(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2813653,      71441]*)
(*NotebookOutlinePosition[   2814350,      71465]*)
(*  CellTagsIndexPosition[   2814306,      71461]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Bad initialization example", "Title"],

Cell[TextData[{
  "This notebook illustrates Gaussian mixture modeling for some 2d synthetic \
data, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{0, 1}, {0, 1}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["No frame ticks", "Subsection"],

Cell[BoxData[{
    \(\(nF = FrameTicks \[Rule] None;\)\), "\[IndentingNewLine]", 
    \(\(FS = Sequence[yS, \ nF];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Specialized data generation and visualization functions", "Subsection"],

Cell[BoxData[
    \(\(AnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {x1\  - \ r2, \ 
              x1 + \ r2}; \[IndentingNewLine]range2\  = \ {x2\  - \ r2, \ 
              x2\  + \ r2}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  < \ 
                  r2\  && \ tst\  > \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(AntiAnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {0, \ 
              1}; \[IndentingNewLine]range2\  = \ {0, 
              1}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  > \ 
                  r2\  || \ tst\  < \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Region definitions", "Subsubsection"],

Cell[BoxData[
    \(\(\(\(c1\  = \ { .5,  .5};\) (*\ 
      center\ of\ annular\ region\ *) \[IndentingNewLine]
    \(rr1\  = \  .12;\) (*\ inner\ radius\ *) \[IndentingNewLine]
    \(rr2\  = \  .35;\)\)\( (*\ outer\ radius\ *) \)\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(DrawAnnularRegion2[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          color2_:  White, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {color2, Disk[center, r1]}}], \ 
            AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot\  := 
        Show[Graphics[{class1Color, 
              Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, rr1, 
            rr2, \ pr, class2Color, \ class1Color, nS]\ , 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize annular region in 2d", "Subsection"],

Cell[CellGroupData[{

Cell["Draw annular region in 2d", "Subsubsection"],

Cell[BoxData[
    \(\(DrawAnnularRegion[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {GrayLevel[1. ], 
                  Disk[center, r1]}}], \ AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for annular region", "Subsubsection"],

Cell[BoxData[
    \(\(AnnularAllPlot[center_, \ r1_, \ 
          r2_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ DrawAnnularRegion[center, 
              rr1, rr2, \ pr, LightPink, \ nF, 
              nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nF, 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nF, nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nF, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              Axes \[Rule] False, nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data generation and visualization", "Section"],

Cell[CellGroupData[{

Cell["Idealized data classes", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
1 1 .5 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo
0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6oooo
o`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC
0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool000030000
0?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3o
oglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3o
ogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
o`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0
000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo
4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?o
ooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0
oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooon60?ooO`P0OoooQ03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooNP3ooglP07ooogP0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooogD0oomo:@1ooomd0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom`0?ooOc<0OoooK`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
KP3ooglg07ooofd0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooofX0oomo@01o
oomX0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomW0?ooOdD0OoooIP3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooI@3oogm907ooof@0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooof<0oomoC@1ooomR0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomQ0?ooOe40OoooH03oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooG`3oogmF07oooed0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooe`0oomoF`1ooomK0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomJ0?oo
Oel0OoooF@3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooF03oogmS07oooeL0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooeL0oomoI@1ooomF0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooomF0?ooOfL0OoooE@3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooE03oogm[07oooe<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooe80oomoK`1ooomA0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooomA0?ooOg40OoooD03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
D03oogmc07ooodl0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodh0oomoM`1o
oom=0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom=0?ooOgP0OoooC@3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooC@3oogmi07oood`0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooood/0oomoO@1ooom:0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooom:0?ooOgl0OoooB@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooB@3oogn107ooodP0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooodP0oomoP`1ooom70?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom70?oo
OhD0OoooAP3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooAP3oogn707ooodD0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodD0oomoR@1ooom40?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooom40?ooOh/0Oooo@`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo@`3oogn=07oood80oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooood80oomoS`1ooom10?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom10?ooOi00Oooo@@3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
@@3oognA07oood00oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocl0oomoU@1o
ooln0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooooln0?ooOiH0Oooo?P3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo?P3oognG07ooocd0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocd0oomoV@1oooll0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooooll0?ooOi/0Oooo>`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo>`3oognL07oooc/0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc/0oomoW@1ooolj0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolj0?oo
Oih0Oooo>P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo>P3oognO07ooocT0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocT0oomoX@1ooolh0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolh0?ooOj<0Oooo=`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo=`3oognT07ooocL0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooocL0oomoY@1ooolf0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolf0?ooOjH0Oooo=P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=P3oognW07ooocD0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocD0oomoZ01o
oole0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooole0?ooOjT0Oooo=03oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=03oognZ07oooc@0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooooc@0oomoZ`1ooolc0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolc0?ooOj`0Oooo<`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo<`3oogn/07oooc<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc<0oomo[@1ooolb0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolb0?oo
Ojh0Oooo<P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo<P3oogn_07oooc40
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc40oomo/01ooola0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooola0?ooOk40Oooo<03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo<03oognb07oooc00oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc00oomo/`1oool_0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00oooool_0?ooOeD0Oooo2`3oogmD07ooobl0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobl0oomoD@1ooolC0?ooOe40Oooo;P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo;P3oogm?07oooaX0oomoC@1oool^0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00oooool^0?ooOdd0Oooo7@3oogm<07ooobh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobh0oomoC01ooolQ0?ooOdT0Oooo;P3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo;P3oogm:07ooob@0oomoB01oool^0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooool^0?ooOdL0Oooo:03oogm807ooobd0oomo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooobd0oomoA`1ooolZ0?ooOdL0Oooo;@3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo;@3oogm607ooob`0oomoA`1oool/0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00oooool/0?ooOdL0Oooo;@3oogm607ooob`0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooob`0oomoAP1oool_0?ooOdD0Oooo;03oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo;03oogm507oooc40oomoA01oool/0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00oooool/0?ooOd@0Oooo<P3oogm407ooob`0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooob`0oomo@`1ooold0?ooOd@0Oooo:`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm407ooocD0oomo@`1oool[0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd<0Oooo=`3oogm207ooob/0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomo@P1oooli0?ooOd40Oooo
:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm207ooocT0oomo@P1o
oolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd80Oooo>`3oogm1
07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@@1oooll0?oo
Od40Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm107oooc`0
oomo@@1ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd00Oooo
?P3oogm007ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@01o
ooln0?ooOd00Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm0
07oooch0oomo@01ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?oo
Od00Oooo?`3ooglo07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0
oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oolZ0?ooOcl0Oooo@03ooglo07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooobX0oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo:P3ooglo07oood40oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolY0?ooOcl0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobT0oomo?`1ooom20?ooOcl0Oooo:@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo:@3ooglo07oood80oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooolY0?ooOcl0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobT0oomo?`1ooom20?ooOcl0Oooo:@3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo:@3ooglo07oood80oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolZ0?ooOch0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooobX0oomo?`1ooom10?ooOch0Oooo:P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooolZ0?ooOcl0Oooo@03ooglo07ooobX0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooobX0oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd00Oooo?`3ooglo07ooobX0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@01oooln0?ooOd00Oooo:P3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm007oooch0oomo@01ooolZ0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd40Oooo?@3oogm007ooobX0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@@1oooll0?ooOd40Oooo
:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm107oooc`0oomo@@1o
oolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd40Oooo>P3oogm2
07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomo@P1oooli0?oo
Od40Oooo:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm207ooocP0
oomo@P1oool[0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd<0Oooo
=P3oogm307ooob/0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomoA01o
oole0?ooOd<0Oooo:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo;03oogm4
07oooc<0oomoA01oool[0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool/0?oo
OdD0Oooo<@3oogm407ooob`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob`0
oomoA@1oool`0?ooOdD0Oooo;03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
;03oogm607ooobh0oomoAP1oool/0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
ool/0?ooOdL0Oooo;03oogm707ooob`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooobd0oomoB01ooolY0?ooOdP0Oooo;03oogl6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo;@3oogm907ooobL0oomoB01oool]0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00oooool^0?ooOd/0Oooo8`3oogm907ooobd0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobh0oomoC@1ooolO0?ooOdX0Oooo;P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo;P3oogm>07oooa/0oomoC@1oool^0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00oooool^0?ooOe40Oooo5`3oogm>07ooobh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobl0oomoD@1ooolC0?ooOe40Oooo;P3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo;`3oogmF07ooo`T0oomoE@1oool_0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooool_0?ooOk@0Oooo;`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo<03oognc07ooobl0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc00oomo/P1oool`0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooola0?oo
Ok40Oooo<03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo<@3oogn`07oooc40
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc80oomo[`1ooola0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolb0?ooOjh0Oooo<P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo<`3oogn]07oooc80oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc<0oomo[01ooolc0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooold0?ooOj/0Oooo<`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=03oognZ07oooc@0oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc@0oomoZP1o
oold0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooole0?ooOjT0Oooo=03oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=@3oognX07ooocD0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocH0oomoY`1ooole0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolf0?ooOjH0Oooo=P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo=`3oognU07ooocH0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooocP0oomoX`1ooolg0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooooli0?oo
Oj40Oooo>03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo>@3oognP07ooocT0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocX0oomoW`1oooli0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolj0?ooOih0Oooo>P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo>`3oognM07ooocX0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc`0oomoV`1ooolk0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolm0?ooOiT0Oooo?03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
?@3oognH07ooocd0oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooch0oomoU`1o
oolm0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom00?ooOi<0Oooo?`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo@03oognB07oood00oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooood40oomoT@1ooom00?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooom20?ooOhl0Oooo@@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo@`3oogn=07oood80oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooood@0oomoR`1ooom30?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom50?oo
OhT0OoooA03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooAP3oogn707ooodD0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodL0oomoQ@1ooom60?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooom80?ooOh<0OoooA`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooB@3oogn107ooodP0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooodX0oomoO`1ooom90?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom<0?ooOg/0OoooB`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
C03oogmj07oood`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodd0oomoN@1o
oom<0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom?0?ooOgD0OoooCP3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooD03oogmc07ooodl0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooooe40oomoL@1ooom@0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomC0?ooOfd0OoooDP3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooE@3oogmY07oooe@0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooeH0oomoI`1ooomE0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomG0?oo
OfD0OoooEP3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooF@3oogmQ07oooeP0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooe/0oomoG@1ooomJ0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooomM0?ooOeT0OoooG03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooH03oogmD07oooeh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooof80oomoC`1ooomQ0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooomT0?ooOd/0OoooH`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
IP3oogm707ooofD0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooofP0oomo@`1o
oomW0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom[0?ooOch0OoooJ@3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooK`3oogle07ooofh0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooog40oomo<@1ooom`0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomf0?ooObL0OoooM@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooN`3ooglN07ooogT0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooohL0oomo1P1ooon50?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?oo
Oa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo
0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6oooo
o`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC
0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool000030000
0?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3o
oglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3o
ogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
o`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0
000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo
4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00o`00000P0000007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[
    \(\(n1\  = \ 1000;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[
    \(\(data1\  = AnnularRegion[c1, \ rr1, \ rr2, \ n1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.69731 .37627 Mdot
.55822 .63893 Mdot
.74094 .54252 Mdot
.39326 .72522 Mdot
.7579 .60297 Mdot
.72463 .54676 Mdot
.5722 .21908 Mdot
.33362 .25536 Mdot
.68197 .59475 Mdot
.18144 .58975 Mdot
.77619 .60588 Mdot
.46636 .79396 Mdot
.65857 .60587 Mdot
.42217 .72379 Mdot
.6538 .64847 Mdot
.54068 .33389 Mdot
.23846 .58625 Mdot
.36392 .23539 Mdot
.35971 .62022 Mdot
.59203 .72103 Mdot
.71191 .23651 Mdot
.30021 .67134 Mdot
.48955 .17974 Mdot
.60669 .8221 Mdot
.20511 .65954 Mdot
.23847 .49518 Mdot
.71312 .62907 Mdot
.48957 .61729 Mdot
.701 .72123 Mdot
.36831 .69836 Mdot
.8035 .41859 Mdot
.46752 .23116 Mdot
.75525 .60219 Mdot
.38592 .57912 Mdot
.19779 .42369 Mdot
.34024 .45971 Mdot
.33993 .5456 Mdot
.29542 .34897 Mdot
.16812 .42865 Mdot
.59683 .22141 Mdot
.256 .6696 Mdot
.36778 .48543 Mdot
.17294 .42965 Mdot
.67615 .72719 Mdot
.77143 .57608 Mdot
.69328 .60815 Mdot
.33146 .51153 Mdot
.59414 .7817 Mdot
.53713 .24208 Mdot
.52106 .65557 Mdot
.36106 .4386 Mdot
.68805 .77152 Mdot
.36841 .56682 Mdot
.44012 .83388 Mdot
.29024 .28343 Mdot
.26552 .47921 Mdot
.53924 .34487 Mdot
.30184 .45312 Mdot
.65273 .79376 Mdot
.63614 .51883 Mdot
.65262 .62724 Mdot
.64 .7976 Mdot
.38636 .17899 Mdot
.57677 .22836 Mdot
.2851 .55948 Mdot
.70385 .24384 Mdot
.20498 .61428 Mdot
.20809 .45973 Mdot
.40812 .65982 Mdot
.53198 .80219 Mdot
.71993 .34144 Mdot
.55198 .64638 Mdot
.49043 .31931 Mdot
.57408 .59337 Mdot
.62856 .53146 Mdot
.37338 .74373 Mdot
.58044 .76032 Mdot
.32216 .44086 Mdot
.32918 .25737 Mdot
.63331 .48181 Mdot
.45239 .75907 Mdot
.2382 .67856 Mdot
.8051 .59662 Mdot
.50725 .24206 Mdot
.20516 .50568 Mdot
.43002 .25449 Mdot
.41974 .81735 Mdot
.2135 .3539 Mdot
.68245 .21389 Mdot
.51013 .79966 Mdot
.25803 .43122 Mdot
.1767 .59579 Mdot
.25265 .44398 Mdot
.23943 .41297 Mdot
.62774 .80722 Mdot
.29145 .3029 Mdot
.43516 .79367 Mdot
.37742 .75307 Mdot
.28163 .46596 Mdot
.23415 .52766 Mdot
.41843 .35232 Mdot
.3925 .29325 Mdot
.50425 .65652 Mdot
.22595 .70598 Mdot
.55305 .39121 Mdot
.48961 .80243 Mdot
.19693 .39571 Mdot
.64106 .7553 Mdot
.46674 .71949 Mdot
.57343 .63664 Mdot
.61821 .76658 Mdot
.51938 .63701 Mdot
.20817 .43649 Mdot
.80947 .40266 Mdot
.67485 .36377 Mdot
.52163 .23835 Mdot
.77588 .46126 Mdot
.82894 .49915 Mdot
.29168 .54909 Mdot
.51907 .6228 Mdot
.56138 .75558 Mdot
.74399 .69936 Mdot
.69268 .41973 Mdot
.60936 .70418 Mdot
.46808 .20462 Mdot
.62355 .36189 Mdot
.33326 .49867 Mdot
.26135 .58223 Mdot
.61502 .58623 Mdot
.36049 .72601 Mdot
.37996 .52061 Mdot
.61374 .65957 Mdot
.62845 .19496 Mdot
.83333 .45454 Mdot
.72885 .71545 Mdot
.52522 .83258 Mdot
.26402 .48555 Mdot
.17114 .5263 Mdot
.60982 .73381 Mdot
.51329 .64796 Mdot
.72797 .60986 Mdot
.43278 .22729 Mdot
.59574 .27409 Mdot
.61945 .1867 Mdot
.48858 .63168 Mdot
.7219 .74101 Mdot
.814 .49784 Mdot
.36547 .24991 Mdot
.76305 .417 Mdot
.20473 .41276 Mdot
.61838 .39772 Mdot
.45213 .29553 Mdot
.80669 .50699 Mdot
.39375 .7075 Mdot
.24166 .60912 Mdot
.42288 .36652 Mdot
.71932 .51607 Mdot
.47259 .2148 Mdot
.39554 .18974 Mdot
.55268 .64094 Mdot
.34767 .62012 Mdot
.77744 .40008 Mdot
.73868 .48145 Mdot
.54162 .32469 Mdot
.69033 .36534 Mdot
.64615 .74337 Mdot
.57547 .65953 Mdot
.38466 .19628 Mdot
.31603 .70235 Mdot
.38066 .67016 Mdot
.68218 .50233 Mdot
.70994 .37503 Mdot
.73893 .52576 Mdot
.76043 .64393 Mdot
.32032 .70937 Mdot
.66696 .54151 Mdot
.77879 .66995 Mdot
.50779 .6823 Mdot
.44653 .26885 Mdot
.73254 .52848 Mdot
.28367 .62769 Mdot
.29725 .62334 Mdot
.6326 .78417 Mdot
.58117 .82266 Mdot
.50547 .77203 Mdot
.69177 .45105 Mdot
.21738 .41908 Mdot
.66917 .2976 Mdot
.33587 .45344 Mdot
.37165 .28859 Mdot
.57901 .59471 Mdot
.23126 .50839 Mdot
.81328 .52367 Mdot
.77948 .63846 Mdot
.71896 .37624 Mdot
.45234 .77503 Mdot
.53996 .76594 Mdot
.75311 .41885 Mdot
.32517 .63421 Mdot
.33096 .66727 Mdot
.25077 .28268 Mdot
.62279 .32094 Mdot
.65211 .55847 Mdot
.65264 .6404 Mdot
.71577 .76315 Mdot
.83994 .54377 Mdot
.23564 .63588 Mdot
.45685 .62097 Mdot
.32566 .3739 Mdot
.83784 .54976 Mdot
.37191 .38569 Mdot
.38566 .30247 Mdot
.51303 .38246 Mdot
.51622 .68183 Mdot
.79565 .38476 Mdot
.63215 .46111 Mdot
.73307 .37001 Mdot
.4171 .23228 Mdot
.50428 .2244 Mdot
.69782 .487 Mdot
.66653 .46635 Mdot
.47503 .16011 Mdot
.71402 .23845 Mdot
.41566 .78554 Mdot
.48796 .71145 Mdot
.45502 .60961 Mdot
.19479 .53419 Mdot
.25061 .43076 Mdot
.34011 .20406 Mdot
.25935 .58882 Mdot
.62745 .58557 Mdot
.64583 .49926 Mdot
.36866 .64317 Mdot
.2605 .66207 Mdot
.28267 .43342 Mdot
.77272 .41385 Mdot
.36575 .49983 Mdot
.30213 .67142 Mdot
.7701 .66311 Mdot
.67819 .62522 Mdot
.73803 .66044 Mdot
.79572 .54454 Mdot
.80845 .40346 Mdot
.58683 .20157 Mdot
.66318 .57518 Mdot
.72971 .54693 Mdot
.17625 .47211 Mdot
.67694 .4504 Mdot
.27549 .56216 Mdot
.74998 .63043 Mdot
.44044 .78008 Mdot
.20351 .56653 Mdot
.74416 .3477 Mdot
.72038 .30356 Mdot
.701 .67459 Mdot
.58237 .26929 Mdot
.75624 .3636 Mdot
.2988 .33235 Mdot
.74428 .39362 Mdot
.65408 .78308 Mdot
.69763 .67023 Mdot
.75306 .59224 Mdot
.47103 .67888 Mdot
.18954 .44555 Mdot
.81728 .39132 Mdot
.33168 .6141 Mdot
.31106 .39729 Mdot
.39796 .19055 Mdot
.45052 .32619 Mdot
.49682 .64007 Mdot
.63958 .38624 Mdot
.72965 .63714 Mdot
.32815 .29095 Mdot
.69698 .34845 Mdot
.35401 .74277 Mdot
.19982 .50235 Mdot
.64499 .46866 Mdot
.47919 .74964 Mdot
.30504 .67173 Mdot
.68276 .52025 Mdot
.50586 .7019 Mdot
.33456 .5678 Mdot
.25612 .53466 Mdot
.5771 .80031 Mdot
.78073 .32268 Mdot
.6474 .72449 Mdot
.2926 .69716 Mdot
.48171 .32353 Mdot
.30401 .59886 Mdot
.43309 .19368 Mdot
.32346 .77383 Mdot
.69912 .23651 Mdot
.38586 .60801 Mdot
.20859 .35516 Mdot
.72666 .3803 Mdot
.26256 .72856 Mdot
.39807 .76884 Mdot
.62399 .56189 Mdot
.70886 .35422 Mdot
.47685 .80616 Mdot
.43264 .31741 Mdot
.57666 .23776 Mdot
.76753 .42432 Mdot
.52493 .72575 Mdot
.67427 .51347 Mdot
.64141 .50231 Mdot
.56857 .62805 Mdot
.4002 .5766 Mdot
.53448 .37924 Mdot
.46774 .26 Mdot
.31435 .22767 Mdot
.52518 .82407 Mdot
.38996 .64648 Mdot
.55883 .28987 Mdot
.35883 .59602 Mdot
.83339 .50496 Mdot
.20253 .4388 Mdot
.42415 .64017 Mdot
.57793 .33566 Mdot
.32231 .57834 Mdot
.42044 .26486 Mdot
.64026 .59741 Mdot
.18734 .46151 Mdot
.64002 .49908 Mdot
.47165 .3285 Mdot
.43804 .7462 Mdot
.4814 .66668 Mdot
.47941 .72679 Mdot
.43573 .38475 Mdot
.73295 .50828 Mdot
.43737 .78423 Mdot
.77837 .30795 Mdot
.17149 .50872 Mdot
.53521 .62507 Mdot
.59014 .18704 Mdot
.72293 .26632 Mdot
.49745 .27617 Mdot
.4729 .62988 Mdot
.74857 .68732 Mdot
.1825 .57786 Mdot
.55274 .79112 Mdot
.17194 .46919 Mdot
.69561 .66576 Mdot
.77438 .47479 Mdot
.35753 .24889 Mdot
.70866 .58005 Mdot
.34254 .21362 Mdot
.77758 .31487 Mdot
.38171 .36688 Mdot
.26453 .30131 Mdot
.36663 .74083 Mdot
.21139 .38666 Mdot
.56986 .68598 Mdot
.71198 .3299 Mdot
.60977 .79326 Mdot
.67533 .63526 Mdot
.69633 .65422 Mdot
.24071 .52755 Mdot
.44113 .3324 Mdot
.64847 .26151 Mdot
.38661 .78888 Mdot
.23547 .41867 Mdot
.63664 .67643 Mdot
.34302 .40805 Mdot
.75255 .72785 Mdot
.25917 .72364 Mdot
.45384 .619 Mdot
.23854 .60657 Mdot
.37523 .35719 Mdot
.56391 .83387 Mdot
.74954 .73179 Mdot
.84044 .49627 Mdot
.39156 .80048 Mdot
.76988 .64731 Mdot
.48214 .22949 Mdot
.66757 .7668 Mdot
.17072 .52032 Mdot
.37059 .30467 Mdot
.36827 .76616 Mdot
.37096 .42675 Mdot
.82254 .46941 Mdot
.20618 .35616 Mdot
.38175 .4325 Mdot
.4834 .71959 Mdot
.55122 .80584 Mdot
.33982 .19655 Mdot
.81199 .61294 Mdot
.49219 .74675 Mdot
.50855 .35843 Mdot
.45756 .22132 Mdot
.49275 .17807 Mdot
.56591 .74281 Mdot
.30575 .41183 Mdot
.61513 .62474 Mdot
.3163 .2683 Mdot
.71367 .70597 Mdot
.66725 .36468 Mdot
.35083 .37657 Mdot
.65847 .33752 Mdot
.35777 .27307 Mdot
.62675 .25411 Mdot
.77741 .6796 Mdot
.16849 .4725 Mdot
.61797 .56816 Mdot
.29795 .60967 Mdot
.79385 .36034 Mdot
.79026 .38996 Mdot
.26171 .37183 Mdot
.75532 .37491 Mdot
.69445 .65832 Mdot
.28543 .27766 Mdot
.27381 .6483 Mdot
.29908 .41055 Mdot
.34836 .20707 Mdot
.76701 .4337 Mdot
.27851 .27764 Mdot
.60932 .2897 Mdot
.36795 .23006 Mdot
.63346 .25107 Mdot
.60473 .44554 Mdot
.68495 .71796 Mdot
.66916 .79618 Mdot
.41461 .41236 Mdot
.33359 .72534 Mdot
.5365 .69854 Mdot
.54326 .63113 Mdot
.51692 .67555 Mdot
.78167 .34245 Mdot
.55346 .67995 Mdot
.25767 .33061 Mdot
.43165 .37757 Mdot
.48874 .36252 Mdot
.54945 .62103 Mdot
.31202 .48032 Mdot
.61189 .69232 Mdot
.49604 .24694 Mdot
.67336 .50673 Mdot
.78572 .41013 Mdot
.57255 .33299 Mdot
.23094 .44814 Mdot
.62017 .74164 Mdot
.65216 .5929 Mdot
.497 .26944 Mdot
.21463 .35498 Mdot
.72824 .42026 Mdot
.56173 .2649 Mdot
.61915 .69791 Mdot
.34143 .62512 Mdot
.76804 .50812 Mdot
.53242 .18908 Mdot
.69732 .38751 Mdot
.63955 .1894 Mdot
.30717 .49938 Mdot
.25229 .58586 Mdot
.45867 .22659 Mdot
.75672 .6631 Mdot
.42852 .3802 Mdot
.73924 .34798 Mdot
.29136 .76746 Mdot
.70382 .42834 Mdot
.49494 .73493 Mdot
.55351 .77209 Mdot
.41712 .81044 Mdot
.45809 .3431 Mdot
.68814 .33777 Mdot
.41648 .80071 Mdot
.65969 .33811 Mdot
.42675 .26337 Mdot
.26304 .40916 Mdot
.64809 .22293 Mdot
.20804 .3985 Mdot
.54348 .77072 Mdot
.79325 .39827 Mdot
.18528 .39997 Mdot
.60166 .29346 Mdot
.25722 .57072 Mdot
.49231 .6195 Mdot
.58444 .19345 Mdot
.76888 .53079 Mdot
.55602 .63661 Mdot
.79749 .50002 Mdot
.46198 .82333 Mdot
.36232 .50263 Mdot
.16657 .47554 Mdot
.6646 .74688 Mdot
.5174 .69917 Mdot
.28691 .46889 Mdot
.56857 .16411 Mdot
.64283 .47646 Mdot
.61851 .7885 Mdot
.67291 .63619 Mdot
.24827 .61379 Mdot
.72139 .42041 Mdot
.72315 .28694 Mdot
.34306 .34927 Mdot
.64266 .36139 Mdot
.18101 .41603 Mdot
.41534 .78934 Mdot
.32394 .33242 Mdot
.59149 .26455 Mdot
.64424 .56902 Mdot
.41571 .27645 Mdot
.76423 .43895 Mdot
.76482 .71672 Mdot
.25429 .66153 Mdot
.68209 .71532 Mdot
.38239 .66352 Mdot
.80982 .54393 Mdot
.79283 .5318 Mdot
.73717 .61675 Mdot
.67126 .45424 Mdot
.57383 .63585 Mdot
.37673 .38076 Mdot
.3293 .69539 Mdot
.36261 .30832 Mdot
.55626 .72135 Mdot
.72814 .42398 Mdot
.49623 .63467 Mdot
.31118 .63127 Mdot
.41944 .71074 Mdot
.41268 .67505 Mdot
.19957 .48684 Mdot
.53676 .23369 Mdot
.72077 .67135 Mdot
.40905 .29351 Mdot
.75596 .50197 Mdot
.47903 .78892 Mdot
.57161 .67136 Mdot
.80492 .51348 Mdot
.31942 .53472 Mdot
.70943 .58199 Mdot
.4066 .18961 Mdot
.76826 .43862 Mdot
.46128 .7216 Mdot
.77179 .39923 Mdot
.47941 .7428 Mdot
.31088 .25266 Mdot
.33864 .50396 Mdot
.38576 .65717 Mdot
.72049 .6255 Mdot
.79184 .38313 Mdot
.21486 .59096 Mdot
.23277 .39969 Mdot
.21246 .56504 Mdot
.74471 .46925 Mdot
.63449 .37136 Mdot
.51582 .65521 Mdot
.75713 .589 Mdot
.53345 .1609 Mdot
.80843 .36273 Mdot
.49601 .7224 Mdot
.77765 .46722 Mdot
.34395 .44835 Mdot
.80452 .59189 Mdot
.44237 .82224 Mdot
.3269 .37739 Mdot
.76969 .32389 Mdot
.4129 .63153 Mdot
.3931 .31985 Mdot
.79474 .5464 Mdot
.5181 .73652 Mdot
.33101 .44504 Mdot
.21257 .48729 Mdot
.73178 .46594 Mdot
.72881 .26677 Mdot
.56899 .82219 Mdot
.65134 .22915 Mdot
.23042 .50631 Mdot
.2901 .33576 Mdot
.21333 .42713 Mdot
.22731 .42479 Mdot
.27195 .67307 Mdot
.26522 .28274 Mdot
.64232 .35156 Mdot
.53937 .30369 Mdot
.61716 .29884 Mdot
.5436 .63567 Mdot
.59793 .73878 Mdot
.48714 .3654 Mdot
.37129 .59562 Mdot
.5721 .40093 Mdot
.7638 .30742 Mdot
.4347 .33724 Mdot
.639 .33233 Mdot
.43782 .67546 Mdot
.22747 .59534 Mdot
.61057 .29795 Mdot
.49443 .67891 Mdot
.65728 .75764 Mdot
.28503 .26727 Mdot
.37945 .57726 Mdot
.58359 .4018 Mdot
.76615 .33393 Mdot
.51298 .6496 Mdot
.69962 .25409 Mdot
.74555 .50852 Mdot
.36205 .41832 Mdot
.2125 .51799 Mdot
.66569 .68463 Mdot
.39835 .60348 Mdot
.33356 .56484 Mdot
.43531 .62442 Mdot
.41054 .38778 Mdot
.55405 .29055 Mdot
.17678 .4663 Mdot
.34886 .71537 Mdot
.52631 .1876 Mdot
.56594 .34483 Mdot
.83192 .45651 Mdot
.54704 .31861 Mdot
.65522 .7348 Mdot
.26859 .53733 Mdot
.34626 .56251 Mdot
.69063 .3702 Mdot
.32633 .25308 Mdot
.36205 .30477 Mdot
.81546 .46722 Mdot
.63924 .80308 Mdot
.24907 .64133 Mdot
.32832 .27591 Mdot
.76991 .61516 Mdot
.63423 .54149 Mdot
.23614 .40183 Mdot
.58065 .747 Mdot
.25957 .29737 Mdot
.60832 .43664 Mdot
.46347 .33743 Mdot
.62478 .42592 Mdot
.37126 .53923 Mdot
.45333 .30688 Mdot
.39077 .43523 Mdot
.59968 .73688 Mdot
.44728 .28989 Mdot
.29179 .44847 Mdot
.70978 .38602 Mdot
.56875 .81368 Mdot
.35436 .43131 Mdot
.49678 .68173 Mdot
.3639 .25919 Mdot
.20636 .54871 Mdot
.22897 .65386 Mdot
.33972 .31954 Mdot
.19675 .50275 Mdot
.23827 .37016 Mdot
.60474 .68984 Mdot
.27364 .25777 Mdot
.31006 .26169 Mdot
.24148 .63466 Mdot
.71719 .34864 Mdot
.69541 .76641 Mdot
.6773 .68902 Mdot
.61401 .55311 Mdot
.36303 .31367 Mdot
.42788 .39002 Mdot
.34326 .59851 Mdot
.30813 .51256 Mdot
.27283 .59993 Mdot
.43867 .75405 Mdot
.2325 .59724 Mdot
.67571 .32977 Mdot
.8294 .54134 Mdot
.4047 .78288 Mdot
.20694 .59027 Mdot
.2183 .34124 Mdot
.21692 .6417 Mdot
.75331 .67182 Mdot
.45432 .23939 Mdot
.50542 .28772 Mdot
.61248 .20322 Mdot
.44352 .83541 Mdot
.53207 .77685 Mdot
.39345 .40201 Mdot
.33339 .60345 Mdot
.56045 .76379 Mdot
.38931 .56168 Mdot
.26299 .68126 Mdot
.72703 .43083 Mdot
.49365 .63491 Mdot
.45411 .74035 Mdot
.55688 .76146 Mdot
.55419 .39214 Mdot
.44062 .74262 Mdot
.83687 .47148 Mdot
.20817 .3378 Mdot
.73074 .63335 Mdot
.32428 .75011 Mdot
.68021 .23699 Mdot
.70272 .26168 Mdot
.65539 .25237 Mdot
.24243 .60188 Mdot
.25807 .70337 Mdot
.64495 .70239 Mdot
.26433 .38876 Mdot
.37673 .59854 Mdot
.42623 .61448 Mdot
.82591 .6001 Mdot
.55606 .60472 Mdot
.30256 .51997 Mdot
.69648 .49991 Mdot
.61091 .74117 Mdot
.3891 .56422 Mdot
.28163 .33233 Mdot
.37231 .51733 Mdot
.74804 .57693 Mdot
.39003 .29812 Mdot
.61957 .45685 Mdot
.53669 .64135 Mdot
.74016 .46817 Mdot
.6154 .2927 Mdot
.58752 .34408 Mdot
.7105 .55891 Mdot
.64143 .44123 Mdot
.78837 .58208 Mdot
.40827 .29997 Mdot
.32566 .28209 Mdot
.71472 .50176 Mdot
.78894 .60158 Mdot
.29938 .62467 Mdot
.65976 .77306 Mdot
.60016 .26858 Mdot
.71453 .34784 Mdot
.54573 .22261 Mdot
.50619 .81604 Mdot
.53137 .70841 Mdot
.36367 .34824 Mdot
.5454 .81137 Mdot
.67968 .70255 Mdot
.30381 .41528 Mdot
.54679 .30356 Mdot
.30539 .58165 Mdot
.3549 .33495 Mdot
.72086 .71124 Mdot
.25348 .543 Mdot
.73295 .35163 Mdot
.64409 .19146 Mdot
.21012 .49222 Mdot
.49715 .61932 Mdot
.1902 .56273 Mdot
.7935 .47262 Mdot
.59546 .29453 Mdot
.28201 .46516 Mdot
.71773 .42642 Mdot
.29559 .57053 Mdot
.72729 .38898 Mdot
.387 .6128 Mdot
.20899 .51559 Mdot
.43664 .29705 Mdot
.32418 .53451 Mdot
.80972 .5761 Mdot
.43835 .30938 Mdot
.71804 .57665 Mdot
.5542 .76354 Mdot
.63258 .49834 Mdot
.32406 .3076 Mdot
.58045 .82589 Mdot
.37097 .3789 Mdot
.23651 .43192 Mdot
.35734 .23171 Mdot
.6413 .2794 Mdot
.24396 .359 Mdot
.69941 .56887 Mdot
.4853 .34683 Mdot
.74975 .6009 Mdot
.28483 .27199 Mdot
.26532 .47836 Mdot
.64553 .61693 Mdot
.79568 .61707 Mdot
.68313 .59996 Mdot
.49843 .68426 Mdot
.33295 .39338 Mdot
.37046 .56913 Mdot
.56807 .79534 Mdot
.20314 .63879 Mdot
.61553 .33514 Mdot
.78797 .57084 Mdot
.77553 .57831 Mdot
.719 .54374 Mdot
.7918 .54722 Mdot
.6363 .54946 Mdot
.45024 .7061 Mdot
.46021 .31295 Mdot
.23664 .29383 Mdot
.39257 .39794 Mdot
.51171 .34162 Mdot
.34629 .60228 Mdot
.40146 .1883 Mdot
.80693 .42817 Mdot
.56489 .17485 Mdot
.42909 .62528 Mdot
.48512 .72416 Mdot
.19338 .38421 Mdot
.81654 .5394 Mdot
.69022 .62507 Mdot
.23408 .53292 Mdot
.27028 .26161 Mdot
.25515 .38066 Mdot
.53339 .36268 Mdot
.20514 .48166 Mdot
.56513 .31507 Mdot
.71804 .53314 Mdot
.42929 .78265 Mdot
.72737 .30459 Mdot
.50927 .67671 Mdot
.62909 .76707 Mdot
.25256 .56126 Mdot
.31178 .65153 Mdot
.43687 .27525 Mdot
.24752 .58027 Mdot
.46157 .65634 Mdot
.36587 .25195 Mdot
.34591 .72127 Mdot
.55108 .25663 Mdot
.54349 .76402 Mdot
.28036 .41299 Mdot
.20204 .41872 Mdot
.66193 .59979 Mdot
.18227 .42557 Mdot
.72568 .39902 Mdot
.29134 .48923 Mdot
.78857 .61109 Mdot
.34351 .76737 Mdot
.57441 .61782 Mdot
.45092 .36169 Mdot
.59798 .58463 Mdot
.63212 .60504 Mdot
.57257 .31592 Mdot
.33606 .25719 Mdot
.69003 .76004 Mdot
.20158 .6111 Mdot
.60879 .81181 Mdot
.52488 .38219 Mdot
.36766 .3807 Mdot
.63822 .22164 Mdot
.26265 .31513 Mdot
.21793 .54716 Mdot
.80491 .54715 Mdot
.3871 .44317 Mdot
.4369 .32183 Mdot
.36294 .30133 Mdot
.41559 .18924 Mdot
.65845 .57075 Mdot
.46739 .72764 Mdot
.59739 .18044 Mdot
.63561 .47643 Mdot
.35557 .31146 Mdot
.66293 .55165 Mdot
.60911 .4545 Mdot
.35039 .42213 Mdot
.72613 .53763 Mdot
.65884 .52993 Mdot
.41149 .22183 Mdot
.66765 .74204 Mdot
.67502 .73191 Mdot
.60349 .60765 Mdot
.34726 .211 Mdot
.66481 .22643 Mdot
.68382 .57181 Mdot
.6776 .45598 Mdot
.40532 .23225 Mdot
.28666 .69192 Mdot
.46499 .62236 Mdot
.21168 .61776 Mdot
.33433 .45453 Mdot
.39594 .32019 Mdot
.32552 .61463 Mdot
.56149 .70735 Mdot
.76334 .53924 Mdot
.43169 .17229 Mdot
.70529 .51798 Mdot
.80983 .39307 Mdot
.75502 .61845 Mdot
.82632 .54006 Mdot
.54421 .64962 Mdot
.65766 .76857 Mdot
.73745 .38619 Mdot
.55104 .76999 Mdot
.6965 .69041 Mdot
.67246 .75848 Mdot
.53585 .69582 Mdot
.55267 .31262 Mdot
.34496 .2959 Mdot
.73815 .38719 Mdot
.36223 .35363 Mdot
.65433 .42677 Mdot
.27204 .44237 Mdot
.39754 .82077 Mdot
.57932 .58969 Mdot
.50837 .18897 Mdot
.18351 .43394 Mdot
.32027 .7362 Mdot
.80118 .53944 Mdot
.30371 .26953 Mdot
.31926 .75611 Mdot
.23371 .37655 Mdot
.20408 .47059 Mdot
.67931 .39892 Mdot
.4679 .72404 Mdot
.32781 .36681 Mdot
.1644 .47375 Mdot
.30961 .40021 Mdot
.74578 .66478 Mdot
.70255 .44149 Mdot
.66893 .44509 Mdot
.3443 .24685 Mdot
.66181 .67936 Mdot
.74619 .64303 Mdot
.65428 .36248 Mdot
.59345 .39968 Mdot
.60479 .42816 Mdot
.57163 .20209 Mdot
.70214 .60652 Mdot
.71222 .60374 Mdot
.21375 .63285 Mdot
.71258 .54286 Mdot
.38178 .43589 Mdot
.57064 .23028 Mdot
.37294 .50015 Mdot
.80899 .64525 Mdot
.64445 .45492 Mdot
.77537 .69432 Mdot
.18692 .60519 Mdot
.16277 .51861 Mdot
.64828 .32615 Mdot
.19638 .61877 Mdot
.66657 .27549 Mdot
.26865 .45062 Mdot
.77443 .53458 Mdot
.37141 .75105 Mdot
.36551 .3893 Mdot
.25295 .60324 Mdot
.32599 .61367 Mdot
.17531 .50737 Mdot
.48044 .67448 Mdot
.74485 .64487 Mdot
.39054 .7051 Mdot
.22606 .33775 Mdot
.65363 .56475 Mdot
.81624 .57765 Mdot
.4845 .79422 Mdot
.82507 .45604 Mdot
.5015 .6247 Mdot
.30315 .36866 Mdot
.33273 .25838 Mdot
.29042 .34297 Mdot
.79683 .4497 Mdot
.33576 .27269 Mdot
.28775 .25916 Mdot
.47026 .36896 Mdot
.3593 .44936 Mdot
.65187 .63212 Mdot
.26748 .48382 Mdot
.5452 .7115 Mdot
.67243 .2399 Mdot
.71873 .63334 Mdot
.23274 .40956 Mdot
.74698 .63968 Mdot
.80353 .41676 Mdot
.30852 .62778 Mdot
.8068 .49441 Mdot
.60645 .75942 Mdot
.29123 .41138 Mdot
.35167 .3909 Mdot
.41564 .62118 Mdot
.5118 .82463 Mdot
.3308 .67408 Mdot
.23508 .55391 Mdot
.37041 .41419 Mdot
.21876 .62955 Mdot
.45545 .71327 Mdot
.74905 .6699 Mdot
.26063 .47923 Mdot
.49028 .20558 Mdot
.82798 .49789 Mdot
.65404 .66695 Mdot
.7434 .51331 Mdot
.37859 .62321 Mdot
.69918 .6995 Mdot
.66251 .43071 Mdot
.45985 .82402 Mdot
.67767 .77596 Mdot
.48137 .7568 Mdot
.5811 .40035 Mdot
.58315 .69939 Mdot
.68478 .46272 Mdot
.36142 .23303 Mdot
.43828 .32309 Mdot
.19233 .57675 Mdot
.61891 .73551 Mdot
.57562 .59586 Mdot
.25112 .6822 Mdot
.76075 .69368 Mdot
.68592 .36964 Mdot
.65045 .63602 Mdot
.759 .70266 Mdot
.46741 .76239 Mdot
.63903 .7864 Mdot
.74948 .29388 Mdot
.79625 .57363 Mdot
.37157 .54199 Mdot
.45571 .68246 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oo
oooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001
ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooooooo
ool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo
00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolL
ooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003o
ooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o0000
0Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0Q?ooool3ool000gooooo0ooo0024ooooo`7o00000Oooool00003o`000?oooooooooo
08?ooooo1Ooo000;ooooo`Goo`001_ooool3ool007[ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Poooool5ool000_ooooo1Ooo0005ooooo`Goo`00NOooool1o`00007ooooo00000ol0003ooooo
ooooo`1gooooo`?oo`002Oooool5ool000_ooooo1Ooo0005ooooo`Goo`00NOooool1o`00007ooooo
00000ol0003oooooooooo`1fooooo`Goo`002Oooool3ool000gooooo0ooo0006ooooo`Goo`00NOoo
ool1o`00007ooooo00000ol0003oooooooooo`1Zooooo`?oo`002Oooool5ool000gooooo1?oo000@
ooooo`Goo`00N_ooool1o`00007ooooo00000ol0003oooooooooo`1Yooooo`Goo`002?ooool5ool0
00cooooo1_oo000?ooooo`Goo`001_ooool3ool0077ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0JOooool5ool000Wooooo0ooo000=ooooo`Koo`003oooool5ool000Gooooo1Ooo0002ooooo`?o
o`00Joooool1o`00007ooooo00000ol0003oooooooooo`1Yooooo`coo`004_ooool9ool000;ooooo
1Ooo0006ooooo`?oo`001Oooool6ool00003oooooooo003oo`0000?oo`000_ooool3ool006Gooooo
0Ol00001ooooo`0000?o0000ooooooooool0J_ooool<ool000;ooooo0ooo000=oooooa3oo`002ooo
ool8ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00000ooo001Tooooo`7o00000Ooo
ool00003o`000?oooooooooo05gooooo0ooo000:ooooo`coo`0000?oooooool00?oo00000ooo000@
ooooo`coo`002_ooool8ool000;ooooo3?oo001Sooooo`7o00000Oooool00003o`000?oooooooooo
05cooooo1Ooo0008ooooo`goo`0000?oooooool00?oo00000ooo000@ooooo`coo`002_ooool7ool0
00Cooooo2ooo001Sooooo`7o00000Oooool00003o`000?oooooooooo05cooooo1Ooo0008ooooo`co
o`000_ooool5ool0017ooooo0ooo0002ooooo`Goo`002?ooool9ool000?ooooo0ooo00000ooooooo
o`00ool00007ool006?ooooo0Ol00001ooooo`0000?o0000ooooooooool0G?ooool6ool000Oooooo
1ooo0008ooooo`?oo`001oooool3ool000?ooooo0ooo000Cooooo`[oo`000_ooool=ool006Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0G?ooool7ool000Oooooo0ooo000Dooooo`Goo`0000?o
ooooool00?oo00000ooo000Booooo`[oo`000_ooool5ool00004oooooooo003oo`00ool006Sooooo
0Ol00001ooooo`0000?o0000ooooooooool0G?ooool7ool001kooooo1Ooo00000oooooooo`00ool0
0003ool001;ooooo2_oo0002ooooo`Goo`004?ooool3ool005Wooooo0Ol00001ooooo`0000?o0000
ooooooooool0GOooool6ool001kooooo1Ooo00000oooooooo`00ool00003ool001?ooooo0ooo0002
ooooo`?oo`001?ooool3ool0013ooooo1Ooo001Hooooo`7o00000Oooool00003o`000?oooooooooo
05gooooo1_oo000Looooo`Soo`0000Coooooool00?oo003oo`005?ooool3ool000Cooooo0ooo0009
ooooo`?oo`002Oooool5ool005Sooooo0Ol00001ooooo`0000?o0000ooooooooool0GOooool5ool0
00oooooo0ooo000:ooooo`Woo`001Oooool3ool000Wooooo0ooo0003ooooo`Goo`000_ooool5ool0
00Oooooo1ooo0006ooooo`Goo`00F?ooool1o`00007ooooo00000ol0003oooooooooo`1Eooooo`?o
o`001_ooool3ool000oooooo1Ooo0002ooooo`?oo`001?ooool9ool000Cooooo1Ooo0007ooooo`Go
o`000_ooool6ool00003oooooooo003oo`0000?oo`001oooool8ool00004oooooooo003oo`00ool0
00;ooooo0ooo001Iooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo1Ooo0009ooooo`Ko
o`002?ooool5ool00003oooooooo003oo`0000?oo`000oooool;ool000;ooooo1Ooo0007ooooo`Go
o`000_ooool<ool000Oooooo3Ooo001Mooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo
1Ooo0008ooooo`Soo`001oooool;ool000?ooooo3?oo00000oooooooo`00ool00003ool000Gooooo
1ooo0002ooooo`Ooo`0000Coooooool00?oo003oo`002Oooool<ool005gooooo0Ol00001ooooo`00
00?o0000ooooooooool0E?ooool5ool000Sooooo2?oo0006ooooo`coo`000oooool<ool000;ooooo
0ooo0002ooooo`[oo`000oooool7ool0013ooooo3?oo0003ooooo`Ooo`00D?ooool1o`00007ooooo
00000ol0003oooooooooo`1Eooooo`?oo`002Oooool8ool000Kooooo2ooo0004ooooo`coo`000ooo
ool<ool000Gooooo1ooo000@ooooo`goo`0000?oooooool00?oo00001ooo001?ooooo`7o00000Ooo
ool00003o`000?oooooooooo06;ooooo1_oo0007ooooo`Soo`001_ooool7ool000;ooooo0ooo0003
ooooo`goo`001_ooool6ool0017ooooo0ooo0002ooooo`Ooo`0000?oooooool00?oo00001ooo001?
ooooo`7o00000Oooool00003o`000?oooooooooo05kooooo0ooo00000oooooooo`00ool00003ool0
00Wooooo1_oo0007ooooo`Goo`002?ooool?ool000Oooooo1Ooo000Fooooo`Ooo`0000?oooooool0
0?oo00001ooo001?ooooo`7o00000Oooool00003o`000?oooooooooo05Cooooo0ooo0006ooooo`[o
o`005_ooool5ool000Oooooo4?oo0008ooooo`?oo`003Oooool3ool000?ooooo0ooo00000ooooooo
o`00ool00004ool000?ooooo1ooo001@ooooo`7o00000Oooool00003o`000?oooooooooo05?ooooo
1Ooo00000oooooooo`00ool0000=ool000oooooo0ooo0004ooooo`?oo`002?ooool7ool000Gooooo
0ooo000Gooooo`Koo`0000?oooooool00?oo00000ooo00001?ooooooo`00ool00?oo0005ooooo`Go
o`00D_ooool1o`00007ooooo00000ol0003oooooooooo`1:ooooo`?oo`0000Coooooool00?oo003o
o`000_oooolEool000kooooo1Ooo0006ooooo`?oo`001Oooool5ool000_ooooo0ooo000Booooo`Oo
o`0000?oooooool00?oo00000ooo0008ooooo`Goo`00Doooool1o`00007ooooo00000ol0003ooooo
ooooo`19ooooo`Woo`0000?oooooool00?oo00003?oo00000oooooooo`00ool00004ool000kooooo
1Ooo0005ooooo`Goo`001Oooool3ool000_ooooo1Ooo000Aooooo`goo`002?ooool5ool005?ooooo
0Ol00001ooooo`0000?o0000ooooooooool0B?ooool:ool00003oooooooo003oo`0000_oo`000ooo
ool5ool000cooooo1ooo0005ooooo`Goo`004oooool7ool000Kooooo0ooo0006ooooo`coo`002Ooo
ool6ool000;ooooo1?oo001<ooooo`7o00000Oooool00003o`000?oooooooooo04Sooooo6?oo0003
ooooo`Goo`002oooool7ool00004oooooooo003oo`00ool000;ooooo1Ooo0005ooooo`?oo`002ooo
ool8ool000;ooooo2?oo0005ooooo`?oo`000_ooool5ool000_ooooo1Ooo00000oooooooo`00ool0
0004ool004_ooooo0Ol00001ooooo`0000?o0000ooooooooool0B?oooolGool000?ooooo1Ooo000<
ooooo`coo`000_ooool3ool000Gooooo1Ooo000;ooooo`Ooo`0000?oooooool00?oo00002?oo0009
ooooo`Goo`002oooool5ool00003oooooooo003oo`0000Coo`00Boooool1o`00007ooooo00000ol0
003oooooooooo`19oooooaOoo`0000?oooooool00?oo00000ooo000=ooooo`coo`002_ooool5ool0
00gooooo1Ooo00000oooooooo`00ool00008ool000[ooooo0ooo0002ooooo`?oo`002?ooool3ool0
00;ooooo1_oo001;ooooo`7o00000Oooool00003o`000?oooooooooo04_ooooo5Ooo00000ooooooo
o`00ool00003ool000cooooo1Ooo00000oooooooo`00ool00005ool000[ooooo1Ooo000>ooooo`?o
o`000_ooool:ool000Sooooo0ooo0003ooooo`Goo`003Oooool4ool004cooooo0Ol00001ooooo`00
00?o0000ooooooooool0@oooool3ool00003oooooooo003oo`0000coo`0000?oooooool00?oo0000
2?oo00000oooooooo`00ool00003ool000cooooo1Ooo00000oooooooo`00ool00004ool000_ooooo
1Ooo000Dooooo`Soo`002?ooool5ool000;ooooo1Ooo001Mooooo`7o00000Oooool00003o`000?oo
oooooooo04;ooooo4Ooo0005ooooo`Ooo`000oooool3ool000gooooo1Ooo00000oooooooo`00ool0
0003ool000cooooo1_oo000Fooooo`Goo`002?ooool5ool000;ooooo1Ooo000=ooooo`?oo`00COoo
ool1o`00007ooooo00000ol0003oooooooooo`12oooooa7oo`001Oooool5ool000Wooooo0ooo000:
ooooo`?oo`000oooool6ool000_ooooo1_oo000:ooooo`Goo`001oooool3ool00004oooooooo003o
o`00ool000Gooooo1Ooo0003ooooo`?oo`003Oooool5ool004cooooo0Ol00001ooooo`0000?o0000
ooooooooool0?ooooolDool000Gooooo1Ooo0008ooooo`Goo`000_ooool3ool000;ooooo0ooo0007
ooooo`Goo`002oooool5ool000Wooooo1ooo0006ooooo`Woo`001?ooool3ool001Cooooo1Ooo0003
ooooo`?oo`00A_ooool1o`00007ooooo00000ol0003oooooooooo`0nooooo`coo`001Oooool3ool0
00Kooooo1Ooo00001?ooooooo`00ool00?oo0004ooooo`Goo`0000?oooooool00?oo00002?oo0004
ooooo`Ooo`002oooool5ool000Wooooo1ooo0005ooooo`_oo`002oooool3ool000cooooo1Ooo0002
ooooo`Goo`00AOooool1o`00007ooooo00000ol0003oooooooooo`0nooooo`Goo`000_ooool5ool0
00kooooo2_oo00000oooooooo`00ool0000@ool000?ooooo2Ooo000;ooooo`?oo`002_ooool7ool0
00Gooooo2ooo000:ooooo`Goo`003?ooool3ool000?ooooo1Ooo0015ooooo`7o00000Oooool00003
o`000?oooooooooo03kooooo1Ooo0002ooooo`Koo`001?ooool3ool000Oooooo0ooo00000ooooooo
o`00ool0000:ool00003oooooooo003oo`0000Woo`000oooool9ool001Gooooo2Ooo0006ooooo`_o
o`002_ooool5ool000_ooooo1Ooo0002ooooo`Goo`00AOooool1o`00007ooooo00000ol0003ooooo
ooooo`0oooooo`?oo`000oooool6ool000?ooooo1Ooo0005ooooo`?oo`000_oooolGool000Cooooo
2Ooo000Dooooo`Ooo`002_ooool:ool000[ooooo1Ooo000:ooooo`Ooo`000_ooool3ool00004oooo
oooo003oo`00ool000;ooooo0ooo000mooooo`7o00000Oooool00003o`000?oooooooooo04Kooooo
1Ooo0003ooooo`Goo`001?ooool5ool000;ooooo4?oo00000oooooooo`00ool00003ool000Gooooo
2?oo000Dooooo`Ooo`003_ooool6ool000_ooooo0ooo000;ooooo`Ooo`001Oooool:ool003cooooo
0Ol00001ooooo`0000?o0000ooooooooool0Aoooool3ool000Cooooo1Ooo0004ooooo`Goo`001?oo
ool>ool000;ooooo0ooo0005ooooo`[oo`004oooool;ool000cooooo0ooo000Jooooo`Ooo`001Ooo
ool:ool003cooooo0Ol00001ooooo`0000?o0000ooooooooool0A_ooool5ool000Cooooo0ooo0005
ooooo`Goo`001?ooool9ool00004oooooooo003oo`00ool000[ooooo3?oo0005ooooo`?oo`002ooo
ool<ool002Sooooo1Ooo0006ooooo`[oo`00??ooool1o`00007ooooo00000ol0003oooooooooo`16
ooooo`Goo`003Oooool3ool000;ooooo2_oo0005ooooo`Coo`001_ooool=ool000Cooooo1Ooo000;
ooooo`coo`002oooool3ool002Gooooo2?oo000mooooo`7o00000Oooool00003o`000?oooooooooo
04Kooooo1Ooo000Aooooo`_oo`001?ooool6ool000Gooooo3Ooo0002ooooo`Ooo`002oooool<ool0
00[ooooo1Ooo0003ooooo`?oo`008?ooool7ool003cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Aoooool3ool001;ooooo1Ooo0002ooooo`?oo`001Oooool6ool000Gooooo3?oo00000ooooooo
o`00ool00007ool000[ooooo3Ooo000:ooooo`Goo`000_ooool5ool000Cooooo0ooo000Gooooo`So
o`00??ooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`?oo`001?ooool3ool000;ooooo
0ooo0004ooooo`?oo`0000?oooooool00?oo00000ooo000:ooooo`Koo`001_ooool:ool00003oooo
oooo003oo`0000Ooo`002oooool5ool000Cooooo0ooo000;ooooo`Goo`0000?oooooool00?oo0000
1?oo0003ooooo`Goo`001_ooool3ool000gooooo2?oo000looooo`7o00000Oooool00003o`000?oo
oooooooo04Cooooo1Ooo0002ooooo`[oo`000_ooool5ool00005oooooooo003oo`00ool00?ooool0
0ooo0008ooooo`Coo`002?ooool9ool00003oooooooo003oo`0000Goo`003Oooool5ool000?ooooo
1_oo0008ooooo`Goo`0000?oooooool00?oo00001Ooo0003ooooo`Goo`001Oooool5ool000cooooo
1ooo000mooooo`7o00000Oooool00003o`000?oooooooooo03Oooooo0ooo0002ooooo`?oo`001Ooo
ool5ool000;ooooo2_oo0002ooooo`Goo`001?ooool5ool001?ooooo4?oo000=ooooo`Goo`001?oo
ool7ool000Kooooo1Ooo0002ooooo`Woo`0000?oooooool00?oo00001_oo0002ooooo`Goo`002ooo
ool5ool0043ooooo0Ol00001ooooo`0000?o0000ooooooooool0=_ooool:ool000Cooooo1Ooo0002
ooooo`[oo`000_ooool5ool000Cooooo1Ooo000Booooo`Ooo`0000?oooooool00?oo00001Ooo0008
ooooo`?oo`001?ooool5ool000Cooooo1ooo0006ooooo`Goo`000_ooool:ool00003oooooooo003o
o`0000Koo`0000?oooooool00?oo00001Ooo0009ooooo`Soo`00?Oooool1o`00007ooooo00000ol0
003oooooooooo`0fooooo`[oo`001Oooool3ool000Cooooo2?oo0004ooooo`?oo`001Oooool5ool0
01;ooooo1_oo00000oooooooo`00ool00004ool000;ooooo0ooo0004ooooo`Goo`000oooool5ool0
00Cooooo2Ooo0004ooooo`Goo`000oooool3ool00003oooooooo003oo`0000?oo`001?ooool5ool0
00;ooooo1ooo0008ooooo`Woo`00??ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`[o
o`003_ooool5ool000_ooooo2Ooo000@ooooo`Goo`000_ooool6ool00003oooooooo003oo`0000?o
o`000oooool5ool000?ooooo1Ooo0003ooooo`_oo`001?ooool3ool000Sooooo1Ooo0004ooooo`Ko
o`000_ooool6ool00003oooooooo003oo`0000?oo`000oooool8ool003cooooo0Ol00001ooooo`00
00?o0000ooooooooool0=oooool8ool000oooooo1_oo0009ooooo`Goo`0000?oooooool00?oo0000
0ooo000;ooooo`?oo`000_ooool3ool000?ooooo1Ooo0002ooooo`Goo`000oooool5ool000?ooooo
1Ooo0003ooooo`Goo`0000?oooooool00?oo00000ooo000;ooooo`?oo`000_ooool3ool000Kooooo
5?oo0005ooooo`Goo`00??ooool1o`00007ooooo00000ol0003oooooooooo`0fooooo`Ooo`004_oo
ool5ool000Wooooo3Ooo0008ooooo`Goo`002?ooool3ool000?ooooo1Ooo0004ooooo`?oo`001?oo
ool5ool000?ooooo1Ooo00000oooooooo`00ool00003ool000[ooooo1Ooo000;oooooa?oo`001_oo
ool3ool003gooooo0Ol00001ooooo`0000?o0000ooooooooool0=Oooool8ool000Cooooo0ooo000;
ooooo`Goo`002Oooool>ool000Oooooo1Ooo000?ooooo`?oo`001?ooool3ool000Kooooo0ooo0005
ooooo`?oo`000oooool3ool000_ooooo1Ooo000;oooooa?oo`002_ooool3ool003Wooooo0Ol00001
ooooo`0000?o0000ooooooooool0=Oooool8ool000?ooooo1Ooo000;ooooo`?oo`002oooool3ool0
0003oooooooo003oo`0000Ooo`001oooool5ool000Kooooo0ooo0007ooooo`?oo`000_ooool5ool0
00?ooooo0ooo000Gooooo`?oo`0000?oooooool00?oo00001_oo0003ooooo`?oo`000ooooolDool0
00Oooooo2?oo000eooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo2?oo0003ooooo`Go
o`005?ooool3ool000Oooooo2Ooo0007ooooo`Goo`001?ooool5ool000Gooooo1Ooo00000ooooooo
o`00ool00003ool000;ooooo1Ooo000Eooooo`Goo`0000?oooooool00?oo00003ooo0002ooooo`Go
o`000_ooool3ool000?ooooo1Ooo0006ooooo`Woo`00=?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0fooooo`Koo`001?ooool5ool000gooooo0ooo0003ooooo`Goo`002_ooool6ool000Oooooo
1Ooo0003ooooo`Goo`0000Goooooool00?oo003oo`00ooooo`05ool00003oooooooo003oo`0000?o
o`000_ooool5ool001Gooooo6?oo0002ooooo`?oo`001?ooool3ool000;ooooo1Ooo0006ooooo`Wo
o`00=?ooool1o`00007ooooo00000ol0003oooooooooo`0oooooo`Goo`000_ooool3ool000Sooooo
1Ooo0002ooooo`Goo`002oooool5ool000Oooooo1Ooo0003ooooo`ooo`000_ooool3ool000?ooooo
1Ooo000EoooooaSoo`000_ooool3ool000?ooooo1Ooo00000oooooooo`00ool00003ool000Oooooo
2?oo000dooooo`7o00000Oooool00003o`000?oooooooooo03kooooo1_oo00000oooooooo`00ool0
0003ool000Oooooo1Ooo0002ooooo`Goo`000oooool3ool000Gooooo1Ooo0007ooooo`Koo`000ooo
ool3ool00003oooooooo003oo`0000Soo`002Oooool3ool001Oooooo7_oo00000oooooooo`00ool0
0003ool00003oooooooo003oo`0000?oo`002oooool3ool003Gooooo0Ol00001ooooo`0000?o0000
ooooooooool0?Oooool=ool000Oooooo1Ooo0002ooooo`Goo`000_ooool5ool00003oooooooo003o
o`0000Goo`002Oooool6ool000Kooooo1Ooo00001?ooooooo`00ool00?oo000;ooooo`?oo`006?oo
ool5ool000Kooooo0ooo00000oooooooo`00ool0000Aool00003oooooooo003oo`0000?oo`00@ooo
ool1o`00007ooooo00000ol0003oooooooooo`0cooooo`?oo`001oooool=ool000Sooooo0ooo0003
ooooo`Goo`000_ooool<ool000[ooooo1_oo0007ooooo`?oo`002Oooool3ool00003oooooooo003o
o`0000Goo`006?ooool3ool000cooooo4Ooo0002ooooo`Goo`001_ooool4ool003Wooooo0Ol00001
ooooo`0000?o0000ooooooooool0<_ooool5ool00004oooooooo003oo`00ool000;ooooo1Ooo0000
0oooooooo`00ool00005ool000kooooo1Ooo0002ooooo`coo`001_ooool3ool00003oooooooo003o
o`0000Goo`004Oooool<ool001[ooooo0ooo000<oooooa3oo`000_ooool3ool000Kooooo1_oo000h
ooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo2_oo0002ooooo`?oo`000_ooool8ool0
00kooooo0ooo0004ooooo`?oo`0000?oooooool00?oo00001Ooo0005ooooo`coo`004Oooool<ool0
0004oooooooo003oo`00ool001Gooooo1Ooo000;oooooa7oo`002_ooool6ool000?ooooo0ooo000b
ooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo2_oo0008ooooo`Ooo`004?ooool3ool0
0003oooooooo003oo`0000Woo`001_ooool<ool0017ooooo2ooo00000oooooooo`00ool00003ool0
01Cooooo1Ooo000;oooooa;oo`002Oooool6ool00003oooooooo003oo`0000Coo`00<Oooool1o`00
007ooooo00000ol0003oooooooooo`0cooooo`Woo`002_ooool5ool000[ooooo0ooo0002oooooa3o
o`000_ooool3ool00003oooooooo003oo`0000Woo`004oooool3ool00004oooooooo003oo`00ool0
00Cooooo1Ooo000?ooooo`?oo`000_ooool5ool000Oooooo0ooo00000oooooooo`00ool0000Aool0
00Cooooo0ooo00000oooooooo`00ool00003ool00003oooooooo003oo`0000Goo`00<Oooool1o`00
007ooooo00000ol0003oooooooooo`0`ooooo`_oo`000oooool4ool000Gooooo0ooo000:ooooo`Go
o`0000?oooooool00?oo00003Ooo0002ooooo`Goo`0000Goooooool00?oo003oo`00ooooo`05ool0
01oooooo1Ooo00000oooooooo`00ool00007ool000Cooooo1Ooo0002ooooo`?oo`001oooool5ool0
0005oooooooo003oo`00ool00?ooool03_oo0003oooooa;oo`00<Oooool1o`00007ooooo00000ol0
003oooooooooo`0_ooooo`coo`000_ooool6ool0013ooooo1_oo00000oooooooo`00ool00003ool0
0005oooooooo003oo`00ool00?ooool00ooo0004ooooo`Goo`001_ooool3ool0027ooooo0ooo0000
0oooooooo`00ool00009ool000?ooooo1Ooo000<ooooo`Goo`002?ooool5ool00003oooooooo003o
o`0000?oo`000ooooolAool003;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool<ool0
00;ooooo1_oo0004ooooo`?oo`002Oooool6ool000;ooooo1_oo000:ooooo`Goo`00;_ooool;ool0
00?ooooo1Ooo000<ooooo`Goo`002?ooool5ool000;ooooo0ooo0004ooooo`ooo`00=?ooool1o`00
007ooooo00000ol0003oooooooooo`0_ooooo`Goo`000_ooool4ool000?ooooo1_oo0003ooooo`Go
o`0000?oooooool00?oo00002_oo0005ooooo`Goo`002Oooool5ool000;ooooo0ooo000Yooooo`_o
o`001?ooool3ool000kooooo0ooo000:ooooo`?oo`002oooool>ool003Cooooo0Ol00001ooooo`00
00?o0000ooooooooool0;oooool4ool000;ooooo1Ooo0003ooooo`Ooo`000_oooolAool000Kooooo
1Ooo0004ooooo`?oo`000oooool3ool000;ooooo1Ooo000Yooooo`Woo`00<Oooool8ool00003oooo
oooo003oo`0000?oo`00=?ooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`Goo`000_oo
ool?ool000;ooooo4Ooo0006ooooo`Goo`0000?oooooool00?oo00001Ooo0007ooooo`Goo`00C?oo
ool3ool000Gooooo1Ooo0004oooooa?oo`00=Oooool1o`00007ooooo00000ol0003oooooooooo`0^
ooooo`Goo`0000?oooooool00?oo00003_oo0003ooooo`?oo`0000?oooooool00?oo00002_oo0007
ooooo`coo`001oooool5ool004_ooooo1Ooo0003ooooo`Ooo`000_oooolDool003Gooooo0Ol00001
ooooo`0000?o0000ooooooooool0;_oooolEool000Wooooo2_oo0009ooooo`_oo`002?ooool3ool0
03Wooooo0ooo0006ooooo`?oo`001oooool5ool000?ooooo1ooo0002ooooo`koo`0000?oooooool0
0?oo00000ooo000eooooo`7o00000Oooool00003o`000?oooooooooo02cooooo6_oo000<ooooo`?o
o`002_ooool;ool003oooooo0ooo00000oooooooo`00ool00003ool000Cooooo1_oo0005ooooo`oo
o`000_ooool:ool000Gooooo1Ooo000eooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo
7Ooo0004ooooo`?oo`004?ooool=ool003cooooo2_oo0004ooooo`Ooo`001Oooool>ool000?ooooo
2?oo0007ooooo`Goo`00=?ooool1o`00007ooooo00000ol0003oooooooooo`0[oooooakoo`000_oo
ool5ool0013ooooo3_oo000jooooo`[oo`001?ooool7ool000Oooooo3?oo0006ooooo`Goo`001ooo
ool5ool003Cooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool9ool00003oooooooo003o
o`0000Coo`0000?oooooool00?oo00002ooo0002ooooo`Goo`002?ooool3ool000Gooooo3ooo000i
ooooo`Woo`000_ooool3ool00003oooooooo003oo`0000Coo`001oooool<ool000Kooooo1Ooo0007
ooooo`Goo`00=?ooool1o`00007ooooo00000ol0003oooooooooo`0/ooooo`ooo`000ooooolBool0
00Oooooo1Ooo0004ooooo`Ooo`0000?oooooool00?oo00001Ooo000jooooo`Goo`001?ooool5ool0
00;ooooo0ooo0009ooooo`?oo`001?ooool3ool000Kooooo1ooo0007ooooo`?oo`00=Oooool1o`00
007ooooo00000ol0003oooooooooo`0`ooooo`_oo`000oooool4ool00003oooooooo003oo`0000[o
o`002?ooool6ool000Cooooo1_oo00000oooooooo`00ool00005ool003[ooooo1Ooo0004ooooo`Go
o`001?ooool3ool000Kooooo1Ooo000<ooooo`Ooo`00?oooool1o`00007ooooo00000ol0003ooooo
ooooo`0aooooo`Woo`000oooool5ool00003oooooooo003oo`0000Soo`000_ooool3ool000Gooooo
2_oo00000oooooooo`00ool00003ool000;ooooo1Ooo000jooooo`Goo`001Oooool5ool000?ooooo
1_oo0002ooooo`Ooo`003?ooool7ool000Cooooo0ooo000hooooo`7o00000Oooool00003o`000?oo
oooooooo037ooooo1ooo0005ooooo`Goo`0000?oooooool00?oo00002?oo00000oooooooo`00ool0
0005ool000?ooooo3_oo0003ooooo`Goo`00>_ooool5ool000Kooooo1?oo0003ooooo`ooo`003Ooo
ool5ool000Cooooo1Ooo0006ooooo`?oo`00;_ooool1o`00007ooooo00000ol0003oooooooooo`0a
ooooo`Goo`001oooool5ool000;ooooo2?oo0002ooooo`Soo`000oooool=ool000Cooooo0ooo000k
ooooo`Soo`000oooool5ool000;ooooo3_oo000Gooooo`Goo`001?ooool6ool002gooooo0Ol00001
ooooo`0000?o0000ooooooooool0<Oooool4ool000;ooooo0ooo0004ooooo`?oo`001_ooool5ool0
00;ooooo2?oo0004ooooo`coo`00@oooool?ool000?ooooo2ooo000Dooooo`?oo`000_ooool5ool0
00?ooooo1ooo000]ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo1Ooo00000ooooooo
o`00ool00003ool000gooooo0ooo00000oooooooo`00ool00008ool000Cooooo1ooo00001?oooooo
o`00ool00?oo0014ooooo`ooo`000oooool:ool001Cooooo1Ooo0002ooooo`?oo`001?ooool7ool0
02gooooo0Ol00001ooooo`0000?o0000ooooooooool0;Oooool8ool00003oooooooo003oo`0000?o
o`004?ooool6ool00004oooooooo003oo`00ool000Kooooo1_oo0019ooooo`goo`000oooool:ool0
00Wooooo1ooo0005ooooo`Goo`001oooool9ool002gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0;?ooool9ool00003oooooooo003oo`0000?oo`004?ooool7ool000[ooooo1Ooo001<ooooo`_o
o`0000?oooooool00?oo00002Ooo0008ooooo`Woo`001?ooool5ool00004oooooooo003oo`00ool0
00;ooooo2_oo000]ooooo`7o00000Oooool00003o`000?oooooooooo02[ooooo2_oo00000ooooooo
o`00ool00003ool0017ooooo1ooo000;ooooo`?oo`00DOooool7ool00003oooooooo003oo`0000?o
o`0000?oooooool00?oo00000ooo0008ooooo`Woo`001?ooool:ool00003oooooooo003oo`0000Wo
o`00;?ooool1o`00007ooooo00000ol0003oooooooooo`0Yooooo`Woo`000oooool5ool000cooooo
1?oo00000oooooooo`00ool00005ool0063ooooo1_oo00000oooooooo`00ool00003ool000;ooooo
0ooo0009ooooo`Woo`000oooool;ool00003oooooooo003oo`0000Woo`00;?ooool1o`00007ooooo
00000ol0003oooooooooo`0Yooooo`Woo`000oooool5ool000_ooooo1_oo00000oooooooo`00ool0
0003ool000Cooooo0ooo001Iooooo`Ooo`000_ooool3ool0013ooooo1ooo0004ooooo`Goo`0000?o
ooooool00?oo00000ooo0002ooooo`[oo`00;?ooool1o`00007ooooo00000ol0003oooooooooo`0Y
ooooo`Soo`001?ooool5ool000_ooooo1_oo0009ooooo`Goo`003?ooool3ool004Sooooo2?oo000F
ooooo`Goo`001Oooool5ool000;ooooo0ooo0005ooooo`?oo`0000Coooooool00?oo003oo`00;Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Coo`001oooool6ool000[ooooo1ooo0003
ooooo`?oo`000_ooool5ool000_ooooo1Ooo0017ooooo`Soo`002oooool3ool000Sooooo1Ooo0006
ooooo`?oo`00?oooool1o`00007ooooo00000ol0003oooooooooo`0dooooo`Soo`002_ooool6ool0
00;ooooo1Ooo00000oooooooo`00ool00003ool000_ooooo1Ooo0017ooooo`Ooo`002oooool5ool0
00Oooooo1Ooo0018ooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo2?oo0004ooooo`?o
o`000oooool6ool000;ooooo1Ooo0002ooooo`?oo`003?ooool5ool004Sooooo0ooo000>ooooo`Go
o`002?ooool3ool0017ooooo0ooo0006ooooo`?oo`00;?ooool1o`00007ooooo00000ol0003ooooo
ooooo`0dooooo`Soo`000oooool5ool000?ooooo1?oo0003ooooo`Soo`001Oooool3ool000Kooooo
1Ooo0018ooooo`Ooo`002_ooool5ool001Wooooo2?oo00000oooooooo`00ool00005ool002_ooooo
0Ol00001ooooo`0000?o0000ooooooooool0=?ooool8ool000?ooooo1Ooo000;ooooo`Soo`000ooo
ool5ool000Cooooo1ooo0016ooooo`Woo`001_ooool8ool00004oooooooo003oo`00ool000Wooooo
0ooo0008oooooa7oo`00:oooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`?oo`000_oo
ool8ool000;ooooo1ooo000>ooooo`Goo`000oooool6ool000;ooooo2?oo0016ooooo`Woo`000ooo
ool@ool000Oooooo1Ooo0007oooooa7oo`00:oooool1o`00007ooooo00000ol0003oooooooooo`0/
ooooo`Koo`0000?oooooool00?oo00001Ooo0002ooooo`Ooo`003oooool5ool000?ooooo1_oo0002
ooooo`Soo`00A_ooool9ool000;ooooo4Ooo00001Oooooooo`00ool00?oo003ooooo00[oo`001?oo
ool@ool002cooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool7ool00003oooooooo003o
o`0000Goo`000_ooool6ool0017ooooo1?oo0003ooooo`Koo`000_ooool7ool004Sooooo1ooo0003
ooooo`_oo`0000?oooooool00?oo00004ooo0004ooooo`Soo`0000?oooooool00?oo00000ooo000]
ooooo`7o00000Oooool00003o`000?oooooooooo02_ooooo1ooo0002ooooo`Ooo`0000?oooooool0
0?oo00001?oo000Aooooo`Goo`0000?oooooool00?oo00001?oo0004ooooo`Koo`00B_ooool3ool0
00Gooooo1ooo0004oooooaKoo`001Oooool6ool000;ooooo1Ooo000]ooooo`7o00000Oooool00003
o`000?oooooooooo02[ooooo1ooo0005ooooo`Koo`0000?oooooool00?oo00000ooo000@ooooo`Ko
o`0000?oooooool00?oo00000ooo0007ooooo`Koo`00Aoooool3ool000Oooooo1_oo0003oooooa3o
o`000_ooool5ool000Gooooo1Ooo0004ooooo`?oo`00;_ooool1o`00007ooooo00000ol0003ooooo
ooooo`0Yooooo`Ooo`001_ooool6ool000;ooooo0ooo000@ooooo`Ooo`0000?oooooool00?oo0000
0ooo0007ooooo`Ooo`00AOooool5ool000Kooooo1ooo0002ooooo`ooo`001?ooool3ool000Kooooo
1ooo000cooooo`7o00000Oooool00003o`000?oooooooooo02Wooooo1ooo0006ooooo`Koo`000_oo
ool5ool000kooooo1_oo0003ooooo`?oo`002?ooool7ool004Gooooo1Ooo0007ooooo`Koo`000_oo
ool>ool000oooooo1ooo000booooo`7o00000Oooool00003o`000?oooooooooo02Wooooo1ooo0007
ooooo`Coo`000_ooool7ool000gooooo1Ooo000@ooooo`Koo`00A?ooool6ool000;ooooo0ooo0003
ooooo`Goo`000oooool3ool00003oooooooo003oo`0000Ooo`001Oooool3ool000Cooooo0ooo0002
ooooo`Goo`00<_ooool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Koo`000oooool3ool0
00Oooooo1ooo00001?ooooooo`00ool00?oo000:ooooo`?oo`000_ooool4ool000gooooo0ooo0014
ooooo`Koo`000_ooool5ool000?ooooo0ooo0007ooooo`[oo`001?ooool5ool000;ooooo1Ooo0000
0oooooooo`00ool00003ool003;ooooo0Ol00001ooooo`0000?o0000ooooooooool0:oooool5ool0
00;ooooo1Ooo0006ooooo`koo`002oooool6ool005?ooooo1Ooo0003ooooo`Goo`003?ooool;ool0
00Cooooo1_oo00000oooooooo`00ool00003ool000;ooooo0ooo000cooooo`7o00000Oooool00003
o`000?oooooooooo02cooooo0ooo0003ooooo`Goo`001_ooool6ool00003oooooooo003oo`0000Ko
o`002_ooool6ool000[ooooo0ooo0016ooooo`Goo`000oooool7ool000[ooooo2_oo0004ooooo`Oo
o`0000?oooooool00?oo00001?oo00000oooooooo`00ool00005ool002oooooo0Ol00001ooooo`00
00?o0000ooooooooool0<_ooool5ool000Kooooo1Ooo0002ooooo`Soo`002_ooool6ool00004oooo
oooo003oo`00ool000Gooooo1Ooo0016ooooo`Goo`000oooool7ool000Wooooo2ooo0002ooooo`So
o`000_ooool@ool002cooooo0Ol00001ooooo`0000?o0000ooooooooool0<oooool6ool00005oooo
oooo003oo`00ool00?ooool00ooo0002ooooo`Woo`000oooool3ool000Gooooo1?oo00000ooooooo
o`00ool00003ool000Cooooo1Ooo0016ooooo`Goo`001Oooool5ool000Sooooo3Ooo00000ooooooo
o`00ool00005ool000;ooooo4_oo000[ooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo
2Ooo0005ooooo`Soo`000oooool5ool000Wooooo1Ooo0004ooooo`Goo`00A_ooool6ool000?ooooo
1_oo0008ooooo`goo`0000?oooooool00?oo00000ooo0003oooooa?oo`00:oooool1o`00007ooooo
00000ol0003oooooooooo`0eooooo`Woo`0000Goooooool00?oo003oo`00ooooo`05ool000Kooooo
1Ooo0009ooooo`Goo`001Oooool3ool004;ooooo0ooo0003ooooo`Goo`000_ooool6ool000Wooooo
3Ooo0002ooooo`?oo`001?oooolCool002_ooooo0Ol00001ooooo`0000?o0000ooooooooool0=Ooo
ool>ool00004oooooooo003oo`00ool000Kooooo1_oo000:ooooo`?oo`00B_ooool5ool000;ooooo
3?oo000:ooooo`coo`002_ooool:ool000Cooooo1Ooo000[ooooo`7o00000Oooool00003o`000?oo
oooooooo03;ooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`0000?oooooool00?oo0000
0ooo00001?ooooooo`00ool00?oo0003ooooo`Soo`003Oooool3ool000Wooooo0ooo000looooo`Oo
o`0000?oooooool00?oo00002Ooo0009ooooo`[oo`003_ooool7ool000Kooooo1Ooo000[ooooo`7o
00000Oooool00003o`000?oooooooooo037ooooo2_oo0003ooooo`[oo`0000?oooooool00?oo0000
1_oo000:ooooo`Soo`000_ooool3ool000;ooooo1Ooo000kooooo`Soo`000oooool7ool000[ooooo
1Ooo000Qooooo`?oo`00;?ooool1o`00007ooooo00000ol0003oooooooooo`0aooooo`_oo`000ooo
ool3ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00001_oo0009ooooo`Woo`0000?o
ooooool00?oo00000ooo00000oooooooo`00ool00003ool003cooooo1ooo0002ooooo`Ooo`002Ooo
ool7ool0053ooooo0Ol00001ooooo`0000?o0000ooooooooool0<Oooool;ool000Oooooo1Ooo0000
0oooooooo`00ool00008ool000Oooooo2Ooo00000oooooooo`00ool00009ool003gooooo1_oo0000
0oooooooo`00ool00006ool000Cooooo0ooo00000oooooooo`00ool00005ool001?ooooo1_oo000h
ooooo`7o00000Oooool00003o`000?oooooooooo03;ooooo2_oo0008ooooo`Goo`0000Coooooool0
0?oo003oo`000_ooool5ool000Kooooo2?oo0002ooooo`goo`00>oooool5ool000;ooooo2Ooo0002
ooooo`[oo`0000Coooooool00?oo003oo`001_ooool3ool000Cooooo3_oo000dooooo`7o00000Ooo
ool00003o`000?oooooooooo033ooooo2ooo0007ooooo`Ooo`001_ooool5ool000Cooooo1ooo0006
ooooo`goo`00>_ooool5ool000;ooooo2_oo00000oooooooo`00ool0000=ool000Cooooo1Ooo0002
oooooa3oo`00<oooool1o`00007ooooo00000ol0003oooooooooo`0_ooooo`Ooo`002oooool8ool0
00Kooooo1ooo00000oooooooo`00ool00005ool000Sooooo3?oo000kooooo`?oo`001?ooool9ool0
0003oooooooo003oo`0000?oo`0000?oooooool00?oo00001ooo0004ooooo`Goo`000_oooolAool0
03;ooooo0Ol00001ooooo`0000?o0000ooooooooool0;oooool7ool000[ooooo2_oo0006ooooo`co
o`002oooool;ool003Gooooo0ooo0002ooooo`Koo`001_ooool5ool000;ooooo0ooo0004ooooo`Oo
o`001?ooool5ool000;ooooo4Ooo000booooo`7o00000Oooool00003o`000?oooooooooo02oooooo
1_oo0002ooooo`Goo`000oooool;ool000Sooooo2_oo000<ooooo`Woo`00<?ooool3ool000;ooooo
3Ooo0006ooooo`?oo`002_ooool6ool000Kooooo1Ooo0002ooooo`Soo`000oooool5ool003;ooooo
0Ol00001ooooo`0000?o0000ooooooooool0;_ooool5ool000?ooooo1ooo0002ooooo`_oo`002?oo
ool5ool00004oooooooo003oo`00ool000oooooo0ooo000cooooo`Goo`0000?oooooool00?oo0000
2ooo0003ooooo`?oo`001_ooool3ool000Cooooo1Ooo0008ooooo`Goo`000_ooool7ool00003oooo
oooo003oo`0000Coo`00<oooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`Goo`000ooo
oolDool000Wooooo0ooo000<ooooo`?oo`0000Coooooool00?oo003oo`00=_ooool6ool00003oooo
oooo003oo`0001;oo`001?ooool5ool000Cooooo0ooo0008ooooo`Koo`001Oooool3ool00003oooo
oooo003oo`0000?oo`00=Oooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`Koo`000ooo
ool=ool00003oooooooo003oo`0000Ooo`001Oooool3ool000Wooooo3?oo000eooooo`Koo`000_oo
ool3ool000;ooooo4?oo0002ooooo`Goo`003oooool6ool000Kooooo2?oo0002ooooo`?oo`00<?oo
ool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`Ooo`000ooooolGool000?ooooo1Ooo0005
oooooa3oo`000oooool3ool002[ooooo0ooo00000oooooooo`00ool00004ool000cooooo3?oo0000
0oooooooo`00ool00003ool000Gooooo0ooo0006ooooo`Ooo`001Oooool9ool00003oooooooo003o
o`0000?oo`00;oooool1o`00007ooooo00000ol0003oooooooooo`0]ooooo`Soo`001oooool<ool0
0003oooooooo003oo`0000?oo`000oooool5ool000Cooooo6?oo000Xooooo`[oo`001?ooool3ool0
00Gooooo3Ooo00000oooooooo`00ool0000<ool000Gooooo2?oo00000oooooooo`00ool0000:ool0
0003oooooooo003oo`0000?oo`00;oooool1o`00007ooooo00000ol0003oooooooooo`0^ooooo`[o
o`001Oooool;ool00003oooooooo003oo`0000?oo`000oooool5ool000Cooooo2ooo00000ooooooo
o`00ool0000:ool000cooooo0ooo000Iooooo`Goo`0000Coooooool00?oo003oo`001?ooool5ool0
00Cooooo1_oo00000oooooooo`00ool00004ool00003oooooooo003oo`0000ooo`000_oooolDool0
00;ooooo1Ooo000_ooooo`7o00000Oooool00003o`000?oooooooooo033ooooo2Ooo0006ooooo`Wo
o`000_ooool3ool000?ooooo1Ooo0004ooooo`[oo`001?ooool;ool000Cooooo0ooo0004ooooo`Go
o`006?ooool5ool000Sooooo1Ooo0004ooooo`Goo`000_ooool5ool000?ooooo4Ooo0002ooooo`oo
o`000oooool3ool00004oooooooo003oo`00ool0033ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0<Oooool:ool000Cooooo2?oo0009ooooo`Goo`000oooool6ool00004oooooooo003oo`00ool0
00Oooooo2?oo0004ooooo`Goo`000oooool5ool000Kooooo0ooo000@ooooo`?oo`000_ooool3ool0
00Cooooo1Ooo0005ooooo`_oo`001OoooolAool000;ooooo3_oo00000oooooooo`00ool00003ool0
03?ooooo0Ol00001ooooo`0000?o0000ooooooooool0<oooool9ool000Cooooo1ooo0009ooooo`Go
o`000oooool6ool00003oooooooo003oo`0000Coo`001?ooool5ool000Cooooo2?oo0002ooooo`So
o`000oooool6ool000cooooo0ooo0003ooooo`Goo`001?ooool3ool000Sooooo2?oo0007ooooo`Ko
o`000ooooolMool003?ooooo0Ol00001ooooo`0000?o0000ooooooooool0<oooool9ool000Gooooo
1_oo000:ooooo`?oo`001?ooool>ool000;ooooo1_oo0003ooooo`[oo`0000?oooooool00?oo0000
1ooo0002ooooo`Ooo`000_ooool3ool000;ooooo2?oo0002ooooo`Goo`002?ooool3ool000Cooooo
1Ooo0006ooooo`Koo`001_oooolBool00003oooooooo003oo`0000Woo`00<oooool1o`00007ooooo
00000ol0003oooooooooo`0cooooo`[oo`001_ooool3ool000Oooooo2_oo0002ooooo`goo`0000?o
ooooool00?oo00001?oo0004oooooaCoo`000_oooolFool00003oooooooo003oo`0000Coo`001ooo
ool5ool000?ooooo1_oo0004ooooo`Soo`000ooooolCool000?ooooo1Ooo00001?ooooooo`00ool0
0?oo000dooooo`7o00000Oooool00003o`000?oooooooooo03Cooooo0ooo00000oooooooo`00ool0
0004ool000kooooo3?oo0004ooooo`[oo`0000?oooooool00?oo00000ooo0005ooooo`_oo`0000?o
ooooool00?oo00001ooo00000oooooooo`00ool0000Jool000Sooooo1Ooo0004ooooo`Koo`000ooo
ool8ool000;ooooo1ooo00000oooooooo`00ool00006ool000Sooooo0ooo000iooooo`7o00000Ooo
ool00003o`000?oooooooooo03Sooooo1_oo00000oooooooo`00ool00003ool000Sooooo6Ooo0002
ooooo`Goo`001Oooool;ool000;ooooo9Ooo0008ooooo`Goo`001Oooool5ool000;ooooo2Ooo0002
ooooo`Woo`0000?oooooool00?oo00000ooo0015ooooo`7o00000Oooool00003o`000?oooooooooo
03Kooooo3ooo0007oooooaCoo`002?ooool3ool000Kooooo2_oo0007ooooo`coo`000_ooool3ool0
00;ooooo3ooo0008ooooo`?oo`001_ooool5ool00003oooooooo003oo`0000Ooo`000oooool?ool0
00Gooooo0ooo000mooooo`7o00000Oooool00003o`000?oooooooooo03Gooooo2?oo00000ooooooo
o`00ool00006ool000Oooooo0ooo0004ooooo`Woo`002?ooool3ool000Wooooo1ooo000:ooooo`co
o`0000?oooooool00?oo00000ooo00000oooooooo`00ool0000=ool0017ooooo1Ooo00000ooooooo
o`00ool00004ool000Oooooo3_oo0004ooooo`Goo`00??ooool1o`00007ooooo00000ol0003ooooo
ooooo`0eoooooa;oo`003_ooool8ool000Oooooo1Ooo0002ooooo`?oo`001?ooool7ool000[ooooo
0ooo00000oooooooo`00ool00005ool00003oooooooo003oo`0001?oo`004Oooool5ool00003oooo
oooo003oo`0000Coo`001oooool@ool000;ooooo1Ooo0004ooooo`?oo`00=Oooool1o`00007ooooo
00000ol0003oooooooooo`0eooooo`Woo`0000?oooooool00?oo00001_oo0003ooooo`?oo`003?oo
ool3ool000Sooooo1Ooo00000oooooooo`00ool00003ool000Gooooo1Ooo000@oooooaKoo`0000Co
ooooool00?oo003oo`004_ooool5ool000;ooooo1?oo0009oooooaKoo`000oooool5ool003Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0=_ooool:ool000;ooooo1Ooo0002ooooo`Goo`001ooo
ool3ool000cooooo1Ooo00000oooooooo`00ool00003ool000Gooooo1Ooo000Aooooo`Woo`0000?o
ooooool00?oo00002?oo000Gooooo`Koo`004_oooolAool000Cooooo1Ooo000dooooo`7o00000Ooo
ool00003o`000?oooooooooo03[ooooo1ooo0002ooooo`?oo`000oooool5ool000Kooooo1Ooo000<
ooooo`?oo`000_ooool5ool000Kooooo0ooo0008ooooo`?oo`002Oooool8ool00003oooooooo003o
o`0000Ooo`006?ooool5ool000Sooooo0ooo000:ooooo`coo`001_ooool5ool003Cooooo0Ol00001
ooooo`0000?o0000ooooooooool0=_ooool3ool000?ooooo1Ooo0008ooooo`Goo`001_ooool5ool0
013ooooo1Ooo0002ooooo`?oo`003?ooool5ool000Oooooo2_oo00000oooooooo`00ool00005ool0
00?ooooo0ooo0008ooooo`?oo`002?ooool5ool000Oooooo1Ooo0008ooooo`Goo`0000?oooooool0
0?oo00001Ooo0007ooooo`?oo`00=Oooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`Go
o`000_ooool5ool000?ooooo1Ooo00001?ooooooo`00ool00?oo0007ooooo`Goo`004?ooool5ool0
0003oooooooo003oo`0000?oo`002oooool5ool000Oooooo2_oo0002ooooo`?oo`001Oooool5ool0
00Kooooo1Ooo0008ooooo`?oo`001oooool6ool000Oooooo1Ooo00001Oooooooo`00ool00?oo003o
oooo00?oo`00@?ooool1o`00007ooooo00000ol0003oooooooooo`0eooooo`Goo`000oooool3ool0
00?ooooo1ooo000;ooooo`?oo`000_ooool3ool000_ooooo1_oo00000oooooooo`00ool00003ool0
00_ooooo1Ooo00001?ooooooo`00ool00?oo0003ooooo`[oo`002_ooool5ool000Kooooo1Ooo0008
ooooo`?oo`001oooool6ool000Oooooo3_oo000oooooo`7o00000Oooool00003o`000?oooooooooo
03Gooooo1Ooo0009ooooo`Ooo`001oooool4ool000Cooooo1Ooo000:ooooo`Goo`000_ooool5ool0
00cooooo0ooo00000oooooooo`00ool00003ool000?ooooo2?oo000;ooooo`Goo`001_ooool5ool0
00Oooooo1Ooo0006ooooo`Koo`000oooool3ool00003oooooooo003oo`0000koo`00?Oooool1o`00
007ooooo00000ol0003oooooooooo`0fooooo`?oo`002_ooool9ool000Cooooo1_oo0003ooooo`Go
o`002Oooool6ool000?ooooo0ooo000Aooooo`Goo`005Oooool5ool000Sooooo0ooo0008ooooo`Go
o`001oooool5ool000;ooooo1Ooo00000oooooooo`00ool0000>ool003cooooo0Ol00001ooooo`00
00?o0000ooooooooool0A?ooool9ool000?ooooo1ooo0002ooooo`Goo`002Oooool5ool000Kooooo
0ooo0004ooooo`?oo`002?ooool5ool000Cooooo1_oo000;ooooo`Goo`003oooool3ool00003oooo
oooo003oo`0000?oo`001oooool6ool00003oooooooo003oo`0000?oo`000_ooool7ool00003oooo
oooo003oo`0000Goo`00??ooool1o`00007ooooo00000ol0003oooooooooo`10ooooo`?oo`0000?o
ooooool00?oo00001ooo0003ooooo`Ooo`000_ooool5ool000Wooooo1Ooo0005ooooo`Goo`000_oo
ool5ool000Gooooo4_oo0006ooooo`?oo`0000?oooooool00?oo00000ooo000>ooooo`Goo`0000?o
ooooool00?oo00000ooo0006ooooo`Koo`0000?oooooool00?oo00000ooo0003ooooo`Koo`000ooo
ool5ool003cooooo0Ol00001ooooo`0000?o0000ooooooooool0?oooool>ool000Cooooo1_oo0002
ooooo`Goo`002_ooool3ool000Kooooo1Ooo0002ooooo`Goo`0000?oooooool00?oo00005?oo0005
ooooo`Goo`0000Coooooool00?oo003oo`003oooool5ool000;ooooo1Ooo0006ooooo`Goo`000_oo
ool3ool000Gooooo1Ooo0002ooooo`Goo`00?Oooool1o`00007ooooo00000ol0003oooooooooo`0o
ooooo`goo`001oooool3ool000Cooooo0ooo000Dooooo`Goo`000_oooolLool000Gooooo1Ooo0000
1?ooooooo`00ool00?oo000?ooooo`Goo`000_ooool6ool000Kooooo0ooo000;ooooo`Coo`000ooo
ool5ool003gooooo0Ol00001ooooo`0000?o0000ooooooooool0?oooool<ool000?ooooo0ooo000Q
ooooo`?oo`001?ooool3ool00003oooooooo003oo`0000Ooo`000_ooool;ool000Kooooo2_oo0006
ooooo`Goo`001?ooool3ool000?ooooo2Ooo0002ooooo`?oo`002oooool5ool000?ooooo1Ooo000m
ooooo`7o00000Oooool00003o`000?oooooooooo043ooooo2_oo0003ooooo`Goo`002?ooool3ool0
023ooooo2?oo0004ooooo`Woo`000oooool3ool000;ooooo0ooo00000oooooooo`00ool00003ool0
00Gooooo1ooo000:ooooo`koo`002_ooool7ool000;ooooo0ooo000nooooo`7o00000Oooool00003
o`000?oooooooooo04?ooooo0ooo0007ooooo`Goo`001oooool5ool000Oooooo0ooo000Fooooo`?o
o`002Oooool9ool00003oooooooo003oo`0000?oo`001Oooool8ool000;ooooo2?oo000:ooooo`go
o`002_ooool=ool003gooooo0Ol00001ooooo`0000?o0000ooooooooool0COooool6ool000?ooooo
2?oo0006ooooo`Goo`008oooool=ool000Kooooo2?oo00000oooooooo`00ool00007ool000?ooooo
0ooo0006ooooo`[oo`002Oooool>ool003gooooo0Ol00001ooooo`0000?o0000ooooooooool0??oo
ool3ool000Kooooo0ooo0006ooooo`Goo`000_ooool9ool000Kooooo1Ooo0002ooooo`?oo`003_oo
ool3ool000cooooo3_oo0009ooooo`Goo`000_ooool8ool000;ooooo1Ooo0005ooooo`Goo`0000?o
ooooool00?oo00001_oo0005ooooo`koo`00?Oooool1o`00007ooooo00000ol0003oooooooooo`0k
ooooo`Goo`001?ooool5ool000Gooooo1Ooo0002ooooo`Soo`001oooool5ool00003oooooooo003o
o`0000?oo`003?ooool5ool000_ooooo3_oo0003ooooo`?oo`000oooool5ool000;ooooo2?oo0002
ooooo`Goo`001Oooool5ool00003oooooooo003oo`0000Ooo`001?ooool9ool00004oooooooo003o
o`00ool003kooooo0Ol00001ooooo`0000?o0000ooooooooool0>oooool5ool000Cooooo1Ooo0006
ooooo`?oo`000oooool6ool000[ooooo0ooo0002ooooo`Koo`001?ooool3ool000Cooooo1_oo0006
ooooo`?oo`0000?oooooool00?oo00004ooo0003ooooo`?oo`000oooool7ool000?ooooo1Ooo0005
ooooo`Goo`0000?oooooool00?oo00002?oo0004ooooo`Soo`00@_ooool1o`00007ooooo00000ol0
003oooooooooo`0kooooo`Goo`001?ooool5ool000gooooo1Ooo0004ooooo`?oo`002?ooool6ool0
00?ooooo1Ooo0003ooooo`Ooo`001?ooool5ool00004oooooooo003oo`00ool000Cooooo3Ooo0009
ooooo`Goo`001_ooool3ool000Oooooo1?oo0002ooooo`_oo`001_ooool5ool0047ooooo0Ol00001
ooooo`0000?o0000ooooooooool0??ooool3ool000Kooooo0ooo000>ooooo`Goo`000oooool5ool0
00Sooooo1Ooo0003ooooo`Goo`001?ooool8ool000;ooooo1Ooo0008ooooo`goo`002_ooool3ool0
017ooooo1Ooo0005ooooo`Soo`001_ooool5ool0043ooooo0Ol00001ooooo`0000?o0000oooooooo
ool0A_ooool3ool000kooooo0ooo0004ooooo`Goo`002Oooool3ool000Cooooo1Ooo0005oooooa3o
o`001oooool;ool000Kooooo0ooo000Fooooo`Woo`000_ooool7ool000Kooooo1Ooo0010ooooo`7o
00000Oooool00003o`000?oooooooooo04Gooooo1Ooo000Aooooo`_oo`001_ooool3ool000Cooooo
1Ooo0006oooooa3oo`001?ooool3ool000?ooooo1ooo0005ooooo`Goo`003?ooool3ool000Gooooo
2ooo0002ooooo`Koo`001_ooool5ool0043ooooo0Ol00001ooooo`0000?o0000ooooooooool0AOoo
ool5ool0013ooooo3Ooo0004ooooo`Goo`000oooool5ool000Oooooo3ooo0003ooooo`Goo`001?oo
ool5ool000Gooooo1Ooo000;ooooo`Goo`000oooool<ool000Cooooo0ooo0004ooooo`?oo`0000Co
ooooool00?oo003oo`00@Oooool1o`00007ooooo00000ol0003oooooooooo`15ooooo`Koo`003ooo
ool=ool000Cooooo1Ooo0003ooooo`Goo`001oooool?ool000?ooooo1Ooo0004ooooo`Goo`001Ooo
ool5ool00004oooooooo003oo`00ool000Oooooo1Ooo0003ooooo`coo`002_ooool5ool004Cooooo
0Ol00001ooooo`0000?o0000ooooooooool0A_ooool5ool000cooooo4?oo0004ooooo`Goo`001?oo
ool3ool000Wooooo3Ooo0003ooooo`Koo`001Oooool3ool000Oooooo2ooo0004ooooo`Koo`000_oo
ool5ool000?ooooo0ooo000:ooooo`Koo`00A?ooool1o`00007ooooo00000ol0003oooooooooo`16
ooooo`Goo`002oooool8ool000Gooooo1?oo0005ooooo`?oo`003oooool?ool000;ooooo1_oo000A
ooooo`_oo`001?ooool6ool00003oooooooo003oo`0000?oo`002Oooool3ool000Cooooo1_oo0014
ooooo`7o00000Oooool00003o`000?oooooooooo04Oooooo0ooo000<ooooo`Goo`001_ooool8ool0
017ooooo2_oo00000oooooooo`00ool00006ool000;ooooo1Ooo000:ooooo`?oo`001Oooool;ool0
00Cooooo3?oo0008ooooo`Goo`000oooool5ool004Gooooo0Ol00001ooooo`0000?o0000oooooooo
ool0E_ooool5ool000Gooooo2_oo000?ooooo`Woo`000_ooool9ool000;ooooo1Ooo0009ooooo`So
o`0000?oooooool00?oo00002Ooo0003ooooo`coo`002Oooool5ool000Cooooo0ooo0016ooooo`7o
00000Oooool00003o`000?oooooooooo05Oooooo1?oo0005ooooo`[oo`003_ooool:ool000;ooooo
2?oo0004ooooo`?oo`002_oooolDool000?ooooo2ooo000:ooooo`Goo`00COooool1o`00007ooooo
00000ol0003oooooooooo`1Gooooo`Goo`001?ooool;ool000gooooo2Ooo0003ooooo`Soo`004Ooo
ool9ool00003oooooooo003oo`0000Soo`000oooool;ool000_ooooo0ooo001>ooooo`7o00000Ooo
ool00003o`000?oooooooooo05Oooooo1Ooo0005ooooo`?oo`0000?oooooool00?oo00001Ooo000<
ooooo`Goo`001oooool8ool0013ooooo2_oo0007ooooo`?oo`000oooool<ool005cooooo0Ol00001
ooooo`0000?o0000ooooooooool0E_ooool6ool000Wooooo1ooo000<ooooo`Soo`001?ooool7ool0
013ooooo1Ooo0002ooooo`?oo`001?ooool3ool000Kooooo3_oo00001?ooooooo`00ool00?oo001G
ooooo`7o00000Oooool00003o`000?oooooooooo05Kooooo1Ooo000;ooooo`Koo`003?oooolAool0
00kooooo2Ooo00000oooooooo`00ool00003ool000;ooooo1Ooo0005oooooa?oo`001?ooool3ool0
04oooooo0Ol00001ooooo`0000?o0000ooooooooool0Coooool3ool000Cooooo1Ooo0003ooooo`?o
o`001?ooool6ool000;ooooo0ooo0009oooooa3oo`003Oooool:ool00003oooooooo003oo`0000?o
o`000_oooolNool000;ooooo1Ooo001>ooooo`7o00000Oooool00003o`000?oooooooooo04kooooo
1Ooo0004ooooo`?oo`000oooool5ool000;ooooo1Ooo0003ooooo`Goo`002oooool<ool000Cooooo
0ooo0006ooooo`_oo`0000?oooooool00?oo00000ooo0002ooooo`koo`0000?oooooool00?oo0000
1_oo00000oooooooo`00ool00005ool00003oooooooo003oo`0000?oo`00C_ooool1o`00007ooooo
00000ol0003oooooooooo`1>ooooo`Goo`001Oooool3ool000;ooooo1Ooo0002ooooo`Goo`000ooo
ool5ool000cooooo2?oo0006ooooo`Goo`001Oooool;ool000;ooooo0ooo0004ooooo`_oo`000ooo
ool@ool00003oooooooo003oo`0000?oo`00C_ooool1o`00007ooooo00000ol0003oooooooooo`1>
ooooo`Goo`001?ooool5ool00003oooooooo003oo`0000?oo`000_ooool5ool000?ooooo1Ooo000;
ooooo`Soo`001oooool5ool000Cooooo2ooo000=ooooo`Soo`000oooool@ool000;ooooo0ooo001?
ooooo`7o00000Oooool00003o`000?oooooooooo04oooooo0ooo0005ooooo`Goo`000_ooool3ool0
00Cooooo0ooo0005ooooo`Goo`001?ooool3ool00003oooooooo003oo`0000Goo`002_ooool5ool0
00?ooooo2ooo0008ooooo`?oo`001?ooool6ool000Cooooo3ooo001Eooooo`7o00000Oooool00003
o`000?oooooooooo05Oooooo1Ooo000Boooooa?oo`002oooool3ool000Cooooo2_oo0008ooooo`Go
o`001ooooolCool005Oooooo0Ol00001ooooo`0000?o0000ooooooooool0F?ooool3ool000oooooo
0ooo00000oooooooo`00ool0000@ool000Gooooo0ooo000;ooooo`Goo`003Oooool5ool000?ooooo
3ooo0002ooooo`?oo`00F_ooool1o`00007ooooo00000ol0003oooooooooo`1YoooooaGoo`001_oo
ool5ool000_ooooo0ooo0003ooooo`?oo`002?oooolFool0063ooooo0Ol00001ooooo`0000?o0000
ooooooooool0JOooool5ool00003oooooooo003oo`0000coo`001?ooool8ool0013ooooo2?oo0005
oooooaCoo`0000Coooooool00?oo003oo`00GOooool1o`00007ooooo00000ol0003oooooooooo`1Y
ooooo`Koo`000_ooool5ool00003oooooooo003oo`0000?oo`001?ooool:ool000Cooooo0ooo0008
ooooo`_oo`001OoooolFool005cooooo0Ol00001ooooo`0000?o0000ooooooooool0J_ooool6ool0
00;ooooo1?oo00000oooooooo`00ool00003ool000Cooooo2ooo0002ooooo`Goo`000_ooool3ool0
00;ooooo3?oo0004ooooo`Ooo`000_ooool=ool005cooooo0Ol00001ooooo`0000?o0000oooooooo
ool0Joooool5ool000;ooooo2_oo0004ooooo`coo`0000?oooooool00?oo00000ooo00000ooooooo
o`00ool00003ool00003oooooooo003oo`0000[oo`001Oooool3ool000;ooooo4?oo001Looooo`7o
00000Oooool00003o`000?oooooooooo06_ooooo1Ooo0002ooooo`Goo`0000Coooooool00?oo003o
o`001_ooool;ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00002?oo00000ooooooo
o`00ool00005ool000Wooooo2ooo0002ooooo`?oo`00GOooool1o`00007ooooo00000ol0003ooooo
ooooo`1/ooooo`?oo`000oooool5ool000cooooo2Ooo0002ooooo`?oo`000_ooool:ool00003oooo
oooo003oo`0000Coo`001_ooool3ool00003oooooooo003oo`0000Ooo`00I?ooool1o`00007ooooo
00000ol0003oooooooooo`1booooo`Goo`003?ooool8ool00004oooooooo003oo`00ool000Gooooo
3_oo0007ooooo`goo`00IOooool1o`00007ooooo00000ol0003oooooooooo`1]ooooo`?oo`000_oo
ool6ool000cooooo0ooo0004ooooo`Goo`001oooool5ool00003oooooooo003oo`0000?oo`001ooo
ool5ool00004oooooooo003oo`00ool006Wooooo0Ol00001ooooo`0000?o0000ooooooooool0K?oo
ool5ool000;ooooo1Ooo0002ooooo`?oo`000_ooool4ool000Sooooo1_oo00001?ooooooo`00ool0
0?oo0002ooooo`Goo`0000?oooooool00?oo00001_oo0004ooooo`Goo`00KOooool1o`00007ooooo
00000ol0003oooooooooo`1/ooooo`Goo`000_ooool5ool00003oooooooo003oo`0000Woo`001ooo
ool;ool000;ooooo0ooo0002ooooo`Woo`000_ooool5ool006kooooo0Ol00001ooooo`0000?o0000
ooooooooool0K?ooool5ool000?ooooo0ooo0002ooooo`_oo`002?ooool:ool000Oooooo2Ooo0002
ooooo`Goo`00K_ooool1o`00007ooooo00000ol0003oooooooooo`1]ooooo`?oo`002Oooool;ool0
00Wooooo2Ooo0007ooooo`Woo`000_ooool5ool006kooooo0Ol00001ooooo`0000?o0000oooooooo
ool0NOooool5ool00003oooooooo003oo`0000;oo`002oooool8ool000Kooooo2_oo0003ooooo`?o
o`00Koooool1o`00007ooooo00000ol0003oooooooooo`1iooooo`Goo`004oooool5ool000Kooooo
1Ooo00001?ooooooo`00ool00?oo001fooooo`7o00000Oooool00003o`000?oooooooooo07Wooooo
1Ooo000Cooooo`Goo`001_ooool5ool007[ooooo0Ol00001ooooo`0000?o0000ooooooooool0N_oo
ool3ool001Gooooo0ooo0008ooooo`?oo`00Noooool1o`00007ooooo00000ol0003oooooooooo`3o
oooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003
o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo
0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooo
oooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001oooo
o`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo
7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000
ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00
007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0
oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo0000
0ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLoooo
o`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooo
ooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Ooo
ool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooo
oacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`00
0?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol0
0001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo
0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooo
oolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0
003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o
00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003ooooooooo
o`3ooooooacooooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool0
0003o`000?oooooooooo0?oooooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooaco
oooo0Ol00001ooooo`0000?o0000ooooooooool0oooooolLooooo`7o00000Oooool00?oo00008?l0
0001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #1: good initialization (full covariances)", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes scalar covariances", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 5;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull[data1, k];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data1, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.129999999999999`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.63462 .22711 m
.65385 .22191 L
.67308 .21866 L
.69231 .21732 L
.71154 .21783 L
.73077 .22015 L
.75 .22425 L
.76923 .23006 L
.77129 .23077 L
.78846 .23805 L
.80769 .24801 L
.81114 .25 L
.82692 .2605 L
.83844 .26923 L
.84615 .27583 L
.85929 .28846 L
.86538 .29507 L
.87568 .30769 L
.88462 .3203 L
.88865 .32692 L
.89873 .34615 L
.90385 .35824 L
.90624 .36538 L
.91131 .38462 L
.91423 .40385 L
.91497 .42308 L
.91348 .44231 L
.9097 .46154 L
.90385 .47996 L
.90351 .48077 L
.89421 .5 L
.88462 .51516 L
.88156 .51923 L
.86538 .53728 L
.86414 .53846 L
.84615 .55306 L
.83927 .55769 L
.82692 .56466 L
.80769 .5732 L
.79699 .57692 L
.78846 .5791 L
.76923 .58268 L
.75 .58429 L
.73077 .58403 L
.71154 .58201 L
.69231 .57834 L
.68637 .57692 L
.67308 .57291 L
.65385 .56593 L
.63462 .55791 L
.63411 .55769 L
.61538 .549 L
.59615 .54085 L
.57692 .53968 L
.57181 .55769 L
.57149 .57692 L
.57227 .59615 L
.57164 .61538 L
.56924 .63462 L
.56481 .65385 L
.55837 .67308 L
.55769 .67484 L
.54812 .69231 L
.53846 .7065 L
.53421 .71154 L
.51923 .72647 L
.51406 .73077 L
.5 .74029 L
.48195 .75 L
.48077 .75045 L
.46154 .75675 L
.44231 .76087 L
.42308 .76265 L
.40385 .76215 L
.38462 .75948 L
.36538 .75488 L
.3495 .75 L
.34615 .74857 L
.32692 .73918 L
.31202 .73077 L
.30769 .7278 L
.28846 .71286 L
.28698 .71154 L
.26923 .69327 L
.26846 .69231 L
.25464 .67308 L
.25 .66561 L
.24447 .65385 L
.2369 .63462 L
.23173 .61538 L
.23077 .61013 L
.22944 .59615 L
.2293 .57692 L
.23077 .56058 L
.23127 .55769 L
.2361 .53846 L
.24341 .51923 L
.25 .50572 L
.25348 .5 L
.26764 .48077 L
.26923 .47907 L
.28748 .46154 L
.28846 .46088 L
.30769 .44831 L
.31842 .44231 L
.32692 .43952 L
.34615 .43392 L
.36538 .43058 L
.38462 .42984 L
.40385 .43153 L
.42308 .43521 L
.44231 .43993 L
.45206 .44231 L
.46154 .44563 L
.48077 .4533 L
.5 .45707 L
.51494 .44231 L
.51505 .42308 L
.51266 .40385 L
.51197 .38462 L
.51332 .36538 L
.51693 .34615 L
.51923 .33722 L
.52339 .32692 L
.53309 .30769 L
.53846 .29867 L
.54611 .28846 L
.55769 .27499 L
.5636 .26923 L
.57692 .25774 L
.58763 .25 L
.59615 .24462 L
.61538 .23455 L
.62419 .23077 L
F
0 g
.63462 .22711 m
.65385 .22191 L
.67308 .21866 L
.69231 .21732 L
.71154 .21783 L
.73077 .22015 L
.75 .22425 L
.76923 .23006 L
.77129 .23077 L
.78846 .23805 L
.80769 .24801 L
.81114 .25 L
.82692 .2605 L
.83844 .26923 L
.84615 .27583 L
.85929 .28846 L
.86538 .29507 L
.87568 .30769 L
.88462 .3203 L
.88865 .32692 L
.89873 .34615 L
.90385 .35824 L
.90624 .36538 L
.91131 .38462 L
.91423 .40385 L
.91497 .42308 L
.91348 .44231 L
.9097 .46154 L
.90385 .47996 L
.90351 .48077 L
.89421 .5 L
.88462 .51516 L
.88156 .51923 L
.86538 .53728 L
.86414 .53846 L
.84615 .55306 L
.83927 .55769 L
.82692 .56466 L
.80769 .5732 L
.79699 .57692 L
.78846 .5791 L
.76923 .58268 L
.75 .58429 L
.73077 .58403 L
.71154 .58201 L
.69231 .57834 L
.68637 .57692 L
.67308 .57291 L
.65385 .56593 L
.63462 .55791 L
Mistroke
.63411 .55769 L
.61538 .549 L
.59615 .54085 L
.57692 .53968 L
.57181 .55769 L
.57149 .57692 L
.57227 .59615 L
.57164 .61538 L
.56924 .63462 L
.56481 .65385 L
.55837 .67308 L
.55769 .67484 L
.54812 .69231 L
.53846 .7065 L
.53421 .71154 L
.51923 .72647 L
.51406 .73077 L
.5 .74029 L
.48195 .75 L
.48077 .75045 L
.46154 .75675 L
.44231 .76087 L
.42308 .76265 L
.40385 .76215 L
.38462 .75948 L
.36538 .75488 L
.3495 .75 L
.34615 .74857 L
.32692 .73918 L
.31202 .73077 L
.30769 .7278 L
.28846 .71286 L
.28698 .71154 L
.26923 .69327 L
.26846 .69231 L
.25464 .67308 L
.25 .66561 L
.24447 .65385 L
.2369 .63462 L
.23173 .61538 L
.23077 .61013 L
.22944 .59615 L
.2293 .57692 L
.23077 .56058 L
.23127 .55769 L
.2361 .53846 L
.24341 .51923 L
.25 .50572 L
.25348 .5 L
.26764 .48077 L
Mistroke
.26923 .47907 L
.28748 .46154 L
.28846 .46088 L
.30769 .44831 L
.31842 .44231 L
.32692 .43952 L
.34615 .43392 L
.36538 .43058 L
.38462 .42984 L
.40385 .43153 L
.42308 .43521 L
.44231 .43993 L
.45206 .44231 L
.46154 .44563 L
.48077 .4533 L
.5 .45707 L
.51494 .44231 L
.51505 .42308 L
.51266 .40385 L
.51197 .38462 L
.51332 .36538 L
.51693 .34615 L
.51923 .33722 L
.52339 .32692 L
.53309 .30769 L
.53846 .29867 L
.54611 .28846 L
.55769 .27499 L
.5636 .26923 L
.57692 .25774 L
.58763 .25 L
.59615 .24462 L
.61538 .23455 L
.62419 .23077 L
.63462 .22711 L
Mfstroke
.2 g
.34615 .4804 m
.36538 .47619 L
.38462 .47466 L
.40385 .4757 L
.42308 .47906 L
.43038 .48077 L
.44231 .48514 L
.46154 .49407 L
.47225 .5 L
.48077 .50588 L
.49706 .51923 L
.5 .5221 L
.5139 .53846 L
.51923 .54611 L
.52542 .55769 L
.53329 .57692 L
.53789 .59615 L
.53846 .60029 L
.53928 .61538 L
.53846 .62994 L
.5378 .63462 L
.53296 .65385 L
.52453 .67308 L
.51923 .68205 L
.51135 .69231 L
.5 .70392 L
.49055 .71154 L
.48077 .71772 L
.46154 .72678 L
.44995 .73077 L
.44231 .73216 L
.42308 .7344 L
.40385 .73409 L
.38462 .7314 L
.38123 .73077 L
.36538 .72589 L
.34615 .71768 L
.33457 .71154 L
.32692 .70654 L
.30881 .69231 L
.30769 .69127 L
.29116 .67308 L
.28846 .66953 L
.27885 .65385 L
.27021 .63462 L
.26923 .633 L
.26535 .61538 L
.26346 .59615 L
.26453 .57692 L
.26863 .55769 L
.26923 .5556 L
.27669 .53846 L
.28846 .52005 L
.28912 .51923 L
.30769 .50079 L
.30868 .5 L
.32692 .48855 L
.34482 .48077 L
F
0 g
.34615 .4804 m
.36538 .47619 L
.38462 .47466 L
.40385 .4757 L
.42308 .47906 L
.43038 .48077 L
.44231 .48514 L
.46154 .49407 L
.47225 .5 L
.48077 .50588 L
.49706 .51923 L
.5 .5221 L
.5139 .53846 L
.51923 .54611 L
.52542 .55769 L
.53329 .57692 L
.53789 .59615 L
.53846 .60029 L
.53928 .61538 L
.53846 .62994 L
.5378 .63462 L
.53296 .65385 L
.52453 .67308 L
.51923 .68205 L
.51135 .69231 L
.5 .70392 L
.49055 .71154 L
.48077 .71772 L
.46154 .72678 L
.44995 .73077 L
.44231 .73216 L
.42308 .7344 L
.40385 .73409 L
.38462 .7314 L
.38123 .73077 L
.36538 .72589 L
.34615 .71768 L
.33457 .71154 L
.32692 .70654 L
.30881 .69231 L
.30769 .69127 L
.29116 .67308 L
.28846 .66953 L
.27885 .65385 L
.27021 .63462 L
.26923 .633 L
.26535 .61538 L
.26346 .59615 L
.26453 .57692 L
.26863 .55769 L
Mistroke
.26923 .5556 L
.27669 .53846 L
.28846 .52005 L
.28912 .51923 L
.30769 .50079 L
.30868 .5 L
.32692 .48855 L
.34482 .48077 L
.34615 .4804 L
Mfstroke
.3 g
.36538 .49701 m
.38462 .49488 L
.40385 .49575 L
.42308 .49939 L
.42556 .5 L
.44231 .50629 L
.46154 .51644 L
.46592 .51923 L
.48077 .53101 L
.48835 .53846 L
.5 .55275 L
.50316 .55769 L
.5128 .57692 L
.51846 .59615 L
.51923 .60064 L
.52035 .61538 L
.51923 .6316 L
.51873 .63462 L
.5131 .65385 L
.50281 .67308 L
.5 .67703 L
.48544 .69231 L
.48077 .696 L
.46154 .7074 L
.45208 .71154 L
.44231 .71402 L
.42308 .71694 L
.40385 .7168 L
.38462 .7138 L
.37512 .71154 L
.36538 .70779 L
.34615 .69841 L
.3364 .69231 L
.32692 .68504 L
.31429 .67308 L
.30769 .66546 L
.29968 .65385 L
.28999 .63462 L
.28846 .63285 L
.28458 .61538 L
.28276 .59615 L
.28448 .57692 L
.28846 .55982 L
.29007 .55769 L
.30061 .53846 L
.30769 .52942 L
.31819 .51923 L
.32692 .51278 L
.34615 .50262 L
.35174 .5 L
F
0 g
.36538 .49701 m
.38462 .49488 L
.40385 .49575 L
.42308 .49939 L
.42556 .5 L
.44231 .50629 L
.46154 .51644 L
.46592 .51923 L
.48077 .53101 L
.48835 .53846 L
.5 .55275 L
.50316 .55769 L
.5128 .57692 L
.51846 .59615 L
.51923 .60064 L
.52035 .61538 L
.51923 .6316 L
.51873 .63462 L
.5131 .65385 L
.50281 .67308 L
.5 .67703 L
.48544 .69231 L
.48077 .696 L
.46154 .7074 L
.45208 .71154 L
.44231 .71402 L
.42308 .71694 L
.40385 .7168 L
.38462 .7138 L
.37512 .71154 L
.36538 .70779 L
.34615 .69841 L
.3364 .69231 L
.32692 .68504 L
.31429 .67308 L
.30769 .66546 L
.29968 .65385 L
.28999 .63462 L
.28846 .63285 L
.28458 .61538 L
.28276 .59615 L
.28448 .57692 L
.28846 .55982 L
.29007 .55769 L
.30061 .53846 L
.30769 .52942 L
.31819 .51923 L
.32692 .51278 L
.34615 .50262 L
.35174 .5 L
Mistroke
.36538 .49701 L
Mfstroke
.4 g
.36538 .51253 m
.38462 .50973 L
.40385 .51046 L
.42308 .51449 L
.43696 .51923 L
.44231 .52194 L
.46154 .53367 L
.46765 .53846 L
.48077 .55143 L
.48572 .55769 L
.49711 .57692 L
.5 .58126 L
.5035 .59615 L
.50567 .61538 L
.50374 .63462 L
.5 .65062 L
.49719 .65385 L
.48442 .67308 L
.48077 .677 L
.46154 .69156 L
.46036 .69231 L
.44231 .69959 L
.42308 .70328 L
.40385 .70335 L
.38462 .70007 L
.36538 .69346 L
.36274 .69231 L
.34615 .6828 L
.33355 .67308 L
.32692 .66676 L
.31626 .65385 L
.30769 .63994 L
.30539 .63462 L
.2994 .61538 L
.29759 .59615 L
.29995 .57692 L
.30698 .55769 L
.30769 .55626 L
.32047 .53846 L
.32692 .53222 L
.34615 .51942 L
.34645 .51923 L
F
0 g
.36538 .51253 m
.38462 .50973 L
.40385 .51046 L
.42308 .51449 L
.43696 .51923 L
.44231 .52194 L
.46154 .53367 L
.46765 .53846 L
.48077 .55143 L
.48572 .55769 L
.49711 .57692 L
.5 .58126 L
.5035 .59615 L
.50567 .61538 L
.50374 .63462 L
.5 .65062 L
.49719 .65385 L
.48442 .67308 L
.48077 .677 L
.46154 .69156 L
.46036 .69231 L
.44231 .69959 L
.42308 .70328 L
.40385 .70335 L
.38462 .70007 L
.36538 .69346 L
.36274 .69231 L
.34615 .6828 L
.33355 .67308 L
.32692 .66676 L
.31626 .65385 L
.30769 .63994 L
.30539 .63462 L
.2994 .61538 L
.29759 .59615 L
.29995 .57692 L
.30698 .55769 L
.30769 .55626 L
.32047 .53846 L
.32692 .53222 L
.34615 .51942 L
.34645 .51923 L
.36538 .51253 L
s
.5 g
.34615 .53432 m
.36538 .52572 L
.38462 .52218 L
.40385 .52273 L
.42308 .52709 L
.44231 .53546 L
.4475 .53846 L
.46154 .54904 L
.47016 .55769 L
.48077 .57194 L
.48342 .57692 L
.49071 .59615 L
.49312 .61538 L
.49073 .63462 L
.4828 .65385 L
.48077 .65726 L
.46656 .67308 L
.46154 .67691 L
.44231 .68691 L
.42308 .69144 L
.40385 .69176 L
.38462 .68827 L
.36538 .68083 L
.35206 .67308 L
.34615 .66862 L
.33111 .65385 L
.32692 .64874 L
.31876 .63462 L
.3121 .61538 L
.31031 .59615 L
.31337 .57692 L
.32217 .55769 L
.32692 .55097 L
.33995 .53846 L
F
0 g
.34615 .53432 m
.36538 .52572 L
.38462 .52218 L
.40385 .52273 L
.42308 .52709 L
.44231 .53546 L
.4475 .53846 L
.46154 .54904 L
.47016 .55769 L
.48077 .57194 L
.48342 .57692 L
.49071 .59615 L
.49312 .61538 L
.49073 .63462 L
.4828 .65385 L
.48077 .65726 L
.46656 .67308 L
.46154 .67691 L
.44231 .68691 L
.42308 .69144 L
.40385 .69176 L
.38462 .68827 L
.36538 .68083 L
.35206 .67308 L
.34615 .66862 L
.33111 .65385 L
.32692 .64874 L
.31876 .63462 L
.3121 .61538 L
.31031 .59615 L
.31337 .57692 L
.32217 .55769 L
.32692 .55097 L
.33995 .53846 L
.34615 .53432 L
s
.6 g
.36538 .538 m
.38462 .5336 L
.40385 .53393 L
.42276 .53846 L
.42308 .53857 L
.44231 .54803 L
.45494 .55769 L
.46154 .56425 L
.47064 .57692 L
.47895 .59615 L
.48077 .60493 L
.48153 .61538 L
.48077 .62486 L
.47858 .63462 L
.4688 .65385 L
.46154 .66218 L
.44617 .67308 L
.44231 .67477 L
.42308 .68037 L
.40385 .681 L
.38462 .67729 L
.37217 .67308 L
.36538 .669 L
.34615 .65438 L
.34562 .65385 L
.33117 .63462 L
.32692 .62536 L
.32384 .61538 L
.32209 .59615 L
.32598 .57692 L
.32692 .57384 L
.33704 .55769 L
.34615 .54875 L
.36399 .53846 L
F
0 g
.36538 .538 m
.38462 .5336 L
.40385 .53393 L
.42276 .53846 L
.42308 .53857 L
.44231 .54803 L
.45494 .55769 L
.46154 .56425 L
.47064 .57692 L
.47895 .59615 L
.48077 .60493 L
.48153 .61538 L
.48077 .62486 L
.47858 .63462 L
.4688 .65385 L
.46154 .66218 L
.44617 .67308 L
.44231 .67477 L
.42308 .68037 L
.40385 .681 L
.38462 .67729 L
.37217 .67308 L
.36538 .669 L
.34615 .65438 L
.34562 .65385 L
.33117 .63462 L
.32692 .62536 L
.32384 .61538 L
.32209 .59615 L
.32598 .57692 L
.32692 .57384 L
.33704 .55769 L
.34615 .54875 L
.36399 .53846 L
.36538 .538 L
s
.7 g
.36538 .55013 m
.38462 .5445 L
.40385 .54456 L
.42308 .54968 L
.4387 .55769 L
.44231 .5606 L
.45797 .57692 L
.46154 .58267 L
.46751 .59615 L
.4703 .61538 L
.4665 .63462 L
.46154 .64657 L
.4541 .65385 L
.44231 .66259 L
.42308 .66963 L
.40385 .67066 L
.38462 .66668 L
.36538 .65703 L
.36093 .65385 L
.34615 .6388 L
.34351 .63462 L
.33515 .61538 L
.33345 .59615 L
.33848 .57692 L
.34615 .56382 L
.35292 .55769 L
F
0 g
.36538 .55013 m
.38462 .5445 L
.40385 .54456 L
.42308 .54968 L
.4387 .55769 L
.44231 .5606 L
.45797 .57692 L
.46154 .58267 L
.46751 .59615 L
.4703 .61538 L
.4665 .63462 L
.46154 .64657 L
.4541 .65385 L
.44231 .66259 L
.42308 .66963 L
.40385 .67066 L
.38462 .66668 L
.36538 .65703 L
.36093 .65385 L
.34615 .6388 L
.34351 .63462 L
.33515 .61538 L
.33345 .59615 L
.33848 .57692 L
.34615 .56382 L
.35292 .55769 L
.36538 .55013 L
s
.8 g
.38462 .55577 m
.40385 .55539 L
.41394 .55769 L
.42308 .56094 L
.44231 .57478 L
.44423 .57692 L
.45593 .59615 L
.45887 .61538 L
.45397 .63462 L
.44231 .65 L
.43437 .65385 L
.42308 .65843 L
.40385 .66015 L
.38462 .65561 L
.37957 .65385 L
.36538 .64457 L
.35631 .63462 L
.34676 .61538 L
.34615 .61279 L
.34519 .59615 L
.34615 .59098 L
.35161 .57692 L
.36538 .56266 L
.37741 .55769 L
F
0 g
.38462 .55577 m
.40385 .55539 L
.41394 .55769 L
.42308 .56094 L
.44231 .57478 L
.44423 .57692 L
.45593 .59615 L
.45887 .61538 L
.45397 .63462 L
.44231 .65 L
.43437 .65385 L
.42308 .65843 L
.40385 .66015 L
.38462 .65561 L
.37957 .65385 L
.36538 .64457 L
.35631 .63462 L
.34676 .61538 L
.34615 .61279 L
.34519 .59615 L
.34615 .59098 L
.35161 .57692 L
.36538 .56266 L
.37741 .55769 L
.38462 .55577 L
s
.9 g
.38462 .56744 m
.40385 .56649 L
.42308 .57383 L
.42819 .57692 L
.44231 .59502 L
.44285 .59615 L
.44632 .61538 L
.44231 .62856 L
.43836 .63462 L
.42308 .64702 L
.40385 .64937 L
.38462 .64414 L
.36962 .63462 L
.36538 .62697 L
.35918 .61538 L
.35766 .59615 L
.36538 .58058 L
.36882 .57692 L
F
0 g
.38462 .56744 m
.40385 .56649 L
.42308 .57383 L
.42819 .57692 L
.44231 .59502 L
.44285 .59615 L
.44632 .61538 L
.44231 .62856 L
.43836 .63462 L
.42308 .64702 L
.40385 .64937 L
.38462 .64414 L
.36962 .63462 L
.36538 .62697 L
.35918 .61538 L
.35766 .59615 L
.36538 .58058 L
.36882 .57692 L
.38462 .56744 L
s
1 g
.38462 .58464 m
.40385 .58148 L
.42308 .59196 L
.42732 .59615 L
.4329 .61538 L
.42308 .62789 L
.40385 .63433 L
.38462 .62703 L
.37139 .61538 L
.37456 .59615 L
F
0 g
.38462 .58464 m
.40385 .58148 L
.42308 .59196 L
.42732 .59615 L
.4329 .61538 L
.42308 .62789 L
.40385 .63433 L
.38462 .62703 L
.37139 .61538 L
.37456 .59615 L
.38462 .58464 L
s
.2 g
.67308 .26471 m
.69231 .26163 L
.71154 .2611 L
.73077 .26298 L
.75 .26722 L
.75689 .26923 L
.76923 .27397 L
.78846 .28342 L
.79689 .28846 L
.80769 .29601 L
.82174 .30769 L
.82692 .31268 L
.83961 .32692 L
.84615 .33567 L
.85278 .34615 L
.86229 .36538 L
.86538 .37296 L
.86859 .38462 L
.87197 .40385 L
.87254 .42308 L
.87022 .44231 L
.86538 .46027 L
.86475 .46154 L
.85547 .48077 L
.84615 .49434 L
.84133 .5 L
.82692 .51359 L
.81937 .51923 L
.80769 .52626 L
.78846 .53466 L
.77636 .53846 L
.76923 .53973 L
.75 .54197 L
.73077 .54172 L
.71154 .53912 L
.70798 .53846 L
.69231 .53409 L
.67308 .52663 L
.65838 .51923 L
.65385 .51656 L
.63462 .50329 L
.63056 .5 L
.61538 .4858 L
.61086 .48077 L
.59635 .46154 L
.59615 .46123 L
.58602 .44231 L
.57887 .42308 L
.57692 .4156 L
.57482 .40385 L
.57364 .38462 L
.57536 .36538 L
.57692 .35514 L
.58026 .34615 L
.58885 .32692 L
.59615 .31518 L
.602 .30769 L
.61538 .29396 L
.62209 .28846 L
.63462 .28004 L
.65385 .27063 L
.65722 .26923 L
F
0 g
.67308 .26471 m
.69231 .26163 L
.71154 .2611 L
.73077 .26298 L
.75 .26722 L
.75689 .26923 L
.76923 .27397 L
.78846 .28342 L
.79689 .28846 L
.80769 .29601 L
.82174 .30769 L
.82692 .31268 L
.83961 .32692 L
.84615 .33567 L
.85278 .34615 L
.86229 .36538 L
.86538 .37296 L
.86859 .38462 L
.87197 .40385 L
.87254 .42308 L
.87022 .44231 L
.86538 .46027 L
.86475 .46154 L
.85547 .48077 L
.84615 .49434 L
.84133 .5 L
.82692 .51359 L
.81937 .51923 L
.80769 .52626 L
.78846 .53466 L
.77636 .53846 L
.76923 .53973 L
.75 .54197 L
.73077 .54172 L
.71154 .53912 L
.70798 .53846 L
.69231 .53409 L
.67308 .52663 L
.65838 .51923 L
.65385 .51656 L
.63462 .50329 L
.63056 .5 L
.61538 .4858 L
.61086 .48077 L
.59635 .46154 L
.59615 .46123 L
.58602 .44231 L
.57887 .42308 L
.57692 .4156 L
.57482 .40385 L
Mistroke
.57364 .38462 L
.57536 .36538 L
.57692 .35514 L
.58026 .34615 L
.58885 .32692 L
.59615 .31518 L
.602 .30769 L
.61538 .29396 L
.62209 .28846 L
.63462 .28004 L
.65385 .27063 L
.65722 .26923 L
.67308 .26471 L
Mfstroke
.3 g
.65385 .30483 m
.67308 .29587 L
.69231 .29107 L
.71154 .28967 L
.73077 .29133 L
.75 .296 L
.76923 .30381 L
.77664 .30769 L
.78846 .31529 L
.80282 .32692 L
.80769 .33165 L
.82004 .34615 L
.82692 .35631 L
.83178 .36538 L
.8393 .38462 L
.84314 .40385 L
.84343 .42308 L
.84 .44231 L
.83226 .46154 L
.82692 .47052 L
.81873 .48077 L
.80769 .49114 L
.79474 .5 L
.78846 .50321 L
.76923 .51023 L
.75 .51348 L
.73077 .51349 L
.71154 .5105 L
.69231 .50452 L
.68179 .5 L
.67308 .49527 L
.65385 .48203 L
.65232 .48077 L
.63462 .46305 L
.63338 .46154 L
.62048 .44231 L
.61538 .43245 L
.61204 .42308 L
.60742 .40385 L
.60638 .38462 L
.60904 .36538 L
.61538 .34682 L
.61586 .34615 L
.62812 .32692 L
.63462 .31972 L
.64927 .30769 L
F
0 g
.65385 .30483 m
.67308 .29587 L
.69231 .29107 L
.71154 .28967 L
.73077 .29133 L
.75 .296 L
.76923 .30381 L
.77664 .30769 L
.78846 .31529 L
.80282 .32692 L
.80769 .33165 L
.82004 .34615 L
.82692 .35631 L
.83178 .36538 L
.8393 .38462 L
.84314 .40385 L
.84343 .42308 L
.84 .44231 L
.83226 .46154 L
.82692 .47052 L
.81873 .48077 L
.80769 .49114 L
.79474 .5 L
.78846 .50321 L
.76923 .51023 L
.75 .51348 L
.73077 .51349 L
.71154 .5105 L
.69231 .50452 L
.68179 .5 L
.67308 .49527 L
.65385 .48203 L
.65232 .48077 L
.63462 .46305 L
.63338 .46154 L
.62048 .44231 L
.61538 .43245 L
.61204 .42308 L
.60742 .40385 L
.60638 .38462 L
.60904 .36538 L
.61538 .34682 L
.61586 .34615 L
.62812 .32692 L
.63462 .31972 L
.64927 .30769 L
.65385 .30483 L
s
.4 g
.67308 .32427 m
.69231 .31689 L
.71154 .31432 L
.73077 .31573 L
.75 .32097 L
.76361 .32692 L
.76923 .33041 L
.78846 .34547 L
.78915 .34615 L
.80449 .36538 L
.80769 .37003 L
.81365 .38462 L
.818 .40385 L
.81781 .42308 L
.81267 .44231 L
.80769 .45291 L
.80107 .46154 L
.78846 .47344 L
.77693 .48077 L
.76923 .48385 L
.75 .48867 L
.73077 .48918 L
.71154 .48585 L
.69598 .48077 L
.69231 .47862 L
.67308 .46672 L
.6668 .46154 L
.65385 .44788 L
.64981 .44231 L
.63946 .42308 L
.63462 .40641 L
.63417 .40385 L
.63343 .38462 L
.63462 .37614 L
.63751 .36538 L
.64767 .34615 L
.65385 .33869 L
.66835 .32692 L
F
0 g
.67308 .32427 m
.69231 .31689 L
.71154 .31432 L
.73077 .31573 L
.75 .32097 L
.76361 .32692 L
.76923 .33041 L
.78846 .34547 L
.78915 .34615 L
.80449 .36538 L
.80769 .37003 L
.81365 .38462 L
.818 .40385 L
.81781 .42308 L
.81267 .44231 L
.80769 .45291 L
.80107 .46154 L
.78846 .47344 L
.77693 .48077 L
.76923 .48385 L
.75 .48867 L
.73077 .48918 L
.71154 .48585 L
.69598 .48077 L
.69231 .47862 L
.67308 .46672 L
.6668 .46154 L
.65385 .44788 L
.64981 .44231 L
.63946 .42308 L
.63462 .40641 L
.63417 .40385 L
.63343 .38462 L
.63462 .37614 L
.63751 .36538 L
.64767 .34615 L
.65385 .33869 L
.66835 .32692 L
.67308 .32427 L
s
.5 g
.69231 .34419 m
.71154 .33926 L
.73077 .34025 L
.74889 .34615 L
.75 .34665 L
.76923 .35948 L
.77499 .36538 L
.78731 .38462 L
.78846 .38754 L
.79248 .40385 L
.79127 .42308 L
.78846 .43146 L
.78268 .44231 L
.76923 .45522 L
.75535 .46154 L
.75 .46309 L
.73077 .46467 L
.71384 .46154 L
.71154 .46084 L
.69231 .45142 L
.6811 .44231 L
.67308 .43376 L
.66704 .42308 L
.66053 .40385 L
.66042 .38462 L
.66757 .36538 L
.67308 .35738 L
.68758 .34615 L
F
0 g
.69231 .34419 m
.71154 .33926 L
.73077 .34025 L
.74889 .34615 L
.75 .34665 L
.76923 .35948 L
.77499 .36538 L
.78731 .38462 L
.78846 .38754 L
.79248 .40385 L
.79127 .42308 L
.78846 .43146 L
.78268 .44231 L
.76923 .45522 L
.75535 .46154 L
.75 .46309 L
.73077 .46467 L
.71384 .46154 L
.71154 .46084 L
.69231 .45142 L
.6811 .44231 L
.67308 .43376 L
.66704 .42308 L
.66053 .40385 L
.66042 .38462 L
.66757 .36538 L
.67308 .35738 L
.68758 .34615 L
.69231 .34419 L
s
.6 g
.71154 .37302 m
.73077 .37225 L
.75 .38327 L
.751 .38462 L
.76103 .40385 L
.7544 .42308 L
.75 .42612 L
.73077 .43555 L
.71154 .42832 L
.70605 .42308 L
.69458 .40385 L
.69746 .38462 L
F
0 g
.71154 .37302 m
.73077 .37225 L
.75 .38327 L
.751 .38462 L
.76103 .40385 L
.7544 .42308 L
.75 .42612 L
.73077 .43555 L
.71154 .42832 L
.70605 .42308 L
.69458 .40385 L
.69746 .38462 L
.71154 .37302 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.663 .742 .908 r
.39902 .5981 .40512 .60377 .41536 .6007 .40928 .59502 Mtetra
.663 .742 .909 r
.40928 .59502 .41536 .6007 .42565 .59763 .41959 .59192 Mtetra
.41959 .59192 .42565 .59763 .43597 .59454 .42994 .58881 Mtetra
.42994 .58881 .43597 .59454 .44633 .59144 .44033 .5857 Mtetra
.44033 .5857 .44633 .59144 .45673 .58833 .45075 .58257 Mtetra
.45075 .58257 .45673 .58833 .46718 .58521 .46122 .57942 Mtetra
.46122 .57942 .46718 .58521 .47766 .58207 .47173 .57627 Mtetra
.47173 .57627 .47766 .58207 .48818 .57893 .48228 .5731 Mtetra
.48228 .5731 .48818 .57893 .49874 .57577 .49287 .56993 Mtetra
.663 .743 .909 r
.49287 .56993 .49874 .57577 .50935 .5726 .5035 .56673 Mtetra
.5035 .56673 .50935 .5726 .51999 .56941 .51417 .56353 Mtetra
.51417 .56353 .51999 .56941 .53068 .56621 .52489 .56031 Mtetra
.52489 .56031 .53068 .56621 .54141 .563 .53564 .55708 Mtetra
.53564 .55708 .54141 .563 .55218 .55978 .54644 .55383 Mtetra
.54644 .55383 .55218 .55978 .56299 .55654 .55728 .55057 Mtetra
.55728 .55057 .56299 .55654 .57385 .55328 .56817 .54729 Mtetra
.56817 .54729 .57385 .55328 .58475 .55002 .57909 .544 Mtetra
.57909 .544 .58475 .55002 .59569 .54673 .59006 .54069 Mtetra
.664 .743 .909 r
.59006 .54069 .59569 .54673 .60667 .54344 .60108 .53737 Mtetra
.60108 .53737 .60667 .54344 .6177 .54013 .61213 .53404 Mtetra
.61213 .53404 .6177 .54013 .62877 .5368 .62323 .53069 Mtetra
.62323 .53069 .62877 .5368 .63988 .53346 .63438 .52732 Mtetra
.63438 .52732 .63988 .53346 .65104 .53011 .64557 .52394 Mtetra
.64557 .52394 .65104 .53011 .66225 .52674 .6568 .52054 Mtetra
.6568 .52054 .66225 .52674 .67349 .52335 .66808 .51713 Mtetra
.66808 .51713 .67349 .52335 .68479 .51996 .6794 .51371 Mtetra
.6794 .51371 .68479 .51996 .69612 .51655 .69077 .51027 Mtetra
.69077 .51027 .69612 .51655 .70751 .51312 .70219 .50681 Mtetra
.70219 .50681 .70751 .51312 .71894 .50968 .71365 .50335 Mtetra
.664 .742 .909 r
.71365 .50335 .71894 .50968 .73041 .50623 .72515 .49987 Mtetra
.664 .742 .908 r
.72515 .49987 .73041 .50623 .74193 .50276 .73671 .49637 Mtetra
.73671 .49637 .74193 .50276 .7535 .49928 .74831 .49286 Mtetra
.74831 .49286 .7535 .49928 .76512 .49579 .75996 .48934 Mtetra
.75996 .48934 .76512 .49579 .77678 .49228 .77165 .4858 Mtetra
.77165 .4858 .77678 .49228 .78849 .48876 .78339 .48225 Mtetra
.78339 .48225 .78849 .48876 .80024 .48522 .79519 .47869 Mtetra
.79519 .47869 .80024 .48522 .81205 .48168 .80703 .47511 Mtetra
.80703 .47511 .81205 .48168 .8239 .47811 .81891 .47152 Mtetra
.81891 .47152 .8239 .47811 .83581 .47454 .83085 .46791 Mtetra
.83085 .46791 .83581 .47454 .84776 .47095 .84284 .4643 Mtetra
.84284 .4643 .84776 .47095 .85976 .46734 .85487 .46066 Mtetra
.85487 .46066 .85976 .46734 .87181 .46372 .86696 .45701 Mtetra
.86696 .45701 .87181 .46372 .88391 .46009 .8791 .45335 Mtetra
.664 .741 .908 r
.8791 .45335 .88391 .46009 .89606 .45644 .89128 .44968 Mtetra
.89128 .44968 .89606 .45644 .90826 .45278 .90352 .44598 Mtetra
.90352 .44598 .90826 .45278 .92051 .4491 .91581 .44228 Mtetra
.91581 .44228 .92051 .4491 .93281 .44541 .92815 .43856 Mtetra
.92815 .43856 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.663 .742 .909 r
.39287 .5924 .39902 .5981 .40928 .59502 .40316 .58929 Mtetra
.40316 .58929 .40928 .59502 .41959 .59192 .41349 .58618 Mtetra
.41349 .58618 .41959 .59192 .42994 .58881 .42387 .58305 Mtetra
.42387 .58305 .42994 .58881 .44033 .5857 .43428 .57992 Mtetra
.43428 .57992 .44033 .5857 .45075 .58257 .44473 .57677 Mtetra
.44473 .57677 .45075 .58257 .46122 .57942 .45523 .57361 Mtetra
.45523 .57361 .46122 .57942 .47173 .57627 .46576 .57043 Mtetra
.663 .743 .909 r
.46576 .57043 .47173 .57627 .48228 .5731 .47633 .56725 Mtetra
.47633 .56725 .48228 .5731 .49287 .56993 .48695 .56405 Mtetra
.48695 .56405 .49287 .56993 .5035 .56673 .49761 .56084 Mtetra
.663 .743 .91 r
.49761 .56084 .5035 .56673 .51417 .56353 .50831 .55761 Mtetra
.50831 .55761 .51417 .56353 .52489 .56031 .51905 .55437 Mtetra
.51905 .55437 .52489 .56031 .53564 .55708 .52983 .55112 Mtetra
.52983 .55112 .53564 .55708 .54644 .55383 .54066 .54785 Mtetra
.54066 .54785 .54644 .55383 .55728 .55057 .55153 .54457 Mtetra
.55153 .54457 .55728 .55057 .56817 .54729 .56244 .54127 Mtetra
.56244 .54127 .56817 .54729 .57909 .544 .5734 .53795 Mtetra
.5734 .53795 .57909 .544 .59006 .54069 .5844 .53462 Mtetra
.664 .744 .91 r
.5844 .53462 .59006 .54069 .60108 .53737 .59544 .53128 Mtetra
.59544 .53128 .60108 .53737 .61213 .53404 .60653 .52792 Mtetra
.60653 .52792 .61213 .53404 .62323 .53069 .61766 .52454 Mtetra
.664 .743 .909 r
.61766 .52454 .62323 .53069 .63438 .52732 .62883 .52115 Mtetra
.62883 .52115 .63438 .52732 .64557 .52394 .64005 .51774 Mtetra
.64005 .51774 .64557 .52394 .6568 .52054 .65131 .51431 Mtetra
.65131 .51431 .6568 .52054 .66808 .51713 .66262 .51087 Mtetra
.66262 .51087 .66808 .51713 .6794 .51371 .67398 .50742 Mtetra
.67398 .50742 .6794 .51371 .69077 .51027 .68538 .50395 Mtetra
.68538 .50395 .69077 .51027 .70219 .50681 .69683 .50047 Mtetra
.69683 .50047 .70219 .50681 .71365 .50335 .70832 .49697 Mtetra
.70832 .49697 .71365 .50335 .72515 .49987 .71986 .49346 Mtetra
.71986 .49346 .72515 .49987 .73671 .49637 .73144 .48994 Mtetra
.73144 .48994 .73671 .49637 .74831 .49286 .74308 .4864 Mtetra
.664 .742 .908 r
.74308 .4864 .74831 .49286 .75996 .48934 .75476 .48285 Mtetra
.75476 .48285 .75996 .48934 .77165 .4858 .76649 .47928 Mtetra
.76649 .47928 .77165 .4858 .78339 .48225 .77826 .4757 Mtetra
.77826 .4757 .78339 .48225 .79519 .47869 .79009 .47211 Mtetra
.79009 .47211 .79519 .47869 .80703 .47511 .80196 .4685 Mtetra
.80196 .4685 .80703 .47511 .81891 .47152 .81389 .46488 Mtetra
.81389 .46488 .81891 .47152 .83085 .46791 .82586 .46124 Mtetra
.82586 .46124 .83085 .46791 .84284 .4643 .83788 .4576 Mtetra
.83788 .4576 .84284 .4643 .85487 .46066 .84995 .45393 Mtetra
.84995 .45393 .85487 .46066 .86696 .45701 .86207 .45026 Mtetra
.86207 .45026 .86696 .45701 .8791 .45335 .87425 .44656 Mtetra
.87425 .44656 .8791 .45335 .89128 .44968 .88647 .44286 Mtetra
.664 .741 .908 r
.88647 .44286 .89128 .44968 .90352 .44598 .89875 .43914 Mtetra
.89875 .43914 .90352 .44598 .91581 .44228 .91107 .4354 Mtetra
.91107 .4354 .91581 .44228 .92815 .43856 .92345 .43165 Mtetra
.92345 .43165 .92815 .43856 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .42031 Mtetra
.663 .742 .909 r
.38668 .58666 .39287 .5924 .40316 .58929 .397 .58353 Mtetra
.397 .58353 .40316 .58929 .41349 .58618 .40735 .5804 Mtetra
.40735 .5804 .41349 .58618 .42387 .58305 .41775 .57726 Mtetra
.41775 .57726 .42387 .58305 .43428 .57992 .42819 .5741 Mtetra
.42819 .5741 .43428 .57992 .44473 .57677 .43867 .57094 Mtetra
.663 .743 .909 r
.43867 .57094 .44473 .57677 .45523 .57361 .44919 .56776 Mtetra
.44919 .56776 .45523 .57361 .46576 .57043 .45975 .56456 Mtetra
.663 .743 .91 r
.45975 .56456 .46576 .57043 .47633 .56725 .47035 .56136 Mtetra
.47035 .56136 .47633 .56725 .48695 .56405 .48099 .55814 Mtetra
.48099 .55814 .48695 .56405 .49761 .56084 .49168 .55491 Mtetra
.49168 .55491 .49761 .56084 .50831 .55761 .5024 .55167 Mtetra
.5024 .55167 .50831 .55761 .51905 .55437 .51317 .54841 Mtetra
.663 .744 .91 r
.51317 .54841 .51905 .55437 .52983 .55112 .52398 .54513 Mtetra
.52398 .54513 .52983 .55112 .54066 .54785 .53484 .54184 Mtetra
.53484 .54184 .54066 .54785 .55153 .54457 .54574 .53854 Mtetra
.54574 .53854 .55153 .54457 .56244 .54127 .55668 .53521 Mtetra
.55668 .53521 .56244 .54127 .5734 .53795 .56766 .53188 Mtetra
.56766 .53188 .5734 .53795 .5844 .53462 .57869 .52852 Mtetra
.664 .744 .91 r
.57869 .52852 .5844 .53462 .59544 .53128 .58976 .52515 Mtetra
.58976 .52515 .59544 .53128 .60653 .52792 .60088 .52176 Mtetra
.60088 .52176 .60653 .52792 .61766 .52454 .61204 .51836 Mtetra
.61204 .51836 .61766 .52454 .62883 .52115 .62324 .51494 Mtetra
.62324 .51494 .62883 .52115 .64005 .51774 .63449 .5115 Mtetra
.63449 .5115 .64005 .51774 .65131 .51431 .64579 .50805 Mtetra
.664 .744 .909 r
.64579 .50805 .65131 .51431 .66262 .51087 .65713 .50458 Mtetra
.65713 .50458 .66262 .51087 .67398 .50742 .66852 .5011 Mtetra
.66852 .5011 .67398 .50742 .68538 .50395 .67995 .4976 Mtetra
.664 .743 .909 r
.67995 .4976 .68538 .50395 .69683 .50047 .69143 .49409 Mtetra
.69143 .49409 .69683 .50047 .70832 .49697 .70295 .49056 Mtetra
.70295 .49056 .70832 .49697 .71986 .49346 .71452 .48702 Mtetra
.71452 .48702 .71986 .49346 .73144 .48994 .72614 .48346 Mtetra
.72614 .48346 .73144 .48994 .74308 .4864 .73781 .47989 Mtetra
.73781 .47989 .74308 .4864 .75476 .48285 .74952 .47631 Mtetra
.664 .743 .908 r
.74952 .47631 .75476 .48285 .76649 .47928 .76128 .47271 Mtetra
.664 .742 .908 r
.76128 .47271 .76649 .47928 .77826 .4757 .77309 .4691 Mtetra
.77309 .4691 .77826 .4757 .79009 .47211 .78495 .46548 Mtetra
.78495 .46548 .79009 .47211 .80196 .4685 .79686 .46184 Mtetra
.79686 .46184 .80196 .4685 .81389 .46488 .80882 .45819 Mtetra
.80882 .45819 .81389 .46488 .82586 .46124 .82083 .45452 Mtetra
.82083 .45452 .82586 .46124 .83788 .4576 .83289 .45085 Mtetra
.83289 .45085 .83788 .4576 .84995 .45393 .84499 .44715 Mtetra
.84499 .44715 .84995 .45393 .86207 .45026 .85715 .44345 Mtetra
.85715 .44345 .86207 .45026 .87425 .44656 .86936 .43972 Mtetra
.86936 .43972 .87425 .44656 .88647 .44286 .88162 .43599 Mtetra
.88162 .43599 .88647 .44286 .89875 .43914 .89393 .43224 Mtetra
.664 .741 .908 r
.89393 .43224 .89875 .43914 .91107 .4354 .9063 .42847 Mtetra
.9063 .42847 .91107 .4354 .92345 .43165 .91871 .42469 Mtetra
.91871 .42469 .92345 .43165 .93588 .42788 .93118 .4209 Mtetra
.93118 .4209 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .42031 .95628 .41326 Mtetra
.663 .742 .909 r
.38044 .58088 .38668 .58666 .397 .58353 .39078 .57774 Mtetra
.39078 .57774 .397 .58353 .40735 .5804 .40117 .57459 Mtetra
.40117 .57459 .40735 .5804 .41775 .57726 .41159 .57143 Mtetra
.41159 .57143 .41775 .57726 .42819 .5741 .42205 .56825 Mtetra
.663 .743 .91 r
.42205 .56825 .42819 .5741 .43867 .57094 .43256 .56507 Mtetra
.43256 .56507 .43867 .57094 .44919 .56776 .4431 .56187 Mtetra
.4431 .56187 .44919 .56776 .45975 .56456 .45369 .55866 Mtetra
.45369 .55866 .45975 .56456 .47035 .56136 .46432 .55544 Mtetra
.46432 .55544 .47035 .56136 .48099 .55814 .47499 .55221 Mtetra
.47499 .55221 .48099 .55814 .49168 .55491 .4857 .54896 Mtetra
.663 .744 .91 r
.4857 .54896 .49168 .55491 .5024 .55167 .49645 .54569 Mtetra
.49645 .54569 .5024 .55167 .51317 .54841 .50725 .54241 Mtetra
.50725 .54241 .51317 .54841 .52398 .54513 .51809 .53912 Mtetra
.51809 .53912 .52398 .54513 .53484 .54184 .52897 .53581 Mtetra
.663 .744 .911 r
.52897 .53581 .53484 .54184 .54574 .53854 .5399 .53248 Mtetra
.5399 .53248 .54574 .53854 .55668 .53521 .55087 .52913 Mtetra
.55087 .52913 .55668 .53521 .56766 .53188 .56188 .52577 Mtetra
.663 .745 .911 r
.56188 .52577 .56766 .53188 .57869 .52852 .57294 .52239 Mtetra
.664 .745 .91 r
.57294 .52239 .57869 .52852 .58976 .52515 .58404 .519 Mtetra
.58404 .519 .58976 .52515 .60088 .52176 .59519 .51559 Mtetra
.59519 .51559 .60088 .52176 .61204 .51836 .60638 .51215 Mtetra
.60638 .51215 .61204 .51836 .62324 .51494 .61761 .50871 Mtetra
.61761 .50871 .62324 .51494 .63449 .5115 .6289 .50524 Mtetra
.6289 .50524 .63449 .5115 .64579 .50805 .64022 .50176 Mtetra
.664 .744 .91 r
.64022 .50176 .64579 .50805 .65713 .50458 .65159 .49826 Mtetra
.65159 .49826 .65713 .50458 .66852 .5011 .66301 .49474 Mtetra
.66301 .49474 .66852 .5011 .67995 .4976 .67447 .49121 Mtetra
.664 .744 .909 r
.67447 .49121 .67995 .4976 .69143 .49409 .68599 .48767 Mtetra
.68599 .48767 .69143 .49409 .70295 .49056 .69754 .48411 Mtetra
.664 .743 .909 r
.69754 .48411 .70295 .49056 .71452 .48702 .70915 .48053 Mtetra
.70915 .48053 .71452 .48702 .72614 .48346 .7208 .47694 Mtetra
.7208 .47694 .72614 .48346 .73781 .47989 .7325 .47334 Mtetra
.7325 .47334 .73781 .47989 .74952 .47631 .74425 .46973 Mtetra
.74425 .46973 .74952 .47631 .76128 .47271 .75604 .4661 Mtetra
.75604 .4661 .76128 .47271 .77309 .4691 .76789 .46246 Mtetra
.664 .742 .908 r
.76789 .46246 .77309 .4691 .78495 .46548 .77978 .4588 Mtetra
.77978 .4588 .78495 .46548 .79686 .46184 .79172 .45513 Mtetra
.79172 .45513 .79686 .46184 .80882 .45819 .80372 .45145 Mtetra
.80372 .45145 .80882 .45819 .82083 .45452 .81576 .44776 Mtetra
.81576 .44776 .82083 .45452 .83289 .45085 .82785 .44405 Mtetra
.82785 .44405 .83289 .45085 .84499 .44715 .84 .44032 Mtetra
.84 .44032 .84499 .44715 .85715 .44345 .85219 .43659 Mtetra
.85219 .43659 .85715 .44345 .86936 .43972 .86444 .43283 Mtetra
.86444 .43283 .86936 .43972 .88162 .43599 .87673 .42907 Mtetra
.87673 .42907 .88162 .43599 .89393 .43224 .88908 .42529 Mtetra
.88908 .42529 .89393 .43224 .9063 .42847 .90149 .42149 Mtetra
.664 .741 .908 r
.90149 .42149 .9063 .42847 .91871 .42469 .91394 .41768 Mtetra
.91394 .41768 .91871 .42469 .93118 .4209 .92645 .41385 Mtetra
.92645 .41385 .93118 .4209 .94371 .41708 .93901 .41001 Mtetra
.93901 .41001 .94371 .41708 .95628 .41326 .95163 .40615 Mtetra
.663 .742 .909 r
.37416 .57507 .38044 .58088 .39078 .57774 .38453 .57191 Mtetra
.38453 .57191 .39078 .57774 .40117 .57459 .39494 .56874 Mtetra
.662 .743 .91 r
.39494 .56874 .40117 .57459 .41159 .57143 .40538 .56556 Mtetra
.40538 .56556 .41159 .57143 .42205 .56825 .41587 .56237 Mtetra
.41587 .56237 .42205 .56825 .43256 .56507 .4264 .55917 Mtetra
.4264 .55917 .43256 .56507 .4431 .56187 .43697 .55596 Mtetra
.43697 .55596 .4431 .56187 .45369 .55866 .44759 .55273 Mtetra
.44759 .55273 .45369 .55866 .46432 .55544 .45824 .54949 Mtetra
.662 .744 .911 r
.45824 .54949 .46432 .55544 .47499 .55221 .46894 .54624 Mtetra
.46894 .54624 .47499 .55221 .4857 .54896 .47968 .54297 Mtetra
.47968 .54297 .4857 .54896 .49645 .54569 .49046 .53969 Mtetra
.663 .744 .911 r
.49046 .53969 .49645 .54569 .50725 .54241 .50128 .53639 Mtetra
.663 .745 .911 r
.50128 .53639 .50725 .54241 .51809 .53912 .51215 .53308 Mtetra
.51215 .53308 .51809 .53912 .52897 .53581 .52306 .52974 Mtetra
.52306 .52974 .52897 .53581 .5399 .53248 .53402 .5264 Mtetra
.53402 .5264 .5399 .53248 .55087 .52913 .54502 .52303 Mtetra
.54502 .52303 .55087 .52913 .56188 .52577 .55606 .51965 Mtetra
.55606 .51965 .56188 .52577 .57294 .52239 .56715 .51625 Mtetra
.663 .746 .911 r
.56715 .51625 .57294 .52239 .58404 .519 .57828 .51283 Mtetra
.664 .746 .911 r
.57828 .51283 .58404 .519 .59519 .51559 .58946 .50939 Mtetra
.58946 .50939 .59519 .51559 .60638 .51215 .60068 .50594 Mtetra
.60068 .50594 .60638 .51215 .61761 .50871 .61194 .50246 Mtetra
.61194 .50246 .61761 .50871 .6289 .50524 .62326 .49896 Mtetra
.62326 .49896 .6289 .50524 .64022 .50176 .63461 .49544 Mtetra
.665 .745 .91 r
.63461 .49544 .64022 .50176 .65159 .49826 .64602 .49191 Mtetra
.64602 .49191 .65159 .49826 .66301 .49474 .65747 .48836 Mtetra
.65747 .48836 .66301 .49474 .67447 .49121 .66896 .48479 Mtetra
.665 .744 .91 r
.66896 .48479 .67447 .49121 .68599 .48767 .6805 .48121 Mtetra
.665 .744 .909 r
.6805 .48121 .68599 .48767 .69754 .48411 .69209 .47762 Mtetra
.69209 .47762 .69754 .48411 .70915 .48053 .70373 .47401 Mtetra
.70373 .47401 .70915 .48053 .7208 .47694 .71542 .47039 Mtetra
.665 .743 .909 r
.71542 .47039 .7208 .47694 .7325 .47334 .72715 .46675 Mtetra
.664 .743 .909 r
.72715 .46675 .7325 .47334 .74425 .46973 .73893 .4631 Mtetra
.73893 .4631 .74425 .46973 .75604 .4661 .75076 .45944 Mtetra
.75076 .45944 .75604 .4661 .76789 .46246 .76264 .45577 Mtetra
.76264 .45577 .76789 .46246 .77978 .4588 .77457 .45208 Mtetra
.664 .743 .908 r
.77457 .45208 .77978 .4588 .79172 .45513 .78654 .44838 Mtetra
.664 .742 .908 r
.78654 .44838 .79172 .45513 .80372 .45145 .79857 .44466 Mtetra
.79857 .44466 .80372 .45145 .81576 .44776 .81065 .44094 Mtetra
.81065 .44094 .81576 .44776 .82785 .44405 .82278 .4372 Mtetra
.82278 .4372 .82785 .44405 .84 .44032 .83496 .43344 Mtetra
.83496 .43344 .84 .44032 .85219 .43659 .84719 .42967 Mtetra
.84719 .42967 .85219 .43659 .86444 .43283 .85947 .42589 Mtetra
.85947 .42589 .86444 .43283 .87673 .42907 .87181 .42209 Mtetra
.87181 .42209 .87673 .42907 .88908 .42529 .8842 .41828 Mtetra
.8842 .41828 .88908 .42529 .90149 .42149 .89664 .41445 Mtetra
.89664 .41445 .90149 .42149 .91394 .41768 .90913 .41061 Mtetra
.664 .741 .908 r
.90913 .41061 .91394 .41768 .92645 .41385 .92168 .40675 Mtetra
.92168 .40675 .92645 .41385 .93901 .41001 .93428 .40288 Mtetra
.93428 .40288 .93901 .41001 .95163 .40615 .94693 .39899 Mtetra
.662 .742 .909 r
.36784 .56922 .37416 .57507 .38453 .57191 .37823 .56605 Mtetra
.662 .743 .91 r
.37823 .56605 .38453 .57191 .39494 .56874 .38866 .56286 Mtetra
.38866 .56286 .39494 .56874 .40538 .56556 .39913 .55967 Mtetra
.39913 .55967 .40538 .56556 .41587 .56237 .40965 .55646 Mtetra
.40965 .55646 .41587 .56237 .4264 .55917 .4202 .55324 Mtetra
.4202 .55324 .4264 .55917 .43697 .55596 .4308 .55001 Mtetra
.662 .744 .911 r
.4308 .55001 .43697 .55596 .44759 .55273 .44144 .54677 Mtetra
.44144 .54677 .44759 .55273 .45824 .54949 .45212 .54352 Mtetra
.45212 .54352 .45824 .54949 .46894 .54624 .46285 .54025 Mtetra
.46285 .54025 .46894 .54624 .47968 .54297 .47361 .53696 Mtetra
.662 .745 .911 r
.47361 .53696 .47968 .54297 .49046 .53969 .48442 .53366 Mtetra
.48442 .53366 .49046 .53969 .50128 .53639 .49527 .53034 Mtetra
.662 .745 .912 r
.49527 .53034 .50128 .53639 .51215 .53308 .50617 .52701 Mtetra
.50617 .52701 .51215 .53308 .52306 .52974 .51711 .52366 Mtetra
.663 .746 .912 r
.51711 .52366 .52306 .52974 .53402 .5264 .5281 .5203 Mtetra
.5281 .5203 .53402 .5264 .54502 .52303 .53912 .51692 Mtetra
.53912 .51692 .54502 .52303 .55606 .51965 .5502 .51353 Mtetra
.663 .747 .912 r
.5502 .51353 .55606 .51965 .56715 .51625 .56131 .51011 Mtetra
.663 .747 .913 r
.56131 .51011 .56715 .51625 .57828 .51283 .57248 .50667 Mtetra
.57248 .50667 .57828 .51283 .58946 .50939 .58368 .50322 Mtetra
.664 .748 .913 r
.58368 .50322 .58946 .50939 .60068 .50594 .59493 .49973 Mtetra
.59493 .49973 .60068 .50594 .61194 .50246 .60623 .49622 Mtetra
.665 .748 .912 r
.60623 .49622 .61194 .50246 .62326 .49896 .61758 .49268 Mtetra
.665 .747 .912 r
.61758 .49268 .62326 .49896 .63461 .49544 .62896 .48913 Mtetra
.665 .747 .911 r
.62896 .48913 .63461 .49544 .64602 .49191 .6404 .48555 Mtetra
.665 .746 .911 r
.6404 .48555 .64602 .49191 .65747 .48836 .65188 .48195 Mtetra
.665 .746 .91 r
.65188 .48195 .65747 .48836 .66896 .48479 .66341 .47835 Mtetra
.665 .745 .91 r
.66341 .47835 .66896 .48479 .6805 .48121 .67498 .47473 Mtetra
.67498 .47473 .6805 .48121 .69209 .47762 .6866 .47109 Mtetra
.6866 .47109 .69209 .47762 .70373 .47401 .69827 .46745 Mtetra
.665 .744 .909 r
.69827 .46745 .70373 .47401 .71542 .47039 .70999 .46379 Mtetra
.70999 .46379 .71542 .47039 .72715 .46675 .72176 .46012 Mtetra
.72176 .46012 .72715 .46675 .73893 .4631 .73357 .45644 Mtetra
.665 .743 .909 r
.73357 .45644 .73893 .4631 .75076 .45944 .74544 .45274 Mtetra
.74544 .45274 .75076 .45944 .76264 .45577 .75735 .44903 Mtetra
.664 .743 .909 r
.75735 .44903 .76264 .45577 .77457 .45208 .76931 .44531 Mtetra
.76931 .44531 .77457 .45208 .78654 .44838 .78133 .44158 Mtetra
.664 .743 .908 r
.78133 .44158 .78654 .44838 .79857 .44466 .79339 .43783 Mtetra
.664 .742 .908 r
.79339 .43783 .79857 .44466 .81065 .44094 .8055 .43407 Mtetra
.8055 .43407 .81065 .44094 .82278 .4372 .81767 .4303 Mtetra
.81767 .4303 .82278 .4372 .83496 .43344 .82989 .42651 Mtetra
.82989 .42651 .83496 .43344 .84719 .42967 .84215 .42271 Mtetra
.84215 .42271 .84719 .42967 .85947 .42589 .85447 .41889 Mtetra
.85447 .41889 .85947 .42589 .87181 .42209 .86685 .41506 Mtetra
.86685 .41506 .87181 .42209 .8842 .41828 .87927 .41122 Mtetra
.87927 .41122 .8842 .41828 .89664 .41445 .89175 .40736 Mtetra
.89175 .40736 .89664 .41445 .90913 .41061 .90428 .40349 Mtetra
.664 .741 .908 r
.90428 .40349 .90913 .41061 .92168 .40675 .91687 .3996 Mtetra
.91687 .3996 .92168 .40675 .93428 .40288 .92951 .3957 Mtetra
.92951 .3957 .93428 .40288 .94693 .39899 .9422 .39177 Mtetra
.662 .743 .91 r
.36146 .56334 .36784 .56922 .37823 .56605 .37188 .56015 Mtetra
.37188 .56015 .37823 .56605 .38866 .56286 .38234 .55695 Mtetra
.38234 .55695 .38866 .56286 .39913 .55967 .39284 .55374 Mtetra
.39284 .55374 .39913 .55967 .40965 .55646 .40338 .55052 Mtetra
.662 .743 .911 r
.40338 .55052 .40965 .55646 .4202 .55324 .41396 .54728 Mtetra
.662 .744 .911 r
.41396 .54728 .4202 .55324 .4308 .55001 .42458 .54404 Mtetra
.42458 .54404 .4308 .55001 .44144 .54677 .43525 .54078 Mtetra
.43525 .54078 .44144 .54677 .45212 .54352 .44596 .53751 Mtetra
.662 .745 .912 r
.44596 .53751 .45212 .54352 .46285 .54025 .45671 .53423 Mtetra
.45671 .53423 .46285 .54025 .47361 .53696 .4675 .53093 Mtetra
.4675 .53093 .47361 .53696 .48442 .53366 .47834 .52761 Mtetra
.662 .746 .912 r
.47834 .52761 .48442 .53366 .49527 .53034 .48922 .52428 Mtetra
.48922 .52428 .49527 .53034 .50617 .52701 .50014 .52094 Mtetra
.662 .746 .913 r
.50014 .52094 .50617 .52701 .51711 .52366 .51111 .51758 Mtetra
.662 .747 .913 r
.51111 .51758 .51711 .52366 .5281 .5203 .52213 .51421 Mtetra
.662 .747 .914 r
.52213 .51421 .5281 .5203 .53912 .51692 .53318 .51083 Mtetra
.662 .748 .914 r
.53318 .51083 .53912 .51692 .5502 .51353 .54429 .50744 Mtetra
.662 .749 .915 r
.54429 .50744 .5502 .51353 .56131 .51011 .55544 .50403 Mtetra
.662 .75 .916 r
.55544 .50403 .56131 .51011 .57248 .50667 .56663 .5006 Mtetra
.663 .751 .916 r
.56663 .5006 .57248 .50667 .58368 .50322 .57787 .49713 Mtetra
.663 .752 .916 r
.57787 .49713 .58368 .50322 .59493 .49973 .58915 .49362 Mtetra
.664 .753 .916 r
.58915 .49362 .59493 .49973 .60623 .49622 .60048 .49007 Mtetra
.665 .753 .915 r
.60048 .49007 .60623 .49622 .61758 .49268 .61185 .48648 Mtetra
.666 .752 .914 r
.61185 .48648 .61758 .49268 .62896 .48913 .62327 .48286 Mtetra
.666 .751 .913 r
.62327 .48286 .62896 .48913 .6404 .48555 .63474 .47922 Mtetra
.666 .749 .912 r
.63474 .47922 .6404 .48555 .65188 .48195 .64625 .47556 Mtetra
.666 .748 .912 r
.64625 .47556 .65188 .48195 .66341 .47835 .65781 .47189 Mtetra
.666 .747 .911 r
.65781 .47189 .66341 .47835 .67498 .47473 .66942 .46822 Mtetra
.666 .746 .91 r
.66942 .46822 .67498 .47473 .6866 .47109 .68107 .46454 Mtetra
.665 .745 .91 r
.68107 .46454 .6866 .47109 .69827 .46745 .69278 .46086 Mtetra
.69278 .46086 .69827 .46745 .70999 .46379 .70453 .45716 Mtetra
.665 .744 .909 r
.70453 .45716 .70999 .46379 .72176 .46012 .71633 .45345 Mtetra
.71633 .45345 .72176 .46012 .73357 .45644 .72818 .44973 Mtetra
.72818 .44973 .73357 .45644 .74544 .45274 .74007 .446 Mtetra
.74007 .446 .74544 .45274 .75735 .44903 .75202 .44225 Mtetra
.665 .743 .909 r
.75202 .44225 .75735 .44903 .76931 .44531 .76402 .4385 Mtetra
.76402 .4385 .76931 .44531 .78133 .44158 .77607 .43473 Mtetra
.664 .743 .908 r
.77607 .43473 .78133 .44158 .79339 .43783 .78817 .43095 Mtetra
.78817 .43095 .79339 .43783 .8055 .43407 .80032 .42715 Mtetra
.664 .742 .908 r
.80032 .42715 .8055 .43407 .81767 .4303 .81252 .42335 Mtetra
.81252 .42335 .81767 .4303 .82989 .42651 .82477 .41953 Mtetra
.82477 .41953 .82989 .42651 .84215 .42271 .83708 .41569 Mtetra
.83708 .41569 .84215 .42271 .85447 .41889 .84943 .41184 Mtetra
.84943 .41184 .85447 .41889 .86685 .41506 .86184 .40798 Mtetra
.86184 .40798 .86685 .41506 .87927 .41122 .87431 .40411 Mtetra
.87431 .40411 .87927 .41122 .89175 .40736 .88683 .40022 Mtetra
.88683 .40022 .89175 .40736 .90428 .40349 .8994 .39631 Mtetra
.8994 .39631 .90428 .40349 .91687 .3996 .91202 .39239 Mtetra
.664 .741 .908 r
.91202 .39239 .91687 .3996 .92951 .3957 .9247 .38845 Mtetra
.9247 .38845 .92951 .3957 .9422 .39177 .93744 .3845 Mtetra
.662 .743 .91 r
.35505 .55743 .36146 .56334 .37188 .56015 .36549 .55422 Mtetra
.36549 .55422 .37188 .56015 .38234 .55695 .37597 .551 Mtetra
.662 .743 .911 r
.37597 .551 .38234 .55695 .39284 .55374 .38649 .54778 Mtetra
.661 .744 .911 r
.38649 .54778 .39284 .55374 .40338 .55052 .39706 .54454 Mtetra
.39706 .54454 .40338 .55052 .41396 .54728 .40767 .5413 Mtetra
.40767 .5413 .41396 .54728 .42458 .54404 .41832 .53804 Mtetra
.661 .744 .912 r
.41832 .53804 .42458 .54404 .43525 .54078 .42901 .53477 Mtetra
.661 .745 .912 r
.42901 .53477 .43525 .54078 .44596 .53751 .43974 .53148 Mtetra
.43974 .53148 .44596 .53751 .45671 .53423 .45052 .52818 Mtetra
.45052 .52818 .45671 .53423 .4675 .53093 .46134 .52487 Mtetra
.661 .746 .913 r
.46134 .52487 .4675 .53093 .47834 .52761 .47221 .52155 Mtetra
.47221 .52155 .47834 .52761 .48922 .52428 .48312 .51821 Mtetra
.661 .747 .914 r
.48312 .51821 .48922 .52428 .50014 .52094 .49407 .51487 Mtetra
.66 .748 .915 r
.49407 .51487 .50014 .52094 .51111 .51758 .50507 .51152 Mtetra
.66 .749 .916 r
.50507 .51152 .51111 .51758 .52213 .51421 .51611 .50818 Mtetra
.659 .75 .917 r
.51611 .50818 .52213 .51421 .53318 .51083 .5272 .50484 Mtetra
.659 .752 .919 r
.5272 .50484 .53318 .51083 .54429 .50744 .53833 .5015 Mtetra
.658 .755 .921 r
.53833 .5015 .54429 .50744 .55544 .50403 .54951 .49814 Mtetra
.659 .758 .923 r
.54951 .49814 .55544 .50403 .56663 .5006 .56074 .49476 Mtetra
.66 .76 .924 r
.56074 .49476 .56663 .5006 .57787 .49713 .57201 .49131 Mtetra
.662 .763 .925 r
.57201 .49131 .57787 .49713 .58915 .49362 .58333 .48779 Mtetra
.665 .764 .924 r
.58333 .48779 .58915 .49362 .60048 .49007 .59469 .48419 Mtetra
.667 .764 .922 r
.59469 .48419 .60048 .49007 .61185 .48648 .6061 .48051 Mtetra
.668 .762 .92 r
.6061 .48051 .61185 .48648 .62327 .48286 .61755 .47678 Mtetra
.669 .759 .918 r
.61755 .47678 .62327 .48286 .63474 .47922 .62904 .47301 Mtetra
.669 .756 .916 r
.62904 .47301 .63474 .47922 .64625 .47556 .64059 .46924 Mtetra
.668 .753 .914 r
.64059 .46924 .64625 .47556 .65781 .47189 .65218 .46547 Mtetra
.668 .75 .912 r
.65218 .46547 .65781 .47189 .66942 .46822 .66381 .46172 Mtetra
.667 .748 .911 r
.66381 .46172 .66942 .46822 .68107 .46454 .6755 .45798 Mtetra
.666 .747 .91 r
.6755 .45798 .68107 .46454 .69278 .46086 .68724 .45423 Mtetra
.666 .746 .91 r
.68724 .45423 .69278 .46086 .70453 .45716 .69902 .45049 Mtetra
.665 .745 .91 r
.69902 .45049 .70453 .45716 .71633 .45345 .71085 .44674 Mtetra
.665 .745 .909 r
.71085 .44674 .71633 .45345 .72818 .44973 .72274 .44298 Mtetra
.665 .744 .909 r
.72274 .44298 .72818 .44973 .74007 .446 .73467 .43921 Mtetra
.73467 .43921 .74007 .446 .75202 .44225 .74665 .43543 Mtetra
.74665 .43543 .75202 .44225 .76402 .4385 .75868 .43164 Mtetra
.665 .743 .909 r
.75868 .43164 .76402 .4385 .77607 .43473 .77077 .42783 Mtetra
.77077 .42783 .77607 .43473 .78817 .43095 .7829 .42401 Mtetra
.665 .743 .908 r
.7829 .42401 .78817 .43095 .80032 .42715 .79509 .42019 Mtetra
.664 .743 .908 r
.79509 .42019 .80032 .42715 .81252 .42335 .80733 .41634 Mtetra
.664 .742 .908 r
.80733 .41634 .81252 .42335 .82477 .41953 .81962 .41249 Mtetra
.81962 .41249 .82477 .41953 .83708 .41569 .83196 .40862 Mtetra
.83196 .40862 .83708 .41569 .84943 .41184 .84435 .40474 Mtetra
.84435 .40474 .84943 .41184 .86184 .40798 .8568 .40085 Mtetra
.8568 .40085 .86184 .40798 .87431 .40411 .86931 .39694 Mtetra
.86931 .39694 .87431 .40411 .88683 .40022 .88186 .39301 Mtetra
.88186 .39301 .88683 .40022 .8994 .39631 .89447 .38908 Mtetra
.89447 .38908 .8994 .39631 .91202 .39239 .90714 .38512 Mtetra
.90714 .38512 .91202 .39239 .9247 .38845 .91986 .38115 Mtetra
.664 .741 .908 r
.91986 .38115 .9247 .38845 .93744 .3845 .93263 .37717 Mtetra
.661 .743 .91 r
.34858 .55148 .35505 .55743 .36549 .55422 .35905 .54825 Mtetra
.661 .743 .911 r
.35905 .54825 .36549 .55422 .37597 .551 .36955 .54503 Mtetra
.36955 .54503 .37597 .551 .38649 .54778 .3801 .54179 Mtetra
.661 .744 .911 r
.3801 .54179 .38649 .54778 .39706 .54454 .39069 .53854 Mtetra
.661 .744 .912 r
.39069 .53854 .39706 .54454 .40767 .5413 .40133 .53528 Mtetra
.661 .745 .912 r
.40133 .53528 .40767 .5413 .41832 .53804 .412 .53201 Mtetra
.412 .53201 .41832 .53804 .42901 .53477 .42272 .52873 Mtetra
.661 .745 .913 r
.42272 .52873 .42901 .53477 .43974 .53148 .43349 .52543 Mtetra
.661 .746 .913 r
.43349 .52543 .43974 .53148 .45052 .52818 .44429 .52212 Mtetra
.44429 .52212 .45052 .52818 .46134 .52487 .45514 .5188 Mtetra
.66 .747 .914 r
.45514 .5188 .46134 .52487 .47221 .52155 .46603 .51548 Mtetra
.66 .747 .915 r
.46603 .51548 .47221 .52155 .48312 .51821 .47697 .51215 Mtetra
.659 .748 .916 r
.47697 .51215 .48312 .51821 .49407 .51487 .48795 .50884 Mtetra
.657 .75 .918 r
.48795 .50884 .49407 .51487 .50507 .51152 .49898 .50556 Mtetra
.655 .752 .921 r
.49898 .50556 .50507 .51152 .51611 .50818 .51005 .50231 Mtetra
.653 .755 .925 r
.51005 .50231 .51611 .50818 .5272 .50484 .52117 .49911 Mtetra
.651 .76 .93 r
.52117 .49911 .5272 .50484 .53833 .5015 .53234 .49593 Mtetra
.649 .766 .934 r
.53234 .49593 .53833 .5015 .54951 .49814 .54355 .49274 Mtetra
.65 .774 .939 r
.54355 .49274 .54951 .49814 .56074 .49476 .55481 .4895 Mtetra
.653 .781 .942 r
.55481 .4895 .56074 .49476 .57201 .49131 .56612 .48614 Mtetra
.658 .786 .943 r
.56612 .48614 .57201 .49131 .58333 .48779 .57747 .48263 Mtetra
.664 .789 .941 r
.57747 .48263 .58333 .48779 .59469 .48419 .58887 .47894 Mtetra
.67 .789 .937 r
.58887 .47894 .59469 .48419 .6061 .48051 .60031 .47509 Mtetra
.674 .784 .932 r
.60031 .47509 .6061 .48051 .61755 .47678 .61179 .47113 Mtetra
.676 .778 .927 r
.61179 .47113 .61755 .47678 .62904 .47301 .62331 .46712 Mtetra
.675 .77 .922 r
.62331 .46712 .62904 .47301 .64059 .46924 .63488 .46312 Mtetra
.674 .763 .918 r
.63488 .46312 .64059 .46924 .65218 .46547 .6465 .45917 Mtetra
.671 .757 .915 r
.6465 .45917 .65218 .46547 .66381 .46172 .65817 .45527 Mtetra
.669 .752 .913 r
.65817 .45527 .66381 .46172 .6755 .45798 .66989 .45142 Mtetra
.668 .749 .911 r
.66989 .45142 .6755 .45798 .68724 .45423 .68166 .4476 Mtetra
.667 .747 .911 r
.68166 .4476 .68724 .45423 .69902 .45049 .69347 .44379 Mtetra
.666 .746 .91 r
.69347 .44379 .69902 .45049 .71085 .44674 .70534 .44 Mtetra
.666 .745 .91 r
.70534 .44 .71085 .44674 .72274 .44298 .71726 .43619 Mtetra
.665 .745 .909 r
.71726 .43619 .72274 .44298 .73467 .43921 .72922 .43238 Mtetra
.665 .744 .909 r
.72922 .43238 .73467 .43921 .74665 .43543 .74124 .42856 Mtetra
.74124 .42856 .74665 .43543 .75868 .43164 .75331 .42473 Mtetra
.75331 .42473 .75868 .43164 .77077 .42783 .76543 .42089 Mtetra
.665 .743 .909 r
.76543 .42089 .77077 .42783 .7829 .42401 .7776 .41704 Mtetra
.7776 .41704 .7829 .42401 .79509 .42019 .78982 .41317 Mtetra
.665 .743 .908 r
.78982 .41317 .79509 .42019 .80733 .41634 .8021 .40929 Mtetra
.664 .743 .908 r
.8021 .40929 .80733 .41634 .81962 .41249 .81442 .4054 Mtetra
.664 .742 .908 r
.81442 .4054 .81962 .41249 .83196 .40862 .8268 .4015 Mtetra
.8268 .4015 .83196 .40862 .84435 .40474 .83924 .39758 Mtetra
.83924 .39758 .84435 .40474 .8568 .40085 .85172 .39366 Mtetra
.85172 .39366 .8568 .40085 .86931 .39694 .86426 .38971 Mtetra
.86426 .38971 .86931 .39694 .88186 .39301 .87686 .38576 Mtetra
.87686 .38576 .88186 .39301 .89447 .38908 .88951 .38179 Mtetra
.88951 .38179 .89447 .38908 .90714 .38512 .90221 .3778 Mtetra
.90221 .3778 .90714 .38512 .91986 .38115 .91497 .3738 Mtetra
.91497 .3738 .91986 .38115 .93263 .37717 .92779 .36978 Mtetra
.661 .743 .911 r
.34207 .54549 .34858 .55148 .35905 .54825 .35256 .54226 Mtetra
.35256 .54226 .35905 .54825 .36955 .54503 .36309 .53902 Mtetra
.661 .744 .912 r
.36309 .53902 .36955 .54503 .3801 .54179 .37367 .53577 Mtetra
.37367 .53577 .3801 .54179 .39069 .53854 .38428 .53251 Mtetra
.66 .745 .912 r
.38428 .53251 .39069 .53854 .40133 .53528 .39494 .52924 Mtetra
.66 .745 .913 r
.39494 .52924 .40133 .53528 .412 .53201 .40564 .52595 Mtetra
.40564 .52595 .412 .53201 .42272 .52873 .41639 .52266 Mtetra
.66 .746 .913 r
.41639 .52266 .42272 .52873 .43349 .52543 .42718 .51936 Mtetra
.66 .746 .914 r
.42718 .51936 .43349 .52543 .44429 .52212 .43801 .51604 Mtetra
.66 .747 .915 r
.43801 .51604 .44429 .52212 .45514 .5188 .44889 .51273 Mtetra
.659 .748 .916 r
.44889 .51273 .45514 .5188 .46603 .51548 .45981 .50943 Mtetra
.657 .749 .918 r
.45981 .50943 .46603 .51548 .47697 .51215 .47077 .50616 Mtetra
.654 .75 .921 r
.47077 .50616 .47697 .51215 .48795 .50884 .48178 .50295 Mtetra
.65 .753 .925 r
.48178 .50295 .48795 .50884 .49898 .50556 .49284 .49983 Mtetra
.644 .758 .932 r
.49284 .49983 .49898 .50556 .51005 .50231 .50394 .49683 Mtetra
.636 .766 .941 r
.50394 .49683 .51005 .50231 .52117 .49911 .51509 .49395 Mtetra
.629 .776 .952 r
.51509 .49395 .52117 .49911 .53234 .49593 .52629 .49116 Mtetra
.623 .79 .962 r
.52629 .49116 .53234 .49593 .54355 .49274 .53754 .48838 Mtetra
.621 .807 .971 r
.53754 .48838 .54355 .49274 .55481 .4895 .54884 .48549 Mtetra
.626 .823 .976 r
.54884 .48549 .55481 .4895 .56612 .48614 .56019 .48235 Mtetra
.639 .837 .976 r
.56019 .48235 .56612 .48614 .57747 .48263 .57158 .47887 Mtetra
.656 .844 .972 r
.57158 .47887 .57747 .48263 .58887 .47894 .58302 .47501 Mtetra
.673 .842 .964 r
.58302 .47501 .58887 .47894 .60031 .47509 .59449 .47081 Mtetra
.685 .832 .954 r
.59449 .47081 .60031 .47509 .61179 .47113 .606 .46639 Mtetra
.69 .816 .943 r
.606 .46639 .61179 .47113 .62331 .46712 .61756 .46189 Mtetra
.689 .799 .933 r
.61756 .46189 .62331 .46712 .63488 .46312 .62915 .45744 Mtetra
.684 .783 .925 r
.62915 .45744 .63488 .46312 .6465 .45917 .6408 .45312 Mtetra
.679 .769 .919 r
.6408 .45312 .6465 .45917 .65817 .45527 .65249 .44895 Mtetra
.674 .76 .915 r
.65249 .44895 .65817 .45527 .66989 .45142 .66424 .44491 Mtetra
.671 .754 .913 r
.66424 .44491 .66989 .45142 .68166 .4476 .67603 .44096 Mtetra
.668 .75 .911 r
.67603 .44096 .68166 .4476 .69347 .44379 .68788 .43708 Mtetra
.667 .748 .91 r
.68788 .43708 .69347 .44379 .70534 .44 .69978 .43322 Mtetra
.666 .746 .91 r
.69978 .43322 .70534 .44 .71726 .43619 .71173 .42937 Mtetra
.666 .745 .91 r
.71173 .42937 .71726 .43619 .72922 .43238 .72374 .42551 Mtetra
.666 .745 .909 r
.72374 .42551 .72922 .43238 .74124 .42856 .73579 .42165 Mtetra
.665 .744 .909 r
.73579 .42165 .74124 .42856 .75331 .42473 .74789 .41778 Mtetra
.74789 .41778 .75331 .42473 .76543 .42089 .76005 .4139 Mtetra
.76005 .4139 .76543 .42089 .7776 .41704 .77225 .41001 Mtetra
.665 .743 .909 r
.77225 .41001 .7776 .41704 .78982 .41317 .78451 .40611 Mtetra
.78451 .40611 .78982 .41317 .8021 .40929 .79682 .40219 Mtetra
.665 .743 .908 r
.79682 .40219 .8021 .40929 .81442 .4054 .80919 .39826 Mtetra
.664 .743 .908 r
.80919 .39826 .81442 .4054 .8268 .4015 .8216 .39433 Mtetra
.664 .742 .908 r
.8216 .39433 .8268 .4015 .83924 .39758 .83408 .39037 Mtetra
.83408 .39037 .83924 .39758 .85172 .39366 .8466 .38641 Mtetra
.8466 .38641 .85172 .39366 .86426 .38971 .85918 .38243 Mtetra
.85918 .38243 .86426 .38971 .87686 .38576 .87181 .37844 Mtetra
.87181 .37844 .87686 .38576 .88951 .38179 .8845 .37444 Mtetra
.8845 .37444 .88951 .38179 .90221 .3778 .89725 .37042 Mtetra
.89725 .37042 .90221 .3778 .91497 .3738 .91005 .36638 Mtetra
.91005 .36638 .91497 .3738 .92779 .36978 .9229 .36233 Mtetra
.661 .743 .911 r
.33551 .53947 .34207 .54549 .35256 .54226 .34602 .53623 Mtetra
.66 .744 .912 r
.34602 .53623 .35256 .54226 .36309 .53902 .35658 .53297 Mtetra
.35658 .53297 .36309 .53902 .37367 .53577 .36718 .52971 Mtetra
.66 .744 .913 r
.36718 .52971 .37367 .53577 .38428 .53251 .37782 .52644 Mtetra
.66 .745 .913 r
.37782 .52644 .38428 .53251 .39494 .52924 .38851 .52316 Mtetra
.38851 .52316 .39494 .52924 .40564 .52595 .39924 .51987 Mtetra
.66 .746 .914 r
.39924 .51987 .40564 .52595 .41639 .52266 .41001 .51657 Mtetra
.659 .746 .914 r
.41001 .51657 .41639 .52266 .42718 .51936 .42082 .51327 Mtetra
.659 .747 .915 r
.42082 .51327 .42718 .51936 .43801 .51604 .43168 .50996 Mtetra
.658 .748 .916 r
.43168 .50996 .43801 .51604 .44889 .51273 .44259 .50667 Mtetra
.655 .749 .919 r
.44259 .50667 .44889 .51273 .45981 .50943 .45354 .50344 Mtetra
.651 .75 .923 r
.45354 .50344 .45981 .50943 .47077 .50616 .46453 .5003 Mtetra
.643 .754 .929 r
.46453 .5003 .47077 .50616 .48178 .50295 .47556 .49733 Mtetra
.632 .759 .939 r
.47556 .49733 .48178 .50295 .49284 .49983 .48664 .49458 Mtetra
.615 .769 .954 r
.48664 .49458 .49284 .49983 .50394 .49683 .49777 .49212 Mtetra
.591 .783 .971 r
.49777 .49212 .50394 .49683 .51509 .49395 .50895 .48994 Mtetra
.561 .801 .989 r
.50895 .48994 .51509 .49395 .52629 .49116 .52019 .48796 Mtetra
.527 .823 .999 r
.52019 .48796 .52629 .49116 .53754 .48838 .53148 .486 Mtetra
.5 .844 .996 r
.53148 .486 .53754 .48838 .54884 .48549 .54283 .48382 Mtetra
.496 .866 .983 r
.54283 .48382 .54884 .48549 .56019 .48235 .55423 .48112 Mtetra
.525 .892 .972 r
.55423 .48112 .56019 .48235 .57158 .47887 .56567 .47771 Mtetra
.583 .916 .971 r
.56567 .47771 .57158 .47887 .58302 .47501 .57715 .47351 Mtetra
.645 .927 .974 r
.57715 .47351 .58302 .47501 .59449 .47081 .58867 .46862 Mtetra
.691 .916 .971 r
.58867 .46862 .59449 .47081 .606 .46639 .60021 .46331 Mtetra
.712 .887 .961 r
.60021 .46331 .606 .46639 .61756 .46189 .61178 .45786 Mtetra
.714 .852 .948 r
.61178 .45786 .61756 .46189 .62915 .45744 .6234 .45256 Mtetra
.705 .818 .935 r
.6234 .45256 .62915 .45744 .6408 .45312 .63506 .44755 Mtetra
.694 .792 .925 r
.63506 .44755 .6408 .45312 .65249 .44895 .64678 .44288 Mtetra
.684 .773 .919 r
.64678 .44288 .65249 .44895 .66424 .44491 .65855 .43852 Mtetra
.676 .761 .915 r
.65855 .43852 .66424 .44491 .67603 .44096 .67037 .43437 Mtetra
.672 .754 .912 r
.67037 .43437 .67603 .44096 .68788 .43708 .68225 .43036 Mtetra
.669 .75 .911 r
.68225 .43036 .68788 .43708 .69978 .43322 .69419 .42642 Mtetra
.667 .747 .91 r
.69419 .42642 .69978 .43322 .71173 .42937 .70617 .42251 Mtetra
.667 .746 .91 r
.70617 .42251 .71173 .42937 .72374 .42551 .71821 .41861 Mtetra
.666 .746 .91 r
.71821 .41861 .72374 .42551 .73579 .42165 .73029 .4147 Mtetra
.666 .745 .909 r
.73029 .4147 .73579 .42165 .74789 .41778 .74243 .41079 Mtetra
.74243 .41079 .74789 .41778 .76005 .4139 .75462 .40687 Mtetra
.665 .744 .909 r
.75462 .40687 .76005 .4139 .77225 .41001 .76687 .40294 Mtetra
.76687 .40294 .77225 .41001 .78451 .40611 .77916 .399 Mtetra
.77916 .399 .78451 .40611 .79682 .40219 .79151 .39504 Mtetra
.665 .743 .909 r
.79151 .39504 .79682 .40219 .80919 .39826 .80391 .39108 Mtetra
.665 .743 .908 r
.80391 .39108 .80919 .39826 .8216 .39433 .81637 .3871 Mtetra
.81637 .3871 .8216 .39433 .83408 .39037 .82888 .38311 Mtetra
.664 .742 .908 r
.82888 .38311 .83408 .39037 .8466 .38641 .84144 .37911 Mtetra
.84144 .37911 .8466 .38641 .85918 .38243 .85406 .3751 Mtetra
.85406 .3751 .85918 .38243 .87181 .37844 .86673 .37107 Mtetra
.86673 .37107 .87181 .37844 .8845 .37444 .87946 .36703 Mtetra
.87946 .36703 .8845 .37444 .89725 .37042 .89224 .36298 Mtetra
.89224 .36298 .89725 .37042 .91005 .36638 .90508 .35891 Mtetra
.90508 .35891 .91005 .36638 .9229 .36233 .91798 .35482 Mtetra
.66 .744 .912 r
.32889 .53342 .33551 .53947 .34602 .53623 .33944 .53016 Mtetra
.33944 .53016 .34602 .53623 .35658 .53297 .35002 .5269 Mtetra
.66 .744 .913 r
.35002 .5269 .35658 .53297 .36718 .52971 .36064 .52363 Mtetra
.659 .745 .913 r
.36064 .52363 .36718 .52971 .37782 .52644 .37131 .52035 Mtetra
.659 .745 .914 r
.37131 .52035 .37782 .52644 .38851 .52316 .38202 .51706 Mtetra
.659 .746 .914 r
.38202 .51706 .38851 .52316 .39924 .51987 .39278 .51377 Mtetra
.659 .746 .915 r
.39278 .51377 .39924 .51987 .41001 .51657 .40358 .51047 Mtetra
.658 .747 .915 r
.40358 .51047 .41001 .51657 .42082 .51327 .41442 .50717 Mtetra
.657 .748 .917 r
.41442 .50717 .42082 .51327 .43168 .50996 .42531 .50389 Mtetra
.654 .748 .919 r
.42531 .50389 .43168 .50996 .44259 .50667 .43624 .50067 Mtetra
.649 .75 .923 r
.43624 .50067 .44259 .50667 .45354 .50344 .44721 .49758 Mtetra
.638 .753 .931 r
.44721 .49758 .45354 .50344 .46453 .5003 .45823 .49471 Mtetra
.62 .758 .944 r
.45823 .49471 .46453 .5003 .47556 .49733 .46928 .49221 Mtetra
.589 .766 .963 r
.46928 .49221 .47556 .49733 .48664 .49458 .48039 .4902 Mtetra
.537 .777 .987 r
.48039 .4902 .48664 .49458 .49777 .49212 .49154 .48877 Mtetra
.445 .782 .998 r
.49154 .48877 .49777 .49212 .50895 .48994 .50275 .4879 Mtetra
.299 .754 .954 r
.50275 .4879 .50895 .48994 .52019 .48796 .51402 .48743 Mtetra
.122 .669 .812 r
.51402 .48743 .52019 .48796 .53148 .486 .52536 .48699 Mtetra
.002 0 0 r
.52536 .48699 .53148 .486 .54283 .48382 .53677 .48607 Mtetra
.026 0 0 r
.53677 .48607 .54283 .48382 .55423 .48112 .54823 .48414 Mtetra
0 0 0 r
.54823 .48414 .55423 .48112 .56567 .47771 .55974 .4808 Mtetra
.55974 .4808 .56567 .47771 .57715 .47351 .57128 .47594 Mtetra
.414 .846 .712 r
.57128 .47594 .57715 .47351 .58867 .46862 .58284 .4698 Mtetra
.61 .955 .853 r
.58284 .4698 .58867 .46862 .60021 .46331 .59441 .46287 Mtetra
.72 .972 .929 r
.59441 .46287 .60021 .46331 .61178 .45786 .606 .45575 Mtetra
.75 .93 .948 r
.606 .45575 .61178 .45786 .6234 .45256 .61763 .44894 Mtetra
.741 .875 .942 r
.61763 .44894 .6234 .45256 .63506 .44755 .6293 .44275 Mtetra
.72 .827 .931 r
.6293 .44275 .63506 .44755 .64678 .44288 .64103 .43724 Mtetra
.701 .794 .923 r
.64103 .43724 .64678 .44288 .65855 .43852 .65282 .43233 Mtetra
.686 .772 .917 r
.65282 .43233 .65855 .43852 .67037 .43437 .66467 .42785 Mtetra
.677 .759 .913 r
.66467 .42785 .67037 .43437 .68225 .43036 .67658 .42365 Mtetra
.671 .753 .912 r
.67658 .42365 .68225 .43036 .69419 .42642 .68854 .4196 Mtetra
.669 .749 .911 r
.68854 .4196 .69419 .42642 .70617 .42251 .70056 .41562 Mtetra
.667 .747 .91 r
.70056 .41562 .70617 .42251 .71821 .41861 .71263 .41167 Mtetra
.667 .746 .91 r
.71263 .41167 .71821 .41861 .73029 .4147 .72476 .40772 Mtetra
.666 .746 .91 r
.72476 .40772 .73029 .4147 .74243 .41079 .73693 .40376 Mtetra
.666 .745 .91 r
.73693 .40376 .74243 .41079 .75462 .40687 .74916 .3998 Mtetra
.666 .745 .909 r
.74916 .3998 .75462 .40687 .76687 .40294 .76144 .39583 Mtetra
.665 .745 .909 r
.76144 .39583 .76687 .40294 .77916 .399 .77377 .39185 Mtetra
.665 .744 .909 r
.77377 .39185 .77916 .399 .79151 .39504 .78616 .38785 Mtetra
.78616 .38785 .79151 .39504 .80391 .39108 .79859 .38385 Mtetra
.79859 .38385 .80391 .39108 .81637 .3871 .81109 .37983 Mtetra
.665 .743 .909 r
.81109 .37983 .81637 .3871 .82888 .38311 .82363 .3758 Mtetra
.665 .743 .908 r
.82363 .3758 .82888 .38311 .84144 .37911 .83624 .37176 Mtetra
.664 .743 .908 r
.83624 .37176 .84144 .37911 .85406 .3751 .84889 .36771 Mtetra
.664 .742 .908 r
.84889 .36771 .85406 .3751 .86673 .37107 .86161 .36365 Mtetra
.86161 .36365 .86673 .37107 .87946 .36703 .87437 .35957 Mtetra
.87437 .35957 .87946 .36703 .89224 .36298 .8872 .35548 Mtetra
.8872 .35548 .89224 .36298 .90508 .35891 .90008 .35137 Mtetra
.90008 .35137 .90508 .35891 .91798 .35482 .91302 .34725 Mtetra
.66 .744 .912 r
.32223 .52733 .32889 .53342 .33944 .53016 .3328 .52406 Mtetra
.659 .744 .913 r
.3328 .52406 .33944 .53016 .35002 .5269 .34341 .52079 Mtetra
.659 .745 .913 r
.34341 .52079 .35002 .5269 .36064 .52363 .35406 .51752 Mtetra
.659 .745 .914 r
.35406 .51752 .36064 .52363 .37131 .52035 .36475 .51423 Mtetra
.659 .746 .914 r
.36475 .51423 .37131 .52035 .38202 .51706 .37549 .51094 Mtetra
.658 .746 .915 r
.37549 .51094 .38202 .51706 .39278 .51377 .38627 .50764 Mtetra
.658 .747 .916 r
.38627 .50764 .39278 .51377 .40358 .51047 .3971 .50434 Mtetra
.657 .747 .917 r
.3971 .50434 .40358 .51047 .41442 .50717 .40797 .50106 Mtetra
.654 .748 .919 r
.40797 .50106 .41442 .50717 .42531 .50389 .41888 .49784 Mtetra
.648 .749 .923 r
.41888 .49784 .42531 .50389 .43624 .50067 .42983 .49475 Mtetra
.636 .751 .931 r
.42983 .49475 .43624 .50067 .44721 .49758 .44083 .49193 Mtetra
.614 .754 .945 r
.44083 .49193 .44721 .49758 .45823 .49471 .45186 .48956 Mtetra
.57 .759 .967 r
.45186 .48956 .45823 .49471 .46928 .49221 .46293 .4879 Mtetra
.482 .759 .992 r
.46293 .4879 .46928 .49221 .48039 .4902 .47405 .48717 Mtetra
.296 .719 .972 r
.47405 .48717 .48039 .4902 .49154 .48877 .48522 .48752 Mtetra
0 .544 .765 r
.48522 .48752 .49154 .48877 .50275 .4879 .49645 .4889 Mtetra
.325 0 0 r
.49645 .4889 .50275 .4879 .51402 .48743 .50776 .49095 Mtetra
.445 0 0 r
.50776 .49095 .51402 .48743 .52536 .48699 .51916 .49299 Mtetra
.458 0 .031 r
.51916 .49299 .52536 .48699 .53677 .48607 .53064 .49409 Mtetra
.413 0 .084 r
.53064 .49409 .53677 .48607 .54823 .48414 .54219 .49331 Mtetra
.325 0 .072 r
.54219 .49331 .54823 .48414 .55974 .4808 .55379 .48997 Mtetra
.183 0 0 r
.55379 .48997 .55974 .4808 .57128 .47594 .5654 .48394 Mtetra
0 0 0 r
.5654 .48394 .57128 .47594 .58284 .4698 .57701 .47568 Mtetra
.57701 .47568 .58284 .4698 .59441 .46287 .58862 .4661 Mtetra
.628 .938 .71 r
.58862 .4661 .59441 .46287 .606 .45575 .60022 .45627 Mtetra
.773 .994 .876 r
.60022 .45627 .606 .45575 .61763 .44894 .61185 .44707 Mtetra
.789 .942 .926 r
.61185 .44707 .61763 .44894 .6293 .44275 .62352 .43899 Mtetra
.76 .874 .93 r
.62352 .43899 .6293 .44275 .64103 .43724 .63526 .43217 Mtetra
.726 .822 .924 r
.63526 .43217 .64103 .43724 .65282 .43233 .64706 .42641 Mtetra
.701 .787 .918 r
.64706 .42641 .65282 .43233 .66467 .42785 .65893 .42145 Mtetra
.684 .767 .914 r
.65893 .42145 .66467 .42785 .67658 .42365 .67086 .41698 Mtetra
.675 .757 .912 r
.67086 .41698 .67658 .42365 .68854 .4196 .68286 .41278 Mtetra
.67 .751 .911 r
.68286 .41278 .68854 .4196 .70056 .41562 .69491 .40871 Mtetra
.668 .749 .911 r
.69491 .40871 .70056 .41562 .71263 .41167 .70702 .4047 Mtetra
.667 .748 .911 r
.70702 .4047 .71263 .41167 .72476 .40772 .71918 .40071 Mtetra
.666 .747 .91 r
.71918 .40071 .72476 .40772 .73693 .40376 .73139 .39672 Mtetra
.73139 .39672 .73693 .40376 .74916 .3998 .74365 .39271 Mtetra
.666 .746 .91 r
.74365 .39271 .74916 .3998 .76144 .39583 .75597 .3887 Mtetra
.75597 .3887 .76144 .39583 .77377 .39185 .76834 .38468 Mtetra
.666 .745 .91 r
.76834 .38468 .77377 .39185 .78616 .38785 .78076 .38064 Mtetra
.78076 .38064 .78616 .38785 .79859 .38385 .79324 .37659 Mtetra
.665 .745 .909 r
.79324 .37659 .79859 .38385 .81109 .37983 .80577 .37253 Mtetra
.665 .744 .909 r
.80577 .37253 .81109 .37983 .82363 .3758 .81835 .36845 Mtetra
.81835 .36845 .82363 .3758 .83624 .37176 .83099 .36437 Mtetra
.665 .743 .909 r
.83099 .36437 .83624 .37176 .84889 .36771 .84369 .36028 Mtetra
.665 .743 .908 r
.84369 .36028 .84889 .36771 .86161 .36365 .85644 .35617 Mtetra
.664 .742 .908 r
.85644 .35617 .86161 .36365 .87437 .35957 .86925 .35205 Mtetra
.86925 .35205 .87437 .35957 .8872 .35548 .88211 .34792 Mtetra
.88211 .34792 .8872 .35548 .90008 .35137 .89504 .34378 Mtetra
.89504 .34378 .90008 .35137 .91302 .34725 .90802 .33962 Mtetra
.659 .744 .913 r
.31552 .5212 .32223 .52733 .3328 .52406 .32611 .51793 Mtetra
.32611 .51793 .3328 .52406 .34341 .52079 .33675 .51465 Mtetra
.658 .745 .914 r
.33675 .51465 .34341 .52079 .35406 .51752 .34742 .51137 Mtetra
.34742 .51137 .35406 .51752 .36475 .51423 .35814 .50808 Mtetra
.658 .746 .915 r
.35814 .50808 .36475 .51423 .37549 .51094 .36891 .50479 Mtetra
.657 .747 .916 r
.36891 .50479 .37549 .51094 .38627 .50764 .37971 .50149 Mtetra
.656 .747 .917 r
.37971 .50149 .38627 .50764 .3971 .50434 .39057 .4982 Mtetra
.654 .748 .919 r
.39057 .4982 .3971 .50434 .40797 .50106 .40146 .49496 Mtetra
.649 .748 .922 r
.40146 .49496 .40797 .50106 .41888 .49784 .4124 .49183 Mtetra
.638 .749 .929 r
.4124 .49183 .41888 .49784 .42983 .49475 .42337 .48896 Mtetra
.615 .751 .942 r
.42337 .48896 .42983 .49475 .44083 .49193 .43438 .48658 Mtetra
.567 .752 .964 r
.43438 .48658 .44083 .49193 .45186 .48956 .44543 .48502 Mtetra
.458 .741 .989 r
.44543 .48502 .45186 .48956 .46293 .4879 .45651 .48469 Mtetra
.199 .656 .943 r
.45651 .48469 .46293 .4879 .47405 .48717 .46762 .48598 Mtetra
.253 0 0 r
.46762 .48598 .47405 .48717 .48522 .48752 .47879 .4891 Mtetra
.544 0 0 r
.47879 .4891 .48522 .48752 .49645 .4889 .49004 .49391 Mtetra
.62 .15 .115 r
.49004 .49391 .49645 .4889 .50776 .49095 .50138 .49976 Mtetra
.617 .203 .234 r
.50138 .49976 .50776 .49095 .51916 .49299 .51283 .50545 Mtetra
.581 .201 .287 r
.51283 .50545 .51916 .49299 .53064 .49409 .5244 .50943 Mtetra
.521 .164 .301 r
.5244 .50943 .53064 .49409 .54219 .49331 .53606 .51017 Mtetra
.434 .092 .283 r
.53606 .51017 .54219 .49331 .55379 .48997 .54777 .50663 Mtetra
.309 0 .228 r
.54777 .50663 .55379 .48997 .5654 .48394 .55949 .49866 Mtetra
.126 0 .114 r
.55949 .49866 .5654 .48394 .57701 .47568 .57117 .48714 Mtetra
0 0 0 r
.57117 .48714 .57701 .47568 .58862 .4661 .58282 .47361 Mtetra
.58282 .47361 .58862 .4661 .60022 .45627 .59444 .45981 Mtetra
.755 .974 .707 r
.59444 .45981 .60022 .45627 .61185 .44707 .60606 .44715 Mtetra
.836 .988 .865 r
.60606 .44715 .61185 .44707 .62352 .43899 .61772 .43641 Mtetra
.809 .92 .912 r
.61772 .43641 .62352 .43899 .63526 .43217 .62945 .42774 Mtetra
.76 .852 .919 r
.62945 .42774 .63526 .43217 .64706 .42641 .64126 .42082 Mtetra
.721 .805 .917 r
.64126 .42082 .64706 .42641 .65893 .42145 .65315 .41518 Mtetra
.695 .777 .914 r
.65315 .41518 .65893 .42145 .67086 .41698 .66511 .41035 Mtetra
.68 .761 .913 r
.66511 .41035 .67086 .41698 .68286 .41278 .67713 .40597 Mtetra
.672 .754 .912 r
.67713 .40597 .68286 .41278 .69491 .40871 .68922 .40181 Mtetra
.669 .751 .912 r
.68922 .40181 .69491 .40871 .70702 .4047 .70136 .39774 Mtetra
.667 .749 .912 r
.70136 .39774 .70702 .4047 .71918 .40071 .71356 .3937 Mtetra
.71356 .3937 .71918 .40071 .73139 .39672 .72581 .38967 Mtetra
.666 .749 .912 r
.72581 .38967 .73139 .39672 .74365 .39271 .73811 .38564 Mtetra
.666 .748 .912 r
.73811 .38564 .74365 .39271 .75597 .3887 .75046 .38158 Mtetra
.666 .748 .911 r
.75046 .38158 .75597 .3887 .76834 .38468 .76287 .37752 Mtetra
.76287 .37752 .76834 .38468 .78076 .38064 .77533 .37343 Mtetra
.666 .747 .911 r
.77533 .37343 .78076 .38064 .79324 .37659 .78784 .36933 Mtetra
.666 .747 .91 r
.78784 .36933 .79324 .37659 .80577 .37253 .80041 .36521 Mtetra
.666 .746 .91 r
.80041 .36521 .80577 .37253 .81835 .36845 .81303 .36108 Mtetra
.666 .745 .909 r
.81303 .36108 .81835 .36845 .83099 .36437 .82571 .35695 Mtetra
.665 .744 .909 r
.82571 .35695 .83099 .36437 .84369 .36028 .83844 .3528 Mtetra
.83844 .3528 .84369 .36028 .85644 .35617 .85123 .34865 Mtetra
.665 .743 .908 r
.85123 .34865 .85644 .35617 .86925 .35205 .86408 .34448 Mtetra
.664 .743 .908 r
.86408 .34448 .86925 .35205 .88211 .34792 .87699 .34031 Mtetra
.664 .742 .908 r
.87699 .34031 .88211 .34792 .89504 .34378 .88995 .33613 Mtetra
.88995 .33613 .89504 .34378 .90802 .33962 .90297 .33193 Mtetra
.658 .744 .913 r
.30876 .51504 .31552 .5212 .32611 .51793 .31938 .51176 Mtetra
.658 .745 .914 r
.31938 .51176 .32611 .51793 .33675 .51465 .33004 .50848 Mtetra
.33004 .50848 .33675 .51465 .34742 .51137 .34074 .50519 Mtetra
.657 .746 .915 r
.34074 .50519 .34742 .51137 .35814 .50808 .35148 .5019 Mtetra
.657 .746 .916 r
.35148 .5019 .35814 .50808 .36891 .50479 .36227 .4986 Mtetra
.656 .747 .917 r
.36227 .4986 .36891 .50479 .37971 .50149 .37311 .49531 Mtetra
.655 .747 .918 r
.37311 .49531 .37971 .50149 .39057 .4982 .38398 .49205 Mtetra
.651 .748 .921 r
.38398 .49205 .39057 .4982 .40146 .49496 .3949 .48886 Mtetra
.642 .748 .926 r
.3949 .48886 .40146 .49496 .4124 .49183 .40586 .48588 Mtetra
.623 .748 .937 r
.40586 .48588 .4124 .49183 .42337 .48896 .41686 .48333 Mtetra
.58 .747 .956 r
.41686 .48333 .42337 .48896 .43438 .48658 .42788 .48159 Mtetra
.48 .733 .982 r
.42788 .48159 .43438 .48658 .44543 .48502 .43892 .48119 Mtetra
.22 .647 .955 r
.43892 .48119 .44543 .48502 .45651 .48469 .44998 .48276 Mtetra
.296 0 0 r
.44998 .48276 .45651 .48469 .46762 .48598 .46108 .48689 Mtetra
.629 .087 0 r
.46108 .48689 .46762 .48598 .47879 .4891 .47223 .49386 Mtetra
.704 .254 .181 r
.47223 .49386 .47879 .4891 .49004 .49391 .48347 .50337 Mtetra
.701 .309 .301 r
.48347 .50337 .49004 .49391 .50138 .49976 .49483 .51432 Mtetra
.672 .314 .358 r
.49483 .51432 .50138 .49976 .51283 .50545 .50635 .52481 Mtetra
.625 .289 .382 r
.50635 .52481 .51283 .50545 .5244 .50943 .51802 .53243 Mtetra
.558 .239 .384 r
.51802 .53243 .5244 .50943 .53606 .51017 .52981 .53488 Mtetra
.466 .16 .363 r
.52981 .53488 .53606 .51017 .54777 .50663 .54166 .5307 Mtetra
.335 .042 .311 r
.54166 .5307 .54777 .50663 .55949 .49866 .5535 .51987 Mtetra
.146 0 .211 r
.5535 .51987 .55949 .49866 .57117 .48714 .56528 .50382 Mtetra
0 0 .033 r
.56528 .50382 .57117 .48714 .58282 .47361 .57698 .485 Mtetra
0 0 0 r
.57698 .485 .58282 .47361 .59444 .45981 .58862 .46602 Mtetra
.759 .924 .562 r
.58862 .46602 .59444 .45981 .60606 .44715 .60024 .44894 Mtetra
.877 .993 .78 r
.60024 .44894 .60606 .44715 .61772 .43641 .61189 .43483 Mtetra
.858 .946 .874 r
.61189 .43483 .61772 .43641 .62945 .42774 .62361 .42384 Mtetra
.797 .875 .904 r
.62361 .42384 .62945 .42774 .64126 .42082 .63542 .41549 Mtetra
.743 .82 .912 r
.63542 .41549 .64126 .42082 .65315 .41518 .64733 .40903 Mtetra
.707 .786 .913 r
.64733 .40903 .65315 .41518 .66511 .41035 .65931 .40378 Mtetra
.685 .767 .913 r
.65931 .40378 .66511 .41035 .67713 .40597 .67137 .39919 Mtetra
.674 .757 .913 r
.67137 .39919 .67713 .40597 .68922 .40181 .68349 .39493 Mtetra
.669 .754 .914 r
.68349 .39493 .68922 .40181 .70136 .39774 .69566 .39081 Mtetra
.667 .752 .914 r
.69566 .39081 .70136 .39774 .71356 .3937 .7079 .38675 Mtetra
.666 .752 .914 r
.7079 .38675 .71356 .3937 .72581 .38967 .72018 .38269 Mtetra
.666 .752 .915 r
.72018 .38269 .72581 .38967 .73811 .38564 .73252 .37863 Mtetra
.73252 .37863 .73811 .38564 .75046 .38158 .74492 .37454 Mtetra
.667 .752 .914 r
.74492 .37454 .75046 .38158 .76287 .37752 .75736 .37042 Mtetra
.75736 .37042 .76287 .37752 .77533 .37343 .76986 .36628 Mtetra
.667 .751 .913 r
.76986 .36628 .77533 .37343 .78784 .36933 .78241 .36211 Mtetra
.667 .75 .912 r
.78241 .36211 .78784 .36933 .80041 .36521 .79501 .35793 Mtetra
.667 .749 .912 r
.79501 .35793 .80041 .36521 .81303 .36108 .80767 .35373 Mtetra
.667 .748 .911 r
.80767 .35373 .81303 .36108 .82571 .35695 .82039 .34952 Mtetra
.666 .746 .91 r
.82039 .34952 .82571 .35695 .83844 .3528 .83316 .3453 Mtetra
.666 .745 .909 r
.83316 .3453 .83844 .3528 .85123 .34865 .84599 .34109 Mtetra
.665 .744 .909 r
.84599 .34109 .85123 .34865 .86408 .34448 .85888 .33687 Mtetra
.665 .743 .909 r
.85888 .33687 .86408 .34448 .87699 .34031 .87182 .33265 Mtetra
.665 .743 .908 r
.87182 .33265 .87699 .34031 .88995 .33613 .88483 .32842 Mtetra
.664 .742 .908 r
.88483 .32842 .88995 .33613 .90297 .33193 .89789 .32418 Mtetra
.658 .744 .914 r
.30195 .50885 .30876 .51504 .31938 .51176 .31259 .50556 Mtetra
.657 .745 .914 r
.31259 .50556 .31938 .51176 .33004 .50848 .32327 .50227 Mtetra
.657 .745 .915 r
.32327 .50227 .33004 .50848 .34074 .50519 .334 .49898 Mtetra
.656 .746 .916 r
.334 .49898 .34074 .50519 .35148 .5019 .34477 .49569 Mtetra
.656 .746 .917 r
.34477 .49569 .35148 .5019 .36227 .4986 .35559 .49239 Mtetra
.655 .747 .918 r
.35559 .49239 .36227 .4986 .37311 .49531 .36645 .48911 Mtetra
.653 .748 .919 r
.36645 .48911 .37311 .49531 .38398 .49205 .37735 .48587 Mtetra
.647 .748 .923 r
.37735 .48587 .38398 .49205 .3949 .48886 .38829 .48277 Mtetra
.633 .747 .93 r
.38829 .48277 .3949 .48886 .40586 .48588 .39927 .47998 Mtetra
.602 .745 .945 r
.39927 .47998 .40586 .48588 .41686 .48333 .41028 .47785 Mtetra
.529 .735 .969 r
.41028 .47785 .41686 .48333 .42788 .48159 .4213 .47692 Mtetra
.335 .679 .978 r
.4213 .47692 .42788 .48159 .43892 .48119 .43233 .47799 Mtetra
0 .406 .759 r
.43233 .47799 .43892 .48119 .44998 .48276 .44337 .48196 Mtetra
.624 .061 0 r
.44337 .48196 .44998 .48276 .46108 .48689 .45442 .48963 Mtetra
.75 .289 .156 r
.45442 .48963 .46108 .48689 .47223 .49386 .46553 .50134 Mtetra
.76 .365 .305 r
.46553 .50134 .47223 .49386 .48347 .50337 .47674 .51655 Mtetra
.739 .381 .375 r
.47674 .51655 .48347 .50337 .49483 .51432 .48811 .53358 Mtetra
.702 .368 .408 r
.48811 .53358 .49483 .51432 .50635 .52481 .49968 .54962 Mtetra
.649 .331 .421 r
.49968 .54962 .50635 .52481 .51802 .53243 .51145 .56122 Mtetra
.574 .27 .416 r
.51145 .56122 .51802 .53243 .52981 .53488 .52339 .56521 Mtetra
.466 .176 .389 r
.52339 .56521 .52981 .53488 .54166 .5307 .5354 .55977 Mtetra
.306 .035 .328 r
.5354 .55977 .54166 .5307 .5535 .51987 .54739 .54511 Mtetra
.071 0 .212 r
.54739 .54511 .5535 .51987 .56528 .50382 .55929 .52349 Mtetra
0 0 .013 r
.55929 .52349 .56528 .50382 .57698 .485 .57105 .49841 Mtetra
0 0 0 r
.57105 .49841 .57698 .485 .58862 .46602 .58272 .4735 Mtetra
.839 .922 .532 r
.58272 .4735 .58862 .46602 .60024 .44894 .59435 .45146 Mtetra
.924 .975 .724 r
.59435 .45146 .60024 .44894 .61189 .43483 .606 .43364 Mtetra
.897 .942 .831 r
.606 .43364 .61189 .43483 .62361 .42384 .61772 .42014 Mtetra
.83 .882 .881 r
.61772 .42014 .62361 .42384 .63542 .41549 .62954 .41025 Mtetra
.765 .829 .902 r
.62954 .41025 .63542 .41549 .64733 .40903 .64146 .40294 Mtetra
.719 .792 .91 r
.64146 .40294 .64733 .40903 .65931 .40378 .65347 .39725 Mtetra
.691 .771 .913 r
.65347 .39725 .65931 .40378 .67137 .39919 .66556 .39246 Mtetra
.676 .761 .915 r
.66556 .39246 .67137 .39919 .68349 .39493 .67771 .38813 Mtetra
.669 .758 .917 r
.67771 .38813 .68349 .39493 .69566 .39081 .68993 .38399 Mtetra
.666 .757 .918 r
.68993 .38399 .69566 .39081 .7079 .38675 .7022 .37993 Mtetra
.665 .758 .919 r
.7022 .37993 .7079 .38675 .72018 .38269 .71453 .37587 Mtetra
.665 .759 .92 r
.71453 .37587 .72018 .38269 .73252 .37863 .72691 .37179 Mtetra
.666 .76 .92 r
.72691 .37179 .73252 .37863 .74492 .37454 .73934 .36767 Mtetra
.667 .76 .92 r
.73934 .36767 .74492 .37454 .75736 .37042 .75183 .36351 Mtetra
.668 .76 .919 r
.75183 .36351 .75736 .37042 .76986 .36628 .76436 .35929 Mtetra
.669 .759 .918 r
.76436 .35929 .76986 .36628 .78241 .36211 .77695 .35503 Mtetra
.669 .757 .916 r
.77695 .35503 .78241 .36211 .79501 .35793 .78959 .35075 Mtetra
.669 .755 .915 r
.78959 .35075 .79501 .35793 .80767 .35373 .80228 .34644 Mtetra
.669 .753 .913 r
.80228 .34644 .80767 .35373 .82039 .34952 .81503 .34213 Mtetra
.668 .75 .912 r
.81503 .34213 .82039 .34952 .83316 .3453 .82784 .33782 Mtetra
.667 .748 .911 r
.82784 .33782 .83316 .3453 .84599 .34109 .84071 .33352 Mtetra
.667 .746 .91 r
.84071 .33352 .84599 .34109 .85888 .33687 .85363 .32923 Mtetra
.666 .745 .909 r
.85363 .32923 .85888 .33687 .87182 .33265 .86661 .32494 Mtetra
.665 .744 .909 r
.86661 .32494 .87182 .33265 .88483 .32842 .87966 .32066 Mtetra
.665 .743 .908 r
.87966 .32066 .88483 .32842 .89789 .32418 .89276 .31638 Mtetra
.657 .744 .914 r
.29509 .50261 .30195 .50885 .31259 .50556 .30575 .49932 Mtetra
.656 .745 .915 r
.30575 .49932 .31259 .50556 .32327 .50227 .31646 .49603 Mtetra
.656 .745 .916 r
.31646 .49603 .32327 .50227 .334 .49898 .32721 .49273 Mtetra
.655 .746 .916 r
.32721 .49273 .334 .49898 .34477 .49569 .33801 .48944 Mtetra
.655 .747 .917 r
.33801 .48944 .34477 .49569 .35559 .49239 .34885 .48615 Mtetra
.653 .747 .919 r
.34885 .48615 .35559 .49239 .36645 .48911 .35973 .48288 Mtetra
.65 .747 .921 r
.35973 .48288 .36645 .48911 .37735 .48587 .37066 .47967 Mtetra
.642 .747 .925 r
.37066 .47967 .37735 .48587 .38829 .48277 .38163 .47666 Mtetra
.623 .745 .934 r
.38163 .47666 .38829 .48277 .39927 .47998 .39263 .47409 Mtetra
.577 .739 .952 r
.39263 .47409 .39927 .47998 .41028 .47785 .40364 .47242 Mtetra
.462 .711 .976 r
.40364 .47242 .41028 .47785 .4213 .47692 .41466 .47241 Mtetra
.141 .575 .928 r
.41466 .47241 .4213 .47692 .43233 .47799 .42567 .4751 Mtetra
.456 0 0 r
.42567 .4751 .43233 .47799 .44337 .48196 .43666 .48169 Mtetra
.751 .247 .021 r
.43666 .48169 .44337 .48196 .45442 .48963 .44765 .4932 Mtetra
.802 .383 .25 r
.44765 .4932 .45442 .48963 .46553 .50134 .45869 .50997 Mtetra
.796 .424 .351 r
.45869 .50997 .46553 .50134 .47674 .51655 .46985 .53118 Mtetra
.77 .425 .401 r
.46985 .53118 .47674 .51655 .48811 .53358 .4812 .55443 Mtetra
.73 .402 .425 r
.4812 .55443 .48811 .53358 .49968 .54962 .49281 .57591 Mtetra
.671 .355 .431 r
.49281 .57591 .49968 .54962 .51145 .56122 .50468 .5911 Mtetra
.581 .277 .419 r
.50468 .5911 .51145 .56122 .52339 .56521 .51677 .59603 Mtetra
.437 .15 .377 r
.51677 .59603 .52339 .56521 .5354 .55977 .52895 .58861 Mtetra
.202 0 .282 r
.52895 .58861 .5354 .55977 .54739 .54511 .5411 .56952 Mtetra
0 0 .099 r
.5411 .56952 .54739 .54511 .55929 .52349 .55313 .54195 Mtetra
0 0 0 r
.55313 .54195 .55929 .52349 .57105 .49841 .56499 .51055 Mtetra
.829 .859 .406 r
.56499 .51055 .57105 .49841 .58272 .4735 .57671 .47985 Mtetra
.946 .932 .584 r
.57671 .47985 .58272 .4735 .59435 .45146 .58837 .45312 Mtetra
.96 .939 .709 r
.58837 .45312 .59435 .45146 .606 .43364 .60003 .43187 Mtetra
.918 .912 .798 r
.60003 .43187 .606 .43364 .61772 .42014 .61176 .41611 Mtetra
.85 .87 .856 r
.61176 .41611 .61772 .42014 .62954 .41025 .6236 .40485 Mtetra
.781 .827 .888 r
.6236 .40485 .62954 .41025 .64146 .40294 .63554 .3968 Mtetra
.727 .795 .905 r
.63554 .3968 .64146 .40294 .65347 .39725 .64758 .39076 Mtetra
.694 .775 .914 r
.64758 .39076 .65347 .39725 .66556 .39246 .6597 .38585 Mtetra
.675 .767 .919 r
.6597 .38585 .66556 .39246 .67771 .38813 .6719 .3815 Mtetra
.667 .764 .923 r
.6719 .3815 .67771 .38813 .68993 .38399 .68416 .37739 Mtetra
.663 .765 .926 r
.68416 .37739 .68993 .38399 .7022 .37993 .69648 .37338 Mtetra
.662 .767 .928 r
.69648 .37338 .7022 .37993 .71453 .37587 .70885 .36936 Mtetra
.663 .77 .929 r
.70885 .36936 .71453 .37587 .72691 .37179 .72127 .3653 Mtetra
.665 .772 .93 r
.72127 .3653 .72691 .37179 .73934 .36767 .73375 .36116 Mtetra
.667 .773 .929 r
.73375 .36116 .73934 .36767 .75183 .36351 .74627 .35693 Mtetra
.67 .773 .928 r
.74627 .35693 .75183 .36351 .76436 .35929 .75884 .35261 Mtetra
.672 .772 .925 r
.75884 .35261 .76436 .35929 .77695 .35503 .77147 .34822 Mtetra
.673 .769 .923 r
.77147 .34822 .77695 .35503 .78959 .35075 .78414 .34378 Mtetra
.673 .765 .92 r
.78414 .34378 .78959 .35075 .80228 .34644 .79687 .33932 Mtetra
.673 .761 .917 r
.79687 .33932 .80228 .34644 .81503 .34213 .80965 .33485 Mtetra
.672 .757 .915 r
.80965 .33485 .81503 .34213 .82784 .33782 .82249 .3304 Mtetra
.67 .753 .913 r
.82249 .3304 .82784 .33782 .84071 .33352 .83539 .32598 Mtetra
.669 .75 .911 r
.83539 .32598 .84071 .33352 .85363 .32923 .84835 .32158 Mtetra
.667 .747 .91 r
.84835 .32158 .85363 .32923 .86661 .32494 .86137 .31721 Mtetra
.666 .745 .909 r
.86137 .31721 .86661 .32494 .87966 .32066 .87445 .31286 Mtetra
.665 .744 .909 r
.87445 .31286 .87966 .32066 .89276 .31638 .8876 .30852 Mtetra
.656 .744 .915 r
.28817 .49633 .29509 .50261 .30575 .49932 .29886 .49304 Mtetra
.655 .745 .916 r
.29886 .49304 .30575 .49932 .31646 .49603 .30959 .48974 Mtetra
.30959 .48974 .31646 .49603 .32721 .49273 .32037 .48645 Mtetra
.654 .746 .917 r
.32037 .48645 .32721 .49273 .33801 .48944 .33119 .48315 Mtetra
.654 .747 .918 r
.33119 .48315 .33801 .48944 .34885 .48615 .34206 .47986 Mtetra
.652 .747 .919 r
.34206 .47986 .34885 .48615 .35973 .48288 .35297 .47661 Mtetra
.648 .747 .922 r
.35297 .47661 .35973 .48288 .37066 .47967 .36392 .47344 Mtetra
.638 .746 .927 r
.36392 .47344 .37066 .47967 .38163 .47666 .37491 .47051 Mtetra
.613 .743 .938 r
.37491 .47051 .38163 .47666 .39263 .47409 .38593 .46815 Mtetra
.553 .73 .957 r
.38593 .46815 .39263 .47409 .40364 .47242 .39695 .46692 Mtetra
.394 .679 .974 r
.39695 .46692 .40364 .47242 .41466 .47241 .40796 .46776 Mtetra
0 .454 .849 r
.40796 .46776 .41466 .47241 .42567 .4751 .41894 .47196 Mtetra
.606 .043 0 r
.41894 .47196 .42567 .4751 .43666 .48169 .42989 .48095 Mtetra
.807 .334 .095 r
.42989 .48095 .43666 .48169 .44765 .4932 .44081 .49592 Mtetra
.839 .434 .274 r
.44081 .49592 .44765 .4932 .45869 .50997 .45178 .51719 Mtetra
.831 .463 .357 r
.45178 .51719 .45869 .50997 .46985 .53118 .46287 .54355 Mtetra
.807 .459 .398 r
.46287 .54355 .46985 .53118 .4812 .55443 .47419 .57195 Mtetra
.767 .43 .416 r
.47419 .57195 .4812 .55443 .49281 .57591 .48582 .59763 Mtetra
.701 .371 .415 r
.48582 .59763 .49281 .57591 .50468 .5911 .49777 .61516 Mtetra
.582 .258 .386 r
.49777 .61516 .50468 .5911 .51677 .59603 .50998 .61999 Mtetra
.34 .037 .296 r
.50998 .61999 .51677 .59603 .52895 .58861 .52232 .61008 Mtetra
0 0 .067 r
.52232 .61008 .52895 .58861 .5411 .56952 .53462 .58667 Mtetra
.677 .752 .258 r
.53462 .58667 .5411 .56952 .55313 .54195 .54678 .55393 Mtetra
.921 .882 .462 r
.54678 .55393 .55313 .54195 .56499 .51055 .55875 .5174 Mtetra
.983 .897 .566 r
.55875 .5174 .56499 .51055 .57671 .47985 .57055 .48227 Mtetra
.985 .889 .64 r
.57055 .48227 .57671 .47985 .58837 .45312 .58225 .45211 Mtetra
.96 .878 .709 r
.58225 .45211 .58837 .45312 .60003 .43187 .59396 .42846 Mtetra
.914 .863 .775 r
.59396 .42846 .60003 .43187 .61176 .41611 .60572 .41116 Mtetra
.852 .841 .834 r
.60572 .41116 .61176 .41611 .6236 .40485 .61759 .39903 Mtetra
.786 .816 .876 r
.61759 .39903 .6236 .40485 .63554 .3968 .62957 .39054 Mtetra
.73 .793 .902 r
.62957 .39054 .63554 .3968 .64758 .39076 .64165 .38434 Mtetra
.693 .779 .917 r
.64165 .38434 .64758 .39076 .6597 .38585 .65381 .37943 Mtetra
.671 .774 .927 r
.65381 .37943 .6597 .38585 .6719 .3815 .66605 .37517 Mtetra
.66 .774 .933 r
.66605 .37517 .6719 .3815 .68416 .37739 .67836 .3712 Mtetra
.656 .778 .939 r
.67836 .3712 .68416 .37739 .69648 .37338 .69073 .36732 Mtetra
.655 .783 .942 r
.69073 .36732 .69648 .37338 .70885 .36936 .70315 .36341 Mtetra
.657 .789 .945 r
.70315 .36341 .70885 .36936 .72127 .3653 .71563 .3594 Mtetra
.662 .793 .945 r
.71563 .3594 .72127 .3653 .73375 .36116 .72815 .35526 Mtetra
.667 .796 .944 r
.72815 .35526 .73375 .36116 .74627 .35693 .74071 .35095 Mtetra
.672 .796 .941 r
.74071 .35095 .74627 .35693 .75884 .35261 .75332 .34649 Mtetra
.676 .794 .937 r
.75332 .34649 .75884 .35261 .77147 .34822 .76598 .3419 Mtetra
.679 .789 .933 r
.76598 .3419 .77147 .34822 .78414 .34378 .77868 .33722 Mtetra
.68 .782 .928 r
.77868 .33722 .78414 .34378 .79687 .33932 .79143 .3325 Mtetra
.679 .775 .923 r
.79143 .3325 .79687 .33932 .80965 .33485 .80424 .32779 Mtetra
.677 .768 .919 r
.80424 .32779 .80965 .33485 .82249 .3304 .81711 .32312 Mtetra
.675 .761 .916 r
.81711 .32312 .82249 .3304 .83539 .32598 .83004 .31851 Mtetra
.672 .755 .913 r
.83004 .31851 .83539 .32598 .84835 .32158 .84303 .31396 Mtetra
.67 .751 .911 r
.84303 .31396 .84835 .32158 .86137 .31721 .85608 .30947 Mtetra
.668 .747 .91 r
.85608 .30947 .86137 .31721 .87445 .31286 .8692 .30503 Mtetra
.666 .745 .909 r
.8692 .30503 .87445 .31286 .8876 .30852 .88239 .30061 Mtetra
.655 .744 .915 r
.2812 .49001 .28817 .49633 .29886 .49304 .29191 .48671 Mtetra
.655 .745 .916 r
.29191 .48671 .29886 .49304 .30959 .48974 .30267 .48341 Mtetra
.654 .745 .917 r
.30267 .48341 .30959 .48974 .32037 .48645 .31347 .48012 Mtetra
.653 .746 .918 r
.31347 .48012 .32037 .48645 .33119 .48315 .32432 .47682 Mtetra
.652 .747 .919 r
.32432 .47682 .33119 .48315 .34206 .47986 .33521 .47354 Mtetra
.651 .747 .92 r
.33521 .47354 .34206 .47986 .35297 .47661 .34615 .47029 Mtetra
.646 .747 .923 r
.34615 .47029 .35297 .47661 .36392 .47344 .35713 .46715 Mtetra
.634 .745 .928 r
.35713 .46715 .36392 .47344 .37491 .47051 .36814 .46429 Mtetra
.605 .739 .94 r
.36814 .46429 .37491 .47051 .38593 .46815 .37917 .46207 Mtetra
.534 .72 .959 r
.37917 .46207 .38593 .46815 .39695 .46692 .39021 .46117 Mtetra
.35 .649 .967 r
.39021 .46117 .39695 .46692 .40796 .46776 .40122 .46262 Mtetra
0 .377 .804 r
.40122 .46262 .40796 .46776 .41894 .47196 .41218 .46788 Mtetra
.65 .105 0 r
.41218 .46788 .41894 .47196 .42989 .48095 .42309 .47854 Mtetra
.835 .368 .08 r
.42309 .47854 .42989 .48095 .44081 .49592 .43396 .49584 Mtetra
.872 .463 .246 r
.43396 .49584 .44081 .49592 .45178 .51719 .44485 .52001 Mtetra
.872 .492 .322 r
.44485 .52001 .45178 .51719 .46287 .54355 .45588 .54951 Mtetra
.856 .49 .356 r
.45588 .54951 .46287 .54355 .47419 .57195 .46717 .58072 Mtetra
.824 .458 .363 r
.46717 .58072 .47419 .57195 .48582 .59763 .4788 .60825 Mtetra
.756 .377 .336 r
.4788 .60825 .48582 .59763 .49777 .61516 .4908 .62616 Mtetra
.559 .148 .22 r
.4908 .62616 .49777 .61516 .50998 .61999 .5031 .62976 Mtetra
0 0 0 r
.5031 .62976 .50998 .61999 .52232 .61008 .51555 .61732 Mtetra
.936 .94 .595 r
.51555 .61732 .52232 .61008 .53462 .58667 .52798 .59074 Mtetra
.991 .876 .613 r
.52798 .59074 .53462 .58667 .54678 .55393 .54026 .55484 Mtetra
.983 .834 .618 r
.54026 .55484 .54678 .55393 .55875 .5174 .55233 .51564 Mtetra
.969 .813 .634 r
.55233 .51564 .55875 .5174 .57055 .48227 .56422 .47852 Mtetra
.951 .806 .664 r
.56422 .47852 .57055 .48227 .58225 .45211 .57601 .44704 Mtetra
.926 .806 .707 r
.57601 .44704 .58225 .45211 .59396 .42846 .58777 .4226 Mtetra
.89 .808 .761 r
.58777 .4226 .59396 .42846 .60572 .41116 .5996 .4049 Mtetra
.839 .806 .819 r
.5996 .4049 .60572 .41116 .61759 .39903 .61152 .39261 Mtetra
.78 .799 .868 r
.61152 .39261 .61759 .39903 .62957 .39054 .62354 .38415 Mtetra
.725 .789 .903 r
.62354 .38415 .62957 .39054 .64165 .38434 .63567 .37808 Mtetra
.685 .784 .925 r
.63567 .37808 .64165 .38434 .65381 .37943 .64789 .37338 Mtetra
.66 .784 .94 r
.64789 .37338 .65381 .37943 .66605 .37517 .66018 .36937 Mtetra
.646 .789 .951 r
.66018 .36937 .66605 .37517 .67836 .3712 .67255 .36567 Mtetra
.64 .798 .959 r
.67255 .36567 .67836 .3712 .69073 .36732 .68497 .36205 Mtetra
.639 .808 .964 r
.68497 .36205 .69073 .36732 .70315 .36341 .69746 .35835 Mtetra
.643 .818 .967 r
.69746 .35835 .70315 .36341 .71563 .3594 .70999 .35446 Mtetra
.652 .827 .967 r
.70999 .35446 .71563 .3594 .72815 .35526 .72256 .35033 Mtetra
.662 .832 .965 r
.72256 .35033 .72815 .35526 .74071 .35095 .73517 .34591 Mtetra
.673 .833 .96 r
.73517 .34591 .74071 .35095 .75332 .34649 .74782 .34123 Mtetra
.682 .829 .954 r
.74782 .34123 .75332 .34649 .76598 .3419 .7605 .33632 Mtetra
.688 .82 .946 r
.7605 .33632 .76598 .3419 .77868 .33722 .77323 .33127 Mtetra
.69 .809 .939 r
.77323 .33127 .77868 .33722 .79143 .3325 .786 .32617 Mtetra
.689 .797 .931 r
.786 .32617 .79143 .3325 .80424 .32779 .79883 .32108 Mtetra
.686 .784 .925 r
.79883 .32108 .80424 .32779 .81711 .32312 .81171 .31607 Mtetra
.682 .773 .92 r
.81171 .31607 .81711 .32312 .83004 .31851 .82466 .31118 Mtetra
.678 .764 .916 r
.82466 .31118 .83004 .31851 .84303 .31396 .83768 .30641 Mtetra
.674 .757 .913 r
.83768 .30641 .84303 .31396 .85608 .30947 .85076 .30175 Mtetra
.671 .751 .911 r
.85076 .30175 .85608 .30947 .8692 .30503 .86392 .29718 Mtetra
.668 .747 .91 r
.86392 .29718 .8692 .30503 .88239 .30061 .87714 .29267 Mtetra
.654 .744 .916 r
.27417 .48364 .2812 .49001 .29191 .48671 .28491 .48034 Mtetra
.654 .745 .916 r
.28491 .48034 .29191 .48671 .30267 .48341 .2957 .47704 Mtetra
.653 .745 .917 r
.2957 .47704 .30267 .48341 .31347 .48012 .30652 .47374 Mtetra
.652 .746 .918 r
.30652 .47374 .31347 .48012 .32432 .47682 .3174 .47045 Mtetra
.651 .746 .919 r
.3174 .47045 .32432 .47682 .33521 .47354 .32831 .46717 Mtetra
.649 .747 .921 r
.32831 .46717 .33521 .47354 .34615 .47029 .33928 .46392 Mtetra
.644 .746 .923 r
.33928 .46392 .34615 .47029 .35713 .46715 .35028 .4608 Mtetra
.632 .744 .929 r
.35028 .4608 .35713 .46715 .36814 .46429 .36132 .45796 Mtetra
.602 .736 .939 r
.36132 .45796 .36814 .46429 .37917 .46207 .37238 .45581 Mtetra
.529 .713 .956 r
.37238 .45581 .37917 .46207 .39021 .46117 .38343 .45502 Mtetra
.347 .635 .961 r
.38343 .45502 .39021 .46117 .40122 .46262 .39445 .4567 Mtetra
0 .375 .82 r
.39445 .4567 .40122 .46262 .41218 .46788 .40541 .46233 Mtetra
.6 .073 0 r
.40541 .46233 .41218 .46788 .42309 .47854 .4163 .47349 Mtetra
.825 .351 0 r
.4163 .47349 .42309 .47854 .43396 .49584 .42715 .49141 Mtetra
.889 .463 .144 r
.42715 .49141 .43396 .49584 .44485 .52001 .43801 .51613 Mtetra
.907 .504 .213 r
.43801 .51613 .44485 .52001 .45588 .54951 .44901 .5459 Mtetra
.908 .507 .22 r
.44901 .5459 .45588 .54951 .46717 .58072 .46027 .5768 Mtetra
.889 .464 .153 r
.46027 .5768 .46717 .58072 .4788 .60825 .4719 .60327 Mtetra
.757 .254 0 r
.4719 .60327 .4788 .60825 .4908 .62616 .48392 .61943 Mtetra
.38 .646 .961 r
.48392 .61943 .4908 .62616 .5031 .62976 .49626 .62095 Mtetra
.824 .747 .779 r
.49626 .62095 .5031 .62976 .51555 .61732 .50876 .60663 Mtetra
.879 .724 .686 r
.50876 .60663 .51555 .61732 .52798 .59074 .52126 .57886 Mtetra
.894 .714 .651 r
.52126 .57886 .52798 .59074 .54026 .55484 .53362 .54267 Mtetra
.898 .712 .641 r
.53362 .54267 .54026 .55484 .55233 .51564 .54578 .50397 Mtetra
.898 .716 .648 r
.54578 .50397 .55233 .51564 .56422 .47852 .55776 .46784 Mtetra
.892 .725 .668 r
.55776 .46784 .56422 .47852 .57601 .44704 .56964 .4375 Mtetra
.879 .74 .704 r
.56964 .4375 .57601 .44704 .58777 .4226 .58149 .41411 Mtetra
.855 .757 .754 r
.58149 .41411 .58777 .4226 .5996 .4049 .59339 .39727 Mtetra
.816 .772 .812 r
.59339 .39727 .5996 .4049 .61152 .39261 .60538 .38565 Mtetra
.764 .782 .867 r
.60538 .38565 .61152 .39261 .62354 .38415 .61746 .37772 Mtetra
.711 .787 .911 r
.61746 .37772 .62354 .38415 .63567 .37808 .62965 .37214 Mtetra
.667 .791 .94 r
.62965 .37214 .63567 .37808 .64789 .37338 .64193 .3679 Mtetra
.635 .798 .961 r
.64193 .3679 .64789 .37338 .66018 .36937 .65429 .36438 Mtetra
.614 .809 .975 r
.65429 .36438 .66018 .36937 .67255 .36567 .66672 .36116 Mtetra
.602 .824 .985 r
.66672 .36116 .67255 .36567 .68497 .36205 .67922 .35796 Mtetra
.599 .841 .99 r
.67922 .35796 .68497 .36205 .69746 .35835 .69178 .35461 Mtetra
.606 .857 .991 r
.69178 .35461 .69746 .35835 .70999 .35446 .70437 .35092 Mtetra
.621 .872 .989 r
.70437 .35092 .70999 .35446 .72256 .35033 .717 .34682 Mtetra
.643 .881 .985 r
.717 .34682 .72256 .35033 .73517 .34591 .72966 .34224 Mtetra
.666 .884 .978 r
.72966 .34224 .73517 .34591 .74782 .34123 .74235 .33722 Mtetra
.686 .878 .97 r
.74235 .33722 .74782 .34123 .7605 .33632 .75506 .33184 Mtetra
.699 .866 .961 r
.75506 .33184 .7605 .33632 .77323 .33127 .7678 .32623 Mtetra
.705 .848 .951 r
.7678 .32623 .77323 .33127 .786 .32617 .78058 .32054 Mtetra
.705 .828 .941 r
.78058 .32054 .786 .32617 .79883 .32108 .79341 .31489 Mtetra
.701 .809 .932 r
.79341 .31489 .79883 .32108 .81171 .31607 .8063 .30938 Mtetra
.694 .791 .925 r
.8063 .30938 .81171 .31607 .82466 .31118 .81927 .30408 Mtetra
.687 .776 .919 r
.81927 .30408 .82466 .31118 .83768 .30641 .8323 .29898 Mtetra
.68 .765 .915 r
.8323 .29898 .83768 .30641 .85076 .30175 .84541 .29408 Mtetra
.675 .756 .912 r
.84541 .29408 .85076 .30175 .86392 .29718 .85859 .28933 Mtetra
.671 .75 .91 r
.85859 .28933 .86392 .29718 .87714 .29267 .87185 .28469 Mtetra
.654 .744 .916 r
.2671 .47723 .27417 .48364 .28491 .48034 .27786 .47392 Mtetra
.653 .744 .917 r
.27786 .47392 .28491 .48034 .2957 .47704 .28867 .47062 Mtetra
.652 .745 .918 r
.28867 .47062 .2957 .47704 .30652 .47374 .29952 .46732 Mtetra
.651 .745 .919 r
.29952 .46732 .30652 .47374 .3174 .47045 .31042 .46403 Mtetra
.65 .746 .92 r
.31042 .46403 .3174 .47045 .32831 .46717 .32136 .46075 Mtetra
.648 .746 .921 r
.32136 .46075 .32831 .46717 .33928 .46392 .33235 .4575 Mtetra
.644 .746 .923 r
.33235 .4575 .33928 .46392 .35028 .4608 .34338 .45436 Mtetra
.632 .743 .928 r
.34338 .45436 .35028 .4608 .36132 .45796 .35445 .45151 Mtetra
.603 .735 .937 r
.35445 .45151 .36132 .45796 .37238 .45581 .36553 .44931 Mtetra
.537 .71 .951 r
.36553 .44931 .37238 .45581 .38343 .45502 .37661 .44842 Mtetra
.382 .638 .956 r
.37661 .44842 .38343 .45502 .39445 .4567 .38766 .44987 Mtetra
.046 .432 .871 r
.38766 .44987 .39445 .4567 .40541 .46233 .39865 .45506 Mtetra
0 .059 .572 r
.39865 .45506 .40541 .46233 .4163 .47349 .40956 .46545 Mtetra
.712 .243 0 r
.40956 .46545 .4163 .47349 .42715 .49141 .42043 .48208 Mtetra
.817 .385 0 r
.42043 .48208 .42715 .49141 .43801 .51613 .43131 .50486 Mtetra
.832 .427 0 r
.43131 .50486 .43801 .51613 .44901 .5459 .44232 .53192 Mtetra
.748 .372 0 r
.44232 .53192 .44901 .5459 .46027 .5768 .45359 .55945 Mtetra
0 0 .473 r
.45359 .55945 .46027 .5768 .4719 .60327 .46521 .58223 Mtetra
.223 .277 .708 r
.46521 .58223 .4719 .60327 .48392 .61943 .47722 .59499 Mtetra
.573 .479 .71 r
.47722 .59499 .48392 .61943 .49626 .62095 .48955 .59415 Mtetra
.71 .554 .674 r
.48955 .59415 .49626 .62095 .50876 .60663 .50205 .57913 Mtetra
.772 .588 .651 r
.50205 .57913 .50876 .60663 .52126 .57886 .51455 .55248 Mtetra
.804 .61 .64 r
.51455 .55248 .52126 .57886 .53362 .54267 .52694 .51893 Mtetra
.823 .627 .639 r
.52694 .51893 .53362 .54267 .54578 .50397 .53916 .48375 Mtetra
.833 .645 .649 r
.53916 .48375 .54578 .50397 .55776 .46784 .55122 .4513 Mtetra
.837 .665 .67 r
.55122 .4513 .55776 .46784 .56964 .4375 .56319 .42426 Mtetra
.833 .689 .705 r
.56319 .42426 .56964 .4375 .58149 .41411 .57513 .40352 Mtetra
.817 .717 .755 r
.57513 .40352 .58149 .41411 .59339 .39727 .58712 .38862 Mtetra
.786 .746 .816 r
.58712 .38862 .59339 .39727 .60538 .38565 .59918 .3784 Mtetra
.74 .77 .877 r
.59918 .3784 .60538 .38565 .61746 .37772 .61134 .3715 Mtetra
.685 .787 .928 r
.61134 .3715 .61746 .37772 .62965 .37214 .6236 .36675 Mtetra
.63 .8 .964 r
.6236 .36675 .62965 .37214 .64193 .3679 .63595 .3633 Mtetra
.582 .813 .987 r
.63595 .3633 .64193 .3679 .65429 .36438 .64839 .36053 Mtetra
.542 .827 .998 r
.64839 .36053 .65429 .36438 .66672 .36116 .66091 .35804 Mtetra
.511 .842 .998 r
.66091 .35804 .66672 .36116 .67922 .35796 .67349 .35551 Mtetra
.497 .858 .989 r
.67349 .35551 .67922 .35796 .69178 .35461 .68613 .35266 Mtetra
.503 .877 .977 r
.68613 .35266 .69178 .35461 .70437 .35092 .6988 .34928 Mtetra
.532 .898 .968 r
.6988 .34928 .70437 .35092 .717 .34682 .7115 .3452 Mtetra
.579 .919 .966 r
.7115 .3452 .717 .34682 .72966 .34224 .72422 .34038 Mtetra
.632 .933 .967 r
.72422 .34038 .72966 .34224 .74235 .33722 .73693 .33487 Mtetra
.678 .934 .968 r
.73693 .33487 .74235 .33722 .75506 .33184 .74966 .32879 Mtetra
.709 .921 .964 r
.74966 .32879 .75506 .33184 .7678 .32623 .7624 .32237 Mtetra
.725 .898 .957 r
.7624 .32237 .7678 .32623 .78058 .32054 .77518 .31583 Mtetra
.727 .869 .948 r
.77518 .31583 .78058 .32054 .79341 .31489 .788 .30937 Mtetra
.721 .84 .938 r
.788 .30937 .79341 .31489 .8063 .30938 .80089 .30316 Mtetra
.711 .814 .929 r
.80089 .30316 .8063 .30938 .81927 .30408 .81386 .29727 Mtetra
.7 .792 .922 r
.81386 .29727 .81927 .30408 .8323 .29898 .8269 .29172 Mtetra
.689 .775 .917 r
.8269 .29172 .8323 .29898 .84541 .29408 .84003 .28648 Mtetra
.681 .763 .913 r
.84003 .28648 .84541 .29408 .85859 .28933 .85323 .2815 Mtetra
.675 .755 .911 r
.85323 .2815 .85859 .28933 .87185 .28469 .86652 .2767 Mtetra
.653 .744 .916 r
.25997 .47076 .2671 .47723 .27786 .47392 .27075 .46745 Mtetra
.652 .744 .917 r
.27075 .46745 .27786 .47392 .28867 .47062 .28158 .46414 Mtetra
.651 .745 .918 r
.28158 .46414 .28867 .47062 .29952 .46732 .29246 .46084 Mtetra
.65 .745 .919 r
.29246 .46084 .29952 .46732 .31042 .46403 .30339 .45755 Mtetra
.649 .746 .92 r
.30339 .45755 .31042 .46403 .32136 .46075 .31436 .45426 Mtetra
.648 .746 .921 r
.31436 .45426 .32136 .46075 .33235 .4575 .32537 .45101 Mtetra
.644 .745 .923 r
.32537 .45101 .33235 .4575 .34338 .45436 .33643 .44785 Mtetra
.633 .743 .927 r
.33643 .44785 .34338 .45436 .35445 .45151 .34752 .44494 Mtetra
.609 .734 .934 r
.34752 .44494 .35445 .45151 .36553 .44931 .35864 .4426 Mtetra
.555 .711 .944 r
.35864 .4426 .36553 .44931 .37661 .44842 .36976 .44139 Mtetra
.439 .652 .949 r
.36976 .44139 .37661 .44842 .38766 .44987 .38085 .44223 Mtetra
.21 .509 .91 r
.38085 .44223 .38766 .44987 .39865 .45506 .39189 .44628 Mtetra
0 .252 .761 r
.39189 .44628 .39865 .45506 .40956 .46545 .40287 .4548 Mtetra
0 0 .559 r
.40287 .4548 .40956 .46545 .42043 .48208 .4138 .46858 Mtetra
0 0 .449 r
.4138 .46858 .42043 .48208 .43131 .50486 .42475 .48741 Mtetra
0 0 .471 r
.42475 .48741 .43131 .50486 .44232 .53192 .43582 .50952 Mtetra
0 .019 .571 r
.43582 .50952 .44232 .53192 .45359 .55945 .44713 .53151 Mtetra
.202 .212 .647 r
.44713 .53151 .45359 .55945 .46521 .58223 .45877 .54895 Mtetra
.444 .356 .662 r
.45877 .54895 .46521 .58223 .47722 .59499 .47075 .55756 Mtetra
.586 .442 .653 r
.47075 .55756 .47722 .59499 .48955 .59415 .48302 .5547 Mtetra
.667 .494 .641 r
.48302 .5547 .48955 .59415 .50205 .57913 .49545 .54026 Mtetra
.717 .528 .634 r
.49545 .54026 .50205 .57913 .51455 .55248 .50791 .51666 Mtetra
.749 .554 .632 r
.50791 .51666 .51455 .55248 .52694 .51893 .52028 .48791 Mtetra
.77 .577 .638 r
.52028 .48791 .52694 .51893 .53916 .48375 .53252 .45831 Mtetra
.784 .6 .651 r
.53252 .45831 .53916 .48375 .55122 .4513 .54464 .4313 Mtetra
.792 .626 .675 r
.54464 .4313 .55122 .4513 .56319 .42426 .55669 .40893 Mtetra
.792 .656 .713 r
.55669 .40893 .56319 .42426 .57513 .40352 .56872 .39182 Mtetra
.781 .692 .766 r
.56872 .39182 .57513 .40352 .58712 .38862 .58079 .37958 Mtetra
.753 .73 .831 r
.58079 .37958 .58712 .38862 .59918 .3784 .59294 .37125 Mtetra
.705 .765 .899 r
.59294 .37125 .59918 .3784 .61134 .3715 .60517 .36577 Mtetra
.637 .791 .956 r
.60517 .36577 .61134 .3715 .6236 .36675 .61751 .36221 Mtetra
.556 .806 .992 r
.61751 .36221 .6236 .36675 .63595 .3633 .62995 .35986 Mtetra
.466 .809 .999 r
.62995 .35986 .63595 .3633 .64839 .36053 .64248 .35817 Mtetra
.376 .799 .972 r
.64248 .35817 .64839 .36053 .66091 .35804 .6551 .35672 Mtetra
.3 .781 .916 r
.6551 .35672 .66091 .35804 .67349 .35551 .66779 .3551 Mtetra
.261 .768 .853 r
.66779 .3551 .67349 .35551 .68613 .35266 .68053 .35295 Mtetra
.268 .775 .808 r
.68053 .35295 .68613 .35266 .6988 .34928 .69329 .34996 Mtetra
.325 .81 .797 r
.69329 .34996 .6988 .34928 .7115 .3452 .70607 .34591 Mtetra
.419 .865 .819 r
.70607 .34591 .7115 .3452 .72422 .34038 .71884 .34073 Mtetra
.531 .923 .861 r
.71884 .34073 .72422 .34038 .73693 .33487 .73159 .3345 Mtetra
.634 .961 .904 r
.73159 .3345 .73693 .33487 .74966 .32879 .74432 .32745 Mtetra
.707 .969 .933 r
.74432 .32745 .74966 .32879 .7624 .32237 .75706 .3199 Mtetra
.745 .95 .945 r
.75706 .3199 .7624 .32237 .77518 .31583 .76981 .3122 Mtetra
.755 .915 .945 r
.76981 .3122 .77518 .31583 .788 .30937 .78262 .30465 Mtetra
.748 .877 .939 r
.78262 .30465 .788 .30937 .80089 .30316 .79548 .29748 Mtetra
.733 .841 .931 r
.79548 .29748 .80089 .30316 .81386 .29727 .80843 .29081 Mtetra
.717 .811 .924 r
.80843 .29081 .81386 .29727 .8269 .29172 .82147 .28466 Mtetra
.701 .788 .918 r
.82147 .28466 .8269 .29172 .84003 .28648 .83461 .27898 Mtetra
.689 .771 .914 r
.83461 .27898 .84003 .28648 .85323 .2815 .84784 .27369 Mtetra
.68 .759 .911 r
.84784 .27369 .85323 .2815 .86652 .2767 .86115 .26869 Mtetra
.652 .743 .916 r
.25278 .46424 .25997 .47076 .27075 .46745 .26359 .46092 Mtetra
.651 .744 .917 r
.26359 .46092 .27075 .46745 .28158 .46414 .27445 .45761 Mtetra
.65 .744 .918 r
.27445 .45761 .28158 .46414 .29246 .46084 .28535 .45431 Mtetra
.65 .745 .919 r
.28535 .45431 .29246 .46084 .30339 .45755 .2963 .45101 Mtetra
.649 .745 .92 r
.2963 .45101 .30339 .45755 .31436 .45426 .3073 .44772 Mtetra
.647 .745 .921 r
.3073 .44772 .31436 .45426 .32537 .45101 .31834 .44446 Mtetra
.644 .745 .923 r
.31834 .44446 .32537 .45101 .33643 .44785 .32943 .44127 Mtetra
.636 .743 .925 r
.32943 .44127 .33643 .44785 .34752 .44494 .34055 .43827 Mtetra
.617 .735 .93 r
.34055 .43827 .34752 .44494 .35864 .4426 .3517 .43572 Mtetra
.578 .716 .937 r
.3517 .43572 .35864 .4426 .36976 .44139 .36287 .43407 Mtetra
.498 .671 .941 r
.36287 .43407 .36976 .44139 .38085 .44223 .37402 .43404 Mtetra
.357 .575 .923 r
.37402 .43404 .38085 .44223 .39189 .44628 .38513 .43655 Mtetra
.162 .417 .857 r
.38513 .43655 .39189 .44628 .40287 .4548 .3962 .44254 Mtetra
0 .247 .755 r
.3962 .44254 .40287 .4548 .4138 .46858 .40724 .45259 Mtetra
0 .154 .681 r
.40724 .45259 .4138 .46858 .42475 .48741 .4183 .46641 Mtetra
.062 .163 .658 r
.4183 .46641 .42475 .48741 .43582 .50952 .42947 .48249 Mtetra
.23 .234 .657 r
.42947 .48249 .43582 .50952 .44713 .53151 .44085 .4981 Mtetra
.39 .316 .653 r
.44085 .4981 .44713 .53151 .45877 .54895 .45251 .50978 Mtetra
.509 .384 .645 r
.45251 .50978 .45877 .54895 .47075 .55756 .46445 .5144 Mtetra
.591 .434 .637 r
.46445 .5144 .47075 .55756 .48302 .5547 .47664 .51018 Mtetra
.647 .471 .631 r
.47664 .51018 .48302 .5547 .49545 .54026 .48898 .49731 Mtetra
.686 .5 .63 r
.48898 .49731 .49545 .54026 .50791 .51666 .50135 .47784 Mtetra
.714 .525 .633 r
.50135 .47784 .50791 .51666 .52028 .48791 .51367 .45488 Mtetra
.734 .549 .642 r
.51367 .45488 .52028 .48791 .53252 .45831 .5259 .43164 Mtetra
.749 .575 .659 r
.5259 .43164 .53252 .45831 .54464 .4313 .53806 .41064 Mtetra
.757 .604 .688 r
.53806 .41064 .54464 .4313 .55669 .40893 .55016 .39333 Mtetra
.758 .639 .73 r
.55016 .39333 .55669 .40893 .56872 .39182 .56227 .38015 Mtetra
.746 .681 .788 r
.56227 .38015 .56872 .39182 .58079 .37958 .57442 .37081 Mtetra
.713 .726 .86 r
.57442 .37081 .58079 .37958 .59294 .37125 .58665 .36462 Mtetra
.651 .766 .934 r
.58665 .36462 .59294 .37125 .60517 .36577 .59897 .36083 Mtetra
.549 .789 .988 r
.59897 .36083 .60517 .36577 .61751 .36221 .6114 .35876 Mtetra
.404 .778 .993 r
.6114 .35876 .61751 .36221 .62995 .35986 .62393 .35784 Mtetra
.23 .721 .921 r
.62393 .35784 .62995 .35986 .64248 .35817 .63657 .35758 Mtetra
.07 .631 .783 r
.63657 .35758 .64248 .35817 .6551 .35672 .6493 .35749 Mtetra
.032 0 0 r
.6493 .35749 .6551 .35672 .66779 .3551 .66211 .35705 Mtetra
.063 0 0 r
.66211 .35705 .66779 .3551 .68053 .35295 .67497 .35579 Mtetra
.029 0 0 r
.67497 .35579 .68053 .35295 .69329 .34996 .68784 .35325 Mtetra
0 0 0 r
.68784 .35325 .69329 .34996 .70607 .34591 .7007 .34917 Mtetra
.7007 .34917 .70607 .34591 .71884 .34073 .71353 .34346 Mtetra
.373 .808 .644 r
.71353 .34346 .71884 .34073 .73159 .3345 .72631 .33626 Mtetra
.548 .918 .757 r
.72631 .33626 .73159 .3345 .74432 .32745 .73904 .32791 Mtetra
.683 .979 .848 r
.73904 .32791 .74432 .32745 .75706 .3199 .75176 .31889 Mtetra
.759 .986 .902 r
.75176 .31889 .75706 .3199 .76981 .3122 .76448 .30969 Mtetra
.785 .956 .925 r
.76448 .30969 .76981 .3122 .78262 .30465 .77724 .30074 Mtetra
.78 .913 .93 r
.77724 .30074 .78262 .30465 .79548 .29748 .79007 .29236 Mtetra
.761 .869 .928 r
.79007 .29236 .79548 .29748 .80843 .29081 .803 .28471 Mtetra
.738 .831 .923 r
.803 .28471 .80843 .29081 .82147 .28466 .81602 .2778 Mtetra
.716 .802 .918 r
.81602 .2778 .82147 .28466 .83461 .27898 .82916 .27158 Mtetra
.699 .78 .914 r
.82916 .27158 .83461 .27898 .84784 .27369 .8424 .26592 Mtetra
.686 .765 .911 r
.8424 .26592 .84784 .27369 .86115 .26869 .85574 .26066 Mtetra
.651 .743 .917 r
.24554 .45766 .25278 .46424 .26359 .46092 .25637 .45433 Mtetra
.65 .743 .917 r
.25637 .45433 .26359 .46092 .27445 .45761 .26726 .45102 Mtetra
.649 .744 .918 r
.26726 .45102 .27445 .45761 .28535 .45431 .27818 .44771 Mtetra
.649 .744 .919 r
.27818 .44771 .28535 .45431 .2963 .45101 .28916 .44441 Mtetra
.648 .745 .92 r
.28916 .44441 .2963 .45101 .3073 .44772 .30018 .44111 Mtetra
.647 .745 .921 r
.30018 .44111 .3073 .44772 .31834 .44446 .31125 .43783 Mtetra
.644 .745 .922 r
.31125 .43783 .31834 .44446 .32943 .44127 .32237 .4346 Mtetra
.638 .743 .924 r
.32237 .4346 .32943 .44127 .34055 .43827 .33352 .43151 Mtetra
.625 .737 .927 r
.33352 .43151 .34055 .43827 .3517 .43572 .34471 .42874 Mtetra
.599 .722 .931 r
.34471 .42874 .3517 .43572 .36287 .43407 .35592 .42661 Mtetra
.548 .689 .932 r
.35592 .42661 .36287 .43407 .37402 .43404 .36714 .42565 Mtetra
.465 .625 .921 r
.36714 .42565 .37402 .43404 .38513 .43655 .37833 .42651 Mtetra
.358 .525 .885 r
.37833 .42651 .38513 .43655 .3962 .44254 .38951 .42986 Mtetra
.27 .414 .823 r
.38951 .42986 .3962 .44254 .40724 .45259 .40068 .43605 Mtetra
.25 .338 .759 r
.40068 .43605 .40724 .45259 .4183 .46641 .41187 .44481 Mtetra
.301 .317 .711 r
.41187 .44481 .4183 .46641 .42947 .48249 .42317 .45499 Mtetra
.386 .337 .68 r
.42317 .45499 .42947 .48249 .44085 .4981 .43463 .46455 Mtetra
.472 .371 .66 r
.43463 .46455 .44085 .4981 .45251 .50978 .44631 .47108 Mtetra
.542 .407 .646 r
.44631 .47108 .45251 .50978 .46445 .5144 .45822 .47244 Mtetra
.597 .439 .638 r
.45822 .47244 .46445 .5144 .47664 .51018 .47033 .46756 Mtetra
.638 .466 .635 r
.47033 .46756 .47664 .51018 .48898 .49731 .48256 .45674 Mtetra
.668 .491 .636 r
.48256 .45674 .48898 .49731 .50135 .47784 .49484 .44155 Mtetra
.692 .514 .642 r
.49484 .44155 .50135 .47784 .51367 .45488 .50709 .42422 Mtetra
.71 .539 .655 r
.50709 .42422 .51367 .45488 .5259 .43164 .51931 .40698 Mtetra
.723 .566 .677 r
.51931 .40698 .5259 .43164 .53806 .41064 .53147 .39155 Mtetra
.73 .599 .711 r
.53147 .39155 .53806 .41064 .55016 .39333 .54363 .37891 Mtetra
.727 .638 .759 r
.54363 .37891 .55016 .39333 .56227 .38015 .5558 .36938 Mtetra
.708 .683 .824 r
.5558 .36938 .56227 .38015 .57442 .37081 .56802 .36281 Mtetra
.659 .729 .901 r
.56802 .36281 .57442 .37081 .58665 .36462 .58033 .35878 Mtetra
.56 .762 .972 r
.58033 .35878 .58665 .36462 .59897 .36083 .59273 .35684 Mtetra
.384 .749 .992 r
.59273 .35684 .59897 .36083 .6114 .35876 .60525 .35652 Mtetra
.136 .652 .891 r
.60525 .35652 .6114 .35876 .62393 .35784 .61789 .35735 Mtetra
.102 0 0 r
.61789 .35735 .62393 .35784 .63657 .35758 .63064 .35884 Mtetra
.248 0 0 r
.63064 .35884 .63657 .35758 .6493 .35749 .6435 .3604 Mtetra
.302 0 0 r
.6435 .3604 .6493 .35749 .66211 .35705 .65645 .36138 Mtetra
.29 0 0 r
.65645 .36138 .66211 .35705 .67497 .35579 .66944 .36113 Mtetra
.227 0 0 r
.66944 .36113 .67497 .35579 .68784 .35325 .68243 .35909 Mtetra
.117 0 0 r
.68243 .35909 .68784 .35325 .7007 .34917 .69538 .35488 Mtetra
0 0 0 r
.69538 .35488 .7007 .34917 .71353 .34346 .70826 .34843 Mtetra
.70826 .34843 .71353 .34346 .72631 .33626 .72107 .33997 Mtetra
.472 .84 .594 r
.72107 .33997 .72631 .33626 .73904 .32791 .7338 .33 Mtetra
.661 .956 .738 r
.7338 .33 .73904 .32791 .75176 .31889 .74648 .31917 Mtetra
.774 .998 .836 r
.74648 .31917 .75176 .31889 .76448 .30969 .75915 .30814 Mtetra
.816 .982 .888 r
.75915 .30814 .76448 .30969 .77724 .30074 .77186 .29752 Mtetra
.814 .94 .91 r
.77186 .29752 .77724 .30074 .79007 .29236 .78465 .28769 Mtetra
.791 .892 .917 r
.78465 .28769 .79007 .29236 .803 .28471 .79753 .27888 Mtetra
.761 .849 .917 r
.79753 .27888 .803 .28471 .81602 .2778 .81054 .2711 Mtetra
.733 .814 .915 r
.81054 .2711 .81602 .2778 .82916 .27158 .82368 .26425 Mtetra
.71 .788 .912 r
.82368 .26425 .82916 .27158 .8424 .26592 .83693 .25815 Mtetra
.693 .77 .91 r
.83693 .25815 .8424 .26592 .85574 .26066 .85029 .2526 Mtetra
.651 .742 .917 r
.23824 .45101 .24554 .45766 .25637 .45433 .2491 .44768 Mtetra
.65 .743 .917 r
.2491 .44768 .25637 .45433 .26726 .45102 .26001 .44436 Mtetra
.649 .743 .918 r
.26001 .44436 .26726 .45102 .27818 .44771 .27096 .44104 Mtetra
.648 .743 .919 r
.27096 .44104 .27818 .44771 .28916 .44441 .28196 .43774 Mtetra
.647 .744 .92 r
.28196 .43774 .28916 .44441 .30018 .44111 .29301 .43443 Mtetra
.646 .744 .921 r
.29301 .43443 .30018 .44111 .31125 .43783 .30411 .43114 Mtetra
.645 .744 .922 r
.30411 .43114 .31125 .43783 .32237 .4346 .31525 .42787 Mtetra
.641 .743 .923 r
.31525 .42787 .32237 .4346 .33352 .43151 .32644 .42469 Mtetra
.633 .738 .924 r
.32644 .42469 .33352 .43151 .34471 .42874 .33767 .42171 Mtetra
.616 .728 .926 r
.33767 .42171 .34471 .42874 .35592 .42661 .34893 .41915 Mtetra
.586 .705 .925 r
.34893 .41915 .35592 .42661 .36714 .42565 .3602 .41735 Mtetra
.538 .662 .916 r
.3602 .41735 .36714 .42565 .37833 .42651 .37148 .41674 Mtetra
.479 .596 .892 r
.37148 .41674 .37833 .42651 .38951 .42986 .38276 .41773 Mtetra
.429 .518 .847 r
.38276 .41773 .38951 .42986 .40068 .43605 .39406 .42055 Mtetra
.411 .452 .792 r
.39406 .42055 .40068 .43605 .41187 .44481 .40539 .42496 Mtetra
.43 .415 .742 r
.40539 .42496 .41187 .44481 .42317 .45499 .4168 .43016 Mtetra
.473 .408 .703 r
.4168 .43016 .42317 .45499 .43463 .46455 .42835 .43479 Mtetra
.521 .417 .677 r
.42835 .43479 .43463 .46455 .44631 .47108 .44006 .43728 Mtetra
.566 .435 .661 r
.44006 .43728 .44631 .47108 .45822 .47244 .45195 .43631 Mtetra
.604 .455 .652 r
.45195 .43631 .45822 .47244 .47033 .46756 .46399 .43128 Mtetra
.635 .475 .65 r
.46399 .43128 .47033 .46756 .48256 .45674 .47614 .4225 Mtetra
.659 .497 .653 r
.47614 .4225 .48256 .45674 .49484 .44155 .48833 .41107 Mtetra
.679 .519 .662 r
.48833 .41107 .49484 .44155 .50709 .42422 .50052 .39846 Mtetra
.694 .544 .68 r
.50052 .39846 .50709 .42422 .51931 .40698 .51271 .38615 Mtetra
.703 .574 .707 r
.51271 .38615 .51931 .40698 .53147 .39155 .52489 .37524 Mtetra
.706 .609 .746 r
.52489 .37524 .53147 .39155 .54363 .37891 .53707 .36641 Mtetra
.695 .65 .801 r
.53707 .36641 .54363 .37891 .5558 .36938 .5493 .35993 Mtetra
.659 .693 .871 r
.5493 .35993 .5558 .36938 .56802 .36281 .56158 .35579 Mtetra
.577 .729 .946 r
.56158 .35579 .56802 .36281 .58033 .35878 .57396 .35383 Mtetra
.408 .727 .99 r
.57396 .35383 .58033 .35878 .59273 .35684 .58644 .35381 Mtetra
.126 .624 .907 r
.58644 .35381 .59273 .35684 .60525 .35652 .59905 .35541 Mtetra
.177 0 0 r
.59905 .35541 .60525 .35652 .61789 .35735 .6118 .35824 Mtetra
.367 0 0 r
.6118 .35824 .61789 .35735 .63064 .35884 .62468 .36173 Mtetra
.443 0 0 r
.62468 .36173 .63064 .35884 .6435 .3604 .63768 .36517 Mtetra
.448 0 0 r
.63768 .36517 .6435 .3604 .65645 .36138 .65077 .36772 Mtetra
.406 0 0 r
.65077 .36772 .65645 .36138 .66944 .36113 .6639 .36854 Mtetra
.323 0 0 r
.6639 .36854 .66944 .36113 .68243 .35909 .67701 .36693 Mtetra
.195 0 0 r
.67701 .36693 .68243 .35909 .69538 .35488 .69006 .36244 Mtetra
.015 0 0 r
.69006 .36244 .69538 .35488 .70826 .34843 .703 .35503 Mtetra
0 0 0 r
.703 .35503 .70826 .34843 .72107 .33997 .71582 .34504 Mtetra
.71582 .34504 .72107 .33997 .7338 .33 .72854 .33316 Mtetra
.68 .942 .665 r
.72854 .33316 .7338 .33 .74648 .31917 .74118 .32024 Mtetra
.806 .997 .781 r
.74118 .32024 .74648 .31917 .75915 .30814 .7538 .30716 Mtetra
.851 .989 .848 r
.7538 .30716 .75915 .30814 .77186 .29752 .76645 .29466 Mtetra
.847 .951 .883 r
.76645 .29466 .77186 .29752 .78465 .28769 .77918 .28324 Mtetra
.82 .904 .899 r
.77918 .28324 .78465 .28769 .79753 .27888 .79203 .27317 Mtetra
.784 .859 .906 r
.79203 .27317 .79753 .27888 .81054 .2711 .80502 .26443 Mtetra
.75 .822 .908 r
.80502 .26443 .81054 .2711 .82368 .26425 .81815 .2569 Mtetra
.722 .794 .909 r
.81815 .2569 .82368 .26425 .83693 .25815 .83141 .25034 Mtetra
.701 .774 .908 r
.83141 .25034 .83693 .25815 .85029 .2526 .84479 .2445 Mtetra
.65 .742 .917 r
.23089 .44431 .23824 .45101 .2491 .44768 .24177 .44096 Mtetra
.649 .742 .917 r
.24177 .44096 .2491 .44768 .26001 .44436 .2527 .43763 Mtetra
.648 .742 .918 r
.2527 .43763 .26001 .44436 .27096 .44104 .26368 .43431 Mtetra
.647 .743 .919 r
.26368 .43431 .27096 .44104 .28196 .43774 .27471 .43099 Mtetra
.647 .743 .92 r
.27471 .43099 .28196 .43774 .29301 .43443 .28578 .42767 Mtetra
.646 .743 .92 r
.28578 .42767 .29301 .43443 .30411 .43114 .29691 .42436 Mtetra
.645 .743 .921 r
.29691 .42436 .30411 .43114 .31525 .42787 .30808 .42106 Mtetra
.643 .743 .922 r
.30808 .42106 .31525 .42787 .32644 .42469 .3193 .41781 Mtetra
.638 .74 .922 r
.3193 .41781 .32644 .42469 .33767 .42171 .33056 .41466 Mtetra
.628 .733 .923 r
.33056 .41466 .33767 .42171 .34893 .41915 .34187 .41176 Mtetra
.612 .718 .921 r
.34187 .41176 .34893 .41915 .3602 .41735 .3532 .40929 Mtetra
.586 .69 .914 r
.3532 .40929 .3602 .41735 .37148 .41674 .36456 .40753 Mtetra
.554 .647 .896 r
.36456 .40753 .37148 .41674 .38276 .41773 .37593 .4067 Mtetra
.524 .591 .864 r
.37593 .4067 .38276 .41773 .39406 .42055 .38734 .40693 Mtetra
.509 .536 .82 r
.38734 .40693 .39406 .42055 .40539 .42496 .39878 .40806 Mtetra
.513 .495 .774 r
.39878 .40806 .40539 .42496 .4168 .43016 .41031 .40956 Mtetra
.533 .473 .735 r
.41031 .40956 .4168 .43016 .42835 .43479 .42193 .41061 Mtetra
.56 .467 .707 r
.42193 .41061 .42835 .43479 .44006 .43728 .43368 .41029 Mtetra
.588 .472 .689 r
.43368 .41029 .44006 .43728 .45195 .43631 .44556 .40782 Mtetra
.615 .484 .679 r
.44556 .40782 .45195 .43631 .46399 .43128 .45756 .40292 Mtetra
.637 .499 .677 r
.45756 .40292 .46399 .43128 .47614 .4225 .46964 .39584 Mtetra
.657 .518 .683 r
.46964 .39584 .47614 .4225 .48833 .41107 .48177 .38729 Mtetra
.672 .54 .695 r
.48177 .38729 .48833 .41107 .50052 .39846 .49392 .37821 Mtetra
.683 .566 .717 r
.49392 .37821 .50052 .39846 .51271 .38615 .50609 .3695 Mtetra
.688 .597 .749 r
.50609 .3695 .51271 .38615 .52489 .37524 .51828 .3619 Mtetra
.681 .632 .794 r
.51828 .3619 .52489 .37524 .53707 .36641 .53049 .35591 Mtetra
.655 .669 .852 r
.53049 .35591 .53707 .36641 .5493 .35993 .54276 .35179 Mtetra
.591 .702 .92 r
.54276 .35179 .5493 .35993 .56158 .35579 .5551 .34968 Mtetra
.454 .708 .976 r
.5551 .34968 .56158 .35579 .57396 .35383 .56753 .34961 Mtetra
.194 .632 .946 r
.56753 .34961 .57396 .35383 .58644 .35381 .58009 .35149 Mtetra
0 .428 .732 r
.58009 .35149 .58644 .35381 .59905 .35541 .5928 .35512 Mtetra
.403 0 0 r
.5928 .35512 .59905 .35541 .6118 .35824 .60565 .36007 Mtetra
.517 0 0 r
.60565 .36007 .6118 .35824 .62468 .36173 .61866 .36568 Mtetra
.545 .012 0 r
.61866 .36568 .62468 .36173 .63768 .36517 .6318 .37106 Mtetra
.522 .02 .003 r
.6318 .37106 .63768 .36517 .65077 .36772 .64503 .37518 Mtetra
.461 0 .027 r
.64503 .37518 .65077 .36772 .6639 .36854 .6583 .37701 Mtetra
.358 0 .009 r
.6583 .37701 .6639 .36854 .67701 .36693 .67153 .37568 Mtetra
.203 0 0 r
.67153 .37568 .67701 .36693 .69006 .36244 .68466 .37073 Mtetra
0 0 0 r
.68466 .37073 .69006 .36244 .703 .35503 .69766 .36214 Mtetra
.69766 .36214 .703 .35503 .71582 .34504 .7105 .35042 Mtetra
.561 .845 .512 r
.7105 .35042 .71582 .34504 .72854 .33316 .7232 .33645 Mtetra
.758 .96 .659 r
.7232 .33645 .72854 .33316 .74118 .32024 .7358 .32131 Mtetra
.859 .995 .758 r
.7358 .32131 .74118 .32024 .7538 .30716 .74837 .30609 Mtetra
.889 .981 .818 r
.74837 .30609 .7538 .30716 .76645 .29466 .76097 .29168 Mtetra
.876 .945 .855 r
.76097 .29168 .76645 .29466 .77918 .28324 .77365 .27867 Mtetra
.844 .902 .878 r
.77365 .27867 .77918 .28324 .79203 .27317 .78647 .26733 Mtetra
.804 .861 .891 r
.78647 .26733 .79203 .27317 .80502 .26443 .79944 .25765 Mtetra
.765 .825 .899 r
.79944 .25765 .80502 .26443 .81815 .2569 .81256 .24946 Mtetra
.732 .796 .903 r
.81256 .24946 .81815 .2569 .83141 .25034 .82584 .24245 Mtetra
.707 .776 .905 r
.82584 .24245 .83141 .25034 .84479 .2445 .83924 .2363 Mtetra
.649 .741 .916 r
.22348 .43753 .23089 .44431 .24177 .44096 .23439 .43417 Mtetra
.648 .741 .917 r
.23439 .43417 .24177 .44096 .2527 .43763 .24535 .43083 Mtetra
.647 .741 .918 r
.24535 .43083 .2527 .43763 .26368 .43431 .25635 .42749 Mtetra
.647 .742 .919 r
.25635 .42749 .26368 .43431 .27471 .43099 .2674 .42416 Mtetra
.646 .742 .919 r
.2674 .42416 .27471 .43099 .28578 .42767 .2785 .42083 Mtetra
.645 .742 .92 r
.2785 .42083 .28578 .42767 .29691 .42436 .28965 .41751 Mtetra
.645 .743 .92 r
.28965 .41751 .29691 .42436 .30808 .42106 .30085 .41418 Mtetra
.644 .742 .921 r
.30085 .41418 .30808 .42106 .3193 .41781 .3121 .41086 Mtetra
.641 .741 .921 r
.3121 .41086 .3193 .41781 .33056 .41466 .3234 .4076 Mtetra
.637 .737 .921 r
.3234 .4076 .33056 .41466 .34187 .41176 .33474 .40445 Mtetra
.628 .728 .919 r
.33474 .40445 .34187 .41176 .3532 .40929 .34613 .40152 Mtetra
.615 .711 .913 r
.34613 .40152 .3532 .40929 .36456 .40753 .35755 .39895 Mtetra
.599 .683 .901 r
.35755 .39895 .36456 .40753 .37593 .4067 .369 .39688 Mtetra
.582 .646 .879 r
.369 .39688 .37593 .4067 .38734 .40693 .3805 .39534 Mtetra
.572 .605 .847 r
.3805 .39534 .38734 .40693 .39878 .40806 .39204 .39424 Mtetra
.571 .567 .811 r
.39204 .39424 .39878 .40806 .41031 .40956 .40365 .39328 Mtetra
.579 .541 .776 r
.40365 .39328 .41031 .40956 .42193 .41061 .41534 .392 Mtetra
.593 .526 .749 r
.41534 .392 .42193 .41061 .43368 .41029 .42713 .3899 Mtetra
.611 .523 .73 r
.42713 .3899 .43368 .41029 .44556 .40782 .43901 .38657 Mtetra
.629 .528 .721 r
.43901 .38657 .44556 .40782 .45756 .40292 .45099 .38189 Mtetra
.645 .539 .72 r
.45099 .38189 .45756 .40292 .46964 .39584 .46303 .37604 Mtetra
.659 .556 .727 r
.46303 .37604 .46964 .39584 .48177 .38729 .47513 .36946 Mtetra
.67 .577 .742 r
.47513 .36946 .48177 .38729 .49392 .37821 .48726 .36273 Mtetra
.675 .603 .767 r
.48726 .36273 .49392 .37821 .50609 .3695 .49943 .35642 Mtetra
.671 .632 .802 r
.49943 .35642 .50609 .3695 .51828 .3619 .51162 .35104 Mtetra
.652 .661 .847 r
.51162 .35104 .51828 .3619 .53049 .35591 .52386 .34701 Mtetra
.604 .687 .901 r
.52386 .34701 .53049 .35591 .54276 .35179 .53617 .34463 Mtetra
.502 .695 .955 r
.53617 .34463 .54276 .35179 .5551 .34968 .54855 .34416 Mtetra
.302 .651 .97 r
.54855 .34416 .5551 .34968 .56753 .34961 .56105 .34575 Mtetra
0 .495 .849 r
.56105 .34575 .56753 .34961 .58009 .35149 .57368 .34944 Mtetra
.342 0 0 r
.57368 .34944 .58009 .35149 .5928 .35512 .58647 .35503 Mtetra
.527 0 0 r
.58647 .35503 .5928 .35512 .60565 .36007 .59942 .36205 Mtetra
.596 .045 0 r
.59942 .36205 .60565 .36007 .61866 .36568 .61255 .3697 Mtetra
.601 .079 0 r
.61255 .3697 .61866 .36568 .6318 .37106 .62581 .37691 Mtetra
.562 .062 .024 r
.62581 .37691 .6318 .37106 .64503 .37518 .63918 .38243 Mtetra
.482 0 .026 r
.63918 .38243 .64503 .37518 .6583 .37701 .65257 .38504 Mtetra
.347 0 0 r
.65257 .38504 .6583 .37701 .67153 .37568 .6659 .38378 Mtetra
.135 0 0 r
.6659 .38378 .67153 .37568 .68466 .37073 .67912 .37815 Mtetra
0 0 0 r
.67912 .37815 .68466 .37073 .69766 .36214 .69217 .36823 Mtetra
.69217 .36823 .69766 .36214 .7105 .35042 .70502 .3547 Mtetra
.734 .938 .61 r
.70502 .3547 .7105 .35042 .7232 .33645 .71771 .33866 Mtetra
.865 .984 .702 r
.71771 .33866 .7232 .33645 .7358 .32131 .73028 .32139 Mtetra
.914 .98 .76 r
.73028 .32139 .7358 .32131 .74837 .30609 .74281 .30416 Mtetra
.917 .954 .8 r
.74281 .30416 .74837 .30609 .76097 .29168 .75537 .28799 Mtetra
.895 .921 .831 r
.75537 .28799 .76097 .29168 .77365 .27867 .76802 .27353 Mtetra
.858 .886 .856 r
.76802 .27353 .77365 .27867 .78647 .26733 .78082 .26107 Mtetra
.817 .851 .875 r
.78082 .26107 .78647 .26733 .79944 .25765 .79378 .25057 Mtetra
.776 .82 .888 r
.79378 .25057 .79944 .25765 .81256 .24946 .80692 .24179 Mtetra
.74 .794 .896 r
.80692 .24179 .81256 .24946 .82584 .24245 .82021 .23439 Mtetra
.713 .775 .901 r
.82021 .23439 .82584 .24245 .83924 .2363 .83364 .22799 Mtetra
.649 .74 .916 r
.21601 .43068 .22348 .43753 .23439 .43417 .22695 .4273 Mtetra
.648 .74 .917 r
.22695 .4273 .23439 .43417 .24535 .43083 .23793 .42394 Mtetra
.647 .741 .918 r
.23793 .42394 .24535 .43083 .25635 .42749 .24896 .42059 Mtetra
.646 .741 .918 r
.24896 .42059 .25635 .42749 .2674 .42416 .26004 .41725 Mtetra
.646 .741 .919 r
.26004 .41725 .2674 .42416 .2785 .42083 .27117 .41391 Mtetra
.645 .741 .919 r
.27117 .41391 .2785 .42083 .28965 .41751 .28234 .41056 Mtetra
.645 .742 .92 r
.28234 .41056 .28965 .41751 .30085 .41418 .29357 .40721 Mtetra
.644 .742 .92 r
.29357 .40721 .30085 .41418 .3121 .41086 .30485 .40385 Mtetra
.643 .741 .92 r
.30485 .40385 .3121 .41086 .3234 .4076 .31618 .4005 Mtetra
.642 .739 .919 r
.31618 .4005 .3234 .4076 .33474 .40445 .32756 .39719 Mtetra
.638 .734 .918 r
.32756 .39719 .33474 .40445 .34613 .40152 .33899 .39397 Mtetra
.632 .724 .914 r
.33899 .39397 .34613 .40152 .35755 .39895 .35046 .3909 Mtetra
.625 .708 .906 r
.35046 .3909 .35755 .39895 .369 .39688 .36198 .38804 Mtetra
.617 .686 .892 r
.36198 .38804 .369 .39688 .3805 .39534 .37354 .38542 Mtetra
.612 .659 .871 r
.37354 .38542 .3805 .39534 .39204 .39424 .38516 .38296 Mtetra
.611 .63 .846 r
.38516 .38296 .39204 .39424 .40365 .39328 .39683 .38053 Mtetra
.614 .607 .82 r
.39683 .38053 .40365 .39328 .41534 .392 .40858 .37787 Mtetra
.622 .591 .797 r
.40858 .37787 .41534 .392 .42713 .3899 .4204 .37474 Mtetra
.632 .584 .781 r
.4204 .37474 .42713 .3899 .43901 .38657 .43231 .37095 Mtetra
.644 .585 .773 r
.43231 .37095 .43901 .38657 .45099 .38189 .44428 .36646 Mtetra
.655 .593 .773 r
.44428 .36646 .45099 .38189 .46303 .37604 .45632 .36139 Mtetra
.663 .606 .781 r
.45632 .36139 .46303 .37604 .47513 .36946 .4684 .35603 Mtetra
.668 .625 .797 r
.4684 .35603 .47513 .36946 .48726 .36273 .48053 .35072 Mtetra
.665 .647 .821 r
.48053 .35072 .48726 .36273 .49943 .35642 .4927 .34588 Mtetra
.651 .668 .854 r
.4927 .34588 .49943 .35642 .51162 .35104 .50492 .34188 Mtetra
.616 .686 .893 r
.50492 .34188 .51162 .35104 .52386 .34701 .51719 .33912 Mtetra
.545 .693 .936 r
.51719 .33912 .52386 .34701 .53617 .34463 .52952 .33797 Mtetra
.409 .669 .967 r
.52952 .33797 .53617 .34463 .54855 .34416 .54195 .33877 Mtetra
.167 .575 .935 r
.54195 .33877 .54855 .34416 .56105 .34575 .55449 .34177 Mtetra
0 .378 .763 r
.55449 .34177 .56105 .34575 .57368 .34944 .56718 .34703 Mtetra
.438 0 0 r
.56718 .34703 .57368 .34944 .58647 .35503 .58004 .35435 Mtetra
.585 .009 0 r
.58004 .35435 .58647 .35503 .59942 .36205 .59308 .36317 Mtetra
.636 .085 0 r
.59308 .36317 .59942 .36205 .61255 .3697 .6063 .37255 Mtetra
.63 .097 0 r
.6063 .37255 .61255 .3697 .62581 .37691 .61967 .38122 Mtetra
.577 .054 0 r
.61967 .38122 .62581 .37691 .63918 .38243 .63314 .38776 Mtetra
.467 0 0 r
.63314 .38776 .63918 .38243 .65257 .38504 .64664 .39081 Mtetra
.262 0 0 r
.64664 .39081 .65257 .38504 .6659 .38378 .66006 .38933 Mtetra
0 0 0 r
.66006 .38933 .6659 .38378 .67912 .37815 .67334 .38286 Mtetra
.484 .833 .559 r
.67334 .38286 .67912 .37815 .69217 .36823 .68643 .37158 Mtetra
.768 .968 .676 r
.68643 .37158 .69217 .36823 .70502 .3547 .6993 .35636 Mtetra
.895 .985 .722 r
.6993 .35636 .70502 .3547 .71771 .33866 .71199 .33847 Mtetra
.937 .964 .744 r
.71199 .33847 .71771 .33866 .73028 .32139 .72455 .3194 Mtetra
.941 .936 .763 r
.72455 .3194 .73028 .32139 .74281 .30416 .73707 .30054 Mtetra
.925 .909 .786 r
.73707 .30054 .74281 .30416 .75537 .28799 .74961 .28298 Mtetra
.898 .884 .811 r
.74961 .28298 .75537 .28799 .76802 .27353 .76226 .26741 Mtetra
.861 .858 .836 r
.76226 .26741 .76802 .27353 .78082 .26107 .77506 .25411 Mtetra
.821 .833 .858 r
.77506 .25411 .78082 .26107 .79378 .25057 .78804 .243 Mtetra
.78 .809 .876 r
.78804 .243 .79378 .25057 .80692 .24179 .80119 .23379 Mtetra
.745 .788 .888 r
.80119 .23379 .80692 .24179 .82021 .23439 .81451 .2261 Mtetra
.716 .772 .896 r
.81451 .2261 .82021 .23439 .83364 .22799 .82798 .21951 Mtetra
.649 .74 .916 r
.20849 .42376 .21601 .43068 .22695 .4273 .21945 .42036 Mtetra
.648 .74 .916 r
.21945 .42036 .22695 .4273 .23793 .42394 .23046 .41698 Mtetra
.647 .74 .917 r
.23046 .41698 .23793 .42394 .24896 .42059 .24152 .41361 Mtetra
.646 .74 .918 r
.24152 .41361 .24896 .42059 .26004 .41725 .25262 .41025 Mtetra
.645 .74 .918 r
.25262 .41025 .26004 .41725 .27117 .41391 .26377 .40689 Mtetra
.26377 .40689 .27117 .41391 .28234 .41056 .27498 .40352 Mtetra
.645 .74 .919 r
.27498 .40352 .28234 .41056 .29357 .40721 .28623 .40014 Mtetra
.645 .741 .919 r
.28623 .40014 .29357 .40721 .30485 .40385 .29754 .39675 Mtetra
.644 .74 .919 r
.29754 .39675 .30485 .40385 .31618 .4005 .3089 .39335 Mtetra
.644 .739 .918 r
.3089 .39335 .31618 .4005 .32756 .39719 .32031 .38994 Mtetra
.643 .737 .917 r
.32031 .38994 .32756 .39719 .33899 .39397 .33178 .38654 Mtetra
.641 .732 .915 r
.33178 .38654 .33899 .39397 .35046 .3909 .34329 .38318 Mtetra
.639 .724 .91 r
.34329 .38318 .35046 .3909 .36198 .38804 .35486 .37988 Mtetra
.636 .712 .902 r
.35486 .37988 .36198 .38804 .37354 .38542 .36648 .37664 Mtetra
.635 .696 .89 r
.36648 .37664 .37354 .38542 .38516 .38296 .37815 .37344 Mtetra
.635 .679 .874 r
.37815 .37344 .38516 .38296 .39683 .38053 .38988 .37019 Mtetra
.638 .663 .858 r
.38988 .37019 .39683 .38053 .40858 .37787 .40167 .36679 Mtetra
.643 .651 .843 r
.40167 .36679 .40858 .37787 .4204 .37474 .41353 .36311 Mtetra
.649 .644 .831 r
.41353 .36311 .4204 .37474 .43231 .37095 .42546 .35909 Mtetra
.656 .644 .826 r
.42546 .35909 .43231 .37095 .44428 .36646 .43745 .35472 Mtetra
.662 .649 .827 r
.43745 .35472 .44428 .36646 .45632 .36139 .44949 .3501 Mtetra
.665 .659 .834 r
.44949 .3501 .45632 .36139 .4684 .35603 .46159 .3454 Mtetra
.664 .672 .848 r
.46159 .3454 .4684 .35603 .48053 .35072 .47373 .34089 Mtetra
.654 .685 .867 r
.47373 .34089 .48053 .35072 .4927 .34588 .48592 .33685 Mtetra
.63 .696 .893 r
.48592 .33685 .4927 .34588 .50492 .34188 .49816 .33365 Mtetra
.583 .699 .923 r
.49816 .33365 .50492 .34188 .51719 .33912 .51045 .33168 Mtetra
.495 .686 .952 r
.51045 .33168 .51719 .33912 .52952 .33797 .52282 .33135 Mtetra
.339 .635 .962 r
.52282 .33135 .52952 .33797 .54195 .33877 .53528 .33306 Mtetra
.09 .514 .905 r
.53528 .33306 .54195 .33877 .55449 .34177 .54786 .33711 Mtetra
0 .317 .736 r
.54786 .33711 .55449 .34177 .56718 .34703 .56059 .34356 Mtetra
.455 0 0 r
.56059 .34356 .56718 .34703 .58004 .35435 .5735 .35217 Mtetra
.587 .016 0 r
.5735 .35217 .58004 .35435 .59308 .36317 .58661 .3623 Mtetra
.635 .072 0 r
.58661 .3623 .59308 .36317 .6063 .37255 .5999 .37285 Mtetra
.622 .059 0 r
.5999 .37285 .6063 .37255 .61967 .38122 .61335 .38243 Mtetra
.544 0 0 r
.61335 .38243 .61967 .38122 .63314 .38776 .62689 .38946 Mtetra
.356 0 0 r
.62689 .38946 .63314 .38776 .64664 .39081 .64045 .39251 Mtetra
0 0 0 r
.64045 .39251 .64664 .39081 .66006 .38933 .65394 .39052 Mtetra
.535 .922 .817 r
.65394 .39052 .66006 .38933 .67334 .38286 .66727 .38311 Mtetra
.82 .999 .836 r
.66727 .38311 .67334 .38286 .68643 .37158 .68039 .37061 Mtetra
.915 .966 .795 r
.68039 .37061 .68643 .37158 .6993 .35636 .69329 .35402 Mtetra
.94 .924 .765 r
.69329 .35402 .6993 .35636 .71199 .33847 .70599 .33477 Mtetra
.941 .892 .753 r
.70599 .33477 .71199 .33847 .72455 .3194 .71857 .31447 Mtetra
.93 .87 .757 r
.71857 .31447 .72455 .3194 .73707 .30054 .7311 .29456 Mtetra
.911 .853 .772 r
.7311 .29456 .73707 .30054 .74961 .28298 .74367 .27617 Mtetra
.886 .838 .794 r
.74367 .27617 .74961 .28298 .76226 .26741 .75635 .25998 Mtetra
.853 .824 .819 r
.75635 .25998 .76226 .26741 .77506 .25411 .76918 .24622 Mtetra
.817 .809 .844 r
.76918 .24622 .77506 .25411 .78804 .243 .78219 .23479 Mtetra
.779 .794 .865 r
.78219 .23479 .78804 .243 .80119 .23379 .79538 .22537 Mtetra
.745 .779 .881 r
.79538 .22537 .80119 .23379 .81451 .2261 .80874 .21753 Mtetra
.717 .766 .892 r
.80874 .21753 .81451 .2261 .82798 .21951 .82226 .21084 Mtetra
.649 .739 .915 r
.20091 .41676 .20849 .42376 .21945 .42036 .2119 .41334 Mtetra
.647 .739 .916 r
.2119 .41334 .21945 .42036 .23046 .41698 .22293 .40994 Mtetra
.646 .739 .917 r
.22293 .40994 .23046 .41698 .24152 .41361 .23401 .40654 Mtetra
.23401 .40654 .24152 .41361 .25262 .41025 .24514 .40316 Mtetra
.645 .739 .917 r
.24514 .40316 .25262 .41025 .26377 .40689 .25632 .39977 Mtetra
.645 .739 .918 r
.25632 .39977 .26377 .40689 .27498 .40352 .26756 .39638 Mtetra
.26756 .39638 .27498 .40352 .28623 .40014 .27884 .39298 Mtetra
.27884 .39298 .28623 .40014 .29754 .39675 .29017 .38956 Mtetra
.29017 .38956 .29754 .39675 .3089 .39335 .30156 .38611 Mtetra
.645 .739 .917 r
.30156 .38611 .3089 .39335 .32031 .38994 .31301 .38264 Mtetra
.646 .738 .917 r
.31301 .38264 .32031 .38994 .33178 .38654 .32451 .37914 Mtetra
.646 .736 .915 r
.32451 .37914 .33178 .38654 .34329 .38318 .33606 .37562 Mtetra
.646 .733 .912 r
.33606 .37562 .34329 .38318 .35486 .37988 .34766 .37208 Mtetra
.646 .727 .908 r
.34766 .37208 .35486 .37988 .36648 .37664 .35932 .36853 Mtetra
.647 .719 .901 r
.35932 .36853 .36648 .37664 .37815 .37344 .37104 .36494 Mtetra
.648 .711 .893 r
.37104 .36494 .37815 .37344 .38988 .37019 .38281 .36128 Mtetra
.651 .702 .884 r
.38281 .36128 .38988 .37019 .40167 .36679 .39465 .35749 Mtetra
.654 .695 .875 r
.39465 .35749 .40167 .36679 .41353 .36311 .40654 .35354 Mtetra
.659 .691 .869 r
.40654 .35354 .41353 .36311 .42546 .35909 .4185 .3494 Mtetra
.662 .69 .866 r
.4185 .3494 .42546 .35909 .43745 .35472 .43051 .34509 Mtetra
.665 .693 .867 r
.43051 .34509 .43745 .35472 .44949 .3501 .44258 .34069 Mtetra
.664 .699 .872 r
.44258 .34069 .44949 .3501 .46159 .3454 .45469 .33632 Mtetra
.658 .705 .882 r
.45469 .33632 .46159 .3454 .47373 .34089 .46686 .33219 Mtetra
.643 .71 .896 r
.46686 .33219 .47373 .34089 .48592 .33685 .47907 .32855 Mtetra
.614 .711 .914 r
.47907 .32855 .48592 .33685 .49816 .33365 .49134 .32576 Mtetra
.56 .702 .936 r
.49134 .32576 .49816 .33365 .51045 .33168 .50366 .32421 Mtetra
.467 .674 .954 r
.50366 .32421 .51045 .33168 .52282 .33135 .51605 .32435 Mtetra
.312 .609 .953 r
.51605 .32435 .52282 .33135 .53528 .33306 .52854 .3266 Mtetra
.084 .486 .896 r
.52854 .3266 .53528 .33306 .54786 .33711 .54115 .33126 Mtetra
0 .313 .764 r
.54115 .33126 .54786 .33711 .56059 .34356 .55391 .33839 Mtetra
0 .148 .601 r
.55391 .33839 .56059 .34356 .5735 .35217 .56686 .3477 Mtetra
.508 0 0 r
.56686 .3477 .5735 .35217 .58661 .3623 .58 .35844 Mtetra
.544 0 0 r
.58 .35844 .58661 .3623 .5999 .37285 .59333 .36945 Mtetra
.498 0 0 r
.59333 .36945 .5999 .37285 .61335 .38243 .60681 .37922 Mtetra
.328 0 0 r
.60681 .37922 .61335 .38243 .62689 .38946 .62039 .38612 Mtetra
.049 .566 .873 r
.62039 .38612 .62689 .38946 .64045 .39251 .63399 .3887 Mtetra
.513 .835 .999 r
.63399 .3887 .64045 .39251 .65394 .39052 .6475 .38598 Mtetra
.769 .892 .932 r
.6475 .38598 .65394 .39052 .66727 .38311 .66086 .37768 Mtetra
.862 .869 .843 r
.66086 .37768 .66727 .38311 .68039 .37061 .67401 .36424 Mtetra
.895 .841 .784 r
.67401 .36424 .68039 .37061 .69329 .35402 .68694 .3468 Mtetra
.905 .82 .753 r
.68694 .3468 .69329 .35402 .70599 .33477 .69969 .32687 Mtetra
.904 .807 .741 r
.69969 .32687 .70599 .33477 .71857 .31447 .71232 .30607 Mtetra
.897 .8 .744 r
.71232 .30607 .71857 .31447 .7311 .29456 .72491 .28586 Mtetra
.883 .795 .758 r
.72491 .28586 .7311 .29456 .74367 .27617 .73754 .26732 Mtetra
.863 .792 .779 r
.73754 .26732 .74367 .27617 .75635 .25998 .75028 .25107 Mtetra
.837 .789 .806 r
.75028 .25107 .75635 .25998 .76918 .24622 .76317 .23731 Mtetra
.806 .784 .832 r
.76317 .23731 .76918 .24622 .78219 .23479 .77624 .2259 Mtetra
.772 .776 .856 r
.77624 .2259 .78219 .23479 .79538 .22537 .78949 .2165 Mtetra
.741 .768 .875 r
.78949 .2165 .79538 .22537 .80874 .21753 .80291 .20867 Mtetra
.714 .76 .888 r
.80291 .20867 .80874 .21753 .82226 .21084 .81647 .20197 Mtetra
.648 .738 .915 r
.19328 .40968 .20091 .41676 .2119 .41334 .20429 .40623 Mtetra
.647 .738 .915 r
.20429 .40623 .2119 .41334 .22293 .40994 .21535 .4028 Mtetra
.646 .738 .916 r
.21535 .4028 .22293 .40994 .23401 .40654 .22646 .39939 Mtetra
.22646 .39939 .23401 .40654 .24514 .40316 .23761 .39597 Mtetra
.645 .738 .917 r
.23761 .39597 .24514 .40316 .25632 .39977 .24882 .39256 Mtetra
.24882 .39256 .25632 .39977 .26756 .39638 .26008 .38914 Mtetra
.26008 .38914 .26756 .39638 .27884 .39298 .27139 .38571 Mtetra
.27139 .38571 .27884 .39298 .29017 .38956 .28275 .38226 Mtetra
.28275 .38226 .29017 .38956 .30156 .38611 .29417 .37877 Mtetra
.646 .738 .916 r
.29417 .37877 .30156 .38611 .31301 .38264 .30565 .37525 Mtetra
.647 .738 .916 r
.30565 .37525 .31301 .38264 .32451 .37914 .31717 .37169 Mtetra
.648 .737 .915 r
.31717 .37169 .32451 .37914 .33606 .37562 .32876 .36808 Mtetra
.649 .736 .913 r
.32876 .36808 .33606 .37562 .34766 .37208 .3404 .36442 Mtetra
.65 .734 .91 r
.3404 .36442 .34766 .37208 .35932 .36853 .3521 .36071 Mtetra
.652 .731 .907 r
.3521 .36071 .35932 .36853 .37104 .36494 .36385 .35693 Mtetra
.654 .727 .903 r
.36385 .35693 .37104 .36494 .38281 .36128 .37566 .35306 Mtetra
.657 .723 .898 r
.37566 .35306 .38281 .36128 .39465 .35749 .38753 .34909 Mtetra
.66 .72 .894 r
.38753 .34909 .39465 .35749 .40654 .35354 .39946 .34501 Mtetra
.662 .719 .89 r
.39946 .34501 .40654 .35354 .4185 .3494 .41145 .3408 Mtetra
.664 .719 .889 r
.41145 .3408 .4185 .3494 .43051 .34509 .42349 .33651 Mtetra
.665 .72 .89 r
.42349 .33651 .43051 .34509 .44258 .34069 .43558 .33218 Mtetra
.662 .722 .893 r
.43558 .33218 .44258 .34069 .45469 .33632 .44773 .32794 Mtetra
.654 .723 .9 r
.44773 .32794 .45469 .33632 .46686 .33219 .45992 .32395 Mtetra
.637 .722 .91 r
.45992 .32395 .46686 .33219 .47907 .32855 .47216 .32048 Mtetra
.606 .716 .923 r
.47216 .32048 .47907 .32855 .49134 .32576 .48446 .31783 Mtetra
.552 .699 .938 r
.48446 .31783 .49134 .32576 .50366 .32421 .49681 .31643 Mtetra
.463 .664 .949 r
.49681 .31643 .50366 .32421 .51605 .32435 .50923 .31671 Mtetra
.325 .597 .944 r
.50923 .31671 .51605 .32435 .52854 .3266 .52174 .3191 Mtetra
.137 .488 .902 r
.52174 .3191 .52854 .3266 .54115 .33126 .53437 .32389 Mtetra
0 .35 .817 r
.53437 .32389 .54115 .33126 .55391 .33839 .54715 .3311 Mtetra
0 .227 .722 r
.54715 .3311 .55391 .33839 .56686 .3477 .56011 .34039 Mtetra
0 .16 .664 r
.56011 .34039 .56686 .3477 .58 .35844 .57326 .35097 Mtetra
0 .169 .676 r
.57326 .35097 .58 .35844 .59333 .36945 .58659 .36163 Mtetra
0 .269 .762 r
.58659 .36163 .59333 .36945 .60681 .37922 .60008 .37083 Mtetra
.106 .444 .88 r
.60008 .37083 .60681 .37922 .62039 .38612 .61366 .37699 Mtetra
.411 .609 .93 r
.61366 .37699 .62039 .38612 .63399 .3887 .62725 .37871 Mtetra
.629 .694 .892 r
.62725 .37871 .63399 .3887 .6475 .38598 .64077 .37515 Mtetra
.747 .722 .829 r
.64077 .37515 .6475 .38598 .66086 .37768 .65414 .36611 Mtetra
.806 .729 .779 r
.65414 .36611 .66086 .37768 .67401 .36424 .66732 .35219 Mtetra
.837 .73 .747 r
.66732 .35219 .67401 .36424 .68694 .3468 .6803 .33454 Mtetra
.852 .732 .729 r
.6803 .33454 .68694 .3468 .69969 .32687 .69311 .3147 Mtetra
.859 .735 .725 r
.69311 .3147 .69969 .32687 .71232 .30607 .70582 .29422 Mtetra
.858 .739 .731 r
.70582 .29422 .71232 .30607 .72491 .28586 .71849 .27449 Mtetra
.851 .745 .747 r
.71849 .27449 .72491 .28586 .73754 .26732 .73122 .25647 Mtetra
.837 .752 .769 r
.73122 .25647 .73754 .26732 .75028 .25107 .74405 .24073 Mtetra
.817 .757 .797 r
.74405 .24073 .75028 .25107 .76317 .23731 .75704 .22742 Mtetra
.791 .76 .825 r
.75704 .22742 .76317 .23731 .77624 .2259 .77019 .21636 Mtetra
.762 .759 .85 r
.77019 .21636 .77624 .2259 .78949 .2165 .78352 .2072 Mtetra
.734 .757 .871 r
.78352 .2072 .78949 .2165 .80291 .20867 .797 .19952 Mtetra
.71 .753 .885 r
.797 .19952 .80291 .20867 .81647 .20197 .81063 .19291 Mtetra
.648 .738 .914 r
.18558 .40252 .19328 .40968 .20429 .40623 .19662 .39905 Mtetra
.647 .737 .915 r
.19662 .39905 .20429 .40623 .21535 .4028 .20771 .39559 Mtetra
.646 .737 .915 r
.20771 .39559 .21535 .4028 .22646 .39939 .21884 .39214 Mtetra
.646 .737 .916 r
.21884 .39214 .22646 .39939 .23761 .39597 .23002 .38869 Mtetra
.645 .737 .916 r
.23002 .38869 .23761 .39597 .24882 .39256 .24126 .38525 Mtetra
.24126 .38525 .24882 .39256 .26008 .38914 .25254 .3818 Mtetra
.645 .736 .916 r
.25254 .3818 .26008 .38914 .27139 .38571 .26388 .37833 Mtetra
.645 .737 .916 r
.26388 .37833 .27139 .38571 .28275 .38226 .27528 .37485 Mtetra
.645 .737 .915 r
.27528 .37485 .28275 .38226 .29417 .37877 .28672 .37133 Mtetra
.646 .737 .915 r
.28672 .37133 .29417 .37877 .30565 .37525 .29823 .36777 Mtetra
.647 .737 .914 r
.29823 .36777 .30565 .37525 .31717 .37169 .30979 .36416 Mtetra
.649 .737 .914 r
.30979 .36416 .31717 .37169 .32876 .36808 .3214 .36049 Mtetra
.65 .737 .912 r
.3214 .36049 .32876 .36808 .3404 .36442 .33307 .35676 Mtetra
.652 .736 .911 r
.33307 .35676 .3404 .36442 .3521 .36071 .34481 .35296 Mtetra
.654 .735 .909 r
.34481 .35296 .3521 .36071 .36385 .35693 .35659 .34908 Mtetra
.657 .734 .907 r
.35659 .34908 .36385 .35693 .37566 .35306 .36844 .34511 Mtetra
.659 .733 .904 r
.36844 .34511 .37566 .35306 .38753 .34909 .38034 .34105 Mtetra
.661 .732 .902 r
.38034 .34105 .38753 .34909 .39946 .34501 .3923 .33689 Mtetra
.664 .732 .9 r
.3923 .33689 .39946 .34501 .41145 .3408 .40432 .33264 Mtetra
.665 .732 .9 r
.40432 .33264 .41145 .3408 .42349 .33651 .4164 .32832 Mtetra
.664 .732 .9 r
.4164 .32832 .42349 .33651 .43558 .33218 .42852 .32401 Mtetra
.661 .732 .902 r
.42852 .32401 .43558 .33218 .44773 .32794 .4407 .31979 Mtetra
.652 .731 .907 r
.4407 .31979 .44773 .32794 .45992 .32395 .45293 .31582 Mtetra
.635 .726 .914 r
.45293 .31582 .45992 .32395 .47216 .32048 .4652 .31234 Mtetra
.606 .716 .923 r
.4652 .31234 .47216 .32048 .48446 .31783 .47752 .30966 Mtetra
.556 .696 .933 r
.47752 .30966 .48446 .31783 .49681 .31643 .4899 .30818 Mtetra
.478 .659 .94 r
.4899 .30818 .49681 .31643 .50923 .31671 .50235 .30831 Mtetra
.364 .596 .935 r
.50235 .30831 .50923 .31671 .52174 .3191 .51489 .31045 Mtetra
.222 .506 .907 r
.51489 .31045 .52174 .3191 .53437 .32389 .52753 .31486 Mtetra
.08 .404 .858 r
.52753 .31486 .53437 .32389 .54715 .3311 .54032 .32154 Mtetra
0 .32 .808 r
.54032 .32154 .54715 .3311 .56011 .34039 .55327 .3301 Mtetra
0 .284 .786 r
.55327 .3301 .56011 .34039 .57326 .35097 .56641 .33976 Mtetra
.022 .308 .798 r
.56641 .33976 .57326 .35097 .58659 .36163 .57972 .34931 Mtetra
.17 .382 .828 r
.57972 .34931 .58659 .36163 .60008 .37083 .59318 .35728 Mtetra
.354 .473 .842 r
.59318 .35728 .60008 .37083 .61366 .37699 .60673 .36219 Mtetra
.517 .547 .825 r
.60673 .36219 .61366 .37699 .62725 .37871 .62029 .36279 Mtetra
.634 .595 .792 r
.62029 .36279 .62725 .37871 .64077 .37515 .63379 .35838 Mtetra
.71 .624 .759 r
.63379 .35838 .64077 .37515 .65414 .36611 .64716 .34891 Mtetra
.758 .643 .734 r
.64716 .34891 .65414 .36611 .66732 .35219 .66037 .33501 Mtetra
.788 .656 .718 r
.66037 .33501 .66732 .35219 .6803 .33454 .6734 .31783 Mtetra
.807 .669 .711 r
.6734 .31783 .6803 .33454 .69311 .3147 .6863 .29882 Mtetra
.817 .681 .713 r
.6863 .29882 .69311 .3147 .70582 .29422 .69911 .27942 Mtetra
.821 .693 .723 r
.69911 .27942 .70582 .29422 .71849 .27449 .7119 .26085 Mtetra
.819 .706 .741 r
.7119 .26085 .71849 .27449 .73122 .25647 .72475 .24396 Mtetra
.81 .719 .765 r
.72475 .24396 .73122 .25647 .74405 .24073 .73771 .22922 Mtetra
.794 .73 .793 r
.73771 .22922 .74405 .24073 .75704 .22742 .7508 .21671 Mtetra
.773 .739 .822 r
.7508 .21671 .75704 .22742 .77019 .21636 .76406 .20627 Mtetra
.749 .745 .848 r
.76406 .20627 .77019 .21636 .78352 .2072 .77747 .19754 Mtetra
.725 .747 .869 r
.77747 .19754 .78352 .2072 .797 .19952 .79103 .19014 Mtetra
.704 .746 .884 r
.79103 .19014 .797 .19952 .81063 .19291 .80472 .18368 Mtetra
.649 .737 .914 r
.17783 .39528 .18558 .40252 .19662 .39905 .18889 .39177 Mtetra
.648 .737 .914 r
.18889 .39177 .19662 .39905 .20771 .39559 .20001 .38828 Mtetra
.647 .736 .914 r
.20001 .38828 .20771 .39559 .21884 .39214 .21117 .38479 Mtetra
.646 .736 .915 r
.21117 .38479 .21884 .39214 .23002 .38869 .22238 .38132 Mtetra
.645 .736 .915 r
.22238 .38132 .23002 .38869 .24126 .38525 .23364 .37784 Mtetra
.645 .735 .915 r
.23364 .37784 .24126 .38525 .25254 .3818 .24495 .37435 Mtetra
.24495 .37435 .25254 .3818 .26388 .37833 .25632 .37085 Mtetra
.25632 .37085 .26388 .37833 .27528 .37485 .26774 .36732 Mtetra
.646 .735 .914 r
.26774 .36732 .27528 .37485 .28672 .37133 .27922 .36377 Mtetra
.647 .735 .914 r
.27922 .36377 .28672 .37133 .29823 .36777 .29075 .36017 Mtetra
.648 .735 .913 r
.29075 .36017 .29823 .36777 .30979 .36416 .30234 .35651 Mtetra
.649 .736 .912 r
.30234 .35651 .30979 .36416 .3214 .36049 .31399 .3528 Mtetra
.651 .736 .911 r
.31399 .3528 .3214 .36049 .33307 .35676 .32569 .34902 Mtetra
.653 .736 .91 r
.32569 .34902 .33307 .35676 .34481 .35296 .33745 .34517 Mtetra
.655 .736 .909 r
.33745 .34517 .34481 .35296 .35659 .34908 .34927 .34123 Mtetra
.658 .736 .907 r
.34927 .34123 .35659 .34908 .36844 .34511 .36115 .3372 Mtetra
.66 .736 .906 r
.36115 .3372 .36844 .34511 .38034 .34105 .37309 .33308 Mtetra
.662 .736 .905 r
.37309 .33308 .38034 .34105 .3923 .33689 .38508 .32886 Mtetra
.664 .736 .904 r
.38508 .32886 .3923 .33689 .40432 .33264 .39714 .32457 Mtetra
.665 .736 .903 r
.39714 .32457 .40432 .33264 .4164 .32832 .40924 .32023 Mtetra
.40924 .32023 .4164 .32832 .42852 .32401 .4214 .31588 Mtetra
.661 .735 .905 r
.4214 .31588 .42852 .32401 .4407 .31979 .43361 .31162 Mtetra
.653 .733 .908 r
.43361 .31162 .4407 .31979 .45293 .31582 .44587 .3076 Mtetra
.638 .727 .913 r
.44587 .3076 .45293 .31582 .4652 .31234 .45818 .30402 Mtetra
.611 .715 .919 r
.45818 .30402 .4652 .31234 .47752 .30966 .47054 .30118 Mtetra
.568 .694 .926 r
.47054 .30118 .47752 .30966 .4899 .30818 .48295 .29943 Mtetra
.504 .658 .93 r
.48295 .29943 .4899 .30818 .50235 .30831 .49542 .29915 Mtetra
.416 .603 .924 r
.49542 .29915 .50235 .30831 .51489 .31045 .50798 .30071 Mtetra
.314 .531 .904 r
.50798 .30071 .51489 .31045 .52753 .31486 .52064 .30431 Mtetra
.222 .454 .872 r
.52064 .30431 .52753 .31486 .54032 .32154 .53343 .30991 Mtetra
.168 .395 .839 r
.53343 .30991 .54032 .32154 .55327 .3301 .54637 .31715 Mtetra
.174 .37 .817 r
.54637 .31715 .55327 .3301 .56641 .33976 .55948 .32524 Mtetra
.24 .383 .807 r
.55948 .32524 .56641 .33976 .57972 .34931 .57275 .33308 Mtetra
.344 .422 .799 r
.57275 .33308 .57972 .34931 .59318 .35728 .58616 .33933 Mtetra
.456 .469 .784 r
.58616 .33933 .59318 .35728 .60673 .36219 .59965 .34267 Mtetra
.554 .512 .763 r
.59965 .34267 .60673 .36219 .62029 .36279 .61317 .34205 Mtetra
.63 .545 .741 r
.61317 .34205 .62029 .36279 .63379 .35838 .62664 .33693 Mtetra
.685 .571 .722 r
.62664 .33693 .63379 .35838 .64716 .34891 .64 .32735 Mtetra
.724 .592 .708 r
.64 .32735 .64716 .34891 .66037 .33501 .65323 .31395 Mtetra
.752 .61 .701 r
.65323 .31395 .66037 .33501 .6734 .31783 .66633 .29783 Mtetra
.771 .627 .701 r
.66633 .29783 .6734 .31783 .6863 .29882 .67932 .28027 Mtetra
.783 .643 .707 r
.67932 .28027 .6863 .29882 .69911 .27942 .69226 .26253 Mtetra
.79 .66 .72 r
.69226 .26253 .69911 .27942 .7119 .26085 .70519 .24564 Mtetra
.79 .678 .74 r
.70519 .24564 .7119 .26085 .72475 .24396 .71818 .23032 Mtetra
.784 .695 .765 r
.71818 .23032 .72475 .24396 .73771 .22922 .73127 .21691 Mtetra
.773 .711 .794 r
.73127 .21691 .73771 .22922 .7508 .21671 .74449 .20547 Mtetra
.756 .724 .823 r
.74449 .20547 .7508 .21671 .76406 .20627 .75785 .19581 Mtetra
.735 .733 .849 r
.75785 .19581 .76406 .20627 .77747 .19754 .77135 .18762 Mtetra
.715 .739 .87 r
.77135 .18762 .77747 .19754 .79103 .19014 .78499 .18057 Mtetra
.698 .741 .885 r
.78499 .18057 .79103 .19014 .80472 .18368 .79876 .17432 Mtetra
.649 .736 .913 r
.17002 .38797 .17783 .39528 .18889 .39177 .18111 .38442 Mtetra
.648 .736 .914 r
.18111 .38442 .18889 .39177 .20001 .38828 .19225 .38088 Mtetra
.647 .736 .914 r
.19225 .38088 .20001 .38828 .21117 .38479 .20344 .37736 Mtetra
.646 .735 .914 r
.20344 .37736 .21117 .38479 .22238 .38132 .21467 .37384 Mtetra
.21467 .37384 .22238 .38132 .23364 .37784 .22596 .37032 Mtetra
.645 .734 .914 r
.22596 .37032 .23364 .37784 .24495 .37435 .23731 .36679 Mtetra
.23731 .36679 .24495 .37435 .25632 .37085 .2487 .36325 Mtetra
.645 .734 .913 r
.2487 .36325 .25632 .37085 .26774 .36732 .26015 .35969 Mtetra
.646 .734 .913 r
.26015 .35969 .26774 .36732 .27922 .36377 .27166 .35609 Mtetra
.647 .734 .912 r
.27166 .35609 .27922 .36377 .29075 .36017 .28322 .35244 Mtetra
.648 .734 .912 r
.28322 .35244 .29075 .36017 .30234 .35651 .29484 .34875 Mtetra
.65 .734 .911 r
.29484 .34875 .30234 .35651 .31399 .3528 .30651 .345 Mtetra
.651 .734 .91 r
.30651 .345 .31399 .3528 .32569 .34902 .31825 .34117 Mtetra
.653 .735 .909 r
.31825 .34117 .32569 .34902 .33745 .34517 .33004 .33727 Mtetra
.656 .735 .908 r
.33004 .33727 .33745 .34517 .34927 .34123 .3419 .33328 Mtetra
.658 .735 .907 r
.3419 .33328 .34927 .34123 .36115 .3372 .35381 .32921 Mtetra
.66 .736 .906 r
.35381 .32921 .36115 .3372 .37309 .33308 .36578 .32504 Mtetra
.662 .736 .905 r
.36578 .32504 .37309 .33308 .38508 .32886 .3778 .32079 Mtetra
.664 .737 .904 r
.3778 .32079 .38508 .32886 .39714 .32457 .38989 .31646 Mtetra
.665 .737 .903 r
.38989 .31646 .39714 .32457 .40924 .32023 .40203 .31207 Mtetra
.40203 .31207 .40924 .32023 .4214 .31588 .41422 .30768 Mtetra
.662 .735 .904 r
.41422 .30768 .4214 .31588 .43361 .31162 .42647 .30336 Mtetra
.655 .732 .906 r
.42647 .30336 .43361 .31162 .44587 .3076 .43876 .29923 Mtetra
.642 .726 .909 r
.43876 .29923 .44587 .3076 .45818 .30402 .45111 .29549 Mtetra
.619 .714 .914 r
.45111 .29549 .45818 .30402 .47054 .30118 .4635 .29239 Mtetra
.584 .694 .918 r
.4635 .29239 .47054 .30118 .48295 .29943 .47594 .29024 Mtetra
.534 .662 .919 r
.47594 .29024 .48295 .29943 .49542 .29915 .48845 .28937 Mtetra
.468 .615 .912 r
.48845 .28937 .49542 .29915 .50798 .30071 .50103 .29008 Mtetra
.397 .556 .896 r
.50103 .29008 .50798 .30071 .52064 .30431 .5137 .29254 Mtetra
.337 .496 .869 r
.5137 .29254 .52064 .30431 .53343 .30991 .52649 .29669 Mtetra
.308 .449 .84 r
.52649 .29669 .53343 .30991 .54637 .31715 .53942 .30217 Mtetra
.319 .425 .813 r
.53942 .30217 .54637 .31715 .55948 .32524 .5525 .30829 Mtetra
.367 .426 .79 r
.5525 .30829 .55948 .32524 .57275 .33308 .56572 .31405 Mtetra
.435 .444 .77 r
.56572 .31405 .57275 .33308 .58616 .33933 .57907 .31831 Mtetra
.507 .47 .75 r
.57907 .31831 .58616 .33933 .59965 .34267 .5925 .31997 Mtetra
.573 .497 .731 r
.5925 .31997 .59965 .34267 .61317 .34205 .60596 .31818 Mtetra
.626 .522 .716 r
.60596 .31818 .61317 .34205 .62664 .33693 .61939 .31254 Mtetra
.669 .544 .704 r
.61939 .31254 .62664 .33693 .64 .32735 .63275 .30317 Mtetra
.701 .564 .697 r
.63275 .30317 .64 .32735 .65323 .31395 .64601 .29069 Mtetra
.726 .583 .695 r
.64601 .29069 .65323 .31395 .66633 .29783 .65918 .27604 Mtetra
.744 .601 .699 r
.65918 .27604 .66633 .29783 .67932 .28027 .67227 .26033 Mtetra
.757 .62 .708 r
.67227 .26033 .67932 .28027 .69226 .26253 .68533 .2446 Mtetra
.764 .64 .724 r
.68533 .2446 .69226 .26253 .70519 .24564 .69841 .22969 Mtetra
.766 .66 .745 r
.69841 .22969 .70519 .24564 .71818 .23032 .71154 .21614 Mtetra
.762 .68 .772 r
.71154 .21614 .71818 .23032 .73127 .21691 .72477 .20423 Mtetra
.753 .699 .8 r
.72477 .20423 .73127 .21691 .74449 .20547 .73811 .19396 Mtetra
.739 .714 .829 r
.73811 .19396 .74449 .20547 .75785 .19581 .75158 .18516 Mtetra
.722 .726 .853 r
.75158 .18516 .75785 .19581 .77135 .18762 .76519 .17757 Mtetra
.705 .734 .873 r
.76519 .17757 .77135 .18762 .78499 .18057 .77891 .17089 Mtetra
.691 .738 .887 r
.77891 .17089 .78499 .18057 .79876 .17432 .79274 .16486 Mtetra
.649 .736 .913 r
.16214 .38057 .17002 .38797 .18111 .38442 .17326 .37698 Mtetra
.648 .735 .913 r
.17326 .37698 .18111 .38442 .19225 .38088 .18443 .3734 Mtetra
.647 .735 .913 r
.18443 .3734 .19225 .38088 .20344 .37736 .19565 .36984 Mtetra
.647 .734 .913 r
.19565 .36984 .20344 .37736 .21467 .37384 .20691 .36627 Mtetra
.646 .734 .913 r
.20691 .36627 .21467 .37384 .22596 .37032 .21823 .36271 Mtetra
.646 .733 .913 r
.21823 .36271 .22596 .37032 .23731 .36679 .2296 .35914 Mtetra
.2296 .35914 .23731 .36679 .2487 .36325 .24103 .35555 Mtetra
.646 .733 .912 r
.24103 .35555 .2487 .36325 .26015 .35969 .2525 .35194 Mtetra
.646 .732 .912 r
.2525 .35194 .26015 .35969 .27166 .35609 .26404 .34829 Mtetra
.647 .732 .911 r
.26404 .34829 .27166 .35609 .28322 .35244 .27563 .3446 Mtetra
.649 .732 .91 r
.27563 .3446 .28322 .35244 .29484 .34875 .28728 .34086 Mtetra
.65 .733 .91 r
.28728 .34086 .29484 .34875 .30651 .345 .29899 .33706 Mtetra
.652 .733 .909 r
.29899 .33706 .30651 .345 .31825 .34117 .31075 .3332 Mtetra
.654 .733 .908 r
.31075 .3332 .31825 .34117 .33004 .33727 .32258 .32925 Mtetra
.656 .733 .907 r
.32258 .32925 .33004 .33727 .3419 .33328 .33446 .32522 Mtetra
.658 .734 .906 r
.33446 .32522 .3419 .33328 .35381 .32921 .3464 .32111 Mtetra
.66 .734 .905 r
.3464 .32111 .35381 .32921 .36578 .32504 .35841 .3169 Mtetra
.662 .735 .904 r
.35841 .3169 .36578 .32504 .3778 .32079 .37047 .31261 Mtetra
.664 .735 .903 r
.37047 .31261 .3778 .32079 .38989 .31646 .38258 .30823 Mtetra
.665 .736 .902 r
.38258 .30823 .38989 .31646 .40203 .31207 .39476 .30381 Mtetra
.39476 .30381 .40203 .31207 .41422 .30768 .40698 .29936 Mtetra
.663 .734 .903 r
.40698 .29936 .41422 .30768 .42647 .30336 .41927 .29496 Mtetra
.658 .731 .904 r
.41927 .29496 .42647 .30336 .43876 .29923 .4316 .29071 Mtetra
.647 .726 .906 r
.4316 .29071 .43876 .29923 .45111 .29549 .44398 .28678 Mtetra
.629 .715 .908 r
.44398 .28678 .45111 .29549 .4635 .29239 .45641 .28337 Mtetra
.602 .697 .91 r
.45641 .28337 .4635 .29239 .47594 .29024 .46889 .28074 Mtetra
.563 .669 .909 r
.46889 .28074 .47594 .29024 .48845 .28937 .48143 .27916 Mtetra
.515 .63 .902 r
.48143 .27916 .48845 .28937 .50103 .29008 .49403 .27888 Mtetra
.465 .581 .886 r
.49403 .27888 .50103 .29008 .5137 .29254 .50673 .28002 Mtetra
.425 .532 .862 r
.50673 .28002 .5137 .29254 .52649 .29669 .51952 .28252 Mtetra
.406 .491 .834 r
.51952 .28252 .52649 .29669 .53942 .30217 .53244 .28604 Mtetra
.414 .466 .805 r
.53244 .28604 .53942 .30217 .5525 .30829 .54548 .29001 Mtetra
.446 .458 .778 r
.54548 .29001 .5525 .30829 .56572 .31405 .55866 .29358 Mtetra
.491 .464 .755 r
.55866 .29358 .56572 .31405 .57907 .31831 .57195 .29582 Mtetra
.54 .478 .735 r
.57195 .29582 .57907 .31831 .5925 .31997 .58532 .29586 Mtetra
.586 .495 .719 r
.58532 .29586 .5925 .31997 .60596 .31818 .59872 .29305 Mtetra
.626 .514 .707 r
.59872 .29305 .60596 .31818 .61939 .31254 .61212 .28711 Mtetra
.659 .533 .699 r
.61212 .28711 .61939 .31254 .63275 .30317 .62548 .27821 Mtetra
.686 .551 .695 r
.62548 .27821 .63275 .30317 .64601 .29069 .63877 .26689 Mtetra
.708 .57 .697 r
.63877 .26689 .64601 .29069 .65918 .27604 .65201 .25393 Mtetra
.724 .589 .704 r
.65201 .25393 .65918 .27604 .67227 .26033 .6652 .24023 Mtetra
.736 .609 .716 r
.6652 .24023 .67227 .26033 .68533 .2446 .67839 .22662 Mtetra
.743 .63 .734 r
.67839 .22662 .68533 .2446 .69841 .22969 .6916 .21374 Mtetra
.745 .651 .757 r
.6916 .21374 .69841 .22969 .71154 .21614 .70487 .20199 Mtetra
.742 .673 .783 r
.70487 .20199 .71154 .21614 .72477 .20423 .71823 .19157 Mtetra
.735 .693 .811 r
.71823 .19157 .72477 .20423 .73811 .19396 .7317 .18246 Mtetra
.723 .71 .837 r
.7317 .18246 .73811 .19396 .75158 .18516 .74528 .1745 Mtetra
.709 .722 .86 r
.74528 .1745 .75158 .18516 .76519 .17757 .75897 .16748 Mtetra
.696 .731 .877 r
.75897 .16748 .76519 .17757 .77891 .17089 .77277 .16116 Mtetra
.685 .736 .89 r
.77277 .16116 .77891 .17089 .79274 .16486 .78667 .15533 Mtetra
.65 .736 .912 r
.15421 .37309 .16214 .38057 .17326 .37698 .16536 .36946 Mtetra
.649 .735 .912 r
.16536 .36946 .17326 .37698 .18443 .3734 .17655 .36584 Mtetra
.648 .734 .912 r
.17655 .36584 .18443 .3734 .19565 .36984 .1878 .36222 Mtetra
.647 .734 .912 r
.1878 .36222 .19565 .36984 .20691 .36627 .19909 .35861 Mtetra
.647 .733 .912 r
.19909 .35861 .20691 .36627 .21823 .36271 .21044 .355 Mtetra
.646 .733 .912 r
.21044 .355 .21823 .36271 .2296 .35914 .22184 .35137 Mtetra
.646 .732 .911 r
.22184 .35137 .2296 .35914 .24103 .35555 .23329 .34774 Mtetra
.647 .732 .911 r
.23329 .34774 .24103 .35555 .2525 .35194 .2448 .34408 Mtetra
.647 .731 .91 r
.2448 .34408 .2525 .35194 .26404 .34829 .25636 .34038 Mtetra
.648 .731 .91 r
.25636 .34038 .26404 .34829 .27563 .3446 .26798 .33664 Mtetra
.649 .731 .909 r
.26798 .33664 .27563 .3446 .28728 .34086 .27966 .33286 Mtetra
.65 .731 .908 r
.27966 .33286 .28728 .34086 .29899 .33706 .2914 .32901 Mtetra
.652 .731 .907 r
.2914 .32901 .29899 .33706 .31075 .3332 .3032 .3251 Mtetra
.654 .732 .906 r
.3032 .3251 .31075 .3332 .32258 .32925 .31505 .32111 Mtetra
.656 .732 .905 r
.31505 .32111 .32258 .32925 .33446 .32522 .32697 .31703 Mtetra
.658 .732 .904 r
.32697 .31703 .33446 .32522 .3464 .32111 .33894 .31288 Mtetra
.66 .733 .903 r
.33894 .31288 .3464 .32111 .35841 .3169 .35098 .30863 Mtetra
.662 .733 .902 r
.35098 .30863 .35841 .3169 .37047 .31261 .36307 .3043 Mtetra
.664 .734 .902 r
.36307 .3043 .37047 .31261 .38258 .30823 .37522 .29989 Mtetra
.666 .734 .901 r
.37522 .29989 .38258 .30823 .39476 .30381 .38743 .29541 Mtetra
.38743 .29541 .39476 .30381 .40698 .29936 .39969 .29091 Mtetra
.664 .733 .901 r
.39969 .29091 .40698 .29936 .41927 .29496 .41201 .28643 Mtetra
.66 .731 .902 r
.41201 .28643 .41927 .29496 .4316 .29071 .42438 .28205 Mtetra
.652 .726 .903 r
.42438 .28205 .4316 .29071 .44398 .28678 .43679 .27791 Mtetra
.639 .716 .904 r
.43679 .27791 .44398 .28678 .45641 .28337 .44926 .27418 Mtetra
.618 .701 .904 r
.44926 .27418 .45641 .28337 .46889 .28074 .46178 .27105 Mtetra
.59 .678 .901 r
.46178 .27105 .46889 .28074 .48143 .27916 .47435 .26874 Mtetra
.555 .645 .894 r
.47435 .26874 .48143 .27916 .49403 .27888 .48699 .26744 Mtetra
.52 .606 .879 r
.48699 .26744 .49403 .27888 .50673 .28002 .49971 .26724 Mtetra
.491 .564 .857 r
.49971 .26724 .50673 .28002 .51952 .28252 .51252 .26806 Mtetra
.477 .527 .83 r
.51252 .26806 .51952 .28252 .53244 .28604 .52543 .26964 Mtetra
.481 .502 .802 r
.52543 .26964 .53244 .28604 .54548 .29001 .53845 .2715 Mtetra
.5 .488 .776 r
.53845 .2715 .54548 .29001 .55866 .29358 .55159 .27299 Mtetra
.53 .486 .752 r
.55159 .27299 .55866 .29358 .57195 .29582 .56483 .27337 Mtetra
.564 .493 .733 r
.56483 .27337 .57195 .29582 .58532 .29586 .57815 .27198 Mtetra
.597 .504 .719 r
.57815 .27198 .58532 .29586 .59872 .29305 .59151 .26835 Mtetra
.628 .517 .709 r
.59151 .26835 .59872 .29305 .61212 .28711 .60488 .26231 Mtetra
.654 .533 .704 r
.60488 .26231 .61212 .28711 .62548 .27821 .61824 .25403 Mtetra
.677 .55 .703 r
.61824 .25403 .62548 .27821 .63877 .26689 .63157 .24395 Mtetra
.695 .568 .707 r
.63157 .24395 .63877 .26689 .65201 .25393 .64487 .2327 Mtetra
.709 .587 .716 r
.64487 .2327 .65201 .25393 .6652 .24023 .65816 .22096 Mtetra
.72 .607 .73 r
.65816 .22096 .6652 .24023 .67839 .22662 .67146 .20936 Mtetra
.726 .629 .75 r
.67146 .20936 .67839 .22662 .6916 .21374 .68479 .19838 Mtetra
.728 .651 .773 r
.68479 .19838 .6916 .21374 .70487 .20199 .69819 .1883 Mtetra
.726 .673 .799 r
.69819 .1883 .70487 .20199 .71823 .19157 .71168 .17923 Mtetra
.719 .693 .825 r
.71168 .17923 .71823 .19157 .7317 .18246 .72525 .17115 Mtetra
.709 .71 .849 r
.72525 .17115 .7317 .18246 .74528 .1745 .73893 .16394 Mtetra
.698 .722 .868 r
.73893 .16394 .74528 .1745 .75897 .16748 .75271 .15742 Mtetra
.688 .73 .883 r
.75271 .15742 .75897 .16748 .77277 .16116 .76659 .15141 Mtetra
.679 .735 .893 r
.76659 .15141 .77277 .16116 .78667 .15533 .78056 .14576 Mtetra
.65 .735 .911 r
.14622 .36554 .15421 .37309 .16536 .36946 .15739 .36186 Mtetra
.649 .734 .911 r
.15739 .36186 .16536 .36946 .17655 .36584 .16861 .35818 Mtetra
.16861 .35818 .17655 .36584 .1878 .36222 .17989 .35452 Mtetra
.648 .733 .911 r
.17989 .35452 .1878 .36222 .19909 .35861 .19121 .35086 Mtetra
.647 .732 .911 r
.19121 .35086 .19909 .35861 .21044 .355 .20259 .34719 Mtetra
.20259 .34719 .21044 .355 .22184 .35137 .21402 .34352 Mtetra
.647 .731 .91 r
.21402 .34352 .22184 .35137 .23329 .34774 .2255 .33983 Mtetra
.2255 .33983 .23329 .34774 .2448 .34408 .23704 .33611 Mtetra
.648 .73 .909 r
.23704 .33611 .2448 .34408 .25636 .34038 .24863 .33236 Mtetra
.24863 .33236 .25636 .34038 .26798 .33664 .26028 .32857 Mtetra
.65 .73 .908 r
.26028 .32857 .26798 .33664 .27966 .33286 .27199 .32474 Mtetra
.651 .73 .907 r
.27199 .32474 .27966 .33286 .2914 .32901 .28376 .32084 Mtetra
.652 .73 .906 r
.28376 .32084 .2914 .32901 .3032 .3251 .29559 .31688 Mtetra
.654 .73 .905 r
.29559 .31688 .3032 .3251 .31505 .32111 .30747 .31284 Mtetra
.656 .73 .904 r
.30747 .31284 .31505 .32111 .32697 .31703 .31942 .30872 Mtetra
.658 .731 .903 r
.31942 .30872 .32697 .31703 .33894 .31288 .33143 .30452 Mtetra
.66 .731 .902 r
.33143 .30452 .33894 .31288 .35098 .30863 .34349 .30024 Mtetra
.662 .732 .901 r
.34349 .30024 .35098 .30863 .36307 .3043 .35562 .29587 Mtetra
.664 .732 .901 r
.35562 .29587 .36307 .3043 .37522 .29989 .3678 .29141 Mtetra
.666 .733 .9 r
.3678 .29141 .37522 .29989 .38743 .29541 .38004 .2869 Mtetra
.38004 .2869 .38743 .29541 .39969 .29091 .39234 .28234 Mtetra
.666 .732 .899 r
.39234 .28234 .39969 .29091 .41201 .28643 .40469 .27778 Mtetra
.663 .73 .9 r
.40469 .27778 .41201 .28643 .42438 .28205 .4171 .27328 Mtetra
.657 .726 .9 r
.4171 .27328 .42438 .28205 .43679 .27791 .42955 .26895 Mtetra
.647 .719 .9 r
.42955 .26895 .43679 .27791 .44926 .27418 .44206 .2649 Mtetra
.633 .706 .899 r
.44206 .2649 .44926 .27418 .46178 .27105 .45462 .2613 Mtetra
.612 .687 .896 r
.45462 .2613 .46178 .27105 .47435 .26874 .46723 .25831 Mtetra
.588 .661 .889 r
.46723 .25831 .47435 .26874 .48699 .26744 .4799 .25605 Mtetra
.563 .629 .876 r
.4799 .25605 .48699 .26744 .49971 .26724 .49265 .25459 Mtetra
.542 .595 .856 r
.49265 .25459 .49971 .26724 .51252 .26806 .50547 .25388 Mtetra
.53 .562 .832 r
.50547 .25388 .51252 .26806 .52543 .26964 .51839 .2537 Mtetra
.53 .537 .807 r
.51839 .2537 .52543 .26964 .53845 .2715 .53141 .25368 Mtetra
.541 .52 .782 r
.53141 .25368 .53845 .2715 .55159 .27299 .54452 .25333 Mtetra
.561 .513 .76 r
.54452 .25333 .55159 .27299 .56483 .27337 .55773 .25211 Mtetra
.584 .514 .742 r
.55773 .25211 .56483 .27337 .57815 .27198 .57101 .24956 Mtetra
.609 .52 .729 r
.57101 .24956 .57815 .27198 .59151 .26835 .58434 .24533 Mtetra
.632 .53 .721 r
.58434 .24533 .59151 .26835 .60488 .26231 .5977 .23933 Mtetra
.653 .543 .717 r
.5977 .23933 .60488 .26231 .61824 .25403 .61106 .23171 Mtetra
.671 .558 .718 r
.61106 .23171 .61824 .25403 .63157 .24395 .62443 .22282 Mtetra
.687 .575 .724 r
.62443 .22282 .63157 .24395 .64487 .2327 .63779 .21313 Mtetra
.699 .594 .735 r
.63779 .21313 .64487 .2327 .65816 .22096 .65116 .20315 Mtetra
.708 .615 .751 r
.65116 .20315 .65816 .22096 .67146 .20936 .66456 .19332 Mtetra
.713 .636 .771 r
.66456 .19332 .67146 .20936 .68479 .19838 .67801 .18397 Mtetra
.714 .658 .793 r
.67801 .18397 .68479 .19838 .69819 .1883 .69152 .17529 Mtetra
.711 .679 .817 r
.69152 .17529 .69819 .1883 .71168 .17923 .70511 .16737 Mtetra
.705 .698 .84 r
.70511 .16737 .71168 .17923 .72525 .17115 .71879 .16015 Mtetra
.697 .713 .861 r
.71879 .16015 .72525 .17115 .73893 .16394 .73256 .15355 Mtetra
.689 .724 .877 r
.73256 .15355 .73893 .16394 .75271 .15742 .74641 .14744 Mtetra
.681 .731 .888 r
.74641 .14744 .75271 .15742 .76659 .15141 .76036 .14168 Mtetra
.675 .736 .896 r
.76036 .14168 .76659 .15141 .78056 .14576 .77439 .13615 Mtetra
.651 .735 .911 r
.13816 .35791 .14622 .36554 .15739 .36186 .14936 .35418 Mtetra
.65 .734 .911 r
.14936 .35418 .15739 .36186 .16861 .35818 .16061 .35045 Mtetra
.649 .733 .911 r
.16061 .35045 .16861 .35818 .17989 .35452 .17192 .34673 Mtetra
.17192 .34673 .17989 .35452 .19121 .35086 .18327 .34302 Mtetra
.648 .732 .91 r
.18327 .34302 .19121 .35086 .20259 .34719 .19467 .33929 Mtetra
.648 .731 .91 r
.19467 .33929 .20259 .34719 .21402 .34352 .20613 .33556 Mtetra
.648 .731 .909 r
.20613 .33556 .21402 .34352 .2255 .33983 .21765 .33182 Mtetra
.648 .73 .909 r
.21765 .33182 .2255 .33983 .23704 .33611 .22921 .32804 Mtetra
.648 .73 .908 r
.22921 .32804 .23704 .33611 .24863 .33236 .24084 .32424 Mtetra
.649 .729 .908 r
.24084 .32424 .24863 .33236 .26028 .32857 .25252 .3204 Mtetra
.65 .729 .907 r
.25252 .3204 .26028 .32857 .27199 .32474 .26426 .3165 Mtetra
.651 .729 .906 r
.26426 .3165 .27199 .32474 .28376 .32084 .27606 .31255 Mtetra
.653 .729 .905 r
.27606 .31255 .28376 .32084 .29559 .31688 .28792 .30854 Mtetra
.655 .729 .904 r
.28792 .30854 .29559 .31688 .30747 .31284 .29983 .30446 Mtetra
.656 .729 .903 r
.29983 .30446 .30747 .31284 .31942 .30872 .31181 .30029 Mtetra
.658 .73 .902 r
.31181 .30029 .31942 .30872 .33143 .30452 .32385 .29605 Mtetra
.66 .73 .901 r
.32385 .29605 .33143 .30452 .34349 .30024 .33595 .29172 Mtetra
.662 .731 .9 r
.33595 .29172 .34349 .30024 .35562 .29587 .34811 .28731 Mtetra
.664 .731 .899 r
.34811 .28731 .35562 .29587 .3678 .29141 .36032 .28282 Mtetra
.666 .732 .899 r
.36032 .28282 .3678 .29141 .38004 .2869 .3726 .27826 Mtetra
.667 .732 .898 r
.3726 .27826 .38004 .2869 .39234 .28234 .38493 .27365 Mtetra
.667 .731 .898 r
.38493 .27365 .39234 .28234 .40469 .27778 .39732 .26902 Mtetra
.665 .73 .898 r
.39732 .26902 .40469 .27778 .4171 .27328 .40976 .26441 Mtetra
.661 .727 .898 r
.40976 .26441 .4171 .27328 .42955 .26895 .42225 .25991 Mtetra
.655 .721 .898 r
.42225 .25991 .42955 .26895 .44206 .2649 .4348 .25559 Mtetra
.644 .712 .897 r
.4348 .25559 .44206 .2649 .45462 .2613 .4474 .25158 Mtetra
.63 .697 .893 r
.4474 .25158 .45462 .2613 .46723 .25831 .46005 .24799 Mtetra
.613 .677 .887 r
.46005 .24799 .46723 .25831 .4799 .25605 .47276 .24491 Mtetra
.596 .652 .876 r
.47276 .24491 .4799 .25605 .49265 .25459 .48554 .24238 Mtetra
.58 .624 .86 r
.48554 .24238 .49265 .25459 .50547 .25388 .49839 .24036 Mtetra
.571 .596 .839 r
.49839 .24036 .50547 .25388 .51839 .2537 .51132 .23869 Mtetra
.569 .572 .817 r
.51132 .23869 .51839 .2537 .53141 .25368 .52434 .23711 Mtetra
.575 .555 .794 r
.52434 .23711 .53141 .25368 .54452 .25333 .53745 .23526 Mtetra
.587 .545 .775 r
.53745 .23526 .54452 .25333 .55773 .25211 .55064 .23278 Mtetra
.603 .541 .759 r
.55064 .23278 .55773 .25211 .57101 .24956 .5639 .22932 Mtetra
.62 .544 .747 r
.5639 .22932 .57101 .24956 .58434 .24533 .57721 .22468 Mtetra
.638 .551 .74 r
.57721 .22468 .58434 .24533 .5977 .23933 .59057 .21881 Mtetra
.655 .562 .738 r
.59057 .21881 .5977 .23933 .61106 .23171 .60395 .21182 Mtetra
.669 .575 .741 r
.60395 .21182 .61106 .23171 .62443 .22282 .61735 .20397 Mtetra
.682 .591 .748 r
.61735 .20397 .62443 .22282 .63779 .21313 .63077 .1956 Mtetra
.692 .61 .76 r
.63077 .1956 .63779 .21313 .65116 .20315 .64422 .18706 Mtetra
.698 .629 .776 r
.64422 .18706 .65116 .20315 .66456 .19332 .65771 .17866 Mtetra
.702 .65 .795 r
.65771 .17866 .66456 .19332 .67801 .18397 .67125 .17062 Mtetra
.702 .671 .816 r
.67125 .17062 .67801 .18397 .69152 .17529 .68486 .16307 Mtetra
.699 .689 .837 r
.68486 .16307 .69152 .17529 .70511 .16737 .69854 .15603 Mtetra
.694 .705 .856 r
.69854 .15603 .70511 .16737 .71879 .16015 .7123 .14948 Mtetra
.687 .718 .872 r
.7123 .14948 .71879 .16015 .73256 .15355 .72614 .14334 Mtetra
.681 .727 .885 r
.72614 .14334 .73256 .15355 .74641 .14744 .74007 .13753 Mtetra
.675 .733 .893 r
.74007 .13753 .74641 .14744 .76036 .14168 .75408 .13195 Mtetra
.671 .737 .899 r
.75408 .13195 .76036 .14168 .77439 .13615 .76817 .12652 Mtetra
.652 .735 .91 r
.13004 .3502 .13816 .35791 .14936 .35418 .14127 .34642 Mtetra
.651 .734 .91 r
.14127 .34642 .14936 .35418 .16061 .35045 .15255 .34264 Mtetra
.65 .733 .91 r
.15255 .34264 .16061 .35045 .17192 .34673 .16388 .33887 Mtetra
.649 .732 .91 r
.16388 .33887 .17192 .34673 .18327 .34302 .17527 .33509 Mtetra
.17527 .33509 .18327 .34302 .19467 .33929 .1867 .33131 Mtetra
.649 .731 .909 r
.1867 .33131 .19467 .33929 .20613 .33556 .19819 .32752 Mtetra
.649 .73 .909 r
.19819 .32752 .20613 .33556 .21765 .33182 .20973 .32371 Mtetra
.649 .73 .908 r
.20973 .32371 .21765 .33182 .22921 .32804 .22133 .31988 Mtetra
.649 .729 .907 r
.22133 .31988 .22921 .32804 .24084 .32424 .23298 .31602 Mtetra
.65 .729 .907 r
.23298 .31602 .24084 .32424 .25252 .3204 .2447 .31212 Mtetra
.651 .728 .906 r
.2447 .31212 .25252 .3204 .26426 .3165 .25647 .30817 Mtetra
.652 .728 .905 r
.25647 .30817 .26426 .3165 .27606 .31255 .2683 .30416 Mtetra
.653 .728 .904 r
.2683 .30416 .27606 .31255 .28792 .30854 .28019 .3001 Mtetra
.655 .728 .903 r
.28019 .3001 .28792 .30854 .29983 .30446 .29214 .29596 Mtetra
.657 .728 .902 r
.29214 .29596 .29983 .30446 .31181 .30029 .30415 .29175 Mtetra
.659 .729 .901 r
.30415 .29175 .31181 .30029 .32385 .29605 .31622 .28747 Mtetra
.66 .729 .9 r
.31622 .28747 .32385 .29605 .33595 .29172 .32835 .2831 Mtetra
.662 .729 .899 r
.32835 .2831 .33595 .29172 .34811 .28731 .34053 .27865 Mtetra
.664 .73 .899 r
.34053 .27865 .34811 .28731 .36032 .28282 .35278 .27412 Mtetra
.666 .73 .898 r
.35278 .27412 .36032 .28282 .3726 .27826 .36509 .26952 Mtetra
.667 .731 .898 r
.36509 .26952 .3726 .27826 .38493 .27365 .37746 .26486 Mtetra
.667 .731 .897 r
.37746 .26486 .38493 .27365 .39732 .26902 .38988 .26017 Mtetra
.666 .73 .897 r
.38988 .26017 .39732 .26902 .40976 .26441 .40236 .25547 Mtetra
.664 .728 .897 r
.40236 .25547 .40976 .26441 .42225 .25991 .41489 .25082 Mtetra
.66 .724 .896 r
.41489 .25082 .42225 .25991 .4348 .25559 .42748 .24629 Mtetra
.653 .717 .895 r
.42748 .24629 .4348 .25559 .4474 .25158 .44012 .24194 Mtetra
.644 .706 .892 r
.44012 .24194 .4474 .25158 .46005 .24799 .45281 .23787 Mtetra
.633 .691 .887 r
.45281 .23787 .46005 .24799 .47276 .24491 .46556 .23412 Mtetra
.621 .672 .878 r
.46556 .23412 .47276 .24491 .48554 .24238 .47838 .23074 Mtetra
.61 .65 .865 r
.47838 .23074 .48554 .24238 .49839 .24036 .49126 .22768 Mtetra
.602 .628 .849 r
.49126 .22768 .49839 .24036 .51132 .23869 .50421 .22485 Mtetra
.599 .607 .831 r
.50421 .22485 .51132 .23869 .52434 .23711 .51725 .22205 Mtetra
.602 .59 .812 r
.51725 .22205 .52434 .23711 .53745 .23526 .53036 .21906 Mtetra
.609 .579 .795 r
.53036 .21906 .53745 .23526 .55064 .23278 .54355 .21562 Mtetra
.62 .574 .781 r
.54355 .21562 .55064 .23278 .5639 .22932 .5568 .21151 Mtetra
.632 .574 .771 r
.5568 .21151 .5639 .22932 .57721 .22468 .57012 .20661 Mtetra
.645 .579 .766 r
.57012 .20661 .57721 .22468 .59057 .21881 .58348 .20089 Mtetra
.658 .588 .765 r
.58348 .20089 .59057 .21881 .60395 .21182 .59688 .19443 Mtetra
.669 .6 .768 r
.59688 .19443 .60395 .21182 .61735 .20397 .61032 .18742 Mtetra
.679 .614 .776 r
.61032 .18742 .61735 .20397 .63077 .1956 .62379 .18009 Mtetra
.686 .631 .788 r
.62379 .18009 .63077 .1956 .64422 .18706 .63731 .17267 Mtetra
.691 .649 .804 r
.63731 .17267 .64422 .18706 .65771 .17866 .65087 .16536 Mtetra
.693 .668 .821 r
.65087 .16536 .65771 .17866 .67125 .17062 .66449 .1583 Mtetra
.692 .685 .839 r
.66449 .1583 .67125 .17062 .68486 .16307 .67818 .15157 Mtetra
.689 .701 .856 r
.67818 .15157 .68486 .16307 .69854 .15603 .69194 .14518 Mtetra
.685 .714 .871 r
.69194 .14518 .69854 .15603 .7123 .14948 .70578 .13911 Mtetra
.68 .723 .883 r
.70578 .13911 .7123 .14948 .72614 .14334 .71969 .1333 Mtetra
.675 .73 .892 r
.71969 .1333 .72614 .14334 .74007 .13753 .73369 .12769 Mtetra
.671 .735 .898 r
.73369 .12769 .74007 .13753 .75408 .13195 .74776 .12222 Mtetra
.669 .738 .902 r
.74776 .12222 .75408 .13195 .76817 .12652 .7619 .11684 Mtetra
.652 .735 .91 r
.12185 .34243 .13004 .3502 .14127 .34642 .13311 .33859 Mtetra
.652 .734 .91 r
.13311 .33859 .14127 .34642 .15255 .34264 .14443 .33475 Mtetra
.651 .733 .909 r
.14443 .33475 .15255 .34264 .16388 .33887 .15579 .33092 Mtetra
.65 .732 .909 r
.15579 .33092 .16388 .33887 .17527 .33509 .1672 .32709 Mtetra
.65 .731 .909 r
.1672 .32709 .17527 .33509 .1867 .33131 .17866 .32324 Mtetra
.65 .731 .908 r
.17866 .32324 .1867 .33131 .19819 .32752 .19018 .31939 Mtetra
.65 .73 .908 r
.19018 .31939 .19819 .32752 .20973 .32371 .20176 .31552 Mtetra
.65 .729 .907 r
.20176 .31552 .20973 .32371 .22133 .31988 .21339 .31163 Mtetra
.21339 .31163 .22133 .31988 .23298 .31602 .22507 .30771 Mtetra
.651 .728 .906 r
.22507 .30771 .23298 .31602 .2447 .31212 .23681 .30375 Mtetra
.652 .728 .905 r
.23681 .30375 .2447 .31212 .25647 .30817 .24862 .29974 Mtetra
.653 .728 .904 r
.24862 .29974 .25647 .30817 .2683 .30416 .26048 .29568 Mtetra
.654 .727 .903 r
.26048 .29568 .2683 .30416 .28019 .3001 .2724 .29156 Mtetra
.655 .727 .902 r
.2724 .29156 .28019 .3001 .29214 .29596 .28438 .28737 Mtetra
.657 .728 .901 r
.28438 .28737 .29214 .29596 .30415 .29175 .29642 .28311 Mtetra
.659 .728 .9 r
.29642 .28311 .30415 .29175 .31622 .28747 .30852 .27878 Mtetra
.66 .728 .899 r
.30852 .27878 .31622 .28747 .32835 .2831 .32068 .27437 Mtetra
.662 .729 .899 r
.32068 .27437 .32835 .2831 .34053 .27865 .3329 .26988 Mtetra
.664 .729 .898 r
.3329 .26988 .34053 .27865 .35278 .27412 .34519 .26531 Mtetra
.665 .73 .897 r
.34519 .26531 .35278 .27412 .36509 .26952 .35753 .26067 Mtetra
.667 .73 .897 r
.35753 .26067 .36509 .26952 .37746 .26486 .36993 .25597 Mtetra
.36993 .25597 .37746 .26486 .38988 .26017 .38238 .25123 Mtetra
.667 .73 .896 r
.38238 .25123 .38988 .26017 .40236 .25547 .3949 .24646 Mtetra
.666 .729 .896 r
.3949 .24646 .40236 .25547 .41489 .25082 .40747 .2417 Mtetra
.664 .726 .896 r
.40747 .2417 .41489 .25082 .42748 .24629 .42009 .23699 Mtetra
.66 .722 .894 r
.42009 .23699 .42748 .24629 .44012 .24194 .43277 .23239 Mtetra
.654 .714 .892 r
.43277 .23239 .44012 .24194 .45281 .23787 .44551 .22795 Mtetra
.647 .704 .888 r
.44551 .22795 .45281 .23787 .46556 .23412 .4583 .22371 Mtetra
.639 .69 .882 r
.4583 .22371 .46556 .23412 .47838 .23074 .47115 .21969 Mtetra
.632 .674 .872 r
.47115 .21969 .47838 .23074 .49126 .22768 .48407 .21587 Mtetra
.626 .657 .86 r
.48407 .21587 .49126 .22768 .50421 .22485 .49706 .21218 Mtetra
.623 .64 .846 r
.49706 .21218 .50421 .22485 .51725 .22205 .51011 .20849 Mtetra
.624 .626 .832 r
.51011 .20849 .51725 .22205 .53036 .21906 .52324 .20467 Mtetra
.628 .615 .818 r
.52324 .20467 .53036 .21906 .54355 .21562 .53644 .20055 Mtetra
.635 .609 .807 r
.53644 .20055 .54355 .21562 .5568 .21151 .5497 .196 Mtetra
.644 .608 .799 r
.5497 .196 .5568 .21151 .57012 .20661 .56303 .19094 Mtetra
.653 .611 .795 r
.56303 .19094 .57012 .20661 .58348 .20089 .57641 .18535 Mtetra
.662 .618 .795 r
.57641 .18535 .58348 .20089 .59688 .19443 .58984 .17931 Mtetra
.67 .628 .799 r
.58984 .17931 .59688 .19443 .61032 .18742 .60332 .17293 Mtetra
.677 .641 .807 r
.60332 .17293 .61032 .18742 .62379 .18009 .61684 .16636 Mtetra
.682 .656 .818 r
.61684 .16636 .62379 .18009 .63731 .17267 .63041 .15974 Mtetra
.684 .671 .831 r
.63041 .15974 .63731 .17267 .65087 .16536 .64405 .15321 Mtetra
.685 .686 .845 r
.64405 .15321 .65087 .16536 .66449 .1583 .65774 .14683 Mtetra
.684 .7 .859 r
.65774 .14683 .66449 .1583 .67818 .15157 .6715 .14067 Mtetra
.681 .712 .872 r
.6715 .14067 .67818 .15157 .69194 .14518 .68532 .13472 Mtetra
.678 .721 .882 r
.68532 .13472 .69194 .14518 .70578 .13911 .69923 .12896 Mtetra
.674 .729 .891 r
.69923 .12896 .70578 .13911 .71969 .1333 .7132 .12336 Mtetra
.671 .734 .897 r
.7132 .12336 .71969 .1333 .73369 .12769 .72725 .11788 Mtetra
.669 .737 .901 r
.72725 .11788 .73369 .12769 .74776 .12222 .74138 .11248 Mtetra
.667 .739 .904 r
.74138 .11248 .74776 .12222 .7619 .11684 .75558 .10712 Mtetra
.653 .735 .909 r
.1136 .33458 .12185 .34243 .13311 .33859 .12489 .33068 Mtetra
.652 .734 .909 r
.12489 .33068 .13311 .33859 .14443 .33475 .13623 .32679 Mtetra
.652 .733 .909 r
.13623 .32679 .14443 .33475 .15579 .33092 .14763 .3229 Mtetra
.651 .732 .909 r
.14763 .3229 .15579 .33092 .1672 .32709 .15907 .319 Mtetra
.651 .731 .908 r
.15907 .319 .1672 .32709 .17866 .32324 .17056 .3151 Mtetra
.17056 .3151 .17866 .32324 .19018 .31939 .18211 .31119 Mtetra
.65 .73 .907 r
.18211 .31119 .19018 .31939 .20176 .31552 .19372 .30725 Mtetra
.651 .729 .907 r
.19372 .30725 .20176 .31552 .21339 .31163 .20538 .3033 Mtetra
.651 .729 .906 r
.20538 .3033 .21339 .31163 .22507 .30771 .21709 .29931 Mtetra
.652 .728 .905 r
.21709 .29931 .22507 .30771 .23681 .30375 .22887 .29529 Mtetra
.652 .728 .904 r
.22887 .29529 .23681 .30375 .24862 .29974 .2407 .29122 Mtetra
.653 .727 .903 r
.2407 .29122 .24862 .29974 .26048 .29568 .25259 .2871 Mtetra
.655 .727 .902 r
.25259 .2871 .26048 .29568 .2724 .29156 .26455 .28292 Mtetra
.656 .727 .902 r
.26455 .28292 .2724 .29156 .28438 .28737 .27656 .27868 Mtetra
.657 .727 .901 r
.27656 .27868 .28438 .28737 .29642 .28311 .28863 .27437 Mtetra
.659 .727 .9 r
.28863 .27437 .29642 .28311 .30852 .27878 .30076 .27 Mtetra
.661 .728 .899 r
.30076 .27 .30852 .27878 .32068 .27437 .31296 .26554 Mtetra
.662 .728 .898 r
.31296 .26554 .32068 .27437 .3329 .26988 .32521 .26101 Mtetra
.664 .728 .898 r
.32521 .26101 .3329 .26988 .34519 .26531 .33753 .25641 Mtetra
.665 .729 .897 r
.33753 .25641 .34519 .26531 .35753 .26067 .3499 .25174 Mtetra
.667 .73 .897 r
.3499 .25174 .35753 .26067 .36993 .25597 .36233 .247 Mtetra
.668 .73 .896 r
.36233 .247 .36993 .25597 .38238 .25123 .37483 .24221 Mtetra
.37483 .24221 .38238 .25123 .3949 .24646 .38738 .23738 Mtetra
.668 .729 .896 r
.38738 .23738 .3949 .24646 .40747 .2417 .39998 .23254 Mtetra
.667 .728 .895 r
.39998 .23254 .40747 .2417 .42009 .23699 .41265 .22771 Mtetra
.664 .725 .895 r
.41265 .22771 .42009 .23699 .43277 .23239 .42536 .22293 Mtetra
.661 .72 .893 r
.42536 .22293 .43277 .23239 .44551 .22795 .43814 .21823 Mtetra
.657 .714 .89 r
.43814 .21823 .44551 .22795 .4583 .22371 .45097 .21364 Mtetra
.652 .705 .886 r
.45097 .21364 .4583 .22371 .47115 .21969 .46387 .20917 Mtetra
.647 .693 .879 r
.46387 .20917 .47115 .21969 .48407 .21587 .47682 .20481 Mtetra
.643 .681 .871 r
.47682 .20481 .48407 .21587 .49706 .21218 .48984 .20051 Mtetra
.641 .669 .861 r
.48984 .20051 .49706 .21218 .51011 .20849 .50293 .19622 Mtetra
.641 .658 .851 r
.50293 .19622 .51011 .20849 .52324 .20467 .51608 .19183 Mtetra
.643 .649 .841 r
.51608 .19183 .52324 .20467 .53644 .20055 .5293 .18726 Mtetra
.648 .644 .833 r
.5293 .18726 .53644 .20055 .5497 .196 .54259 .18241 Mtetra
.653 .643 .827 r
.54259 .18241 .5497 .196 .56303 .19094 .55593 .17726 Mtetra
.659 .645 .824 r
.55593 .17726 .56303 .19094 .57641 .18535 .56934 .17178 Mtetra
.665 .65 .825 r
.56934 .17178 .57641 .18535 .58984 .17931 .5828 .16604 Mtetra
.671 .658 .829 r
.5828 .16604 .58984 .17931 .60332 .17293 .59632 .16009 Mtetra
.675 .668 .836 r
.59632 .16009 .60332 .17293 .61684 .16636 .60989 .15404 Mtetra
.678 .68 .845 r
.60989 .15404 .61684 .16636 .63041 .15974 .62352 .14796 Mtetra
.679 .692 .855 r
.62352 .14796 .63041 .15974 .64405 .15321 .63721 .14194 Mtetra
.679 .703 .865 r
.63721 .14194 .64405 .15321 .65774 .14683 .65096 .13602 Mtetra
.677 .713 .875 r
.65096 .13602 .65774 .14683 .6715 .14067 .66478 .13022 Mtetra
.675 .721 .884 r
.66478 .13022 .6715 .14067 .68532 .13472 .67867 .12454 Mtetra
.673 .728 .891 r
.67867 .12454 .68532 .13472 .69923 .12896 .69263 .11898 Mtetra
.67 .733 .897 r
.69263 .11898 .69923 .12896 .7132 .12336 .70666 .1135 Mtetra
.668 .736 .901 r
.70666 .1135 .7132 .12336 .72725 .11788 .72077 .10808 Mtetra
.667 .738 .904 r
.72077 .10808 .72725 .11788 .74138 .11248 .73495 .1027 Mtetra
.666 .74 .905 r
.73495 .1027 .74138 .11248 .75558 .10712 .7492 .09733 Mtetra
.654 .735 .909 r
.10529 .32667 .1136 .33458 .12489 .33068 .11661 .32271 Mtetra
.653 .734 .909 r
.11661 .32271 .12489 .33068 .13623 .32679 .12798 .31876 Mtetra
.653 .733 .908 r
.12798 .31876 .13623 .32679 .14763 .3229 .1394 .31481 Mtetra
.652 .732 .908 r
.1394 .31481 .14763 .3229 .15907 .319 .15087 .31085 Mtetra
.652 .731 .908 r
.15087 .31085 .15907 .319 .17056 .3151 .1624 .30688 Mtetra
.651 .731 .907 r
.1624 .30688 .17056 .3151 .18211 .31119 .17398 .3029 Mtetra
.651 .73 .907 r
.17398 .3029 .18211 .31119 .19372 .30725 .18561 .29891 Mtetra
.652 .729 .906 r
.18561 .29891 .19372 .30725 .20538 .3033 .19731 .29488 Mtetra
.652 .729 .905 r
.19731 .29488 .20538 .3033 .21709 .29931 .20905 .29083 Mtetra
.652 .728 .904 r
.20905 .29083 .21709 .29931 .22887 .29529 .22086 .28675 Mtetra
.653 .727 .904 r
.22086 .28675 .22887 .29529 .2407 .29122 .23272 .28262 Mtetra
.654 .727 .903 r
.23272 .28262 .2407 .29122 .25259 .2871 .24465 .27844 Mtetra
.655 .727 .902 r
.24465 .27844 .25259 .2871 .26455 .28292 .25663 .2742 Mtetra
.656 .727 .901 r
.25663 .2742 .26455 .28292 .27656 .27868 .26867 .26991 Mtetra
.658 .727 .9 r
.26867 .26991 .27656 .27868 .28863 .27437 .28078 .26555 Mtetra
.659 .727 .899 r
.28078 .26555 .28863 .27437 .30076 .27 .29294 .26113 Mtetra
.661 .727 .899 r
.29294 .26113 .30076 .27 .31296 .26554 .30517 .25663 Mtetra
.662 .728 .898 r
.30517 .25663 .31296 .26554 .32521 .26101 .31746 .25206 Mtetra
.664 .728 .897 r
.31746 .25206 .32521 .26101 .33753 .25641 .3298 .24742 Mtetra
.665 .729 .897 r
.3298 .24742 .33753 .25641 .3499 .25174 .34221 .24272 Mtetra
.666 .729 .896 r
.34221 .24272 .3499 .25174 .36233 .247 .35468 .23794 Mtetra
.667 .73 .896 r
.35468 .23794 .36233 .247 .37483 .24221 .36721 .23312 Mtetra
.668 .73 .896 r
.36721 .23312 .37483 .24221 .38738 .23738 .37979 .22824 Mtetra
.37979 .22824 .38738 .23738 .39998 .23254 .39243 .22334 Mtetra
.668 .729 .896 r
.39243 .22334 .39998 .23254 .41265 .22771 .40513 .21842 Mtetra
.667 .728 .895 r
.40513 .21842 .41265 .22771 .42536 .22293 .41789 .21351 Mtetra
.665 .725 .894 r
.41789 .21351 .42536 .22293 .43814 .21823 .43071 .20864 Mtetra
.663 .721 .892 r
.43071 .20864 .43814 .21823 .45097 .21364 .44358 .20381 Mtetra
.66 .715 .889 r
.44358 .20381 .45097 .21364 .46387 .20917 .45651 .19904 Mtetra
.657 .708 .885 r
.45651 .19904 .46387 .20917 .47682 .20481 .46951 .19433 Mtetra
.655 .7 .88 r
.46951 .19433 .47682 .20481 .48984 .20051 .48256 .18964 Mtetra
.653 .692 .874 r
.48256 .18964 .48984 .20051 .50293 .19622 .49568 .18495 Mtetra
.653 .684 .867 r
.49568 .18495 .50293 .19622 .51608 .19183 .50887 .18019 Mtetra
.654 .678 .861 r
.50887 .18019 .51608 .19183 .5293 .18726 .52212 .17532 Mtetra
.657 .674 .855 r
.52212 .17532 .5293 .18726 .54259 .18241 .53543 .17029 Mtetra
.66 .673 .852 r
.53543 .17029 .54259 .18241 .55593 .17726 .54881 .16508 Mtetra
.664 .675 .85 r
.54881 .16508 .55593 .17726 .56934 .17178 .56225 .15968 Mtetra
.667 .678 .851 r
.56225 .15968 .56934 .17178 .5828 .16604 .57575 .15413 Mtetra
.67 .684 .855 r
.57575 .15413 .5828 .16604 .59632 .16009 .5893 .14846 Mtetra
.673 .692 .86 r
.5893 .14846 .59632 .16009 .60989 .15404 .60292 .14274 Mtetra
.674 .7 .866 r
.60292 .14274 .60989 .15404 .62352 .14796 .6166 .137 Mtetra
.674 .709 .874 r
.6166 .137 .62352 .14796 .63721 .14194 .63034 .13129 Mtetra
.674 .716 .881 r
.63034 .13129 .63721 .14194 .65096 .13602 .64415 .12564 Mtetra
.673 .723 .887 r
.64415 .12564 .65096 .13602 .66478 .13022 .65802 .12005 Mtetra
.671 .729 .893 r
.65802 .12005 .66478 .13022 .67867 .12454 .67197 .11453 Mtetra
.669 .733 .898 r
.67197 .11453 .67867 .12454 .69263 .11898 .68598 .10907 Mtetra
.668 .736 .901 r
.68598 .10907 .69263 .11898 .70666 .1135 .70007 .10365 Mtetra
.667 .738 .903 r
.70007 .10365 .70666 .1135 .72077 .10808 .71423 .09825 Mtetra
.666 .74 .905 r
.71423 .09825 .72077 .10808 .73495 .1027 .72846 .09286 Mtetra
.665 .74 .906 r
.72846 .09286 .73495 .1027 .7492 .09733 .74276 .08747 Mtetra
.655 .735 .909 r
.0969 .31869 .10529 .32667 .11661 .32271 .10825 .31467 Mtetra
.654 .734 .908 r
.10825 .31467 .11661 .32271 .12798 .31876 .11965 .31066 Mtetra
.654 .733 .908 r
.11965 .31066 .12798 .31876 .1394 .31481 .13111 .30665 Mtetra
.653 .733 .908 r
.13111 .30665 .1394 .31481 .15087 .31085 .14261 .30262 Mtetra
.653 .732 .907 r
.14261 .30262 .15087 .31085 .1624 .30688 .15417 .29859 Mtetra
.652 .731 .907 r
.15417 .29859 .1624 .30688 .17398 .3029 .16578 .29455 Mtetra
.652 .73 .906 r
.16578 .29455 .17398 .3029 .18561 .29891 .17744 .29049 Mtetra
.653 .729 .906 r
.17744 .29049 .18561 .29891 .19731 .29488 .18917 .2864 Mtetra
.653 .729 .905 r
.18917 .2864 .19731 .29488 .20905 .29083 .20095 .28228 Mtetra
.653 .728 .904 r
.20095 .28228 .20905 .29083 .22086 .28675 .21278 .27813 Mtetra
.654 .728 .903 r
.21278 .27813 .22086 .28675 .23272 .28262 .22468 .27394 Mtetra
.655 .727 .902 r
.22468 .27394 .23272 .28262 .24465 .27844 .23664 .2697 Mtetra
.656 .727 .902 r
.23664 .2697 .24465 .27844 .25663 .2742 .24865 .26541 Mtetra
.657 .727 .901 r
.24865 .26541 .25663 .2742 .26867 .26991 .26073 .26106 Mtetra
.658 .727 .9 r
.26073 .26106 .26867 .26991 .28078 .26555 .27286 .25665 Mtetra
.659 .727 .899 r
.27286 .25665 .28078 .26555 .29294 .26113 .28506 .25218 Mtetra
.661 .727 .899 r
.28506 .25218 .29294 .26113 .30517 .25663 .29732 .24764 Mtetra
.662 .728 .898 r
.29732 .24764 .30517 .25663 .31746 .25206 .30964 .24303 Mtetra
.664 .728 .897 r
.30964 .24303 .31746 .25206 .3298 .24742 .32202 .23836 Mtetra
.665 .728 .897 r
.32202 .23836 .3298 .24742 .34221 .24272 .33446 .23362 Mtetra
.666 .729 .897 r
.33446 .23362 .34221 .24272 .35468 .23794 .34696 .22881 Mtetra
.667 .73 .896 r
.34696 .22881 .35468 .23794 .36721 .23312 .35952 .22395 Mtetra
.668 .73 .896 r
.35952 .22395 .36721 .23312 .37979 .22824 .37214 .21904 Mtetra
.37214 .21904 .37979 .22824 .39243 .22334 .38482 .21409 Mtetra
.669 .73 .896 r
.38482 .21409 .39243 .22334 .40513 .21842 .39756 .20911 Mtetra
.668 .73 .896 r
.39756 .20911 .40513 .21842 .41789 .21351 .41035 .20412 Mtetra
.667 .728 .895 r
.41035 .20412 .41789 .21351 .43071 .20864 .42321 .19913 Mtetra
.666 .726 .894 r
.42321 .19913 .43071 .20864 .44358 .20381 .43612 .19416 Mtetra
.665 .723 .893 r
.43612 .19416 .44358 .20381 .45651 .19904 .44909 .1892 Mtetra
.663 .719 .89 r
.44909 .1892 .45651 .19904 .46951 .19433 .46212 .18426 Mtetra
.662 .714 .887 r
.46212 .18426 .46951 .19433 .48256 .18964 .47522 .17933 Mtetra
.661 .709 .884 r
.47522 .17933 .48256 .18964 .49568 .18495 .48838 .17438 Mtetra
.661 .705 .88 r
.48838 .17438 .49568 .18495 .50887 .18019 .5016 .1694 Mtetra
.661 .701 .876 r
.5016 .1694 .50887 .18019 .52212 .17532 .51488 .16434 Mtetra
.662 .698 .873 r
.51488 .16434 .52212 .17532 .53543 .17029 .52823 .1592 Mtetra
.664 .697 .871 r
.52823 .1592 .53543 .17029 .54881 .16508 .54164 .15395 Mtetra
.666 .698 .87 r
.54164 .15395 .54881 .16508 .56225 .15968 .55512 .1486 Mtetra
.668 .701 .871 r
.55512 .1486 .56225 .15968 .57575 .15413 .56865 .14316 Mtetra
.67 .705 .874 r
.56865 .14316 .57575 .15413 .5893 .14846 .58225 .13765 Mtetra
.671 .71 .878 r
.58225 .13765 .5893 .14846 .60292 .14274 .59591 .13211 Mtetra
.671 .716 .882 r
.59591 .13211 .60292 .14274 .6166 .137 .60964 .12657 Mtetra
.671 .721 .887 r
.60964 .12657 .6166 .137 .63034 .13129 .62343 .12104 Mtetra
.67 .726 .891 r
.62343 .12104 .63034 .13129 .64415 .12564 .63729 .11553 Mtetra
.669 .73 .895 r
.63729 .11553 .64415 .12564 .65802 .12005 .65122 .11005 Mtetra
.668 .734 .899 r
.65122 .11005 .65802 .12005 .67197 .11453 .66521 .10461 Mtetra
.667 .736 .902 r
.66521 .10461 .67197 .11453 .68598 .10907 .67928 .09918 Mtetra
.666 .738 .904 r
.67928 .09918 .68598 .10907 .70007 .10365 .69342 .09377 Mtetra
.666 .739 .905 r
.69342 .09377 .70007 .10365 .71423 .09825 .70763 .08837 Mtetra
.665 .74 .906 r
.70763 .08837 .71423 .09825 .72846 .09286 .72191 .08296 Mtetra
.665 .741 .907 r
.72191 .08296 .72846 .09286 .74276 .08747 .73626 .07754 Mtetra
.656 .735 .908 r
.08845 .31064 .0969 .31869 .10825 .31467 .09983 .30657 Mtetra
.655 .734 .908 r
.09983 .30657 .10825 .31467 .11965 .31066 .11126 .3025 Mtetra
.654 .734 .908 r
.11126 .3025 .11965 .31066 .13111 .30665 .12274 .29842 Mtetra
.654 .733 .907 r
.12274 .29842 .13111 .30665 .14261 .30262 .13428 .29434 Mtetra
.654 .732 .907 r
.13428 .29434 .14261 .30262 .15417 .29859 .14587 .29024 Mtetra
.653 .731 .906 r
.14587 .29024 .15417 .29859 .16578 .29455 .15751 .28613 Mtetra
.653 .73 .906 r
.15751 .28613 .16578 .29455 .17744 .29049 .16921 .282 Mtetra
.653 .73 .905 r
.16921 .282 .17744 .29049 .18917 .2864 .18096 .27785 Mtetra
.654 .729 .905 r
.18096 .27785 .18917 .2864 .20095 .28228 .19277 .27367 Mtetra
.654 .728 .904 r
.19277 .27367 .20095 .28228 .21278 .27813 .20464 .26945 Mtetra
.655 .728 .903 r
.20464 .26945 .21278 .27813 .22468 .27394 .21657 .2652 Mtetra
.655 .728 .902 r
.21657 .2652 .22468 .27394 .23664 .2697 .22856 .2609 Mtetra
.656 .727 .901 r
.22856 .2609 .23664 .2697 .24865 .26541 .24061 .25655 Mtetra
.657 .727 .901 r
.24061 .25655 .24865 .26541 .26073 .26106 .25271 .25215 Mtetra
.658 .727 .9 r
.25271 .25215 .26073 .26106 .27286 .25665 .26488 .24769 Mtetra
.66 .727 .899 r
.26488 .24769 .27286 .25665 .28506 .25218 .27711 .24316 Mtetra
.661 .727 .899 r
.27711 .24316 .28506 .25218 .29732 .24764 .2894 .23858 Mtetra
.662 .728 .898 r
.2894 .23858 .29732 .24764 .30964 .24303 .30176 .23393 Mtetra
.663 .728 .897 r
.30176 .23393 .30964 .24303 .32202 .23836 .31417 .22922 Mtetra
.665 .729 .897 r
.31417 .22922 .32202 .23836 .33446 .23362 .32664 .22445 Mtetra
.666 .729 .897 r
.32664 .22445 .33446 .23362 .34696 .22881 .33918 .21961 Mtetra
.667 .73 .897 r
.33918 .21961 .34696 .22881 .35952 .22395 .35177 .21472 Mtetra
.668 .73 .896 r
.35177 .21472 .35952 .22395 .37214 .21904 .36442 .20978 Mtetra
.668 .731 .896 r
.36442 .20978 .37214 .21904 .38482 .21409 .37714 .2048 Mtetra
.669 .731 .896 r
.37714 .2048 .38482 .21409 .39756 .20911 .38991 .19977 Mtetra
.38991 .19977 .39756 .20911 .41035 .20412 .40274 .19473 Mtetra
.40274 .19473 .41035 .20412 .42321 .19913 .41564 .18966 Mtetra
.668 .73 .896 r
.41564 .18966 .42321 .19913 .43612 .19416 .42859 .18459 Mtetra
.667 .728 .895 r
.42859 .18459 .43612 .19416 .44909 .1892 .4416 .17952 Mtetra
.666 .726 .894 r
.4416 .17952 .44909 .1892 .46212 .18426 .45467 .17444 Mtetra
.666 .724 .892 r
.45467 .17444 .46212 .18426 .47522 .17933 .46781 .16936 Mtetra
.665 .721 .891 r
.46781 .16936 .47522 .17933 .48838 .17438 .481 .16426 Mtetra
.665 .718 .889 r
.481 .16426 .48838 .17438 .5016 .1694 .49426 .15914 Mtetra
.665 .716 .887 r
.49426 .15914 .5016 .1694 .51488 .16434 .50758 .15397 Mtetra
.666 .715 .885 r
.50758 .15397 .51488 .16434 .52823 .1592 .52097 .14875 Mtetra
.666 .715 .884 r
.52097 .14875 .52823 .1592 .54164 .15395 .53442 .14348 Mtetra
.667 .715 .884 r
.53442 .14348 .54164 .15395 .55512 .1486 .54793 .13814 Mtetra
.668 .717 .885 r
.54793 .13814 .55512 .1486 .56865 .14316 .56151 .13276 Mtetra
.669 .72 .887 r
.56151 .13276 .56865 .14316 .58225 .13765 .57515 .12734 Mtetra
.669 .723 .89 r
.57515 .12734 .58225 .13765 .59591 .13211 .58886 .12189 Mtetra
.669 .726 .892 r
.58886 .12189 .59591 .13211 .60964 .12657 .60263 .11644 Mtetra
.669 .73 .895 r
.60263 .11644 .60964 .12657 .62343 .12104 .61647 .111 Mtetra
.668 .733 .898 r
.61647 .111 .62343 .12104 .63729 .11553 .63038 .10555 Mtetra
.667 .735 .9 r
.63038 .10555 .63729 .11553 .65122 .11005 .64436 .10012 Mtetra
.667 .737 .903 r
.64436 .10012 .65122 .11005 .66521 .10461 .6584 .0947 Mtetra
.666 .739 .904 r
.6584 .0947 .66521 .10461 .67928 .09918 .67252 .08928 Mtetra
.665 .74 .905 r
.67252 .08928 .67928 .09918 .69342 .09377 .68671 .08385 Mtetra
.665 .74 .906 r
.68671 .08385 .69342 .09377 .70763 .08837 .70097 .07842 Mtetra
.665 .741 .907 r
.70097 .07842 .70763 .08837 .72191 .08296 .7153 .07298 Mtetra
.664 .741 .907 r
.7153 .07298 .72191 .08296 .73626 .07754 .72971 .06752 Mtetra
.656 .735 .908 r
.07993 .30253 .08845 .31064 .09983 .30657 .09134 .2984 Mtetra
.09134 .2984 .09983 .30657 .11126 .3025 .1028 .29427 Mtetra
.655 .734 .907 r
.1028 .29427 .11126 .3025 .12274 .29842 .11431 .29013 Mtetra
.655 .733 .907 r
.11431 .29013 .12274 .29842 .13428 .29434 .12588 .28598 Mtetra
.655 .732 .907 r
.12588 .28598 .13428 .29434 .14587 .29024 .1375 .28182 Mtetra
.654 .732 .906 r
.1375 .28182 .14587 .29024 .15751 .28613 .14917 .27765 Mtetra
.654 .731 .906 r
.14917 .27765 .15751 .28613 .16921 .282 .1609 .27345 Mtetra
.654 .73 .905 r
.1609 .27345 .16921 .282 .18096 .27785 .17269 .26924 Mtetra
.655 .73 .904 r
.17269 .26924 .18096 .27785 .19277 .27367 .18453 .26499 Mtetra
.655 .729 .904 r
.18453 .26499 .19277 .27367 .20464 .26945 .19643 .26071 Mtetra
.655 .728 .903 r
.19643 .26071 .20464 .26945 .21657 .2652 .20839 .25639 Mtetra
.656 .728 .902 r
.20839 .25639 .21657 .2652 .22856 .2609 .22041 .25203 Mtetra
.657 .728 .901 r
.22041 .25203 .22856 .2609 .24061 .25655 .23249 .24763 Mtetra
.658 .728 .901 r
.23249 .24763 .24061 .25655 .25271 .25215 .24463 .24317 Mtetra
.659 .727 .9 r
.24463 .24317 .25271 .25215 .26488 .24769 .25684 .23866 Mtetra
.66 .727 .899 r
.25684 .23866 .26488 .24769 .27711 .24316 .2691 .23409 Mtetra
.661 .728 .899 r
.2691 .23409 .27711 .24316 .2894 .23858 .28142 .22946 Mtetra
.662 .728 .898 r
.28142 .22946 .2894 .23858 .30176 .23393 .29381 .22477 Mtetra
.663 .728 .898 r
.29381 .22477 .30176 .23393 .31417 .22922 .30625 .22002 Mtetra
.664 .729 .897 r
.30625 .22002 .31417 .22922 .32664 .22445 .31876 .21521 Mtetra
.665 .729 .897 r
.31876 .21521 .32664 .22445 .33918 .21961 .33133 .21035 Mtetra
.666 .73 .897 r
.33133 .21035 .33918 .21961 .35177 .21472 .34395 .20543 Mtetra
.667 .731 .897 r
.34395 .20543 .35177 .21472 .36442 .20978 .35664 .20046 Mtetra
.668 .731 .897 r
.35664 .20046 .36442 .20978 .37714 .2048 .36939 .19545 Mtetra
.668 .732 .897 r
.36939 .19545 .37714 .2048 .38991 .19977 .3822 .19039 Mtetra
.669 .732 .897 r
.3822 .19039 .38991 .19977 .40274 .19473 .39507 .18531 Mtetra
.39507 .18531 .40274 .19473 .41564 .18966 .408 .18019 Mtetra
.408 .18019 .41564 .18966 .42859 .18459 .42099 .17506 Mtetra
.668 .731 .897 r
.42099 .17506 .42859 .18459 .4416 .17952 .43404 .16992 Mtetra
.43404 .16992 .4416 .17952 .45467 .17444 .44715 .16476 Mtetra
.668 .73 .896 r
.44715 .16476 .45467 .17444 .46781 .16936 .46033 .15959 Mtetra
.667 .728 .895 r
.46033 .15959 .46781 .16936 .481 .16426 .47356 .1544 Mtetra
.667 .727 .894 r
.47356 .1544 .481 .16426 .49426 .15914 .48686 .14919 Mtetra
.667 .726 .894 r
.48686 .14919 .49426 .15914 .50758 .15397 .50022 .14395 Mtetra
.667 .726 .893 r
.50022 .14395 .50758 .15397 .52097 .14875 .51365 .13868 Mtetra
.51365 .13868 .52097 .14875 .53442 .14348 .52714 .13338 Mtetra
.668 .726 .893 r
.52714 .13338 .53442 .14348 .54793 .13814 .54069 .12804 Mtetra
.668 .727 .894 r
.54069 .12804 .54793 .13814 .56151 .13276 .55432 .12268 Mtetra
.668 .729 .895 r
.55432 .12268 .56151 .13276 .57515 .12734 .568 .11729 Mtetra
.668 .731 .897 r
.568 .11729 .57515 .12734 .58886 .12189 .58175 .11188 Mtetra
.668 .733 .899 r
.58175 .11188 .58886 .12189 .60263 .11644 .59557 .10647 Mtetra
.667 .735 .9 r
.59557 .10647 .60263 .11644 .61647 .111 .60946 .10105 Mtetra
.667 .736 .902 r
.60946 .10105 .61647 .111 .63038 .10555 .62341 .09562 Mtetra
.666 .738 .903 r
.62341 .09562 .63038 .10555 .64436 .10012 .63744 .09019 Mtetra
.666 .739 .905 r
.63744 .09019 .64436 .10012 .6584 .0947 .65154 .08476 Mtetra
.665 .74 .906 r
.65154 .08476 .6584 .0947 .67252 .08928 .6657 .07932 Mtetra
.6657 .07932 .67252 .08928 .68671 .08385 .67994 .07387 Mtetra
.665 .741 .907 r
.67994 .07387 .68671 .08385 .70097 .07842 .69425 .0684 Mtetra
.664 .741 .907 r
.69425 .0684 .70097 .07842 .7153 .07298 .70863 .06291 Mtetra
.70863 .06291 .7153 .07298 .72971 .06752 .72309 .05741 Mtetra
.657 .736 .908 r
.07133 .29436 .07993 .30253 .09134 .2984 .08277 .29018 Mtetra
.657 .735 .907 r
.08277 .29018 .09134 .2984 .1028 .29427 .09426 .28598 Mtetra
.656 .734 .907 r
.09426 .28598 .1028 .29427 .11431 .29013 .10581 .28178 Mtetra
.10581 .28178 .11431 .29013 .12588 .28598 .11741 .27757 Mtetra
.656 .733 .906 r
.11741 .27757 .12588 .28598 .1375 .28182 .12906 .27335 Mtetra
.655 .732 .906 r
.12906 .27335 .1375 .28182 .14917 .27765 .14076 .26911 Mtetra
.655 .731 .905 r
.14076 .26911 .14917 .27765 .1609 .27345 .15253 .26485 Mtetra
.15253 .26485 .1609 .27345 .17269 .26924 .16435 .26056 Mtetra
.656 .73 .904 r
.16435 .26056 .17269 .26924 .18453 .26499 .17622 .25625 Mtetra
.17622 .25625 .18453 .26499 .19643 .26071 .18816 .25191 Mtetra
.656 .729 .903 r
.18816 .25191 .19643 .26071 .20839 .25639 .20015 .24753 Mtetra
.657 .729 .902 r
.20015 .24753 .20839 .25639 .22041 .25203 .2122 .24311 Mtetra
.658 .728 .902 r
.2122 .24311 .22041 .25203 .23249 .24763 .22431 .23864 Mtetra
.658 .728 .901 r
.22431 .23864 .23249 .24763 .24463 .24317 .23649 .23413 Mtetra
.659 .728 .9 r
.23649 .23413 .24463 .24317 .25684 .23866 .24872 .22957 Mtetra
.66 .728 .9 r
.24872 .22957 .25684 .23866 .2691 .23409 .26101 .22495 Mtetra
.661 .728 .899 r
.26101 .22495 .2691 .23409 .28142 .22946 .27337 .22028 Mtetra
.662 .728 .899 r
.27337 .22028 .28142 .22946 .29381 .22477 .28579 .21555 Mtetra
.663 .729 .898 r
.28579 .21555 .29381 .22477 .30625 .22002 .29827 .21076 Mtetra
.664 .729 .898 r
.29827 .21076 .30625 .22002 .31876 .21521 .31081 .20592 Mtetra
.665 .73 .898 r
.31081 .20592 .31876 .21521 .33133 .21035 .32341 .20102 Mtetra
.666 .73 .898 r
.32341 .20102 .33133 .21035 .34395 .20543 .33607 .19608 Mtetra
.667 .731 .897 r
.33607 .19608 .34395 .20543 .35664 .20046 .34879 .19108 Mtetra
.668 .731 .898 r
.34879 .19108 .35664 .20046 .36939 .19545 .36158 .18604 Mtetra
.668 .732 .898 r
.36158 .18604 .36939 .19545 .3822 .19039 .37442 .18096 Mtetra
.668 .733 .898 r
.37442 .18096 .3822 .19039 .39507 .18531 .38733 .17584 Mtetra
.669 .733 .898 r
.38733 .17584 .39507 .18531 .408 .18019 .4003 .1707 Mtetra
.4003 .1707 .408 .18019 .42099 .17506 .41332 .16553 Mtetra
.41332 .16553 .42099 .17506 .43404 .16992 .42641 .16034 Mtetra
.668 .733 .898 r
.42641 .16034 .43404 .16992 .44715 .16476 .43956 .15513 Mtetra
.43956 .15513 .44715 .16476 .46033 .15959 .45278 .1499 Mtetra
.45278 .1499 .46033 .15959 .47356 .1544 .46605 .14465 Mtetra
.668 .732 .898 r
.46605 .14465 .47356 .1544 .48686 .14919 .47939 .13939 Mtetra
.47939 .13939 .48686 .14919 .50022 .14395 .4928 .1341 Mtetra
.4928 .1341 .50022 .14395 .51365 .13868 .50626 .1288 Mtetra
.667 .732 .898 r
.50626 .1288 .51365 .13868 .52714 .13338 .5198 .12347 Mtetra
.667 .733 .899 r
.5198 .12347 .52714 .13338 .54069 .12804 .53339 .11812 Mtetra
.53339 .11812 .54069 .12804 .55432 .12268 .54706 .11274 Mtetra
.667 .734 .9 r
.54706 .11274 .55432 .12268 .568 .11729 .56079 .10736 Mtetra
.667 .736 .901 r
.56079 .10736 .568 .11729 .58175 .11188 .57458 .10195 Mtetra
.667 .737 .902 r
.57458 .10195 .58175 .11188 .59557 .10647 .58845 .09654 Mtetra
.666 .738 .903 r
.58845 .09654 .59557 .10647 .60946 .10105 .60238 .09111 Mtetra
.666 .739 .904 r
.60238 .09111 .60946 .10105 .62341 .09562 .61639 .08567 Mtetra
.666 .739 .905 r
.61639 .08567 .62341 .09562 .63744 .09019 .63046 .08023 Mtetra
.665 .74 .906 r
.63046 .08023 .63744 .09019 .65154 .08476 .6446 .07477 Mtetra
.6446 .07477 .65154 .08476 .6657 .07932 .65882 .06929 Mtetra
.665 .741 .907 r
.65882 .06929 .6657 .07932 .67994 .07387 .67311 .0638 Mtetra
.664 .741 .907 r
.67311 .0638 .67994 .07387 .69425 .0684 .68747 .05829 Mtetra
.68747 .05829 .69425 .0684 .70863 .06291 .7019 .05276 Mtetra
.7019 .05276 .70863 .06291 .72309 .05741 .71641 .0472 Mtetra
.658 .736 .908 r
.06266 .28614 .07133 .29436 .08277 .29018 .07414 .28189 Mtetra
.657 .736 .907 r
.07414 .28189 .08277 .29018 .09426 .28598 .08566 .27764 Mtetra
.657 .735 .907 r
.08566 .27764 .09426 .28598 .10581 .28178 .09723 .27338 Mtetra
.657 .734 .907 r
.09723 .27338 .10581 .28178 .11741 .27757 .10886 .2691 Mtetra
.656 .733 .906 r
.10886 .2691 .11741 .27757 .12906 .27335 .12055 .26481 Mtetra
.12055 .26481 .12906 .27335 .14076 .26911 .13229 .26051 Mtetra
.656 .732 .905 r
.13229 .26051 .14076 .26911 .15253 .26485 .14408 .25618 Mtetra
.656 .731 .905 r
.14408 .25618 .15253 .26485 .16435 .26056 .15593 .25184 Mtetra
.656 .731 .904 r
.15593 .25184 .16435 .26056 .17622 .25625 .16784 .24746 Mtetra
.657 .73 .904 r
.16784 .24746 .17622 .25625 .18816 .25191 .1798 .24305 Mtetra
.657 .73 .903 r
.1798 .24305 .18816 .25191 .20015 .24753 .19183 .23861 Mtetra
.658 .729 .902 r
.19183 .23861 .20015 .24753 .2122 .24311 .20391 .23413 Mtetra
.20391 .23413 .2122 .24311 .22431 .23864 .21606 .22961 Mtetra
.659 .729 .901 r
.21606 .22961 .22431 .23864 .23649 .23413 .22827 .22504 Mtetra
.66 .729 .9 r
.22827 .22504 .23649 .23413 .24872 .22957 .24053 .22043 Mtetra
.24053 .22043 .24872 .22957 .26101 .22495 .25286 .21576 Mtetra
.661 .729 .899 r
.25286 .21576 .26101 .22495 .27337 .22028 .26525 .21104 Mtetra
.662 .729 .899 r
.26525 .21104 .27337 .22028 .28579 .21555 .2777 .20627 Mtetra
.663 .729 .899 r
.2777 .20627 .28579 .21555 .29827 .21076 .29021 .20145 Mtetra
.664 .73 .898 r
.29021 .20145 .29827 .21076 .31081 .20592 .30278 .19657 Mtetra
.665 .73 .898 r
.30278 .19657 .31081 .20592 .32341 .20102 .31542 .19164 Mtetra
.666 .731 .898 r
.31542 .19164 .32341 .20102 .33607 .19608 .32812 .18667 Mtetra
.32812 .18667 .33607 .19608 .34879 .19108 .34088 .18165 Mtetra
.667 .732 .898 r
.34088 .18165 .34879 .19108 .36158 .18604 .3537 .17658 Mtetra
.668 .733 .898 r
.3537 .17658 .36158 .18604 .37442 .18096 .36658 .17147 Mtetra
.668 .733 .899 r
.36658 .17147 .37442 .18096 .38733 .17584 .37952 .16633 Mtetra
.668 .734 .899 r
.37952 .16633 .38733 .17584 .4003 .1707 .39252 .16116 Mtetra
.39252 .16116 .4003 .1707 .41332 .16553 .40559 .15596 Mtetra
.668 .735 .899 r
.40559 .15596 .41332 .16553 .42641 .16034 .41872 .15073 Mtetra
.668 .735 .9 r
.41872 .15073 .42641 .16034 .43956 .15513 .43191 .14549 Mtetra
.43191 .14549 .43956 .15513 .45278 .1499 .44516 .14022 Mtetra
.44516 .14022 .45278 .1499 .46605 .14465 .45848 .13494 Mtetra
.45848 .13494 .46605 .14465 .47939 .13939 .47186 .12964 Mtetra
.668 .735 .901 r
.47186 .12964 .47939 .13939 .4928 .1341 .4853 .12431 Mtetra
.667 .736 .901 r
.4853 .12431 .4928 .1341 .50626 .1288 .49881 .11898 Mtetra
.49881 .11898 .50626 .1288 .5198 .12347 .51239 .11362 Mtetra
.667 .736 .902 r
.51239 .11362 .5198 .12347 .53339 .11812 .52603 .10824 Mtetra
.667 .737 .902 r
.52603 .10824 .53339 .11812 .54706 .11274 .53973 .10285 Mtetra
.667 .737 .903 r
.53973 .10285 .54706 .11274 .56079 .10736 .55351 .09744 Mtetra
.666 .738 .904 r
.55351 .09744 .56079 .10736 .57458 .10195 .56735 .09202 Mtetra
.666 .739 .904 r
.56735 .09202 .57458 .10195 .58845 .09654 .58126 .08659 Mtetra
.666 .739 .905 r
.58126 .08659 .58845 .09654 .60238 .09111 .59524 .08114 Mtetra
.665 .74 .906 r
.59524 .08114 .60238 .09111 .61639 .08567 .60929 .07567 Mtetra
.60929 .07567 .61639 .08567 .63046 .08023 .62342 .07019 Mtetra
.665 .741 .906 r
.62342 .07019 .63046 .08023 .6446 .07477 .63761 .06469 Mtetra
.665 .741 .907 r
.63761 .06469 .6446 .07477 .65882 .06929 .65187 .05918 Mtetra
.664 .741 .907 r
.65187 .05918 .65882 .06929 .67311 .0638 .66621 .05364 Mtetra
.66621 .05364 .67311 .0638 .68747 .05829 .68062 .04809 Mtetra
.68062 .04809 .68747 .05829 .7019 .05276 .69511 .04251 Mtetra
.664 .741 .908 r
.69511 .04251 .7019 .05276 .71641 .0472 .70967 .03691 Mtetra
.658 .737 .907 r
.05392 .27785 .06266 .28614 .07414 .28189 .06543 .27354 Mtetra
.658 .736 .907 r
.06543 .27354 .07414 .28189 .08566 .27764 .07698 .26923 Mtetra
.658 .735 .907 r
.07698 .26923 .08566 .27764 .09723 .27338 .08859 .26491 Mtetra
.657 .735 .907 r
.08859 .26491 .09723 .27338 .10886 .2691 .10025 .26058 Mtetra
.657 .734 .906 r
.10025 .26058 .10886 .2691 .12055 .26481 .11196 .25622 Mtetra
.657 .733 .906 r
.11196 .25622 .12055 .26481 .13229 .26051 .12373 .25186 Mtetra
.657 .733 .905 r
.12373 .25186 .13229 .26051 .14408 .25618 .13556 .24747 Mtetra
.657 .732 .905 r
.13556 .24747 .14408 .25618 .15593 .25184 .14744 .24306 Mtetra
.657 .732 .904 r
.14744 .24306 .15593 .25184 .16784 .24746 .15938 .23862 Mtetra
.657 .731 .904 r
.15938 .23862 .16784 .24746 .1798 .24305 .17138 .23415 Mtetra
.658 .731 .903 r
.17138 .23415 .1798 .24305 .19183 .23861 .18344 .22965 Mtetra
.658 .73 .903 r
.18344 .22965 .19183 .23861 .20391 .23413 .19556 .22511 Mtetra
.659 .73 .902 r
.19556 .22511 .20391 .23413 .21606 .22961 .20774 .22053 Mtetra
.659 .73 .901 r
.20774 .22053 .21606 .22961 .22827 .22504 .21997 .21591 Mtetra
.66 .73 .901 r
.21997 .21591 .22827 .22504 .24053 .22043 .23227 .21124 Mtetra
.661 .73 .9 r
.23227 .21124 .24053 .22043 .25286 .21576 .24463 .20652 Mtetra
.662 .73 .9 r
.24463 .20652 .25286 .21576 .26525 .21104 .25706 .20176 Mtetra
.25706 .20176 .26525 .21104 .2777 .20627 .26954 .19695 Mtetra
.663 .73 .899 r
.26954 .19695 .2777 .20627 .29021 .20145 .28209 .19209 Mtetra
.664 .73 .899 r
.28209 .19209 .29021 .20145 .30278 .19657 .29469 .18717 Mtetra
.665 .731 .899 r
.29469 .18717 .30278 .19657 .31542 .19164 .30736 .18221 Mtetra
.30736 .18221 .31542 .19164 .32812 .18667 .32009 .17721 Mtetra
.666 .732 .899 r
.32009 .17721 .32812 .18667 .34088 .18165 .33289 .17216 Mtetra
.667 .732 .899 r
.33289 .17216 .34088 .18165 .3537 .17658 .34574 .16706 Mtetra
.667 .733 .899 r
.34574 .16706 .3537 .17658 .36658 .17147 .35866 .16193 Mtetra
.667 .734 .899 r
.35866 .16193 .36658 .17147 .37952 .16633 .37164 .15677 Mtetra
.668 .734 .9 r
.37164 .15677 .37952 .16633 .39252 .16116 .38468 .15157 Mtetra
.668 .735 .9 r
.38468 .15157 .39252 .16116 .40559 .15596 .39779 .14634 Mtetra
.39779 .14634 .40559 .15596 .41872 .15073 .41095 .14109 Mtetra
.668 .736 .901 r
.41095 .14109 .41872 .15073 .43191 .14549 .42418 .13582 Mtetra
.42418 .13582 .43191 .14549 .44516 .14022 .43747 .13052 Mtetra
.43747 .13052 .44516 .14022 .45848 .13494 .45083 .1252 Mtetra
.668 .737 .902 r
.45083 .1252 .45848 .13494 .47186 .12964 .46425 .11987 Mtetra
.667 .737 .902 r
.46425 .11987 .47186 .12964 .4853 .12431 .47774 .11452 Mtetra
.667 .737 .903 r
.47774 .11452 .4853 .12431 .49881 .11898 .49129 .10915 Mtetra
.667 .738 .903 r
.49129 .10915 .49881 .11898 .51239 .11362 .50491 .10376 Mtetra
.50491 .10376 .51239 .11362 .52603 .10824 .51859 .09836 Mtetra
.666 .739 .904 r
.51859 .09836 .52603 .10824 .53973 .10285 .53234 .09294 Mtetra
.53234 .09294 .53973 .10285 .55351 .09744 .54616 .0875 Mtetra
.666 .739 .905 r
.54616 .0875 .55351 .09744 .56735 .09202 .56005 .08205 Mtetra
.666 .74 .905 r
.56005 .08205 .56735 .09202 .58126 .08659 .57401 .07658 Mtetra
.665 .74 .906 r
.57401 .07658 .58126 .08659 .59524 .08114 .58804 .0711 Mtetra
.58804 .0711 .59524 .08114 .60929 .07567 .60214 .0656 Mtetra
.665 .741 .907 r
.60214 .0656 .60929 .07567 .62342 .07019 .61631 .06008 Mtetra
.61631 .06008 .62342 .07019 .63761 .06469 .63055 .05454 Mtetra
.664 .741 .907 r
.63055 .05454 .63761 .06469 .65187 .05918 .64486 .04898 Mtetra
.64486 .04898 .65187 .05918 .66621 .05364 .65925 .0434 Mtetra
.65925 .0434 .66621 .05364 .68062 .04809 .67371 .03779 Mtetra
.664 .741 .908 r
.67371 .03779 .68062 .04809 .69511 .04251 .68825 .03216 Mtetra
.68825 .03216 .69511 .04251 .70967 .03691 .70286 .02651 Mtetra
.659 .737 .907 r
.04511 .2695 .05392 .27785 .06543 .27354 .05664 .26514 Mtetra
.659 .736 .907 r
.05664 .26514 .06543 .27354 .07698 .26923 .06823 .26077 Mtetra
.658 .736 .907 r
.06823 .26077 .07698 .26923 .08859 .26491 .07986 .25639 Mtetra
.658 .735 .907 r
.07986 .25639 .08859 .26491 .10025 .26058 .09156 .25199 Mtetra
.658 .735 .906 r
.09156 .25199 .10025 .26058 .11196 .25622 .1033 .24758 Mtetra
.658 .734 .906 r
.1033 .24758 .11196 .25622 .12373 .25186 .11511 .24315 Mtetra
.658 .733 .905 r
.11511 .24315 .12373 .25186 .13556 .24747 .12696 .2387 Mtetra
.12696 .2387 .13556 .24747 .14744 .24306 .13888 .23423 Mtetra
.658 .732 .904 r
.13888 .23423 .14744 .24306 .15938 .23862 .15085 .22972 Mtetra
.15085 .22972 .15938 .23862 .17138 .23415 .16288 .2252 Mtetra
.658 .731 .903 r
.16288 .2252 .17138 .23415 .18344 .22965 .17498 .22063 Mtetra
.659 .731 .903 r
.17498 .22063 .18344 .22965 .19556 .22511 .18713 .21604 Mtetra
.659 .731 .902 r
.18713 .21604 .19556 .22511 .20774 .22053 .19934 .2114 Mtetra
.66 .731 .902 r
.19934 .2114 .20774 .22053 .21997 .21591 .21161 .20672 Mtetra
.66 .73 .901 r
.21161 .20672 .21997 .21591 .23227 .21124 .22394 .202 Mtetra
.661 .73 .901 r
.22394 .202 .23227 .21124 .24463 .20652 .23633 .19724 Mtetra
.662 .73 .901 r
.23633 .19724 .24463 .20652 .25706 .20176 .24879 .19243 Mtetra
.662 .731 .9 r
.24879 .19243 .25706 .20176 .26954 .19695 .26131 .18758 Mtetra
.663 .731 .9 r
.26131 .18758 .26954 .19695 .28209 .19209 .27389 .18267 Mtetra
.664 .731 .9 r
.27389 .18267 .28209 .19209 .29469 .18717 .28653 .17773 Mtetra
.664 .732 .9 r
.28653 .17773 .29469 .18717 .30736 .18221 .29923 .17273 Mtetra
.665 .732 .9 r
.29923 .17273 .30736 .18221 .32009 .17721 .312 .16769 Mtetra
.666 .732 .9 r
.312 .16769 .32009 .17721 .33289 .17216 .32483 .16261 Mtetra
.666 .733 .9 r
.32483 .16261 .33289 .17216 .34574 .16706 .33772 .1575 Mtetra
.667 .734 .9 r
.33772 .1575 .34574 .16706 .35866 .16193 .35067 .15234 Mtetra
.35067 .15234 .35866 .16193 .37164 .15677 .36369 .14715 Mtetra
.667 .735 .9 r
.36369 .14715 .37164 .15677 .38468 .15157 .37677 .14193 Mtetra
.667 .735 .901 r
.37677 .14193 .38468 .15157 .39779 .14634 .38991 .13667 Mtetra
.667 .736 .901 r
.38991 .13667 .39779 .14634 .41095 .14109 .40312 .1314 Mtetra
.667 .736 .902 r
.40312 .1314 .41095 .14109 .42418 .13582 .41638 .12609 Mtetra
.667 .737 .902 r
.41638 .12609 .42418 .13582 .43747 .13052 .42972 .12077 Mtetra
.42972 .12077 .43747 .13052 .45083 .1252 .44312 .11542 Mtetra
.667 .738 .903 r
.44312 .11542 .45083 .1252 .46425 .11987 .45658 .11006 Mtetra
.45658 .11006 .46425 .11987 .47774 .11452 .47011 .10468 Mtetra
.667 .738 .904 r
.47011 .10468 .47774 .11452 .49129 .10915 .4837 .09928 Mtetra
.667 .739 .904 r
.4837 .09928 .49129 .10915 .50491 .10376 .49736 .09386 Mtetra
.666 .739 .904 r
.49736 .09386 .50491 .10376 .51859 .09836 .51109 .08842 Mtetra
.666 .739 .905 r
.51109 .08842 .51859 .09836 .53234 .09294 .52489 .08297 Mtetra
.666 .74 .905 r
.52489 .08297 .53234 .09294 .54616 .0875 .53875 .0775 Mtetra
.666 .74 .906 r
.53875 .0775 .54616 .0875 .56005 .08205 .55269 .07201 Mtetra
.665 .74 .906 r
.55269 .07201 .56005 .08205 .57401 .07658 .56669 .06651 Mtetra
.56669 .06651 .57401 .07658 .58804 .0711 .58077 .06098 Mtetra
.665 .741 .907 r
.58077 .06098 .58804 .0711 .60214 .0656 .59491 .05544 Mtetra
.59491 .05544 .60214 .0656 .61631 .06008 .60913 .04988 Mtetra
.60913 .04988 .61631 .06008 .63055 .05454 .62342 .04429 Mtetra
.664 .741 .907 r
.62342 .04429 .63055 .05454 .64486 .04898 .63779 .03869 Mtetra
.63779 .03869 .64486 .04898 .65925 .0434 .65223 .03306 Mtetra
.65223 .03306 .65925 .0434 .67371 .03779 .66674 .0274 Mtetra
.664 .741 .908 r
.66674 .0274 .67371 .03779 .68825 .03216 .68133 .02172 Mtetra
.68133 .02172 .68825 .03216 .70286 .02651 .69599 .01602 Mtetra
.66 .737 .907 r
.03622 .26109 .04511 .2695 .05664 .26514 .04778 .25667 Mtetra
.659 .737 .907 r
.04778 .25667 .05664 .26514 .06823 .26077 .0594 .25225 Mtetra
.659 .736 .907 r
.0594 .25225 .06823 .26077 .07986 .25639 .07106 .24781 Mtetra
.07106 .24781 .07986 .25639 .09156 .25199 .08279 .24335 Mtetra
.659 .735 .906 r
.08279 .24335 .09156 .25199 .1033 .24758 .09457 .23888 Mtetra
.09457 .23888 .1033 .24758 .11511 .24315 .1064 .23439 Mtetra
.659 .734 .906 r
.1064 .23439 .11511 .24315 .12696 .2387 .11829 .22988 Mtetra
.659 .734 .905 r
.11829 .22988 .12696 .2387 .13888 .23423 .13024 .22534 Mtetra
.659 .733 .905 r
.13024 .22534 .13888 .23423 .15085 .22972 .14225 .22078 Mtetra
.659 .733 .904 r
.14225 .22078 .15085 .22972 .16288 .2252 .15431 .21619 Mtetra
.659 .732 .904 r
.15431 .21619 .16288 .2252 .17498 .22063 .16644 .21157 Mtetra
.659 .732 .903 r
.16644 .21157 .17498 .22063 .18713 .21604 .17862 .20692 Mtetra
.66 .732 .903 r
.17862 .20692 .18713 .21604 .19934 .2114 .19086 .20222 Mtetra
.66 .731 .902 r
.19086 .20222 .19934 .2114 .21161 .20672 .20317 .19749 Mtetra
.661 .731 .902 r
.20317 .19749 .21161 .20672 .22394 .202 .21553 .19272 Mtetra
.661 .731 .901 r
.21553 .19272 .22394 .202 .23633 .19724 .22796 .18791 Mtetra
.662 .731 .901 r
.22796 .18791 .23633 .19724 .24879 .19243 .24045 .18306 Mtetra
.24045 .18306 .24879 .19243 .26131 .18758 .253 .17816 Mtetra
.663 .732 .901 r
.253 .17816 .26131 .18758 .27389 .18267 .26562 .17322 Mtetra
.664 .732 .9 r
.26562 .17322 .27389 .18267 .28653 .17773 .27829 .16823 Mtetra
.27829 .16823 .28653 .17773 .29923 .17273 .29103 .1632 Mtetra
.665 .733 .9 r
.29103 .1632 .29923 .17273 .312 .16769 .30383 .15813 Mtetra
.30383 .15813 .312 .16769 .32483 .16261 .3167 .15302 Mtetra
.666 .734 .9 r
.3167 .15302 .32483 .16261 .33772 .1575 .32962 .14787 Mtetra
.666 .734 .901 r
.32962 .14787 .33772 .1575 .35067 .15234 .34261 .14269 Mtetra
.666 .735 .901 r
.34261 .14269 .35067 .15234 .36369 .14715 .35567 .13747 Mtetra
.667 .735 .901 r
.35567 .13747 .36369 .14715 .37677 .14193 .36878 .13222 Mtetra
.667 .736 .901 r
.36878 .13222 .37677 .14193 .38991 .13667 .38196 .12694 Mtetra
.667 .736 .902 r
.38196 .12694 .38991 .13667 .40312 .1314 .39521 .12164 Mtetra
.667 .737 .902 r
.39521 .12164 .40312 .1314 .41638 .12609 .40852 .11631 Mtetra
.667 .737 .903 r
.40852 .11631 .41638 .12609 .42972 .12077 .42189 .11096 Mtetra
.667 .738 .903 r
.42189 .11096 .42972 .12077 .44312 .11542 .43533 .10558 Mtetra
.43533 .10558 .44312 .11542 .45658 .11006 .44883 .10019 Mtetra
.667 .739 .904 r
.44883 .10019 .45658 .11006 .47011 .10468 .4624 .09477 Mtetra
.666 .739 .904 r
.4624 .09477 .47011 .10468 .4837 .09928 .47604 .08934 Mtetra
.666 .739 .905 r
.47604 .08934 .4837 .09928 .49736 .09386 .48975 .08389 Mtetra
.666 .74 .905 r
.48975 .08389 .49736 .09386 .51109 .08842 .50352 .07842 Mtetra
.50352 .07842 .51109 .08842 .52489 .08297 .51736 .07293 Mtetra
.666 .74 .906 r
.51736 .07293 .52489 .08297 .53875 .0775 .53127 .06742 Mtetra
.665 .74 .906 r
.53127 .06742 .53875 .0775 .55269 .07201 .54525 .06189 Mtetra
.54525 .06189 .55269 .07201 .56669 .06651 .5593 .05635 Mtetra
.665 .741 .907 r
.5593 .05635 .56669 .06651 .58077 .06098 .57343 .05078 Mtetra
.57343 .05078 .58077 .06098 .59491 .05544 .58762 .0452 Mtetra
.58762 .0452 .59491 .05544 .60913 .04988 .60189 .03959 Mtetra
.664 .741 .907 r
.60189 .03959 .60913 .04988 .62342 .04429 .61623 .03395 Mtetra
.61623 .03395 .62342 .04429 .63779 .03869 .63064 .0283 Mtetra
.63064 .0283 .63779 .03869 .65223 .03306 .64513 .02262 Mtetra
.664 .741 .908 r
.64513 .02262 .65223 .03306 .66674 .0274 .6597 .01691 Mtetra
.6597 .01691 .66674 .0274 .68133 .02172 .67434 .01118 Mtetra
.67434 .01118 .68133 .02172 .69599 .01602 .68905 .00542 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.758 .33964 m
.7838 .3407 L
.79882 .3452 L
.8096 .34994 L
.83412 .371 L
.8354 .3717 L
.84837 .3968 L
.8529 .4226 L
.84947 .4484 L
.8365 .4742 L
.8354 .47577 L
.8096 .49848 L
.80642 .5 L
.7838 .50804 L
.758 .50909 L
.7322 .50178 L
.72784 .5 L
.7064 .48419 L
.69824 .4742 L
.68562 .4484 L
.68234 .4226 L
.68668 .3968 L
.70097 .371 L
.7064 .36473 L
.7322 .34676 L
.73623 .3452 L
.758 .33964 L
s
.6806 .29283 m
.7064 .29163 L
.71744 .2936 L
.7322 .29832 L
.758 .31646 L
.76074 .3194 L
.7769 .3452 L
.78234 .371 L
.78012 .3968 L
.76911 .4226 L
.758 .43686 L
.74437 .4484 L
.7322 .45405 L
.7064 .46115 L
.6806 .45997 L
.6548 .45003 L
.65182 .4484 L
.629 .42746 L
.62583 .4226 L
.61441 .3968 L
.61208 .371 L
.61779 .3452 L
.629 .32329 L
.63324 .3194 L
.6548 .30207 L
.67718 .2936 L
.6806 .29283 L
s
.3452 .53505 m
.371 .52996 L
.3968 .53481 L
.41906 .5516 L
.4226 .55578 L
.43433 .5774 L
.43653 .6032 L
.42738 .629 L
.4226 .63705 L
.3981 .6548 L
.3968 .6554 L
.371 .6609 L
.3452 .65514 L
.34447 .6548 L
.3194 .63616 L
.31524 .629 L
.30607 .6032 L
.30828 .5774 L
.3194 .55653 L
.32351 .5516 L
.3452 .53505 L
s
.3968 .56819 m
.4226 .55983 L
.4484 .56239 L
.47299 .5774 L
.4742 .57854 L
.49117 .6032 L
.49471 .629 L
.48798 .6548 L
.4742 .67521 L
.46315 .6806 L
.4484 .68772 L
.4226 .69044 L
.3968 .68173 L
.39449 .6806 L
.37112 .6548 L
.371 .65438 L
.36386 .629 L
.36781 .6032 L
.371 .59619 L
.38264 .5774 L
.3968 .56819 L
s
.2936 .16413 m
.3194 .1588 L
.3452 .15662 L
.371 .15747 L
.3968 .16141 L
.41075 .1646 L
.4226 .16858 L
.4484 .17936 L
.46816 .1904 L
.4742 .19439 L
.5 .21485 L
.50146 .2162 L
.52489 .242 L
.5258 .24318 L
.54209 .2678 L
.5516 .28645 L
.5546 .2936 L
.5633 .3194 L
.5686 .3452 L
.57078 .371 L
.56992 .3968 L
.56598 .4226 L
.55879 .4484 L
.5516 .46678 L
.548 .4742 L
.53297 .5 L
.5258 .51 L
.51253 .5258 L
.5 .53832 L
.48418 .5516 L
.4742 .55875 L
.4484 .57377 L
.44091 .5774 L
.4226 .58455 L
.3968 .59174 L
.371 .59566 L
.3452 .59652 L
.3194 .59434 L
.2936 .58902 L
.2678 .58032 L
.26085 .5774 L
.242 .5678 L
.21751 .5516 L
.2162 .55059 L
.1904 .52714 L
.18916 .5258 L
.16869 .5 L
.1646 .49381 L
.15365 .4742 L
.14286 .4484 L
Mistroke
.1388 .43627 L
.13568 .4226 L
.13174 .3968 L
.13087 .371 L
.13305 .3452 L
.13837 .3194 L
.1388 .31772 L
.14704 .2936 L
.15957 .2678 L
.1646 .25933 L
.17674 .242 L
.1904 .22596 L
.20015 .2162 L
.2162 .20252 L
.2335 .1904 L
.242 .18534 L
.2678 .17281 L
.29176 .1646 L
.2936 .16413 L
Mfstroke
0 g
.03 w
.76753 .42432 Mdot
.69731 .37627 Mdot
.37129 .59562 Mdot
.42909 .62528 Mdot
.35083 .37657 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.38235 .58629 m
.40196 .58308 L
.42157 .59376 L
.4259 .59804 L
.43158 .61765 L
.42157 .63039 L
.40196 .63697 L
.38235 .62952 L
.36887 .61765 L
.3721 .59804 L
.38235 .58629 L
s
.38235 .56876 m
.40196 .5678 L
.42157 .57528 L
.42678 .57843 L
.44118 .59689 L
.44173 .59804 L
.44527 .61765 L
.44118 .63108 L
.43715 .63725 L
.42157 .6499 L
.40196 .65229 L
.38235 .64696 L
.36707 .63725 L
.36275 .62946 L
.35642 .61765 L
.35487 .59804 L
.36275 .58216 L
.36625 .57843 L
.38235 .56876 L
s
.38235 .55686 m
.40196 .55648 L
.41225 .55882 L
.42157 .56214 L
.44118 .57625 L
.44314 .57843 L
.45506 .59804 L
.45807 .61765 L
.45306 .63725 L
.44118 .65294 L
.43308 .65686 L
.42157 .66154 L
.40196 .66329 L
.38235 .65866 L
.37721 .65686 L
.36275 .6474 L
.35349 .63725 L
.34375 .61765 L
.34314 .615 L
.34216 .59804 L
.34314 .59276 L
.3487 .57843 L
.36275 .56389 L
.375 .55882 L
.38235 .55686 L
s
.36275 .55112 m
.38235 .54537 L
.40196 .54543 L
.42157 .55066 L
.43749 .55882 L
.44118 .56179 L
.45714 .57843 L
.46078 .5843 L
.46687 .59804 L
.46972 .61765 L
.46584 .63725 L
.46078 .64945 L
.4532 .65686 L
.44118 .66578 L
.42157 .67295 L
.40196 .67401 L
.38235 .66995 L
.36275 .66011 L
.3582 .65686 L
.34314 .64152 L
.34045 .63725 L
.33191 .61765 L
.33018 .59804 L
.33531 .57843 L
.34314 .56508 L
.35004 .55882 L
.36275 .55112 L
s
.36275 .53875 m
.38235 .53426 L
.40196 .53459 L
.42125 .53922 L
.42157 .53933 L
.44118 .54897 L
.45405 .55882 L
.46078 .56551 L
.47007 .57843 L
.47854 .59804 L
.48039 .60699 L
.48117 .61765 L
.48039 .62731 L
.47816 .63725 L
.46819 .65686 L
.46078 .66536 L
.44511 .67647 L
.44118 .6782 L
.42157 .6839 L
.40196 .68455 L
.38235 .68076 L
.36967 .67647 L
.36275 .67232 L
.34314 .65741 L
.34259 .65686 L
.32786 .63725 L
.32353 .62782 L
.32038 .61765 L
.3186 .59804 L
.32257 .57843 L
.32353 .57529 L
.33384 .55882 L
.34314 .54971 L
.36133 .53922 L
.36275 .53875 L
s
.71569 .37053 m
.73529 .36974 L
.7549 .38098 L
.75592 .38235 L
.76614 .40196 L
.75939 .42157 L
.7549 .42467 L
.73529 .43429 L
.71569 .42691 L
.71009 .42157 L
.6984 .40196 L
.70133 .38235 L
.71569 .37053 L
s
.34314 .53499 m
.36275 .52622 L
.38235 .52262 L
.40196 .52317 L
.42157 .52762 L
.44118 .53616 L
.44648 .53922 L
.46078 .55 L
.46957 .55882 L
.48039 .57335 L
.48309 .57843 L
.49052 .59804 L
.49298 .61765 L
.49055 .63725 L
.48247 .65686 L
.48039 .66034 L
.4659 .67647 L
.46078 .68038 L
.44118 .69057 L
.42157 .69519 L
.40196 .69552 L
.38235 .69196 L
.36275 .68438 L
.34916 .67647 L
.34314 .67193 L
.32779 .65686 L
.32353 .65166 L
.3152 .63725 L
.30842 .61765 L
.30659 .59804 L
.30971 .57843 L
.31869 .55882 L
.32353 .55197 L
.33681 .53922 L
.34314 .53499 L
s
.69608 .34113 m
.71569 .33611 L
.73529 .33711 L
.75377 .34314 L
.7549 .34364 L
.77451 .35672 L
.78038 .36275 L
.79295 .38235 L
.79412 .38534 L
.79821 .40196 L
.79698 .42157 L
.79412 .43012 L
.78823 .44118 L
.77451 .45434 L
.76036 .46078 L
.7549 .46237 L
.73529 .46398 L
.71804 .46078 L
.71569 .46007 L
.69608 .45047 L
.68465 .44118 L
.67647 .43246 L
.67032 .42157 L
.66368 .40196 L
.66357 .38235 L
.67086 .36275 L
.67647 .35458 L
.69126 .34314 L
.69608 .34113 L
s
.36275 .51278 m
.38235 .50992 L
.40196 .51066 L
.42157 .51477 L
.43573 .51961 L
.44118 .52237 L
.46078 .53433 L
.46701 .53922 L
.48039 .55244 L
.48544 .55882 L
.49705 .57843 L
.5 .58286 L
.50357 .59804 L
.50578 .61765 L
.50381 .63725 L
.5 .65358 L
.49713 .65686 L
.48412 .67647 L
.48039 .68047 L
.46078 .69532 L
.45958 .69608 L
.44118 .70351 L
.42157 .70727 L
.40196 .70734 L
.38235 .70399 L
.36275 .69725 L
.36005 .69608 L
.34314 .68638 L
.33028 .67647 L
.32353 .67003 L
.31266 .65686 L
.30392 .64268 L
.30157 .63725 L
.29547 .61765 L
.29362 .59804 L
.29603 .57843 L
.3032 .55882 L
.30392 .55737 L
.31695 .53922 L
.32353 .53285 L
.34314 .5198 L
.34344 .51961 L
.36275 .51278 L
s
.67647 .32083 m
.69608 .3133 L
.71569 .31068 L
.73529 .31211 L
.7549 .31746 L
.76878 .32353 L
.77451 .32709 L
.79412 .34244 L
.79482 .34314 L
.81046 .36275 L
.81373 .36748 L
.8198 .38235 L
.82423 .40196 L
.82404 .42157 L
.81881 .44118 L
.81373 .45199 L
.80698 .46078 L
.79412 .47292 L
.78236 .48039 L
.77451 .48353 L
.7549 .48844 L
.73529 .48897 L
.71569 .48558 L
.69983 .48039 L
.69608 .4782 L
.67647 .46607 L
.67007 .46078 L
.65686 .44686 L
.65275 .44118 L
.6422 .42157 L
.63725 .40457 L
.6368 .40196 L
.63605 .38235 L
.63725 .37371 L
.64021 .36275 L
.65057 .34314 L
.65686 .33552 L
.67165 .32353 L
.67647 .32083 L
s
.36275 .49695 m
.38235 .49478 L
.40196 .49567 L
.42157 .49938 L
.4241 .5 L
.44118 .50641 L
.46078 .51676 L
.46525 .51961 L
.48039 .53162 L
.48812 .53922 L
.5 .55378 L
.50322 .55882 L
.51305 .57843 L
.51883 .59804 L
.51961 .60262 L
.52075 .61765 L
.51961 .63418 L
.5191 .63725 L
.51336 .65686 L
.50287 .67647 L
.5 .6805 L
.48516 .69608 L
.48039 .69985 L
.46078 .71147 L
.45114 .71569 L
.44118 .71821 L
.42157 .72119 L
.40196 .72105 L
.38235 .71799 L
.37267 .71569 L
.36275 .71186 L
.34314 .7023 L
.33319 .69608 L
.32353 .68867 L
.31065 .67647 L
.30392 .6687 L
.29575 .65686 L
.28587 .63725 L
.28431 .63545 L
.28035 .61765 L
.2785 .59804 L
.28026 .57843 L
.28431 .56099 L
.28595 .55882 L
.2967 .53922 L
.30392 .53 L
.31462 .51961 L
.32353 .51304 L
.34314 .50267 L
.34883 .5 L
Mistroke
.36275 .49695 L
Mfstroke
.65686 .301 m
.67647 .29187 L
.69608 .28698 L
.71569 .28554 L
.73529 .28724 L
.7549 .292 L
.77451 .29997 L
.78206 .30392 L
.79412 .31167 L
.80876 .32353 L
.81373 .32834 L
.82632 .34314 L
.83333 .35349 L
.83828 .36275 L
.84595 .38235 L
.84986 .40196 L
.85016 .42157 L
.84667 .44118 L
.83878 .46078 L
.83333 .46994 L
.82498 .48039 L
.81373 .49097 L
.80052 .5 L
.79412 .50327 L
.77451 .51044 L
.7549 .51374 L
.73529 .51375 L
.71569 .51071 L
.69608 .50461 L
.68536 .5 L
.67647 .49518 L
.65686 .48168 L
.6553 .48039 L
.63725 .46233 L
.636 .46078 L
.62284 .44118 L
.61765 .43112 L
.61424 .42157 L
.60953 .40196 L
.60847 .38235 L
.61117 .36275 L
.61765 .34382 L
.61813 .34314 L
.63063 .32353 L
.63725 .31618 L
.6522 .30392 L
.65686 .301 L
s
.34314 .48001 m
.36275 .47572 L
.38235 .47417 L
.40196 .47523 L
.42157 .47865 L
.42901 .48039 L
.44118 .48485 L
.46078 .49396 L
.47171 .5 L
.48039 .50599 L
.497 .51961 L
.5 .52253 L
.51417 .53922 L
.51961 .54702 L
.52592 .55882 L
.53394 .57843 L
.53864 .59804 L
.53922 .60225 L
.54005 .61765 L
.53922 .63249 L
.53854 .63725 L
.53361 .65686 L
.52501 .67647 L
.51961 .68562 L
.51157 .69608 L
.5 .70792 L
.49037 .71569 L
.48039 .72199 L
.46078 .73123 L
.44897 .73529 L
.44118 .73672 L
.42157 .73899 L
.40196 .73868 L
.38235 .73594 L
.3789 .73529 L
.36275 .73032 L
.34314 .72195 L
.33133 .71569 L
.32353 .71059 L
.30506 .69608 L
.30392 .69502 L
.28707 .67647 L
.28431 .67286 L
.27451 .65686 L
.2657 .63725 L
.26471 .63561 L
.26075 .61765 L
.25882 .59804 L
.25991 .57843 L
.2641 .55882 L
Mistroke
.26471 .55669 L
.27231 .53922 L
.28431 .52044 L
.28498 .51961 L
.30392 .50081 L
.30493 .5 L
.32353 .48833 L
.34178 .48039 L
.34314 .48001 L
Mfstroke
.67647 .26009 m
.69608 .25696 L
.71569 .25642 L
.73529 .25834 L
.7549 .26266 L
.76192 .26471 L
.77451 .26954 L
.79412 .27917 L
.80271 .28431 L
.81373 .29201 L
.82805 .30392 L
.83333 .30901 L
.84627 .32353 L
.85294 .33245 L
.85969 .34314 L
.86939 .36275 L
.87255 .37047 L
.87582 .38235 L
.87927 .40196 L
.87985 .42157 L
.87748 .44118 L
.87255 .45949 L
.8719 .46078 L
.86244 .48039 L
.85294 .49423 L
.84802 .5 L
.83333 .51386 L
.82563 .51961 L
.81373 .52678 L
.79412 .53534 L
.78178 .53922 L
.77451 .54051 L
.7549 .5428 L
.73529 .54254 L
.71569 .53988 L
.71205 .53922 L
.69608 .53476 L
.67647 .52715 L
.66149 .51961 L
.65686 .51689 L
.63725 .50336 L
.63312 .5 L
.61765 .48552 L
.61304 .48039 L
.59824 .46078 L
.59804 .46047 L
.58771 .44118 L
.58042 .42157 L
.57843 .41395 L
.57628 .40196 L
Mistroke
.57509 .38235 L
.57683 .36275 L
.57843 .3523 L
.58184 .34314 L
.59059 .32353 L
.59804 .31156 L
.604 .30392 L
.61765 .28992 L
.62448 .28431 L
.63725 .27573 L
.65686 .26613 L
.6603 .26471 L
.67647 .26009 L
Mfstroke
.63725 .22176 m
.65686 .21645 L
.67647 .21315 L
.69608 .21178 L
.71569 .2123 L
.73529 .21467 L
.7549 .21885 L
.77451 .22476 L
.77661 .22549 L
.79412 .23291 L
.81373 .24307 L
.81724 .2451 L
.83333 .2558 L
.84508 .26471 L
.85294 .27143 L
.86633 .28431 L
.87255 .29105 L
.88305 .30392 L
.89216 .31678 L
.89627 .32353 L
.90655 .34314 L
.91176 .35546 L
.9142 .36275 L
.91937 .38235 L
.92235 .40196 L
.9231 .42157 L
.92159 .44118 L
.91773 .46078 L
.91176 .47957 L
.91142 .48039 L
.90194 .5 L
.89216 .51546 L
.88904 .51961 L
.87255 .53801 L
.87128 .53922 L
.85294 .5541 L
.84592 .55882 L
.83333 .56592 L
.81373 .57464 L
.80281 .57843 L
.79412 .58065 L
.77451 .5843 L
.7549 .58594 L
.73529 .58568 L
.71569 .58361 L
.69608 .57988 L
.69003 .57843 L
.67647 .57434 L
.65686 .56723 L
.63725 .55905 L
Mistroke
.63674 .55882 L
.61765 .54996 L
.59804 .54166 L
.57843 .54046 L
.57322 .55882 L
.5729 .57843 L
.57369 .59804 L
.57305 .61765 L
.5706 .63725 L
.56608 .65686 L
.55952 .67647 L
.55882 .67827 L
.54907 .69608 L
.53922 .71055 L
.53488 .71569 L
.51961 .73091 L
.51434 .73529 L
.5 .745 L
.4816 .7549 L
.48039 .75536 L
.46078 .76179 L
.44118 .76598 L
.42157 .7678 L
.40196 .76729 L
.38235 .76457 L
.36275 .75988 L
.34655 .7549 L
.34314 .75345 L
.32353 .74387 L
.30834 .73529 L
.30392 .73227 L
.28431 .71703 L
.2828 .71569 L
.26471 .69706 L
.26392 .69608 L
.24983 .67647 L
.2451 .66886 L
.23946 .65686 L
.23174 .63725 L
.22646 .61765 L
.22549 .61229 L
.22413 .59804 L
.224 .57843 L
.22549 .56177 L
.226 .55882 L
.23093 .53922 L
.23838 .51961 L
.2451 .50583 L
.24865 .5 L
.26308 .48039 L
Mistroke
.26471 .47866 L
.28331 .46078 L
.28431 .46012 L
.30392 .4473 L
.31486 .44118 L
.32353 .43833 L
.34314 .43263 L
.36275 .42922 L
.38235 .42847 L
.40196 .43019 L
.42157 .43394 L
.44118 .43875 L
.45112 .44118 L
.46078 .44456 L
.48039 .45239 L
.5 .45623 L
.51524 .44118 L
.51535 .42157 L
.51291 .40196 L
.5122 .38235 L
.51359 .36275 L
.51727 .34314 L
.51961 .33403 L
.52385 .32353 L
.53374 .30392 L
.53922 .29472 L
.54701 .28431 L
.55882 .27058 L
.56485 .26471 L
.57843 .25299 L
.58934 .2451 L
.59804 .23961 L
.61765 .22935 L
.62663 .22549 L
.63725 .22176 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
o`000=7ooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0coooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`3?ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo0<oooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oo
oooooooo0<oooooo0009ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003ooooooooo
o`3?ooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0cooo
ool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo0<oooooo0009
ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003oooooooooo`3?ooooo`002Oooool0
1?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0coooool000Wooooo00Co0000
oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?oooooo
ooooooooojgo00001?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooooooooooo
oon]o`0000Cooooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo[Ol0
0004ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?ooooooooooooooojgo00001?oo
ool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o
0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oo
oooooooo08_ooooo0_l00012ooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o
0000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`04o`000?oooooo
ooooooooojgo00001?ooool00ol0003oooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`00
0011ooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0Pooo
ool3o`0000;ooooo1?nY_NP00ol0003oooooo`000010ooooo`002Oooool01?l0003ooooooooooooo
oon]o`0000Cooooo00?o0000ooooooooool0P?ooool3o`0000;ooooo1onY_NP00ol0003oooooo`00
0010ooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0O_oo
ool2o`0000?ooooo2OnY_NP01?l0003oZKgXooooool0000oooooo`002Oooool01?l0003ooooooooo
oooooon]o`0000Cooooo00?o0000ooooooooool0Noooool3o`0000;ooooo3?nY_NP01Ol0003oZKgX
oooooooooooo000003kooooo0009ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003o
ooooooooo`1iooooo`;o00000oooool>ojVmj005o`000?nY_NSoZKgXooooool00000?_ooool000Wo
oooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo07Kooooo0ol00002oooo
o`03ojZmj?nY_NSoZKgX00koZKgX00Ko0000ojVmj?nY_NSoZKgXooooool0000mooooo`002Oooool0
1?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0M?ooool2o`0000;ooooo1OnZ
_NP2ojVmj003ojZmj?nY_NSoZKgX00[oZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003ooooooooo
o`0kooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0LOoo
ool3o`0000;ooooo2onZ_NP;ojVmj003o`000?nY_NSoZKgX00;oZKgX00?oooooo`000?ooool0>ooo
ool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo06kooooo0ol0
0002ooooo`;oZ[gW3?nZ_NP;ojVmj003o`000?nY_NSoZKgX00?oZKgX00?oooooo`000?ooool0>_oo
ool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo06cooooo0_l0
0003ooooo`GoZ[gW00?oZ[gXojZmionZ_NP02OnZ_NP2ojVmj003ojZmj?nY_NSoZKgX00KoZKgX00?o
0000ojVmj?nY_NP00onY_NP00ol0003oooooooooo`0iooooo`002Oooool01?l0003ooooooooooooo
oon]o`0000Cooooo00?o0000ooooooooool0JOooool3o`0000;ooooo2onZ_NL2ojZmj003ojZmionZ
_NSoZ[gX00?oZ[gX0_nZ_NL3ojZmj0;oZKgX0_nZ_NP2ojVmj003ojZmj?l0003oZKgX00CoZKgX00?o
ooooo`000?ooool0>Oooool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oo
oooooooo06Oooooo0_l00003oooooa7oZ[gW0_nZ_NP5ojZmi`03ojZmj?nZ_NOoZ[gW00;oZ[gX00Ko
Z[gWojZmj?nZ_NSoZ[gXo`000?nY_NP2ojZmj0?oZKgX00?oooooo`000?ooool0>?ooool000Wooooo
00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo06Cooooo0ol00002ooooob;o
Z[gW0_nZ_NP00ol0003oZ[gXojZmj002ojZmj004ojVmj?nZ_NSoooooo`0003Wooooo0009ooooo`04
o`000?ooooooooooooooojgo00001?ooool00ol0003oooooooooo`1Rooooo`;o00000ooooolVojZm
i`05o`000?nZ_NOoZ[gXojZmj?nZ_NL00onZ_NP00ooooooo0000ooooo`0gooooo`002Oooool01?l0
003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0Goooool3o`0000;ooooo7OnZ_NL2
ojZli`[oZ[gW00?o0000ojZmionZ_NL00onZ_NL01OnZ_NSoZ[gWojZmiooooooo000003Oooooo0009
ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003oooooooooo`1Mooooo`;o00000ooo
oolCojZmi`03ojZlionZ_NOoZ[gW00?oZ[gW0_nZ_>L2ojZmi`03ojZli_nZ_>OoZ[cW00;oZ[cW00?o
Z[gWojZlionZ_NL01?nZ_NL2ojZli`03o`000?nZ_NOoZ[gW00OoZ[gW00?o0000ooooooooool0=Ooo
ool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo05[ooooo0ol0
0002ooooo`;oZ[cW1OnZ_NL00onZ_>OoZ[gWojZmi`03ojZmi`03ojZlionZ_NOoZ[gW00?oZ[gW1OnZ
_>L01OnZ_NOoZ[cVojZli_nZ_>KoZ[cW00GoZ[cV0_nZ_>L01?nZ_>KoZ[cWojZlionZ_>L2ojZmi`07
ojZli_nZ_>OoZ[cWojZliol0003oZ[gWojZli`08ojZmi`03o`000?oooooooooo03Cooooo0009oooo
o`04o`000?ooooooooooooooojgo00001?ooool00ol0003oooooooooo`1Gooooo`?o00000oooool5
ojZli`03ojZmionZ_>OoZ[cW00?oZ[cW00?oZ[gWojZlionZ_>L00onZ_>L2ojZmi`03ojZli_nZ_>Oo
Z[cW00?oZ[cW1?nZ_>H00on[^nKoZ[cVojZliP03ojZliP03oj^kiOnZ_>KoZ[cV00;oZ[cV00?oZ[cW
oj^ki_n[^nH00onZ_>H2ojZli`04o`000?nZ_>OoZ[cWojZli`;oZ[gW0_nZ_>L3ojZmi`03ooooool0
003ooooo03Cooooo0009ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003ooooooooo
o`1Eooooo`;o00000ooooolCojZli`GoZ[cV00GoZ[cWojZki_nZ^nKoZ[_VojZliP02oj^ki@?oZk_V
0_nZ_>H01?n[^^GoZk_Uoj^kiOn[^nD2ojZliP03oj^jiOn[^nKoZk_V00;oZk_V00OoZ[cVoj^kiOn[
_>KoZkcVo`000?n[_>KoZ[cW00?oZkcV00?oZ[cWoj^li_nZ_NL00onZ_NL00ol0003oooooooooo`0c
ooooo`002Oooool01?l0003ooooooooooooooomho`0000@00000<Ol00004ooooo`03o`000?oooooo
oooo05;ooooo0ol00003ooooo`03ojZli_nZ_>OoZ[cW00?oZ[cW0_nZ_>H4ojZli`;oZ[cV1OnZ_>L4
ojZliPKoZ[_V00?oZk[Uoj^kiOn[^nD00_n[^nD00on[^nKoZkWToj^ji@03oj^ji@03oj^kiOn[^NCo
ZkWT00?oZk[U0_n[^nH01_n[^^CoZk_Uoj^kiOn[^nGoZkcVo`0000;oZk_U0_n[_>H01?n[^nGoZkcV
oj^li_n[_>H2ojZmi`03oj^li_oooooo000003Cooooo0009ooooo`04o`000?ooooooooooooooog7o
00001`00000401TI6@L00000:_l00004ooooo`03o`000?oooooooooo053ooooo0_l00004ooooo`Co
Z[cV0_nZ_>L5ojZliP03ojZlion[_>KoZ[cV00?oZ[cV00?oZ[cWojZli_nZ_>H00_nZ_>H00onZ^nGo
Z[_VojZkiP03ojZkiP;oZk[T0on[^^D2oj^ki@04oj^ihon[^NCoZkWToj^ii0;oZk[U00?oZkSSoj^i
i?n[^N@00_n[^N@00on[^^Go[;WSoj^ji003oj^ji006oj^kiOn/^^Co[;[To`000?n[^nGo[;[T1?n[
^nD00on[_>KoZkcUoj^liP03oj^liP03o`000?oooooooooo03;ooooo0009ooooo`04o`000?oooooo
ooooooooofko00000`00000B01TI6@@000009_l00004ooooo`03o`000?oooooooooo04gooooo0ol0
0003ooooo`goZ[cV1?n[_>H2ojZliP;oZkcV0_nZ_>H01?n[^nGoZ[_UojZkiOnZ^nD2ojZkiP03oj^i
i?n[^^CoZk[T00;oZk[T00?oZk[Uoj^hhon[^N<00on[^N<00on[^NCoZkOQoj^gh@03oj^hh`;oZkWT
00Co[;OQojbihon/^N?o[;WS0_n[^^@2ojbhhP;o[;[T00Co0000ojbji?n/^^Co[;[T0_n[^nD01?n/
^^CoZkcUoj^liOn[_>D3oj^liP03ooooool0003ooooo03;ooooo0009ooooo`04o`000?oooooooooo
ooooofco00000P00000I01TI6@<000008ol00004ooooo`03o`000?oooooooooo04_ooooo0_l00004
ooooo`coZ[cV2_n[_>H5oj^ki@03ojZkiOnZ^NCoZ[WT00?oZkWT0_n[^^@01?n[]n;oZkSSoj^hhon[
^><2oj^ih`03oj^eh?n[]n7oZkOQ00;oZkOQ00?oZkSSojbegon/]n400on/]n400on/^N?o[KKOojff
g`03ojbhhP;o[KSQ00Co0000ojfhhOn/^^Co[[WR1?n/^^@00on[_>Go[;_Tojbki003oj^liP03oooo
ool0003ooooo037ooooo0009ooooo`04o`000?ooooooooooooooof[o00000P00000N01TI6@<00000
8?l00004ooooo`03o`000?oooooooooo04Sooooo0ol00003ooooo`goZ[cV2_n[_>H6oj^ki@GoZ[WT
00?oZkWTojZgh_n[]n800on[]n800on[^>?oZkCOoj^dg`03oj^eh0;oZkOQ00Co[;?Mojbegon/]Moo
[;GO0_n/]n400on]/mgo[KKOojffg`02ojffg`06ojbhh_n^]]oo[[KOojfhhOl0003o[kKN0on^^N82
ojbji003ojjjh_n/^nCo[;_T00;o[;_T00CoZkcVojbliOn/_>Go0000<_ooool000Wooooo00Co0000
ooooooooooooooooIol00003000002<06ATI00<00000o`000?l000007Ol00004ooooo`03o`000?oo
oooooooo04Gooooo0ol00004ooooo`03ojZki_nZ_>KoZ[cV00WoZ[cV2_n[_>H7oj^ki@KoZ[WT1?nZ
]n82oj^ghP03oj^cg_n[]=ooZkCO00;oZkCO00?oZkGPojbag?n//md00on//md00on/]Moo[K7Jojfa
fP03ojfcg@;o[KKO00Ko[k?Kojjfgon^]]oo[[KOojnfg_l00002ojnfgP03ojjih_n_]moo[kOO00?o
[[[R0_n/^n@01_n^^n?o[;cUojbliOn/_>Goooooo`00037ooooo0009ooooo`04o`000?oooooooooo
ooooofKo000000<0000001TI6@0I6AT09@0I6AT00ol0000000000000000Lo`0000Cooooo00?o0000
ooooooooool0@oooool2o`0000Gooooo1?nZ^nH2ojZliP;oZ[_V1?nZ_>H:oj^liPKoZk_U00?oZ[[T
ojZii?nZ^N@00onZ^N@6ojZghP;oZ[;N0on[/mh2oj^dg`04oj^_f_n//Mco[;7Lojbag0;o[;?M00?o
[JkHojfaf_n]/MX00_n]/MX00on]/mgo[joHojncf`03ojncf`06ojjfgon`/m_o/;?Ko`000?n_]]ko
/KCK1?n_]ml00on^^^;o/;WPojjkh`03ojjkh`05ojbliOn]_>Co[KcTooooool00000<?ooool000Wo
oooo00Co0000ooooooooooooooooIOl000000`0000006ATI01TI6@0Y01TI6@0300000?l0003o0000
01Wo00001?ooool00ol0003oooooooooo`10ooooo`?o00001?ooool<ojZkiP?oZk_V00?oZkcVoj^k
i_n[^nH01On[_>H6oj^ki@04ojZjiOnZ^^CoZ[[TojZji0;oZ[WT00?oZ[OSojZgh_nZ]n800onZ]n80
0onY/]koZ[;NojZbgP02ojZbgP03oj^cg_nZ[MWoZjoJ00?oZjoJ00?o[;7Lojb[e_n/ZmH00on][]P2
ojfafP04ojn[e?n_[mSo[joHojn_f0;o[k?K00Go/JoFok2cfon`/m_o/;?Ko`000003ok6df`;o[kOO
00Co/[KLok2ih?n`^N3o/;WP0_n^^n<2ok2jhP04ojfli?n__>?oooooo`00033ooooo0009ooooo`04
o`000?ooooooooooooooofCo000000<0000001TI6@0I6AT04@0I6AT8000001806ATI00<00000o`00
0?l000006?l00004ooooo`03o`000?oooooooooo03kooooo0_l00005ooooo`ooZ[_V1_n[^nH00on[
_>KoZk_Uoj^ki@04oj^ki@;oZk[U0onZ^^D00onZ^^CoZ[OSojZgh`03ojZgh`;oZ[OR00CoZK;OojVb
g_nY/]koZK;N0_nZ/]h01?nY[=WoZZgIojZ]fOnZ[MT2oj^_fP03oj^Xe?n/ZmKo[:_F00;o[:_F00?o
[JkHojjWdOn_Zm@00on_Zm@00on_[mSo/J_Bok6_eP03ok6_eP06ok2cfonb/=Ko0000ok:`e_na]=_o
];;G1?nb]]`00on`^N3o/[SNok:hgP02ok2jhP06ok:kh?n__>?o[kcSojnlhooooooo0000;oooool0
00Wooooo00Co0000ooooooooooooooooHol000000`0000006ATI01TI6@0?01TI6@<00000200c<c<4
00000003o`00000I6AT06ATI00`06ATI00<00000o`000?l000005ol00004ooooo`03o`000?oooooo
oooo03_ooooo0ol00005ooooo`;oZK_V3_nZ^nH6oj^kiPOoZk_U1?n[^^D00onZ^^GoZ[STojZgh`04
ojZgh`03ojVch?nY/]ooZK;O00;oZK;O00?oZK;NojR/f_nX[=X00onY[=T00onZ[MWoZZKCoj^Xe003
oj^Xe0;o[:_F00Co[JC>ojjWdOn^Ym7o[ZOA0_n_Zm@01?n`Y/go/J_Bok6[d_naZm82ok6_eP05ok>[
d?nb/=Ko/[3Fo`000?nf[M400ond/]L2ok:fg004okFefOnb^=ko/[SNok:hgPCo/[_P00Go[kcSok2l
hon`_>?oooooo`00000^ooooo`002Oooool01?l0003ooooooooooooooomRo`0000030000000I6AT0
6ATI00`06ATI00@00000o`00000000000000400c<c<2000000d06ATI6Ol00004ooooo`03o`000?oo
oooooooo03Wooooo0_l00003ooooo`SoZK_V2_nZ^nH2oj^ki@CoZk_V2on[^nD2oj^ji@04ojZii?nZ
^>CoZ[STojZhi0;oZ[OS00CoZKCQojVch?nY/n3oZK?P0_nY/]l5ojR/fP03ojV/fOnXYM;oZZKC00;o
ZZKC0on[Z=@4ojfTcP;o[ZOA1?n`Y/d00onaZm;o/jK;ok>Vb`03ok>[d004ok:`e_l0003o]ZgAokJ]
d@;o];;G1?ne]MT00onb^=ko]KSLokFhg002ok:kh003okBkgon`_>?o/;cS00;o/;cS00?o0000oooo
ooooool0;?ooool000Wooooo00Co0000ooooooooooooooooH_l0000>01TI6@030000000c<c<0<c<c
01@0<c<c0`00000;01TI6@0300000?l0003o000001Go00001?ooool00ol0003oooooooooo`0foooo
o`?o00000oooool;ojVkiPOoZ[_V00?oZ[_Uoj^kiOn[^nD00_n[^nD00on[^nKoZk_Uoj^ki@0:oj^k
i@GoZ[WT00?oZ[STojVeh_nY]N800onY]>400onY/n3oYjgLojN]g005ojR/fP04ojNTdonXYM;oZ:GB
ojRUdP?oZZKC00?oZjSDoj^Pc?n[X<`00on]Y<h00on^Ym7o[j79ojnQb@03ok2Vc@Co/jK;00Co/j_@
okJXbonf[M7o00000_nf[M400ond/]Oo^;7CokRad`02okFef@05okVee_ne^=co]KSLokFhg?nh^MX0
0ond^ml2ok2lh`;o/[gR00?o0000ooooooooool0:oooool000Wooooo00Co0000oooooooooooooooo
H?l000000`0000006ATI01TI6@0;01TI6@8000006P0c<c<00`00003o000001TI6@0901TI6@030000
0?l0003o000001Co00001?ooool00ol0003oooooooooo`0cooooo`?o00001?ooool<ojVkiPKoZ[_V
1?nZ^nD>oj^ki@;oZ[[U0_nZ^N@01?nY^>?oZKKSojVfhonY]^<3ojVehP03ojVdhOnW[mgoYjgL00?o
YjgL00?oZ:cJojFTeOnWY=<00onWY=<2ojRUdP;oZZKC00CoZIk;oj^Pc?n[X<coZj3<0_n]Y<h00on]
WLKo[j79ojnQb@02ojnQb@03ok2VcOnbXLKo/Z7600;o/jK;00Oo]Z;5okJXbonfZ<_o]ZS;o`000?nf
[M7o^Jc<00?o^;7C00Go_;7?okVee_ni]MKo^KGFokFhg003okRifP03okBkgong_Mko/[gR00;o/[gR
00?o];kRo`000?ooool0;?ooool000Wooooo00Co0000ooooooooooooooooGol000000`0000006ATI
01TI6@0:01TI6@8000003@0c<c<5o`0000`0<c<c00<0000001TI6@0I6AT0200I6ATFo`0000Cooooo
00?o0000ooooooooool0<Oooool2o`0000Cooooo3?nY^nH2ojVjiPCoZ[_V1_nZ^nD<oj^ki@?oZk[U
00?oZ[[UojZii?nZ^N@00onY^><00onY]^?oYk?QojNch@02ojNag`?oYjoM0_nW[M`01?nTY]OoYJCE
ojFTeOnUY=D3ojNTd`03ojRUd_nWW<_oYic;00?oZIk;00?oZj3<oj^Ia?n]WLH00on]WLH2ojnQb@05
ok6L`_nbXLKo/Z76ok:Qa_ncY//00onfX/D2okJXb`05okV/c?l0003o^Jc<okV/c?nh/M<00onl/Ll0
0oni]MKo_KKDokRifP02okRifP05okbkfOng_Mko]kgNokNmg_nb_N800ond_^800ol0003ooooooooo
o`0Zooooo`002Oooool01?l0003ooooooooooooooomNo`0000030000000I6AT06ATI00X06ATI00<0
000003<c<`0c<c<02P0c<c<3o`0000D0C4a<0ol0000:03<c<`030000000I6AT06ATI00P06ATI00<0
0000o`000?l000004_l00004ooooo`03o`000?oooooooooo02kooooo0ol00004ooooo`KoZK_V0_nY
^^H4ojVkiPGoZK[V00CoZ[_VojZjiOnZ^^GoZ[[U1_nZ^nD<oj^ki@03oj^jiOnZ^NCoZ[WT00?oZ[WT
00?oZKSSojReh_nW/n400onW/n42ojNag`03ojN_gOnTZ=WoY:SI00?oY:KG0_nUY=D2ojNTd`03ojBK
c?nWW<_oYic;00;oYic;00?oZIk;ojRF`on[VL@00_n[VL@3ojfMaP04ojnQbOnaW<;o/Ic2ok6L`P;o
/Z761?nfX/D01?nfZ<_o^ZK5okZVaOl00002okV/c0?o_;7?00Go`;;<okffe?nm]]Co_KKDokRifP03
okbkf@03okNmg_ni_mko^KoN00;o];kR00?o]L3Rooooool00000:oooool000Wooooo00Co0000oooo
ooooooooooooGOl000000`0000006ATI01TI6@0;01TI6@030000000c<c<0<c<c00H0<c<c1?l0000;
04a<C0Co00001`0c<c<2000000P06ATI00<00000o`000?l000004_l00004ooooo`03o`000?oooooo
oooo02cooooo0_l00005ooooo`03ojRki_nY^nKoZK_V00?oZK_V1OnY^^H00onY^nKoZK[VojVjiP04
ojVjiP;oZK[U1_nZ^^D3ojZki@_oZk_U00?oZ[[UojZii?nZ^N@00onZ^N@01?nX]n?oZ;GRojReh_nX
]N82ojNch@03ojB^g_nTZmcoY:_L00CoY:SI00?oY:KGoj2MdOnRVlh00_nRVlh3ojBKc0;oYic;00Co
YIC4ojRF`onXU/?oZ9K30on[VL@00on]WLKo[YNook6L`P03ok6L`P03ok:Qa_neWL3o]Ig000;o]Z;5
00Ko^J6ookZVaOnjY/Go^ZK5o`000?ni[<`2okf/b005okbacoo0//co`;;<ol2bc?nm]]@00_o1^M82
okbkf@04oknnfOni_mko^KoNokVogPCo]L3R00?o0000ooooooooool0:Oooool000Wooooo00Co0000
ooooooooooooooooGOl000000`0000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00D0<c<c0_l0
000C04a<C003o`00000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT01P0I6AT00`00003o0000o`00
000Ao`0000Cooooo00?o0000ooooooooool0:Oooool3o`0000Gooooo0_nX^nL2ojRkiP;oZK_V0_nX
^^H<ojVjiP?oZK[U1_nZ^^D3ojZki@OoZk_U0_n[^^D3ojZji@03ojZii?nY^>CoZKST00?oZ;OS00?o
Z;GRojFahOnU/N400onT[]h2ojB[g0;oY:SI00CoWj3Doj2MdOnPWM7oX9gA0onRVlh00onTVlcoXI;5
ojFDa002ojFDa0?oZ9K30_n[VL@01?n[Tkgo[YNoojjG_on^Ukl2ok6L`P05ok:H_?neWL3o]Ig0okFM
`?nfX/D00oniXKl2okZVa@04o`000?nm[<So_Jc8okf/b0?o`;;<00CoaKK;ol6id_o1^M;o`KWB1?no
_]T00oni_mko^l7Nok_1gP02okG0hP;o]/;S00?o0000ooooooooool0:?ooool000Wooooo00Co0000
ooooooooooooooooG?l000000`0000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00D0<c<c00?o
000004a<C01<C4`0501<C4`3o`0000H0<c<c00?o000001TI6@0I6AT01P0I6AT00`00003o0000o`00
000@o`0000Cooooo00?o0000ooooooooool09oooool2o`0000?ooooo1_nX^nL5ojRkiP?oZ;[V2_nY
^^H5ojVji@KoZ[[U00?oZ[_Uoj^jiOn[^nD01?n[^nD5oj^ji@03ojZjiOnZ^NCoZKST00?oZKST00?o
Z;OSojJdh_nU/N400onU/N42ojB^gP03ojB[g?nOXmSoWj?H00?oWj3D0_nPWM42oj:KcP03oijBaonQ
T/GoXI;500CoYIC40_nXU/<4oj^C_@;o[YNo00Co/Ic2ok:H_?nbV;co/YRl0_neWL04okVQ_`05okZV
aOnnY/7o0000okjV`Onm[<P00_o3[/D01Oo0//coaKK;olFfboo5]/_o`KWB00;oaKgB0_no_]T2ol?2
f@03ok_1g_nma=oo_LCO00;o]/;S00?o]lCTooooool00000:Oooool000Wooooo00Co0000oooooooo
ooooooooG?l000000`0000006ATI01TI6@0901TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<
C01<C4`01@1<C4`;o`0000P0C4a<00?o000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI
6@0300000?l0003o000000oo00001?ooool00ol0003oooooooooo`0Tooooo`?o00000oooool7ojRk
i`GoZ;_V1OnX^^H00onY^^KoZ;[VojVjiP05ojVjiPKoZK[U1_nZ^^D3oj^ji@;oZk_U1_n[^^D2ojZj
i@;oZ[WT0_nY^>@01?nX]^?oY[CRojJdh_nV]>82ojFah@03oj6/gonPZ=coX:SL00CoWj?H0_nOX=@0
0onPWM7oViC;oijBa`02oijBa`?oXI;50onUU<@00onXU/?oYhnlojN?_003oj^C_@03ojjG_on_TkWo
/YRl00?o/YRl00?o]Ig0okRK^_nhVkX00oniXKl2okjV`@03o`000?nnY/7o`jk500;o`jk51?o5]//3
olFmdP?o`l;I00CoaLKKokg4gonma=oo_LCO1?nga>@00ol0003oooooooooo`0Wooooo`002Oooool0
1?l0003ooooooooooooooomKo`0000030000000I6AT06ATI00X06ATI00<0000003<c<`0c<c<0100c
<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV00T0IVIV0ol0000604a<C003o`00000c
<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01P0I6ATAo`0000Cooooo00?o0000ooooooooool08_oo
ool2o`0000Cooooo2_nX^nL2ojRkiP[oZ;[V1_nY^^H6ojVji@KoZ[[U2_n[^^D00onZ^^GoZKWUojVh
i003ojVhi0;oZ;KS00?oY[CRoj>`hOnS/>400onQ[=l2oj2Xg0;oWj?H00?oVI_DoiZGconJUll00onK
U</3oijBa`;oXI;50_nUU<@01?nSSKgoYhnlojN?_?nWSk`3oj^C_@?o[i>i0onbV;`4okRK^P05okVQ
_onnXK_o_Z6kokjV`Ol000000_o4Z;h2ol>^a@03olRa`oo5]/_oaKK;00;obk[;00CoaKgBol[2doo:
`]?o`l;I0oo5a]/00onma=oo_/OQokk7h@02okO4i0;o]lGU00?o0000ooooooooool09_ooool000Wo
oooo00Co0000ooooooooooooooooFol000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c
00@0<c<c00?o000004a<C01<C4`00`1<C4`3o`0000l0IVIV00?o000004a<C01<C4`0101<C4`00ol0
0000<c<c03<c<`0403<c<`030000000I6AT06ATI00H06ATI00<00000o`000?l000003Ol00004oooo
o`03o`000?oooooooooo01oooooo0ol00004ooooo`_oZ;_W0onX^^L<ojRjiP?oZK[V1_nY^^D8ojZj
i@SoZk[U00CoZ[[UojViiOnY^NGoZKWU0_nY^>@01?nW]^CoYKCSojFdhonU]><3oj>`h@03oj6/gonL
Y]goVZ3I00;oVZ3I0onIVm@2oiZGc`?oViC;0_nNT/L00onQT/GoWX^ooj>=_@03oj>=_@?oYhnl00?o
Zi>moj^>]on_TkT00on_TkT00onbV;co]IJgokRK^P03okRK^P?o_Z6k00Go_ZK1o`000?o4Z;koa:Rn
ol>^a@02olRa``04olFfboo;^/_obk[;ol^jb`?ob/;C00Ooc/SDolG6foo5a]_oaLKKolO;gOnnan7o
_/WS00?o]lGU00?o]/KVooooool000009oooool000Wooooo00Co0000ooooooooooooooooFol00000
0`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00P1<C4`0
0ol00000IVIV06IVIP0A06IVIP;o00001@1<C4`00ol00000<c<c03<c<`0303<c<`030000000I6AT0
6ATI00H06ATI00<00000o`000?l000003Ol00004ooooo`03o`000?oooooooooo01cooooo0ol00004
ooooo`ooZ;_W00?oZ;[WojRji_nX^^H02onX^^H3ojVjiPKoZK[U2OnZ^^D6oj^ji@?oZ[[U00?oZKWU
ojRhi?nX^>@00onW]^@00onU]>?oX[3Soj:`h`02oij/h0?oW:KM0onJX=T2oiVKe0;oVYO?0_nKU</0
0onFRlKoVX[2oiZ:`P03oij;_`?oXhfm0_nWSk`01?nWRkOoZhjgoj^>]on[S[L2ojnC^@04ok6A]?ne
U[Oo]IJgokFF]`;o^9^j0_nlVkL2okjQ^`04olBX__l0003oa:RnolBX_P?ob;7300KockS3ol^jboo;
^/_obk[;om71c?o:`]<3olk8e003olG6foo7bmgoal_M00?o_/WS00Go]lGUokK6i_nfa^Ko]/KVo`00
000Wooooo`002Oooool01?l0003ooooooooooooooomJo`0000030000000I6AT06ATI00T06ATI00<0
000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00204a<C003o`00001VIVH0IVIV00H0IVIV1Ol0
000906IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@0601TI6@0300000?l0003o000000co00001?ooool00ol0003oooooooooo`0Jooooo`;o00000ooo
ool5ojRli`goZ;_W00?oZ;[WojRji_nX^^H03OnX^^H3ojVjiPKoZK[U2OnZ^^D6oj^ji@03ojZjiOnY
^NGoZ;ST00?oZ;ST00?oYkKTojBdi?nR/><00onR/><2oij/h0;oW:KM0_nJX=T00onBV=KoTI;Aoi6B
d@02oi>>b`?oUX_60onJR/82oij;_`?oXhfm0onWRkL3oj^>]`03ojnC^OnaTKCo/I6d00?o]IJg00Go
^9^jokbK]onlVkOo_9^gokjQ^`02ol>S^@05o`000?o4Z;koa:RnolZ]_Oo8/L<00oo?^<<00oo;^/_o
dL7<om71c003olk8e0;odLoH00Coal_MolO?h?o7cn3o_/WS0_nmbnD2okK6iP;o]<KW00?o0000oooo
ooooool09?ooool000Wooooo00Co0000ooooooooooooooooF_l000000`0000006ATI01TI6@0901TI
6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0406IV
IP;o00001@1oOgl3o`0000L0IVIV00?o000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`0303<c
<`030000000I6AT06ATI00H06ATI00<00000o`000?l000003?l00004ooooo`03o`000?oooooooooo
01Oooooo0ol00003ooooo`;oZ;cX1?nX_>L<ojRki`CoZ;[W3onX^^H3ojVjiPKoZK[U1onZ^^D6oj^j
i@;oZ[[U0_nY^ND2ojRhi004ojNgiOnT]>CoY;CTojBdi0;oX[3S00?oW:gSoiRVh?nHY^000_nDWm`4
oi:HeP;oTI;A0_nCS//3oiJ;aP;oVX[20onNRkl00onSSKgoXHNhojN;]`03ojN;]`;oZhjg1?naTK@2
okFF]`Co_9^g0_o3XkT2o`000003olBX__o:[KgobZfm00CockS30ooA`L`01?oFbLkoc/SDom7?f?oA
cmP2om;Ef`04olO?h?o6dN?oa]7Sokg;i@;o^l_W0_nda^L00onca^Soooooo`00000Uooooo`002Ooo
ool01?l0003ooooooooooooooomJo`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0
0`0c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00@0IVIV00?o000007moO`1oOgl0
201oOgl3o`0000D0IVIV00?o000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`0303<c<`030000
000I6AT06ATI00H06ATI00<00000o`000?l000002ol00004ooooo`03o`000?oooooooooo01Kooooo
0_l00003ooooo`GoZ;cX0onX_>L9ojRki`?oYk_W0onX^^L2ojNji`ooZ;[V0_nY^^H6ojVji@OoZ[[U
0on[^^D4ojZji@03ojVjiOnX^NGoZ;WU00;oZ;WU0_nW]nD00onT]>CoXK;Toj6bi003oib]h`;oV:KP
0_nDWm`3oi:HeP;oTI;A0onCS//2oiJ;aP03oiZ:`_nEPkgoVhFj00;oVhFj0onQQkP3ojN;]`03oj^>
]on]S;?o[Hbc00?o/I6d00?o]IJgokVF]?niU[@00_nlVkL3o`000003ol>S^Ol0003obZfm00;obZfm
00?odKBmolnh`oo?^<<00_oF`<@01OoA`Lcoe/W>omK9c_oJd]7odLoH00;od]GK00CodMWOolKAhoo6
dN?oa]7S0onkbnL4ok?6j003o`000?oooooooooo02?ooooo0009ooooo`04o`000?oooooooooooooo
oe[o000000<0000001TI6@0I6AT01`0I6AT00ol00000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<
00<0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0<07moO`03o`00001VIVH0IVIV
0080IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0203<c<`030000000I6AT06ATI
00H06ATI00<00000o`000?l000002ol00004ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ool000002?nX_>P00onX_>OoZ;_WojRki`04ojRki`KoYk_W1onW^^L00onX^^KoYk[VojNjiP0<ojRj
iP;oZK[V1_nY^^D<ojZji@?oZK[U0_nX^ND01?nW^>GoY;KUojBfiOnT]^D3oj6bi004oib]honFZN?o
T:7Poi2Qh0;oRYSK0on7Sm@2ohN9cP?oRXG80_n?Pl83oiF3_@;oVhFj0onQQkP2ojN;]`04ojN8]?n]
S;?o[Hbcojf</`?o/I6d0_niU[@3o`0000;o`Ije0_o3XkT00oo:Z;So0000olZ]_@02om6d_@03olnh
`ooF`<Coe/3400;og<[700Goe/W>om[BdOoJd]7og=_Fom;Ef`03om7Ig`04olKAhoo3dnKo`m?Vok_;
i`;o^<_X0_nca^P2ok75j003o`000?oooooooooo02;ooooo0009ooooo`04o`000?oooooooooooooo
oeWo000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<
00<0C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0>07moO`03o`00001VIVH0IVIV
0080IVIV00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0203<c<`030000000I6AT06ATI
00D06ATI3_l00004ooooo`03o`000?oooooooooo01Kooooo00?o0000ojRlj?nX_>P02OnX_>P4ojRk
i`OoYk_W2OnW^^L6ojNjiPSoZ;[V1?nY^^H5ojVji@SoZ[[U00CoZ[_UojZjiOnZ^^GoZ[[U0onY^^D3
ojNhi@03ojBfiOnR]>KoX[CV00;oW:oU0onFZN<2oi2Qh0;oRYSK0on7Sm@2ohN9cP;oRXG80_n?Pl83
oiF3_@?oVhFj0_nQQkP00onWRkOoYhRdojN8]004ojf</`04ok6A]?l0003o0000o`0000;o^IJd0oo1
W[D01Oo3XkWobZRholZX^?o:Z;So000000;odKBm00?ofKjoomK0a?oLb/L00_oLb/L01OoRe/_of];A
omcKe_oLfmKofn;K00;odMWO0_o=g>@01?o3dnKo_m;XokoBj?nhbnP2okG9j@;o/LGX00?o[l?Yo`00
0?ooool08oooool000Wooooo00Co0000ooooooooooooooooFOl000000`0000006ATI01TI6@0801TI
6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP0306IV
IP03o`00001oOgl0Ogmo0100Ogmo00?o000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00204a<
C003o`00000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01@0I6AT00`00003o0000o`00000:o`00
00Cooooo00?o0000ooooooooool05_ooool00ol0003oZ;cXojRlj00:ojRlj003ojRkionW^nOoYk_W
00SoYk_W2OnW^^L5ojNjiPWoZ;[V0onY^^H6ojVji@CoZ[[U1OnZ^nD2ojZji@CoZK[U00?oYkSUojFh
i_nR]>H00onR]>H2oib_i@;oUZWS00?oT:7PohFKhOmmT=/00_mmT=/2ohN?e0;oQhW>0on:QLP2ohn3
`P?oUH>m0_nKQKX00onQQkSoX8BeojN8]003ojN8]004ojf</ol0003o0000o`0000;o]I6b0_niU[@0
1?nnVK;o`Ijeol6N]Oo1W[D4olZX^005om:a^Ol0003odKBmomVn_ooRbl800ooLb/L01OoRe/_og=_F
omcKe_oLfmKofn;K00?ocMcT0_o8fnL01Onod^So^m3Zok_@j_nebNWo//OY00Co[l?Y00?o0000oooo
ooooool08Oooool000Wooooo00Co0000ooooooooooooooooFOl000000`0000006ATI01TI6@0801TI
6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP0306IV
IP03o`00001oOgl0Ogmo00L0Ogmo0ol0000607moO`03o`00001VIVH0IVIV00<0IVIV00Go000004a<
C01<C4`0C4a<o`00000503<c<`030000000I6AT06ATI00D06ATI00<00000o`000?l000002_l00004
ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooooooo2OnX_>P2ojRkj0WoYk_W2onW
^^L5ojNjiP;oZ;[V00?oYk[VojRji_nX^^H01?nX^^H3ojVjiP03ojVjiOnY^^KoZK[V00?oZK[U0onZ
^^D6ojZki@;oZ[[U0_nY^^D2ojRiiP;oYKSV0_nR]>H00onN/nOoUjgVoiN]iP02ohjUi0?oQI_Q0_mm
T=/2ogZ6e0;oNh3=0omoO<H2ohn3`P;oUH>m00?oT7jkoiR1^?nHPKP00onPQ;D01?nWR;Co0000o`00
0?l00002ojn=/@?o]I6b00Co^IJdokjI/_nnVK;o_YVb0_o1W[D00oo8Y;CobZRholZX^002om:a^@03
o`000?oI_[oofKjo00;oh/_200Gog<[7on;FbooRe/_oiN;?omcKeP02om_Rf`04omSVh?o=g>Cob=_W
olSKi`;o`]WZ00?o^m3ZokO=jonbanT00_nbanT2ojo3j@;o[/;Y00?o0000ooooooooool08?ooool0
00Wooooo00Co0000ooooooooooooooooFOl000000`0000006ATI01TI6@0801TI6@030000000c<c<0
<c<c00<0<c<c00?o000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP0206IVIP03o`00001oOgl0
Ogmo00D0Ogmo0ol0000309VIV@;o00001@1oOgl00ol00000IVIV06IVIP0206IVIP03o`00001<C4`0
C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@0300000?l0003o
000000[o00001?ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooooooo`WoZ;cX00?o
Z;_XojNkj?nW^nP02OnW^nL;ojNji`03ojNji_nW^^OoYk[W00GoYk[V1_nX^^H00onY^^KoZ;[VojRj
iP03ojVjiP04ojVjiOnY^^KoZK[VojZji@;oZ[_V1?nZ^nD2ojZkiP?oZK[V00?oZ;WVojJiionS]nL0
0onS]nL2oijci`;oUjgV0_n>YN@3ohFKh@;oOI3K0_mjQ]@2og^0c@;oOgc60_n7O<03oi1n^`;oV86h
00CoX8Beo`000?l0003o00000_nWR;@4ojn=/@;o]I6b1?nnVK801?o1W[Gob:BdolRT]?o:Z;P3om:a
^@03omVn_ol0003oh/_200;oh/_200OojM[5on;FbooUh/ooiN;?onG[e?oKh]_of>KP00;odNOV00Co
b=_Wol;Ij_o2fN[o_=C/0ongcN/00onbanWo/<GYok35j@02ojk2j@03ojc1jOl0003ooooo027ooooo
0009ooooo`04o`000?oooooooooooooooeWo000000<0000001TI6@0I6AT0200I6AT00`000000<c<c
03<c<`0303<c<`03o`00001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH00P1VIVH00ol00000Ogmo
07moO`0407moO`03o`00002IVIT0VIVI00H0VIVI00?o000007moO`1oOgl00P1oOgl00ol00000IVIV
06IVIP0306IVIP05o`00001<C4`0C4a<04a<C?l00000100c<c<00`0000006ATI01TI6@0601TI6@03
00000?l0003o000000Wo00001?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;o
oooo1onX_>P5ojNkj003ojNkionW^nSoYk_W00CoYk_W4?nW^^L5ojNjiPWoZ;[V1?nY^^H2ojVkiP?o
Z[_V00?oZ[_UojZki_nZ^nH00onZ^nH00onY^^KoZ;_VojJii`02ojJii`;oXkOW00?oXKOXoiZbj?nJ
/^P00on@ZnP2oh>QiP;oMiCR0_m/R=`2ofMme@;oNh3=0omoO<H01?n7O<3oT7jkoi1n^on@O[/3o`00
00?oX8Be00?oYhRdojR8/_n_SK400on_SK42okFA/P04okVE/OnnVK;o_YVbokjI/P?ob:Bd00SodJjf
om:a^OoB/KWod[6iom^m^ooI_[oo0000on;;`P;ojM[500Ook>S9onGRcooUjmCoiN_Don3af_oHln;o
dNOV00;ob^CZ00Go`]WZokcDk?nle>co_=C/okO=j`02ok?9j`03ok35jOn^`nWo[/?Y00?o[<7Y00?o
0000ooooooooool07oooool000Wooooo00Co0000ooooooooooooooooFOl000000`0000006ATI01TI
6@0801TI6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00P1<C4`01Ol00000IVIV06IV
IP1VIVKo000000H0Ogmo00?o000009VIV@2IVIT01`2IVIT00ol00000Ogmo07moO`0307moO`;o0000
0`1VIVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0
1@0I6AT00`00003o0000o`000009o`0000Cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`04ooooo`KoZ;cX1onW^nP4ojNki`WoYk[W00?oY[[WojNjionW^^L01?nW^^L6ojNjiPWoZ;[V
00?oZK[VojVki_nY^nH00onY^nH7ojZkiP;oZK_V0_nX^nH00onV^NOoYKWWojFii`03oj6gj0;oV[;X
00?oT:_XohRYjon8ZN/00_mgWNT2ogNDhP;oK8SL00CoIggEofUgc_mYMlkoJGO>0_moO<H01On7O<3o
0000o`000?l0003oT7jk00;oV86h0_nPQ;D01?nPPkCoZ8RbojR8/_nXR;83ojn=/@03okFA/_niUK7o
^IFa00?o_YVb00?oaJ2colRT]?o8Y;@00_oA[[H01ooB/KWofkfkom^m^ooUc;koh/_2o`000?oYf/D0
0_o/j<T00ooZm<coiN_Don3afP02omSchP04om3`j?o:i>[o`]k]ol;Nk@;o_=C/0_ngcn`01OncbN_o
/<KZok36j_n^`nWo[<7Y00CoZkoX00?o0000ooooooooool07_ooool000Wooooo00Co0000oooooooo
ooooooooFOl000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00<0<c<c00?o000004a<
C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVKo000000H0Ogmo00?o000009VIV@2IVIT01`2IVIT0
0ol00000Ogmo07moO`0407moO`05o`00001VIVH0IVIV06IVI_l00000101<C4`00ol00000<c<c03<c
<`0203<c<`030000000I6AT06ATI00D06ATI00<00000o`000?l000002Ol00004ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01?ooool5ojRlj003ojNlj?nW^nSoYk_X00OoYk_X00?o
Yk_WojJkj?nV^^L00onV^^L00onW^^OoY[[WojJji`04ojJji`;oYk[W0_nV^^L2ojNji`04ojNji_nW
^^OoYk[WojNji`;oYk[V2OnX^^H6ojVkiPKoZ[_V00?oZK_VojVkionX^nL00_nX^nL3ojFii`03oj6g
j?nN]^WoUK7[00;oUK7[0on8ZN/00omgWNWoIHkUofF>i@02oeIngP;oIggE0_mYMlh01?mbMLOo0000
o`000?mmM/43oi1n^`03oiR1^?nFO[SoX8>d00;oX8>d0onXR;82ojn=/@03ok>@/_niUK7o^IFa00;o
^IFa00Co_YVbolFP/oo5X;?ob:Bd0ooA[[H3om^m^`03onG<__o^g/7o000000;ok>S900Goj_C<on?k
dOoSnm7ofOgIomSchP02om3`j004olOYk_o2g^go^mO^ok_GkP;o]lo/0_ncb^`00on`a^[o[/?Zojc1
j@02ojc1j@?oZkoX00?o0000ooooooooool07_ooool000Wooooo00Co0000ooooooooooooooooFOl0
00000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00P1<
C4`01Ol00000IVIV06IVIP1VIVKo000000H0Ogmo00?o000009VIV@2IVIT0202IVIT00ol00000Ogmo
07moO`0307moO`03o`00001VIVH0IVIV0080IVIV00Go000004a<C01<C4`0C4a<o`00000503<c<`03
0000000I6AT06ATI00@06ATI00<00000o`000?l000002Ol00004ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01Oooool2ojRlj0CoYkcX2?nW^nP3ojJkj0;oY[[W00?oY[[XojJjionV
^^L02OnV^^L9ojNji`03ojRji_nW^^OoYk[W00CoZ;[V0_nX^nH5ojVkiPGoZ[_V00GoZ[cVojVkionY
^nOoZK_WojRki`02ojNki`?oY;WX0_nN]^T00onE/N_oTK7]oi6ak@02oh6XkP;oJY[/0_mUS^D2oeIn
gP05odibeol0003o0000o`000?mbMLL00_mmM/43ohYj_0?oUWjh0onPPk@2ojR8/P03ojn=/OncT;;o
/i2b00Co^IFa0oo5X;<4om6^]P08om^l^OoK_K_oiLbnonG<__o^g/7ol>o3o`000?oZm<`2on?kd@05
omWmfOo@nn?od?_Som3`j?o7jNh00_noh?000onkenko]]3]okK@k@02ok?:k005ojo6jon^`n[o[/?Z
ojk3j_n/`NT00_n[`>T3oj^oj003o`000?oooooooooo01gooooo0009ooooo`04o`000?oooooooooo
oooooeWo000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0303<c<`03o`00001<C4`0
C4a<0080C4a<00Go000006IVIP1VIVH0IVIVo`00000607moO`03o`00002IVIT0VIVI00T0VIVI00?o
000007moO`1oOgl00P1oOgl00ol00000IVIV06IVIP0206IVIP05o`00001<C4`0C4a<04a<C?l00000
1@0c<c<00`0000006ATI01TI6@0401TI6@0300000?l0003o000000Wo00001?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Sooooo0onW_>P:ojNkj0CoY[_X0_nV^^P00onV^^OoY[[X
ojJjj008ojJji`;oYk[W00?oY[[WojNjionW^^L01onW^^L00onX^^KoZ;_WojRkiP03ojRkiPGoZK_V
00?oZ[_VojZli_nZ_>H00onZ_>H00onY^nOoZKcWojVli`03ojNki`03ojBij?nS^^WoW;O[00;oW;O[
0onA/Nd2oh6XkP;oJY[/00GoD8OWo`000?l0003o0000odibe`02oe5/d0;oLWG70_mmM/42ohYj_0?o
UWjh0onPPk@2ojR8/PCo/i2b0_niUK401Oo0W;?oaJ2colFP/oo5X;?ocZ^f00;odJjf0_oK_;T2onG<
_P;ok]k100Gol>o3onWj`_l0003oho_AomWmf@02om3kh`04olSdk?o1j_7o`N[aokoPl0;o^=O`00?o
]]3]ok7:k?nab^`00on_a^/01On^`n[o[<7Yojc1jOn[`>WoZkoX00CoZ[kX00?o0000ooooooooool0
7?ooool000Wooooo00Co0000ooooooooooooooooFOl000000`0000006ATI01TI6@0801TI6@030000
000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVKo000000H0
Ogmo00?o000009VIV@2IVIT02@2IVIT00ol00000Ogmo07moO`0207moO`03o`00001VIVH0IVIV0080
IVIV00Go000004a<C01<C4`0C4a<o`00000503<c<`030000000I6AT06ATI00@06ATI00<00000o`00
0?l000002Ol00004ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool3ojNl
j0KoYk_X1onV^nP6ojJjj003ojJjionV^^SoY[[X00SoY[[W2OnW^^L2ojRki`;oZ;_V0_nX^nL3ojVk
iP?oZKcW0onZ_>H2ojZli`?oZKcW0onW^nP2oj>jj@03oibgjonK]ncoVkO/00?oS[;^00GoNZS`o`00
0?l0003o0000ocR1j002ocQdg`;o:fGF00?oDFc@oee]b_mMKLX00_mmM/43ohYj_0;oUWjh0onPPk@0
0onXR;;oZh^doj^;]003ok>@/P05okVE/Oo0W;?o`9bcol2L/oo5X;<00_o>ZkH01ooA[[Kofkbiom^l
^OoK_;WoiljmonG<__o^g/400_o`kl<01_oYn/;ofok2o`000?o6omKo`_cVolSdk0;o`N[a0_njg_80
1Onheo3o/lo^ok??k_nab^co[/G[00Co[L?Z00?o[<7Yoj_0jOn[_nP00_n[_nP3ojZnj003o`000?oo
oooooooo01cooooo0009ooooo`04o`000?oooooooooooooooeWo000000<0000001TI6@0I6AT0200I
6AT00`000000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH00P1V
IVH00ol00000Ogmo07moO`0407moO`03o`00002IVIT0VIVI00L0VIVI00?o000007moO`1oOgl00`1o
Ogl00ol00000IVIV06IVIP0206IVIP05o`00001<C4`0C4a<04a<C?l000001@0c<c<00`0000006ATI
01TI6@0401TI6@0300000?l0003o000000Wo00001?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00[ooooo0_nW_>P6ojNkj0SoY[_X3?nV^^P00onV^^OoY[[XojJji`02ojJji`03ojNj
ionV^^OoY[[W00CoYk[W0_nW^nL5ojRki`KoZKcW1_nZ_>L3ojVli`03ojNkj?nV^nSoX[WY00;oX[WY
0onK]n`3o`000003ogJYl_mCV?7oDiSa00;o>87X0_lDIm/01?l[IMKo;5kAoe5/d?mMKLX3ofmaa@;o
RWZl0onFO[P00onPPkCoX8Fgoj^;]002oj^;]0?o/i2b1?o0W;<01?o5X;?ocZ^folj[]_oJ^kX2om^l
^@;oiljm00Wol>C0onkN`Oo`kl?ojO[2om_n`_o>olOo0000ol;li_nnlo400_niiO@2ok[NlP;o]=?`
00?o/lo^ojo8k?n^aN/00_n^aN/2ojg3jP05ojc1jOn[`>WoZl3Yoj_0jOn[_nP01OnZ_^P00ol0003o
ooooooooo`0Kooooo`002Oooool01?l0003ooooooooooooooomIo`0000030000000I6AT06ATI00P0
6ATI00<0000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00204a<C005o`00001VIVH0IVIV06IV
I_l000001P1oOgl00ol00000VIVI09VIV@0709VIV@03o`00001oOgl0Ogmo00<0Ogmo00?o000006IV
IP1VIVH00P1VIVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI
6@0I6AT0100I6AT00`00003o0000o`000009o`0000Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0;ooooo`;oYkcX1_nW^nP9ojJkj0goY[[X00?oY[[WojJjj?nV^^P00onV^^L00onW
^^OoYk_WojNki`03ojNki`GoZ;_W1_nY_>L6ojZli`03ojVlionY^nKoZK_V00;oY[_X00?oX[WYoj>h
j?l000000_l000000onK]ncoSK;`ohfbl002ogJYlP?oDiSa00Go8gcVoaAWfol0DLko:fGFobaNd@02
oee]bP;oKg750_n1N;l3oi9o^`;oX8Fg1?n[Rk@00oncT;;o^INeol2L/`03ol2L/`?ocZ^f0_oJ^kX0
3OoK_;WoiljmonO>_Oo`i<3okoJnomgk/oo2mJSo[_6ZojkjfOndn>ko0000okG[m_niiO@00_ndfO<2
okCCl0;o/<c^0_n_b>`01On^aN_o[<;Zojc2j_n/`NWoZkoY00CoZ[oX1OnZ_^P00ooooooo0000oooo
o`0Kooooo`002Oooool01?l0003ooooooooooooooomIo`0000030000000I6AT06ATI00T06ATI00<0
000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00204a<C003o`00001VIVH0IVIV0080IVIV00?o
000007moO`1oOgl0101oOgl00ol00000VIVI09VIV@0409VIV@;o00001P1oOgl00ol00000IVIV06IV
IP0206IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI
6@0401TI6@0300000?l0003o000000Wo00001?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00cooooo0onW_>P00onW^nSoY[_XojJkj00:ojJkj0CoY[[X1OnU^^P8ojJjj003ojJjionV
^nSoY[_X00CoYk_W0_nW^nP3ojRki`?oZ;cW1OnY_>L4ojZli`?oZK_V00?oZKSTojNii_l000000_l0
0002oj>hj003oi^gk?nM]^WoWKKY00;oSk?_0omg[?@2odnKl`04oaEliOl0FM7o057>obaNd@?o?F;>
00CoKg75oh5h_on1N;ooPGRo0_nBOk/3oj25]`;oZh^d00Co[i:hokVG]OniUkGo^INe0_o0W;<2olVW
]`04olj[]_oJ^k[of[^jomZk^P;oiljm0_o`i<000oo_m[kogO^cojkaZP02oj;fi`05okChk_nejoKo
0000ok;Mm_ndfO<00_n`co02ok3<kP05ojg6k?n]a>_o[LC[ojg4jon/`^X00_n[`>T2oj^oj@;oZ[oX
1OnZ_^P2ojVmj003o`000?oooooooooo01[ooooo0009ooooo`04o`000?ooooooooooooooocgo0000
2`00000Ao`0000030000000I6AT06ATI00T06ATI00<0000003<c<`0c<c<00`0c<c<00ol00000C4a<
04a<C00204a<C003o`00001VIVH0IVIV0080IVIV00?o000007moO`1oOgl01@1oOgl3o`00000309VI
VOl0003o000000P0Ogmo00?o000006IVIP1VIVH00P1VIVH00ol00000C4a<04a<C00204a<C003o`00
000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0100I6AT00`00003o0000o`000009o`0000Cooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`?oYkcX3OnV^nP00onV^^SoYK_X
ojFkj008ojFjj0;oY[[X1onV^nP4ojNkj004ojNlj?nX_>SoZ;cXojRlj0?oZ;cW1?nY_>L00onY^nKo
Z[_VojZkiP02ojZkiP03ojVki_nZ^>?o000000;o000000?oYkWVojRdhOnX]>400onT]ND00onM]^Wo
XK;ToiFbk003oiFbk0;oOZoc0_mFX_H01?lGPnOo0533o`18bOl/G]42oceRcP04oeQ/c?m_LLGoPGRo
oh5h_`?oTWnk0_nPQKL00on[RkCo[i:hojnB^003okVG]@05ol2L/oo9YkOobJNgolVW]oo>ZkH00ooJ
^kX01_oWdL3oiljmoo3T`?o_m[kogO^cohc[`@;oX_KW00Co[NogojoPn?n_h?So00000_n`dO800on`
co3o[/S]ojg6k002ojg6k0;o[LC[0_n/`NX00on[`>WoZ[oYojZnj008ojZnj0;oZKgX00?oooooo`00
0?ooool06_ooool000Wooooo00Co0000oooooooooooooooo>Ol00004000000/06ATI1000000=o`00
00030000000I6AT06ATI00X06ATI00<0000003<c<`0c<c<00P0c<c<00ol00000C4a<04a<C00304a<
C003o`00001VIVH0IVIV0080IVIV00?o000007moO`1oOgl01`1oOgl00ol00000Ogmo07moO`0807mo
O`05o`00001VIVH0IVIV06IVI_l00000101<C4`00ol00000<c<c03<c<`0203<c<`030000000I6AT0
6ATI00D06ATI00<00000o`000?l000002Ol00004ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03oooool00onW_>SoY[cXojJlj00;ojJkj0GoYK_X00?oYK[XojFkj?nU^nP00onU^^P3
ojFkj0SoY[_X00?oYk_XojNlj?nW_>P00_nW_>P3ojRlj0?oZ;cW00?oZKcWojVki_nY^nH00_nY^nH2
ojZkiP?o000000CoZ[SSojVhi?nY/]ooZK;O0onX]>400onT]NGoYjoMoj6bi002oj6bi0;oUK;/00Co
WJoToh^akon;/NooRk7_0_mXZoL00olZTnoo056lo`18b@03oceRcP04oeQ/c?n1N;ooPGRooh5h_`;o
TWnk00?oX8Fgoj6;_On_T[P00on_T[P2okVG]@CobJNg0ooJ^kX2onOA`005oo3/`ooUo;So^o2LohoH
PonQk_L00_nZh_X2ojoPn0;o[]Cd00?o0000ojg9k_n]bNh00_n^b>d00on]a^co[<;Zojc2jP02ojc1
jP04oj^ojOnZ_nWoZ[oYojZoj@OoZ[kX1?nY_NP00ol0003oooooooooo`0Iooooo`002Oooool01?l0
003oooooooooooooooleo`00000400000?l000000000000001<06ATI10000009o`0000030000000I
6AT06ATI00X06ATI00<0000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00304a<C003o`00001V
IVH0IVIV0080IVIV00?o000007moO`1oOgl03`1oOgl2o`0000@0IVIV00?o000004a<C01<C4`00P1<
C4`00ol00000<c<c03<c<`0203<c<`030000000I6AT06ATI00D06ATI00<00000o`000?l000002Ol0
0004ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool2ojJlj0KoY[_X0_nV
^nT4ojFkj003ojFkjOnU^nSoYK_X00;oYK_X0_nU^nT4ojFkj003ojFkjOnV^nSoY[_X00OoY[_X1_nW
_>P2ojRlj003ojRlionX^nOoZ;_W00?oZK_V00?oZKSSo`000?l000000_nY^><00onZ^>?oZ[7MojZa
g@03ojVbg`03ojRdhOnY[=WoYjoM00;oYjoM00?oXK;TojJ[f_nVZmX00onM[n@00on;/NooVZoVoh2a
m002oh2am0;oCJKh00Co0633o`E>c?l5C/coF6c<0omdN<P2ohf3``?oXH^m0on_T[P00oniUkGo`ZBk
ol:T^`03olVW]`04omJj_ooJ^k[oim70onOA`0;ol>c300GoiObhok_`W?nThOcoY>7loj[RnP02ojcE
m@;o[]Cd0_n]bnl00ol0003o[<C/ojc3j`02ojc3j`03ojc2j_n[`>WoZl3Y00?oZkoY00?oZ[oYojZn
j?nZ_^P00_nZ_^P4ojVnj0GoZKgX00?o0000ooooooooool06?ooool000Wooooo00Co0000oooooooo
oooooooo<ol00002000001/06ATI0`000005o`0000030000000I6AT06ATI00/06ATI00<0000003<c
<`0c<c<00`0c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00<0IVIV00?o000007mo
O`1oOgl03@1oOgl00ol00000IVIV06IVIP0406IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c
<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@0300000?l0003o000000Wo00001?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo0onV_>P3ojJkj0GoY[_Y00?oYK_XojFk
jOnU^nT00_nU^nT00onU^nSoYK_YojFkj@03ojFkj@03ojFkj?nU^nWoYK_Y00;oYK_Y00?oY[_XojFk
jOnU^nT00onV^nT00onV^nSoY[cYojNlj005ojNlj0?oZ;_X00?oZ;_WojRiiOnX^>@00ol000000onY
^>?oZ;3NojV`g@02ojV`g@03ojZagOnYY]?oZZSE00;oZZSE0onY[=T00onW[mgoZZGBojJ[fP03ojJ[
fP03oif_i?nVZMSoVZoV00;oVZoV00CoP;7doiNcjonG/n_oUk?[0_md]OT00ol5C/co:f7CoeQ/c002
ogAhb0;oSH?30onQRkd3ojnB^0Co`ZBk00GobJNgomJj_ooF^[ooiMO8onOA`002oo3/``04onGl^?nk
l9coW]omojCQo0;oZMCg00?o[=Geojc;l?n/bo000_n]bnl2ojc5k003o`000?n/a>co[<?[00;oZl7Z
00?oZl3YojZojOnZ_^P02?nZ_^P2ojVnj0OoZKgX00?o0000ooooooooool05oooool000Wooooo00Co
0000oooooooooooooooo<Ol00002000002006ATI0`0000000ol00000000001TI6@0>01TI6@030000
000c<c<0<c<c00<0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0306IVIP?o0000
2`1oOgl00ol00000IVIV06IVIP0406IVIP03o`00001<C4`0C4a<00<0C4a<00Go000003<c<`0c<c<0
<c<c0000000801TI6@0300000?l0003o000000Wo00001?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?oY[cXojJljOnV^nT01OnV^nTFojFkj@03ojJkjOnV_>WoY[cY00;o
Y[cY00CoYkcXojJljOnV_>WoY[cY0_nW_>P00onX^nSoYk[Wo`000002o`0000;oZ;ST00KoYk7OojR`
g_nX/=koZ;3NojV`gOnWY=<3ojVVd`?oZZSE00?oZJcIoj^Oc?nZYM800_nZYM82ojJ[fP05oj^QcOnV
ZMSoYZWHojJYf?nJ[nH00_nWZmX2oiNcj`06ojRag_nC^_;oTk[boi>jl_l5C/co:f7C0omdN<P2ohf3
``?oXH^m00?o[i:hokFO`_neWl800_o2Y;/01Oo>^/Ooe[ZoomJj_ooF^[ooiMO800;oj_O;00Col>c3
ojCAmonVdoOoY]?g0_nYbo42oj[;l@03ojc;l?n[aNgoZlG]00;o[<G/00?oZl;[o`000?n[`NX00_n[
`NX4ojZoj@OoZ[kX2_nY_NP00ol0003oooooooooo`0Gooooo`002Oooool01?l0003ooooooooooooo
ool`o`0000030000000I6AT06ATI02<06ATI00<0000001TI6@0I6AT03`0I6AT00`000000<c<c03<c
<`0303<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH01@1VIVH2o`0000P0Ogmo00?o
000006IVIP1VIVH01@1VIVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00?o
000001TI6@0I6AT01@0I6AT00`00003o0000o`00000:o`0000Cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Cooooo`;oY[cY1_nV^nTBojFkj@CoYKcY1onV_>T2ojJkj0?o00000_nU
]^@3ojJchP;oYk7O00?oZ;3NojJTe?nWY=<00_nWY=<3ojVVd`03ojZXeOnYVlOoZio<00;oZio<00?o
ZZGBojbJa?n/V/@00on[XLd01?nVZMSo[Z7;ojjQbonWZmX2ok6Vc@?oZ;7N00?oTk[bojRji_nX^^H0
0_l[HM<2oeYie`;oSH?30_nQRkd01OnRV<[o]Io2okFO`_neWl;o`ZBk00?oc[[700Koe[ZoonGGb?oU
elSoj_O;olCg[OnTdOL3ojS9l@03ojW;lOnZaNkoZ/G]00;oZ/G]00?oZlG]oj_2jon[`^/00on[`^/0
1?l0003oZ[oYojZojOnZ_nT:ojZnj0_oZKgX00?o0000ooooooooool05_ooool000Wooooo00Co0000
oooooooooooooooo<Ol0000g01TI6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<
C4`2o`0000H0IVIV2Ol0000706IVIP03o`00001<C4`0C4a<00<0C4a<00?o000003<c<`0c<c<00P0c
<c<00`0000006ATI01TI6@0501TI6@0300000?l0003o000000[o00001?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Cooooo0onV_>T00onV^nWoY[cYojFkj@0AojFkj@OoYKcY1OnV
_>T3o`000003ojJkj?nU^>KoYKKT00?oYKKT00CoY[?Roj>YfonTY]OoY:KG0onVY=@00onWY=?oY9G5
ojNGa@02ojNGa@?oZI_700?oZio<oj^C_On/V/@00on/V/@00on[XLgo/9RoojjQb`02ojjQb`Co/JK=
00CoZ;7NokF^d_ne[];oZ;[V0_nf^M`2o`14``03oeYieon4S=?oQ8cC00CoXYS:0_neWl802?no^=Co
c[[7oljjaoo>^/Oog=kGonGGb?oZml_oa?N]0_nWb?42ojS9l@;oZLG]0_nZaNh01?nZaNgoZ/;[oj[2
jon[`^/5oj[0j@03o`000?nZ_nSoZ[kX00WoZ[kX3OnY_NP00ol0003oooooooooo`0Eooooo`002Ooo
ool01?l0003oooooooooooooool_o`0000030000000I6AT06ATI03L06ATI00<0000003<c<`0c<c<0
100c<c<00ol00000C4a<04a<C00404a<C003o`00001VIVH0IVIV0180IVIV00?o000004a<C01<C4`0
0`1<C4`00ol00000<c<c03<c<`0303<c<`030000000I6AT06ATI00D06ATI00<00000o`000?l00000
2_l00004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool5ojJlj@04ojFk
jOnU_>WoYKcYojFlj@?oYK_Y0_nU_>T3ojFkj@GoYKcZ00?oYKcYojFlj_nU_>X00_nU_>X01?nU_>Wo
YKcZojFlj_nU_>X3o`000004ojFkjOnU^^SoYK[XojFjj0;oYKSV0_nU]^@01?nR[MooXjWKoj>YfonS
ZM/2ojBVe`03ojJTe?nQULOoY9G500;oY9G50onWUlD00onYVlOoZ8jjoj^C_@02oj^C_@;o[9[400Go
[Y2gok2H_on`V;oo/9RoojjQb`02okBK_P;o/JK=00Co^Z?2okF^d_ne[];o]JkB0onf^M`2okC3iP;o
6g7Q0_n4S=<3oj:HbP05okFO`_no^=Co_kSDoknhe?o>^/L00_oLg]L01?oAomKoNmF?ojO7l?nWb?42
ojW4k@;oZLG]1OnZ`^/6oj[0j@;oZ[oY00?o0000ojZoj?nZ_^P01?nZ_^P4ojVnj0goZKgX00?o0000
ooooooooool05Oooool000Wooooo00Co0000oooooooooooooooo;_l000000`0000006ATI01TI6@0<
01TI6@/000008P0I6AT00`000000<c<c03<c<`0403<c<`03o`00001<C4`0C4a<00@0C4a<00?o0000
06IVIP1VIVH03`1VIVH2o`0000D0C4a<00?o000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@05
01TI6@0300000?l0003o000000_o00001?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Oooooo0onV_>T9ojFlj@ooYKcZ0ol00003ojFljP;oYK_Y00?oYK[Xoj:fi_nR]^H00onR/^<2
oj:]g`04oj>YfonMVm7oWiO<oinGc0?oXIG70onTULD00onWUlGoYHVhojR>^P02ojR>^P;oZi>m00Co
[9[4ojj@]on^T;Oo[Y2g0_n`V;l3okBK_P05ok6VcOnjXl;o^Z?2okZS`_ne[]800_nn[/T01_nf^Mco
`;[Dol2je?nd`nKo_LGPoa]ah@;oJI_^0_nRV<X01?nQ/NCo_kSDoknhe?no^=@2olCTkP03omcNeooA
omKoNmF?00?oZL?]00?oZLC]oj[2jonZ`^/01?nZ`^/2oj[0jP03oj[0jOnZ_nWoZ[oY00CoZ[oY00?o
Z[kXo`000?nZ_^P01_nZ_^P2ojVnj0ooZKgX00?o0000ooooooooool05?ooool000Wooooo00Co0000
oooooooooooooooo;Ol000000`0000006ATI01TI6@0901TI6@0400000?l0003o0000000000/0<c<c
00@00000o`000000000000007`0I6AT00`000000<c<c03<c<`0403<c<`;o00001@1<C4`4o`0000/0
IVIV0_l0000604a<C003o`00000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01@0I6AT00`00003o
0000o`00000;o`0000Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`;o
Y[cY1_nU_>T>ojFljP?o000000?oYKgZojFlj_nU_>X00_nU_>X01?nT^n[oXkWXoj>ij?nS^NP3oj:f
iP04oj:bhonLZ=koW:7HoibQf0?oWI_A0_nOUl`2oj6Ea`;oY9G500?oXHNhojF9^?nURKP00onXS[X0
0on[Tkgo[8Zaojj@]`03ojj@]`03ok2H_oncT[Co/i:d00;o]9^n00Co^YVfokZS`_njXl;o^Z?20onn
[/T00oo7/LCo`;[DolVnd002olVnd003okg5h?o3b=goJI_^00;oJI_^0_nQ/N@01_no^=Coa>C^olCT
k_n8k=7o0000ojc4j`;oZ/?/00GoZL?]oj[1jonZ`N_oZ/;[oj[0j@05oj[0jPGoZ[oY1OnZ_^P00ol0
003oZ[kXojZnj002ojZnj1CoZKgX00?o0000ooooooooool04oooool000Wooooo00Co0000oooooooo
oooooooo;?l000000`0000006ATI01TI6@0701TI6@<000004`0c<c<3000001`06ATI00?o00000000
000c<c<01P0c<c<00ol00000C4a<04a<C00604a<C0?o00000P1VIVH6o`0000L0C4a<00?o000003<c
<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6@0300000?l0003o000000_o00001?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo0onV_>T6ojFlj@_oYKcZ0_l000000onU
_>[oYKg[ojFmj`02ojFmjP03ojFlj_nT_>[oY;cZ00;oY;_Z00?oXkWXoineionO]NL00_nM[n@3oibX
gP;oW:7H0_nMVm42oinGc003oj6EaonLQK[oXHNh00;oXHNh0onURKP2ojR>^P?o[8Za0on^T;L3ok>B
]005okBK__njVKKo^YVfokZI]_njXl800_o2XkX00onn[/Woak74olNaa003olVnd0;od<G?00?o`lSM
olO<g_l<T=l00_l<T=l2oh?Eo`05olCTk_n8k=7o[<C[ojc4jon]`^X00on[`^X00onZ`N_oZ/3Yoj[0
j@02oj[0j@;oZ/3Z0onZ_nT:ojZnj003o`000?nZ_^SoZ[kX00;oZ[kX4onY_NP00ol0003ooooooooo
o`0Cooooo`002Oooool01?l0003oooooooooooooool[o`0000030000000I6AT06ATI00L06ATI00<0
000003<c<`0c<c<05`0c<c<00`00003o000001TI6@0K01TI6@030000000c<c<0<c<c00D0<c<c00?o
000004a<C01<C4`0201<C4`2o`0000/0C4a<0_l0000603<c<`03o`00000I6AT06ATI00H06ATI00<0
0000o`000?l000003?l00004ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06_oo
ool4ojJlj@?oYKcY2OnU_>X3o`0000CoYKg[1?nT_N/00onT_>[oXk_[oj>kj`03oj6ij@;oWkGW0_nM
[n@01?nLZ=koTY[Hoi:AconBTLl2oiB:aP;oUhJo0onLQKX3oj67^0;oYHVh00?oZ8jjojR4[_n/R[40
0on/R[400on^T;Oo/H^^ok>B]002ok>B]0Co^YVf0oo2XkX3olNaa004om6g`Oo9_]3od<G?om35c`;o
e/kA00CoalcNolW@h?o9d>3o^/_V0_njbnL00onaa^Wo/<GYok35j@03ojg2jP04oj_2j_n[`NWoZl7Y
oj[0j@KoZ[oY0_nZ_nP;ojZnj003o`000?nY_^SoZKgX01GoZKgX00?o0000ooooooooool04_ooool0
00Wooooo00Co0000oooooooooooooooo:_l000000`0000006ATI01TI6@0701TI6@030000000c<c<0
<c<c00D0<c<c3`00000603<c<`030000000I6AT06ATI01X06ATI00<0000003<c<`0c<c<01@0c<c<3
o`0001<0C4a<00?o000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0701TI6@0300000?l0003o
000000co00001?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo00?oY[cY
ojFljOnU_>X02?nU_>X3o`0000OoYKg[1_nT_N/2oj>kj`04oj6ijOnM]^WoVJkVoiV^iP;oU:GQ0onB
V]P2oi:Ac`;oU8[60_nGQ[l2oib5^P?oXHNh00?oYHVhoj=o[OnXQ:h00_nXQ:h2ojb:/@04ojf4ZOna
Rjko/H^^ok6;[P;o/i:d00?o^I2]okZI]_njVKH00_o1V[02ol:S^P06olZW]_o7/LCodKO1om6g`OoJ
`L7od<G?0ooFc]401OoJemGobM3PolOChoo7dn?o^/_W00;o^<[X00?o/<GYojo4jOn_a>T00on/`NT0
0on[`NWoZl3Yoj_0j@03ojZoj@CoZ[oX3?nZ_^P00ol0003oZKkXojVnj00EojVmj003o`000?oooooo
oooo01;ooooo0009ooooo`04o`000?ooooooooooooooob[o000000<0000001TI6@0I6AT01P0I6AT0
0`00003o000003<c<`0403<c<`0300000?l00000C4a<00h0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0J01TI6@03o`0000000000<c<c00L0<c<c0ol0000=04a<C0?o0000200c<c<0
0`0000006ATI01TI6@0701TI6@0300000?l0003o000000co00001?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01gooooo0_nU_>T5ojFljP?o00000onU_NX6ojFmj`KoY;g[00CoXkc[
oj2jjonP^^_oX;[[0_nM]^T2oiV^iP;oU:GQ0_nBV]P2oi:Ac`;oU8[60_nGQ[l3oib5^P04oj67^?nM
NjgoXgn]oj=o[@?oZ8B^00?o[8Zaojf4ZOn]Q:T00onaRjh01?ncT[Co^I2]okV@[OnjVKH3ol6J/003
ol:S^_o:YkKobZNf00?odKO100?of/71on?>`_oFc]400_oFc]400ooJemGofMkKolOCh`02ol?DiP03
okS:j?ndbNWo]<WY00?o[lCY0on/`NT00on[`>WoZkoYojZoj@02ojZoj@03ojZoj?nZ_^SoZ[kX00co
Z[kX00?oZKkXojVmj?l000005onY_NP00ol0003oooooooooo`0Aooooo`002Oooool01?l0003ooooo
oooooooooolYo`0000030000000I6AT06ATI00H06ATI00<0000003<c<`0c<c<00`0c<c<2000000H0
C4a<2?l0000404a<C0<00000100c<c<2000001`06ATI00<0000003<c<`0c<c<0200c<c<4o`0000H0
C4a<0ol0000:03<c<`030000000I6AT06ATI00L06ATI00<00000o`000?l000003Ol00004ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool4ojFljP?o00000onU_NX9ojFmj`Ko
Y;g[0_nS_>/01?nP^^_oW;O[oiJ`jOnF/>T2ohfUi@;oQYOM0_n2RM42oh=naP;oR7Vl0_n?Mk@3oiIh
/0;oWG^]0onSOjd2ojR4[PCo[HBY0_naRjh3okV@[@Co`IZ`0oo:YkH01?oE/;CodKO1om[1`OoJ`L42
on?>`P06omK>dOoJemGofMkKomWNfooDhN7o`mCV0_nndNT00ondbNWo/LKYojk2j@03ojk2j@03ojc1
jOn[`>WoZl3Y00;oZkoY00?oZ[oYojZnj?nZ_^P03_nZ_^P2ojVnj003ojVmj?l0003oZKgX01KoZKgX
00?o0000ooooooooool04?ooool000Wooooo00Co0000oooooooooooooooo:Ol000000`0000006ATI
01TI6@0501TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00`1<C4`3o`0000P0IVIV
0ol0000404a<C00300000?l00000<c<c00<0<c<c00<0000001TI6@0I6AT06P0I6AT00`000000<c<c
03<c<`0;03<c<`Ko00002`0c<c<2000000T06ATI4Ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool07oooool3o`000003ojJmj_nU_N[oYKgZ00?oYKgZ2?nU_N/3ojFnj`?oY;g[
0_nS_N`2oj2kk0;oW;O[0_nF/>T2ohfUi@;oQYOM0_n2RM401?n3O/KoR7VlohQi_?n8NK`2ohmg]0;o
UWR`0onMNjd2oj=o[@;oZ8B^00CoZ7nWojf4ZOn]Q:Wo[HBY0_naRjh3okV@[@06oknCZ?o1V[3o`IZ`
ol6J/?o:X:cobZNf0_oE/;@2om[1`@?ohlk200?ojMc6on_Yc?oIg]/00_oDhN401?o<gnOo_]7YokS>
j_nhc^X2ok76j@;o[/;Y0_n/`NT00on[`>WoZkoYojZoj002ojZoj0ooZ[kX00?oZKkXojVmj?nY_NP0
0_nY_NP00ol0003oZKgXojVmj00DojVmj003o`000?oooooooooo013ooooo0009ooooo`04o`000?oo
ooooooooooooobSo000000<0000001TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0303<c<`04o`00
001<C4`0C4a<04a<C0?o00003P1VIVH3o`000080C4a<0P00000403<c<`030000000I6AT06ATI01X0
6ATI00?o00000000000000006@0c<c<2000000X06ATI00<00000o`000?l000003ol00004ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool07?ooool3o`0000;ooooo0onV_NX3ojFmjP[o
YKg[0_nU_^/3ojBnk003oj>mk?nR_>coWK[]00;oWK[]0_nF]>`2ohVYjP03ogZHi?m]Q=SoKHCH00;o
JG?:0_n3O/H2ohQi_0;oSgNd0onFN;02oiek[@;oXgn]00?oZ8B^ojQoYonXOjL00on]Q:T01?naRjko
]HVWokF9YoniT:d2oknCZ0;o`IZ`0_o:X:`01Oo:YkKoeK2domF`]?oQ_KCof/7100;ohlk20_oYg<H0
0oo[jLcoiO7DomCQh@02olcOi`03ol;Jjonhc^[o/lW[00?o[lCY0_n/`NT2oj_0j@;oZkoY00?oZ[oX
ojZnj?nZ_^P03_nZ_^P2ojVnj0?oZKgX00?o0000ojVmj?nY_NP05OnY_NP00ol0003oooooooooo`0?
ooooo`002Oooool01?l0003ooooooooooooooolXo`0000030000000I6AT06ATI00D06ATI00<00000
03<c<`0c<c<00P0c<c<00`000000C4a<04a<C002o`0000<0IVIV3_l0000306IVIP05o`00001<C4`0
C4a<04a<C0000000100c<c<00`0000006ATI01TI6@0L01TI6@8000005@0c<c<2000000/06ATI00<0
0000o`000?l000004?l00004ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06Ooo
ool3o`0000Kooooo0_nV_NX3ojFmjPOoYKg[1_nU_^/3ojBnk0;oX[c/00?oWK[]oiVhk_nI^>h00_n<
/>h2ogNOj`04oe^6h_m]Q=SoKHCHofUcbP;oKVZm0_n8NK`2ohmg]0?oUWR`0_nMNjd00onSOjgoXWVV
ojQoY`02ojQoY`?o[HBY0oneRJL01OniT:go_i>XoknCZ?noTjSo`IZ`00;obZ2/0_oE/;@2on6m]004
ong>]?oSc/;ojMc6onWLaP;ojnW<00CoiO7Dom_bgoo<gnOo`][[0_nid^`2ok?9j`03ojo4jOn]`^Wo
[L;Y00;oZl3Y00CoZkoYojZoj?nZ_nSoZ[oX3onZ_^P00onY_^SoZKgXojVmj004ojVmj003o`000?nY
_NSoZKgX01GoZKgX00?o0000ooooooooool03_ooool000Wooooo00Co0000oooooooooooooooo9ol0
00000`0000006ATI01TI6@0501TI6@040000000c<c<0<c<c03<c<`8000000P1<C4`00ol00000IVIV
06IVIP0206IVIP03o`00001oOgl0Ogmo00`0Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<C003
o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT07@0I6AT00`000000<c<c03<c<`0A03<c<`03
0000000I6AT06ATI00X06ATI00<00000o`000?l000004Ol00004ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05_ooool3o`0000[ooooo0_nV_NX4ojFmjP?oYKg[1onU_^/2ojFnk004
ojBnk?nS_^coXkk/oj>nk0;oWkc]0_nI^>h2ohb`kP;oMio[00GoFhKRodEYd_m5JM;oJG?:ofiZ_@03
ogUX/`;oSgNd0_nFN;001?nMNjgoVWBVoj9iY_nRNJH4ojQoY`;o[HBY0oneRJL4oknCZ0?obZ2/00Go
eZZ[omF`]?oQ_KCohKfdong>]002ooGP]@04ooG`]Oo[jLcoiO7Dom_bg`;ocn_Y00Co`]o^okWBk?nc
bnco/l_/0_n_aNX00on]`^Wo[<7Yojc1j@03oj^oj@03ojZoj?nZ_^SoZ[kX00coZ[kX1?nY_^P6ojVm
j003o`000?nY_NSoZKgX01CoZKgX00?o0000ooooooooool03_ooool000Wooooo00Co0000oooooooo
oooooooo9ol000000`0000006ATI01TI6@0401TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`0
1?l00000IVIV06IVIP1VIVH2o`00000307moOol0003o000000co000000D0Ogmoo`000?l0003o0000
06IVIP02o`000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0M01TI6@@00000
2`0c<c<01?l00000000000000000000<01TI6@0300000?l0003o000001;o00001?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo0_l0000>ooooo`?oY[gZ00?oYKgZojJmj_nU
_N/00_nU_N/8ojFnj`?oY;k/00?oXkk/oj:nk?nM_>h00_nM_>h2oi>gk`;oOj_`00GoFi?/obUZfolY
J]_oAFWBocmF`P02ofiZ_@;oNFRc0_n5JZd2oi1_Z@;oVWBV0_nRNJH4ojQoY`03ojf4ZOnaPjCo/H>T
00;o]HVW1?noTjP2olZP[0;oeZZ[0_oQ_K@2ong>]0;omN2e00KomO2eonci^OoPo/Ooe_cMolo[jOo2
gnh2okSCkP03ok?;k?n_aN_o[L;Z00;o[L;Z00?o[<7Yoj^ojOn[_nT00onZ_nP=ojZnj0?oZKkX2OnY
_NP00ol0003oZKgXojVmj00@ojVmj0?ooooo00?o0000ooooooooool03_ooool000Wooooo00Co0000
oooooooooooooooo9ol000000`0000006ATI01TI6@0401TI6@050000000c<c<0<c<c03<c<`000000
0`1<C4`01?l00000IVIV06IVI_l0000207moO`03o`00002IVIT0VIVI00`0VIVI00Oo000007moO`1o
Ogl0Ogmoo`00001VIVKo00000080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@08
01TI6@L000004P0I6AT00ol00000000000000008000000l06ATI00<00000o`000?l000004ol00004
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool3o`00017ooooo1OnV_NX0
0onU_N_oY[k[ojJnj`08ojFnj`?oY;k/0_nR_^`00onM_>koVk__oi^kk`02ohjfl@08og2Vl_leP^So
=H;XobUZfol0?l7oAFWBocmF`_m^J[d2ogUX/`;oQFZ]0_n@KjT2oiYdYP?oXWVV0onXOjL3ok63Y003
okF9YonkS:Co^hbT00;o_i>X0_o8VJH01_o:X:coeZZ[omJZZooT^J_ohKfdong>]0;omN2e0_oel;D0
0ooPo/Ooe_cMolWak@02okgOl@03okSCk_nab^co/L[/00;o[lG[00Go[L;Zoj_1jOn[`NWoZkoYojZo
j@0?ojZnj0CoZKkX2OnY_NP00ol0003oZKgXojVmj00>ojVmj0Gooooo00?o0000ooooooooool03_oo
ool000Wooooo00Co0000oooooooooooooooo9ol000000`0000006ATI01TI6@0401TI6@050000000c
<c<0<c<c03<c<`0000000P1<C4`01?l00000IVIV06IVI_l0000207moO`03o`00002IVIT0VIVI0080
VIVI2_l0000209VIV@07o`00001oOgl0Ogmo07moOol00000IVIVo`00000204a<C0030000000c<c<0
<c<c0080<c<c00<0000001TI6@0I6AT01`0I6AT00`00003o0000o`000004o`0000800000:@0I6AT0
0`00003o0000o`00000Do`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`?o00005Oooool3ojJmjP;oY[kZ1_nV_^/00onU_^_oY[k[ojJnj`02ojFnj`?oY;k/0_nR_^d0
0onK^nooV[c_ohVel`02ohVel`06of6Sm?leP^So=H;Xo`10`_l0?l7o?eK20_m=DKH2ogUX/`03ohEZ
[On@KjWoT6nY00?oVWBV0_nRNJH2ojQoY`05oj]mX_naPjCo/H>Tok63Y?neRJL00_nkS:@01_noTjSo
b9VVolRIY_o8VJKobZ2/omJZZ`;oi;V[00?olljYong>]?oeh;D00_oel;D01Oo2k8oo`OVdolGnh?no
k_;o_Moa00;o]=7_00?o/L[/ojg4jon]a>/00_n/`^X00on[`NWoZkoYoj^oj@02ojZoj@_oZ[kX1_nY
_^P;ojVmj003o`000?nY_NSoZKgX00WoZKgX2_ooool00ol0003oooooooooo`0=ooooo`002Oooool0
1?l0003ooooooooooooooolVo`0000030000000I6AT06ATI00@06ATI00D0000003<c<`0c<c<0<c<c
0000000304a<C003o`00001VIVKo00000080Ogmo00?o000009VIV@2IVIT00ol0000:0;>c/`04o`00
002IVIT0VIVIo`000080Ogmo00Co000006IVIP1VIVKo00000P1<C4`01Ol00000<c<c03<c<`0c<c<0
000000P06ATI00<00000o`000?l000001ol00002000002H06ATI6?l00004ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03?ooool3o`0001Wooooo00?oY[gZojJnj_nV_^X00onV_^X8
ojJnj`;oYKk[0onT_^`2oj6nk@;oV[c_00SoRKGcohNfm?n7]_CoF:;fo`]^g_l03i;o03o1ocmF`P;o
CE6f00CoHUJ^ogUX/on5JZgoQFZ]0_n@KjT2oiYdYP;oXWVV00?oZ7nWoj]mX_n[OJ800onaPj@3ok^<
Y004oknCZ?o8VJKob9VVolRIYP;oeZZ[0_oT^J/02?occZWoo>>Soo;^UOobkYGoe^b8ol7i]?o5o^3o
_nkb0_nff_801OnddNoo[lS/ojo8k?n]a>_oZl7Z00?oZl3Y00?oZkoYojZoj?nZ_^P03OnZ_^P4ojVn
j0goZKgX00?o0000ojVmj?nY_NP01OnY_NP=ooooo`03o`000?oooooooooo00gooooo0009ooooo`04
o`000?ooooooooooooooobKo000000<0000001TI6@0I6AT0100I6AT01@000000<c<c03<c<ol00000
00000080C4a<00?o000006IVI_l000000P1oOgl01?l00000VIVI09VIVOl000020;>c/`[o00000P2c
/k<2o`00000509VIVOl0003o000007moOol000000P1VIVH01?l00000C4a<04a<C000000303<c<`03
0000000I6AT06ATI00D06ATI00<00000o`000?l000002Ol00003000002406ATI0P00000Ho`0000Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`?o00007_ooool5ojJnjPOo
Y[k[0onU_^/3ojBnk0?oXKk]0_nJ_?02ohNfm0;oF:;f00Co00nBo`0o`OloE/;oCE6f0_mREZh2ohEZ
[@;oT6nY0_nJM:H2oj9iYPCoZgfR0_naPj@3ok^<Y0Cob9VV00?oeJFVomJZZooT^J/00_occZT01Ool
hj?ol^jEoo;^UOnPl;Go^?S]00;o]^?f00Co]][bok3<k_n`c>ko[lS/0_n/`n/2oj_1jP03oj_0jOnZ
_nWoZ[oY00;oZ[oX2_nZ_^P5ojVnj0ooZKgX00Co0000ojVmj?nY_NSoZKgX4Oooool00ol0003ooooo
ooooo`0=ooooo`002Oooool01?l0003ooooooooooooooolVo`0000030000000I6AT06ATI00@06ATI
00@0000003<c<`0c<c<000000`1<C4`00ol00000IVIVo`00000207moO`03o`00002IVIWo00000080
/k>c00?o00000<c<c03<c<`0203<c<`2o`000080/k>c00So000009VIV@2IVIWo000007moOol00000
IVIVo`000080C4a<00D0000003<c<`0c<c<0<c<c0000000701TI6@0300000?l0003o000000co0000
0P00000M01TI6@8000006_l00004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
1_ooool3o`0002;ooooo1OnV_^X7ojJnj`04ojFnjonV_n_oY[o[ojJoj`;oY;k/00?oXKk]oj:nkOnR
_^d00_nJ_O02ohRhm@;oFJKg00Go002?o`0W[_m=DKKoCE6fof9F[P02ogQNZ0;oT6nY0_nJM:H00onR
NJKoXgNRoj]mXP03oj]mXP03ok63Y?nfQZ;o^hbT00;o^hbT00?oaI>SolRIY_o8VJH00_oEYJH2onBi
Z`05oo?>ZOolhj?ol^jEoo;^UOnLm=X00_n`j_P01?nfhoKo/=3aok3@lOn`c>h2ojc5k003ojc3jon[
`>WoZl3Y00;oZkoY00?oZ[oYojZnj?nZ_^P02OnZ_^P7ojVnj13oZKgX00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0=ooooo`002Oooool01?l0003ooooooooooooooolVo`0000030000000I
6AT06ATI00<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C003o`00001VIVKo00000080Ogmo
00?o000009VIVOl000000P2c/k<01?l00000c<c<0<c<c03<c<`7o`0000<0c<c<00Ko00000;>c/`2c
/k?o000009VIVOl0000207moO`03o`00001VIVKo00000080C4a<00D0000003<c<`0c<c<0<c<c0000
000601TI6@0300000?l0003o000000ko00000P00000I01TI6@8000007?l00004ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00oooool3o`0002Kooooo0_nW_^X01?nV_^[oYkkZojNn
j_nW_^X7ojJnj`?oY[o[0_nU_n`00onR_^goXkk]oj>nk@02oibnl0;oSK[d0_mT[OT01?l09jko3bVX
odeA]_mREZh2ogQNZ0;oRVRU00CoVWBVoiQ`XonSMj;oXgNR1?n[OJ801?naPjCo]XJRokJ6X_nkS:@2
olFCX`;ob9VV0_oEYJH2onBiZ`04oo?>ZOolhj?ol^jEo`0000;o[=Of00?o[mCdojc8k_n/b>h00_n]
and01?n/aNcoZl7Zoj_1j_n[`>T4ojZoj@_oZ[kX1_nY_^P=ojVmj0Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0=ooooo`002Oooool01?l0003ooooooooooooooolVo`0000030000
000I6AT06ATI00<06ATI00L0000003<c<`0c<c<0<c<c0000001<C4co00000080IVIV00Go000007mo
Ool00000VIVIo`0000020;>c/`03o`00003<c<`0c<c<00;o00001`3Vi^H2o`000080c<c<00So0000
0;>c/`2c/k?o000009VIVOl00000Ogmoo`000080IVIV00Co000004a<C01<C4`000000P0c<c<00`00
00006ATI01TI6@0401TI6@0300000?l0003o0000013o00000`00000C01TI6@03o`00000000000000
01ko00001?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`?o0000:_ooool8
ojNnjP03ojJnjonW_^_oY[o[00GoY[o[0_nU_n`00onS_^goY;o/ojBok002oinnk`;oTkgc00GoM[Ki
okHn0?l09jko3bVXof9F[P02ogQNZ0;oRVRU0_nHL:<3oj=gXP?oZgfR00Co/H>TokJ6X_nfQZ;o^hbT
0_o5Tj<2olRIYP;oeJFV00OoiKNUoo?>ZOoccZWoo>>So`000?nWf?So[=Of00;oZlW_00?o[<S^oj_3
jon[`n/00_n[`^/00on[`N[oZ[oYojZoj@03ojZoj@SoZ[kX2_nY_^P;ojVmj0Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0=ooooo`002Oooool01?l0003ooooooooooooooolVo`00
00030000000I6AT06ATI00<06ATI00L0000003<c<`0c<c<0<c<c0000001<C4co00000080IVIV00Go
000007moOol00000VIVIo`0000020;>c/`03o`00003<c<co000000D0i^KV0ol000020>KViP04o`00
003<c<`0c<c<o`0000<0/k>c0_l000001@1oOgoo000006IVIP1VIVKo00000080C4a<00@0000003<c
<`0c<c<000001P0I6AT00`00003o0000o`00000Do`0000H000001P0I6AT60000027o00001?ooool0
0ol0003oooooooooo`0?ooooo`Co0000;_ooool8ojNnjP;oYkk[00GoY[o[ojNojonW_n_oY[o[ojNo
j`03ojJoj`03ojBok?nU_ncoX[o^00;oX[o^0_nJ__400on7_?So001bo`lYZ002of9F[P03ogQNZ?n:
J:GoRVRU00;oV72S0onSMj83oj]mXP?o]XJR00Co^hbTolFCXoo5Tj?oaI>S0_oEYJH2onFgY@04ooS@
X_okiI3oe=]WojS9l@;oZLW`00CoZlW_oj[3k?nZ`ncoZl?[1?nZ`>T00onZ_nWoZ[kYojZnj@08ojZn
j0WoZKkX2_nY_NP<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool000Wo
oooo00Co0000oooooooooooooooo9_l000000`0000006ATI01TI6@0301TI6@070000000c<c<0<c<c
03<c<`000000C4a<o`00000206IVIP07o`00001oOgoo000009VIVOl00000/k>co`0000020<c<c004
o`00003Vi^H0i^KV0>KViP;o00000`3oool2o`0000050>KVi_l00000c<c<0<c<c?l000000P2c/k<0
1ol00000VIVIo`00001oOgoo000006IVI_l000000P1<C4`010000000<c<c03<c<`00000601TI6@03
00000?l0003o000001[o00001P00000Wo`0000Cooooo00?o0000ooooooooool03oooool2o`00037o
oooo2_nW_^X00onW_n_oYkoZojNojP02ojNoj`03ojJojonW_n_oYko[00;oYKo/00CoX[o^ojBokOnT
_ngoY;o]0_nO_nl00ol?:JSo>S^Xof9F[P02ogQNZ004ohYXYOnHL:?oV72SoiQ`X`;oXgNR0_n[OJ80
1?n_Oj7o]XJRokJ6X_nfQZ84olFCX`;oeJFV0_oU]jD00oohd:;onnF@ojS9l@02ojW3k0?oZ/?/0_nZ
`>X3oj[0j@;oZ[oY00?oZ[kYojZnj?nZ_^P00onZ_^P<ojVnj0WoZKgX3oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00cooooo0009ooooo`04o`000?ooooooooooooooobKo000000<0
000001TI6@0I6AT00`0I6AT010000000<c<c03<c<`00000204a<C007o`00001VIVKo000007moOol0
0000VIVIo`0000020;>c/`03o`00003<c<co000000<0i^KV00?o00000?ooo`3oool01@3oool00ol0
0000i^KVo`0000020<c<c003o`00002c/k<0/k>c00;o000000D0Ogmoo`00001VIVH0IVIVo`000002
04a<C0040000000c<c<0<c<c000000H06ATI00<00000o`000?l00000A_l00004ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0;oooool:ojNnjP04ojNoj_nW_^[oYkkZojNnjPGoYko[
0_nV_n/01onT_ngoY[o/ojJok?nS_ngo001bo`lYZ?lj>jP00_mhGZP2ohYXY@;oV72S0_nSMj800on[
OJ;o[gnQojmoX@03okJ6XPCoaI>S00?odZ2SomFUY_oU]jD00_ohd:800ooDffOoZ<;/ojW3k004ojW0
jP03oj[0j_nZ_nWoZ[oY00?oZ[oY1OnZ_^P=ojVnj0KoZKgX5?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00cooooo0009ooooo`04o`000?ooooooooooooooobKo000000<0000001TI
6@0I6AT00`0I6AT010000000<c<c03<c<`00000204a<C009o`00001VIVKo000007moOol00000VIVI
o`00002c/k?o00000080c<c<00Co00000>KViP3Vi^Ko0000203oool01?l00000i^KV0>KVi_l00002
0<c<c009o`00002c/k?o000009VIVOl00000Ogmoo`00001VIVKo00000080C4a<00Co000003<c<`0c
<c?o00001P0I6AT00`00003o0000o`000016o`0000Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0_ooooo`03ojNnj_nX_^WoZ;kY00?oYkkZ0_nX_^X4ojNnjP;oZ;kZ0_nW_nX00onW
_n_oYkoZojNojP02ojNoj`08ojJok?nW_n_oYko[ojFok?l?:JSo>S^Xof=@YomhGZP2ohYXY@;oV72S
0_nSMj84ojmoX@03okJ6X_noSJ7oaI>S00;oaI>S0_oBX:<2onFgY@03ooS@X_okiI3oZ<;/00GoZL3Z
0_nY_nT00onZ_nWoZKkYojVnj@02ojVnj@03ojZnj?nY_^SoZKkX00goZKkX0onY_NPJooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool000Wooooo00Co0000oooooooooooooooo
9_l000000`0000006ATI01TI6@0301TI6@040000000c<c<0<c<c00000080C4a<00Wo000006IVI_l0
0000Ogmoo`00002IVIWo00000;>c/ol000000P3<c<`01?l00000i^KV0>KVi_l000080?ooo`04o`00
003Vi^H0i^KVo`000080c<c<00Wo00000;>c/ol00000VIVIo`00001oOgoo000006IVI_l000000P1<
C4`010000000<c<c03<c<`00000601TI6@0300000?l0003o000004Ko00001?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo033ooooo0_nX_^T00onW_^[oZ;kYojRnj@02ojRnjP03ojNn
j_nX_^[oZ;kZ00;oZ;kZ0onX_nX00onW_n[oZ;oZojRojP02ojRojP05ojNojonX_n[oZ;oZo`00N?lj
>jP00_mSD:L2ohYXY@;oV72S00?oXgNRojEhXOn_Oj400on_Oj400onfQZ;o_hfQokn=X@02olFCX`;o
dZ2S0_oU]jD01?ohd:;onnF@ojVoj_nY`>X5ojVoj@GoZKkY3onY_^P3ojVmj1cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`002Oooool01?l0003ooooooooooooooolVo`00
00030000000I6AT06ATI00<06ATI00L0000003<c<`0c<c<0<c<c0000001<C4co00000080IVIV00_o
000007moOol00000VIVIo`00002c/k?o00000<c<c?l00000i^KVo`00000:0?ooo`0>o`00003Vi^H0
i^KVo`00003<c<co00000;>c/ol00000VIVIo`00001oOgoo000006IVI_l0000204a<C0040000000c
<c<0<c<c000000D06ATI00<00000o`000?l00000Aol00004ooooo`03o`000?oooooooooo01Cooooo
0_l0000aooooo`OoZ;kY00?oZ;kZojRnjOnX_^T00_nX_^X01OnX_n[oZ;kZojRnj_nX_n[oZ;kZ00Go
Z;oZ00CodF80ocXkZ?mSD:OoHe2W0_n2HZD00onHL:?oUfnSojEhX@02ojEhX@?o[gnQ00Co]XJRokn=
XOnoSJ7oaI>S0ooBX:<00ooU]ZCon=2RooS@XP04ojVoj@GoZKkY4_nY_^PQooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool000Wooooo00Co0000oooooooooooooooo9ol00005
01TI6@070000000c<c<0<c<c03<c<`000000C4a<o`00000206IVIP0:o`00001oOgoo000009VIVOl0
0000/k>co`00003<c<co00000>KViP;o00002@3oool03_l00000i^KV0>KVi_l00000c<c<o`00002c
/k?o000009VIVOl00000Ogmoo`00001VIVKo00000P1<C4`01@000000<c<c03<c<`0c<c<0000000@0
6ATI00<00000o`000?l00000Aol00004ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;oooool<ojRnj@03ojRnj_nX_^WoZ;kY00;oZ;kZ00SoZ;oZojRnjOnX_^WoZ;oZojRnjOl019;o
>S^Xof=@Y`;oPV:U0_nGKj<3ojEhX@?o[gnQ0onoSJ401oo5Tj?odZ2Som:PXooBX:?oiKJToo_EW_ok
iI000_nY_nT3ojVnjACoZKkX9?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo0009ooooo`04o`000?ooooooooooooooobKo000000<0000001TI6@0I6AT00`0I6AT01`000000
<c<c03<c<`0c<c<0000004a<C?l000000P1VIVH02Ol00000Ogmoo`00002IVIWo00000;>c/ol00000
c<c<o`0000030>KViP03o`00003oool0oooo00H0oooo00ko00000>KViP3Vi^Ko00000<c<c?l00000
/k>co`00002IVIWo000007moOol00000IVIVo`000080C4a<00D0000003<c<`0c<c<0<c<c00000004
01TI6@0300000?l0003o000004Oo00001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02kooooo5_nX_^T00ol007So>S^Xof=@Y`02oh9RY@;oUfnS0onUN:43ojmoX@?o_hfQ0ooBX:<2
onFfY003oo_EW_l0003oZKkY00;oZKkY4_nY_^PYooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool000Wooooo00Co0000oooooooooooooooo9_l000000`0000006ATI01TI6@03
01TI6@070000000c<c<0<c<c03<c<`000000C4a<o`00000206IVIP05o`00001oOgoo000009VIVOl0
00000P2c/k<00ol00000c<c<o`0000030>KViP;o00001@3oool01?l00000i^KV0>KVi_l000020<c<
c009o`00002c/k?o000009VIVOl00000Ogmoo`00001VIVKo00000080C4a<00@0000003<c<`0c<c<0
00001@0I6AT00`00003o0000o`000017o`0000Cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0^oooooa?oZ;kY0onY_^T01?l019;oHe2Wof=@Yon2HZD2oiM_X`?oYGRQ0on_Oj43okn=
X@03olfLXooBX:?odZ2S00;oiKJT00?onmFNojVnjOnY_^T00_nY_^T>ojVnj2gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`002Oooool01?l0003ooooooooooooooolWo`00
00030000000I6AT06ATI00<06ATI00@0000003<c<`0c<c<000000P1<C4`00ol00000IVIV06IVIP02
o`000080VIVI00Go00000;>c/ol00000c<c<o`0000050>KViP03o`00003oool0oooo00?o00000P3V
i^H01Ol00000c<c<o`00002c/k?o00000080VIVI00Go000007moOol00000IVIVo`00000204a<C004
o`00000c<c<0<c<co`0000D06ATI00<00000o`000?l00000Aol00004ooooo`03o`000?oooooooooo
01Wooooo0_l0000`ooooo`WoZ;kY00?oZKkYojRnjOnX_^T00_nX_^T6ojVnj@04o`04T_mSD:OoHe2W
oh9RY@?oUfnS0onUN:401?n_Oj7o]hNRokn=XOnoSJ42olfLX`;odZ2S00CoiKJToo_EW_o[hGKoZKkY
3onY_^P`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool000Wooooo00Co
0000oooooooooooooooo9ol000000`0000006ATI01TI6@0301TI6@070000000c<c<0<c<c00000?l0
0000C4a<o`00000206IVIP05o`00001oOgoo000009VIVOl000000P2c/k<01?l00000c<c<o`000?l0
00040>KViP;o0000103Vi^H01_l00000c<c<0<c<c?l00000/k>co`000080VIVI00Go000007moOol0
0000IVIVo`00000204a<C0040000000c<c<0<c<c000000D06ATI00<00000o`000?l00000Aol00004
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;_ooool00onX_^WoZKkYojVnj@03
ojRnj@CoZKkY00?oZ;kYojVnjOnY_^T01_nY_^T00ooDK@3o<cJUof=@Y`02oh9RY@;oUfnS0onUN:40
1?n_Oj7o]hNRokN7X_noSJ43olfLX`;oiKJT00?onmFNojVnj?nY_^P02onY_^Peooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool000Wooooo00Co0000oooooooooooooooo9ol0
00000`0000006ATI01TI6@0301TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`00ol00000IVIV
o`00000207moO`05o`00002IVIWo00000;>c/ol000000`3<c<`00ol00000i^KV0>KViP060>KViP07
o`00003<c<`0c<c<0<c<c?l00000/k>co`00000209VIV@05o`00001oOgoo000006IVI_l000000P1<
C4`010000000<c<c03<c<`00000501TI6@0300000?l0003o000004Oo00001?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02kooooo4onY_^T01?l019;o<cJUoh9RYOn2HZD2oiM_X`;o
YGRQ00GoZWjTokN7X_ngQj;o]hNRokn=X@03olfLX`;oiKJT00?onmFNojVnj?nY_^P01onY_^Pjoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wooooo00Co0000oooooooo
oooooooo:?l000000`0000006ATI01TI6@0301TI6@070000000c<c<0<c<c03<c<`000000C4a<o`00
000206IVIP07o`00001oOgl0Ogmoo`00002IVIWo00000;>c/`03o`0000030<c<c?l0003o000000Ko
00000`3<c<`02_l00000/k>co`000?l00000VIVIo`00001oOgoo000006IVI_l0000204a<C0040000
000c<c<0<c<c000000D06ATI00<00000o`000?l00000B?l00004ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0;_ooool00onY_^WoZKkXojVnj00?ojVnj@04o`04T_lc=ZGoLE^Yoh9R
Y@;oUfnS00?oYGRQojYnY?nZOZ@00ongQj84olfLX`03onBfY_oU]ZCojn5f00OoZKkX??ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`04o`000?oooooooooooooo
obSo000000<0000001TI6@0I6AT0100I6AT010000000<c<c03<c<`00000204a<C004o`00001VIVH0
IVIVo`000080Ogmo00?o000009VIVOl000000`2c/k<00ol00000c<c<0<c<c0060<c<c0?o000000L0
/k>co`00002IVIT0VIVIo`00001oOgoo00000080IVIV00Co000004a<C01<C4`000000P0c<c<00`00
00006ATI01TI6@0301TI6@0300000?l0003o000004So00001?ooool00ol0003oooooooooo`0Noooo
o`;o0000;oooool5ojVnj003ojVnjOnY_^SoZKkX00;oZKkX00?oZKkYojVnj?nY_^P00_nY_^P01?nY
_^WoZKkXojVnj?lc=ZD2og5KZ@03oiM_XonFLJOoZWjT00;oZWjT0ongQj83olfLX`;oi;JV00?onmFN
ojVnj?nY_^P00_nY_^Q1ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool0
00Wooooo00Co0000oooooooooooooooo:?l000000`0000006ATI01TI6@0401TI6@070000000c<c<0
<c<c03<c<`000000C4a<o`00000306IVIP05o`00001oOgl0Ogmoo`00002IVIT00_l000020;>c/`So
00000`2c/k<01ol00000VIVI09VIV@2IVIWo000007moOol000000P1VIVH01?l00000C4a<04a<C000
000203<c<`030000000I6AT06ATI00<06ATI00<00000o`000?l00000B?l00004ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0;OoooolAojVnj003oc<fYOmaFjWoLE^Y00;oUW6W1?nZ
OZ@2okN7XP?ocIbS0_oT]ZH00oomh9coooooooooo`14ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool000Wooooo00Co0000oooooooooooooooo:Ol000000`0000006ATI01TI
6@0401TI6@070000000c<c<0<c<c03<c<`000000C4a<o`00000306IVIP04o`00001oOgl0Ogmoo`00
0080VIVI0_l000090;>c/`;o00000P2IVIT2o`00000507moOol00000IVIV06IVI_l000000P1<C4`0
1@000000<c<c03<c<`0c<c<0000000D06ATI00<00000o`000?l00000B?l00004ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0;_ooool?ojVnj003okmO0?lc=ZGoLE^Y00?oUW6W0onZ
OZ@01?ngQj;oaIJVolFFY_o=W:<3onBfYP03ojg0@_oooooooooo04Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0:ooooo`002Oooool01?l0003ooooooooooooooolYo`0000030000
000I6AT06ATI00@06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C005o`00001VIVH0IVIV06IV
I_l000000P1oOgl01?l00000VIVI09VIV@2IVIT9o`0000<0VIVI00Co000007moO`1oOgoo00000`1V
IVH01?l00000C4a<04a<C000000203<c<`030000000I6AT06ATI00<06ATI00<00000o`000?l00000
BOl00004ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;_ooool2ojVmj003ojVn
j?nY_NSoZKgX00;oZKkX0_nY_NP00onY_^SoZKgXojVmj003ojVnj003oc<fYOmaFjWoUW6W00;oUW6W
0onZOZ@01?ngQj;oaIJVolFFY_o=W:<2onBfYP03oogPW?oooooooooo04Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01?l0003ooooooooooooooolZo`000003
0000000I6AT06ATI00@06ATI00Go000003<c<`0c<c<0<c<c0000000204a<C0;o00000P1VIVH2o`00
000407moOol0003o0000o`0000T0VIVI0ol000000`1oOgoo0000o`00000206IVIP;o000000<0C4a<
00000?l000000`0c<c<00ol000006ATI01TI6@0301TI6@0300000?l0003o000004Wo00001?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02kooooo3_nY_NP00ol007WoLE^Yog5KZ@02
oiIaY`?oZWjT00Co]hNRolFFY_o5UZKocIbS0_oT]ZH00oomh9coooooooooo`17ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool000Wooooo00Co0000oooooooooooooooo:ol0
00000`0000006ATI01TI6@0401TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`01?l00000IVIV
06IVIP1VIVH2o`000080Ogmo2Ol0000207moO`;o00000`1VIVH01Ol00000C4a<04a<C01<C4`00000
00<0<c<c00<0000001TI6@0I6AT0100I6AT00`00003o0000o`000019o`0000Cooooo00?o0000oooo
ooooool09?ooool2o`0002oooooo3_nY_NP2og5KZ@;oUW6W0onZOZ@3olFFYP03on6i[ooT]ZKoi;JV
04_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`002Oooool01?l0003o
ooooooooooooool/o`0000030000000I6AT06ATI00@06ATI00@0000003<c<`0c<c<0<c<c0P000002
04a<C0?o00000P1VIVH2o`0000T0Ogmo0_l0000406IVIP05o`00001<C4`0C4a<04a<C0000000100c
<c<00`0000006ATI01TI6@0301TI6@0300000?l0003o000004[o00001?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02gooooo3OnY_NP00oliA[GoLE^YoiIaY`02oiIaY`;oZWjT0oo5
UZH2on6i[`03oogPW?oooooooooo04Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`002Oooool01?l0003oooooooooooooool]o`0000030000000I6AT06ATI00@06ATI00<0
000003<c<`0c<c<00P0c<c<2000000<0C4a<0_l0000206IVIPWo00000`1VIVH3o`0000<0C4a<00Co
000003<c<`0c<c<0<c<c0P00000501TI6@0300000?l0003o000004_o00001?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02gooooo2?nY_NP4ooooo`03o`00NOliA[GoUW6W00;oUW6W
00CoZWjTokF=[?neSJcoaIJV0ooQ^Jl00oo_l9Soooooooooo`1:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool000Wooooo00Co0000oooooooooooooooo;Ol000000`000000
6ATI01TI6@0501TI6@030000000c<c<0<c<c00<0<c<c0P00000304a<C0;o00002`1VIVH00ol00000
C4a<04a<C00204a<C08000000`0c<c<00`0000006ATI01TI6@0501TI6@0300000?l0003o000004_o
00001?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02gooooo0onY_NP9ooooo`04
ocU6]OnBN[GoTWZeoi9j]@?o]Hf/00CoaIJVon6i[ooQ^JoohKV_C_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Wooooo0009ooooo`04o`000?ooooooooooooooobko000000<00000
01TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<2ol00004
04a<C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AT00`00003o0000o`00001<
o`0000Cooooo00?o0000ooooooooool0:Oooool2o`0002gooooo00?o0000ooooooooool02_ooool0
0oliA[GoTWZeoi9j]@03okF=[004olFFY_oQ^JoohKV_ono`V4oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`09ooooo`002Oooool01?l0003oooooooooooooool_o`0000030000000I
6AT06ATI00D06ATI0P00000503<c<`8000003`1<C4`2000000D0<c<c00<0000001TI6@0I6AT0100I
6AU@o`0000Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00_ooooo0onBN[D2okF=[0;ohKV_0_o_l9Q?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool000Wooooo00Co0000oooooooooooooooo<?l00002000000L06ATI0P00
000503<c<`D000001P1<C4`4000000D0<c<c0P00000601TI6@800000Col00004ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`;oTWZe00Co
]Hf/om:oaooB_lOohKV_D_ooool01Ol0003ooooooooooooooooo000000_ooooo0009ooooo`04o`00
0?oooooooooooooooc;o000000<0000001TI6@0I6AT01P0I6AT3000000L0<c<c1P00000703<c<`80
00001`0I6AT00`00003o0000o`00001?o`0000Cooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00CoHJGfom:oaooB_lOod[o7E?ooool01?l0
003oooooooooool0000;ooooo`002Oooool01?l0003ooooooooooooooolco`0000030000000I6AT0
6ATI00P06ATI0`00000>03<c<`<00000200I6AUCo`0000Cooooo00?o0000ooooooooool0;_ooool2
o`0002Sooooo00?o0000ooooooooool03oooool00ooB_lOoooooooooo`1Dooooo`03o`000?oooooo
000000_ooooo0009ooooo`04o`000?ooooooooooooooocCo000000<00000o`00000I6AT02P0I6AT0
1000003o000000000000000603<c<`80000000?o00000000000I6AT0200I6AT2000005?o00001?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooo`00000;ooooo`002Oooool01?l0003ooooooooooooooolfo`0000030000000I
6AT06ATI00`06ATI1P00000<01TI6@0300000?l0003o000005?o00001?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooo`00
000:ooooo`002Oooool01?l0003ooooooooooooooolgo`0000<000006`0I6AT2000005Ko00001?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?oo
ool2o`0000[ooooo0009ooooo`04o`000?oooooooooooooooc[o00000P00000H01TI6@0300000?l0
003o000005Ko00001?ooool00ol0003oooooooooo`0cooooo`;o00008oooool00ol0003ooooooooo
o`1Wooooo`?o00002_ooool000Wooooo00Co0000oooooooooooooooo??l00002000001@06ATI0P00
001Io`0000Cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo06?ooooo1?l0000=ooooo`002Oooool01?l0003ooooooooooooooolno`0000L000002@0I
6AT4000005_o00001?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0H?ooool3o`00017ooooo0009ooooo`04o`000?ooooooooooooooodGo00002@00
001Oo`0000Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo05cooooo1?l0000Dooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o
0000ooooooooool0>?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001Sooooo0009
ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0001cooooo0009ooooo`04o`000?oooooo
ooooooooojgo00001?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0DOooool3o`00023ooooo0009ooooo`04o`000?ooooooooooooooojgo00001?oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0COoo
ool4o`0002?ooooo0009ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003ooooooooo
o`0mooooo`;o00006Oooool00ol0003oooooooooo`19ooooo`Co00009oooool000Wooooo00Co0000
oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`15ooooo`Co0000:oooool000Wooooo00Co0000oooooooooooooooo[Ol0
0004ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`13ooooo`?o0000;oooool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0oooooo`Co0000<_oo
ool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo04;ooooo0_l0
000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`002Oooool01?l0003ooooooooooooo
oon]o`0000Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo03Oooooo1?l0000jooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0
000nooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0ol00012ooooo`002Oooool0
1?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02cooooo1?l00015ooooo`002Oooool01?l0003ooooooooooooo
oon]o`0000Cooooo00?o0000ooooooooool0B?ooool2o`0000gooooo00?o0000ooooooooool0:?oo
ool4o`0004Wooooo0009ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool4o`0004gooooo0009
ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo0009ooooo`04o`000?oooooo
ooooooooojgo00001?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07Oooool4o`0005Cooooo0009ooooo`04o`000?ooooooooooooooojgo00001?oo
ool00ol0003oooooooooo`1=ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?oo
ool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?ooool000Wooooo00Co0000
oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Booooo`?o0000H?ooool000Wooooo00Co0000oooooooooooooooo[Ol0
0004ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0>ooooo`Co0000Hoooool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oo
oooooooo05;ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0001Wooooo`002Oooool0
1?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0E?ooool01?l0003ooooooooo
ool00008ooooo`Co0000Joooool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`00
0?oooooooooo05Gooooo00?o0000ooooool000001Oooool3o`0006oooooo0009ooooo`04o`000?oo
ooooooooooooojgo00001?ooool00ol0003oooooooooo`1Fooooo`;o000000?oooooo`000?l00000
0_l0001booooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0
Eoooool2o`0007Kooooo0009ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003ooooo
ooooo`3?ooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0
coooool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo0<oooooo
0009ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003oooooooooo`3?ooooo`002Ooo
ool01?l0003ooooooooooooooon]o`0000Cooooo00?o0000ooooooooool0coooool000Wooooo00Co
0000oooooooooooooooo[Ol00004ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?oo
ooooooooooooojgo00001?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooooooo
oooooon]o`0000Cooooo00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo
[Ol00004ooooo`03o`000?oooooooooo0<oooooo0009ooooo`04o`000?ooooooooooooooojgo0000
1?ooool00ol0003oooooooooo`3?ooooo`002Oooool01?l0003ooooooooooooooon]o`0000Cooooo
00?o0000ooooooooool0coooool000Wooooo00Co0000oooooooooooooooo[Ol00004ooooo`03o`00
0?oooooooooo0<oooooo0009ooooo`04o`000?ooooooooooooooojgo00001?ooool00ol0003ooooo
ooooo`3?ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo0<oooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0coooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`3?ooooo`002Ooooonfo`000=7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo0009oooookKo00004Ooooonfo`0000[ooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo03[ooooo1@000?mcooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0eooooo`D0003o1Ooo
ool80000of_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo033ooooo0P000?l00ol00?l0003o0000o`0B
ooooo`80003o0ooooolI0?nf`Dgooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1<
oooooaT0okK1COooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0]oooo
o`<0003o6Oooool20000oad0okK1B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04Wooooo7`3o]/5:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02_o
oooo0P000?lIooooo`D0okK10`000?lM0?nf`DOooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`16ooooobD0okK1Aoooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Zooooo`030000oooooooooooo01Kooooo2`3o]/420000oah0okK1A?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04?ooooo:`3o]/54ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02Sooooo0P000?lFoooooa00okK10P000?lO0?nf`D7ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`10oooooc40okK1@Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Vooooo`80003o5OoooolE0?nf`@03o`00o`000?l0
okK101l0okK1?_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo=`3o]/4n
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Gooooo00<0003ooooo
ooooool04_oooolJ0?nf`@030000o`3o]/40okK101h0okK1?Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03[ooooo>`3o]/4mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo02?ooooo0P000?lDoooooa`0okK100<0003o0?nf`@3o]/407P3o]/4looooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0>Ooooolm0?nf`Ccooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool08_ooool00`000?ooooooooooo`0Boooooal0okK1
00<0003o0?nf`@3o]/40803o]/4iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
=ooooom20?nf`@D00000=?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Qooooo`030000oooooooooooo017ooooo8P3o]/400ol00?l0003o0?nf`@0Q0?nf`COooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0eooooocd0okK11`0000020?nf`@?ooooo1`00
000]ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027ooooo00<0003o
ooooooooool04?oooolT0?nf`@030000o`3o]/40okK10240okK1=_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Cooooo>`3o]/43000000X0okK12Oooool4000002Wooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool08?ooool00`000?ooooooooooo`0@oooo
obH0okK100<0003o0?nf`@3o]/408@3o]/4eooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0<ooooolk0?nf`@030000003o]/40okK100`0okK13?ooool3000002Kooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool07oooool00`000?ooooooooooo`0@ooooobP0
okK100<0003o0?nf`@3o]/408@3o]/4dooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0<_ooooli0?nf`@80000000?o00000?nf`@3o]/403P3o]/4>ooooo`<000008oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo`030000oooooooooooo00oooooo
:`3o]/400`000?l0okK10?nf`@0R0?nf`C;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0`ooooocT0okK10P00000E0?nf`@oooooo00<00000ooooooooool08?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`030000oooooooooooo00oooooo;@3o
]/400`000?l0okK10?nf`@0R0?nf`C7ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0_ooooocT0okK100?o00000?nf`@3o]/405P3o]/4?ooooo`03o`0000000000000001oooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07Oooool00`000?ooooooooooo`0>
ooooobh0okK100<0003o0?nf`@3o]/408`3o]/4`ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0;_ooooli0?nf`@030000003o]/40okK101P0okK14Oooool00`00003oooooooooo`0L
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01cooooo00<0003ooooo
ooooool03_ooool`0?nf`@030000o`3o]/40okK102<0okK1;oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02gooooo>03o]/42000001`0okK14Oooool00`00003oooooooooo`0Koooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo00<0003ooooooooo
ool03_oooolb0?nf`@030000o`3o]/40okK102<0okK1;_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02cooooo>03o]/400`000000okK10?nf`@0?0?nf`@l000004?ooool00`00003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo
00<0003oooooooooool03Ooooolc0?nf`@030000o`3o]/40okK102@0okK1;Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02_ooooo>03o]/400`000000okK10?nf`@0=0?nf`@<00000
3`3o]/401000003o000000000000000=ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool06_ooool00`000?ooooooooooo`0=ooooocD0okK1
00<0003o0?nf`@3o]/408`3o]/4]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:_oooolh0?nf`@03o`00003o]/40okK100`0okK10P00000B0?nf`@Cooooo0P00000<ooooo`030000
0?oooooooooo01Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_oo
ool00`000?ooooooooooo`0=ooooocD0okK100<0003o0?nf`@3o]/40903o]/4/ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0:_oooolh0?nf`@030000003o]/40okK100/0okK100<0
00000?nf`@3o]/404`3o]/45ooooo`8000002oooool00`00003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo00<0003oooooooooool03Ooooolg
0?nf`@030000o`3o]/40okK102@0okK1:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Wooooo>03o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK101D0okK11_ooool0
0ol0003oooooooooo`09ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool06Oooool00`000?ooooooooooo`0<ooooocT0okK100?o003o0?nf
`@3o]/40903o]/4Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?oooolh0?nf
`@030000003o]/40okK100/0okK100<000000?nf`@3o]/40203o]/4<000000<0okK11_ooool20000
00[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Hooooo`030000oooooooooooo00cooooo>P3o]/400`000?l0okK10?nf`@0B0?nf`@_o
003o203o]/4Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09ooooolh0?nf`@03
o`00003o]/40okK100X0okK100<00000o`00003o]/401`3o]/43000000`0okK110000007ooooo`80
00002Oooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01Sooooo00<0003oooooooooool02ooooolk0?nf`@030000o`3o]/40okK10100okK1
0_l00?l;0?nf`@;o003o1P3o]/4Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
9_ooooli0?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/401`3o]/400`000000okK1
0?nf`@0A0?nf`@03o`000?oooooooooo00Kooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Oooooo00<0
003oooooooooool03?ooooll0?nf`@030000o`3o]/40okK100h0okK100?o003o0?nf`@3o]/403@3o
]/42o`00o`D0okK1:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo>03o
]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100D0okK100<00000o`000?l000005@3o
]/42000000Oooooo00?o0000ooooooooool01oooool00`00003oooooooooo`0Booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Oooooo00<0003oooooooooool02ooooolm
0?nf`@030000o`3o]/40okK100d0okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@03
0?nf`BOooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0UooooocT0okK100<00000
0?nf`@3o]/40203o]/400ol00000okK10?nf`@050?nf`@030000003o]/40okK100T0okK11000000:
0?nf`@03ooooo`00003ooooo00Kooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0B
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Oooooo00<0003ooooo
ooooool02_ooooln0?nf`@030000o`3o]/40okK100`0okK100?o003o0?nf`@3o]/404P3o]/400ol0
0?l0okK10?nf`@020?nf`BOooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Toooo
ocT0okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00H0okK1100000040?nf`@@000001P3o]/42ooooo`0300000?oooooooooo00Cooooo00<00000oooo
ooooool01oooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01Kooooo00<0003oooooooooool02ooooolo0?nf`@030000o`3o]/40okK100X0
okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@020?nf`BKooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0TooooocT0okK100<000000?nf`@3o]/40203o]/400`000000
okK10?nf`@050?nf`@030000003o]/40okK100@0okK100?o00000000003o]/402`3o]/43000000@0
okK10_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool04Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Fooooo`030000
oooooooooooo00[ooooo@03o]/400`000?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK101D0okK1
00?o003o0?nf`@3o]/400P3o]/4Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
8oooooli0?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/40103o]/400`000000okK1
0?nf`@040?nf`@03o`00003o]/40okK100l0okK100Co0000000000000000okK10oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Fooooo`030000oooooooooooo00[ooooo
@03o]/400`000?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/40
0P3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooooli0?nf`@030000
003o]/40okK100T0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK101<0okK100<000000?nf`Oooool00_ooool00`00003oooooooooo`04ooooo`030000
0?oooooooooo00Gooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Eooooo`030000oooooooooooo00[ooooo@P3o]/400`000?l0okK10?nf
`@070?nf`@03o`00o`3o]/40okK101P0okK100?o003o0?nf`@3o]/400P3o]/4Tooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool08_ooooli0?nf`@030000003o]/40okK100T0okK100<0
00000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100H0okK12?l0
00070?nf`@030000003o]/7ooooo00;ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`06ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool05Oooool00`000?ooooooooooo`09oooood<0okK100<0003o0?nf`@3o]/401`3o]/40
0ol00?l0okK10?nf`@0C0?nf`@Wo003o00<0okK1ooooooooool08_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo027ooooo>P3o]/400ol00000okK10?nf`@080?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@Co0000203o]/42
o`0000H0okK100<00000ooooooooool00_ooool00`00003oooooooooo`03ooooo`0300000?oooooo
oooo00Kooooo00<00000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Eooooo`030000oooooooooooo00Wooooo@`3o]/400`000?l0okK10?nf`@060?nf
`@03o`00o`3o]/40okK10100okK11?l00?l60?nf`@03o`00o`3o]/40okK100Co003o8Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo>P3o]/400`000000okK10?nf`@080?nf
`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf
`@03o`00003o]/40okK100`0okK100?o00000?nf`@3o]/400`3o]/400`000000okK1ooooo`03oooo
o`0300000?oooooooooo00;ooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0>oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Gooooo00<0003ooooooooo
ool02?oooom40?nf`@030000o`3o]/40okK100H0okK100?o003o0?nf`@3o]/403`3o]/400ol00?l0
okK10?nf`@080?nf`@03o`00o`3o]/40okK10080okK10_ooool00ol00?ooooooooooo`0Nooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool08?oooolk0?nf`@030000003o]/40okK100P0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080
okK100?o00000?nf`@3o]/403P3o]/400ol00000okK10?nf`@030?nf`@0300000?oooooooooo00?o
oooo00<00000ooooooooool00_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00go
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05Oooool00`000?oooooo
ooooo`08oooood@0okK100<0003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@0>0?nf`@03o`00
o`3o]/40okK100T0okK100?o003o0?nf`@3o]/400`3o]/42ooooo`03o`00oooooooooooo01gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0PooooocX0okK100<000000?nf`@3o]/40
2@3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/400ol00000okK10?nf`@0?0?nf`@03o`00003o]/40okK100<0okK100<00000ooooooooool0
0_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
3Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Eooooo`030000oooo
oooooooo00Oooooo703o]/43o`0002H0okK100<0003o0?nf`@3o]/401@3o]/400ol00?l0okK10?nf
`@0;0?nf`@?o000000?o003o0?nf`@3o]/402P3o]/400ol00?l0okK10?nf`@040?nf`@;ooooo00?o
003oooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo>`3o
]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK10140okK100?o00000?nf`@3o]/400`3o
]/400ol0003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01Gooooo00<0003oooooooooool01_oooolL0?nf`@Go00009@3o]/400`000?l0okK10?nf`@05
0?nf`@03o`00o`3o]/40okK100X0okK11Ol0000<0?nf`@03o`00o`3o]/40okK100@0okK10oooool0
0ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooooll
0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@02
0?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/401@3o]/46o`0000H0okK100?o0000
0?nf`@3o]/400`3o]/400`00003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01Gooooo00<0003oooooooooool01_oooolL0?nf`@Go00009@3o]/400`00
0?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK100X0okK11Ol0000<0?nf`@03o`00o`3o]/40okK1
00D0okK10_ooool00ol00?ooooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07_ooooll0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/401@3o]/400ol0
0000okK10?nf`@040?nf`@;o00001@3o]/400ol00000okK10?nf`@020?nf`@030000003o]/7ooooo
00?ooooo00<00000ooooooooool00_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo
00cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05Oooool00`000?oo
ooooooooo`05oooooad0okK11Ol0000U0?nf`@030000o`3o]/40okK100D0okK100?o003o0?nf`@3o
]/402P3o]/45o`0000`0okK100?o003o0?nf`@3o]/401@3o]/43ooooo`03o`00oooooooooooo01[o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooocd0okK100<000000?nf`@3o
]/40203o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o
]/400P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100L0okK100?o00000?nf`@3o
]/400`3o]/400ol00000okK10?nf`@020?nf`@0300000?oooooooooo00;ooooo00<00000oooooooo
ool00_ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool05Oooool00`000?ooooooooooo`05oooooah0okK1
0ol0000F0?nf`@L0oooo2@3o]/400`000?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK100/0okK1
0ol0000=0?nf`@03o`00o`3o]/40okK100D0okK10oooool00ol00?ooooooooooo`0Jooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool07Ooooolg0?nf`@H0oooo00<000000?nf`@3o]/40
203o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
0P3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100L0okK100?o00000?nf`@3o]/40
103o]/401Ol00000okK10?nf`@3o]/40000000Cooooo00<00000ooooooooool00_ooool00`00003o
ooooooooo`05ooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool05Oooool00`000?ooooooooooo`05oooooc<0okK13`3oool50?nf`@030000
o`3o]/40okK100D0okK100?o003o0?nf`@3o]/402`3o]/400ol00?l0okK10?nf`@0=0?nf`@03o`00
o`3o]/40okK100H0okK10_ooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07Ooooolc0?nf`@X0oooo00<000000?ooo`3oool00P3oool60?nf`@030000
003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@03o`00
003o]/40okK100@0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@030?nf`@06o`00
003o]/40okK10?nf`@000000okK10oooool00`00003oooooooooo`02ooooo`0300000?oooooooooo
00Gooooo00<00000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Eooooo`030000oooooooooooo00Cooooo<P3o]/4C0?ooo`<0okK100<0003o0?nf`@3o
]/401@3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK100h0okK100?o003o0?nf`@3o
]/401P3o]/43ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Loooooc80okK1303oool00`000000oooo0?ooo`040?ooo`@0okK100<000000?nf`@3o
]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o
]/400`3o]/400ol00000okK10?nf`@090?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o
]/400P3o]/400`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000oooooooo
ool01Oooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01Gooooo00<0003oooooooooool01?ooool`0?nf`AL0oooo00<0okK10000o`3o]/40
1P3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK100h0okK100?o003o0?nf`@3o]/40
1P3o]/43ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Loooooc00okK13P3oool00`000000oooo0?ooo`060?ooo`80okK100<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/40
0`3o]/400ol00000okK10?nf`@0:0?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/40
0P3o]/400`00003oooooooooo`02ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool0
1Oooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo01Gooooo00<0003oooooooooool01?ooool_0?nf`AT0oooo00<0003o0?nf`@3o]/401P3o
]/400ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/40203o
]/42ooooo`03o`00oooooooooooo01Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Looooobl0okK13`3oool00`000000oooo0?ooo`080?ooo`030000003o]/40okK100<0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK100<0okK100?o
00000?nf`@3o]/402P3o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100<0
00000?nf`Oooool00_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo00Gooooo00<0
0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0F
ooooo`030000oooooooooooo00;ooooo;`3o]/4I0?ooo`030000o`3oool0oooo00L0okK100?o003o
0?nf`@3o]/40203o]/400ol00?l0okK10?nf`@0<0?nf`@?o00002P3o]/43ooooo`03o`00oooooooo
oooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooobl0okK1403oool0
0`000000oooo0?ooo`090?ooo`030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@020?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/40203o]/40
0ol00000okK10?nf`@030?nf`@03o`00003o]/40okK10080okK100<000000?nf`Oooool00_ooool0
0`00003oooooooooo`02ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Fooooo`030000oooooooooooo
00;ooooo;P3o]/4J0?ooo`040000o`3oool0oooo0?ooo`H0okK100?o003o0?nf`@3o]/40203o]/40
0ol00?l0okK10?nf`@0;0?nf`@Go00002@3o]/43ooooo`03o`00oooooooooooo01Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Kooooobh0okK14@3oool00`000000oooo0?ooo`09
0?ooo`03o`00003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@02
0?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@04
0?nf`@03o`00003o]/40okK10080okK100<000000?nf`Oooool00_ooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Fooooo`030000oooooooooooo00;ooooo;@3o]/4K0?oo
o`030000o`3oool0oooo0080oooo1P3o]/42o`00o`P0okK100?o003o0?nf`@3o]/402`3o]/45o`00
00T0okK10oooool00ol00?ooooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06oooool]0?nf`A80oooo00<000000?ooo`3oool02@3oool00`000000oooo0?nf`@030?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@050?nf
`@;o00001@3o]/42o`0000H0okK100?o00000?nf`@3o]/400P3o]/400`000000okK1ooooo`02oooo
o`0300000?oooooooooo00;ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Kooooo00<0003ooooooooo
ool00_ooool]0?nf`A/0oooo00<0003o0?ooo`3oool00P3oool80?nf`@03o`00o`3o]/40okK100D0
okK100?o003o0?nf`@3o]/402`3o]/45o`0000T0okK10oooool00ol00?ooooooooooo`0Hooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06ooooolO0?nf`@l000004@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@020?nf`@03o`00003o]/40okK100H0okK10_l000000`3o]/7o0000o`0000080?nf`@03
o`00003o]/40okK10080okK100<000000?nf`Oooool00_ooool00`00003oooooooooo`02ooooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool02oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Fooooo`030000oooooooooooo00;ooooo:`3o]/4M0?ooo`030000
o`3oool0oooo00<0oooo203o]/400ol00?l0okK10?nf`@040?nf`@03o`00o`3o]/40okK100/0okK1
00Co003oo`000?l0003o00002P3o]/43ooooo`03o`00oooooooooooo01Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Koooooa`0okK10`00000<0?nf`@<0oooo1P00000;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3o]/400`3o]/400`000000okK10?nf`@020?nf`@03
0000003o]/40okK100<0okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf`@080?nf`@05
o`00003o]/40okK10?nf`@0000000P3o]/42ooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool01Oooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01Kooooo00<0003oooooooooool00_oooolZ0?nf`Ad0oooo00<0003o0?ooo`3o
ool01@3oool80?nf`@03o`00o`3o]/40okK100@0okK100?o003o0?nf`@3o]/402@3o]/400ol00?l0
okK10?nf`@0=0?nf`@;ooooo00?o003oooooooooool06?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo6P3o]/42000000h0okK12P3oool00ol00000oooo0?ooo`080?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0103o]/400`000000okK10?nf`@020?nf`@03
0000003o]/40okK100<0okK100?o00000?nf`@3o]/403`3o]/42o`0000@0okK100H000000?nf`@3o
]/40okK1ooooo`000005ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Gooooo`030000oooooooooooo
02/0okK17@3oool00`000?l0oooo0?ooo`050?ooo`T0okK100?o003o0?nf`@3o]/400`3o]/400ol0
0?l0okK10?nf`@070?nf`@;o003o403o]/42ooooo`03o`00oooooooooooo01Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0JoooooaT0okK10P00000@0?nf`@/0oooo0`0000060?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103o]/400`000000okK10?nf`@030?nf
`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/403@3o]/400ol00000okK10?nf`@040?nf
`@060000003o]/40okK10?nf`Oooool000001Oooool00`00003oooooooooo`05ooooo`0300000?oo
oooooooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05oooool0
0`000?ooooooooooo`0Z0?nf`Ah0oooo00<0003o0?ooo`3oool01P3oool80?nf`@Co003o0P3o]/40
0ol00?l0okK10?nf`@040?nf`@?o003o4P3o]/42ooooo`03o`00oooooooooooo01Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0JoooooaL0okK10P00000A0?nf`@l0oooo10000000
0`3oool000000?ooo`0>0?ooo`030000003oool0oooo00@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@030?nf`@?o00002P3o]/42o`0000H0okK100?o00000?nf`@3o]/400P3o]/40
0`00003oooooooooo`03ooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool03?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Hooooo`030000ooooool0okK1
02T0okK17P3oool00`000?l0oooo0?ooo`060?ooo``0okK11Ol00?l20?nf`@;o003o5@3o]/400ooo
oooo003oooooo`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_oooolF0?nf
`@030000003o]/40okK10140okK14`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0okK1
00@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@050?nf`@Co00001@3o]/400ol0
0000okK10?nf`@050?nf`@030000003o]/40okK100<0okK100<00000ooooooooool00oooool00`00
003oooooooooo`05ooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06?ooool00`000?oooooo0?nf`@0X0?nf`Ah0oooo00<0003o0?ooo`3o
ool0203oool>0?nf`@04o`00o`3o]/7o003oo`00oaL0okK100?o003oooooooooool06_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo5P3o]/400`000000okK10?nf`@0@0?nf
`BH0oooo00<000000?ooo`3oool0103o]/400ol0000000000?nf`@040?nf`@03o`0000000000okK1
00P0okK11Ol000080?nf`@030000003o]/40okK100<0okK100<00000ooooooooool00oooool00`00
003oooooooooo`05ooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06?ooool00`000?oooooo0?nf`@0X0?nf`Ah0oooo00?o003o0?ooo`3o
ool0203oool>0?nf`@03o`00o`3o]/40okK101P0okK100?o003oooooooooool06_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo5@3o]/400`000000okK10?nf`@0A0?nf`BL0
oooo00<000000?ooo`3o]/401@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10180
okK100<000000?nf`@3o]/400`3o]/400`00003oooooooooo`03ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Iooooo`030000o`3o]/40okK102L0okK17@3oool00`000?l0oooo0?ooo`090?ooo`l0okK1
00?o003o0?nf`@3o]/405@3o]/42o`00oagooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Joooooa@0okK100<000000?nf`@3o]/40303o]/4<00000280oooo00<000000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100l0okK10P0000050?nf`@030000
003o]/7ooooo00Cooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo00<0003o0?nf`@3o]/409`3o
]/4M0?ooo`030000o`3oool0oooo00T0oooo403o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o
]/40okK101gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Joooooa<0okK100<0
00000?nf`@3o]/402P3o]/400`00003o0000000000060?nf`@H0oooo1000000O0?ooo`030000003o
]/40okK100D0okK100<000000?nf`@3o]/40103o]/400`00003o00000000000<0?nf`@03o`000000
0000okK100D0okK100<000000?nf`@3o]/401?ooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo00gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool0
0`000?l0okK10?nf`@0U0?nf`Ad0oooo00<0003o0?ooo`3oool02`3oool@0?nf`@;o003o4P3o]/40
1?l00?l0okK10?nf`@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_oo
oolC0?nf`@030000003o]/40okK100L0okK10`0000080?nf`@/0oooo0`00000M0?ooo`03o`00003o
]/40okK100D0okK100<000000?nf`@3o]/401P3o]/43000000<0okK11P0000070?nf`@040000003o
]/40okK10?nf`@?ooooo00<00000ooooooooool01oooool00`00003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo00<0okK10000o`3o]/409@3o
]/4L0?ooo`030000o`3oool0oooo00`0oooo4P3o]/400ol00?l0okK10?nf`@0>0?nf`@03o`00o`3o
]/40okK10080okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo4P3o
]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100T0okK13P3oool00`000000oooo0?oo
o`0J0?ooo`030?nf`@000000okK100H0okK100<000000?nf`@3o]/40203o]/43000000`0okK100<0
00000?nf`@3o]/400P3o]/42ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool03_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Iooooo`80okK100<0003o
0?nf`@3o]/40903o]/4L0?ooo`030000o`3oool0oooo00`0oooo4`3o]/400ol00?l0okK10?nf`@0<
0?nf`@03o`00o`3o]/40okK100<0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Wooooo4P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100H0okK12`000000
0ol00000oooo0?ooo`050?ooo`030000003oool0oooo01T0oooo0P3o]/400`000000okK10?nf`@05
0?nf`@8000005P3o]/400`000000okK10?nf`@030?nf`@;ooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01Wooooo0`3o]/400`000?l0okK10?nf`@0S0?nf`A/0oooo00?o003o0?ooo`3oool03@3ooolD0?nf
`@Co003o203o]/43o`00o`D0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Wooooo4@3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100<0okK100@00000o`00
000000000000103o]/480?ooo`<000001@3oool2000001T0oooo0`3o]/42000000L0okK11@00000=
0?nf`@<0000000?o00000?nf`@3o]/40103o]/400oooool00000ooooo`08ooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06Oooool30?nf
`@030000o`3o]/40okK102<0okK16P3oool00`000?l0oooo0?ooo`0>0?oooaP0okK12?l00?l80?nf
`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Ioooooa00okK100?o00000?nf
`@3o]/401`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100D0okK1200000040?oo
o`8000001@3oool2000001L0oooo1@3o]/400`000000okK10?nf`@090?nf`@<000001`3o]/430000
00X0okK100<00000ooooooooool01oooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo103o]/400`000?l0okK10?nf`@0R0?nf`AX0
oooo00<0003o0?ooo`3oool03P3ooolX0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Ioooooa00okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@020?nf`@80
0000103o]/44000000030?nf`@3oool0oooo00D0oooo0`0000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool60?nf`@030000003o]/40okK100/0okK11`00000;0?nf`@80
00002Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01[ooooo103o]/400`000?l0okK10?nf`@0Q0?nf`AT0oooo00<0003o0?ooo`3oool0
3`3ooolX0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`h0okK1
00<000000?nf`@3o]/401@3o]/400ol0000000000?nf`@030?nf`@040000003o]/40okK10?nf`@<0
00001@3o]/4:0?ooo`05o`00003oool0oooo0?ooool000000P0000040?ooo`03o`00003oool0oooo
01<0oooo1`3o]/400`00003o00000000000J0?nf`@8000000P3o]/49ooooo`0300000?oooooooooo
017ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool50?nf`@03
0000ool00?l0okK10200okK15`3oool20000oa80oooo:03o]/4Mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06_ooool>0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o
]/400P3o]/401@000000okK10?nf`@3o]/40000000@0okK12ol000040?ooo`800000103oool01@00
0000oooo0?ooo`3oool0000001D0oooo2P3o]/42000001H0okK10P0000040?nf`@Sooooo00<00000
ooooooooool04_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Joooo
o`H0okK100<0003o0?nf`@3o]/406`3o]/46o`00oa@0oooo00<0003o0?ooo`3oool04@3ooolY0?nf
`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`h0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/42
o`0000D0okK11P3oool3o`0000<0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0000001<0oooo3@3o]/42000001<0okK100<000000?nf`@3o]/40103o]/47ooooo`0300000?oo
oooooooo01?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool7
0?nf`@030000o`3o]/40okK101L0okK10ol00?l50?nf`@040?ooool00?oo003oo`00oa00oooo00<0
003o0?ooo`3oool04P3ooolY0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Jooooo`d0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@020?nf`@040000003o
]/40okK1000000<0okK100?o00000?nf`@3o]/400`3o]/48o`0000<0oooo0_l000020?ooo`800000
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo3`3o]/43000000h0okK1
0P0000070?nf`@Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Jooooo`P0okK100<0003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf
`@060?nf`@@0oooo00?o003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0B0?ooobT0okK17Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo3@3o]/400`000000okK10?nf
`@040?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/4000000`3o]/400ol00000okK1
0?nf`@04o`000080okK11P3oool3o`000080oooo00Go00000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00?o00000?ooo`3oool02@3oool5000000030?ooo`3o]/40okK10100
okK1300000000ol0000000000?nf`@080?nf`@Gooooo0P00000Fooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo01[ooooo2@3o]/400`000?l0okK10?nf`@0C0?nf`@03o`00
o`3o]/40okK100L0okK11@3oool00ol00?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01<0oooo
:@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool=0?nf`@030000
003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@0000020?nf`@04
o`00003o]/40okK1o`0000@0okK12?l000030?ooo`;o000000<0ooooo`00003oool00P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool2
000002P0okK10oooool2000001Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool06_ooool:0?nf`@80003o4P3o]/400ol00?l0okK10?nf`@090?nf`@D0oooo00?o003o0?oo
o`3oool0203oool20000oaD0oooo:P3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06_ooool<0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/401000
0000okK10?nf`@0000020?nf`@04o`00003o]/7o0000o`000080okK10ol000030?nf`@D0oooo0ol0
00020?ooo`04o`00003ooooo0000o`000080oooo00Co00000?ooo`3ooooo00000`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P3o]/43000002D0okK10_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo
303o]/420000o`l0okK100?o003o0?nf`@3o]/402P3o]/440?ooo`Go003o1@3oool20000oaL0oooo
:P3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool<0?nf`@030000
003o]/40okK100@0okK100D000000?nf`@3o]/40okK1000000020?nf`@060000003o]/40okK1o`00
003o]/7o00000P3o]/42o`000080okK12Ol000030?ooo`04o`00003oool0ooooo`000080oooo00Co
00000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3o
ool00`3oool50?nf`@8000008`3o]/42000001_ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool06_ooool>0?nf`@030000o`3o]/40okK100`0okK100?o003o0?nf`@3o]/40
2`3o]/401@3ooooo003oo`00o`3ooooo003o00<0oooo0ol00?l20000oaP0oooo:`3o]/4Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool<0?nf`@03o`00003o]/40okK100@0
okK100@000000?nf`@3o]/7o00000`3o]/4020000000okK10?nf`Ol00000okK1o`00003o]/7o0000
0`3o]/400ol00000okK10?nf`@030?nf`@@0oooo0_l000020?ooo`06o`00003oool0ooooo`00003o
oooo00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool80?nf`@8000007`3o]/42000001gooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool06oooool>0?nf`@80003o2`3o]/400ol00?l0okK10?nf`@0;0?nf
`@;o003o00D0okK10?ooo`3oool0ooooo`00o`040?ooo`030000ool00?oo003o01P0oooo:`3o]/4M
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool;0?nf`@030000003o]/40
okK100@0okK100@000000?nf`@3o]/4000000`3o]/401@000000okK1o`00003o]/7o00000080okK1
00Co00000?nf`@3o]/7o00000P3o]/48o`000080oooo0_l00000103ooooo00000?ooool000020?oo
o`04o`00003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo0080oooo2P3o]/43000001X0okK10P0000020?nf`Agooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool06oooool@0?nf`@030000o`3o]/40okK100P0okK100?o003o
0?nf`@3o]/402P3o]/401?l00?l0okK10?nf`@3o]/440?ooo`04o`00o`3oool0ooooo`00o`<0oooo
00?o003o0?ooo`3oool0503oool[0?nf`Akooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Kooooo`/0okK100<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/4000000080
okK100P000000?nf`@3o]/7o00000?nf`Ol00000okK1o`000080okK100Co00000?nf`@3o]/7o0000
1P3o]/420?ooo`09o`00003oool0oooo0?ooool00000ooooo`00003ooooo00000080oooo00?o0000
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000L0oooo00@000000?ooo`3oool0oooo
3P3o]/43000001D0okK10P0000030?nf`Akooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool06ooooolA0?nf`@@0003o1@3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o
]/40okK100<0okK10`3oool30000o`D0oooo00?o003o0?ooo`3oool04P3oool/0?nf`Akooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`/0okK100<000000?nf`@3o]/400`3o
]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`Ol00000okK1o`0000020?nf`@03
o`00003o]/7o00000080okK100?o00000?nf`@3o]/401P3o]/420?ooo`04o`00003oool0ooooo`00
0080oooo00Go00000?ooool00000ooooo`0000020?ooo`04o`00003oool0oooo000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?nf`@0400000?l000000000000000d0okK1
0`0000000ol00000okK10?nf`@030?nf`Akooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool06ooooolE0?nf`@80003o0`3o]/400ol00?l0okK10?nf`@070?nf`@?o000000?o
003o0?nf`@3o]/400P3o]/440000o`030?ooool00?l0oooo00D0oooo00?o003o0?ooo`3oool04@3o
ool]0?nf`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`/0okK100<0
00000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`Ol00000
okK1o`0000020?nf`@03o`00003o]/7o00000080okK100?o00000?nf`@3o]/401ol000020?ooo`03
o`00003ooooo00000080oooo00Go00000?ooool00000ooooo`0000020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?nf`@0F0?nf`@d000002@3o]/4N
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo5`3o]/440000
o`P0okK11Ol000040000o`<0okK10P3oool00ol00?l0oooo0?ooo`050?ooo`03o`00o`3oool0oooo
00l0oooo;P3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool;0?nf
`@030000003o]/40okK100<0okK100@000000?nf`@3o]/4000000P3o]/402P000000okK10?nf`Ol0
0000okK1o`00003o]/7o00000?nf`Ol000020?nf`@04o`00003o]/40okK1o`0000L0okK100So0000
0?ooo`3ooooo00000?ooool00000ooooo`000080oooo00Go00000?ooool00000oooo000000030?oo
o`040000003oool0oooo000000H0oooo00<000000?nf`@3o]/40;03o]/4Nooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo01cooooo603o]/400ol00?l0okK10000o`070000
o`Go0000203o]/400`3ooooo003o0?ooo`070?ooo`03o`00o`3oool0oooo00`0oooo<03o]/4Noooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool:0?nf`@030000003o]/40okK1
00<0okK100@000000?nf`@3o]/4000000P3o]/4030000000okK10?nf`Ol00000okK1o`00003o]/7o
00000?nf`Ol00000okK1o`000080okK100?o00000?nf`@3o]/401`3o]/402?l00000oooo0?ooool0
0000ooooo`00003ooooo00000P3oool01Ol00000ooooo`00003oool000000080oooo00Co00000?oo
o`3ooooo00001@3oool00`3o]/4000000?nf`@0]0?nf`Akooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool07?oooolH0?nf`@03o`00o`3o]/40okK100L0okK11Ol000090?nf
`@03o`00o`3oool0oooo00L0oooo00?o003o0?ooo`3oool02@3ooola0?nf`Aoooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Looooo`X0okK100<000000?nf`@3o]/400`3o]/401000
0000okK10?nf`@0000020?nf`@0<0000003o]/40okK1o`00003o]/7o00000?nf`Ol00000okK1o`00
003o]/7o00000P3o]/400ol00000okK10?nf`@070?nf`@08o`00003o]/40okK1o`00003ooooo0000
0?ooool000020?ooo`05o`00003ooooo00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo0`3o]/400`000000okK10?nf`@0[0?nf`Aoooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool07?oooolH0?nf`@03o`00o`3o]/40okK100P0okK10ol0000:0?nf
`@03o`00o`3o]/40okK100L0oooo00?o003o0?ooo`3oool01`3ooolc0?nf`Aoooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Looooo`X0okK100<000000?nf`@3o]/400`3o]/401000
0000okK10?nf`@0000020?nf`@0<0000003o]/40okK1o`00003o]/7o00000?nf`Ol00000okK1o`00
003o]/7o00000P3o]/400ol00000okK10?nf`@070?nf`@08o`00003o]/40okK1o`00003o]/7o0000
0?ooool000020?ooo`05o`00003ooooo00000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000D0okK100<000000?nf`@3o]/40:`3o]/4Oooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01gooooo603o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK1
00H0okK10ol000050?nf`@D0oooo00?o003o0?ooo`3oool01@3ooole0?nf`Aoooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Mooooo`T0okK100<000000?nf`@3o]/400`3o]/401@00
0000okK10?nf`@3o]/4000000080okK100T000000?nf`Ol00000okK1o`00003o]/7o00000?nf`Ol0
00000P3o]/400ol00000okK1o`00000:0?nf`@0<o`00003o]/40okK1o`00003o]/7o00000?ooool0
0000ooooo`00003ooooo00000P3oool00`000000oooo000000020?ooo`030?nf`@000000okK100@0
okK100<000000?nf`@3o]/40:`3o]/4Oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01gooooo603o]/400ol00?l0okK10?nf`@070?nf`@03o`00o`3o]/40okK100H0okK1
1Ol000080?nf`@80oooo00?o003o0?ooo`3oool0>03o]/4Pooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool07Oooool90?nf`@03o`00003o]/40okK100<0okK100D000000?nf`@3o]/40
okK1000000020?nf`@090000003o]/7o00000?nf`Ol00000okK1o`00003o]/7o00000080okK100?o
00000?nf`Ol000002P3o]/403?l00000okK10?nf`Ol00000okK1o`00003o]/7o00000?nf`Ol00000
ooooo`000080oooo00<000000?nf`@0000000`3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK102X0okK18?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0M
oooooaP0okK100?o003o0?nf`@3o]/401`3o]/400ol00?l0okK10?nf`@060?nf`@Go00002P3o]/40
0ol00?l0okK10?nf`@0h0?nf`B3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0M
ooooo`T0okK100<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/4000000080okK100T0
00000?nf`Ol00000okK1o`00003o]/7o00000?nf`Ol000000P3o]/401?l00000okK10?nf`Ol00008
0?nf`@0=o`00003o]/40okK10?nf`Ol00000okK1o`00003o]/7o00000?nf`Ol00000okK1o`000002
0?nf`@030000003o]/40000000<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0Z
0?nf`B3ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_oooolH0?nf
`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/401P3o]/45o`0000X0okK100?o003o0?nf
`@3o]/40>03o]/4Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool90?nf
`@030000003o]/40okK100<0okK100@000000?nf`@3o]/4000000`3o]/402@000000okK1o`00003o
]/7o00000?nf`Ol00000okK1o`0000020?nf`@03o`00003o]/40okK100?o00000`3o]/42o`0000<0
okK100Go00000?nf`Ol00000okK1o`0000020?nf`@05o`00003o]/7o00000?nf`@0000000P3o]/40
1@000000okK10?nf`@3o]/7o000000@0okK100<000000?nf`@3o]/40:`3o]/4Pooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01kooooo6@3o]/42o`00o`H0okK100?o003o
0?nf`@3o]/401P3o]/401?l00?oo0000o`000?l0000;0?nf`@03o`00o`3o]/40okK103L0okK18Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo2@3o]/400`000000okK10?nf
`@030?nf`@050000003o]/40okK100000?l000000P3o]/401@000000okK1o`00003o]/7o00000080
okK100Co00000?nf`Ol00000okK10_l000040?nf`@?o0000103o]/401_l00000okK10?nf`Ol00000
okK1o`000080okK100Go00000?nf`Ol00000okK1000000020?nf`@040000003o]/40okK1000000D0
okK100<000000?nf`@3o]/40:P3o]/4Qooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01oooooo6P3o]/400ol00?l0okK10?nf`@030?nf`@03o`00o`3o]/40okK100D0okK1
00?o003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@0h0?nf`B7ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Oooooo`P0okK100<000000?nf`@3o]/400`3o]/401@000000okK1
0?nf`@3o]/4000000080okK100Go00000?nf`Ol00000okK1o`0000020?nf`@04o`00003o]/40okK1
o`000080okK100?o00000?nf`@3o]/401`3o]/401ol00000okK10?nf`@3o]/7o00000?nf`Ol00000
0P3o]/401Ol00000okK1o`00003o]/4000000080okK100@000000?nf`@3o]/4000001@3o]/400`00
0000okK10?nf`@0Z0?nf`B7ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool08?oooolJ0?nf`@03o`00o`3o]/40okK100<0okK100?o003o0?nf`@3o]/400`3o]/400ol00?l0
okK10?nf`@0=0?nf`@03o`00o`3o]/40okK103L0okK18_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo023ooooo1`3o]/400`000000okK10?nf`@040?nf`@070000003o]/40okK10?nf
`@000000okK1000000020?nf`@03o`00003o]/7o00000080okK100Co00000?nf`@3o]/7o00000P3o
]/43o`0000D0okK100Oo00000?nf`@3o]/40okK1o`00003o]/7o00000080okK100Go00000?nf`Ol0
0000okK1000000030?nf`@040000003o]/40okK1000000D0okK100<000000?nf`@3o]/40:@3o]/4R
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo023ooooo6`3o]/400ol0
0?l0okK10?nf`@020?nf`@03o`00o`3o]/40okK10080okK100?o003o0?nf`@3o]/403@3o]/400ol0
0?l0okK10?nf`@0g0?nf`B?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Poooo
o`P0okK100<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/4000000080okK100H00000
0?nf`@3o]/7o00000?nf`Ol000020?nf`@04o`00003o]/40okK1o`0000@0okK11Ol000020?nf`@;o
00000P3o]/402?l00000okK10?nf`Ol00000okK1o`00003o]/7o00000P3o]/401@000000okK10?nf
`@3o]/40000000@0okK100<000000?nf`@3o]/40:@3o]/4Sooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo027ooooo6`3o]/43o`00o`040?nf`Ol00?l0okK10?nf`@?o003o
3`3o]/400ol00?l0okK10?nf`@0g0?nf`B?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Qooooo`L0okK100<000000?nf`@3o]/40103o]/401@000000okK10?nf`@3o]/4000000080
okK100<000000?nf`Ol000000P3o]/42o`0000030?nf`Ol0003o000000Go00001@3o]/42o`000080
okK10_l000001@3o]/7o0000o`00003o]/7o00000080okK100@000000?nf`@3o]/4000000`3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK102T0okK18oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Qoooooah0okK11?l00?lA0?nf`@03o`00o`3o]/40okK1
03L0okK19?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo1`3o]/400`00
0000okK10?nf`@040?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`000000okK1o`000003
0?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/45o`000080okK10_l000020?nf`@03o`00003o
]/40okK100;o00000P3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/40:03o]/4Tooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo027ooooo8@3o]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK103L0okK19?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo203o]/400`000000okK10?nf
`@040?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`000000okK1o`0000030?nf`@04o`00
003o]/40okK10?nf`@?o00001@3o]/42o`0000<0okK100Co00000?nf`@3o]/7o00000`3o]/401000
0000okK10?nf`@0000030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40:@3o]/4T
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02;ooooo8@3o]/400ol0
0?l0okK10?nf`@0<0?nf`@;o003o>P3o]/4Tooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool08_ooool80?nf`@03o`00003o]/40okK100<0okK100<00000o`00003o]/400P3o]/401_l0
0000okK10?nf`@3o]/7o00000?nf`@?o000000@0okK1o`000?l0003o00000`3o]/45o`0000@0okK1
00Co00000?nf`@3o]/7o00000`3o]/401?l00000okK10?nf`Ol000030?nf`@030000003o]/40okK1
00<0okK100?o00000?nf`@3o]/40:@3o]/4Tooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo02?ooooo8@3o]/43o`00o`T0okK10_l00?lk0?nf`BGooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Sooooo`L0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/401?l00000okK10?nf`@3o]/43
o`0000H0okK10ol000000`3o]/7o0000o`0000020?nf`@8000000P3o]/400`000000okK10?nf`@02
0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40:03o]/4Uooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02?ooooo903o]/42o`00o`<0okK11?l00?ll0?nf
`BKooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`P0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK10?nf`@8000000P3o]/43
o`0000<0okK11_l000030?nf`@05o`00003o]/40okK10?nf`@000000103o]/401@000000okK10?nf
`@3o]/40000000H0okK100<000000?nf`@3o]/409`3o]/4Vooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02Cooooo9@3o]/43o`00od00okK19_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Cooooo203o]/400`000000okK10?nf`@040?nf`@030000003o
]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@?o00001P3o
]/43o`0000<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o
]/40okK100<0okK100<000000?nf`@3o]/40:03o]/4Vooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02CoooooI`3o]/4Wooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09?ooool90?nf`@030000003o]/40okK100@0okK10P0000030?nf`@03o`0000000000
okK10080okK100@00000o`000000000000000`3o]/46o`0000@0okK10P0000040?nf`@04o`00003o
]/40okK10?nf`@8000001@3o]/400`000000okK10?nf`@0X0?nf`BOooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool09OoooomV0?nf`BOooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Uooooo`P0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@020?nf`@8000001@3o]/43000000H0okK1100000040?nf`@8000000`3o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK102P0okK19oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Vooooof@0okK1:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Kooooo203o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK100<0okK10P000006
0?nf`@H000001P3o]/42000000@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@0X
0?nf`BSooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09ooooomR0?nf
`BWooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Wooooo`P0okK100<000000?nf
`@3o]/401P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100h0okK100?o00000?nf
`@3o]/40103o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK102L0okK1:Oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Xooooof00okK1:_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo203o]/42000000L0okK100?o00000000003o
]/40103o]/400ol0000000000000000=000000D0okK10P0000060?nf`@800000:@3o]/4Zooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02SoooooG`3o]/4[ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0:?ooool:0?nf`@8000001`3o]/43000001@0okK1
0`0000070?nf`@030000003o]/40okK102P0okK1:oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Yoooooeh0okK1:oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Wooooo2`3o]/400`000000okK10?nf`@070?nf`@@000003@3o]/43000000T0okK100?o
00000?nf`@3o]/40:@3o]/4[ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo02[oooooG03o]/4/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool;
0?nf`@03o`0000000000okK100X0okK10`0000060?nf`@<0000000?o00000?nf`@3o]/40203o]/42
000002/0okK1;?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0[oooo
oeX0okK1;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo303o]/400`00
0000okK10?nf`@0;0?nf`@H000003@3o]/400`000000okK10?nf`@0Z0?nf`Bgooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0;?oooomH0?nf`Bkooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0/ooooo``0okK10`00000K0?nf`@800000;03o]/4^ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02goooooE@3o]/4`ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0;Oooool>0?nf`@030000003o]/40okK101L0okK1
00<000000?nf`@3o]/40:P3o]/4`ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo02koooooD`3o]/4aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;_oo
ool>0?nf`@03o`0000000000000000<00000403o]/43000002`0okK1<Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0`oooooe00okK1<_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo033ooooo4P3o]/43000000X0okK10`00000^0?nf`C;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0<Ooooom>0?nf`C?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0aoooooa@0okK12P00000`0?nf`C?ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0<_oooom<0?nf`CCooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0boooood`0okK1=?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0cooooodX0okK1=Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?oooooBP3o]/4eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo03GoooooAP3o]/4gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Ooo
oom60?nf`COooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=_oooom4
0?nf`CSooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0foooood@0okK1>?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0hoooood00okK1>_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03Sooooo@03o]/4jooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo03[ooooo?03o]/4looooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0>_ooooll0?nf`Ccooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0>ooooolj0?nf`Cgooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0kooooocX0okK1?Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0nooooocD0okK1?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo=@3o
]/4oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo047ooooo;`3o]/52
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool_0?nf`D;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A?oooolY0?nf`DGooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`14ooooobT0okK1AOooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`17ooooob<0okK1B?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04Oooooo8`3o]/58ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo04[ooooo7@3o]/5;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
B_oooolM0?nf`D_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0COoo
oolG0?nf`Dkooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=oooooaL0okK1C_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Fooooo`@0okK1F?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Kooooo103o]/5Hooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo0009oooookKo00004Ooooonfo`0000[ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.42308 .13399 m
.44231 .13019 L
.46154 .12772 L
.48077 .12671 L
.5 .12722 L
.51923 .12918 L
.53846 .13241 L
.54907 .13462 L
.55769 .13683 L
.57692 .14241 L
.59615 .14879 L
.61049 .15385 L
.61538 .15584 L
.63462 .16429 L
.65342 .17308 L
.65385 .1733 L
.67308 .18423 L
.68669 .19231 L
.69231 .1961 L
.71154 .20974 L
.71401 .21154 L
.73077 .22517 L
.73742 .23077 L
.75 .24214 L
.75837 .25 L
.76923 .26064 L
.77762 .26923 L
.78846 .28066 L
.79546 .28846 L
.80769 .30254 L
.8118 .30769 L
.82639 .32692 L
.82692 .32767 L
.83854 .34615 L
.84615 .35967 L
.84879 .36538 L
.85688 .38462 L
.86348 .40385 L
.86538 .41045 L
.86795 .42308 L
.87089 .44231 L
.87256 .46154 L
.87298 .48077 L
.87223 .5 L
.87049 .51923 L
.86801 .53846 L
.86538 .55597 L
.86501 .55769 L
.86042 .57692 L
.85509 .59615 L
.84942 .61538 L
.84615 .62676 L
.84312 .63462 L
.83517 .65385 L
.82717 .67308 L
.82692 .67369 L
.81725 .69231 L
.80769 .71046 L
.80705 .71154 L
.7951 .73077 L
.78846 .74124 L
.78229 .75 L
.76923 .7675 L
.76782 .76923 L
.75088 .78846 L
.75 .78937 L
.73077 .80725 L
.73024 .80769 L
.71154 .82155 L
.70326 .82692 L
.69231 .833 L
.67308 .84228 L
.66375 .84615 L
.65385 .84951 L
.63462 .85518 L
.61538 .85975 L
.59615 .86325 L
.57998 .86538 L
.57692 .86562 L
.55769 .86674 L
.53846 .86695 L
.51923 .86624 L
.50582 .86538 L
.5 .86445 L
.48077 .86129 L
.46154 .85704 L
.44231 .85187 L
.42308 .84616 L
.42307 .84615 L
.40385 .83879 L
.38462 .83096 L
.37469 .82692 L
.36538 .82261 L
.34615 .81346 L
.33413 .80769 L
.32692 .80382 L
.30769 .79288 L
.30026 .78846 L
.28846 .78045 L
.27314 .76923 L
.26923 .76603 L
.25107 .75 L
.25 .74896 L
.23258 .73077 L
.23077 .72873 L
.21673 .71154 L
.21154 .70483 L
.20293 .69231 L
.19231 .6768 L
.19027 .67308 L
.17906 .65385 L
.17308 .6435 L
.16916 .63462 L
.15973 .61538 L
.15385 .60311 L
.15156 .59615 L
.14441 .57692 L
.13743 .55769 L
.13462 .54904 L
.1324 .53846 L
.12843 .51923 L
.12525 .5 L
.12331 .48077 L
.12282 .46154 L
.12388 .44231 L
.12658 .42308 L
.13096 .40385 L
.13462 .39157 L
.13743 .38462 L
.14682 .36538 L
.15385 .35336 L
.1588 .34615 L
.17308 .32741 L
.17348 .32692 L
.18978 .30769 L
.19231 .30468 L
.20619 .28846 L
.21154 .28192 L
.22237 .26923 L
.23077 .2592 L
.23897 .25 L
.25 .23793 L
.25698 .23077 L
.26923 .21892 L
.27733 .21154 L
.28846 .20226 L
.30101 .19231 L
.30769 .18762 L
.32692 .17469 L
.32948 .17308 L
.34615 .16387 L
.36538 .15406 L
.36584 .15385 L
.38462 .14627 L
.40385 .13943 L
.42031 .13462 L
F
0 g
.42308 .13399 m
.44231 .13019 L
.46154 .12772 L
.48077 .12671 L
.5 .12722 L
.51923 .12918 L
.53846 .13241 L
.54907 .13462 L
.55769 .13683 L
.57692 .14241 L
.59615 .14879 L
.61049 .15385 L
.61538 .15584 L
.63462 .16429 L
.65342 .17308 L
.65385 .1733 L
.67308 .18423 L
.68669 .19231 L
.69231 .1961 L
.71154 .20974 L
.71401 .21154 L
.73077 .22517 L
.73742 .23077 L
.75 .24214 L
.75837 .25 L
.76923 .26064 L
.77762 .26923 L
.78846 .28066 L
.79546 .28846 L
.80769 .30254 L
.8118 .30769 L
.82639 .32692 L
.82692 .32767 L
.83854 .34615 L
.84615 .35967 L
.84879 .36538 L
.85688 .38462 L
.86348 .40385 L
.86538 .41045 L
.86795 .42308 L
.87089 .44231 L
.87256 .46154 L
.87298 .48077 L
.87223 .5 L
.87049 .51923 L
.86801 .53846 L
.86538 .55597 L
.86501 .55769 L
.86042 .57692 L
.85509 .59615 L
Mistroke
.84942 .61538 L
.84615 .62676 L
.84312 .63462 L
.83517 .65385 L
.82717 .67308 L
.82692 .67369 L
.81725 .69231 L
.80769 .71046 L
.80705 .71154 L
.7951 .73077 L
.78846 .74124 L
.78229 .75 L
.76923 .7675 L
.76782 .76923 L
.75088 .78846 L
.75 .78937 L
.73077 .80725 L
.73024 .80769 L
.71154 .82155 L
.70326 .82692 L
.69231 .833 L
.67308 .84228 L
.66375 .84615 L
.65385 .84951 L
.63462 .85518 L
.61538 .85975 L
.59615 .86325 L
.57998 .86538 L
.57692 .86562 L
.55769 .86674 L
.53846 .86695 L
.51923 .86624 L
.50582 .86538 L
.5 .86445 L
.48077 .86129 L
.46154 .85704 L
.44231 .85187 L
.42308 .84616 L
.42307 .84615 L
.40385 .83879 L
.38462 .83096 L
.37469 .82692 L
.36538 .82261 L
.34615 .81346 L
.33413 .80769 L
.32692 .80382 L
.30769 .79288 L
.30026 .78846 L
.28846 .78045 L
.27314 .76923 L
Mistroke
.26923 .76603 L
.25107 .75 L
.25 .74896 L
.23258 .73077 L
.23077 .72873 L
.21673 .71154 L
.21154 .70483 L
.20293 .69231 L
.19231 .6768 L
.19027 .67308 L
.17906 .65385 L
.17308 .6435 L
.16916 .63462 L
.15973 .61538 L
.15385 .60311 L
.15156 .59615 L
.14441 .57692 L
.13743 .55769 L
.13462 .54904 L
.1324 .53846 L
.12843 .51923 L
.12525 .5 L
.12331 .48077 L
.12282 .46154 L
.12388 .44231 L
.12658 .42308 L
.13096 .40385 L
.13462 .39157 L
.13743 .38462 L
.14682 .36538 L
.15385 .35336 L
.1588 .34615 L
.17308 .32741 L
.17348 .32692 L
.18978 .30769 L
.19231 .30468 L
.20619 .28846 L
.21154 .28192 L
.22237 .26923 L
.23077 .2592 L
.23897 .25 L
.25 .23793 L
.25698 .23077 L
.26923 .21892 L
.27733 .21154 L
.28846 .20226 L
.30101 .19231 L
.30769 .18762 L
.32692 .17469 L
.32948 .17308 L
Mistroke
.34615 .16387 L
.36538 .15406 L
.36584 .15385 L
.38462 .14627 L
.40385 .13943 L
.42031 .13462 L
.42308 .13399 L
Mfstroke
.2 g
.42308 .17114 m
.44231 .16865 L
.46154 .16761 L
.48077 .16787 L
.5 .16916 L
.51923 .17115 L
.53457 .17308 L
.53846 .17362 L
.55769 .17663 L
.57692 .18035 L
.59615 .18503 L
.61538 .19083 L
.61982 .19231 L
.63462 .19818 L
.65385 .20713 L
.6624 .21154 L
.67308 .21783 L
.69231 .23044 L
.69278 .23077 L
.71154 .24534 L
.71711 .25 L
.73077 .26235 L
.73792 .26923 L
.75 .2815 L
.75648 .28846 L
.76923 .30272 L
.77344 .30769 L
.78846 .3262 L
.78901 .32692 L
.80283 .34615 L
.80769 .35352 L
.81471 .36538 L
.82463 .38462 L
.82692 .38969 L
.83229 .40385 L
.83811 .42308 L
.84227 .44231 L
.84484 .46154 L
.846 .48077 L
.84588 .5 L
.84461 .51923 L
.8423 .53846 L
.839 .55769 L
.83481 .57692 L
.82985 .59615 L
.82692 .60659 L
.82386 .61538 L
.8164 .63462 L
.80815 .65385 L
.80769 .65487 L
.79811 .67308 L
.78846 .68992 L
.78695 .69231 L
.77398 .71154 L
.76923 .71813 L
.75936 .73077 L
.75 .74191 L
.74267 .75 L
.73077 .76209 L
.72311 .76923 L
.71154 .77904 L
.69913 .78846 L
.69231 .7931 L
.67308 .80466 L
.66736 .80769 L
.65385 .81401 L
.63462 .82166 L
.61854 .82692 L
.61538 .82779 L
.59615 .83234 L
.57692 .83566 L
.55769 .83773 L
.53846 .83849 L
.51923 .83792 L
.5 .83602 L
.48077 .83281 L
.46154 .82837 L
.4561 .82692 L
.44231 .82238 L
.42308 .81498 L
.40617 .80769 L
.40385 .80658 L
.38462 .79696 L
.36819 .78846 L
.36538 .78695 L
.34615 .77661 L
.3323 .76923 L
.32692 .76626 L
.30769 .75522 L
.29915 .75 L
.28846 .74284 L
.27223 .73077 L
.26923 .72829 L
.25078 .71154 L
.25 .71076 L
.23311 .69231 L
.23077 .6895 L
.21821 .67308 L
.21154 .66366 L
.20536 .65385 L
.1938 .63462 L
.19231 .63196 L
.18421 .61538 L
.1752 .59615 L
.17308 .59126 L
.16801 .57692 L
.16154 .55769 L
.15605 .53846 L
.15385 .52944 L
.15217 .51923 L
.14966 .5 L
.14846 .48077 L
.14882 .46154 L
.15094 .44231 L
.15385 .4274 L
.15513 .42308 L
.16202 .40385 L
.17156 .38462 L
.17308 .38199 L
.18414 .36538 L
.19231 .35435 L
.19871 .34615 L
.21154 .32971 L
.21372 .32692 L
.22845 .30769 L
.23077 .30458 L
.24333 .28846 L
.25 .28004 L
.25917 .26923 L
.26923 .25802 L
.27701 .25 L
.28846 .23909 L
.29795 .23077 L
.30769 .22302 L
.32353 .21154 L
.32692 .20936 L
.34615 .198 L
.35708 .19231 L
.36538 .18862 L
.38462 .1811 L
.40385 .17523 L
.41213 .17308 L
F
0 g
.42308 .17114 m
.44231 .16865 L
.46154 .16761 L
.48077 .16787 L
.5 .16916 L
.51923 .17115 L
.53457 .17308 L
.53846 .17362 L
.55769 .17663 L
.57692 .18035 L
.59615 .18503 L
.61538 .19083 L
.61982 .19231 L
.63462 .19818 L
.65385 .20713 L
.6624 .21154 L
.67308 .21783 L
.69231 .23044 L
.69278 .23077 L
.71154 .24534 L
.71711 .25 L
.73077 .26235 L
.73792 .26923 L
.75 .2815 L
.75648 .28846 L
.76923 .30272 L
.77344 .30769 L
.78846 .3262 L
.78901 .32692 L
.80283 .34615 L
.80769 .35352 L
.81471 .36538 L
.82463 .38462 L
.82692 .38969 L
.83229 .40385 L
.83811 .42308 L
.84227 .44231 L
.84484 .46154 L
.846 .48077 L
.84588 .5 L
.84461 .51923 L
.8423 .53846 L
.839 .55769 L
.83481 .57692 L
.82985 .59615 L
.82692 .60659 L
.82386 .61538 L
.8164 .63462 L
.80815 .65385 L
.80769 .65487 L
Mistroke
.79811 .67308 L
.78846 .68992 L
.78695 .69231 L
.77398 .71154 L
.76923 .71813 L
.75936 .73077 L
.75 .74191 L
.74267 .75 L
.73077 .76209 L
.72311 .76923 L
.71154 .77904 L
.69913 .78846 L
.69231 .7931 L
.67308 .80466 L
.66736 .80769 L
.65385 .81401 L
.63462 .82166 L
.61854 .82692 L
.61538 .82779 L
.59615 .83234 L
.57692 .83566 L
.55769 .83773 L
.53846 .83849 L
.51923 .83792 L
.5 .83602 L
.48077 .83281 L
.46154 .82837 L
.4561 .82692 L
.44231 .82238 L
.42308 .81498 L
.40617 .80769 L
.40385 .80658 L
.38462 .79696 L
.36819 .78846 L
.36538 .78695 L
.34615 .77661 L
.3323 .76923 L
.32692 .76626 L
.30769 .75522 L
.29915 .75 L
.28846 .74284 L
.27223 .73077 L
.26923 .72829 L
.25078 .71154 L
.25 .71076 L
.23311 .69231 L
.23077 .6895 L
.21821 .67308 L
.21154 .66366 L
.20536 .65385 L
Mistroke
.1938 .63462 L
.19231 .63196 L
.18421 .61538 L
.1752 .59615 L
.17308 .59126 L
.16801 .57692 L
.16154 .55769 L
.15605 .53846 L
.15385 .52944 L
.15217 .51923 L
.14966 .5 L
.14846 .48077 L
.14882 .46154 L
.15094 .44231 L
.15385 .4274 L
.15513 .42308 L
.16202 .40385 L
.17156 .38462 L
.17308 .38199 L
.18414 .36538 L
.19231 .35435 L
.19871 .34615 L
.21154 .32971 L
.21372 .32692 L
.22845 .30769 L
.23077 .30458 L
.24333 .28846 L
.25 .28004 L
.25917 .26923 L
.26923 .25802 L
.27701 .25 L
.28846 .23909 L
.29795 .23077 L
.30769 .22302 L
.32353 .21154 L
.32692 .20936 L
.34615 .198 L
.35708 .19231 L
.36538 .18862 L
.38462 .1811 L
.40385 .17523 L
.41213 .17308 L
.42308 .17114 L
Mfstroke
.3 g
.36538 .21037 m
.38462 .20333 L
.40385 .19836 L
.42308 .1955 L
.44231 .19467 L
.46154 .19567 L
.48077 .19801 L
.5 .20072 L
.51923 .20274 L
.53846 .20377 L
.55769 .20456 L
.57692 .20608 L
.59615 .20898 L
.60871 .21154 L
.61538 .21362 L
.63462 .22027 L
.65385 .22894 L
.65746 .23077 L
.67308 .23993 L
.68796 .25 L
.69231 .25328 L
.71151 .26923 L
.71154 .26925 L
.73077 .28796 L
.73125 .28846 L
.74862 .30769 L
.75 .3093 L
.76437 .32692 L
.76923 .33319 L
.77874 .34615 L
.78846 .36039 L
.79161 .36538 L
.80259 .38462 L
.80769 .39497 L
.81149 .40385 L
.81835 .42308 L
.82336 .44231 L
.82667 .46154 L
.82692 .46357 L
.82837 .48077 L
.82877 .5 L
.82802 .51923 L
.82692 .53474 L
.82618 .53846 L
.82314 .55769 L
.81898 .57692 L
.81374 .59615 L
.80769 .61477 L
.80746 .61538 L
.79943 .63462 L
.79007 .65385 L
.78846 .6569 L
.77884 .67308 L
.76923 .68751 L
.76575 .69231 L
.75038 .71154 L
.75 .71198 L
.73246 .73077 L
.73077 .73244 L
.71154 .75 L
.71154 .75 L
.69231 .76517 L
.68667 .76923 L
.67308 .77826 L
.65568 .78846 L
.65385 .78944 L
.63462 .79873 L
.61538 .80636 L
.61155 .80769 L
.59615 .81223 L
.57692 .81653 L
.55769 .81929 L
.53846 .82051 L
.51923 .82018 L
.5 .81829 L
.48077 .81483 L
.46154 .80983 L
.45467 .80769 L
.44231 .80308 L
.42308 .79461 L
.41084 .78846 L
.40385 .78462 L
.38462 .77333 L
.37786 .76923 L
.36538 .76161 L
.34615 .75044 L
.34536 .75 L
.32692 .74013 L
.30928 .73077 L
.30769 .7299 L
.28846 .71825 L
.27868 .71154 L
.26923 .70411 L
.25581 .69231 L
.25 .68648 L
.23779 .67308 L
.23077 .66441 L
.22299 .65385 L
.21154 .63662 L
.21037 .63462 L
.19975 .61538 L
.19231 .60039 L
.19053 .59615 L
.18289 .57692 L
.17628 .55769 L
.17308 .54683 L
.17119 .53846 L
.16755 .51923 L
.16527 .5 L
.16461 .48077 L
.16581 .46154 L
.16915 .44231 L
.17308 .42824 L
.17502 .42308 L
.18397 .40385 L
.19231 .38994 L
.19592 .38462 L
.20998 .36538 L
.21154 .3633 L
.22427 .34615 L
.23077 .33703 L
.23793 .32692 L
.25 .30977 L
.25152 .30769 L
.26622 .28846 L
.26923 .28474 L
.28296 .26923 L
.28846 .26355 L
.30293 .25 L
.30769 .24599 L
.32692 .23148 L
.32796 .23077 L
.34615 .21977 L
.3626 .21154 L
F
0 g
.36538 .21037 m
.38462 .20333 L
.40385 .19836 L
.42308 .1955 L
.44231 .19467 L
.46154 .19567 L
.48077 .19801 L
.5 .20072 L
.51923 .20274 L
.53846 .20377 L
.55769 .20456 L
.57692 .20608 L
.59615 .20898 L
.60871 .21154 L
.61538 .21362 L
.63462 .22027 L
.65385 .22894 L
.65746 .23077 L
.67308 .23993 L
.68796 .25 L
.69231 .25328 L
.71151 .26923 L
.71154 .26925 L
.73077 .28796 L
.73125 .28846 L
.74862 .30769 L
.75 .3093 L
.76437 .32692 L
.76923 .33319 L
.77874 .34615 L
.78846 .36039 L
.79161 .36538 L
.80259 .38462 L
.80769 .39497 L
.81149 .40385 L
.81835 .42308 L
.82336 .44231 L
.82667 .46154 L
.82692 .46357 L
.82837 .48077 L
.82877 .5 L
.82802 .51923 L
.82692 .53474 L
.82618 .53846 L
.82314 .55769 L
.81898 .57692 L
.81374 .59615 L
.80769 .61477 L
.80746 .61538 L
.79943 .63462 L
Mistroke
.79007 .65385 L
.78846 .6569 L
.77884 .67308 L
.76923 .68751 L
.76575 .69231 L
.75038 .71154 L
.75 .71198 L
.73246 .73077 L
.73077 .73244 L
.71154 .75 L
.71154 .75 L
.69231 .76517 L
.68667 .76923 L
.67308 .77826 L
.65568 .78846 L
.65385 .78944 L
.63462 .79873 L
.61538 .80636 L
.61155 .80769 L
.59615 .81223 L
.57692 .81653 L
.55769 .81929 L
.53846 .82051 L
.51923 .82018 L
.5 .81829 L
.48077 .81483 L
.46154 .80983 L
.45467 .80769 L
.44231 .80308 L
.42308 .79461 L
.41084 .78846 L
.40385 .78462 L
.38462 .77333 L
.37786 .76923 L
.36538 .76161 L
.34615 .75044 L
.34536 .75 L
.32692 .74013 L
.30928 .73077 L
.30769 .7299 L
.28846 .71825 L
.27868 .71154 L
.26923 .70411 L
.25581 .69231 L
.25 .68648 L
.23779 .67308 L
.23077 .66441 L
.22299 .65385 L
.21154 .63662 L
.21037 .63462 L
Mistroke
.19975 .61538 L
.19231 .60039 L
.19053 .59615 L
.18289 .57692 L
.17628 .55769 L
.17308 .54683 L
.17119 .53846 L
.16755 .51923 L
.16527 .5 L
.16461 .48077 L
.16581 .46154 L
.16915 .44231 L
.17308 .42824 L
.17502 .42308 L
.18397 .40385 L
.19231 .38994 L
.19592 .38462 L
.20998 .36538 L
.21154 .3633 L
.22427 .34615 L
.23077 .33703 L
.23793 .32692 L
.25 .30977 L
.25152 .30769 L
.26622 .28846 L
.26923 .28474 L
.28296 .26923 L
.28846 .26355 L
.30293 .25 L
.30769 .24599 L
.32692 .23148 L
.32796 .23077 L
.34615 .21977 L
.3626 .21154 L
.36538 .21037 L
Mfstroke
.4 g
.36538 .22774 m
.38462 .22108 L
.40385 .21702 L
.42308 .21567 L
.44231 .21711 L
.46154 .22142 L
.48077 .22827 L
.487 .23077 L
.5 .23413 L
.51923 .23626 L
.53846 .2341 L
.55705 .23077 L
.55769 .23065 L
.57692 .22866 L
.59615 .22927 L
.60691 .23077 L
.61538 .2325 L
.63462 .23837 L
.65385 .24688 L
.65983 .25 L
.67308 .25815 L
.68846 .26923 L
.69231 .27235 L
.71023 .28846 L
.71154 .28975 L
.72835 .30769 L
.73077 .31047 L
.74427 .32692 L
.75 .33433 L
.75874 .34615 L
.76923 .36117 L
.77202 .36538 L
.78385 .38462 L
.78846 .39301 L
.79384 .40385 L
.80181 .42308 L
.80769 .44202 L
.80777 .44231 L
.81182 .46154 L
.81426 .48077 L
.81524 .5 L
.81489 .51923 L
.81332 .53846 L
.81056 .55769 L
.80769 .5725 L
.80659 .57692 L
.80111 .59615 L
.79421 .61538 L
.78846 .62894 L
.78572 .63462 L
.77519 .65385 L
.76923 .66334 L
.76248 .67308 L
.75 .68883 L
.74702 .69231 L
.73077 .70915 L
.72828 .71154 L
.71154 .7262 L
.7059 .73077 L
.69231 .74124 L
.68027 .75 L
.67308 .75505 L
.65385 .76775 L
.65145 .76923 L
.63462 .77894 L
.61538 .78828 L
.61496 .78846 L
.59615 .79561 L
.57692 .80101 L
.55769 .80455 L
.53846 .80625 L
.51923 .80616 L
.5 .80427 L
.48077 .80054 L
.46154 .79494 L
.44469 .78846 L
.44231 .78739 L
.42308 .77761 L
.40922 .76923 L
.40385 .76573 L
.38462 .75203 L
.38187 .75 L
.36538 .73818 L
.35388 .73077 L
.34615 .72639 L
.32692 .71725 L
.31404 .71154 L
.30769 .70869 L
.28846 .6984 L
.27874 .69231 L
.26923 .68494 L
.25557 .67308 L
.25 .66728 L
.2381 .65385 L
.23077 .64426 L
.22408 .63462 L
.21235 .61538 L
.21154 .61391 L
.20275 .59615 L
.19459 .57692 L
.19231 .57087 L
.18815 .55769 L
.18312 .53846 L
.17955 .51923 L
.17766 .5 L
.17766 .48077 L
.17981 .46154 L
.18452 .44231 L
.19228 .42308 L
.19231 .42301 L
.20344 .40385 L
.21154 .3922 L
.2171 .38462 L
.23077 .3657 L
.23099 .36538 L
.24386 .34615 L
.25 .33656 L
.25628 .32692 L
.26923 .30799 L
.26945 .30769 L
.28459 .28846 L
.28846 .28402 L
.3028 .26923 L
.30769 .26473 L
.3259 .25 L
.32692 .24928 L
.34615 .23709 L
.35823 .23077 L
F
0 g
.36538 .22774 m
.38462 .22108 L
.40385 .21702 L
.42308 .21567 L
.44231 .21711 L
.46154 .22142 L
.48077 .22827 L
.487 .23077 L
.5 .23413 L
.51923 .23626 L
.53846 .2341 L
.55705 .23077 L
.55769 .23065 L
.57692 .22866 L
.59615 .22927 L
.60691 .23077 L
.61538 .2325 L
.63462 .23837 L
.65385 .24688 L
.65983 .25 L
.67308 .25815 L
.68846 .26923 L
.69231 .27235 L
.71023 .28846 L
.71154 .28975 L
.72835 .30769 L
.73077 .31047 L
.74427 .32692 L
.75 .33433 L
.75874 .34615 L
.76923 .36117 L
.77202 .36538 L
.78385 .38462 L
.78846 .39301 L
.79384 .40385 L
.80181 .42308 L
.80769 .44202 L
.80777 .44231 L
.81182 .46154 L
.81426 .48077 L
.81524 .5 L
.81489 .51923 L
.81332 .53846 L
.81056 .55769 L
.80769 .5725 L
.80659 .57692 L
.80111 .59615 L
.79421 .61538 L
.78846 .62894 L
.78572 .63462 L
Mistroke
.77519 .65385 L
.76923 .66334 L
.76248 .67308 L
.75 .68883 L
.74702 .69231 L
.73077 .70915 L
.72828 .71154 L
.71154 .7262 L
.7059 .73077 L
.69231 .74124 L
.68027 .75 L
.67308 .75505 L
.65385 .76775 L
.65145 .76923 L
.63462 .77894 L
.61538 .78828 L
.61496 .78846 L
.59615 .79561 L
.57692 .80101 L
.55769 .80455 L
.53846 .80625 L
.51923 .80616 L
.5 .80427 L
.48077 .80054 L
.46154 .79494 L
.44469 .78846 L
.44231 .78739 L
.42308 .77761 L
.40922 .76923 L
.40385 .76573 L
.38462 .75203 L
.38187 .75 L
.36538 .73818 L
.35388 .73077 L
.34615 .72639 L
.32692 .71725 L
.31404 .71154 L
.30769 .70869 L
.28846 .6984 L
.27874 .69231 L
.26923 .68494 L
.25557 .67308 L
.25 .66728 L
.2381 .65385 L
.23077 .64426 L
.22408 .63462 L
.21235 .61538 L
.21154 .61391 L
.20275 .59615 L
.19459 .57692 L
Mistroke
.19231 .57087 L
.18815 .55769 L
.18312 .53846 L
.17955 .51923 L
.17766 .5 L
.17766 .48077 L
.17981 .46154 L
.18452 .44231 L
.19228 .42308 L
.19231 .42301 L
.20344 .40385 L
.21154 .3922 L
.2171 .38462 L
.23077 .3657 L
.23099 .36538 L
.24386 .34615 L
.25 .33656 L
.25628 .32692 L
.26923 .30799 L
.26945 .30769 L
.28459 .28846 L
.28846 .28402 L
.3028 .26923 L
.30769 .26473 L
.3259 .25 L
.32692 .24928 L
.34615 .23709 L
.35823 .23077 L
.36538 .22774 L
Mfstroke
.5 g
.36538 .243 m
.38462 .23679 L
.40385 .23383 L
.42308 .23444 L
.44231 .23944 L
.45964 .25 L
.46154 .25072 L
.47247 .26923 L
.47404 .28846 L
.46889 .30769 L
.46154 .32692 L
.46152 .32692 L
.45129 .34615 L
.44231 .3613 L
.4395 .36538 L
.42517 .38462 L
.42308 .38714 L
.40745 .40385 L
.40385 .40725 L
.38488 .42308 L
.38462 .42328 L
.36538 .4369 L
.35769 .44231 L
.34615 .45092 L
.33602 .46154 L
.32692 .47978 L
.32667 .48077 L
.32481 .5 L
.32677 .51923 L
.32692 .52056 L
.3306 .53846 L
.33549 .55769 L
.34101 .57692 L
.34615 .5932 L
.34704 .59615 L
.3537 .61538 L
.3648 .63462 L
.36538 .63491 L
.38462 .64553 L
.40385 .64305 L
.42308 .63705 L
.43103 .63462 L
.44231 .63113 L
.46154 .62675 L
.48077 .62436 L
.5 .62399 L
.51923 .62543 L
.53846 .62828 L
.55769 .63177 L
.57692 .63456 L
.59615 .63397 L
.61538 .62343 L
.62188 .61538 L
.63039 .59615 L
.63462 .58197 L
.63607 .57692 L
.64134 .55769 L
.64662 .53846 L
.65196 .51923 L
.65385 .51287 L
.65699 .5 L
.6607 .48077 L
.66154 .46154 L
.65761 .44231 L
.65385 .43277 L
.64698 .42308 L
.63462 .40872 L
.62966 .40385 L
.61538 .39001 L
.60989 .38462 L
.59615 .37026 L
.59193 .36538 L
.57692 .34626 L
.57685 .34615 L
.56466 .32692 L
.55769 .31682 L
.5555 .30769 L
.55091 .28846 L
.55469 .26923 L
.55769 .26263 L
.57692 .25216 L
.58698 .25 L
.59615 .249 L
.61406 .25 L
.61538 .2502 L
.63462 .25506 L
.65385 .26336 L
.66453 .26923 L
.67308 .27502 L
.69019 .28846 L
.69231 .29036 L
.70973 .30769 L
.71154 .30968 L
.72598 .32692 L
.73077 .33313 L
.74032 .34615 L
.75 .36011 L
.75355 .36538 L
.76591 .38462 L
.76923 .39019 L
.77697 .40385 L
.78619 .42308 L
.78846 .42871 L
.79331 .44231 L
.79847 .46154 L
.80177 .48077 L
.80343 .5 L
.8036 .51923 L
.80236 .53846 L
.79972 .55769 L
.79564 .57692 L
.79006 .59615 L
.78846 .60089 L
.78271 .61538 L
.77331 .63462 L
.76923 .64179 L
.76155 .65385 L
.75 .66904 L
.74667 .67308 L
.73077 .68935 L
.72767 .69231 L
.71154 .70542 L
.70326 .71154 L
.69231 .71909 L
.67509 .73077 L
.67308 .73217 L
.65385 .74583 L
.64797 .75 L
.63462 .75932 L
.61849 .76923 L
.61538 .77097 L
.59615 .78027 L
.57692 .78701 L
.57207 .78846 L
.55769 .7914 L
.53846 .79364 L
.51923 .7938 L
.5 .79193 L
.48211 .78846 L
.48077 .78799 L
.46154 .78178 L
.44231 .77309 L
.43527 .76923 L
.42308 .76164 L
.40776 .75 L
.40385 .74694 L
.38685 .73077 L
.38462 .72925 L
.36704 .71154 L
.36538 .71016 L
.34615 .69951 L
.32692 .69427 L
.31846 .69231 L
.30769 .68903 L
.28846 .68072 L
.2746 .67308 L
.26923 .66816 L
.25294 .65385 L
.25 .65044 L
.23667 .63462 L
.23077 .62617 L
.22389 .61538 L
.21344 .59615 L
.21154 .59219 L
.20509 .57692 L
.19839 .55769 L
.19339 .53846 L
.19231 .53567 L
.19018 .51923 L
.18881 .5 L
.18955 .48077 L
.19231 .46371 L
.19281 .46154 L
.19913 .44231 L
.20933 .42308 L
.21154 .41965 L
.2228 .40385 L
.23077 .39319 L
.23689 .38462 L
.24922 .36538 L
.25 .36407 L
.26042 .34615 L
.26923 .33124 L
.27195 .32692 L
.28516 .30769 L
.28846 .30335 L
.30118 .28846 L
.30769 .28177 L
.32165 .26923 L
.32692 .26512 L
.34615 .25235 L
.35005 .25 L
F
0 g
.36538 .243 m
.38462 .23679 L
.40385 .23383 L
.42308 .23444 L
.44231 .23944 L
.45964 .25 L
.46154 .25072 L
.47247 .26923 L
.47404 .28846 L
.46889 .30769 L
.46154 .32692 L
.46152 .32692 L
.45129 .34615 L
.44231 .3613 L
.4395 .36538 L
.42517 .38462 L
.42308 .38714 L
.40745 .40385 L
.40385 .40725 L
.38488 .42308 L
.38462 .42328 L
.36538 .4369 L
.35769 .44231 L
.34615 .45092 L
.33602 .46154 L
.32692 .47978 L
.32667 .48077 L
.32481 .5 L
.32677 .51923 L
.32692 .52056 L
.3306 .53846 L
.33549 .55769 L
.34101 .57692 L
.34615 .5932 L
.34704 .59615 L
.3537 .61538 L
.3648 .63462 L
.36538 .63491 L
.38462 .64553 L
.40385 .64305 L
.42308 .63705 L
.43103 .63462 L
.44231 .63113 L
.46154 .62675 L
.48077 .62436 L
.5 .62399 L
.51923 .62543 L
.53846 .62828 L
.55769 .63177 L
.57692 .63456 L
Mistroke
.59615 .63397 L
.61538 .62343 L
.62188 .61538 L
.63039 .59615 L
.63462 .58197 L
.63607 .57692 L
.64134 .55769 L
.64662 .53846 L
.65196 .51923 L
.65385 .51287 L
.65699 .5 L
.6607 .48077 L
.66154 .46154 L
.65761 .44231 L
.65385 .43277 L
.64698 .42308 L
.63462 .40872 L
.62966 .40385 L
.61538 .39001 L
.60989 .38462 L
.59615 .37026 L
.59193 .36538 L
.57692 .34626 L
.57685 .34615 L
.56466 .32692 L
.55769 .31682 L
.5555 .30769 L
.55091 .28846 L
.55469 .26923 L
.55769 .26263 L
.57692 .25216 L
.58698 .25 L
.59615 .249 L
.61406 .25 L
.61538 .2502 L
.63462 .25506 L
.65385 .26336 L
.66453 .26923 L
.67308 .27502 L
.69019 .28846 L
.69231 .29036 L
.70973 .30769 L
.71154 .30968 L
.72598 .32692 L
.73077 .33313 L
.74032 .34615 L
.75 .36011 L
.75355 .36538 L
.76591 .38462 L
.76923 .39019 L
Mistroke
.77697 .40385 L
.78619 .42308 L
.78846 .42871 L
.79331 .44231 L
.79847 .46154 L
.80177 .48077 L
.80343 .5 L
.8036 .51923 L
.80236 .53846 L
.79972 .55769 L
.79564 .57692 L
.79006 .59615 L
.78846 .60089 L
.78271 .61538 L
.77331 .63462 L
.76923 .64179 L
.76155 .65385 L
.75 .66904 L
.74667 .67308 L
.73077 .68935 L
.72767 .69231 L
.71154 .70542 L
.70326 .71154 L
.69231 .71909 L
.67509 .73077 L
.67308 .73217 L
.65385 .74583 L
.64797 .75 L
.63462 .75932 L
.61849 .76923 L
.61538 .77097 L
.59615 .78027 L
.57692 .78701 L
.57207 .78846 L
.55769 .7914 L
.53846 .79364 L
.51923 .7938 L
.5 .79193 L
.48211 .78846 L
.48077 .78799 L
.46154 .78178 L
.44231 .77309 L
.43527 .76923 L
.42308 .76164 L
.40776 .75 L
.40385 .74694 L
.38685 .73077 L
.38462 .72925 L
.36704 .71154 L
.36538 .71016 L
Mistroke
.34615 .69951 L
.32692 .69427 L
.31846 .69231 L
.30769 .68903 L
.28846 .68072 L
.2746 .67308 L
.26923 .66816 L
.25294 .65385 L
.25 .65044 L
.23667 .63462 L
.23077 .62617 L
.22389 .61538 L
.21344 .59615 L
.21154 .59219 L
.20509 .57692 L
.19839 .55769 L
.19339 .53846 L
.19231 .53567 L
.19018 .51923 L
.18881 .5 L
.18955 .48077 L
.19231 .46371 L
.19281 .46154 L
.19913 .44231 L
.20933 .42308 L
.21154 .41965 L
.2228 .40385 L
.23077 .39319 L
.23689 .38462 L
.24922 .36538 L
.25 .36407 L
.26042 .34615 L
.26923 .33124 L
.27195 .32692 L
.28516 .30769 L
.28846 .30335 L
.30118 .28846 L
.30769 .28177 L
.32165 .26923 L
.32692 .26512 L
.34615 .25235 L
.35005 .25 L
.36538 .243 L
Mfstroke
.6 g
.34615 .26679 m
.36538 .25734 L
.38462 .25174 L
.40385 .25025 L
.42308 .25382 L
.44231 .26717 L
.44371 .26923 L
.45094 .28846 L
.45014 .30769 L
.44484 .32692 L
.44231 .33452 L
.4363 .34615 L
.42475 .36538 L
.42308 .36784 L
.40974 .38462 L
.40385 .39095 L
.38994 .40385 L
.38462 .4081 L
.36538 .42155 L
.36305 .42308 L
.34615 .43324 L
.33275 .44231 L
.32692 .44687 L
.31646 .46154 L
.31188 .48077 L
.31264 .5 L
.31594 .51923 L
.32045 .53846 L
.32534 .55769 L
.32692 .56385 L
.33009 .57692 L
.33456 .59615 L
.33847 .61538 L
.3412 .63462 L
.34006 .65385 L
.32692 .66756 L
.30769 .66924 L
.28846 .66389 L
.27116 .65385 L
.26923 .65245 L
.25003 .63462 L
.25 .63457 L
.23493 .61538 L
.23077 .60856 L
.2237 .59615 L
.21477 .57692 L
.21154 .56855 L
.20802 .55769 L
.2031 .53846 L
.20013 .51923 L
.19931 .5 L
.201 .48077 L
.20591 .46154 L
.21154 .4485 L
.21463 .44231 L
.22846 .42308 L
.23077 .42028 L
.24381 .40385 L
.25 .39496 L
.25611 .38462 L
.26591 .36538 L
.26923 .35848 L
.27548 .34615 L
.28647 .32692 L
.28846 .32376 L
.30001 .30769 L
.30769 .29858 L
.31754 .28846 L
.32692 .28025 L
.34203 .26923 L
F
0 g
.34615 .26679 m
.36538 .25734 L
.38462 .25174 L
.40385 .25025 L
.42308 .25382 L
.44231 .26717 L
.44371 .26923 L
.45094 .28846 L
.45014 .30769 L
.44484 .32692 L
.44231 .33452 L
.4363 .34615 L
.42475 .36538 L
.42308 .36784 L
.40974 .38462 L
.40385 .39095 L
.38994 .40385 L
.38462 .4081 L
.36538 .42155 L
.36305 .42308 L
.34615 .43324 L
.33275 .44231 L
.32692 .44687 L
.31646 .46154 L
.31188 .48077 L
.31264 .5 L
.31594 .51923 L
.32045 .53846 L
.32534 .55769 L
.32692 .56385 L
.33009 .57692 L
.33456 .59615 L
.33847 .61538 L
.3412 .63462 L
.34006 .65385 L
.32692 .66756 L
.30769 .66924 L
.28846 .66389 L
.27116 .65385 L
.26923 .65245 L
.25003 .63462 L
.25 .63457 L
.23493 .61538 L
.23077 .60856 L
.2237 .59615 L
.21477 .57692 L
.21154 .56855 L
.20802 .55769 L
.2031 .53846 L
.20013 .51923 L
Mistroke
.19931 .5 L
.201 .48077 L
.20591 .46154 L
.21154 .4485 L
.21463 .44231 L
.22846 .42308 L
.23077 .42028 L
.24381 .40385 L
.25 .39496 L
.25611 .38462 L
.26591 .36538 L
.26923 .35848 L
.27548 .34615 L
.28647 .32692 L
.28846 .32376 L
.30001 .30769 L
.30769 .29858 L
.31754 .28846 L
.32692 .28025 L
.34203 .26923 L
.34615 .26679 L
Mfstroke
.7 g
.38462 .26696 m
.40385 .26776 L
.40878 .26923 L
.42308 .27625 L
.42988 .28846 L
.43297 .30769 L
.4296 .32692 L
.42308 .34364 L
.42188 .34615 L
.41018 .36538 L
.40385 .37368 L
.39378 .38462 L
.38462 .39287 L
.36992 .40385 L
.36538 .4066 L
.34615 .417 L
.33344 .42308 L
.32692 .42573 L
.30769 .4368 L
.30391 .44231 L
.29662 .46154 L
.29737 .48077 L
.30089 .5 L
.30548 .51923 L
.30769 .52852 L
.31044 .53846 L
.31545 .55769 L
.31982 .57692 L
.32303 .59615 L
.32445 .61538 L
.32023 .63462 L
.30769 .64721 L
.28846 .64681 L
.26923 .63689 L
.26539 .63462 L
.25 .61871 L
.24711 .61538 L
.23381 .59615 L
.23077 .58994 L
.22449 .57692 L
.2173 .55769 L
.21264 .53846 L
.21154 .53121 L
.21023 .51923 L
.2103 .5 L
.21154 .49024 L
.21295 .48077 L
.2199 .46154 L
.23077 .44757 L
.23557 .44231 L
.25 .42868 L
.25392 .42308 L
.26888 .40385 L
.26923 .40307 L
.27563 .38462 L
.28213 .36538 L
.28846 .3488 L
.29016 .34615 L
.30078 .32692 L
.30769 .31677 L
.31511 .30769 L
.32692 .29571 L
.33529 .28846 L
.34615 .28121 L
.36538 .27169 L
.37325 .26923 L
F
0 g
.38462 .26696 m
.40385 .26776 L
.40878 .26923 L
.42308 .27625 L
.42988 .28846 L
.43297 .30769 L
.4296 .32692 L
.42308 .34364 L
.42188 .34615 L
.41018 .36538 L
.40385 .37368 L
.39378 .38462 L
.38462 .39287 L
.36992 .40385 L
.36538 .4066 L
.34615 .417 L
.33344 .42308 L
.32692 .42573 L
.30769 .4368 L
.30391 .44231 L
.29662 .46154 L
.29737 .48077 L
.30089 .5 L
.30548 .51923 L
.30769 .52852 L
.31044 .53846 L
.31545 .55769 L
.31982 .57692 L
.32303 .59615 L
.32445 .61538 L
.32023 .63462 L
.30769 .64721 L
.28846 .64681 L
.26923 .63689 L
.26539 .63462 L
.25 .61871 L
.24711 .61538 L
.23381 .59615 L
.23077 .58994 L
.22449 .57692 L
.2173 .55769 L
.21264 .53846 L
.21154 .53121 L
.21023 .51923 L
.2103 .5 L
.21154 .49024 L
.21295 .48077 L
.2199 .46154 L
.23077 .44757 L
.23557 .44231 L
Mistroke
.25 .42868 L
.25392 .42308 L
.26888 .40385 L
.26923 .40307 L
.27563 .38462 L
.28213 .36538 L
.28846 .3488 L
.29016 .34615 L
.30078 .32692 L
.30769 .31677 L
.31511 .30769 L
.32692 .29571 L
.33529 .28846 L
.34615 .28121 L
.36538 .27169 L
.37325 .26923 L
.38462 .26696 L
Mfstroke
.8 g
.25 .46088 m
.26499 .46154 L
.26923 .46455 L
.2796 .48077 L
.28733 .5 L
.28846 .50319 L
.29439 .51923 L
.30073 .53846 L
.30574 .55769 L
.30769 .5712 L
.30864 .57692 L
.3102 .59615 L
.30769 .61251 L
.30663 .61538 L
.28846 .628 L
.26923 .62046 L
.2629 .61538 L
.25 .60167 L
.24554 .59615 L
.23374 .57692 L
.23077 .56748 L
.22743 .55769 L
.22238 .53846 L
.22012 .51923 L
.22121 .5 L
.22867 .48077 L
.23077 .4778 L
.24843 .46154 L
F
0 g
.25 .46088 m
.26499 .46154 L
.26923 .46455 L
.2796 .48077 L
.28733 .5 L
.28846 .50319 L
.29439 .51923 L
.30073 .53846 L
.30574 .55769 L
.30769 .5712 L
.30864 .57692 L
.3102 .59615 L
.30769 .61251 L
.30663 .61538 L
.28846 .628 L
.26923 .62046 L
.2629 .61538 L
.25 .60167 L
.24554 .59615 L
.23374 .57692 L
.23077 .56748 L
.22743 .55769 L
.22238 .53846 L
.22012 .51923 L
.22121 .5 L
.22867 .48077 L
.23077 .4778 L
.24843 .46154 L
.25 .46088 L
s
.9 g
.25 .49226 m
.26832 .5 L
.26923 .501 L
.28002 .51923 L
.28769 .53846 L
.28846 .54083 L
.29408 .55769 L
.29954 .57692 L
.29231 .59615 L
.28846 .60299 L
.26923 .60109 L
.26312 .59615 L
.25 .58068 L
.24724 .57692 L
.23947 .55769 L
.23501 .53846 L
.23468 .51923 L
.24111 .5 L
F
0 g
.25 .49226 m
.26832 .5 L
.26923 .501 L
.28002 .51923 L
.28769 .53846 L
.28846 .54083 L
.29408 .55769 L
.29954 .57692 L
.29231 .59615 L
.28846 .60299 L
.26923 .60109 L
.26312 .59615 L
.25 .58068 L
.24724 .57692 L
.23947 .55769 L
.23501 .53846 L
.23468 .51923 L
.24111 .5 L
.25 .49226 L
s
1 g
.26923 .548 m
.27093 .55769 L
.26923 .56247 L
.26166 .55769 L
F
0 g
.26923 .548 m
.27093 .55769 L
.26923 .56247 L
.26166 .55769 L
.26923 .548 L
s
.8 g
.36538 .28722 m
.38462 .28375 L
.40152 .28846 L
.40385 .29002 L
.41496 .30769 L
.41392 .32692 L
.40673 .34615 L
.40385 .35236 L
.39456 .36538 L
.38462 .37625 L
.37536 .38462 L
.36538 .3909 L
.34615 .40037 L
.33323 .40385 L
.32692 .40492 L
.31109 .40385 L
.30769 .40236 L
.29731 .38462 L
.29921 .36538 L
.30563 .34615 L
.30769 .34067 L
.31594 .32692 L
.32692 .31288 L
.33174 .30769 L
.34615 .29665 L
.36217 .28846 L
F
0 g
.36538 .28722 m
.38462 .28375 L
.40152 .28846 L
.40385 .29002 L
.41496 .30769 L
.41392 .32692 L
.40673 .34615 L
.40385 .35236 L
.39456 .36538 L
.38462 .37625 L
.37536 .38462 L
.36538 .3909 L
.34615 .40037 L
.33323 .40385 L
.32692 .40492 L
.31109 .40385 L
.30769 .40236 L
.29731 .38462 L
.29921 .36538 L
.30563 .34615 L
.30769 .34067 L
.31594 .32692 L
.32692 .31288 L
.33174 .30769 L
.34615 .29665 L
.36217 .28846 L
.36538 .28722 L
s
.9 g
.36538 .30637 m
.38455 .30769 L
.38462 .30773 L
.3968 .32692 L
.38864 .34615 L
.38462 .35195 L
.37288 .36538 L
.36538 .37222 L
.34615 .37962 L
.32692 .37581 L
.31993 .36538 L
.32417 .34615 L
.32692 .34061 L
.33202 .32692 L
.34615 .31415 L
.36179 .30769 L
F
0 g
.36538 .30637 m
.38455 .30769 L
.38462 .30773 L
.3968 .32692 L
.38864 .34615 L
.38462 .35195 L
.37288 .36538 L
.36538 .37222 L
.34615 .37962 L
.32692 .37581 L
.31993 .36538 L
.32417 .34615 L
.32692 .34061 L
.33202 .32692 L
.34615 .31415 L
.36179 .30769 L
.36538 .30637 L
s
.3 g
.5 .31184 m
.51923 .30998 L
.53846 .32528 L
.54064 .32692 L
.55693 .34615 L
.55769 .34735 L
.57306 .36538 L
.57692 .36993 L
.5906 .38462 L
.59615 .39033 L
.60973 .40385 L
.61538 .40945 L
.62789 .42308 L
.63462 .4313 L
.6408 .44231 L
.64695 .46154 L
.6477 .48077 L
.64503 .5 L
.64053 .51923 L
.63522 .53846 L
.63462 .54059 L
.62982 .55769 L
.62358 .57692 L
.61538 .59474 L
.61476 .59615 L
.59615 .61441 L
.59395 .61538 L
.57692 .6189 L
.55769 .61799 L
.53846 .61541 L
.53832 .61538 L
.51923 .61303 L
.5 .61166 L
.48077 .61177 L
.46154 .6135 L
.44893 .61538 L
.44231 .61673 L
.42308 .62074 L
.40385 .62342 L
.38462 .62022 L
.37693 .61538 L
.36538 .60189 L
.36182 .59615 L
.3531 .57692 L
.34693 .55769 L
.34615 .55528 L
.34183 .53846 L
.33846 .51923 L
.33804 .5 L
.34294 .48077 L
.34615 .47397 L
.35711 .46154 L
.36538 .45412 L
.38092 .44231 L
.38462 .43949 L
.40385 .42404 L
.40496 .42308 L
.42308 .40575 L
.42487 .40385 L
.44143 .38462 L
.44231 .38352 L
.45569 .36538 L
.46154 .35736 L
.46851 .34615 L
.48077 .33055 L
.48363 .32692 L
F
0 g
.5 .31184 m
.51923 .30998 L
.53846 .32528 L
.54064 .32692 L
.55693 .34615 L
.55769 .34735 L
.57306 .36538 L
.57692 .36993 L
.5906 .38462 L
.59615 .39033 L
.60973 .40385 L
.61538 .40945 L
.62789 .42308 L
.63462 .4313 L
.6408 .44231 L
.64695 .46154 L
.6477 .48077 L
.64503 .5 L
.64053 .51923 L
.63522 .53846 L
.63462 .54059 L
.62982 .55769 L
.62358 .57692 L
.61538 .59474 L
.61476 .59615 L
.59615 .61441 L
.59395 .61538 L
.57692 .6189 L
.55769 .61799 L
.53846 .61541 L
.53832 .61538 L
.51923 .61303 L
.5 .61166 L
.48077 .61177 L
.46154 .6135 L
.44893 .61538 L
.44231 .61673 L
.42308 .62074 L
.40385 .62342 L
.38462 .62022 L
.37693 .61538 L
.36538 .60189 L
.36182 .59615 L
.3531 .57692 L
.34693 .55769 L
.34615 .55528 L
.34183 .53846 L
.33846 .51923 L
.33804 .5 L
.34294 .48077 L
Mistroke
.34615 .47397 L
.35711 .46154 L
.36538 .45412 L
.38092 .44231 L
.38462 .43949 L
.40385 .42404 L
.40496 .42308 L
.42308 .40575 L
.42487 .40385 L
.44143 .38462 L
.44231 .38352 L
.45569 .36538 L
.46154 .35736 L
.46851 .34615 L
.48077 .33055 L
.48363 .32692 L
.5 .31184 L
Mfstroke
.2 g
.51923 .34473 m
.52347 .34615 L
.53846 .35537 L
.55119 .36538 L
.55769 .37302 L
.5694 .38462 L
.57692 .39243 L
.58838 .40385 L
.59615 .41161 L
.60707 .42308 L
.61538 .43254 L
.622 .44231 L
.63046 .46154 L
.63287 .48077 L
.6313 .5 L
.62741 .51923 L
.62212 .53846 L
.61555 .55769 L
.61538 .55811 L
.60757 .57692 L
.59615 .59088 L
.58882 .59615 L
.57692 .60074 L
.55769 .60223 L
.53846 .60076 L
.51923 .59877 L
.5 .59744 L
.48077 .59732 L
.46154 .59855 L
.44231 .60087 L
.42308 .60326 L
.40385 .6032 L
.38577 .59615 L
.38462 .59534 L
.36864 .57692 L
.36538 .56925 L
.36058 .55769 L
.35492 .53846 L
.3523 .51923 L
.35388 .5 L
.36262 .48077 L
.36538 .47682 L
.3811 .46154 L
.38462 .45852 L
.40385 .44286 L
.40452 .44231 L
.42308 .42572 L
.42581 .42308 L
.44231 .40585 L
.44404 .40385 L
.46044 .38462 L
.46154 .38333 L
.47641 .36538 L
.48077 .36127 L
.5 .3465 L
.50079 .34615 L
F
0 g
.51923 .34473 m
.52347 .34615 L
.53846 .35537 L
.55119 .36538 L
.55769 .37302 L
.5694 .38462 L
.57692 .39243 L
.58838 .40385 L
.59615 .41161 L
.60707 .42308 L
.61538 .43254 L
.622 .44231 L
.63046 .46154 L
.63287 .48077 L
.6313 .5 L
.62741 .51923 L
.62212 .53846 L
.61555 .55769 L
.61538 .55811 L
.60757 .57692 L
.59615 .59088 L
.58882 .59615 L
.57692 .60074 L
.55769 .60223 L
.53846 .60076 L
.51923 .59877 L
.5 .59744 L
.48077 .59732 L
.46154 .59855 L
.44231 .60087 L
.42308 .60326 L
.40385 .6032 L
.38577 .59615 L
.38462 .59534 L
.36864 .57692 L
.36538 .56925 L
.36058 .55769 L
.35492 .53846 L
.3523 .51923 L
.35388 .5 L
.36262 .48077 L
.36538 .47682 L
.3811 .46154 L
.38462 .45852 L
.40385 .44286 L
.40452 .44231 L
.42308 .42572 L
.42581 .42308 L
.44231 .40585 L
.44404 .40385 L
Mistroke
.46044 .38462 L
.46154 .38333 L
.47641 .36538 L
.48077 .36127 L
.5 .3465 L
.50079 .34615 L
.51923 .34473 L
Mfstroke
.1 g
.5 .3785 m
.51923 .37614 L
.53789 .38462 L
.53846 .38499 L
.55769 .40051 L
.5615 .40385 L
.57692 .41868 L
.58131 .42308 L
.59615 .43953 L
.59824 .44231 L
.60958 .46154 L
.6141 .48077 L
.61376 .5 L
.61043 .51923 L
.60465 .53846 L
.59615 .55634 L
.59559 .55769 L
.57692 .57636 L
.57577 .57692 L
.55769 .58185 L
.53846 .58207 L
.51923 .58074 L
.5 .57953 L
.48077 .57918 L
.46154 .57984 L
.44231 .58116 L
.42308 .58177 L
.40385 .5783 L
.40075 .57692 L
.38462 .56354 L
.38075 .55769 L
.37294 .53846 L
.37111 .51923 L
.37568 .5 L
.38462 .48412 L
.38924 .48077 L
.40385 .46667 L
.4101 .46154 L
.42308 .44997 L
.4315 .44231 L
.44231 .43178 L
.45069 .42308 L
.46154 .41174 L
.4683 .40385 L
.48077 .3921 L
.4898 .38462 L
F
0 g
.5 .3785 m
.51923 .37614 L
.53789 .38462 L
.53846 .38499 L
.55769 .40051 L
.5615 .40385 L
.57692 .41868 L
.58131 .42308 L
.59615 .43953 L
.59824 .44231 L
.60958 .46154 L
.6141 .48077 L
.61376 .5 L
.61043 .51923 L
.60465 .53846 L
.59615 .55634 L
.59559 .55769 L
.57692 .57636 L
.57577 .57692 L
.55769 .58185 L
.53846 .58207 L
.51923 .58074 L
.5 .57953 L
.48077 .57918 L
.46154 .57984 L
.44231 .58116 L
.42308 .58177 L
.40385 .5783 L
.40075 .57692 L
.38462 .56354 L
.38075 .55769 L
.37294 .53846 L
.37111 .51923 L
.37568 .5 L
.38462 .48412 L
.38924 .48077 L
.40385 .46667 L
.4101 .46154 L
.42308 .44997 L
.4315 .44231 L
.44231 .43178 L
.45069 .42308 L
.46154 .41174 L
.4683 .40385 L
.48077 .3921 L
.4898 .38462 L
.5 .3785 L
s
.6 g
.61538 .26879 m
.62077 .26923 L
.63462 .27197 L
.65385 .27992 L
.66844 .28846 L
.67308 .29222 L
.6907 .30769 L
.69231 .30932 L
.70776 .32692 L
.71154 .33172 L
.72186 .34615 L
.73077 .35966 L
.73448 .36538 L
.74686 .38462 L
.75 .38986 L
.75897 .40385 L
.76923 .42232 L
.76964 .42308 L
.77878 .44231 L
.78534 .46154 L
.78846 .47444 L
.78967 .48077 L
.79221 .5 L
.79301 .51923 L
.79217 .53846 L
.78975 .55769 L
.78846 .56532 L
.78568 .57692 L
.77978 .59615 L
.7718 .61538 L
.76923 .62062 L
.76143 .63462 L
.75 .65082 L
.74775 .65385 L
.73077 .67151 L
.72938 .67308 L
.71154 .68648 L
.70298 .69231 L
.69231 .6978 L
.67308 .70772 L
.66615 .71154 L
.65385 .71997 L
.64071 .73077 L
.63462 .73646 L
.61823 .75 L
.61538 .75223 L
.59615 .76475 L
.58685 .76923 L
.57692 .77331 L
.55769 .77897 L
.53846 .7819 L
.51923 .78239 L
.5 .7805 L
.48077 .77617 L
.46169 .76923 L
.46154 .76916 L
.44231 .75909 L
.42957 .75 L
.42308 .74504 L
.40981 .73077 L
.40385 .7229 L
.39722 .71154 L
.39196 .69231 L
.40157 .67308 L
.40385 .66612 L
.42308 .65422 L
.42395 .65385 L
.44231 .6452 L
.46154 .63931 L
.48077 .63616 L
.5 .63545 L
.51923 .63691 L
.53846 .64018 L
.55769 .64467 L
.57692 .64938 L
.59615 .65244 L
.61538 .64959 L
.63121 .63462 L
.63462 .62542 L
.63803 .61538 L
.64292 .59615 L
.64722 .57692 L
.65175 .55769 L
.65385 .54944 L
.65687 .53846 L
.66257 .51923 L
.66832 .5 L
.67308 .48136 L
.67316 .48077 L
.67564 .46154 L
.67419 .44231 L
.67308 .43785 L
.6663 .42308 L
.65385 .40706 L
.65056 .40385 L
.63462 .38892 L
.62987 .38462 L
.61538 .37059 L
.61057 .36538 L
.59615 .3474 L
.59535 .34615 L
.58427 .32692 L
.5781 .30769 L
.579 .28846 L
.59615 .27061 L
.60635 .26923 L
F
0 g
.61538 .26879 m
.62077 .26923 L
.63462 .27197 L
.65385 .27992 L
.66844 .28846 L
.67308 .29222 L
.6907 .30769 L
.69231 .30932 L
.70776 .32692 L
.71154 .33172 L
.72186 .34615 L
.73077 .35966 L
.73448 .36538 L
.74686 .38462 L
.75 .38986 L
.75897 .40385 L
.76923 .42232 L
.76964 .42308 L
.77878 .44231 L
.78534 .46154 L
.78846 .47444 L
.78967 .48077 L
.79221 .5 L
.79301 .51923 L
.79217 .53846 L
.78975 .55769 L
.78846 .56532 L
.78568 .57692 L
.77978 .59615 L
.7718 .61538 L
.76923 .62062 L
.76143 .63462 L
.75 .65082 L
.74775 .65385 L
.73077 .67151 L
.72938 .67308 L
.71154 .68648 L
.70298 .69231 L
.69231 .6978 L
.67308 .70772 L
.66615 .71154 L
.65385 .71997 L
.64071 .73077 L
.63462 .73646 L
.61823 .75 L
.61538 .75223 L
.59615 .76475 L
.58685 .76923 L
.57692 .77331 L
.55769 .77897 L
Mistroke
.53846 .7819 L
.51923 .78239 L
.5 .7805 L
.48077 .77617 L
.46169 .76923 L
.46154 .76916 L
.44231 .75909 L
.42957 .75 L
.42308 .74504 L
.40981 .73077 L
.40385 .7229 L
.39722 .71154 L
.39196 .69231 L
.40157 .67308 L
.40385 .66612 L
.42308 .65422 L
.42395 .65385 L
.44231 .6452 L
.46154 .63931 L
.48077 .63616 L
.5 .63545 L
.51923 .63691 L
.53846 .64018 L
.55769 .64467 L
.57692 .64938 L
.59615 .65244 L
.61538 .64959 L
.63121 .63462 L
.63462 .62542 L
.63803 .61538 L
.64292 .59615 L
.64722 .57692 L
.65175 .55769 L
.65385 .54944 L
.65687 .53846 L
.66257 .51923 L
.66832 .5 L
.67308 .48136 L
.67316 .48077 L
.67564 .46154 L
.67419 .44231 L
.67308 .43785 L
.6663 .42308 L
.65385 .40706 L
.65056 .40385 L
.63462 .38892 L
.62987 .38462 L
.61538 .37059 L
.61057 .36538 L
.59615 .3474 L
Mistroke
.59535 .34615 L
.58427 .32692 L
.5781 .30769 L
.579 .28846 L
.59615 .27061 L
.60635 .26923 L
.61538 .26879 L
Mfstroke
.5 .42144 m
.51923 .41802 L
.53381 .42308 L
.53846 .42558 L
.55769 .44105 L
.55902 .44231 L
.57516 .46154 L
.57692 .46497 L
.58366 .48077 L
.58534 .5 L
.58097 .51923 L
.57692 .5295 L
.57154 .53846 L
.55769 .54728 L
.53846 .55195 L
.51923 .55222 L
.5 .55145 L
.48077 .55081 L
.46154 .55058 L
.44231 .55021 L
.42308 .54365 L
.4142 .53846 L
.40821 .51923 L
.41645 .5 L
.42308 .4918 L
.43328 .48077 L
.44231 .47105 L
.45266 .46154 L
.46154 .45269 L
.47193 .44231 L
.48077 .43469 L
.49689 .42308 L
F
.5 .42144 m
.51923 .41802 L
.53381 .42308 L
.53846 .42558 L
.55769 .44105 L
.55902 .44231 L
.57516 .46154 L
.57692 .46497 L
.58366 .48077 L
.58534 .5 L
.58097 .51923 L
.57692 .5295 L
.57154 .53846 L
.55769 .54728 L
.53846 .55195 L
.51923 .55222 L
.5 .55145 L
.48077 .55081 L
.46154 .55058 L
.44231 .55021 L
.42308 .54365 L
.4142 .53846 L
.40821 .51923 L
.41645 .5 L
.42308 .4918 L
.43328 .48077 L
.44231 .47105 L
.45266 .46154 L
.46154 .45269 L
.47193 .44231 L
.48077 .43469 L
.49689 .42308 L
.5 .42144 L
s
.7 g
.46154 .65226 m
.48077 .64787 L
.5 .64668 L
.51923 .64819 L
.53846 .65201 L
.54541 .65385 L
.55769 .65757 L
.57692 .66457 L
.59615 .6728 L
.59678 .67308 L
.61538 .68216 L
.6242 .69231 L
.6224 .71154 L
.61538 .72474 L
.61116 .73077 L
.59615 .74799 L
.59128 .75 L
.57692 .75903 L
.55769 .76639 L
.5448 .76923 L
.53846 .77019 L
.51923 .77112 L
.50008 .76923 L
.5 .76922 L
.48077 .76453 L
.46154 .75638 L
.45092 .75 L
.44231 .74431 L
.42943 .73077 L
.42308 .72172 L
.41825 .71154 L
.41644 .69231 L
.42308 .67727 L
.42656 .67308 L
.44231 .66004 L
.45681 .65385 L
F
0 g
.46154 .65226 m
.48077 .64787 L
.5 .64668 L
.51923 .64819 L
.53846 .65201 L
.54541 .65385 L
.55769 .65757 L
.57692 .66457 L
.59615 .6728 L
.59678 .67308 L
.61538 .68216 L
.6242 .69231 L
.6224 .71154 L
.61538 .72474 L
.61116 .73077 L
.59615 .74799 L
.59128 .75 L
.57692 .75903 L
.55769 .76639 L
.5448 .76923 L
.53846 .77019 L
.51923 .77112 L
.50008 .76923 L
.5 .76922 L
.48077 .76453 L
.46154 .75638 L
.45092 .75 L
.44231 .74431 L
.42943 .73077 L
.42308 .72172 L
.41825 .71154 L
.41644 .69231 L
.42308 .67727 L
.42656 .67308 L
.44231 .66004 L
.45681 .65385 L
.46154 .65226 L
s
.8 g
.46154 .66628 m
.48077 .65996 L
.5 .65818 L
.51923 .65966 L
.53846 .66419 L
.55769 .67201 L
.55974 .67308 L
.57692 .68092 L
.58586 .69231 L
.59312 .71154 L
.58602 .73077 L
.57692 .74433 L
.56265 .75 L
.55769 .7523 L
.53846 .75809 L
.51923 .75966 L
.5 .7577 L
.48077 .752 L
.47591 .75 L
.46154 .74282 L
.44872 .73077 L
.44231 .72228 L
.43719 .71154 L
.43696 .69231 L
.44231 .68209 L
.45105 .67308 L
F
0 g
.46154 .66628 m
.48077 .65996 L
.5 .65818 L
.51923 .65966 L
.53846 .66419 L
.55769 .67201 L
.55974 .67308 L
.57692 .68092 L
.58586 .69231 L
.59312 .71154 L
.58602 .73077 L
.57692 .74433 L
.56265 .75 L
.55769 .7523 L
.53846 .75809 L
.51923 .75966 L
.5 .7577 L
.48077 .752 L
.47591 .75 L
.46154 .74282 L
.44872 .73077 L
.44231 .72228 L
.43719 .71154 L
.43696 .69231 L
.44231 .68209 L
.45105 .67308 L
.46154 .66628 L
s
.9 g
.5 .67169 m
.51825 .67308 L
.51923 .67326 L
.53846 .67615 L
.55769 .69104 L
.55861 .69231 L
.56835 .71154 L
.56015 .73077 L
.55769 .7343 L
.53846 .74608 L
.51923 .74769 L
.5 .74575 L
.48077 .73827 L
.47063 .73077 L
.46154 .72034 L
.45706 .71154 L
.45871 .69231 L
.46154 .68818 L
.48077 .67531 L
.4891 .67308 L
F
0 g
.5 .67169 m
.51825 .67308 L
.51923 .67326 L
.53846 .67615 L
.55769 .69104 L
.55861 .69231 L
.56835 .71154 L
.56015 .73077 L
.55769 .7343 L
.53846 .74608 L
.51923 .74769 L
.5 .74575 L
.48077 .73827 L
.47063 .73077 L
.46154 .72034 L
.45706 .71154 L
.45871 .69231 L
.46154 .68818 L
.48077 .67531 L
.4891 .67308 L
.5 .67169 L
s
1 g
.5 .69088 m
.51923 .69214 L
.51975 .69231 L
.53837 .71154 L
.51923 .72722 L
.5 .72504 L
.48419 .71154 L
.49488 .69231 L
F
0 g
.5 .69088 m
.51923 .69214 L
.51975 .69231 L
.53837 .71154 L
.51923 .72722 L
.5 .72504 L
.48419 .71154 L
.49488 .69231 L
.5 .69088 L
s
.7 g
.61538 .29316 m
.63462 .29056 L
.65385 .2985 L
.67047 .30769 L
.67308 .31161 L
.68774 .32692 L
.69231 .33197 L
.70124 .34615 L
.71154 .36499 L
.71174 .36538 L
.72405 .38462 L
.73077 .39896 L
.73515 .40385 L
.74854 .42308 L
.75 .42506 L
.76329 .44231 L
.76923 .45803 L
.77078 .46154 L
.77738 .48077 L
.78116 .5 L
.78273 .51923 L
.78238 .53846 L
.78015 .55769 L
.77598 .57692 L
.76966 .59615 L
.76923 .59727 L
.76105 .61538 L
.75 .63292 L
.74897 .63462 L
.73164 .65385 L
.73077 .65458 L
.71154 .66854 L
.70225 .67308 L
.69231 .67673 L
.67308 .67974 L
.65385 .67485 L
.65233 .67308 L
.64899 .65385 L
.65013 .63462 L
.65202 .61538 L
.65385 .59835 L
.6544 .59615 L
.65751 .57692 L
.66163 .55769 L
.66685 .53846 L
.67303 .51923 L
.67308 .51911 L
.67945 .5 L
.68582 .48077 L
.69092 .46154 L
.69231 .45322 L
.69309 .44231 L
.69231 .43228 L
.68967 .42308 L
.67768 .40385 L
.67308 .39957 L
.65526 .38462 L
.65385 .38373 L
.63462 .36745 L
.63242 .36538 L
.61563 .34615 L
.61538 .3456 L
.60485 .32692 L
.60076 .30769 L
F
0 g
.61538 .29316 m
.63462 .29056 L
.65385 .2985 L
.67047 .30769 L
.67308 .31161 L
.68774 .32692 L
.69231 .33197 L
.70124 .34615 L
.71154 .36499 L
.71174 .36538 L
.72405 .38462 L
.73077 .39896 L
.73515 .40385 L
.74854 .42308 L
.75 .42506 L
.76329 .44231 L
.76923 .45803 L
.77078 .46154 L
.77738 .48077 L
.78116 .5 L
.78273 .51923 L
.78238 .53846 L
.78015 .55769 L
.77598 .57692 L
.76966 .59615 L
.76923 .59727 L
.76105 .61538 L
.75 .63292 L
.74897 .63462 L
.73164 .65385 L
.73077 .65458 L
.71154 .66854 L
.70225 .67308 L
.69231 .67673 L
.67308 .67974 L
.65385 .67485 L
.65233 .67308 L
.64899 .65385 L
.65013 .63462 L
.65202 .61538 L
.65385 .59835 L
.6544 .59615 L
.65751 .57692 L
.66163 .55769 L
.66685 .53846 L
.67303 .51923 L
.67308 .51911 L
.67945 .5 L
.68582 .48077 L
.69092 .46154 L
Mistroke
.69231 .45322 L
.69309 .44231 L
.69231 .43228 L
.68967 .42308 L
.67768 .40385 L
.67308 .39957 L
.65526 .38462 L
.65385 .38373 L
.63462 .36745 L
.63242 .36538 L
.61563 .34615 L
.61538 .3456 L
.60485 .32692 L
.60076 .30769 L
.61538 .29316 L
Mfstroke
.8 g
.71154 .46142 m
.73077 .44812 L
.75 .46052 L
.75133 .46154 L
.76597 .48077 L
.76898 .5 L
.76923 .50257 L
.77177 .51923 L
.7722 .53846 L
.77026 .55769 L
.76923 .56513 L
.76627 .57692 L
.7595 .59615 L
.75 .61394 L
.74941 .61538 L
.73435 .63462 L
.73077 .63763 L
.71154 .65075 L
.70233 .65385 L
.69231 .65498 L
.6859 .65385 L
.67308 .64446 L
.66847 .63462 L
.66549 .61538 L
.66572 .59615 L
.66787 .57692 L
.6717 .55769 L
.67308 .55197 L
.67679 .53846 L
.6836 .51923 L
.692 .5 L
.69231 .49939 L
.6984 .48077 L
.7114 .46154 L
F
0 g
.71154 .46142 m
.73077 .44812 L
.75 .46052 L
.75133 .46154 L
.76597 .48077 L
.76898 .5 L
.76923 .50257 L
.77177 .51923 L
.7722 .53846 L
.77026 .55769 L
.76923 .56513 L
.76627 .57692 L
.7595 .59615 L
.75 .61394 L
.74941 .61538 L
.73435 .63462 L
.73077 .63763 L
.71154 .65075 L
.70233 .65385 L
.69231 .65498 L
.6859 .65385 L
.67308 .64446 L
.66847 .63462 L
.66549 .61538 L
.66572 .59615 L
.66787 .57692 L
.6717 .55769 L
.67308 .55197 L
.67679 .53846 L
.6836 .51923 L
.692 .5 L
.69231 .49939 L
.6984 .48077 L
.7114 .46154 L
.71154 .46142 L
s
.9 g
.71154 .49512 m
.73077 .48237 L
.75 .49468 L
.75427 .5 L
.76104 .51923 L
.76214 .53846 L
.76036 .55769 L
.7556 .57692 L
.75 .59149 L
.74737 .59615 L
.73561 .61538 L
.73077 .6194 L
.71154 .63191 L
.69231 .63057 L
.68177 .61538 L
.67665 .59615 L
.67809 .57692 L
.68176 .55769 L
.68797 .53846 L
.69231 .52809 L
.69653 .51923 L
.70589 .5 L
F
0 g
.71154 .49512 m
.73077 .48237 L
.75 .49468 L
.75427 .5 L
.76104 .51923 L
.76214 .53846 L
.76036 .55769 L
.7556 .57692 L
.75 .59149 L
.74737 .59615 L
.73561 .61538 L
.73077 .6194 L
.71154 .63191 L
.69231 .63057 L
.68177 .61538 L
.67665 .59615 L
.67809 .57692 L
.68176 .55769 L
.68797 .53846 L
.69231 .52809 L
.69653 .51923 L
.70589 .5 L
.71154 .49512 L
s
1 g
.73077 .51301 m
.73955 .51923 L
.74663 .53846 L
.74654 .55769 L
.74175 .57692 L
.73113 .59615 L
.73077 .59664 L
.71154 .60987 L
.69526 .59615 L
.69277 .57692 L
.69567 .55769 L
.70268 .53846 L
.71154 .52345 L
.71605 .51923 L
F
0 g
.73077 .51301 m
.73955 .51923 L
.74663 .53846 L
.74654 .55769 L
.74175 .57692 L
.73113 .59615 L
.73077 .59664 L
.71154 .60987 L
.69526 .59615 L
.69277 .57692 L
.69567 .55769 L
.70268 .53846 L
.71154 .52345 L
.71605 .51923 L
.73077 .51301 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57245 .5035 .56654 Mtetra
.5035 .56654 .50935 .57245 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .5601 Mtetra
.663 .741 .908 r
.52489 .5601 .53068 .56605 .54141 .56283 .53564 .55686 Mtetra
.53564 .55686 .54141 .56283 .55218 .5596 .54644 .55361 Mtetra
.54644 .55361 .55218 .5596 .56299 .55636 .55728 .55034 Mtetra
.663 .742 .908 r
.55728 .55034 .56299 .55636 .57385 .5531 .56816 .54707 Mtetra
.56816 .54707 .57385 .5531 .58474 .54984 .57909 .54379 Mtetra
.663 .742 .909 r
.57909 .54379 .58474 .54984 .59568 .54656 .59006 .5405 Mtetra
.59006 .5405 .59568 .54656 .60667 .54327 .60107 .53719 Mtetra
.60107 .53719 .60667 .54327 .61769 .53997 .61213 .53388 Mtetra
.663 .743 .91 r
.61213 .53388 .61769 .53997 .62877 .53665 .62323 .53055 Mtetra
.62323 .53055 .62877 .53665 .63988 .53333 .63437 .52722 Mtetra
.663 .744 .91 r
.63437 .52722 .63988 .53333 .65104 .52999 .64556 .52387 Mtetra
.663 .744 .911 r
.64556 .52387 .65104 .52999 .66224 .52664 .6568 .52051 Mtetra
.663 .745 .911 r
.6568 .52051 .66224 .52664 .67349 .52327 .66808 .51714 Mtetra
.663 .745 .912 r
.66808 .51714 .67349 .52327 .68478 .51989 .6794 .51375 Mtetra
.663 .746 .912 r
.6794 .51375 .68478 .51989 .69612 .5165 .69078 .51034 Mtetra
.69078 .51034 .69612 .5165 .70751 .51309 .70219 .50691 Mtetra
.663 .747 .912 r
.70219 .50691 .70751 .51309 .71894 .50966 .71365 .50346 Mtetra
.71365 .50346 .71894 .50966 .73041 .50622 .72516 .49999 Mtetra
.664 .747 .912 r
.72516 .49999 .73041 .50622 .74193 .50276 .73672 .49649 Mtetra
.664 .746 .912 r
.73672 .49649 .74193 .50276 .7535 .49929 .74832 .49298 Mtetra
.664 .746 .911 r
.74832 .49298 .7535 .49929 .76512 .49579 .75996 .48944 Mtetra
.75996 .48944 .76512 .49579 .77678 .49228 .77166 .48589 Mtetra
.665 .745 .91 r
.77166 .48589 .77678 .49228 .78849 .48876 .7834 .48231 Mtetra
.664 .744 .91 r
.7834 .48231 .78849 .48876 .80024 .48522 .79519 .47873 Mtetra
.664 .744 .909 r
.79519 .47873 .80024 .48522 .81205 .48166 .80703 .47513 Mtetra
.664 .743 .909 r
.80703 .47513 .81205 .48166 .8239 .4781 .81891 .47152 Mtetra
.664 .742 .908 r
.81891 .47152 .8239 .4781 .8358 .47452 .83085 .46791 Mtetra
.83085 .46791 .8358 .47452 .84775 .47093 .84284 .46428 Mtetra
.84284 .46428 .84775 .47093 .85976 .46733 .85487 .46065 Mtetra
.85487 .46065 .85976 .46733 .87181 .46371 .86696 .457 Mtetra
.664 .741 .908 r
.86696 .457 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44967 Mtetra
.89128 .44967 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57343 Mtetra
.45523 .57343 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.663 .741 .908 r
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55736 Mtetra
.50831 .55736 .51417 .56332 .52489 .5601 .51905 .55411 Mtetra
.51905 .55411 .52489 .5601 .53564 .55686 .52983 .55085 Mtetra
.52983 .55085 .53564 .55686 .54644 .55361 .54066 .54758 Mtetra
.663 .742 .909 r
.54066 .54758 .54644 .55361 .55728 .55034 .55153 .54431 Mtetra
.55153 .54431 .55728 .55034 .56816 .54707 .56244 .54102 Mtetra
.56244 .54102 .56816 .54707 .57909 .54379 .5734 .53773 Mtetra
.662 .743 .91 r
.5734 .53773 .57909 .54379 .59006 .5405 .58439 .53444 Mtetra
.662 .743 .911 r
.58439 .53444 .59006 .5405 .60107 .53719 .59544 .53114 Mtetra
.662 .744 .911 r
.59544 .53114 .60107 .53719 .61213 .53388 .60652 .52783 Mtetra
.661 .745 .912 r
.60652 .52783 .61213 .53388 .62323 .53055 .61766 .52451 Mtetra
.661 .746 .913 r
.61766 .52451 .62323 .53055 .63437 .52722 .62883 .52119 Mtetra
.661 .748 .914 r
.62883 .52119 .63437 .52722 .64556 .52387 .64006 .51787 Mtetra
.661 .749 .916 r
.64006 .51787 .64556 .52387 .6568 .52051 .65132 .51453 Mtetra
.661 .751 .917 r
.65132 .51453 .6568 .52051 .66808 .51714 .66264 .51117 Mtetra
.661 .752 .918 r
.66264 .51117 .66808 .51714 .6794 .51375 .674 .50779 Mtetra
.662 .753 .918 r
.674 .50779 .6794 .51375 .69078 .51034 .6854 .50438 Mtetra
.662 .754 .919 r
.6854 .50438 .69078 .51034 .70219 .50691 .69685 .50093 Mtetra
.663 .755 .919 r
.69685 .50093 .70219 .50691 .71365 .50346 .70835 .49745 Mtetra
.663 .755 .918 r
.70835 .49745 .71365 .50346 .72516 .49999 .71989 .49394 Mtetra
.664 .755 .918 r
.71989 .49394 .72516 .49999 .73672 .49649 .73147 .49039 Mtetra
.665 .754 .917 r
.73147 .49039 .73672 .49649 .74832 .49298 .74311 .48682 Mtetra
.665 .753 .916 r
.74311 .48682 .74832 .49298 .75996 .48944 .75478 .48321 Mtetra
.666 .752 .914 r
.75478 .48321 .75996 .48944 .77166 .48589 .76651 .47958 Mtetra
.666 .75 .913 r
.76651 .47958 .77166 .48589 .7834 .48231 .77828 .47593 Mtetra
.666 .748 .912 r
.77828 .47593 .7834 .48231 .79519 .47873 .7901 .47227 Mtetra
.666 .747 .911 r
.7901 .47227 .79519 .47873 .80703 .47513 .80197 .4686 Mtetra
.665 .745 .91 r
.80197 .4686 .80703 .47513 .81891 .47152 .81389 .46494 Mtetra
.665 .744 .909 r
.81389 .46494 .81891 .47152 .83085 .46791 .82586 .46127 Mtetra
.664 .743 .909 r
.82586 .46127 .83085 .46791 .84284 .46428 .83788 .4576 Mtetra
.664 .742 .908 r
.83788 .4576 .84284 .46428 .85487 .46065 .84995 .45393 Mtetra
.84995 .45393 .85487 .46065 .86696 .457 .86207 .45024 Mtetra
.86207 .45024 .86696 .457 .87909 .45334 .87425 .44655 Mtetra
.664 .741 .908 r
.87425 .44655 .87909 .45334 .89128 .44967 .88647 .44285 Mtetra
.88647 .44285 .89128 .44967 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57343 .44919 .56753 Mtetra
.44919 .56753 .45523 .57343 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.663 .741 .908 r
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55736 .5024 .55135 Mtetra
.5024 .55135 .50831 .55736 .51905 .55411 .51317 .54808 Mtetra
.663 .742 .908 r
.51317 .54808 .51905 .55411 .52983 .55085 .52398 .54481 Mtetra
.663 .742 .909 r
.52398 .54481 .52983 .55085 .54066 .54758 .53484 .54154 Mtetra
.662 .742 .91 r
.53484 .54154 .54066 .54758 .55153 .54431 .54573 .53826 Mtetra
.662 .743 .91 r
.54573 .53826 .55153 .54431 .56244 .54102 .55668 .53499 Mtetra
.661 .744 .912 r
.55668 .53499 .56244 .54102 .5734 .53773 .56766 .53172 Mtetra
.66 .745 .913 r
.56766 .53172 .5734 .53773 .58439 .53444 .57869 .52845 Mtetra
.66 .747 .914 r
.57869 .52845 .58439 .53444 .59544 .53114 .58976 .52519 Mtetra
.659 .749 .916 r
.58976 .52519 .59544 .53114 .60652 .52783 .60088 .52193 Mtetra
.658 .751 .919 r
.60088 .52193 .60652 .52783 .61766 .52451 .61205 .51868 Mtetra
.657 .754 .921 r
.61205 .51868 .61766 .52451 .62883 .52119 .62326 .51543 Mtetra
.656 .757 .924 r
.62326 .51543 .62883 .52119 .64006 .51787 .63452 .51219 Mtetra
.656 .76 .927 r
.63452 .51219 .64006 .51787 .65132 .51453 .64582 .50893 Mtetra
.656 .764 .929 r
.64582 .50893 .65132 .51453 .66264 .51117 .65717 .50563 Mtetra
.657 .768 .931 r
.65717 .50563 .66264 .51117 .674 .50779 .66857 .5023 Mtetra
.658 .771 .932 r
.66857 .5023 .674 .50779 .6854 .50438 .68001 .4989 Mtetra
.66 .773 .933 r
.68001 .4989 .6854 .50438 .69685 .50093 .69149 .49544 Mtetra
.662 .774 .932 r
.69149 .49544 .69685 .50093 .70835 .49745 .70302 .49192 Mtetra
.663 .774 .931 r
.70302 .49192 .70835 .49745 .71989 .49394 .7146 .48833 Mtetra
.665 .772 .93 r
.7146 .48833 .71989 .49394 .73147 .49039 .72622 .48469 Mtetra
.667 .77 .927 r
.72622 .48469 .73147 .49039 .74311 .48682 .73788 .481 Mtetra
.668 .768 .925 r
.73788 .481 .74311 .48682 .75478 .48321 .74959 .47727 Mtetra
.669 .764 .922 r
.74959 .47727 .75478 .48321 .76651 .47958 .76134 .4735 Mtetra
.669 .761 .919 r
.76134 .4735 .76651 .47958 .77828 .47593 .77314 .46972 Mtetra
.669 .757 .916 r
.77314 .46972 .77828 .47593 .7901 .47227 .78499 .46593 Mtetra
.668 .753 .914 r
.78499 .46593 .7901 .47227 .80197 .4686 .79689 .46215 Mtetra
.667 .75 .912 r
.79689 .46215 .80197 .4686 .81389 .46494 .80884 .45838 Mtetra
.666 .747 .911 r
.80884 .45838 .81389 .46494 .82586 .46127 .82084 .45463 Mtetra
.666 .745 .91 r
.82084 .45463 .82586 .46127 .83788 .4576 .83289 .45089 Mtetra
.665 .744 .909 r
.83289 .45089 .83788 .4576 .84995 .45393 .84499 .44717 Mtetra
.664 .743 .908 r
.84499 .44717 .84995 .45393 .86207 .45024 .85715 .44344 Mtetra
.664 .742 .908 r
.85715 .44344 .86207 .45024 .87425 .44655 .86936 .43971 Mtetra
.86936 .43971 .87425 .44655 .88647 .44285 .88162 .43598 Mtetra
.664 .741 .908 r
.88162 .43598 .88647 .44285 .89874 .43913 .89393 .43223 Mtetra
.89393 .43223 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.663 .741 .908 r
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55185 Mtetra
.47499 .55185 .48099 .55785 .49168 .5546 .4857 .54858 Mtetra
.4857 .54858 .49168 .5546 .5024 .55135 .49646 .54531 Mtetra
.663 .742 .909 r
.49646 .54531 .5024 .55135 .51317 .54808 .50725 .54203 Mtetra
.662 .742 .909 r
.50725 .54203 .51317 .54808 .52398 .54481 .51809 .53877 Mtetra
.661 .743 .91 r
.51809 .53877 .52398 .54481 .53484 .54154 .52897 .53551 Mtetra
.66 .744 .912 r
.52897 .53551 .53484 .54154 .54573 .53826 .5399 .53227 Mtetra
.659 .745 .914 r
.5399 .53227 .54573 .53826 .55668 .53499 .55087 .52905 Mtetra
.657 .747 .916 r
.55087 .52905 .55668 .53499 .56766 .53172 .56188 .52585 Mtetra
.656 .75 .919 r
.56188 .52585 .56766 .53172 .57869 .52845 .57294 .52267 Mtetra
.654 .754 .923 r
.57294 .52267 .57869 .52845 .58976 .52519 .58405 .51952 Mtetra
.652 .758 .927 r
.58405 .51952 .58976 .52519 .60088 .52193 .59521 .51641 Mtetra
.649 .763 .932 r
.59521 .51641 .60088 .52193 .61205 .51868 .60641 .51333 Mtetra
.646 .769 .938 r
.60641 .51333 .61205 .51868 .62326 .51543 .61766 .51028 Mtetra
.644 .777 .944 r
.61766 .51028 .62326 .51543 .63452 .51219 .62896 .50723 Mtetra
.642 .785 .95 r
.62896 .50723 .63452 .51219 .64582 .50893 .6403 .50417 Mtetra
.642 .793 .955 r
.6403 .50417 .64582 .50893 .65717 .50563 .6517 .50104 Mtetra
.643 .801 .959 r
.6517 .50104 .65717 .50563 .66857 .5023 .66314 .49781 Mtetra
.647 .808 .961 r
.66314 .49781 .66857 .5023 .68001 .4989 .67462 .49446 Mtetra
.651 .812 .961 r
.67462 .49446 .68001 .4989 .69149 .49544 .68615 .49098 Mtetra
.656 .814 .959 r
.68615 .49098 .69149 .49544 .70302 .49192 .69771 .48737 Mtetra
.661 .813 .956 r
.69771 .48737 .70302 .49192 .7146 .48833 .70932 .48364 Mtetra
.666 .809 .952 r
.70932 .48364 .7146 .48833 .72622 .48469 .72097 .47981 Mtetra
.67 .804 .947 r
.72097 .47981 .72622 .48469 .73788 .481 .73266 .4759 Mtetra
.673 .797 .941 r
.73266 .4759 .73788 .481 .74959 .47727 .74439 .47193 Mtetra
.675 .79 .936 r
.74439 .47193 .74959 .47727 .76134 .4735 .75617 .46791 Mtetra
.675 .782 .93 r
.75617 .46791 .76134 .4735 .77314 .46972 .76799 .46388 Mtetra
.675 .774 .924 r
.76799 .46388 .77314 .46972 .78499 .46593 .77986 .45985 Mtetra
.674 .766 .92 r
.77986 .45985 .78499 .46593 .79689 .46215 .79178 .45586 Mtetra
.672 .759 .916 r
.79178 .45586 .79689 .46215 .80884 .45838 .80376 .45192 Mtetra
.67 .753 .913 r
.80376 .45192 .80884 .45838 .82084 .45463 .81578 .44803 Mtetra
.668 .749 .911 r
.81578 .44803 .82084 .45463 .83289 .45089 .82787 .44419 Mtetra
.666 .746 .91 r
.82787 .44419 .83289 .45089 .84499 .44717 .84 .44039 Mtetra
.665 .744 .909 r
.84 .44039 .84499 .44717 .85715 .44344 .85219 .43661 Mtetra
.664 .743 .908 r
.85219 .43661 .85715 .44344 .86936 .43971 .86444 .43283 Mtetra
.664 .742 .908 r
.86444 .43283 .86936 .43971 .88162 .43598 .87673 .42906 Mtetra
.87673 .42906 .88162 .43598 .89393 .43223 .88908 .42527 Mtetra
.664 .741 .908 r
.88908 .42527 .89393 .43223 .9063 .42846 .90149 .42148 Mtetra
.90149 .42148 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.663 .741 .908 r
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55235 Mtetra
.4476 .55235 .45369 .55835 .46432 .5551 .45825 .54908 Mtetra
.45825 .54908 .46432 .5551 .47499 .55185 .46895 .5458 Mtetra
.46895 .5458 .47499 .55185 .4857 .54858 .47968 .54252 Mtetra
.662 .742 .909 r
.47968 .54252 .4857 .54858 .49646 .54531 .49046 .53924 Mtetra
.661 .742 .91 r
.49046 .53924 .49646 .54531 .50725 .54203 .50129 .53598 Mtetra
.66 .743 .911 r
.50129 .53598 .50725 .54203 .51809 .53877 .51215 .53275 Mtetra
.658 .744 .914 r
.51215 .53275 .51809 .53877 .52897 .53551 .52306 .52957 Mtetra
.655 .747 .917 r
.52306 .52957 .52897 .53551 .5399 .53227 .53402 .52643 Mtetra
.652 .75 .921 r
.53402 .52643 .5399 .53227 .55087 .52905 .54502 .52335 Mtetra
.649 .755 .926 r
.54502 .52335 .55087 .52905 .56188 .52585 .55607 .52032 Mtetra
.645 .76 .933 r
.55607 .52032 .56188 .52585 .57294 .52267 .56716 .51735 Mtetra
.64 .767 .94 r
.56716 .51735 .57294 .52267 .58405 .51952 .57831 .51446 Mtetra
.633 .776 .949 r
.57831 .51446 .58405 .51952 .59521 .51641 .5895 .51166 Mtetra
.624 .787 .96 r
.5895 .51166 .59521 .51641 .60641 .51333 .60075 .50895 Mtetra
.614 .799 .971 r
.60075 .50895 .60641 .51333 .61766 .51028 .61205 .50632 Mtetra
.603 .814 .981 r
.61205 .50632 .61766 .51028 .62896 .50723 .6234 .5037 Mtetra
.593 .83 .989 r
.6234 .5037 .62896 .50723 .6403 .50417 .6348 .50104 Mtetra
.587 .845 .994 r
.6348 .50104 .6403 .50417 .6517 .50104 .64625 .49823 Mtetra
.586 .86 .995 r
.64625 .49823 .6517 .50104 .66314 .49781 .65774 .49523 Mtetra
.592 .871 .994 r
.65774 .49523 .66314 .49781 .67462 .49446 .66927 .49196 Mtetra
.604 .88 .992 r
.66927 .49196 .67462 .49446 .68615 .49098 .68084 .48842 Mtetra
.621 .884 .989 r
.68084 .48842 .68615 .49098 .69771 .48737 .69245 .48462 Mtetra
.638 .883 .986 r
.69245 .48462 .69771 .48737 .70932 .48364 .70409 .4806 Mtetra
.655 .876 .981 r
.70409 .4806 .70932 .48364 .72097 .47981 .71576 .47641 Mtetra
.668 .866 .974 r
.71576 .47641 .72097 .47981 .73266 .4759 .72748 .47208 Mtetra
.678 .852 .966 r
.72748 .47208 .73266 .4759 .74439 .47193 .73923 .46766 Mtetra
.684 .836 .957 r
.73923 .46766 .74439 .47193 .75617 .46791 .75102 .46319 Mtetra
.687 .82 .947 r
.75102 .46319 .75617 .46791 .76799 .46388 .76285 .4587 Mtetra
.686 .804 .937 r
.76285 .4587 .76799 .46388 .77986 .45985 .77473 .45426 Mtetra
.684 .789 .929 r
.77473 .45426 .77986 .45985 .79178 .45586 .78667 .44991 Mtetra
.68 .775 .922 r
.78667 .44991 .79178 .45586 .80376 .45192 .79866 .44566 Mtetra
.676 .764 .917 r
.79866 .44566 .80376 .45192 .81578 .44803 .8107 .44154 Mtetra
.672 .756 .914 r
.8107 .44154 .81578 .44803 .82787 .44419 .82281 .43753 Mtetra
.669 .75 .911 r
.82281 .43753 .82787 .44419 .84 .44039 .83498 .43361 Mtetra
.667 .746 .91 r
.83498 .43361 .84 .44039 .85219 .43661 .8472 .42974 Mtetra
.665 .744 .909 r
.8472 .42974 .85219 .43661 .86444 .43283 .85948 .42591 Mtetra
.665 .743 .908 r
.85948 .42591 .86444 .43283 .87673 .42906 .87181 .42209 Mtetra
.664 .742 .908 r
.87181 .42209 .87673 .42906 .88908 .42527 .8842 .41827 Mtetra
.8842 .41827 .88908 .42527 .90149 .42148 .89664 .41444 Mtetra
.664 .741 .908 r
.89664 .41444 .90149 .42148 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55285 Mtetra
.663 .741 .908 r
.42022 .55285 .42641 .55885 .43698 .5556 .43081 .54958 Mtetra
.43081 .54958 .43698 .5556 .4476 .55235 .44145 .5463 Mtetra
.44145 .5463 .4476 .55235 .45825 .54908 .45213 .54301 Mtetra
.45213 .54301 .45825 .54908 .46895 .5458 .46285 .53972 Mtetra
.662 .742 .909 r
.46285 .53972 .46895 .5458 .47968 .54252 .47362 .53644 Mtetra
.661 .742 .91 r
.47362 .53644 .47968 .54252 .49046 .53924 .48443 .53319 Mtetra
.658 .743 .912 r
.48443 .53319 .49046 .53924 .50129 .53598 .49528 .52999 Mtetra
.655 .745 .916 r
.49528 .52999 .50129 .53598 .51215 .53275 .50617 .52686 Mtetra
.65 .748 .921 r
.50617 .52686 .51215 .53275 .52306 .52957 .51711 .52384 Mtetra
.645 .752 .927 r
.51711 .52384 .52306 .52957 .53402 .52643 .5281 .52092 Mtetra
.638 .759 .936 r
.5281 .52092 .53402 .52643 .54502 .52335 .53913 .51812 Mtetra
.63 .768 .946 r
.53913 .51812 .54502 .52335 .55607 .52032 .55021 .51544 Mtetra
.62 .779 .957 r
.55021 .51544 .55607 .52032 .56716 .51735 .56134 .51289 Mtetra
.604 .791 .971 r
.56134 .51289 .56716 .51735 .57831 .51446 .57253 .5105 Mtetra
.58 .805 .985 r
.57253 .5105 .57831 .51446 .5895 .51166 .58377 .50831 Mtetra
.544 .819 .997 r
.58377 .50831 .5895 .51166 .60075 .50895 .59507 .50632 Mtetra
.495 .83 .999 r
.59507 .50632 .60075 .50895 .61205 .50632 .60643 .50447 Mtetra
.433 .831 .981 r
.60643 .50447 .61205 .50632 .6234 .5037 .61785 .50265 Mtetra
.367 .819 .938 r
.61785 .50265 .6234 .5037 .6348 .50104 .62933 .50071 Mtetra
.313 .8 .88 r
.62933 .50071 .6348 .50104 .64625 .49823 .64085 .49849 Mtetra
.287 .787 .828 r
.64085 .49849 .64625 .49823 .65774 .49523 .65241 .49584 Mtetra
.295 .792 .802 r
.65241 .49584 .65774 .49523 .66927 .49196 .66401 .49269 Mtetra
.337 .818 .807 r
.66401 .49269 .66927 .49196 .68084 .48842 .67563 .489 Mtetra
.404 .858 .839 r
.67563 .489 .68084 .48842 .69245 .48462 .68728 .48482 Mtetra
.482 .899 .884 r
.68728 .48482 .69245 .48462 .70409 .4806 .69895 .48024 Mtetra
.557 .928 .927 r
.69895 .48024 .70409 .4806 .71576 .47641 .71064 .47536 Mtetra
.619 .937 .958 r
.71064 .47536 .71576 .47641 .72748 .47208 .72237 .47029 Mtetra
.662 .929 .972 r
.72237 .47029 .72748 .47208 .73923 .46766 .73412 .46509 Mtetra
.688 .909 .972 r
.73412 .46509 .73923 .46766 .75102 .46319 .74592 .45985 Mtetra
.701 .882 .965 r
.74592 .45985 .75102 .46319 .76285 .4587 .75775 .45462 Mtetra
.705 .853 .953 r
.75775 .45462 .76285 .4587 .77473 .45426 .76962 .44948 Mtetra
.702 .826 .942 r
.76962 .44948 .77473 .45426 .78667 .44991 .78156 .44452 Mtetra
.695 .802 .931 r
.78156 .44452 .78667 .44991 .79866 .44566 .79355 .43977 Mtetra
.687 .782 .923 r
.79355 .43977 .79866 .44566 .8107 .44154 .80561 .43527 Mtetra
.68 .768 .917 r
.80561 .43527 .8107 .44154 .82281 .43753 .81773 .43098 Mtetra
.674 .757 .913 r
.81773 .43098 .82281 .43753 .83498 .43361 .82992 .42686 Mtetra
.67 .75 .911 r
.82992 .42686 .83498 .43361 .8472 .42974 .84217 .42287 Mtetra
.667 .746 .909 r
.84217 .42287 .8472 .42974 .85948 .42591 .85448 .41896 Mtetra
.665 .744 .909 r
.85448 .41896 .85948 .42591 .87181 .42209 .86685 .41508 Mtetra
.664 .742 .908 r
.86685 .41508 .87181 .42209 .8842 .41827 .87927 .41121 Mtetra
.87927 .41121 .8842 .41827 .89664 .41444 .89175 .40735 Mtetra
.89175 .40735 .89664 .41444 .90913 .4106 .90428 .40347 Mtetra
.664 .741 .908 r
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39959 Mtetra
.91687 .39959 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55285 .41397 .5468 Mtetra
.663 .741 .908 r
.41397 .5468 .42022 .55285 .43081 .54958 .4246 .54351 Mtetra
.4246 .54351 .43081 .54958 .44145 .5463 .43526 .54021 Mtetra
.43526 .54021 .44145 .5463 .45213 .54301 .44597 .53691 Mtetra
.662 .741 .909 r
.44597 .53691 .45213 .54301 .46285 .53972 .45672 .53362 Mtetra
.66 .742 .91 r
.45672 .53362 .46285 .53972 .47362 .53644 .46751 .53037 Mtetra
.657 .743 .913 r
.46751 .53037 .47362 .53644 .48443 .53319 .47834 .52719 Mtetra
.652 .744 .917 r
.47834 .52719 .48443 .53319 .49528 .52999 .48922 .52412 Mtetra
.645 .748 .924 r
.48922 .52412 .49528 .52999 .50617 .52686 .50014 .52123 Mtetra
.635 .754 .934 r
.50014 .52123 .50617 .52686 .51711 .52384 .51111 .51853 Mtetra
.623 .763 .946 r
.51111 .51853 .51711 .52384 .5281 .52092 .52213 .51604 Mtetra
.607 .775 .961 r
.52213 .51604 .5281 .52092 .53913 .51812 .53319 .51375 Mtetra
.585 .789 .977 r
.53319 .51375 .53913 .51812 .55021 .51544 .54431 .51167 Mtetra
.55 .803 .992 r
.54431 .51167 .55021 .51544 .56134 .51289 .55549 .50985 Mtetra
.492 .811 1 r
.55549 .50985 .56134 .51289 .57253 .5105 .56673 .50835 Mtetra
.393 .8 .982 r
.56673 .50835 .57253 .5105 .58377 .50831 .57803 .50722 Mtetra
.239 .741 .899 r
.57803 .50722 .58377 .50831 .59507 .50632 .5894 .50645 Mtetra
.048 .616 .726 r
.5894 .50645 .59507 .50632 .60643 .50447 .60084 .50593 Mtetra
.115 0 0 r
.60084 .50593 .60643 .50447 .61785 .50265 .61235 .50544 Mtetra
.213 0 0 r
.61235 .50544 .61785 .50265 .62933 .50071 .62392 .50469 Mtetra
.252 0 0 r
.62392 .50469 .62933 .50071 .64085 .49849 .63554 .50338 Mtetra
.248 0 0 r
.63554 .50338 .64085 .49849 .65241 .49584 .6472 .50126 Mtetra
.213 0 0 r
.6472 .50126 .65241 .49584 .66401 .49269 .65887 .49818 Mtetra
.15 0 0 r
.65887 .49818 .66401 .49269 .67563 .489 .67056 .49415 Mtetra
.059 0 0 r
.67056 .49415 .67563 .489 .68728 .48482 .68225 .48925 Mtetra
0 0 0 r
.68225 .48925 .68728 .48482 .69895 .48024 .69394 .48369 Mtetra
.69394 .48369 .69895 .48024 .71064 .47536 .70565 .47767 Mtetra
.382 .82 .674 r
.70565 .47767 .71064 .47536 .72237 .47029 .71737 .47137 Mtetra
.533 .921 .818 r
.71737 .47137 .72237 .47029 .73412 .46509 .72912 .46494 Mtetra
.642 .963 .91 r
.72912 .46494 .73412 .46509 .74592 .45985 .7409 .45849 Mtetra
.702 .955 .951 r
.7409 .45849 .74592 .45985 .75775 .45462 .75271 .4521 Mtetra
.725 .922 .959 r
.75271 .4521 .75775 .45462 .76962 .44948 .76456 .44589 Mtetra
.727 .881 .952 r
.76456 .44589 .76962 .44948 .78156 .44452 .77647 .43998 Mtetra
.718 .843 .941 r
.77647 .43998 .78156 .44452 .79355 .43977 .78845 .43444 Mtetra
.705 .81 .93 r
.78845 .43444 .79355 .43977 .80561 .43527 .8005 .42933 Mtetra
.693 .785 .922 r
.8005 .42933 .80561 .43527 .81773 .43098 .81263 .4246 Mtetra
.682 .768 .916 r
.81263 .4246 .81773 .43098 .82992 .42686 .82483 .42019 Mtetra
.675 .756 .912 r
.82483 .42019 .82992 .42686 .84217 .42287 .83711 .41601 Mtetra
.67 .749 .91 r
.83711 .41601 .84217 .42287 .85448 .41896 .84945 .41198 Mtetra
.667 .745 .909 r
.84945 .41198 .85448 .41896 .86685 .41508 .86185 .40803 Mtetra
.665 .743 .908 r
.86185 .40803 .86685 .41508 .87927 .41121 .87431 .40411 Mtetra
.664 .742 .908 r
.87431 .40411 .87927 .41121 .89175 .40735 .88682 .4002 Mtetra
.88682 .4002 .89175 .40735 .90428 .40347 .89939 .39629 Mtetra
.664 .741 .908 r
.89939 .39629 .90428 .40347 .91687 .39959 .91202 .39237 Mtetra
.91202 .39237 .91687 .39959 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.663 .741 .908 r
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .54351 .41834 .5374 Mtetra
.41834 .5374 .4246 .54351 .43526 .54021 .42903 .53409 Mtetra
.662 .741 .909 r
.42903 .53409 .43526 .54021 .44597 .53691 .43976 .53078 Mtetra
.66 .742 .91 r
.43976 .53078 .44597 .53691 .45672 .53362 .45054 .52752 Mtetra
.657 .742 .913 r
.45054 .52752 .45672 .53362 .46751 .53037 .46135 .52434 Mtetra
.65 .744 .918 r
.46135 .52434 .46751 .53037 .47834 .52719 .47221 .52133 Mtetra
.64 .747 .927 r
.47221 .52133 .47834 .52719 .48922 .52412 .48311 .51855 Mtetra
.624 .753 .939 r
.48311 .51855 .48922 .52412 .50014 .52123 .49406 .51608 Mtetra
.602 .763 .956 r
.49406 .51608 .50014 .52123 .51111 .51853 .50506 .51397 Mtetra
.571 .777 .976 r
.50506 .51397 .51111 .51853 .52213 .51604 .5161 .5122 Mtetra
.527 .791 .993 r
.5161 .5122 .52213 .51604 .53319 .51375 .5272 .51074 Mtetra
.457 .797 .999 r
.5272 .51074 .53319 .51375 .54431 .51167 .53837 .50963 Mtetra
.336 .773 .967 r
.53837 .50963 .54431 .51167 .55549 .50985 .54959 .50893 Mtetra
.136 .675 .844 r
.54959 .50893 .55549 .50985 .56673 .50835 .56089 .50879 Mtetra
.117 0 0 r
.56089 .50879 .56673 .50835 .57803 .50722 .57227 .50931 Mtetra
.324 0 0 r
.57227 .50931 .57803 .50722 .5894 .50645 .58373 .51044 Mtetra
.439 0 0 r
.58373 .51044 .5894 .50645 .60084 .50593 .59528 .51197 Mtetra
.485 .015 .063 r
.59528 .51197 .60084 .50593 .61235 .50544 .60691 .51348 Mtetra
.493 .061 .147 r
.60691 .51348 .61235 .50544 .62392 .50469 .61861 .51448 Mtetra
.479 .073 .191 r
.61861 .51448 .62392 .50469 .63554 .50338 .63035 .51444 Mtetra
.45 .061 .209 r
.63035 .51444 .63554 .50338 .6472 .50126 .64212 .51297 Mtetra
.407 .029 .205 r
.64212 .51297 .6472 .50126 .65887 .49818 .65389 .50987 Mtetra
.352 0 .18 r
.65389 .50987 .65887 .49818 .67056 .49415 .66565 .50515 Mtetra
.283 0 .132 r
.66565 .50515 .67056 .49415 .68225 .48925 .67739 .49904 Mtetra
.194 0 .055 r
.67739 .49904 .68225 .48925 .69394 .48369 .6891 .4919 Mtetra
.079 0 0 r
.6891 .4919 .69394 .48369 .70565 .47767 .70081 .48412 Mtetra
0 0 0 r
.70081 .48412 .70565 .47767 .71737 .47137 .71252 .47602 Mtetra
.71252 .47602 .71737 .47137 .72912 .46494 .72424 .46781 Mtetra
.466 .853 .645 r
.72424 .46781 .72912 .46494 .7409 .45849 .73598 .45964 Mtetra
.633 .961 .818 r
.73598 .45964 .7409 .45849 .75271 .4521 .74775 .45161 Mtetra
.725 .981 .911 r
.74775 .45161 .75271 .4521 .76456 .44589 .75956 .44388 Mtetra
.755 .947 .942 r
.75956 .44388 .76456 .44589 .77647 .43998 .77143 .4366 Mtetra
.75 .897 .944 r
.77143 .4366 .77647 .43998 .78845 .43444 .78337 .42991 Mtetra
.733 .849 .936 r
.78337 .42991 .78845 .43444 .8005 .42933 .7954 .42389 Mtetra
.712 .811 .926 r
.7954 .42389 .8005 .42933 .81263 .4246 .80752 .4185 Mtetra
.695 .783 .919 r
.80752 .4185 .81263 .4246 .82483 .42019 .81972 .41365 Mtetra
.682 .765 .914 r
.81972 .41365 .82483 .42019 .83711 .41601 .83201 .40919 Mtetra
.674 .754 .911 r
.83201 .40919 .83711 .41601 .84945 .41198 .84438 .40499 Mtetra
.669 .747 .909 r
.84438 .40499 .84945 .41198 .86185 .40803 .85681 .40094 Mtetra
.666 .744 .908 r
.85681 .40094 .86185 .40803 .87431 .40411 .86931 .39695 Mtetra
.665 .743 .908 r
.86931 .39695 .87431 .40411 .88682 .4002 .88186 .393 Mtetra
.664 .742 .908 r
.88186 .393 .88682 .4002 .89939 .39629 .89447 .38906 Mtetra
.89447 .38906 .89939 .39629 .91202 .39237 .90713 .3851 Mtetra
.664 .741 .908 r
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37716 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.663 .741 .908 r
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53458 Mtetra
.40135 .53458 .40769 .54071 .41834 .5374 .41203 .53125 Mtetra
.662 .741 .909 r
.41203 .53125 .41834 .5374 .42903 .53409 .42275 .52793 Mtetra
.661 .741 .91 r
.42275 .52793 .42903 .53409 .43976 .53078 .43351 .52465 Mtetra
.657 .742 .913 r
.43351 .52465 .43976 .53078 .45054 .52752 .44431 .52146 Mtetra
.649 .743 .918 r
.44431 .52146 .45054 .52752 .46135 .52434 .45515 .51845 Mtetra
.636 .745 .927 r
.45515 .51845 .46135 .52434 .47221 .52133 .46603 .51575 Mtetra
.614 .751 .943 r
.46603 .51575 .47221 .52133 .48311 .51855 .47695 .51349 Mtetra
.579 .76 .964 r
.47695 .51349 .48311 .51855 .49406 .51608 .48792 .51177 Mtetra
.524 .77 .987 r
.48792 .51177 .49406 .51608 .50506 .51397 .49894 .5106 Mtetra
.439 .775 .997 r
.49894 .5106 .50506 .51397 .5161 .5122 .51002 .50992 Mtetra
.305 .748 .963 r
.51002 .50992 .5161 .5122 .5272 .51074 .52116 .50968 Mtetra
.106 .651 .836 r
.52116 .50968 .5272 .51074 .53837 .50963 .53237 .5099 Mtetra
.14 0 0 r
.53237 .5099 .53837 .50963 .54959 .50893 .54365 .51076 Mtetra
.359 0 0 r
.54365 .51076 .54959 .50893 .56089 .50879 .55502 .51252 Mtetra
.498 0 0 r
.55502 .51252 .56089 .50879 .57227 .50931 .56648 .51532 Mtetra
.567 .106 .119 r
.56648 .51532 .57227 .50931 .58373 .51044 .57805 .5191 Mtetra
.591 .175 .222 r
.57805 .5191 .58373 .51044 .59528 .51197 .58973 .52345 Mtetra
.591 .207 .284 r
.58973 .52345 .59528 .51197 .60691 .51348 .60151 .52769 Mtetra
.574 .214 .32 r
.60151 .52769 .60691 .51348 .61861 .51448 .61337 .53099 Mtetra
.547 .204 .338 r
.61337 .53099 .61861 .51448 .63035 .51444 .62527 .53255 Mtetra
.511 .179 .341 r
.62527 .53255 .63035 .51444 .64212 .51297 .63718 .53176 Mtetra
.466 .142 .333 r
.63718 .53176 .64212 .51297 .65389 .50987 .64907 .52837 Mtetra
.412 .092 .311 r
.64907 .52837 .65389 .50987 .66565 .50515 .6609 .52247 Mtetra
.349 .029 .274 r
.6609 .52247 .66565 .50515 .67739 .49904 .67268 .5145 Mtetra
.274 0 .22 r
.67268 .5145 .67739 .49904 .6891 .4919 .68441 .50509 Mtetra
.184 0 .142 r
.68441 .50509 .6891 .4919 .70081 .48412 .69611 .49489 Mtetra
.072 0 .032 r
.69611 .49489 .70081 .48412 .71252 .47602 .7078 .48441 Mtetra
0 0 0 r
.7078 .48441 .71252 .47602 .72424 .46781 .71948 .47393 Mtetra
.71948 .47393 .72424 .46781 .73598 .45964 .73118 .4636 Mtetra
.48 .83 .555 r
.73118 .4636 .73598 .45964 .74775 .45161 .7429 .45351 Mtetra
.665 .962 .758 r
.7429 .45351 .74775 .45161 .75956 .44388 .75465 .4438 Mtetra
.763 .993 .878 r
.75465 .4438 .75956 .44388 .77143 .4366 .76645 .43469 Mtetra
.785 .956 .925 r
.76645 .43469 .77143 .4366 .78337 .42991 .77833 .42642 Mtetra
.769 .898 .933 r
.77833 .42642 .78337 .42991 .7954 .42389 .79031 .41912 Mtetra
.741 .845 .929 r
.79031 .41912 .7954 .42389 .80752 .4185 .8024 .41279 Mtetra
.714 .805 .921 r
.8024 .41279 .80752 .4185 .81972 .41365 .81459 .4073 Mtetra
.694 .777 .915 r
.81459 .4073 .81972 .41365 .83201 .40919 .82689 .40244 Mtetra
.68 .76 .912 r
.82689 .40244 .83201 .40919 .84438 .40499 .83928 .398 Mtetra
.672 .751 .91 r
.83928 .398 .84438 .40499 .85681 .40094 .85174 .39381 Mtetra
.668 .746 .909 r
.85174 .39381 .85681 .40094 .86931 .39695 .86427 .38975 Mtetra
.665 .743 .908 r
.86427 .38975 .86931 .39695 .88186 .393 .87686 .38575 Mtetra
.664 .742 .908 r
.87686 .38575 .88186 .393 .89447 .38906 .8895 .38176 Mtetra
.8895 .38176 .89447 .38906 .90713 .3851 .90221 .37778 Mtetra
.664 .741 .908 r
.90221 .37778 .90713 .3851 .91985 .38114 .91497 .37378 Mtetra
.91497 .37378 .91985 .38114 .93263 .37716 .92778 .36976 Mtetra
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.663 .741 .908 r
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53509 Mtetra
.3737 .53509 .38013 .54122 .39072 .5379 .38431 .53175 Mtetra
.38431 .53175 .39072 .5379 .40135 .53458 .39497 .52841 Mtetra
.663 .741 .909 r
.39497 .52841 .40135 .53458 .41203 .53125 .40568 .52507 Mtetra
.661 .741 .909 r
.40568 .52507 .41203 .53125 .42275 .52793 .41642 .52176 Mtetra
.658 .741 .912 r
.41642 .52176 .42275 .52793 .43351 .52465 .4272 .51853 Mtetra
.65 .742 .917 r
.4272 .51853 .43351 .52465 .44431 .52146 .43803 .51549 Mtetra
.636 .744 .926 r
.43803 .51549 .44431 .52146 .45515 .51845 .44889 .5128 Mtetra
.608 .747 .943 r
.44889 .5128 .45515 .51845 .46603 .51575 .45979 .51066 Mtetra
.559 .753 .968 r
.45979 .51066 .46603 .51575 .47695 .51349 .47072 .50928 Mtetra
.472 .755 .992 r
.47072 .50928 .47695 .51349 .48792 .51177 .48171 .50873 Mtetra
.32 .729 .978 r
.48171 .50873 .48792 .51177 .49894 .5106 .49275 .50896 Mtetra
.093 .63 .857 r
.49275 .50896 .49894 .5106 .51002 .50992 .50386 .5098 Mtetra
.151 0 0 r
.50386 .5098 .51002 .50992 .52116 .50968 .51504 .5111 Mtetra
.342 0 0 r
.51504 .5111 .52116 .50968 .53237 .5099 .5263 .51296 Mtetra
.477 0 0 r
.5263 .51296 .53237 .5099 .54365 .51076 .53764 .51569 Mtetra
.567 .086 .072 r
.53764 .51569 .54365 .51076 .55502 .51252 .54909 .51973 Mtetra
.62 .187 .198 r
.54909 .51973 .55502 .51252 .56648 .51532 .56065 .52537 Mtetra
.643 .249 .283 r
.56065 .52537 .56648 .51532 .57805 .5191 .57234 .53243 Mtetra
.645 .28 .337 r
.57234 .53243 .57805 .5191 .58973 .52345 .58417 .54026 Mtetra
.632 .288 .37 r
.58417 .54026 .58973 .52345 .60151 .52769 .59612 .5478 Mtetra
.608 .28 .389 r
.59612 .5478 .60151 .52769 .61337 .53099 .60816 .55379 Mtetra
.574 .259 .397 r
.60816 .55379 .61337 .53099 .62527 .53255 .62024 .55707 Mtetra
.532 .226 .394 r
.62024 .55707 .62527 .53255 .63718 .53176 .63231 .55682 Mtetra
.481 .183 .383 r
.63231 .55682 .63718 .53176 .64907 .52837 .64432 .55272 Mtetra
.421 .129 .36 r
.64432 .55272 .64907 .52837 .6609 .52247 .65624 .54504 Mtetra
.353 .063 .326 r
.65624 .54504 .6609 .52247 .67268 .5145 .66806 .53454 Mtetra
.277 0 .277 r
.66806 .53454 .67268 .5145 .68441 .50509 .6798 .52224 Mtetra
.193 0 .211 r
.6798 .52224 .68441 .50509 .69611 .49489 .69149 .50912 Mtetra
.098 0 .125 r
.69149 .50912 .69611 .49489 .7078 .48441 .70315 .49591 Mtetra
0 0 .012 r
.70315 .49591 .7078 .48441 .71948 .47393 .71481 .48293 Mtetra
0 0 0 r
.71481 .48293 .71948 .47393 .73118 .4636 .72648 .47026 Mtetra
.72648 .47026 .73118 .4636 .7429 .45351 .73814 .45787 Mtetra
.559 .858 .545 r
.73814 .45787 .7429 .45351 .75465 .4438 .74983 .44587 Mtetra
.728 .976 .741 r
.74983 .44587 .75465 .4438 .76645 .43469 .76155 .43455 Mtetra
.806 .996 .862 r
.76155 .43455 .76645 .43469 .77833 .42642 .77334 .42425 Mtetra
.809 .95 .913 r
.77334 .42425 .77833 .42642 .79031 .41912 .78525 .41525 Mtetra
.777 .888 .924 r
.78525 .41525 .79031 .41912 .8024 .41279 .79728 .40763 Mtetra
.74 .833 .922 r
.79728 .40763 .8024 .41279 .81459 .4073 .80945 .40124 Mtetra
.71 .794 .917 r
.80945 .40124 .81459 .4073 .82689 .40244 .82174 .39581 Mtetra
.689 .769 .913 r
.82174 .39581 .82689 .40244 .83928 .398 .83414 .39104 Mtetra
.677 .755 .91 r
.83414 .39104 .83928 .398 .85174 .39381 .84663 .38667 Mtetra
.67 .748 .909 r
.84663 .38667 .85174 .39381 .86427 .38975 .85919 .38251 Mtetra
.666 .744 .908 r
.85919 .38251 .86427 .38975 .87686 .38575 .87181 .37844 Mtetra
.665 .742 .908 r
.87181 .37844 .87686 .38575 .8895 .38176 .8845 .37441 Mtetra
.664 .742 .908 r
.8845 .37441 .8895 .38176 .90221 .37778 .89724 .37039 Mtetra
.664 .741 .908 r
.89724 .37039 .90221 .37778 .91497 .37378 .91004 .36636 Mtetra
.91004 .36636 .91497 .37378 .92778 .36976 .9229 .36231 Mtetra
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.663 .741 .908 r
.35661 .53226 .36312 .53841 .3737 .53509 .36722 .52891 Mtetra
.36722 .52891 .3737 .53509 .38431 .53175 .37786 .52555 Mtetra
.37786 .52555 .38431 .53175 .39497 .52841 .38855 .52219 Mtetra
.662 .741 .909 r
.38855 .52219 .39497 .52841 .40568 .52507 .39927 .51885 Mtetra
.659 .741 .911 r
.39927 .51885 .40568 .52507 .41642 .52176 .41004 .51558 Mtetra
.652 .741 .915 r
.41004 .51558 .41642 .52176 .4272 .51853 .42085 .51247 Mtetra
.638 .742 .924 r
.42085 .51247 .4272 .51853 .43803 .51549 .43169 .50972 Mtetra
.609 .744 .941 r
.43169 .50972 .43803 .51549 .44889 .5128 .44257 .50759 Mtetra
.55 .745 .967 r
.44257 .50759 .44889 .5128 .45979 .51066 .45347 .50639 Mtetra
.43 .734 .99 r
.45347 .50639 .45979 .51066 .47072 .50928 .46442 .50636 Mtetra
.193 .66 .938 r
.46442 .50636 .47072 .50928 .48171 .50873 .47541 .50753 Mtetra
.135 0 0 r
.47541 .50753 .48171 .50873 .49275 .50896 .48647 .50966 Mtetra
.369 0 0 r
.48647 .50966 .49275 .50896 .50386 .5098 .49761 .51234 Mtetra
.478 0 0 r
.49761 .51234 .50386 .5098 .51504 .5111 .50883 .51534 Mtetra
.538 .038 .015 r
.50883 .51534 .51504 .5111 .5263 .51296 .52015 .51883 Mtetra
.59 .13 .13 r
.52015 .51883 .5263 .51296 .53764 .51569 .53156 .52341 Mtetra
.636 .213 .223 r
.53156 .52341 .53764 .51569 .54909 .51973 .54308 .52982 Mtetra
.667 .277 .296 r
.54308 .52982 .54909 .51973 .56065 .52537 .55474 .53846 Mtetra
.68 .315 .348 r
.55474 .53846 .56065 .52537 .57234 .53243 .56656 .54907 Mtetra
.676 .331 .383 r
.56656 .54907 .57234 .53243 .58417 .54026 .57854 .56065 Mtetra
.658 .329 .405 r
.57854 .56065 .58417 .54026 .59612 .5478 .59066 .57167 Mtetra
.628 .312 .416 r
.59066 .57167 .59612 .5478 .60816 .55379 .60289 .58037 Mtetra
.588 .282 .418 r
.60289 .58037 .60816 .55379 .62024 .55707 .61515 .58519 Mtetra
.537 .24 .411 r
.61515 .58519 .62024 .55707 .63231 .55682 .62738 .58508 Mtetra
.473 .185 .394 r
.62738 .58508 .63231 .55682 .64432 .55272 .63951 .57977 Mtetra
.398 .117 .366 r
.63951 .57977 .64432 .55272 .65624 .54504 .65151 .56977 Mtetra
.312 .036 .324 r
.65151 .56977 .65624 .54504 .66806 .53454 .66337 .55627 Mtetra
.22 0 .268 r
.66337 .55627 .66806 .53454 .6798 .52224 .67512 .54078 Mtetra
.129 0 .2 r
.67512 .54078 .6798 .52224 .69149 .50912 .68681 .52468 Mtetra
.041 0 .121 r
.68681 .52468 .69149 .50912 .70315 .49591 .69848 .50889 Mtetra
0 0 .034 r
.69848 .50889 .70315 .49591 .71481 .48293 .71015 .49373 Mtetra
0 0 0 r
.71015 .49373 .71481 .48293 .72648 .47026 .72181 .47902 Mtetra
.72181 .47902 .72648 .47026 .73814 .45787 .73346 .46453 Mtetra
.73346 .46453 .73814 .45787 .74983 .44587 .74509 .45022 Mtetra
.656 .9 .566 r
.74509 .45022 .74983 .44587 .76155 .43455 .75673 .43641 Mtetra
.793 .99 .746 r
.75673 .43641 .76155 .43455 .77334 .42425 .76842 .42368 Mtetra
.84 .99 .858 r
.76842 .42368 .77334 .42425 .78525 .41525 .78023 .41253 Mtetra
.819 .934 .906 r
.78023 .41253 .78525 .41525 .79728 .40763 .79219 .4032 Mtetra
.775 .869 .918 r
.79219 .4032 .79728 .40763 .80945 .40124 .8043 .39559 Mtetra
.733 .817 .917 r
.8043 .39559 .80945 .40124 .82174 .39581 .81657 .38938 Mtetra
.702 .782 .913 r
.81657 .38938 .82174 .39581 .83414 .39104 .82897 .38415 Mtetra
.683 .761 .91 r
.82897 .38415 .83414 .39104 .84663 .38667 .84148 .37952 Mtetra
.673 .75 .909 r
.84148 .37952 .84663 .38667 .85919 .38251 .85407 .37523 Mtetra
.668 .745 .908 r
.85407 .37523 .85919 .38251 .87181 .37844 .86673 .37109 Mtetra
.665 .743 .908 r
.86673 .37109 .87181 .37844 .8845 .37441 .87946 .36701 Mtetra
.664 .742 .908 r
.87946 .36701 .8845 .37441 .89724 .37039 .89224 .36294 Mtetra
.664 .741 .908 r
.89224 .36294 .89724 .37039 .91004 .36636 .90508 .35888 Mtetra
.90508 .35888 .91004 .36636 .9229 .36231 .91798 .3548 Mtetra
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.663 .741 .908 r
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52269 Mtetra
.36069 .52269 .36722 .52891 .37786 .52555 .37136 .51931 Mtetra
.662 .741 .909 r
.37136 .51931 .37786 .52555 .38855 .52219 .38207 .51594 Mtetra
.66 .741 .91 r
.38207 .51594 .38855 .52219 .39927 .51885 .39282 .51262 Mtetra
.655 .741 .913 r
.39282 .51262 .39927 .51885 .41004 .51558 .40362 .50943 Mtetra
.643 .741 .921 r
.40362 .50943 .41004 .51558 .42085 .51247 .41444 .50655 Mtetra
.615 .741 .936 r
.41444 .50655 .42085 .51247 .43169 .50972 .4253 .50429 Mtetra
.554 .74 .962 r
.4253 .50429 .43169 .50972 .44257 .50759 .43617 .50307 Mtetra
.415 .719 .987 r
.43617 .50307 .44257 .50759 .45347 .50639 .44708 .50333 Mtetra
.102 .597 .902 r
.44708 .50333 .45347 .50639 .46442 .50636 .45801 .5053 Mtetra
.314 0 0 r
.45801 .5053 .46442 .50636 .47541 .50753 .469 .5088 Mtetra
.524 0 0 r
.469 .5088 .47541 .50753 .48647 .50966 .48008 .51325 Mtetra
.577 .072 .018 r
.48008 .51325 .48647 .50966 .49761 .51234 .49125 .51788 Mtetra
.585 .119 .114 r
.49125 .51788 .49761 .51234 .50883 .51534 .50252 .52234 Mtetra
.595 .154 .173 r
.50252 .52234 .50883 .51534 .52015 .51883 .51389 .52698 Mtetra
.624 .204 .225 r
.51389 .52698 .52015 .51883 .53156 .52341 .52537 .53285 Mtetra
.663 .264 .279 r
.52537 .53285 .53156 .52341 .54308 .52982 .53697 .5411 Mtetra
.695 .317 .328 r
.53697 .5411 .54308 .52982 .55474 .53846 .54871 .55232 Mtetra
.708 .35 .367 r
.54871 .55232 .55474 .53846 .56656 .54907 .56064 .56611 Mtetra
.703 .36 .393 r
.56064 .56611 .56656 .54907 .57854 .56065 .57276 .58107 Mtetra
.682 .352 .409 r
.57276 .58107 .57854 .56065 .59066 .57167 .58505 .59513 Mtetra
.647 .327 .415 r
.58505 .59513 .59066 .57167 .60289 .58037 .59744 .60601 Mtetra
.596 .285 .412 r
.59744 .60601 .60289 .58037 .61515 .58519 .60986 .61179 Mtetra
.528 .225 .397 r
.60986 .61179 .61515 .58519 .62738 .58508 .62223 .61127 Mtetra
.437 .144 .368 r
.62223 .61127 .62738 .58508 .63951 .57977 .63447 .60427 Mtetra
.322 .04 .319 r
.63447 .60427 .63951 .57977 .65151 .56977 .64653 .59167 Mtetra
.188 0 .251 r
.64653 .59167 .65151 .56977 .66337 .55627 .65843 .57518 Mtetra
.053 0 .166 r
.65843 .57518 .66337 .55627 .67512 .54078 .67022 .55683 Mtetra
0 0 .08 r
.67022 .55683 .67512 .54078 .68681 .52468 .68194 .53842 Mtetra
0 0 .007 r
.68194 .53842 .68681 .52468 .69848 .50889 .69366 .521 Mtetra
0 0 0 r
.69366 .521 .69848 .50889 .71015 .49373 .70539 .50469 Mtetra
.70539 .50469 .71015 .49373 .72181 .47902 .71712 .48895 Mtetra
.71712 .48895 .72181 .47902 .73346 .46453 .7288 .47309 Mtetra
.7288 .47309 .73346 .46453 .74509 .45022 .74042 .45683 Mtetra
.74042 .45683 .74509 .45022 .75673 .43641 .75199 .44054 Mtetra
.74 .932 .59 r
.75199 .44054 .75673 .43641 .76842 .42368 .76359 .42506 Mtetra
.845 .995 .758 r
.76359 .42506 .76842 .42368 .78023 .41253 .77527 .41128 Mtetra
.859 .975 .862 r
.77527 .41128 .78023 .41253 .79219 .4032 .78712 .39975 Mtetra
.816 .911 .904 r
.78712 .39975 .79219 .4032 .8043 .39559 .79916 .39051 Mtetra
.763 .847 .914 r
.79916 .39051 .8043 .39559 .81657 .38938 .81139 .38323 Mtetra
.721 .799 .913 r
.81139 .38323 .81657 .38938 .82897 .38415 .82378 .37736 Mtetra
.693 .77 .911 r
.82378 .37736 .82897 .38415 .84148 .37952 .8363 .37239 Mtetra
.677 .754 .909 r
.8363 .37239 .84148 .37952 .85407 .37523 .84891 .36791 Mtetra
.669 .747 .908 r
.84891 .36791 .85407 .37523 .86673 .37109 .86161 .36368 Mtetra
.666 .743 .908 r
.86161 .36368 .86673 .37109 .87946 .36701 .87437 .35954 Mtetra
.664 .742 .908 r
.87437 .35954 .87946 .36701 .89224 .36294 .88719 .35544 Mtetra
.88719 .35544 .89224 .36294 .90508 .35888 .90008 .35134 Mtetra
.664 .741 .908 r
.90008 .35134 .90508 .35888 .91798 .3548 .91302 .34722 Mtetra
.663 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .52321 Mtetra
.33285 .52321 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52269 .35411 .51643 Mtetra
.35411 .51643 .36069 .52269 .37136 .51931 .36481 .51303 Mtetra
.661 .741 .909 r
.36481 .51303 .37136 .51931 .38207 .51594 .37555 .50967 Mtetra
.658 .741 .911 r
.37555 .50967 .38207 .51594 .39282 .51262 .38632 .50639 Mtetra
.648 .741 .917 r
.38632 .50639 .39282 .51262 .40362 .50943 .39714 .50336 Mtetra
.625 .74 .93 r
.39714 .50336 .40362 .50943 .41444 .50655 .40797 .50088 Mtetra
.571 .737 .954 r
.40797 .50088 .41444 .50655 .4253 .50429 .41883 .49943 Mtetra
.434 .714 .983 r
.41883 .49943 .4253 .50429 .43617 .50307 .42969 .49963 Mtetra
.084 .572 .9 r
.42969 .49963 .43617 .50307 .44708 .50333 .44057 .50202 Mtetra
.416 0 0 r
.44057 .50202 .44708 .50333 .45801 .5053 .45148 .50673 Mtetra
.624 .091 0 r
.45148 .50673 .45801 .5053 .469 .5088 .46246 .51317 Mtetra
.655 .186 .128 r
.46246 .51317 .469 .5088 .48008 .51325 .47354 .52015 Mtetra
.635 .202 .201 r
.47354 .52015 .48008 .51325 .49125 .51788 .48475 .52643 Mtetra
.607 .19 .225 r
.48475 .52643 .49125 .51788 .50252 .52234 .49609 .53152 Mtetra
.596 .185 .233 r
.49609 .53152 .50252 .52234 .51389 .52698 .50753 .53619 Mtetra
.622 .213 .247 r
.50753 .53619 .51389 .52698 .52537 .53285 .51907 .5421 Mtetra
.672 .272 .278 r
.51907 .5421 .52537 .53285 .53697 .5411 .53074 .55099 Mtetra
.717 .33 .315 r
.53074 .55099 .53697 .5411 .54871 .55232 .54256 .56364 Mtetra
.739 .367 .347 r
.54256 .56364 .54871 .55232 .56064 .56611 .55457 .57948 Mtetra
.738 .377 .369 r
.55457 .57948 .56064 .56611 .57276 .58107 .56678 .59666 Mtetra
.716 .364 .38 r
.56678 .59666 .57276 .58107 .58505 .59513 .57918 .6126 Mtetra
.673 .326 .378 r
.57918 .6126 .58505 .59513 .59744 .60601 .59169 .62458 Mtetra
.603 .26 .362 r
.59169 .62458 .59744 .60601 .60986 .61179 .60422 .63041 Mtetra
.489 .151 .32 r
.60422 .63041 .60986 .61179 .62223 .61127 .61669 .62887 Mtetra
.309 0 .239 r
.61669 .62887 .62223 .61127 .63447 .60427 .629 .61997 Mtetra
.046 0 .1 r
.629 .61997 .63447 .60427 .64653 .59167 .64112 .60502 Mtetra
0 0 0 r
.64112 .60502 .64653 .59167 .65843 .57518 .65307 .58624 Mtetra
.65307 .58624 .65843 .57518 .67022 .55683 .66491 .56618 Mtetra
.66491 .56618 .67022 .55683 .68194 .53842 .67672 .54697 Mtetra
.67672 .54697 .68194 .53842 .69366 .521 .68857 .52966 Mtetra
.68857 .52966 .69366 .521 .70539 .50469 .70046 .51405 Mtetra
.70046 .51405 .70539 .50469 .71712 .48895 .71234 .49898 Mtetra
.71234 .49898 .71712 .48895 .7288 .47309 .72414 .4831 Mtetra
.72414 .4831 .7288 .47309 .74042 .45683 .73581 .46571 Mtetra
.73581 .46571 .74042 .45683 .75199 .44054 .74736 .44719 Mtetra
.658 .839 .428 r
.74736 .44719 .75199 .44054 .76359 .42506 .75885 .42876 Mtetra
.81 .954 .616 r
.75885 .42876 .76359 .42506 .77527 .41128 .7704 .41187 Mtetra
.879 .993 .779 r
.7704 .41187 .77527 .41128 .78712 .39975 .78211 .39759 Mtetra
.86 .953 .871 r
.78211 .39759 .78712 .39975 .79916 .39051 .79405 .38623 Mtetra
.801 .883 .905 r
.79405 .38623 .79916 .39051 .81139 .38323 .8062 .3775 Mtetra
.745 .822 .912 r
.8062 .3775 .81139 .38323 .82378 .37736 .81856 .37076 Mtetra
.706 .783 .911 r
.81856 .37076 .82378 .37736 .8363 .37239 .83108 .36531 Mtetra
.684 .76 .909 r
.83108 .36531 .8363 .37239 .84891 .36791 .84372 .36058 Mtetra
.672 .749 .908 r
.84372 .36058 .84891 .36791 .86161 .36368 .85645 .35623 Mtetra
.667 .744 .908 r
.85645 .35623 .86161 .36368 .87437 .35954 .86925 .35202 Mtetra
.665 .742 .908 r
.86925 .35202 .87437 .35954 .88719 .35544 .88211 .34787 Mtetra
.664 .742 .908 r
.88211 .34787 .88719 .35544 .90008 .35134 .89503 .34373 Mtetra
.664 .741 .908 r
.89503 .34373 .90008 .35134 .91302 .34722 .90801 .33958 Mtetra
.663 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .52321 .32617 .51694 Mtetra
.32617 .51694 .33285 .52321 .34346 .51982 .33681 .51354 Mtetra
.33681 .51354 .34346 .51982 .35411 .51643 .34749 .51012 Mtetra
.662 .741 .909 r
.34749 .51012 .35411 .51643 .36481 .51303 .35821 .50672 Mtetra
.66 .741 .91 r
.35821 .50672 .36481 .51303 .37555 .50967 .36897 .50337 Mtetra
.653 .741 .914 r
.36897 .50337 .37555 .50967 .38632 .50639 .37977 .5002 Mtetra
.636 .74 .924 r
.37977 .5002 .38632 .50639 .39714 .50336 .3906 .49745 Mtetra
.593 .737 .944 r
.3906 .49745 .39714 .50336 .40797 .50088 .40144 .49561 Mtetra
.479 .719 .976 r
.40144 .49561 .40797 .50088 .41883 .49943 .41228 .49542 Mtetra
.151 .596 .931 r
.41228 .49542 .41883 .49943 .42969 .49963 .42311 .49771 Mtetra
.433 0 0 r
.42311 .49771 .42969 .49963 .44057 .50202 .43393 .50307 Mtetra
.683 .166 0 r
.43393 .50307 .44057 .50202 .45148 .50673 .4448 .51131 Mtetra
.714 .27 .196 r
.4448 .51131 .45148 .50673 .46246 .51317 .45575 .52114 Mtetra
.689 .282 .27 r
.45575 .52114 .46246 .51317 .47354 .52015 .46685 .5305 Mtetra
.642 .25 .287 r
.46685 .5305 .47354 .52015 .48475 .52643 .47812 .53755 Mtetra
.588 .197 .268 r
.47812 .53755 .48475 .52643 .49609 .53152 .48953 .54182 Mtetra
.555 .151 .23 r
.48953 .54182 .49609 .53152 .50753 .53619 .50106 .54474 Mtetra
.579 .155 .2 r
.50106 .54474 .50753 .53619 .51907 .5421 .51268 .54886 Mtetra
.659 .222 .201 r
.51268 .54886 .51907 .5421 .53074 .55099 .5244 .55658 Mtetra
.737 .306 .226 r
.5244 .55658 .53074 .55099 .54256 .56364 .53626 .56889 Mtetra
.78 .36 .253 r
.53626 .56889 .54256 .56364 .55457 .57948 .54831 .58499 Mtetra
.79 .376 .265 r
.54831 .58499 .55457 .57948 .56678 .59666 .56057 .6026 Mtetra
.773 .354 .256 r
.56057 .6026 .56678 .59666 .57918 .6126 .57301 .61872 Mtetra
.718 .28 .21 r
.57301 .61872 .57918 .6126 .59169 .62458 .58557 .63036 Mtetra
.577 .099 .084 r
.58557 .63036 .59169 .62458 .60422 .63041 .59815 .63524 Mtetra
.148 0 0 r
.59815 .63524 .60422 .63041 .61669 .62887 .61065 .63224 Mtetra
.629 .938 .706 r
.61065 .63224 .61669 .62887 .629 .61997 .623 .62167 Mtetra
.908 .983 .764 r
.623 .62167 .629 .61997 .64112 .60502 .63516 .60523 Mtetra
.949 .935 .745 r
.63516 .60523 .64112 .60502 .65307 .58624 .64717 .58557 Mtetra
.949 .918 .747 r
.64717 .58557 .65307 .58624 .66491 .56618 .65911 .56564 Mtetra
.937 .937 .77 r
.65911 .56564 .66491 .56618 .67672 .54697 .67107 .54778 Mtetra
.894 .986 .791 r
.67107 .54778 .67672 .54697 .68857 .52966 .68312 .53294 Mtetra
.709 .958 .689 r
.68312 .53294 .68857 .52966 .70046 .51405 .69527 .52042 Mtetra
0 0 0 r
.69527 .52042 .70046 .51405 .71234 .49898 .70742 .50824 Mtetra
.70742 .50824 .71234 .49898 .72414 .4831 .71945 .49415 Mtetra
.71945 .49415 .72414 .4831 .73581 .46571 .73126 .47684 Mtetra
.73126 .47684 .73581 .46571 .74736 .44719 .74282 .4566 Mtetra
.74282 .4566 .74736 .44719 .75885 .42876 .75423 .43514 Mtetra
.742 .875 .459 r
.75423 .43514 .75885 .42876 .7704 .41187 .76563 .41469 Mtetra
.868 .972 .657 r
.76563 .41469 .7704 .41187 .78211 .39759 .77718 .39704 Mtetra
.895 .98 .808 r
.77718 .39704 .78211 .39759 .79405 .38623 .78897 .38298 Mtetra
.845 .922 .883 r
.78897 .38298 .79405 .38623 .8062 .3775 .80103 .37236 Mtetra
.777 .852 .907 r
.80103 .37236 .8062 .3775 .81856 .37076 .81333 .36444 Mtetra
.725 .799 .911 r
.81333 .36444 .81856 .37076 .83108 .36531 .82584 .35832 Mtetra
.693 .769 .91 r
.82584 .35832 .83108 .36531 .84372 .36058 .83849 .35326 Mtetra
.676 .753 .909 r
.83849 .35326 .84372 .36058 .85645 .35623 .85124 .34874 Mtetra
.669 .746 .908 r
.85124 .34874 .85645 .35623 .86925 .35202 .86408 .34445 Mtetra
.665 .743 .908 r
.86408 .34445 .86925 .35202 .88211 .34787 .87698 .34025 Mtetra
.664 .742 .908 r
.87698 .34025 .88211 .34787 .89503 .34373 .88995 .33607 Mtetra
.664 .741 .908 r
.88995 .33607 .89503 .34373 .90801 .33958 .90297 .33189 Mtetra
.663 .741 .908 r
.30883 .51406 .31558 .52034 .32617 .51694 .31945 .51064 Mtetra
.31945 .51064 .32617 .51694 .33681 .51354 .33011 .50721 Mtetra
.33011 .50721 .33681 .51354 .34749 .51012 .34082 .50378 Mtetra
.661 .741 .909 r
.34082 .50378 .34749 .51012 .35821 .50672 .35156 .50038 Mtetra
.657 .741 .912 r
.35156 .50038 .35821 .50672 .36897 .50337 .36235 .49708 Mtetra
.645 .74 .918 r
.36235 .49708 .36897 .50337 .37977 .5002 .37316 .49409 Mtetra
.615 .738 .934 r
.37316 .49409 .37977 .5002 .3906 .49745 .38399 .49181 Mtetra
.531 .727 .963 r
.38399 .49181 .3906 .49745 .40144 .49561 .39482 .49097 Mtetra
.276 .647 .967 r
.39482 .49097 .40144 .49561 .41228 .49542 .40562 .49261 Mtetra
.347 0 0 r
.40562 .49261 .41228 .49542 .42311 .49771 .41638 .49781 Mtetra
.707 .188 0 r
.41638 .49781 .42311 .49771 .43393 .50307 .42713 .50705 Mtetra
.758 .325 .223 r
.42713 .50705 .43393 .50307 .4448 .51131 .43792 .51953 Mtetra
.739 .349 .313 r
.43792 .51953 .4448 .51131 .45575 .52114 .44885 .53292 Mtetra
.692 .321 .34 r
.44885 .53292 .45575 .52114 .46685 .5305 .45998 .54401 Mtetra
.622 .254 .324 r
.45998 .54401 .46685 .5305 .47812 .53755 .47134 .55036 Mtetra
.527 .146 .262 r
.47134 .55036 .47812 .53755 .48953 .54182 .48287 .55182 Mtetra
.43 .013 .145 r
.48287 .55182 .48953 .54182 .50106 .54474 .49451 .55079 Mtetra
.407 0 0 r
.49451 .55079 .50106 .54474 .51268 .54886 .50621 .55099 Mtetra
.528 0 0 r
.50621 .55099 .51268 .54886 .5244 .55658 .51797 .55552 Mtetra
.677 .129 0 r
.51797 .55552 .5244 .55658 .53626 .56889 .52986 .56548 Mtetra
.745 .226 0 r
.52986 .56548 .53626 .56889 .54831 .58499 .54191 .57981 Mtetra
.731 .227 0 r
.54191 .57981 .54831 .58499 .56057 .6026 .55415 .59586 Mtetra
.587 .094 0 r
.55415 .59586 .56057 .6026 .57301 .61872 .56658 .61034 Mtetra
0 .245 .755 r
.56658 .61034 .57301 .61872 .58557 .63036 .57911 .62022 Mtetra
.41 .552 .886 r
.57911 .62022 .58557 .63036 .59815 .63524 .59166 .62335 Mtetra
.663 .642 .819 r
.59166 .62335 .59815 .63524 .61065 .63224 .60415 .61882 Mtetra
.756 .661 .757 r
.60415 .61882 .61065 .63224 .623 .62167 .61649 .60725 Mtetra
.794 .666 .723 r
.61649 .60725 .623 .62167 .63516 .60523 .62869 .59063 Mtetra
.807 .67 .712 r
.62869 .59063 .63516 .60523 .64717 .58557 .64076 .5719 Mtetra
.808 .679 .721 r
.64076 .5719 .64717 .58557 .65911 .56564 .65283 .55424 Mtetra
.802 .704 .757 r
.65283 .55424 .65911 .56564 .67107 .54778 .66499 .54006 Mtetra
.79 .77 .835 r
.66499 .54006 .67107 .54778 .68312 .53294 .67732 .53013 Mtetra
.741 .92 .952 r
.67732 .53013 .68312 .53294 .69527 .52042 .68981 .52316 Mtetra
.376 .812 .653 r
.68981 .52316 .69527 .52042 .70742 .50824 .70233 .5162 Mtetra
0 0 0 r
.70233 .5162 .70742 .50824 .71945 .49415 .71469 .5059 Mtetra
.71469 .5059 .71945 .49415 .73126 .47684 .72673 .49008 Mtetra
.72673 .49008 .73126 .47684 .74282 .4566 .73838 .46885 Mtetra
.73838 .46885 .74282 .4566 .75423 .43514 .74973 .44443 Mtetra
.671 .787 .321 r
.74973 .44443 .75423 .43514 .76563 .41469 .76097 .42001 Mtetra
.83 .916 .52 r
.76097 .42001 .76563 .41469 .77718 .39704 .77232 .39837 Mtetra
.909 .98 .715 r
.77232 .39837 .77718 .39704 .78897 .38298 .78393 .38097 Mtetra
.887 .954 .842 r
.78393 .38097 .78897 .38298 .80103 .37236 .79586 .36794 Mtetra
.816 .884 .894 r
.79586 .36794 .80103 .37236 .81333 .36444 .8081 .35848 Mtetra
.749 .82 .908 r
.8081 .35848 .81333 .36444 .82584 .35832 .82057 .35149 Mtetra
.705 .78 .91 r
.82057 .35149 .82584 .35832 .83849 .35326 .83323 .34598 Mtetra
.682 .758 .909 r
.83323 .34598 .83849 .35326 .85124 .34874 .846 .34123 Mtetra
.671 .748 .908 r
.846 .34123 .85124 .34874 .86408 .34445 .85887 .33683 Mtetra
.666 .744 .908 r
.85887 .33683 .86408 .34445 .87698 .34025 .87181 .33257 Mtetra
.664 .742 .908 r
.87181 .33257 .87698 .34025 .88995 .33607 .88482 .32835 Mtetra
.88482 .32835 .88995 .33607 .90297 .33189 .89788 .32413 Mtetra
.663 .741 .908 r
.30202 .50773 .30883 .51406 .31945 .51064 .31267 .50428 Mtetra
.31267 .50428 .31945 .51064 .33011 .50721 .32336 .50084 Mtetra
.662 .741 .909 r
.32336 .50084 .33011 .50721 .34082 .50378 .33409 .4974 Mtetra
.66 .741 .91 r
.33409 .4974 .34082 .50378 .35156 .50038 .34486 .49402 Mtetra
.652 .741 .915 r
.34486 .49402 .35156 .50038 .36235 .49708 .35567 .49083 Mtetra
.632 .739 .925 r
.35567 .49083 .36235 .49708 .37316 .49409 .36649 .48814 Mtetra
.577 .733 .949 r
.36649 .48814 .37316 .49409 .38399 .49181 .37732 .48657 Mtetra
.408 .691 .978 r
.37732 .48657 .38399 .49181 .39482 .49097 .38811 .48719 Mtetra
0 .404 .781 r
.38811 .48719 .39482 .49097 .40562 .49261 .39884 .49139 Mtetra
.684 .142 0 r
.39884 .49139 .40562 .49261 .41638 .49781 .40949 .50039 Mtetra
.786 .349 .211 r
.40949 .50039 .41638 .49781 .42713 .50705 .42012 .51438 Mtetra
.78 .396 .33 r
.42012 .51438 .42713 .50705 .43792 .51953 .43083 .53159 Mtetra
.744 .385 .373 r
.43083 .53159 .43792 .51953 .44885 .53292 .44173 .54824 Mtetra
.681 .33 .373 r
.44173 .54824 .44885 .53292 .45998 .54401 .45293 .55985 Mtetra
.575 .219 .327 r
.45293 .55985 .45998 .54401 .47134 .55036 .46442 .56355 Mtetra
.381 .001 .188 r
.46442 .56355 .47134 .55036 .48287 .55182 .47611 .55992 Mtetra
.015 0 0 r
.47611 .55992 .48287 .55182 .49451 .55079 .4879 .55281 Mtetra
.428 .865 .772 r
.4879 .55281 .49451 .55079 .50621 .55099 .49969 .54721 Mtetra
.405 .757 .994 r
.49969 .54721 .50621 .55099 .51797 .55552 .51151 .54683 Mtetra
.168 .445 .876 r
.51151 .54683 .51797 .55552 .52986 .56548 .52339 .55277 Mtetra
.063 .276 .766 r
.52339 .55277 .52986 .56548 .54191 .57981 .53541 .56361 Mtetra
.12 .257 .732 r
.53541 .56361 .54191 .57981 .55415 .59586 .5476 .5764 Mtetra
.272 .321 .73 r
.5476 .5764 .55415 .59586 .56658 .61034 .55995 .58782 Mtetra
.433 .4 .722 r
.55995 .58782 .56658 .61034 .57911 .62022 .5724 .59497 Mtetra
.553 .461 .705 r
.5724 .59497 .57911 .62022 .59166 .62335 .58487 .59597 Mtetra
.631 .502 .687 r
.58487 .59597 .59166 .62335 .60415 .61882 .59729 .59025 Mtetra
.679 .528 .673 r
.59729 .59025 .60415 .61882 .61649 .60725 .60961 .57862 Mtetra
.706 .544 .667 r
.60961 .57862 .61649 .60725 .62869 .59063 .62182 .56323 Mtetra
.715 .554 .669 r
.62182 .56323 .62869 .59063 .64076 .5719 .63397 .54713 Mtetra
.708 .559 .683 r
.63397 .54713 .64076 .5719 .65283 .55424 .64618 .53357 Mtetra
.682 .564 .715 r
.64618 .53357 .65283 .55424 .66499 .54006 .65857 .52493 Mtetra
.625 .58 .783 r
.65857 .52493 .66499 .54006 .67732 .53013 .67121 .52181 Mtetra
.495 .645 .924 r
.67121 .52181 .67732 .53013 .68981 .52316 .6841 .52235 Mtetra
.061 .622 .793 r
.6841 .52235 .68981 .52316 .70233 .5162 .69706 .5226 Mtetra
.143 0 0 r
.69706 .5226 .70233 .5162 .71469 .5059 .70984 .51793 Mtetra
.002 0 .008 r
.70984 .51793 .71469 .5059 .72673 .49008 .72219 .50506 Mtetra
0 0 0 r
.72219 .50506 .72673 .49008 .73838 .46885 .73399 .4837 Mtetra
.73399 .4837 .73838 .46885 .74973 .44443 .74532 .45654 Mtetra
.74532 .45654 .74973 .44443 .76097 .42001 .75641 .42788 Mtetra
.794 .856 .406 r
.75641 .42788 .76097 .42001 .77232 .39837 .76755 .4017 Mtetra
.905 .953 .61 r
.76755 .4017 .77232 .39837 .78393 .38097 .77896 .38035 Mtetra
.92 .969 .779 r
.77896 .38035 .78393 .38097 .79586 .36794 .79072 .36436 Mtetra
.857 .914 .87 r
.79072 .36436 .79586 .36794 .8081 .35848 .80285 .35297 Mtetra
.778 .844 .901 r
.80285 .35297 .8081 .35848 .82057 .35149 .81528 .34486 Mtetra
.722 .793 .908 r
.81528 .34486 .82057 .35149 .83323 .34598 .82793 .33875 Mtetra
.69 .765 .909 r
.82793 .33875 .83323 .34598 .846 .34123 .84073 .33371 Mtetra
.674 .751 .908 r
.84073 .33371 .846 .34123 .85887 .33683 .85362 .32917 Mtetra
.667 .745 .908 r
.85362 .32917 .85887 .33683 .87181 .33257 .8666 .32484 Mtetra
.665 .743 .908 r
.8666 .32484 .87181 .33257 .88482 .32835 .87965 .32056 Mtetra
.664 .742 .908 r
.87965 .32056 .88482 .32835 .89788 .32413 .89275 .3163 Mtetra
.663 .741 .908 r
.29517 .50135 .30202 .50773 .31267 .50428 .30584 .49789 Mtetra
.663 .741 .909 r
.30584 .49789 .31267 .50428 .32336 .50084 .31656 .49443 Mtetra
.661 .741 .909 r
.31656 .49443 .32336 .50084 .33409 .4974 .32731 .49099 Mtetra
.657 .741 .912 r
.32731 .49099 .33409 .4974 .34486 .49402 .33811 .48767 Mtetra
.645 .74 .919 r
.33811 .48767 .34486 .49402 .35567 .49083 .34893 .48465 Mtetra
.61 .737 .935 r
.34893 .48465 .35567 .49083 .36649 .48814 .35976 .48243 Mtetra
.509 .718 .967 r
.35976 .48243 .36649 .48814 .37732 .48657 .37056 .4819 Mtetra
.154 .577 .932 r
.37056 .4819 .37732 .48657 .38811 .48719 .38129 .48454 Mtetra
.566 0 0 r
.38129 .48454 .38811 .48719 .39884 .49139 .3919 .49207 Mtetra
.794 .334 .148 r
.3919 .49207 .39884 .49139 .40949 .50039 .40241 .50574 Mtetra
.81 .422 .32 r
.40241 .50574 .40949 .50039 .42012 .51438 .4129 .52513 Mtetra
.787 .432 .385 r
.4129 .52513 .42012 .51438 .43083 .53159 .4235 .5471 Mtetra
.741 .399 .403 r
.4235 .5471 .43083 .53159 .44173 .54824 .4344 .56614 Mtetra
.658 .317 .383 r
.4344 .56614 .44173 .54824 .45293 .55985 .44571 .57654 Mtetra
.481 .127 .289 r
.44571 .57654 .45293 .55985 .46442 .56355 .45739 .57543 Mtetra
0 0 0 r
.45739 .57543 .46442 .56355 .47611 .55992 .4693 .56469 Mtetra
.814 .982 .702 r
.4693 .56469 .47611 .55992 .4879 .55281 .48126 .54994 Mtetra
.87 .881 .842 r
.48126 .54994 .4879 .55281 .49969 .54721 .49318 .53742 Mtetra
.709 .69 .83 r
.49318 .53742 .49969 .54721 .51151 .54683 .50504 .53124 Mtetra
.537 .521 .785 r
.50504 .53124 .51151 .54683 .52339 .55277 .51692 .53224 Mtetra
.43 .41 .735 r
.51692 .53224 .52339 .55277 .53541 .56361 .52889 .53862 Mtetra
.414 .371 .701 r
.52889 .53862 .53541 .56361 .5476 .5764 .541 .54725 Mtetra
.458 .38 .681 r
.541 .54725 .5476 .5764 .55995 .58782 .55324 .5549 Mtetra
.519 .409 .668 r
.55324 .5549 .55995 .58782 .5724 .59497 .56557 .55899 Mtetra
.575 .439 .658 r
.56557 .55899 .5724 .59497 .58487 .59597 .57794 .558 Mtetra
.618 .464 .65 r
.57794 .558 .58487 .59597 .59729 .59025 .59027 .55162 Mtetra
.647 .482 .646 r
.59027 .55162 .59729 .59025 .60961 .57862 .60255 .54083 Mtetra
.664 .495 .646 r
.60255 .54083 .60961 .57862 .62182 .56323 .61476 .52778 Mtetra
.664 .5 .652 r
.61476 .52778 .62182 .56323 .63397 .54713 .62698 .51544 Mtetra
.645 .496 .666 r
.62698 .51544 .63397 .54713 .64618 .53357 .63933 .50701 Mtetra
.592 .48 .695 r
.63933 .50701 .64618 .53357 .65857 .52493 .65194 .50487 Mtetra
.475 .446 .746 r
.65194 .50487 .65857 .52493 .67121 .52181 .6649 .50946 Mtetra
.192 .372 .813 r
.6649 .50946 .67121 .52181 .6841 .52235 .67819 .51853 Mtetra
0 .173 .595 r
.67819 .51853 .6841 .52235 .69706 .5226 .69161 .52719 Mtetra
.447 0 0 r
.69161 .52719 .69706 .5226 .70984 .51793 .70486 .52949 Mtetra
.17 0 .058 r
.70486 .52949 .70984 .51793 .72219 .50506 .71758 .52086 Mtetra
0 0 .036 r
.71758 .52086 .72219 .50506 .73399 .4837 .72959 .50031 Mtetra
0 0 0 r
.72959 .50031 .73399 .4837 .74532 .45654 .74094 .47086 Mtetra
.74094 .47086 .74532 .45654 .75641 .42788 .75191 .43794 Mtetra
.783 .816 .337 r
.75191 .43794 .75641 .42788 .76755 .4017 .76284 .40685 Mtetra
.9 .917 .523 r
.76284 .40685 .76755 .4017 .77896 .38035 .77402 .38106 Mtetra
.941 .964 .707 r
.77402 .38106 .77896 .38035 .79072 .36436 .7856 .36165 Mtetra
.895 .935 .833 r
.7856 .36165 .79072 .36436 .80285 .35297 .79761 .34795 Mtetra
.811 .868 .889 r
.79761 .34795 .80285 .35297 .81528 .34486 .80997 .33846 Mtetra
.742 .809 .905 r
.80997 .33846 .81528 .34486 .82793 .33875 .8226 .33161 Mtetra
.699 .773 .908 r
.8226 .33161 .82793 .33875 .84073 .33371 .83541 .3262 Mtetra
.678 .754 .908 r
.83541 .3262 .84073 .33371 .85362 .32917 .84834 .32148 Mtetra
.669 .746 .908 r
.84834 .32148 .85362 .32917 .8666 .32484 .86135 .31705 Mtetra
.665 .743 .908 r
.86135 .31705 .8666 .32484 .87965 .32056 .87444 .31272 Mtetra
.664 .742 .908 r
.87444 .31272 .87965 .32056 .89275 .3163 .88758 .30841 Mtetra
.663 .741 .908 r
.28827 .49493 .29517 .50135 .30584 .49789 .29897 .49145 Mtetra
.662 .741 .909 r
.29897 .49145 .30584 .49789 .31656 .49443 .3097 .48798 Mtetra
.659 .741 .91 r
.3097 .48798 .31656 .49443 .32731 .49099 .32048 .48457 Mtetra
.652 .741 .915 r
.32048 .48457 .32731 .49099 .33811 .48767 .3313 .48134 Mtetra
.632 .739 .925 r
.3313 .48134 .33811 .48767 .34893 .48465 .34213 .4786 Mtetra
.574 .731 .949 r
.34213 .4786 .34893 .48465 .35976 .48243 .35294 .47705 Mtetra
.383 .677 .975 r
.35294 .47705 .35976 .48243 .37056 .4819 .3637 .47796 Mtetra
0 .3 .695 r
.3637 .47796 .37056 .4819 .38129 .48454 .37433 .48319 Mtetra
.76 .253 0 r
.37433 .48319 .38129 .48454 .3919 .49207 .3848 .49478 Mtetra
.828 .422 .278 r
.3848 .49478 .3919 .49207 .40241 .50574 .39513 .51378 Mtetra
.82 .461 .376 r
.39513 .51378 .40241 .50574 .4129 .52513 .40544 .53877 Mtetra
.79 .451 .413 r
.40544 .53877 .4129 .52513 .4235 .5471 .41595 .56492 Mtetra
.735 .401 .415 r
.41595 .56492 .4235 .5471 .4344 .56614 .4269 .58489 Mtetra
.618 .277 .37 r
.4269 .58489 .4344 .56614 .44571 .57654 .43838 .59202 Mtetra
.257 0 .158 r
.43838 .59202 .44571 .57654 .45739 .57543 .45031 .58415 Mtetra
.763 .914 .535 r
.45031 .58415 .45739 .57543 .4693 .56469 .46247 .56501 Mtetra
.956 .887 .723 r
.46247 .56501 .4693 .56469 .48126 .54994 .47463 .54209 Mtetra
.867 .754 .736 r
.47463 .54209 .48126 .54994 .49318 .53742 .48667 .52265 Mtetra
.749 .638 .738 r
.48667 .52265 .49318 .53742 .50504 .53124 .49859 .51081 Mtetra
.625 .529 .725 r
.49859 .51081 .50504 .53124 .51692 .53224 .51047 .50693 Mtetra
.537 .447 .701 r
.51047 .50693 .51692 .53224 .52889 .53862 .52239 .5088 Mtetra
.507 .409 .679 r
.52239 .5088 .52889 .53862 .541 .54725 .53441 .51322 Mtetra
.52 .405 .663 r
.53441 .51322 .541 .54725 .55324 .5549 .54655 .51716 Mtetra
.552 .418 .652 r
.54655 .51716 .55324 .5549 .56557 .55899 .55876 .51843 Mtetra
.585 .435 .644 r
.55876 .51843 .56557 .55899 .57794 .558 .57101 .51589 Mtetra
.612 .451 .64 r
.57101 .51589 .57794 .558 .59027 .55162 .58326 .50946 Mtetra
.631 .464 .638 r
.58326 .50946 .59027 .55162 .60255 .54083 .59548 .50013 Mtetra
.639 .472 .641 r
.59548 .50013 .60255 .54083 .61476 .52778 .60769 .48993 Mtetra
.631 .472 .648 r
.60769 .48993 .61476 .52778 .62698 .51544 .61997 .48168 Mtetra
.595 .457 .663 r
.61997 .48168 .62698 .51544 .63933 .50701 .63243 .47847 Mtetra
.51 .419 .688 r
.63243 .47847 .63933 .50701 .65194 .50487 .64522 .48266 Mtetra
.314 .327 .714 r
.64522 .48266 .65194 .50487 .6649 .50946 .65845 .49472 Mtetra
0 .123 .667 r
.65845 .49472 .6649 .50946 .67819 .51853 .6721 .51218 Mtetra
.627 .137 0 r
.6721 .51218 .67819 .51853 .69161 .52719 .68597 .52947 Mtetra
.664 .136 0 r
.68597 .52947 .69161 .52719 .70486 .52949 .69968 .53938 Mtetra
.33 0 .07 r
.69968 .53938 .70486 .52949 .71758 .52086 .71281 .53593 Mtetra
0 0 .027 r
.71281 .53593 .71758 .52086 .72959 .50031 .72508 .51717 Mtetra
0 0 0 r
.72508 .51717 .72959 .50031 .74094 .47086 .73652 .48616 Mtetra
.73652 .48616 .74094 .47086 .75191 .43794 .7474 .44931 Mtetra
.81 .807 .319 r
.7474 .44931 .75191 .43794 .76284 .40685 .75814 .41331 Mtetra
.909 .891 .473 r
.75814 .41331 .76284 .40685 .77402 .38106 .7691 .38284 Mtetra
.955 .946 .644 r
.7691 .38284 .77402 .38106 .7856 .36165 .78049 .35969 Mtetra
.926 .942 .789 r
.78049 .35969 .7856 .36165 .79761 .34795 .79236 .3434 Mtetra
.845 .886 .87 r
.79236 .3434 .79761 .34795 .80997 .33846 .80464 .3323 Mtetra
.764 .824 .899 r
.80464 .3323 .80997 .33846 .8226 .33161 .81724 .32456 Mtetra
.712 .782 .907 r
.81724 .32456 .8226 .33161 .83541 .3262 .83005 .31869 Mtetra
.684 .759 .908 r
.83005 .31869 .83541 .3262 .84834 .32148 .84301 .31375 Mtetra
.671 .748 .908 r
.84301 .31375 .84834 .32148 .86135 .31705 .85606 .30921 Mtetra
.666 .744 .908 r
.85606 .30921 .86135 .31705 .87444 .31272 .86918 .30482 Mtetra
.665 .742 .908 r
.86918 .30482 .87444 .31272 .88758 .30841 .88237 .30046 Mtetra
.662 .741 .909 r
.28131 .48846 .28827 .49493 .29897 .49145 .29203 .48497 Mtetra
.661 .741 .91 r
.29203 .48497 .29897 .49145 .3097 .48798 .3028 .4815 Mtetra
.657 .741 .912 r
.3028 .4815 .3097 .48798 .32048 .48457 .3136 .47813 Mtetra
.646 .74 .918 r
.3136 .47813 .32048 .48457 .3313 .48134 .32443 .47505 Mtetra
.614 .737 .933 r
.32443 .47505 .3313 .48134 .34213 .4786 .33526 .47272 Mtetra
.516 .717 .964 r
.33526 .47272 .34213 .4786 .35294 .47705 .34605 .4721 Mtetra
.157 .571 .932 r
.34605 .4721 .35294 .47705 .3637 .47796 .35674 .47483 Mtetra
.6 .034 0 r
.35674 .47483 .3637 .47796 .37433 .48319 .36724 .48319 Mtetra
.825 .381 .179 r
.36724 .48319 .37433 .48319 .3848 .49478 .37752 .49936 Mtetra
.842 .468 .343 r
.37752 .49936 .3848 .49478 .39513 .51378 .38764 .5239 Mtetra
.826 .483 .405 r
.38764 .5239 .39513 .51378 .40544 .53877 .39778 .55408 Mtetra
.793 .46 .425 r
.39778 .55408 .40544 .53877 .41595 .56492 .40824 .58312 Mtetra
.726 .391 .411 r
.40824 .58312 .41595 .56492 .4269 .58489 .41928 .60205 Mtetra
.538 .184 .314 r
.41928 .60205 .4269 .58489 .43838 .59202 .43099 .60392 Mtetra
0 0 0 r
.43099 .60392 .43838 .59202 .45031 .58415 .44323 .588 Mtetra
.978 .907 .669 r
.44323 .588 .45031 .58415 .46247 .56501 .45566 .56026 Mtetra
.928 .782 .679 r
.45566 .56026 .46247 .56501 .47463 .54209 .46803 .5299 Mtetra
.854 .698 .688 r
.46803 .5299 .47463 .54209 .48667 .52265 .48019 .50465 Mtetra
.765 .621 .7 r
.48019 .50465 .48667 .52265 .49859 .51081 .49217 .48821 Mtetra
.666 .541 .702 r
.49217 .48821 .49859 .51081 .51047 .50693 .50405 .48032 Mtetra
.589 .474 .69 r
.50405 .48032 .51047 .50693 .52239 .5088 .51593 .47837 Mtetra
.554 .437 .675 r
.51593 .47837 .52239 .5088 .53441 .51322 .52788 .47916 Mtetra
.554 .427 .662 r
.52788 .47916 .53441 .51322 .54655 .51716 .53992 .47999 Mtetra
.571 .432 .652 r
.53992 .47999 .54655 .51716 .55876 .51843 .55203 .47906 Mtetra
.592 .442 .646 r
.55203 .47906 .55876 .51843 .57101 .51589 .56419 .47552 Mtetra
.611 .453 .643 r
.56419 .47552 .57101 .51589 .58326 .50946 .57636 .46945 Mtetra
.623 .461 .643 r
.57636 .46945 .58326 .50946 .59548 .50013 .58853 .4618 Mtetra
.623 .465 .647 r
.58853 .4618 .59548 .50013 .60769 .48993 .60074 .45439 Mtetra
.604 .458 .656 r
.60074 .45439 .60769 .48993 .61997 .48168 .61306 .44985 Mtetra
.549 .432 .672 r
.61306 .44985 .61997 .48168 .63243 .47847 .6256 .4511 Mtetra
.418 .363 .69 r
.6256 .4511 .63243 .47847 .64522 .48266 .63852 .46056 Mtetra
.126 .203 .674 r
.63852 .46056 .64522 .48266 .65845 .49472 .65194 .47883 Mtetra
0 0 .513 r
.65194 .47883 .65845 .49472 .6721 .51218 .66587 .50348 Mtetra
.724 .285 0 r
.66587 .50348 .6721 .51218 .68597 .52947 .68009 .52858 Mtetra
.775 .268 0 r
.68009 .52858 .68597 .52947 .69968 .53938 .69422 .54595 Mtetra
.475 0 .014 r
.69422 .54595 .69968 .53938 .71281 .53593 .70776 .54819 Mtetra
0 0 0 r
.70776 .54819 .71281 .53593 .72508 .51717 .72034 .53217 Mtetra
.72034 .53217 .72508 .51717 .73652 .48616 .73192 .50063 Mtetra
.763 .763 .254 r
.73192 .50063 .73652 .48616 .7474 .44931 .74278 .46064 Mtetra
.867 .823 .346 r
.74278 .46064 .7474 .44931 .75814 .41331 .75338 .42019 Mtetra
.934 .878 .461 r
.75338 .42019 .75814 .41331 .7691 .38284 .76415 .38518 Mtetra
.968 .925 .602 r
.76415 .38518 .7691 .38284 .78049 .35969 .77535 .35824 Mtetra
.949 .936 .746 r
.77535 .35824 .78049 .35969 .79236 .3434 .78708 .3392 Mtetra
.874 .897 .845 r
.78708 .3392 .79236 .3434 .80464 .3323 .79928 .32635 Mtetra
.788 .838 .89 r
.79928 .32635 .80464 .3323 .81724 .32456 .81185 .3176 Mtetra
.725 .791 .904 r
.81185 .3176 .81724 .32456 .83005 .31869 .82466 .31121 Mtetra
.691 .764 .908 r
.82466 .31121 .83005 .31869 .84301 .31375 .83764 .306 Mtetra
.674 .751 .908 r
.83764 .306 .84301 .31375 .85606 .30921 .85072 .30133 Mtetra
.668 .745 .908 r
.85072 .30133 .85606 .30921 .86918 .30482 .86388 .29686 Mtetra
.665 .743 .908 r
.86388 .29686 .86918 .30482 .88237 .30046 .87711 .29245 Mtetra
.662 .741 .909 r
.2743 .48195 .28131 .48846 .29203 .48497 .28505 .47844 Mtetra
.66 .741 .91 r
.28505 .47844 .29203 .48497 .3028 .4815 .29584 .47499 Mtetra
.653 .741 .914 r
.29584 .47499 .3028 .4815 .3136 .47813 .30666 .47169 Mtetra
.636 .739 .923 r
.30666 .47169 .3136 .47813 .32443 .47505 .3175 .46883 Mtetra
.586 .732 .944 r
.3175 .46883 .32443 .47505 .33526 .47272 .32832 .46705 Mtetra
.421 .687 .973 r
.32832 .46705 .33526 .47272 .34605 .4721 .33907 .46758 Mtetra
0 .358 .765 r
.33907 .46758 .34605 .4721 .35674 .47483 .34966 .47249 Mtetra
.76 .247 0 r
.34966 .47249 .35674 .47483 .36724 .48319 .36 .48435 Mtetra
.851 .446 .27 r
.36 .48435 .36724 .48319 .37752 .49936 .37008 .50525 Mtetra
.852 .495 .377 r
.37008 .50525 .37752 .49936 .38764 .5239 .37998 .53498 Mtetra
.833 .497 .417 r
.37998 .53498 .38764 .5239 .39778 .55408 .38998 .56917 Mtetra
.798 .464 .424 r
.38998 .56917 .39778 .55408 .40824 .58312 .40044 .59918 Mtetra
.712 .364 .385 r
.40044 .59918 .40824 .58312 .41928 .60205 .41165 .61491 Mtetra
.308 0 .122 r
.41165 .61491 .41928 .60205 .43099 .60392 .42365 .61001 Mtetra
.952 .951 .661 r
.42365 .61001 .43099 .60392 .44323 .588 .4362 .58581 Mtetra
.951 .8 .657 r
.4362 .58581 .44323 .588 .45566 .56026 .4489 .55053 Mtetra
.9 .724 .654 r
.4489 .55053 .45566 .56026 .46803 .5299 .46145 .51451 Mtetra
.846 .672 .667 r
.46145 .51451 .46803 .5299 .48019 .50465 .47372 .48536 Mtetra
.776 .619 .685 r
.47372 .48536 .48019 .50465 .49217 .48821 .48575 .46595 Mtetra
.694 .559 .697 r
.48575 .46595 .49217 .48821 .50405 .48032 .49763 .45533 Mtetra
.624 .503 .695 r
.49763 .45533 .50405 .48032 .51593 .47837 .5095 .4506 Mtetra
.586 .468 .685 r
.5095 .4506 .51593 .47837 .52788 .47916 .5214 .44868 Mtetra
.579 .454 .673 r
.5214 .44868 .52788 .47916 .53992 .47999 .53337 .44721 Mtetra
.588 .453 .665 r
.53337 .44721 .53992 .47999 .55203 .47906 .54541 .44474 Mtetra
.601 .458 .659 r
.54541 .44474 .55203 .47906 .56419 .47552 .55749 .44069 Mtetra
.613 .465 .656 r
.55749 .44069 .56419 .47552 .57636 .46945 .56961 .43519 Mtetra
.619 .47 .658 r
.56961 .43519 .57636 .46945 .58853 .4618 .58175 .42908 Mtetra
.612 .47 .664 r
.58175 .42908 .58853 .4618 .60074 .45439 .59396 .42399 Mtetra
.581 .457 .675 r
.59396 .42399 .60074 .45439 .61306 .44985 .60629 .42228 Mtetra
.5 .415 .691 r
.60629 .42228 .61306 .44985 .6256 .4511 .61888 .42674 Mtetra
.308 .307 .695 r
.61888 .42674 .6256 .4511 .63852 .46056 .63187 .43982 Mtetra
0 .078 .616 r
.63187 .43982 .63852 .46056 .65194 .47883 .6454 .46239 Mtetra
0 0 .395 r
.6454 .46239 .65194 .47883 .66587 .50348 .65948 .49228 Mtetra
.748 .347 0 r
.65948 .49228 .66587 .50348 .68009 .52858 .67396 .52355 Mtetra
.8 .327 0 r
.67396 .52355 .68009 .52858 .69422 .54595 .68842 .54745 Mtetra
.588 .027 0 r
.68842 .54745 .69422 .54595 .70776 .54819 .70232 .55539 Mtetra
0 0 0 r
.70232 .55539 .70776 .54819 .72034 .53217 .71523 .54294 Mtetra
.772 .823 .351 r
.71523 .54294 .72034 .53217 .73192 .50063 .72702 .51212 Mtetra
.884 .832 .364 r
.72702 .51212 .73192 .50063 .74278 .46064 .73795 .47026 Mtetra
.934 .846 .405 r
.73795 .47026 .74278 .46064 .75338 .42019 .74848 .42633 Mtetra
.966 .872 .478 r
.74848 .42633 .75338 .42019 .76415 .38518 .75911 .38738 Mtetra
.982 .905 .584 r
.75911 .38738 .76415 .38518 .77535 .35824 .77016 .35691 Mtetra
.964 .922 .711 r
.77016 .35691 .77535 .35824 .78708 .3392 .78177 .33519 Mtetra
.898 .899 .819 r
.78177 .33519 .78708 .3392 .79928 .32635 .79389 .32054 Mtetra
.811 .848 .878 r
.79389 .32054 .79928 .32635 .81185 .3176 .80642 .31072 Mtetra
.74 .8 .9 r
.80642 .31072 .81185 .3176 .82466 .31121 .81923 .30373 Mtetra
.698 .769 .906 r
.81923 .30373 .82466 .31121 .83764 .306 .83223 .29823 Mtetra
.678 .753 .908 r
.83223 .29823 .83764 .306 .85072 .30133 .84534 .29339 Mtetra
.669 .746 .908 r
.84534 .29339 .85072 .30133 .86388 .29686 .85854 .28884 Mtetra
.666 .743 .908 r
.85854 .28884 .86388 .29686 .87711 .29245 .87181 .28437 Mtetra
.661 .741 .909 r
.26724 .47539 .2743 .48195 .28505 .47844 .27801 .47187 Mtetra
.658 .741 .911 r
.27801 .47187 .28505 .47844 .29584 .47499 .28882 .46844 Mtetra
.648 .74 .916 r
.28882 .46844 .29584 .47499 .30666 .47169 .29966 .46525 Mtetra
.623 .737 .929 r
.29966 .46525 .30666 .47169 .3175 .46883 .31051 .46269 Mtetra
.547 .722 .955 r
.31051 .46269 .3175 .46883 .32832 .46705 .32131 .46157 Mtetra
.28 .625 .961 r
.32131 .46157 .32832 .46705 .33907 .46758 .332 .46347 Mtetra
.469 0 0 r
.332 .46347 .33907 .46758 .34966 .47249 .34247 .47077 Mtetra
.824 .359 .107 r
.34247 .47077 .34966 .47249 .36 .48435 .35264 .48619 Mtetra
.865 .482 .317 r
.35264 .48619 .36 .48435 .37008 .50525 .3625 .5115 Mtetra
.861 .512 .391 r
.3625 .5115 .37008 .50525 .37998 .53498 .37222 .54537 Mtetra
.843 .506 .417 r
.37222 .54537 .37998 .53498 .38998 .56917 .38213 .58176 Mtetra
.806 .462 .406 r
.38213 .58176 .38998 .56917 .40044 .59918 .39266 .61049 Mtetra
.683 .297 .309 r
.39266 .61049 .40044 .59918 .41165 .61491 .4041 .62115 Mtetra
.613 .903 .612 r
.4041 .62115 .41165 .61491 .42365 .61001 .41642 .60885 Mtetra
.954 .823 .676 r
.41642 .60885 .42365 .61001 .4362 .58581 .42927 .57734 Mtetra
.915 .733 .642 r
.42927 .57734 .4362 .58581 .4489 .55053 .4422 .53664 Mtetra
.881 .692 .643 r
.4422 .53664 .4489 .55053 .46145 .51451 .45489 .49742 Mtetra
.841 .661 .659 r
.45489 .49742 .46145 .51451 .47372 .48536 .46724 .46653 Mtetra
.787 .627 .683 r
.46724 .46653 .47372 .48536 .48575 .46595 .4793 .44586 Mtetra
.718 .584 .704 r
.4793 .44586 .48575 .46595 .49763 .45533 .49121 .43379 Mtetra
.654 .538 .711 r
.49121 .43379 .49763 .45533 .5095 .4506 .50306 .42732 Mtetra
.615 .505 .706 r
.50306 .42732 .5095 .4506 .5214 .44868 .51495 .42358 Mtetra
.602 .489 .697 r
.51495 .42358 .5214 .44868 .53337 .44721 .52688 .42056 Mtetra
.605 .484 .689 r
.52688 .42056 .53337 .44721 .54541 .44474 .53887 .41714 Mtetra
.612 .485 .683 r
.53887 .41714 .54541 .44474 .55749 .44069 .55091 .41288 Mtetra
.619 .489 .682 r
.55091 .41288 .55749 .44069 .56961 .43519 .56299 .40794 Mtetra
.62 .492 .685 r
.56299 .40794 .56961 .43519 .58175 .42908 .57512 .40304 Mtetra
.605 .488 .693 r
.57512 .40304 .58175 .42908 .59396 .42399 .58733 .39959 Mtetra
.56 .467 .707 r
.58733 .39959 .59396 .42399 .60629 .42228 .59967 .39967 Mtetra
.444 .406 .721 r
.59967 .39967 .60629 .42228 .61888 .42674 .61227 .40593 Mtetra
.186 .252 .699 r
.61227 .40593 .61888 .42674 .63187 .43982 .62527 .42086 Mtetra
0 0 .555 r
.62527 .42086 .63187 .43982 .6454 .46239 .63882 .44558 Mtetra
0 0 .335 r
.63882 .44558 .6454 .46239 .65948 .49228 .65296 .47838 Mtetra
.727 .357 0 r
.65296 .47838 .65948 .49228 .67396 .52355 .66756 .51367 Mtetra
.745 .323 0 r
.66756 .51367 .67396 .52355 .68842 .54745 .68224 .54256 Mtetra
.534 .003 0 r
.68224 .54256 .68842 .54745 .70232 .55539 .69644 .55568 Mtetra
.659 .972 .878 r
.69644 .55568 .70232 .55539 .71523 .54294 .70967 .54737 Mtetra
.953 .927 .578 r
.70967 .54737 .71523 .54294 .72702 .51212 .72172 .51861 Mtetra
.976 .869 .487 r
.72172 .51861 .72702 .51212 .73795 .47026 .73279 .47649 Mtetra
.984 .854 .476 r
.73279 .47649 .73795 .47026 .74848 .42633 .74336 .4305 Mtetra
.99 .863 .51 r
.74336 .4305 .74848 .42633 .75911 .38738 .75393 .38864 Mtetra
.992 .884 .584 r
.75393 .38864 .75911 .38738 .77016 .35691 .76489 .35525 Mtetra
.972 .902 .689 r
.76489 .35525 .77016 .35691 .78177 .33519 .7764 .33112 Mtetra
.915 .893 .794 r
.7764 .33112 .78177 .33519 .79389 .32054 .78846 .31477 Mtetra
.83 .853 .864 r
.78846 .31477 .79389 .32054 .80642 .31072 .80095 .30386 Mtetra
.755 .807 .894 r
.80095 .30386 .80642 .31072 .81923 .30373 .81376 .29626 Mtetra
.707 .774 .905 r
.81376 .29626 .81923 .30373 .83223 .29823 .82677 .29042 Mtetra
.682 .756 .907 r
.82677 .29042 .83223 .29823 .84534 .29339 .83992 .28541 Mtetra
.671 .747 .908 r
.83992 .28541 .84534 .29339 .85854 .28884 .85316 .28076 Mtetra
.666 .744 .908 r
.85316 .28076 .85854 .28884 .87181 .28437 .86647 .27623 Mtetra
.66 .741 .91 r
.26013 .46877 .26724 .47539 .27801 .47187 .27092 .46526 Mtetra
.655 .74 .912 r
.27092 .46526 .27801 .47187 .28882 .46844 .28175 .46187 Mtetra
.642 .739 .919 r
.28175 .46187 .28882 .46844 .29966 .46525 .29261 .45881 Mtetra
.606 .733 .935 r
.29261 .45881 .29966 .46525 .31051 .46269 .30345 .45659 Mtetra
.495 .706 .964 r
.30345 .45659 .31051 .46269 .32131 .46157 .31423 .45625 Mtetra
.095 .523 .908 r
.31423 .45625 .32131 .46157 .332 .46347 .32485 .45961 Mtetra
.65 .099 0 r
.32485 .45961 .332 .46347 .34247 .47077 .33519 .46931 Mtetra
.854 .419 .184 r
.33519 .46931 .34247 .47077 .35264 .48619 .34519 .48801 Mtetra
.876 .504 .336 r
.34519 .48801 .35264 .48619 .3625 .5115 .35486 .51684 Mtetra
.872 .525 .391 r
.35486 .51684 .3625 .5115 .37222 .54537 .36444 .55325 Mtetra
.857 .513 .402 r
.36444 .55325 .37222 .54537 .38213 .58176 .37435 .58965 Mtetra
.82 .453 .361 r
.37435 .58965 .38213 .58176 .39266 .61049 .38503 .61497 Mtetra
.556 .052 .014 r
.38503 .61497 .39266 .61049 .4041 .62115 .39674 .61947 Mtetra
.923 .871 .769 r
.39674 .61947 .4041 .62115 .41642 .60885 .40935 .60036 Mtetra
.908 .736 .656 r
.40935 .60036 .41642 .60885 .42927 .57734 .42245 .56359 Mtetra
.888 .694 .635 r
.42245 .56359 .42927 .57734 .4422 .53664 .43554 .52018 Mtetra
.868 .675 .639 r
.43554 .52018 .4422 .53664 .45489 .49742 .44832 .48031 Mtetra
.84 .661 .659 r
.44832 .48031 .45489 .49742 .46724 .46653 .46072 .44964 Mtetra
.799 .644 .69 r
.46072 .44964 .46724 .46653 .4793 .44586 .47281 .42906 Mtetra
.742 .618 .721 r
.47281 .42906 .4793 .44586 .49121 .43379 .48473 .41651 Mtetra
.684 .585 .738 r
.48473 .41651 .49121 .43379 .50306 .42732 .4966 .40904 Mtetra
.644 .555 .74 r
.4966 .40904 .50306 .42732 .51495 .42358 .50848 .40413 Mtetra
.627 .537 .733 r
.50848 .40413 .51495 .42358 .52688 .42056 .5204 .4001 Mtetra
.624 .528 .726 r
.5204 .4001 .52688 .42056 .53887 .41714 .53238 .39609 Mtetra
.627 .526 .721 r
.53238 .39609 .53887 .41714 .55091 .41288 .5444 .39176 Mtetra
.629 .527 .72 r
.5444 .39176 .55091 .41288 .56299 .40794 .55647 .38725 Mtetra
.624 .528 .725 r
.55647 .38725 .56299 .40794 .57512 .40304 .5686 .38316 Mtetra
.602 .521 .735 r
.5686 .38316 .57512 .40304 .58733 .39959 .58081 .38065 Mtetra
.539 .492 .752 r
.58081 .38065 .58733 .39959 .59967 .39967 .59316 .3816 Mtetra
.387 .408 .76 r
.59316 .3816 .59967 .39967 .61227 .40593 .60574 .38842 Mtetra
.072 .21 .703 r
.60574 .38842 .61227 .40593 .62527 .42086 .61872 .4036 Mtetra
0 0 .515 r
.61872 .4036 .62527 .42086 .63882 .44558 .63222 .42851 Mtetra
0 0 .324 r
.63222 .42851 .63882 .44558 .65296 .47838 .64632 .46195 Mtetra
.673 .334 0 r
.64632 .46195 .65296 .47838 .66756 .51367 .66092 .49893 Mtetra
0 0 .31 r
.66092 .49893 .66756 .51367 .68224 .54256 .67569 .53092 Mtetra
0 .059 .622 r
.67569 .53092 .68224 .54256 .69644 .55568 .6901 .54823 Mtetra
.647 .758 .93 r
.6901 .54823 .69644 .55568 .70967 .54737 .70361 .54422 Mtetra
.96 .869 .703 r
.70361 .54422 .70967 .54737 .72172 .51861 .71595 .51871 Mtetra
.995 .847 .58 r
.71595 .51871 .72172 .51861 .73279 .47649 .72725 .47801 Mtetra
.999 .838 .539 r
.72725 .47801 .73279 .47649 .74336 .4305 .73795 .43165 Mtetra
.998 .844 .546 r
.73795 .43165 .74336 .4305 .75393 .38864 .74855 .3882 Mtetra
.994 .861 .594 r
.74855 .3882 .75393 .38864 .76489 .35525 .75949 .35278 Mtetra
.974 .88 .677 r
.75949 .35278 .76489 .35525 .7764 .33112 .77095 .32673 Mtetra
.924 .881 .774 r
.77095 .32673 .7764 .33112 .78846 .31477 .78296 .30889 Mtetra
.845 .853 .849 r
.78296 .30889 .78846 .31477 .80095 .30386 .79544 .29697 Mtetra
.768 .811 .887 r
.79544 .29697 .80095 .30386 .81376 .29626 .80825 .28876 Mtetra
.715 .778 .902 r
.80825 .28876 .81376 .29626 .82677 .29042 .82127 .28257 Mtetra
.686 .758 .906 r
.82127 .28257 .82677 .29042 .83992 .28541 .83445 .27737 Mtetra
.673 .749 .908 r
.83445 .27737 .83992 .28541 .85316 .28076 .84773 .27261 Mtetra
.667 .744 .908 r
.84773 .27261 .85316 .28076 .86647 .27623 .86108 .26802 Mtetra
.659 .741 .91 r
.25296 .46211 .26013 .46877 .27092 .46526 .26378 .45859 Mtetra
.653 .74 .913 r
.26378 .45859 .27092 .46526 .28175 .46187 .27463 .45525 Mtetra
.635 .737 .922 r
.27463 .45525 .28175 .46187 .29261 .45881 .28549 .45234 Mtetra
.587 .728 .941 r
.28549 .45234 .29261 .45881 .30345 .45659 .29634 .4505 Mtetra
.434 .682 .968 r
.29634 .4505 .30345 .45659 .31423 .45625 .30708 .45096 Mtetra
0 .394 .815 r
.30708 .45096 .31423 .45625 .32485 .45961 .31762 .45576 Mtetra
.739 .215 0 r
.31762 .45576 .32485 .45961 .33519 .46931 .32785 .4676 Mtetra
.871 .452 .217 r
.32785 .4676 .33519 .46931 .34519 .48801 .33769 .48889 Mtetra
.888 .519 .337 r
.33769 .48889 .34519 .48801 .35486 .51684 .34723 .51994 Mtetra
.886 .534 .376 r
.34723 .51994 .35486 .51684 .36444 .55325 .35675 .55695 Mtetra
.876 .518 .365 r
.35675 .55695 .36444 .55325 .37435 .58965 .36673 .59125 Mtetra
.838 .42 .245 r
.36673 .59125 .37435 .58965 .38503 .61497 .37762 .61174 Mtetra
.458 .809 .998 r
.37762 .61174 .38503 .61497 .39674 .61947 .38959 .61015 Mtetra
.871 .733 .707 r
.38959 .61015 .39674 .61947 .40935 .60036 .40245 .58596 Mtetra
.876 .689 .645 r
.40245 .58596 .40935 .60036 .42245 .56359 .4157 .5467 Mtetra
.872 .675 .633 r
.4157 .5467 .42245 .56359 .43554 .52018 .42887 .50337 Mtetra
.863 .671 .642 r
.42887 .50337 .43554 .52018 .44832 .48031 .44169 .465 Mtetra
.847 .674 .667 r
.44169 .465 .44832 .48031 .46072 .44964 .45411 .43591 Mtetra
.818 .676 .706 r
.45411 .43591 .46072 .44964 .47281 .42906 .46623 .41618 Mtetra
.772 .669 .749 r
.46623 .41618 .47281 .42906 .48473 .41651 .47819 .40358 Mtetra
.719 .648 .777 r
.47819 .40358 .48473 .41651 .4966 .40904 .49008 .39545 Mtetra
.678 .621 .785 r
.49008 .39545 .4966 .40904 .50848 .40413 .50198 .38966 Mtetra
.656 .6 .78 r
.50198 .38966 .50848 .40413 .5204 .4001 .51391 .38488 Mtetra
.647 .587 .773 r
.51391 .38488 .5204 .4001 .53238 .39609 .52589 .38042 Mtetra
.644 .581 .769 r
.52589 .38042 .53238 .39609 .5444 .39176 .53791 .37601 Mtetra
.641 .579 .77 r
.53791 .37601 .5444 .39176 .55647 .38725 .54999 .37176 Mtetra
.631 .577 .776 r
.54999 .37176 .55647 .38725 .5686 .38316 .56213 .36811 Mtetra
.6 .566 .788 r
.56213 .36811 .5686 .38316 .58081 .38065 .57435 .36604 Mtetra
.521 .53 .805 r
.57435 .36604 .58081 .38065 .59316 .3816 .5867 .36716 Mtetra
.335 .424 .805 r
.5867 .36716 .59316 .3816 .60574 .38842 .59927 .37367 Mtetra
0 .194 .711 r
.59927 .37367 .60574 .38842 .61872 .4036 .61219 .38795 Mtetra
0 0 .505 r
.61219 .38795 .61872 .4036 .63222 .42851 .6256 .41154 Mtetra
0 0 .342 r
.6256 .41154 .63222 .42851 .64632 .46195 .63959 .44374 Mtetra
0 0 .301 r
.63959 .44374 .64632 .46195 .66092 .49893 .65411 .48031 Mtetra
0 0 .395 r
.65411 .48031 .66092 .49893 .67569 .53092 .66886 .51341 Mtetra
0 .102 .647 r
.66886 .51341 .67569 .53092 .6901 .54823 .68336 .53357 Mtetra
.548 .56 .819 r
.68336 .53357 .6901 .54823 .70361 .54422 .69709 .53356 Mtetra
.871 .749 .725 r
.69709 .53356 .70361 .54422 .71595 .51871 .70973 .51202 Mtetra
.958 .789 .63 r
.70973 .51202 .71595 .51871 .72725 .47801 .72132 .47418 Mtetra
.983 .802 .583 r
.72132 .47418 .72725 .47801 .73795 .43165 .73222 .42909 Mtetra
.989 .816 .577 r
.73222 .42909 .73795 .43165 .74855 .3882 .74296 .38549 Mtetra
.986 .836 .608 r
.74296 .38549 .74855 .3882 .75949 .35278 .75393 .34906 Mtetra
.969 .856 .674 r
.75393 .34906 .75949 .35278 .77095 .32673 .7654 .32175 Mtetra
.926 .864 .759 r
.7654 .32175 .77095 .32673 .78296 .30889 .7774 .30275 Mtetra
.855 .847 .835 r
.7774 .30275 .78296 .30889 .79544 .29697 .78987 .28996 Mtetra
.779 .812 .879 r
.78987 .28996 .79544 .29697 .80825 .28876 .80268 .28118 Mtetra
.723 .78 .898 r
.80268 .28118 .80825 .28876 .82127 .28257 .81573 .27466 Mtetra
.691 .76 .905 r
.81573 .27466 .82127 .28257 .83445 .27737 .82893 .26927 Mtetra
.675 .75 .907 r
.82893 .26927 .83445 .27737 .84773 .27261 .84225 .2644 Mtetra
.668 .745 .908 r
.84225 .2644 .84773 .27261 .86108 .26802 .85564 .25974 Mtetra
.658 .74 .91 r
.24573 .4554 .25296 .46211 .26378 .45859 .25657 .45188 Mtetra
.65 .739 .914 r
.25657 .45188 .26378 .45859 .27463 .45525 .26745 .44857 Mtetra
.628 .735 .924 r
.26745 .44857 .27463 .45525 .28549 .45234 .27833 .44582 Mtetra
.566 .721 .946 r
.27833 .44582 .28549 .45234 .29634 .4505 .28916 .44436 Mtetra
.371 .652 .966 r
.28916 .44436 .29634 .4505 .30708 .45096 .29987 .44556 Mtetra
0 .28 .721 r
.29987 .44556 .30708 .45096 .31762 .45576 .31035 .45159 Mtetra
.779 .275 0 r
.31035 .45159 .31762 .45576 .32785 .4676 .32047 .46506 Mtetra
.883 .469 .219 r
.32047 .46506 .32785 .4676 .33769 .48889 .3302 .48793 Mtetra
.9 .527 .318 r
.3302 .48793 .33769 .48889 .34723 .51994 .33968 .51964 Mtetra
.903 .54 .34 r
.33968 .51964 .34723 .51994 .35675 .55695 .34923 .55537 Mtetra
.9 .515 .289 r
.34923 .55537 .35675 .55695 .36673 .59125 .35935 .58603 Mtetra
.771 .269 0 r
.35935 .58603 .36673 .59125 .37762 .61174 .37045 .60133 Mtetra
.706 .687 .829 r
.37045 .60133 .37762 .61174 .38959 .61015 .38264 .59495 Mtetra
.836 .673 .68 r
.38264 .59495 .38959 .61015 .40245 .58596 .39563 .56829 Mtetra
.858 .667 .643 r
.39563 .56829 .40245 .58596 .4157 .5467 .40894 .52951 Mtetra
.866 .671 .638 r
.40894 .52951 .4157 .5467 .42887 .50337 .42212 .4887 Mtetra
.869 .685 .651 r
.42212 .4887 .42887 .50337 .44169 .465 .43494 .45332 Mtetra
.866 .707 .683 r
.43494 .45332 .44169 .465 .45411 .43591 .44737 .42644 Mtetra
.851 .733 .733 r
.44737 .42644 .45411 .43591 .46623 .41618 .45953 .40765 Mtetra
.815 .746 .787 r
.45953 .40765 .46623 .41618 .47819 .40358 .47154 .39489 Mtetra
.766 .735 .825 r
.47154 .39489 .47819 .40358 .49008 .39545 .48348 .38598 Mtetra
.721 .707 .837 r
.48348 .38598 .49008 .39545 .50198 .38966 .49541 .37925 Mtetra
.691 .679 .833 r
.49541 .37925 .50198 .38966 .51391 .38488 .50737 .37367 Mtetra
.674 .658 .826 r
.50737 .37367 .51391 .38488 .52589 .38042 .51937 .36871 Mtetra
.663 .645 .822 r
.51937 .36871 .52589 .38042 .53791 .37601 .53142 .36413 Mtetra
.654 .639 .823 r
.53142 .36413 .53791 .37601 .54999 .37176 .54352 .35994 Mtetra
.637 .633 .83 r
.54352 .35994 .54999 .37176 .56213 .36811 .55567 .35649 Mtetra
.597 .618 .844 r
.55567 .35649 .56213 .36811 .57435 .36604 .56791 .35456 Mtetra
.504 .575 .86 r
.56791 .35456 .57435 .36604 .5867 .36716 .58027 .35551 Mtetra
.294 .453 .849 r
.58027 .35551 .5867 .36716 .59927 .37367 .59282 .36129 Mtetra
0 .201 .727 r
.59282 .36129 .59927 .37367 .61219 .38795 .60569 .37409 Mtetra
0 0 .512 r
.60569 .37409 .61219 .38795 .6256 .41154 .619 .3955 Mtetra
0 0 .366 r
.619 .3955 .6256 .41154 .63959 .44374 .63285 .4252 Mtetra
0 0 .345 r
.63285 .4252 .63959 .44374 .65411 .48031 .64721 .45973 Mtetra
0 0 .448 r
.64721 .45973 .65411 .48031 .66886 .51341 .66185 .49215 Mtetra
0 .125 .646 r
.66185 .49215 .66886 .51341 .68336 .53357 .67636 .5136 Mtetra
.493 .469 .759 r
.67636 .5136 .68336 .53357 .69709 .53356 .69023 .51674 Mtetra
.789 .657 .717 r
.69023 .51674 .69709 .53356 .70973 .51202 .70313 .49927 Mtetra
.905 .728 .652 r
.70313 .49927 .70973 .51202 .72132 .47418 .71502 .46518 Mtetra
.951 .761 .611 r
.71502 .46518 .72132 .47418 .73222 .42909 .7262 .42265 Mtetra
.969 .785 .601 r
.7262 .42265 .73222 .42909 .74296 .38549 .73712 .3802 Mtetra
.971 .808 .622 r
.73712 .3802 .74296 .38549 .75393 .34906 .74821 .3438 Mtetra
.958 .831 .675 r
.74821 .3438 .75393 .34906 .7654 .32175 .75973 .31591 Mtetra
.922 .844 .75 r
.75973 .31591 .7654 .32175 .7774 .30275 .77175 .29617 Mtetra
.858 .836 .823 r
.77175 .29617 .7774 .30275 .78987 .28996 .78423 .28273 Mtetra
.786 .809 .871 r
.78423 .28273 .78987 .28996 .80268 .28118 .79706 .27348 Mtetra
.729 .781 .894 r
.79706 .27348 .80268 .28118 .81573 .27466 .81013 .26665 Mtetra
.694 .761 .903 r
.81013 .26665 .81573 .27466 .82893 .26927 .82337 .26109 Mtetra
.677 .75 .906 r
.82337 .26109 .82893 .26927 .84225 .2644 .83672 .25611 Mtetra
.669 .745 .907 r
.83672 .25611 .84225 .2644 .85564 .25974 .85016 .25139 Mtetra
.658 .74 .911 r
.23845 .44863 .24573 .4554 .25657 .45188 .24932 .4451 Mtetra
.648 .738 .915 r
.24932 .4451 .25657 .45188 .26745 .44857 .26021 .44184 Mtetra
.621 .733 .926 r
.26021 .44184 .26745 .44857 .27833 .44582 .2711 .43922 Mtetra
.548 .714 .949 r
.2711 .43922 .27833 .44582 .28916 .44436 .28194 .43807 Mtetra
.321 .623 .958 r
.28194 .43807 .28916 .44436 .29987 .44556 .29262 .43986 Mtetra
0 .21 .667 r
.29262 .43986 .29987 .44556 .31035 .45159 .30305 .44674 Mtetra
.79 .294 0 r
.30305 .44674 .31035 .45159 .32047 .46506 .31311 .46111 Mtetra
.89 .472 .191 r
.31311 .46111 .32047 .46506 .3302 .48793 .32279 .48437 Mtetra
.912 .529 .276 r
.32279 .48437 .3302 .48793 .33968 .51964 .33227 .51519 Mtetra
.919 .539 .271 r
.33227 .51519 .33968 .51964 .34923 .55537 .34192 .54817 Mtetra
.899 .481 .123 r
.34192 .54817 .34923 .55537 .35935 .58603 .35221 .57455 Mtetra
0 .178 .713 r
.35221 .57455 .35935 .58603 .37045 .60133 .36349 .58545 Mtetra
.709 .616 .751 r
.36349 .58545 .37045 .60133 .38264 .59495 .3758 .57655 Mtetra
.815 .646 .674 r
.3758 .57655 .38264 .59495 .39563 .56829 .38882 .55047 Mtetra
.85 .663 .65 r
.38882 .55047 .39563 .56829 .40894 .52951 .40208 .51495 Mtetra
.871 .687 .65 r
.40208 .51495 .40894 .52951 .42212 .4887 .41519 .4785 Mtetra
.89 .723 .669 r
.41519 .4785 .42212 .4887 .43494 .45332 .42799 .44687 Mtetra
.904 .774 .708 r
.42799 .44687 .43494 .45332 .44737 .42644 .44045 .42218 Mtetra
.902 .828 .764 r
.44045 .42218 .44737 .42644 .45953 .40765 .45268 .40389 Mtetra
.873 .861 .825 r
.45268 .40389 .45953 .40765 .47154 .39489 .46476 .39042 Mtetra
.825 .853 .868 r
.46476 .39042 .47154 .39489 .48348 .38598 .47677 .38021 Mtetra
.776 .815 .883 r
.47677 .38021 .48348 .38598 .49541 .37925 .48877 .37214 Mtetra
.736 .771 .881 r
.48877 .37214 .49541 .37925 .50737 .37367 .50077 .36548 Mtetra
.706 .735 .874 r
.50077 .36548 .50737 .37367 .51937 .36871 .51281 .35979 Mtetra
.684 .711 .869 r
.51281 .35979 .51937 .36871 .53142 .36413 .52489 .35484 Mtetra
.664 .696 .87 r
.52489 .35484 .53142 .36413 .54352 .35994 .53701 .35058 Mtetra
.638 .685 .878 r
.53701 .35058 .54352 .35994 .55567 .35649 .5492 .34722 Mtetra
.589 .667 .893 r
.5492 .34722 .55567 .35649 .56791 .35456 .56146 .34537 Mtetra
.48 .619 .91 r
.56146 .34537 .56791 .35456 .58027 .35551 .57384 .34617 Mtetra
.244 .483 .888 r
.57384 .34617 .58027 .35551 .59282 .36129 .58639 .35127 Mtetra
0 .21 .735 r
.58639 .35127 .59282 .36129 .60569 .37409 .59922 .3626 Mtetra
0 0 .505 r
.59922 .3626 .60569 .37409 .619 .3955 .61244 .38163 Mtetra
0 0 .367 r
.61244 .38163 .619 .3955 .63285 .4252 .62614 .40827 Mtetra
0 0 .36 r
.62614 .40827 .63285 .4252 .64721 .45973 .64032 .43971 Mtetra
0 0 .473 r
.64032 .43971 .64721 .45973 .66185 .49215 .65481 .46999 Mtetra
.02 .139 .649 r
.65481 .46999 .66185 .49215 .67636 .5136 .66924 .49114 Mtetra
.464 .431 .737 r
.66924 .49114 .67636 .5136 .69023 .51674 .68317 .49611 Mtetra
.734 .602 .71 r
.68317 .49611 .69023 .51674 .70313 .49927 .69626 .48208 Mtetra
.859 .682 .662 r
.69626 .48208 .70313 .49927 .71502 .46518 .70843 .45189 Mtetra
.916 .725 .629 r
.70843 .45189 .71502 .46518 .7262 .42265 .7199 .41263 Mtetra
.943 .754 .619 r
.7199 .41263 .7262 .42265 .73712 .3802 .73106 .37227 Mtetra
.951 .781 .635 r
.73106 .37227 .73712 .3802 .74821 .3438 .74232 .33681 Mtetra
.943 .806 .679 r
.74232 .33681 .74821 .3438 .75973 .31591 .75394 .30903 Mtetra
.912 .823 .745 r
.75394 .30903 .75973 .31591 .77175 .29617 .76601 .28899 Mtetra
.857 .822 .814 r
.76601 .28899 .77175 .29617 .78423 .28273 .77852 .27517 Mtetra
.789 .803 .863 r
.77852 .27517 .78423 .28273 .79706 .27348 .79138 .26558 Mtetra
.733 .778 .889 r
.79138 .26558 .79706 .27348 .81013 .26665 .80448 .25852 Mtetra
.697 .76 .901 r
.80448 .25852 .81013 .26665 .82337 .26109 .81776 .25281 Mtetra
.678 .75 .905 r
.81776 .25281 .82337 .26109 .83672 .25611 .83115 .24775 Mtetra
.67 .745 .907 r
.83115 .24775 .83672 .25611 .85016 .25139 .84463 .24296 Mtetra
.657 .74 .911 r
.23111 .4418 .23845 .44863 .24932 .4451 .24201 .43827 Mtetra
.646 .737 .916 r
.24201 .43827 .24932 .4451 .26021 .44184 .25292 .43502 Mtetra
.617 .731 .927 r
.25292 .43502 .26021 .44184 .2711 .43922 .26383 .4325 Mtetra
.536 .707 .949 r
.26383 .4325 .2711 .43922 .28194 .43807 .27467 .43156 Mtetra
.296 .604 .952 r
.27467 .43156 .28194 .43807 .29262 .43986 .28534 .43368 Mtetra
0 .198 .668 r
.28534 .43368 .29262 .43986 .30305 .44674 .29574 .44093 Mtetra
.773 .277 0 r
.29574 .44093 .30305 .44674 .31311 .46111 .30579 .45535 Mtetra
.887 .458 .126 r
.30579 .45535 .31311 .46111 .32279 .48437 .31549 .4778 Mtetra
.916 .517 .196 r
.31549 .4778 .32279 .48437 .33227 .51519 .32506 .50642 Mtetra
.914 .515 .144 r
.32506 .50642 .33227 .51519 .34192 .54817 .33485 .53583 Mtetra
.752 .345 0 r
.33485 .53583 .34192 .54817 .35221 .57455 .34529 .55817 Mtetra
.253 .352 .771 r
.34529 .55817 .35221 .57455 .36349 .58545 .35667 .56638 Mtetra
.688 .58 .728 r
.35667 .56638 .36349 .58545 .3758 .57655 .36897 .55775 Mtetra
.796 .636 .683 r
.36897 .55775 .3758 .57655 .38882 .55047 .38187 .53521 Mtetra
.849 .677 .669 r
.38187 .53521 .38882 .55047 .40208 .51495 .39499 .50527 Mtetra
.891 .729 .675 r
.39499 .50527 .40208 .51495 .41519 .4785 .40801 .47442 Mtetra
.93 .801 .696 r
.40801 .47442 .41519 .4785 .42799 .44687 .42078 .44682 Mtetra
.953 .885 .726 r
.42078 .44682 .42799 .44687 .44045 .42218 .4333 .42389 Mtetra
.94 .95 .758 r
.4333 .42389 .44045 .42218 .45268 .40389 .44562 .40533 Mtetra
.903 .977 .801 r
.44562 .40533 .45268 .40389 .46476 .39042 .45782 .39031 Mtetra
.87 .969 .855 r
.45782 .39031 .46476 .39042 .47677 .38021 .46994 .37805 Mtetra
.833 .928 .895 r
.46994 .37805 .47677 .38021 .48877 .37214 .48203 .36798 Mtetra
.789 .87 .908 r
.48203 .36798 .48877 .37214 .50077 .36548 .4941 .35972 Mtetra
.745 .816 .907 r
.4941 .35972 .50077 .36548 .51281 .35979 .50619 .35294 Mtetra
.708 .775 .905 r
.50619 .35294 .51281 .35979 .52489 .35484 .51831 .34738 Mtetra
.673 .749 .907 r
.51831 .34738 .52489 .35484 .53701 .35058 .53047 .34292 Mtetra
.633 .73 .918 r
.53047 .34292 .53701 .35058 .5492 .34722 .54269 .33967 Mtetra
.565 .708 .937 r
.54269 .33967 .5492 .34722 .56146 .34537 .55499 .3381 Mtetra
.424 .651 .953 r
.55499 .3381 .56146 .34537 .57384 .34617 .56739 .3391 Mtetra
.131 .486 .901 r
.56739 .3391 .57384 .34617 .58639 .35127 .57996 .344 Mtetra
0 .173 .682 r
.57996 .344 .58639 .35127 .59922 .3626 .59278 .35437 Mtetra
.566 .108 0 r
.59278 .35437 .59922 .3626 .61244 .38163 .60594 .37141 Mtetra
.665 .243 0 r
.60594 .37141 .61244 .38163 .62614 .40827 .61953 .39503 Mtetra
0 0 .321 r
.61953 .39503 .62614 .40827 .64032 .43971 .63354 .42288 Mtetra
0 0 .467 r
.63354 .42288 .64032 .43971 .65481 .46999 .64784 .44988 Mtetra
.01 .152 .665 r
.64784 .44988 .65481 .46999 .66924 .49114 .66214 .46914 Mtetra
.455 .43 .741 r
.66214 .46914 .66924 .49114 .68317 .49611 .67605 .47431 Mtetra
.708 .581 .711 r
.67605 .47431 .68317 .49611 .69626 .48208 .68925 .46243 Mtetra
.827 .654 .668 r
.68925 .46243 .69626 .48208 .70843 .45189 .70164 .43555 Mtetra
.887 .697 .64 r
.70164 .43555 .70843 .45189 .7199 .41263 .71338 .39963 Mtetra
.917 .728 .632 r
.71338 .39963 .7199 .41263 .73106 .37227 .7248 .36188 Mtetra
.929 .756 .646 r
.7248 .36188 .73106 .37227 .74232 .33681 .73625 .32801 Mtetra
.924 .781 .684 r
.73625 .32801 .74232 .33681 .75394 .30903 .748 .30096 Mtetra
.898 .801 .743 r
.748 .30096 .75394 .30903 .76601 .28899 .76017 .2811 Mtetra
.849 .805 .807 r
.76017 .2811 .76601 .28899 .77852 .27517 .77273 .26718 Mtetra
.788 .793 .856 r
.77273 .26718 .77852 .27517 .79138 .26558 .78563 .25743 Mtetra
.734 .774 .885 r
.78563 .25743 .79138 .26558 .80448 .25852 .79878 .25023 Mtetra
.698 .758 .898 r
.79878 .25023 .80448 .25852 .81776 .25281 .81209 .24442 Mtetra
.679 .749 .904 r
.81209 .24442 .81776 .25281 .83115 .24775 .82553 .23929 Mtetra
.67 .744 .906 r
.82553 .23929 .83115 .24775 .84463 .24296 .83905 .23445 Mtetra
.657 .74 .911 r
.22372 .43492 .23111 .4418 .24201 .43827 .23464 .43136 Mtetra
.645 .737 .916 r
.23464 .43136 .24201 .43827 .25292 .43502 .24558 .42812 Mtetra
.614 .729 .927 r
.24558 .42812 .25292 .43502 .26383 .4325 .2565 .42562 Mtetra
.533 .702 .948 r
.2565 .42562 .26383 .4325 .27467 .43156 .26736 .42475 Mtetra
.303 .599 .949 r
.26736 .42475 .27467 .43156 .28534 .43368 .27804 .42691 Mtetra
0 .24 .72 r
.27804 .42691 .28534 .43368 .29574 .44093 .28846 .43396 Mtetra
.711 .213 0 r
.28846 .43396 .29574 .44093 .30579 .45535 .29854 .44758 Mtetra
.857 .414 .007 r
.29854 .44758 .30579 .45535 .31549 .4778 .30833 .46819 Mtetra
.887 .474 .058 r
.30833 .46819 .31549 .4778 .32506 .50642 .31803 .49374 Mtetra
.829 .431 0 r
.31803 .49374 .32506 .50642 .33485 .53583 .32797 .51936 Mtetra
0 0 .481 r
.32797 .51936 .33485 .53583 .34529 .55817 .33853 .5386 Mtetra
.338 .367 .744 r
.33853 .5386 .34529 .55817 .35667 .56638 .3499 .5462 Mtetra
.646 .549 .73 r
.3499 .5462 .35667 .56638 .36897 .55775 .36205 .54053 Mtetra
.771 .634 .71 r
.36205 .54053 .36897 .55775 .38187 .53521 .37472 .52406 Mtetra
.852 .714 .709 r
.37472 .52406 .38187 .53521 .39499 .50527 .38761 .50145 Mtetra
.924 .814 .719 r
.38761 .50145 .39499 .50527 .40801 .47442 .40049 .47705 Mtetra
.964 .922 .712 r
.40049 .47705 .40801 .47442 .42078 .44682 .41324 .45351 Mtetra
.91 .965 .649 r
.41324 .45351 .42078 .44682 .4333 .42389 .42585 .43186 Mtetra
.818 .945 .589 r
.42585 .43186 .4333 .42389 .44562 .40533 .43833 .41228 Mtetra
.794 .951 .615 r
.43833 .41228 .44562 .40533 .45782 .39031 .45069 .39483 Mtetra
.829 .987 .715 r
.45069 .39483 .45782 .39031 .46994 .37805 .46297 .37963 Mtetra
.855 .995 .823 r
.46297 .37963 .46994 .37805 .48203 .36798 .47517 .36678 Mtetra
.838 .956 .89 r
.47517 .36678 .48203 .36798 .4941 .35972 .48734 .35626 Mtetra
.791 .896 .917 r
.48734 .35626 .4941 .35972 .50619 .35294 .4995 .3479 Mtetra
.737 .84 .928 r
.4995 .3479 .50619 .35294 .51831 .34738 .51166 .34144 Mtetra
.681 .8 .938 r
.51166 .34144 .51831 .34738 .53047 .34292 .52387 .33671 Mtetra
.613 .771 .956 r
.52387 .33671 .53047 .34292 .54269 .33967 .53613 .33373 Mtetra
.5 .736 .978 r
.53613 .33373 .54269 .33967 .55499 .3381 .54847 .3328 Mtetra
.272 .641 .965 r
.54847 .3328 .55499 .3381 .56739 .3391 .56092 .33461 Mtetra
0 .383 .787 r
.56092 .33461 .56739 .3391 .57996 .344 .57353 .34011 Mtetra
.523 0 0 r
.57353 .34011 .57996 .344 .59278 .35437 .58638 .35039 Mtetra
.713 .193 0 r
.58638 .35039 .59278 .35437 .60594 .37141 .59952 .3662 Mtetra
.778 .294 0 r
.59952 .3662 .60594 .37141 .61953 .39503 .61303 .38722 Mtetra
.754 .299 0 r
.61303 .38722 .61953 .39503 .63354 .42288 .6269 .4113 Mtetra
0 0 .408 r
.6269 .4113 .63354 .42288 .64784 .44988 .64102 .43415 Mtetra
0 .179 .702 r
.64102 .43415 .64784 .44988 .66214 .46914 .65515 .44999 Mtetra
.475 .466 .769 r
.65515 .44999 .66214 .46914 .67605 .47431 .66897 .45348 Mtetra
.708 .587 .718 r
.66897 .45348 .67605 .47431 .68925 .46243 .6822 .44208 Mtetra
.812 .643 .673 r
.6822 .44208 .68925 .46243 .70164 .43555 .69474 .41735 Mtetra
.865 .678 .648 r
.69474 .41735 .70164 .43555 .71338 .39963 .7067 .38433 Mtetra
.893 .706 .642 r
.7067 .38433 .71338 .39963 .7248 .36188 .71836 .34931 Mtetra
.906 .732 .656 r
.71836 .34931 .7248 .36188 .73625 .32801 .73003 .31746 Mtetra
.903 .757 .691 r
.73003 .31746 .73625 .32801 .748 .30096 .74194 .29165 Mtetra
.881 .778 .743 r
.74194 .29165 .748 .30096 .76017 .2811 .75421 .2724 Mtetra
.838 .787 .803 r
.75421 .2724 .76017 .2811 .77273 .26718 .76686 .25871 Mtetra
.783 .781 .851 r
.76686 .25871 .77273 .26718 .78563 .25743 .77982 .249 Mtetra
.732 .768 .881 r
.77982 .249 .78563 .25743 .79878 .25023 .79301 .24177 Mtetra
.698 .755 .896 r
.79301 .24177 .79878 .25023 .81209 .24442 .80637 .23592 Mtetra
.679 .748 .903 r
.80637 .23592 .81209 .24442 .82553 .23929 .81985 .23074 Mtetra
.67 .744 .906 r
.81985 .23074 .82553 .23929 .83905 .23445 .83343 .22586 Mtetra
.657 .74 .911 r
.21627 .42798 .22372 .43492 .23464 .43136 .22722 .42439 Mtetra
.645 .736 .916 r
.22722 .42439 .23464 .43136 .24558 .42812 .23818 .42112 Mtetra
.615 .728 .926 r
.23818 .42112 .24558 .42812 .2565 .42562 .24913 .41859 Mtetra
.538 .701 .945 r
.24913 .41859 .2565 .42562 .26736 .42475 .26001 .41762 Mtetra
.339 .609 .948 r
.26001 .41762 .26736 .42475 .27804 .42691 .27073 .4195 Mtetra
0 .322 .797 r
.27073 .4195 .27804 .42691 .28846 .43396 .2812 .42583 Mtetra
.572 .089 0 r
.2812 .42583 .28846 .43396 .29854 .44758 .29137 .43792 Mtetra
.76 .313 0 r
.29137 .43792 .29854 .44758 .30833 .46819 .3013 .45592 Mtetra
.774 .368 0 r
.3013 .45592 .30833 .46819 .31803 .49374 .31116 .47795 Mtetra
0 0 .322 r
.31116 .47795 .31803 .49374 .32797 .51936 .32126 .50004 Mtetra
0 .039 .597 r
.32126 .50004 .32797 .51936 .33853 .5386 .33185 .51737 Mtetra
.313 .334 .723 r
.33185 .51737 .33853 .5386 .3499 .5462 .34311 .52626 Mtetra
.563 .502 .745 r
.34311 .52626 .3499 .5462 .36205 .54053 .35499 .52565 Mtetra
.712 .629 .763 r
.35499 .52565 .36205 .54053 .37472 .52406 .36733 .51701 Mtetra
.84 .781 .795 r
.36733 .51701 .37472 .52406 .38761 .50145 .37993 .50291 Mtetra
.927 .953 .784 r
.37993 .50291 .38761 .50145 .40049 .47705 .39263 .48554 Mtetra
.799 .94 .585 r
.39263 .48554 .40049 .47705 .41324 .45351 .40537 .46621 Mtetra
.604 .797 .374 r
.40537 .46621 .41324 .45351 .42585 .43186 .41809 .44563 Mtetra
0 0 0 r
.41809 .44563 .42585 .43186 .43833 .41228 .43075 .42457 Mtetra
.608 .798 .374 r
.43075 .42457 .43833 .41228 .45069 .39483 .44333 .40404 Mtetra
.718 .892 .507 r
.44333 .40404 .45069 .39483 .46297 .37963 .4558 .38513 Mtetra
.819 .973 .67 r
.4558 .38513 .46297 .37963 .47517 .36678 .46818 .36871 Mtetra
.86 .996 .807 r
.46818 .36871 .47517 .36678 .48734 .35626 .48047 .35523 Mtetra
.834 .963 .891 r
.48047 .35523 .48734 .35626 .4995 .3479 .49272 .34474 Mtetra
.769 .908 .936 r
.49272 .34474 .4995 .3479 .51166 .34144 .50495 .33708 Mtetra
.682 .856 .965 r
.50495 .33708 .51166 .34144 .52387 .33671 .5172 .33205 Mtetra
.558 .808 .992 r
.5172 .33205 .52387 .33671 .53613 .33373 .52951 .32957 Mtetra
.333 .72 .983 r
.52951 .32957 .53613 .33373 .54847 .3328 .5419 .32983 Mtetra
0 .476 .798 r
.5419 .32983 .54847 .3328 .56092 .33461 .55441 .33321 Mtetra
.484 0 0 r
.55441 .33321 .56092 .33461 .57353 .34011 .56709 .34025 Mtetra
.683 .142 0 r
.56709 .34025 .57353 .34011 .58638 .35039 .57999 .35143 Mtetra
.765 .267 .03 r
.57999 .35143 .58638 .35039 .59952 .3662 .59316 .36686 Mtetra
.803 .322 .065 r
.59316 .36686 .59952 .3662 .61303 .38722 .60664 .38574 Mtetra
.807 .318 0 r
.60664 .38574 .61303 .38722 .6269 .4113 .62041 .40595 Mtetra
.694 .189 0 r
.62041 .40595 .6269 .4113 .64102 .43415 .63436 .42382 Mtetra
0 .262 .771 r
.63436 .42382 .64102 .43415 .65515 .44999 .6483 .43478 Mtetra
.542 .552 .815 r
.6483 .43478 .65515 .44999 .66897 .45348 .66197 .43478 Mtetra
.734 .617 .727 r
.66197 .43478 .66897 .45348 .6822 .44208 .67516 .42206 Mtetra
.81 .644 .677 r
.67516 .42206 .6822 .44208 .69474 .41735 .68777 .39813 Mtetra
.85 .666 .654 r
.68777 .39813 .69474 .41735 .7067 .38433 .6999 .36729 Mtetra
.872 .688 .65 r
.6999 .36729 .7067 .38433 .71836 .34931 .71178 .33486 Mtetra
.883 .711 .664 r
.71178 .33486 .71836 .34931 .73003 .31746 .72366 .3053 Mtetra
.88 .735 .697 r
.72366 .3053 .73003 .31746 .74194 .29165 .73575 .28113 Mtetra
.86 .756 .746 r
.73575 .28113 .74194 .29165 .75421 .2724 .74816 .26289 Mtetra
.823 .768 .801 r
.74816 .26289 .75421 .2724 .76686 .25871 .76091 .24974 Mtetra
.773 .768 .848 r
.76091 .24974 .76686 .25871 .77982 .249 .77394 .24027 Mtetra
.728 .76 .878 r
.77394 .24027 .77982 .249 .79301 .24177 .78719 .23313 Mtetra
.696 .752 .895 r
.78719 .23313 .79301 .24177 .80637 .23592 .8006 .22729 Mtetra
.678 .746 .902 r
.8006 .22729 .80637 .23592 .81985 .23074 .81413 .22209 Mtetra
.67 .743 .906 r
.81413 .22209 .81985 .23074 .83343 .22586 .82775 .21718 Mtetra
.657 .74 .91 r
.20876 .42098 .21627 .42798 .22722 .42439 .21974 .41736 Mtetra
.646 .736 .915 r
.21974 .41736 .22722 .42439 .23818 .42112 .23073 .41402 Mtetra
.618 .727 .924 r
.23073 .41402 .23818 .42112 .24913 .41859 .24171 .41139 Mtetra
.551 .702 .94 r
.24171 .41139 .24913 .41859 .26001 .41762 .25263 .41018 Mtetra
.393 .627 .947 r
.25263 .41018 .26001 .41762 .27073 .4195 .2634 .41151 Mtetra
.064 .42 .867 r
.2634 .41151 .27073 .4195 .2812 .42583 .27396 .41668 Mtetra
0 .093 .629 r
.27396 .41668 .2812 .42583 .29137 .43792 .28426 .42672 Mtetra
0 0 .429 r
.28426 .42672 .29137 .43792 .3013 .45592 .29437 .44168 Mtetra
0 0 .401 r
.29437 .44168 .3013 .45592 .31116 .47795 .30442 .46008 Mtetra
0 0 .505 r
.30442 .46008 .31116 .47795 .32126 .50004 .31464 .4791 Mtetra
0 .1 .627 r
.31464 .4791 .32126 .50004 .33185 .51737 .32522 .49552 Mtetra
.224 .27 .7 r
.32522 .49552 .33185 .51737 .34311 .52626 .33628 .50694 Mtetra
.398 .408 .754 r
.33628 .50694 .34311 .52626 .35499 .52565 .34782 .51252 Mtetra
.535 .57 .837 r
.34782 .51252 .35499 .52565 .36733 .51701 .35975 .51254 Mtetra
.683 .847 .961 r
.35975 .51254 .36733 .51701 .37993 .50291 .37199 .50752 Mtetra
.581 .918 .699 r
.37199 .50752 .37993 .50291 .39263 .48554 .38449 .49765 Mtetra
0 0 0 r
.38449 .49765 .39263 .48554 .40537 .46621 .39719 .48291 Mtetra
.39719 .48291 .40537 .46621 .41809 .44563 .41002 .4637 Mtetra
.41002 .4637 .41809 .44563 .43075 .42457 .42289 .44125 Mtetra
.42289 .44125 .43075 .42457 .44333 .40404 .43572 .41746 Mtetra
.641 .801 .361 r
.43572 .41746 .44333 .40404 .4558 .38513 .44844 .39441 Mtetra
.768 .909 .521 r
.44844 .39441 .4558 .38513 .46818 .36871 .46102 .37383 Mtetra
.847 .979 .684 r
.46102 .37383 .46818 .36871 .48047 .35523 .47347 .35679 Mtetra
.855 .996 .819 r
.47347 .35679 .48047 .35523 .49272 .34474 .48583 .3437 Mtetra
.793 .968 .915 r
.48583 .3437 .49272 .34474 .50495 .33708 .49815 .33457 Mtetra
.662 .914 .978 r
.49815 .33457 .50495 .33708 .5172 .33205 .51046 .32924 Mtetra
.416 .81 .986 r
.51046 .32924 .5172 .33205 .52951 .32957 .52282 .32758 Mtetra
0 .536 .792 r
.52282 .32758 .52951 .32957 .5419 .32983 .53527 .32959 Mtetra
.465 0 0 r
.53527 .32959 .5419 .32983 .55441 .33321 .54785 .33532 Mtetra
.658 .128 0 r
.54785 .33532 .55441 .33321 .56709 .34025 .56061 .34477 Mtetra
.725 .248 .116 r
.56061 .34477 .56709 .34025 .57999 .35143 .57359 .35766 Mtetra
.75 .302 .186 r
.57359 .35766 .57999 .35143 .59316 .36686 .58682 .37329 Mtetra
.761 .317 .196 r
.58682 .37329 .59316 .36686 .60664 .38574 .60031 .39024 Mtetra
.758 .289 .133 r
.60031 .39024 .60664 .38574 .62041 .40595 .614 .40627 Mtetra
.683 .14 0 r
.614 .40627 .62041 .40595 .63436 .42382 .62781 .41832 Mtetra
.032 .486 .881 r
.62781 .41832 .63436 .42382 .6483 .43478 .64155 .4231 Mtetra
.664 .672 .847 r
.64155 .4231 .6483 .43478 .66197 .43478 .65504 .41806 Mtetra
.775 .653 .728 r
.65504 .41806 .66197 .43478 .67516 .42206 .66813 .40252 Mtetra
.816 .65 .677 r
.66813 .40252 .67516 .42206 .68777 .39813 .68076 .37822 Mtetra
.839 .658 .657 r
.68076 .37822 .68777 .39813 .6999 .36729 .69301 .34889 Mtetra
.854 .673 .656 r
.69301 .34889 .6999 .36729 .71178 .33486 .70508 .31887 Mtetra
.86 .692 .672 r
.70508 .31887 .71178 .33486 .72366 .3053 .71717 .29175 Mtetra
.856 .714 .704 r
.71717 .29175 .72366 .3053 .73575 .28113 .72945 .26956 Mtetra
.838 .736 .751 r
.72945 .26956 .73575 .28113 .74816 .26289 .74201 .25267 Mtetra
.805 .751 .802 r
.74201 .25267 .74816 .26289 .76091 .24974 .75487 .24032 Mtetra
.762 .756 .847 r
.75487 .24032 .76091 .24974 .77394 .24027 .76799 .23127 Mtetra
.721 .753 .877 r
.76799 .23127 .77394 .24027 .78719 .23313 .78131 .22432 Mtetra
.693 .748 .894 r
.78131 .22432 .78719 .23313 .8006 .22729 .79478 .21855 Mtetra
.677 .745 .902 r
.79478 .21855 .8006 .22729 .81413 .22209 .80835 .21336 Mtetra
.669 .743 .905 r
.80835 .21336 .81413 .22209 .82775 .21718 .82202 .20843 Mtetra
.658 .74 .91 r
.2012 .41393 .20876 .42098 .21974 .41736 .2122 .41025 Mtetra
.648 .736 .914 r
.2122 .41025 .21974 .41736 .23073 .41402 .22322 .40684 Mtetra
.624 .728 .922 r
.22322 .40684 .23073 .41402 .24171 .41139 .23424 .40404 Mtetra
.569 .706 .934 r
.23424 .40404 .24171 .41139 .25263 .41018 .2452 .40248 Mtetra
.451 .647 .942 r
.2452 .40248 .25263 .41018 .2634 .41151 .25605 .40305 Mtetra
.228 .508 .907 r
.25605 .40305 .2634 .41151 .27396 .41668 .26672 .4068 Mtetra
0 .281 .783 r
.26672 .4068 .27396 .41668 .28426 .42672 .27719 .41451 Mtetra
0 .087 .645 r
.27719 .41451 .28426 .42672 .29437 .44168 .28749 .42628 Mtetra
0 .017 .59 r
.28749 .42628 .29437 .44168 .30442 .46008 .29773 .44118 Mtetra
0 .047 .603 r
.29773 .44118 .30442 .46008 .31464 .4791 .30806 .45755 Mtetra
0 .117 .634 r
.30806 .45755 .31464 .4791 .32522 .49552 .3186 .47357 Mtetra
.098 .184 .666 r
.3186 .47357 .32522 .49552 .33628 .50694 .32943 .48787 Mtetra
.135 .242 .711 r
.32943 .48787 .33628 .50694 .34782 .51252 .34059 .49964 Mtetra
.095 .319 .795 r
.34059 .49964 .34782 .51252 .35975 .51254 .35208 .50811 Mtetra
0 .457 .825 r
.35208 .50811 .35975 .51254 .37199 .50752 .36394 .51207 Mtetra
.128 0 0 r
.36394 .51207 .37199 .50752 .38449 .49765 .37618 .50994 Mtetra
.005 0 0 r
.37618 .50994 .38449 .49765 .39719 .48291 .38879 .50043 Mtetra
0 0 0 r
.38879 .50043 .39719 .48291 .41002 .4637 .4017 .48343 Mtetra
.4017 .48343 .41002 .4637 .42289 .44125 .41478 .46034 Mtetra
.41478 .46034 .42289 .44125 .43572 .41746 .42787 .43377 Mtetra
.639 .772 .308 r
.42787 .43377 .43572 .41746 .44844 .39441 .44086 .40673 Mtetra
.755 .866 .437 r
.44086 .40673 .44844 .39441 .46102 .37383 .45368 .38183 Mtetra
.832 .942 .579 r
.45368 .38183 .46102 .37383 .47347 .35679 .46633 .36091 Mtetra
.852 .989 .722 r
.46633 .36091 .47347 .35679 .48583 .3437 .47883 .34492 Mtetra
.789 .998 .852 r
.47883 .34492 .48583 .3437 .49815 .33457 .49125 .33416 Mtetra
.585 .937 .934 r
.49125 .33416 .49815 .33457 .51046 .32924 .50363 .3286 Mtetra
.119 .667 .809 r
.50363 .3286 .51046 .32924 .52282 .32758 .51604 .32807 Mtetra
.407 0 0 r
.51604 .32807 .52282 .32758 .53527 .32959 .52855 .33232 Mtetra
.642 .115 0 r
.52855 .33232 .53527 .32959 .54785 .33532 .5412 .34097 Mtetra
.713 .248 .144 r
.5412 .34097 .54785 .33532 .56061 .34477 .55405 .35335 Mtetra
.73 .3 .228 r
.55405 .35335 .56061 .34477 .57359 .35766 .56713 .36829 Mtetra
.728 .313 .261 r
.56713 .36829 .57359 .35766 .58682 .37329 .58044 .38416 Mtetra
.713 .295 .253 r
.58044 .38416 .58682 .37329 .60031 .39024 .59396 .39888 Mtetra
.677 .229 .181 r
.59396 .39888 .60031 .39024 .614 .40627 .6076 .41011 Mtetra
.526 0 0 r
.6076 .41011 .614 .40627 .62781 .41832 .62127 .41551 Mtetra
.438 .83 .984 r
.62127 .41551 .62781 .41832 .64155 .4231 .63482 .41316 Mtetra
.785 .75 .821 r
.63482 .41316 .64155 .4231 .65504 .41806 .64812 .40211 Mtetra
.812 .676 .714 r
.64812 .40211 .65504 .41806 .66813 .40252 .66108 .38289 Mtetra
.822 .652 .673 r
.66108 .38289 .66813 .40252 .68076 .37822 .6737 .35757 Mtetra
.83 .65 .659 r
.6737 .35757 .68076 .37822 .69301 .34889 .68605 .32938 Mtetra
.836 .659 .662 r
.68605 .32938 .69301 .34889 .70508 .31887 .69829 .30169 Mtetra
.838 .675 .68 r
.69829 .30169 .70508 .31887 .71717 .29175 .71059 .27716 Mtetra
.832 .696 .713 r
.71059 .27716 .71717 .29175 .72945 .26956 .72306 .25718 Mtetra
.815 .718 .758 r
.72306 .25718 .72945 .26956 .74201 .25267 .73579 .24189 Mtetra
.786 .736 .807 r
.73579 .24189 .74201 .25267 .75487 .24032 .74877 .23054 Mtetra
.748 .745 .849 r
.74877 .23054 .75487 .24032 .76799 .23127 .76198 .22205 Mtetra
.713 .746 .878 r
.76198 .22205 .76799 .23127 .78131 .22432 .77537 .21537 Mtetra
.689 .745 .894 r
.77537 .21537 .78131 .22432 .79478 .21855 .7889 .2097 Mtetra
.675 .743 .902 r
.7889 .2097 .79478 .21855 .80835 .21336 .80253 .20454 Mtetra
.668 .742 .906 r
.80253 .20454 .80835 .21336 .82202 .20843 .81624 .19959 Mtetra
.659 .74 .91 r
.19357 .40681 .2012 .41393 .2122 .41025 .2046 .40309 Mtetra
.65 .737 .913 r
.2046 .40309 .2122 .41025 .22322 .40684 .21566 .39958 Mtetra
.631 .73 .919 r
.21566 .39958 .22322 .40684 .23424 .40404 .22672 .39658 Mtetra
.589 .711 .928 r
.22672 .39658 .23424 .40404 .2452 .40248 .23774 .39459 Mtetra
.505 .667 .935 r
.23774 .39459 .2452 .40248 .25605 .40305 .24867 .3943 Mtetra
.361 .574 .921 r
.24867 .3943 .25605 .40305 .26672 .4068 .25947 .39652 Mtetra
.176 .425 .86 r
.25947 .39652 .26672 .4068 .27719 .41451 .27011 .40187 Mtetra
.031 .273 .77 r
.27011 .40187 .27719 .41451 .28749 .42628 .28062 .41054 Mtetra
0 .179 .699 r
.28062 .41054 .28749 .42628 .29773 .44118 .29104 .42219 Mtetra
0 .141 .66 r
.29104 .42219 .29773 .44118 .30806 .45755 .30147 .43615 Mtetra
.006 .124 .638 r
.30147 .43615 .30806 .45755 .3186 .47357 .31197 .45172 Mtetra
0 .102 .625 r
.31197 .45172 .3186 .47357 .32943 .48787 .3226 .46834 Mtetra
0 .057 .609 r
.3226 .46834 .32943 .48787 .34059 .49964 .33341 .48524 Mtetra
0 0 .567 r
.33341 .48524 .34059 .49964 .35208 .50811 .34449 .50094 Mtetra
.56 .049 0 r
.34449 .50094 .35208 .50811 .36394 .51207 .35595 .51299 Mtetra
.517 0 0 r
.35595 .51299 .36394 .51207 .37618 .50994 .36789 .51842 Mtetra
.202 0 0 r
.36789 .51842 .37618 .50994 .38879 .50043 .38036 .51477 Mtetra
0 0 0 r
.38036 .51477 .38879 .50043 .4017 .48343 .39328 .50118 Mtetra
.39328 .50118 .4017 .48343 .41478 .46034 .4065 .47886 Mtetra
.4065 .47886 .41478 .46034 .42787 .43377 .41982 .45073 Mtetra
.711 .806 .339 r
.41982 .45073 .42787 .43377 .44086 .40673 .43308 .42053 Mtetra
.794 .867 .427 r
.43308 .42053 .44086 .40673 .45368 .38183 .44616 .39178 Mtetra
.843 .921 .527 r
.44616 .39178 .45368 .38183 .46633 .36091 .45903 .36715 Mtetra
.846 .966 .641 r
.45903 .36715 .46633 .36091 .47883 .34492 .4717 .34828 Mtetra
.758 .987 .76 r
.4717 .34828 .47883 .34492 .49125 .33416 .48422 .33592 Mtetra
.428 .867 .79 r
.48422 .33592 .49125 .33416 .50363 .3286 .49668 .33024 Mtetra
.206 0 0 r
.49668 .33024 .50363 .3286 .51604 .32807 .50916 .33103 Mtetra
.585 .047 0 r
.50916 .33103 .51604 .32807 .52855 .33232 .52172 .33776 Mtetra
.704 .233 .131 r
.52172 .33776 .52855 .33232 .5412 .34097 .53445 .34948 Mtetra
.734 .304 .23 r
.53445 .34948 .5412 .34097 .55405 .35335 .54739 .3647 Mtetra
.731 .323 .275 r
.54739 .3647 .55405 .35335 .56713 .36829 .56057 .38131 Mtetra
.71 .308 .285 r
.56057 .38131 .56713 .36829 .58044 .38416 .57396 .39676 Mtetra
.668 .255 .254 r
.57396 .39676 .58044 .38416 .59396 .39888 .5875 .40843 Mtetra
.569 .115 .135 r
.5875 .40843 .59396 .39888 .6076 .41011 .6011 .41406 Mtetra
.134 0 0 r
.6011 .41406 .6076 .41011 .62127 .41551 .61464 .4122 Mtetra
.804 .93 .917 r
.61464 .4122 .62127 .41551 .63482 .41316 .62801 .40238 Mtetra
.843 .749 .759 r
.62801 .40238 .63482 .41316 .64812 .40211 .64114 .38522 Mtetra
.828 .675 .693 r
.64114 .38522 .64812 .40211 .66108 .38289 .65399 .36232 Mtetra
.821 .647 .667 r
.65399 .36232 .66108 .38289 .6737 .35757 .66659 .33603 Mtetra
.819 .64 .661 r
.66659 .33603 .6737 .35757 .68605 .32938 .67904 .30903 Mtetra
.818 .646 .669 r
.67904 .30903 .68605 .32938 .69829 .30169 .69145 .28376 Mtetra
.816 .661 .69 r
.69145 .28376 .69829 .30169 .71059 .27716 .70394 .26194 Mtetra
.809 .682 .724 r
.70394 .26194 .71059 .27716 .72306 .25718 .71661 .24432 Mtetra
.793 .705 .768 r
.71661 .24432 .72306 .25718 .73579 .24189 .7295 .23077 Mtetra
.766 .724 .814 r
.7295 .23077 .73579 .24189 .74877 .23054 .74261 .22054 Mtetra
.734 .736 .853 r
.74261 .22054 .74877 .23054 .76198 .22205 .75592 .21268 Mtetra
.704 .741 .88 r
.75592 .21268 .76198 .22205 .77537 .21537 .76938 .20631 Mtetra
.684 .742 .895 r
.76938 .20631 .77537 .21537 .7889 .2097 .78297 .20077 Mtetra
.673 .742 .902 r
.78297 .20077 .7889 .2097 .80253 .20454 .79665 .19564 Mtetra
.667 .742 .906 r
.79665 .19564 .80253 .20454 .81624 .19959 .81041 .19068 Mtetra
.66 .74 .909 r
.18588 .39964 .19357 .40681 .2046 .40309 .19694 .39586 Mtetra
.653 .737 .912 r
.19694 .39586 .2046 .40309 .21566 .39958 .20803 .39225 Mtetra
.638 .731 .916 r
.20803 .39225 .21566 .39958 .22672 .39658 .21913 .38904 Mtetra
.607 .716 .922 r
.21913 .38904 .22672 .39658 .23774 .39459 .23022 .3866 Mtetra
.55 .684 .927 r
.23022 .3866 .23774 .39459 .24867 .3943 .24124 .38545 Mtetra
.459 .621 .92 r
.24124 .38545 .24867 .3943 .25947 .39652 .25217 .38619 Mtetra
.342 .521 .888 r
.25217 .38619 .25947 .39652 .27011 .40187 .26299 .38932 Mtetra
.231 .404 .829 r
.26299 .38932 .27011 .40187 .28062 .41054 .27369 .39516 Mtetra
.152 .3 .762 r
.27369 .39516 .28062 .41054 .29104 .42219 .2843 .40383 Mtetra
.092 .217 .702 r
.2843 .40383 .29104 .42219 .30147 .43615 .29484 .41543 Mtetra
.02 .141 .651 r
.29484 .41543 .30147 .43615 .31197 .45172 .30534 .43008 Mtetra
0 .053 .597 r
.30534 .43008 .31197 .45172 .3226 .46834 .31582 .4478 Mtetra
0 0 .528 r
.31582 .4478 .3226 .46834 .33341 .48524 .32636 .46798 Mtetra
0 0 .439 r
.32636 .46798 .33341 .48524 .34449 .50094 .3371 .48885 Mtetra
.615 .202 0 r
.3371 .48885 .34449 .50094 .35595 .51299 .3482 .5073 Mtetra
.634 .1 0 r
.3482 .5073 .35595 .51299 .36789 .51842 .35983 .51949 Mtetra
.32 0 0 r
.35983 .51949 .36789 .51842 .38036 .51477 .37208 .52198 Mtetra
0 0 0 r
.37208 .52198 .38036 .51477 .39328 .50118 .38491 .513 Mtetra
.63 .833 .432 r
.38491 .513 .39328 .50118 .4065 .47886 .39819 .49316 Mtetra
.772 .865 .429 r
.39819 .49316 .4065 .47886 .41982 .45073 .41168 .4653 Mtetra
.839 .881 .446 r
.41168 .4653 .41982 .45073 .43308 .42053 .42517 .43351 Mtetra
.874 .899 .482 r
.42517 .43351 .43308 .42053 .44616 .39178 .43849 .40206 Mtetra
.886 .924 .535 r
.43849 .40206 .44616 .39178 .45903 .36715 .45158 .37448 Mtetra
.861 .955 .607 r
.45158 .37448 .45903 .36715 .4717 .34828 .46442 .35319 Mtetra
.73 .961 .684 r
.46442 .35319 .4717 .34828 .48422 .33592 .47707 .3395 Mtetra
0 0 0 r
.47707 .3395 .48422 .33592 .49668 .33024 .48962 .33384 Mtetra
.389 0 0 r
.48962 .33384 .49668 .33024 .50916 .33103 .50215 .33596 Mtetra
.654 .162 .07 r
.50215 .33596 .50916 .33103 .52172 .33776 .51478 .34497 Mtetra
.73 .287 .199 r
.51478 .34497 .52172 .33776 .53445 .34948 .52757 .35928 Mtetra
.745 .329 .259 r
.52757 .35928 .53445 .34948 .54739 .3647 .54059 .37652 Mtetra
.732 .325 .279 r
.54059 .37652 .54739 .3647 .56057 .38131 .55385 .39365 Mtetra
.693 .282 .262 r
.55385 .39365 .56057 .38131 .57396 .39676 .5673 .40739 Mtetra
.606 .167 .18 r
.5673 .40739 .57396 .39676 .5875 .40843 .58086 .41485 Mtetra
.311 0 0 r
.58086 .41485 .5875 .40843 .6011 .41406 .5944 .4142 Mtetra
.708 .984 .887 r
.5944 .4142 .6011 .41406 .61464 .4122 .60783 .40503 Mtetra
.877 .82 .789 r
.60783 .40503 .61464 .4122 .62801 .40238 .62105 .38828 Mtetra
.848 .707 .707 r
.62105 .38828 .62801 .40238 .64114 .38522 .63405 .36588 Mtetra
.826 .657 .673 r
.63405 .36588 .64114 .38522 .65399 .36232 .64683 .3402 Mtetra
.813 .635 .661 r
.64683 .3402 .65399 .36232 .66659 .33603 .65945 .31363 Mtetra
.805 .629 .663 r
.65945 .31363 .66659 .33603 .67904 .30903 .672 .28824 Mtetra
.801 .635 .677 r
.672 .28824 .67904 .30903 .69145 .28376 .68458 .26559 Mtetra
.796 .65 .701 r
.68458 .26559 .69145 .28376 .70394 .26194 .69726 .24657 Mtetra
.787 .672 .737 r
.69726 .24657 .70394 .26194 .71661 .24432 .71012 .23135 Mtetra
.771 .696 .781 r
.71012 .23135 .71661 .24432 .7295 .23077 .72316 .21955 Mtetra
.747 .717 .824 r
.72316 .21955 .7295 .23077 .74261 .22054 .7364 .21045 Mtetra
.719 .731 .86 r
.7364 .21045 .74261 .22054 .75592 .21268 .7498 .20323 Mtetra
.696 .738 .883 r
.7498 .20323 .75592 .21268 .76938 .20631 .76334 .19717 Mtetra
.68 .74 .897 r
.76334 .19717 .76938 .20631 .78297 .20077 .77698 .19176 Mtetra
.671 .741 .903 r
.77698 .19176 .78297 .20077 .79665 .19564 .79072 .18666 Mtetra
.666 .741 .906 r
.79072 .18666 .79665 .19564 .81041 .19068 .80453 .18169 Mtetra
.66 .74 .909 r
.17814 .39242 .18588 .39964 .19694 .39586 .18923 .38858 Mtetra
.655 .738 .911 r
.18923 .38858 .19694 .39586 .20803 .39225 .20035 .38486 Mtetra
.644 .733 .913 r
.20035 .38486 .20803 .39225 .21913 .38904 .21149 .38144 Mtetra
.623 .722 .917 r
.21149 .38144 .21913 .38904 .23022 .3866 .22264 .37858 Mtetra
.585 .698 .92 r
.22264 .37858 .23022 .3866 .24124 .38545 .23375 .37665 Mtetra
.528 .654 .916 r
.23375 .37665 .24124 .38545 .25217 .38619 .2448 .37607 Mtetra
.452 .585 .896 r
.2448 .37607 .25217 .38619 .26299 .38932 .25578 .37726 Mtetra
.367 .495 .856 r
.25578 .37726 .26299 .38932 .27369 .39516 .26667 .38063 Mtetra
.279 .396 .803 r
.26667 .38063 .27369 .39516 .2843 .40383 .27746 .38662 Mtetra
.18 .292 .743 r
.27746 .38662 .2843 .40383 .29484 .41543 .28813 .3958 Mtetra
.056 .179 .677 r
.28813 .3958 .29484 .41543 .30534 .43008 .29868 .40883 Mtetra
0 .053 .599 r
.29868 .40883 .30534 .43008 .31582 .4478 .30911 .42616 Mtetra
0 0 .51 r
.30911 .42616 .31582 .4478 .32636 .46798 .31951 .44742 Mtetra
0 0 .431 r
.31951 .44742 .32636 .46798 .3371 .48885 .33001 .47091 Mtetra
0 0 .403 r
.33001 .47091 .3371 .48885 .3482 .5073 .34082 .49346 Mtetra
0 0 .483 r
.34082 .49346 .3482 .5073 .35983 .51949 .35215 .51087 Mtetra
0 .269 .763 r
.35215 .51087 .35983 .51949 .37208 .52198 .36414 .51907 Mtetra
.562 .872 .994 r
.36414 .51907 .37208 .52198 .38491 .513 .37681 .51544 Mtetra
.888 .988 .796 r
.37681 .51544 .38491 .513 .39819 .49316 .39003 .49971 Mtetra
.946 .953 .654 r
.39003 .49971 .39819 .49316 .41168 .4653 .40358 .47418 Mtetra
.957 .929 .591 r
.40358 .47418 .41168 .4653 .42517 .43351 .41721 .44289 Mtetra
.956 .924 .574 r
.41721 .44289 .42517 .43351 .43849 .40206 .43073 .41054 Mtetra
.943 .935 .588 r
.43073 .41054 .43849 .40206 .45158 .37448 .44401 .38137 Mtetra
.901 .959 .627 r
.44401 .38137 .45158 .37448 .46442 .35319 .45702 .35856 Mtetra
.74 .959 .668 r
.45702 .35856 .46442 .35319 .47707 .3395 .46979 .34403 Mtetra
0 0 0 r
.46979 .34403 .47707 .3395 .48962 .33384 .48242 .3385 Mtetra
.465 0 0 r
.48242 .3385 .48962 .33384 .50215 .33596 .49502 .34169 Mtetra
.682 .208 .118 r
.49502 .34169 .50215 .33596 .51478 .34497 .5077 .35229 Mtetra
.745 .306 .21 r
.5077 .35229 .51478 .34497 .52757 .35928 .52055 .36804 Mtetra
.754 .33 .243 r
.52055 .36804 .52757 .35928 .54059 .37652 .53364 .38575 Mtetra
.732 .304 .232 r
.53364 .38575 .54059 .37652 .55385 .39365 .54695 .40166 Mtetra
.663 .204 .152 r
.54695 .40166 .55385 .39365 .5673 .40739 .56044 .41209 Mtetra
.405 0 0 r
.56044 .41209 .5673 .40739 .58086 .41485 .57399 .41432 Mtetra
.633 .957 .924 r
.57399 .41432 .58086 .41485 .5944 .4142 .58748 .40723 Mtetra
.869 .826 .803 r
.58748 .40723 .5944 .4142 .60783 .40503 .60081 .39152 Mtetra
.852 .715 .711 r
.60081 .39152 .60783 .40503 .62105 .38828 .61393 .36932 Mtetra
.83 .661 .674 r
.61393 .36932 .62105 .38828 .63405 .36588 .62685 .34341 Mtetra
.812 .633 .66 r
.62685 .34341 .63405 .36588 .64683 .3402 .63961 .3165 Mtetra
.799 .62 .659 r
.63961 .3165 .64683 .3402 .65945 .31363 .65228 .29073 Mtetra
.79 .619 .668 r
.65228 .29073 .65945 .31363 .672 .28824 .66496 .26756 Mtetra
.783 .627 .687 r
.66496 .26756 .672 .28824 .68458 .26559 .67771 .24776 Mtetra
.776 .644 .716 r
.67771 .24776 .68458 .26559 .69726 .24657 .69057 .23151 Mtetra
.766 .667 .754 r
.69057 .23151 .69726 .24657 .71012 .23135 .7036 .21859 Mtetra
.75 .692 .796 r
.7036 .21859 .71012 .23135 .72316 .21955 .71679 .20845 Mtetra
.729 .714 .837 r
.71679 .20845 .72316 .21955 .7364 .21045 .73015 .20039 Mtetra
.706 .728 .868 r
.73015 .20039 .7364 .21045 .7498 .20323 .74364 .19376 Mtetra
.688 .736 .888 r
.74364 .19376 .7498 .20323 .76334 .19717 .75724 .18799 Mtetra
.675 .739 .899 r
.75724 .18799 .76334 .19717 .77698 .19176 .77095 .18269 Mtetra
.669 .741 .904 r
.77095 .18269 .77698 .19176 .79072 .18666 .78474 .17761 Mtetra
.666 .741 .906 r
.78474 .17761 .79072 .18666 .80453 .18169 .7986 .17263 Mtetra
.661 .74 .909 r
.17033 .38513 .17814 .39242 .18923 .38858 .18145 .38124 Mtetra
.658 .739 .91 r
.18145 .38124 .18923 .38858 .20035 .38486 .19261 .37743 Mtetra
.65 .735 .911 r
.19261 .37743 .20035 .38486 .21149 .38144 .20379 .37382 Mtetra
.636 .727 .914 r
.20379 .37382 .21149 .38144 .22264 .37858 .21499 .37059 Mtetra
.612 .71 .914 r
.21499 .37059 .22264 .37858 .23375 .37665 .22618 .368 Mtetra
.575 .679 .911 r
.22618 .368 .23375 .37665 .2448 .37607 .23735 .36632 Mtetra
.525 .631 .898 r
.23735 .36632 .2448 .37607 .25578 .37726 .24847 .36593 Mtetra
.461 .563 .872 r
.24847 .36593 .25578 .37726 .26667 .38063 .25952 .36724 Mtetra
.377 .476 .834 r
.25952 .36724 .26667 .38063 .27746 .38662 .27048 .37084 Mtetra
.267 .369 .783 r
.27048 .37084 .27746 .38662 .28813 .3958 .28131 .37756 Mtetra
.123 .241 .715 r
.28131 .37756 .28813 .3958 .29868 .40883 .29197 .38834 Mtetra
0 .099 .63 r
.29197 .38834 .29868 .40883 .30911 .42616 .30246 .40387 Mtetra
0 0 .541 r
.30246 .40387 .30911 .42616 .31951 .44742 .31283 .42409 Mtetra
0 0 .478 r
.31283 .42409 .31951 .44742 .33001 .47091 .32324 .44764 Mtetra
0 0 .473 r
.32324 .44764 .33001 .47091 .34082 .49346 .33387 .47168 Mtetra
0 0 .549 r
.33387 .47168 .34082 .49346 .35215 .51087 .34496 .49219 Mtetra
.063 .209 .704 r
.34496 .49219 .35215 .51087 .36414 .51907 .35668 .50491 Mtetra
.473 .533 .838 r
.35668 .50491 .36414 .51907 .37681 .51544 .36911 .50655 Mtetra
.784 .757 .829 r
.36911 .50655 .37681 .51544 .39003 .49971 .38217 .49599 Mtetra
.92 .844 .753 r
.38217 .49599 .39003 .49971 .40358 .47418 .39566 .47462 Mtetra
.967 .875 .691 r
.39566 .47462 .40358 .47418 .41721 .44289 .40933 .44602 Mtetra
.981 .895 .659 r
.40933 .44602 .41721 .44289 .43073 .41054 .42295 .4149 Mtetra
.977 .919 .656 r
.42295 .4149 .43073 .41054 .44401 .38137 .43637 .38592 Mtetra
.945 .959 .683 r
.43637 .38592 .44401 .38137 .45702 .35856 .44951 .36285 Mtetra
.8 .986 .725 r
.44951 .36285 .45702 .35856 .46979 .34403 .4624 .34813 Mtetra
0 0 0 r
.4624 .34813 .46979 .34403 .48242 .3385 .47512 .34279 Mtetra
.476 0 0 r
.47512 .34279 .48242 .3385 .49502 .34169 .48778 .34647 Mtetra
.69 .205 .092 r
.48778 .34647 .49502 .34169 .5077 .35229 .50051 .3575 Mtetra
.752 .293 .16 r
.50051 .3575 .5077 .35229 .52055 .36804 .51341 .37302 Mtetra
.759 .298 .156 r
.51341 .37302 .52055 .36804 .53364 .38575 .52654 .38925 Mtetra
.714 .217 .057 r
.52654 .38925 .53364 .38575 .54695 .40166 .53989 .40205 Mtetra
.459 0 0 r
.53989 .40205 .54695 .40166 .56044 .41209 .55338 .40781 Mtetra
.566 .845 .997 r
.55338 .40781 .56044 .41209 .57399 .41432 .5669 .40436 Mtetra
.808 .758 .806 r
.5669 .40436 .57399 .41432 .58748 .40723 .58033 .39149 Mtetra
.823 .684 .711 r
.58033 .39149 .58748 .40723 .60081 .39152 .59359 .37089 Mtetra
.816 .645 .671 r
.59359 .37089 .60081 .39152 .61393 .36932 .60666 .34542 Mtetra
.805 .623 .656 r
.60666 .34542 .61393 .36932 .62685 .34341 .61956 .3182 Mtetra
.793 .611 .654 r
.61956 .3182 .62685 .34341 .63961 .3165 .63236 .29184 Mtetra
.783 .607 .662 r
.63236 .29184 .63961 .3165 .65228 .29073 .64513 .26804 Mtetra
.774 .611 .678 r
.64513 .26804 .65228 .29073 .66496 .26756 .65795 .24762 Mtetra
.766 .624 .702 r
.65795 .24762 .66496 .26756 .67771 .24776 .67086 .23075 Mtetra
.758 .644 .735 r
.67086 .23075 .67771 .24776 .69057 .23151 .6839 .21715 Mtetra
.746 .669 .774 r
.6839 .21715 .69057 .23151 .7036 .21859 .69708 .2063 Mtetra
.731 .694 .815 r
.69708 .2063 .7036 .21859 .71679 .20845 .7104 .1976 Mtetra
.712 .714 .85 r
.7104 .1976 .71679 .20845 .73015 .20039 .72386 .19044 Mtetra
.694 .728 .876 r
.72386 .19044 .73015 .20039 .74364 .19376 .73743 .1843 Mtetra
.681 .735 .892 r
.73743 .1843 .74364 .19376 .75724 .18799 .7511 .17876 Mtetra
.672 .739 .901 r
.7511 .17876 .75724 .18799 .77095 .18269 .76486 .17355 Mtetra
.667 .74 .905 r
.76486 .17355 .77095 .18269 .78474 .17761 .7787 .16849 Mtetra
.665 .741 .907 r
.7787 .16849 .78474 .17761 .7986 .17263 .79262 .16348 Mtetra
.662 .741 .908 r
.16246 .37779 .17033 .38513 .18145 .38124 .17361 .37385 Mtetra
.659 .739 .909 r
.17361 .37385 .18145 .38124 .19261 .37743 .1848 .36995 Mtetra
.654 .737 .91 r
.1848 .36995 .19261 .37743 .20379 .37382 .19602 .36619 Mtetra
.645 .731 .911 r
.19602 .36619 .20379 .37382 .21499 .37059 .20727 .36266 Mtetra
.63 .719 .911 r
.20727 .36266 .21499 .37059 .22618 .368 .21854 .35954 Mtetra
.608 .698 .908 r
.21854 .35954 .22618 .368 .23735 .36632 .2298 .35702 Mtetra
.575 .664 .899 r
.2298 .35702 .23735 .36632 .24847 .36593 .24104 .35539 Mtetra
.527 .615 .883 r
.24104 .35539 .24847 .36593 .25952 .36724 .25224 .35504 Mtetra
.456 .544 .858 r
.25224 .35504 .25952 .36724 .27048 .37084 .26336 .35659 Mtetra
.353 .448 .819 r
.26336 .35659 .27048 .37084 .28131 .37756 .27435 .36092 Mtetra
.212 .323 .761 r
.27435 .36092 .28131 .37756 .29197 .38834 .28516 .36903 Mtetra
.051 .181 .681 r
.28516 .36903 .29197 .38834 .30246 .40387 .29579 .38175 Mtetra
0 .055 .597 r
.29579 .38175 .30246 .40387 .31283 .42409 .30627 .39928 Mtetra
0 0 .541 r
.30627 .39928 .31283 .42409 .32324 .44764 .31671 .42072 Mtetra
0 0 .533 r
.31671 .42072 .32324 .44764 .33387 .47168 .32729 .44381 Mtetra
0 .052 .575 r
.32729 .44381 .33387 .47168 .34496 .49219 .33823 .46507 Mtetra
.165 .197 .649 r
.33823 .46507 .34496 .49219 .35668 .50491 .34973 .48046 Mtetra
.412 .383 .716 r
.34973 .48046 .35668 .50491 .36911 .50655 .3619 .48647 Mtetra
.635 .552 .744 r
.3619 .48647 .36911 .50655 .38217 .49599 .37472 .48122 Mtetra
.79 .673 .735 r
.37472 .48122 .38217 .49599 .39566 .47462 .38804 .46516 Mtetra
.882 .752 .715 r
.38804 .46516 .39566 .47462 .40933 .44602 .40163 .44106 Mtetra
.931 .807 .7 r
.40163 .44106 .40933 .44602 .42295 .4149 .41526 .4132 Mtetra
.955 .857 .704 r
.41526 .4132 .42295 .4149 .43637 .38592 .42873 .38626 Mtetra
.953 .918 .739 r
.42873 .38626 .43637 .38592 .44951 .36285 .44196 .3643 Mtetra
.869 .992 .817 r
.44196 .3643 .44951 .36285 .4624 .34813 .45494 .35011 Mtetra
.359 .826 .76 r
.45494 .35011 .4624 .34813 .47512 .34279 .46773 .34491 Mtetra
.406 0 0 r
.46773 .34491 .47512 .34279 .48778 .34647 .48046 .34831 Mtetra
.663 .132 0 r
.48046 .34831 .48778 .34647 .50051 .3575 .49324 .35836 Mtetra
.729 .214 0 r
.49324 .35836 .50051 .3575 .51341 .37302 .50619 .37182 Mtetra
.696 .155 0 r
.50619 .37182 .51341 .37302 .52654 .38925 .51934 .38467 Mtetra
0 .196 .614 r
.51934 .38467 .52654 .38925 .53989 .40205 .5327 .39287 Mtetra
.463 .644 .936 r
.5327 .39287 .53989 .40205 .55338 .40781 .54617 .3933 Mtetra
.713 .654 .79 r
.54617 .3933 .55338 .40781 .5669 .40436 .55965 .38461 Mtetra
.768 .629 .706 r
.55965 .38461 .5669 .40436 .58033 .39149 .57303 .36746 Mtetra
.782 .611 .668 r
.57303 .36746 .58033 .39149 .59359 .37089 .58625 .34418 Mtetra
.784 .601 .652 r
.58625 .34418 .59359 .37089 .60666 .34542 .59931 .31789 Mtetra
.781 .595 .649 r
.59931 .31789 .60666 .34542 .61956 .3182 .61224 .29153 Mtetra
.774 .594 .655 r
.61224 .29153 .61956 .3182 .63236 .29184 .62512 .2673 Mtetra
.767 .598 .67 r
.62512 .2673 .63236 .29184 .64513 .26804 .63802 .24635 Mtetra
.758 .609 .692 r
.63802 .24635 .64513 .26804 .65795 .24762 .65098 .22899 Mtetra
.75 .626 .722 r
.65098 .22899 .65795 .24762 .67086 .23075 .66404 .21496 Mtetra
.74 .649 .759 r
.66404 .21496 .67086 .23075 .6839 .21715 .67723 .2037 Mtetra
.728 .675 .798 r
.67723 .2037 .6839 .21715 .69708 .2063 .69055 .1946 Mtetra
.714 .699 .835 r
.69055 .1946 .69708 .2063 .7104 .1976 .70398 .18708 Mtetra
.698 .717 .864 r
.70398 .18708 .7104 .1976 .72386 .19044 .71753 .18063 Mtetra
.685 .729 .884 r
.71753 .18063 .72386 .19044 .73743 .1843 .73117 .17487 Mtetra
.675 .736 .896 r
.73117 .17487 .73743 .1843 .7511 .17876 .74491 .16951 Mtetra
.669 .739 .903 r
.74491 .16951 .7511 .17876 .76486 .17355 .75873 .16436 Mtetra
.666 .74 .906 r
.75873 .16436 .76486 .17355 .7787 .16849 .77262 .15929 Mtetra
.664 .741 .907 r
.77262 .15929 .7787 .16849 .79262 .16348 .78658 .15426 Mtetra
.662 .741 .908 r
.15452 .3704 .16246 .37779 .17361 .37385 .1657 .3664 Mtetra
.661 .74 .909 r
.1657 .3664 .17361 .37385 .1848 .36995 .17692 .36244 Mtetra
.658 .738 .909 r
.17692 .36244 .1848 .36995 .19602 .36619 .18819 .35854 Mtetra
.652 .734 .909 r
.18819 .35854 .19602 .36619 .20727 .36266 .19948 .35479 Mtetra
.643 .726 .909 r
.19948 .35479 .20727 .36266 .21854 .35954 .21081 .35128 Mtetra
.629 .712 .906 r
.21081 .35128 .21854 .35954 .2298 .35702 .22215 .34814 Mtetra
.608 .689 .901 r
.22215 .34814 .2298 .35702 .24104 .35539 .23349 .34559 Mtetra
.574 .654 .891 r
.23349 .34559 .24104 .35539 .25224 .35504 .24481 .34397 Mtetra
.519 .601 .876 r
.24481 .34397 .25224 .35504 .26336 .35659 .25607 .34383 Mtetra
.434 .523 .85 r
.25607 .34383 .26336 .35659 .27435 .36092 .26723 .34596 Mtetra
.313 .414 .805 r
.26723 .34596 .27435 .36092 .28516 .36903 .27823 .35129 Mtetra
.171 .283 .737 r
.27823 .35129 .28516 .36903 .29579 .38175 .28905 .36069 Mtetra
.049 .161 .661 r
.28905 .36069 .29579 .38175 .30627 .39928 .29972 .37455 Mtetra
0 .085 .604 r
.29972 .37455 .30627 .39928 .31671 .42072 .3103 .39239 Mtetra
.002 .071 .582 r
.3103 .39239 .31671 .42072 .32729 .44381 .32094 .41261 Mtetra
.087 .116 .595 r
.32094 .41261 .32729 .44381 .33823 .46507 .33185 .43248 Mtetra
.226 .208 .629 r
.33185 .43248 .33823 .46507 .34973 .48046 .34321 .44851 Mtetra
.391 .326 .664 r
.34321 .44851 .34973 .48046 .3619 .48647 .35515 .45732 Mtetra
.55 .445 .688 r
.35515 .45732 .3619 .48647 .37472 .48122 .36771 .45663 Mtetra
.681 .55 .698 r
.36771 .45663 .37472 .48122 .38804 .46516 .38079 .44609 Mtetra
.779 .634 .701 r
.38079 .44609 .38804 .46516 .40163 .44106 .3942 .4275 Mtetra
.845 .702 .704 r
.3942 .4275 .40163 .44106 .41526 .4132 .40772 .40439 Mtetra
.887 .764 .72 r
.40772 .40439 .41526 .4132 .42873 .38626 .42117 .38102 Mtetra
.904 .83 .762 r
.42117 .38102 .42873 .38626 .44196 .3643 .43442 .36137 Mtetra
.869 .911 .856 r
.43442 .36137 .44196 .3643 .45494 .35011 .44745 .34831 Mtetra
.604 .921 .973 r
.44745 .34831 .45494 .35011 .46773 .34491 .46031 .34315 Mtetra
0 .49 .737 r
.46031 .34315 .46773 .34491 .48046 .34831 .4731 .34545 Mtetra
.456 0 0 r
.4731 .34545 .48046 .34831 .49324 .35836 .48594 .35318 Mtetra
.45 0 0 r
.48594 .35318 .49324 .35836 .50619 .37182 .49893 .36305 Mtetra
0 .319 .803 r
.49893 .36305 .50619 .37182 .51934 .38467 .5121 .37122 Mtetra
.414 .518 .855 r
.5121 .37122 .51934 .38467 .5327 .39287 .52545 .37416 Mtetra
.626 .564 .764 r
.52545 .37416 .5327 .39287 .54617 .3933 .53888 .36955 Mtetra
.705 .57 .7 r
.53888 .36955 .54617 .3933 .55965 .38461 .55232 .35688 Mtetra
.739 .571 .666 r
.55232 .35688 .55965 .38461 .57303 .36746 .56566 .33746 Mtetra
.754 .572 .65 r
.56566 .33746 .57303 .36746 .58625 .34418 .57887 .31382 Mtetra
.76 .574 .645 r
.57887 .31382 .58625 .34418 .59931 .31789 .59195 .28887 Mtetra
.76 .578 .65 r
.59195 .28887 .59931 .31789 .61224 .29153 .60495 .26507 Mtetra
.757 .585 .663 r
.60495 .26507 .61224 .29153 .62512 .2673 .61794 .24402 Mtetra
.751 .596 .684 r
.61794 .24402 .62512 .2673 .63802 .24635 .63096 .22637 Mtetra
.743 .613 .713 r
.63096 .22637 .63802 .24635 .65098 .22899 .64406 .21204 Mtetra
.735 .635 .748 r
.64406 .21204 .65098 .22899 .66404 .21496 .65726 .20054 Mtetra
.724 .66 .786 r
.65726 .20054 .66404 .21496 .67723 .2037 .67058 .19123 Mtetra
.712 .685 .823 r
.67058 .19123 .67723 .2037 .69055 .1946 .68401 .18351 Mtetra
.699 .706 .854 r
.68401 .18351 .69055 .1946 .70398 .18708 .69754 .17688 Mtetra
.687 .722 .876 r
.69754 .17688 .70398 .18708 .71753 .18063 .71116 .17096 Mtetra
.677 .732 .891 r
.71116 .17096 .71753 .18063 .73117 .17487 .72487 .16547 Mtetra
.671 .737 .9 r
.72487 .16547 .73117 .17487 .74491 .16951 .73867 .16022 Mtetra
.667 .74 .904 r
.73867 .16022 .74491 .16951 .75873 .16436 .75254 .1551 Mtetra
.665 .741 .906 r
.75254 .1551 .75873 .16436 .77262 .15929 .76648 .15002 Mtetra
.664 .741 .907 r
.76648 .15002 .77262 .15929 .78658 .15426 .78049 .14495 Mtetra
.663 .741 .908 r
.14652 .36294 .15452 .3704 .1657 .3664 .15773 .3589 Mtetra
.662 .74 .908 r
.15773 .3589 .1657 .3664 .17692 .36244 .16898 .35488 Mtetra
.66 .739 .908 r
.16898 .35488 .17692 .36244 .18819 .35854 .18028 .35088 Mtetra
.657 .736 .908 r
.18028 .35088 .18819 .35854 .19948 .35479 .19162 .34696 Mtetra
.652 .731 .908 r
.19162 .34696 .19948 .35479 .21081 .35128 .20299 .34318 Mtetra
.643 .722 .906 r
.20299 .34318 .21081 .35128 .22215 .34814 .2144 .33961 Mtetra
.63 .708 .902 r
.2144 .33961 .22215 .34814 .23349 .34559 .22582 .33641 Mtetra
.607 .684 .897 r
.22582 .33641 .23349 .34559 .24481 .34397 .23724 .33385 Mtetra
.567 .646 .888 r
.23724 .33385 .24481 .34397 .25607 .34383 .24863 .33237 Mtetra
.503 .587 .872 r
.24863 .33237 .25607 .34383 .26723 .34596 .25994 .33261 Mtetra
.409 .5 .841 r
.25994 .33261 .26723 .34596 .27823 .35129 .27114 .33537 Mtetra
.293 .388 .789 r
.27114 .33537 .27823 .35129 .28905 .36069 .28218 .34143 Mtetra
.187 .275 .723 r
.28218 .34143 .28905 .36069 .29972 .37455 .29307 .35128 Mtetra
.125 .193 .663 r
.29307 .35128 .29972 .37455 .3103 .39239 .30387 .3648 Mtetra
.124 .161 .628 r
.30387 .3648 .3103 .39239 .32094 .41261 .31468 .38099 Mtetra
.179 .177 .619 r
.31468 .38099 .32094 .41261 .33185 .43248 .32565 .39787 Mtetra
.274 .232 .628 r
.32565 .39787 .33185 .43248 .34321 .44851 .33696 .4127 Mtetra
.388 .308 .644 r
.33696 .4127 .34321 .44851 .35515 .45732 .34874 .42253 Mtetra
.504 .392 .66 r
.34874 .42253 .35515 .45732 .36771 .45663 .36106 .42504 Mtetra
.609 .474 .672 r
.36106 .42504 .36771 .45663 .38079 .44609 .37387 .41933 Mtetra
.695 .547 .682 r
.37387 .41933 .38079 .44609 .3942 .4275 .38705 .40632 Mtetra
.76 .612 .694 r
.38705 .40632 .3942 .4275 .40772 .40439 .40039 .38859 Mtetra
.805 .67 .715 r
.40039 .38859 .40772 .40439 .42117 .38102 .41374 .36968 Mtetra
.826 .727 .754 r
.41374 .36968 .42117 .38102 .43442 .36137 .42696 .35312 Mtetra
.806 .781 .829 r
.42696 .35312 .43442 .36137 .44745 .34831 .44 .34158 Mtetra
.683 .799 .936 r
.44 .34158 .44745 .34831 .46031 .34315 .45291 .33631 Mtetra
.393 .678 .974 r
.45291 .33631 .46031 .34315 .4731 .34545 .46576 .33689 Mtetra
.18 .5 .907 r
.46576 .33689 .4731 .34545 .48594 .35318 .47866 .34139 Mtetra
.25 .456 .865 r
.47866 .34139 .48594 .35318 .49893 .36305 .49168 .34682 Mtetra
.437 .484 .811 r
.49168 .34682 .49893 .36305 .5121 .37122 .50487 .3499 Mtetra
.575 .51 .746 r
.50487 .3499 .5121 .37122 .52545 .37416 .51819 .34789 Mtetra
.652 .526 .697 r
.51819 .34789 .52545 .37416 .53888 .36955 .53159 .33935 Mtetra
.695 .535 .666 r
.53159 .33935 .53888 .36955 .55232 .35688 .54498 .32445 Mtetra
.72 .543 .65 r
.54498 .32445 .55232 .35688 .56566 .33746 .55829 .30478 Mtetra
.733 .551 .645 r
.55829 .30478 .56566 .33746 .57887 .31382 .57151 .2827 Mtetra
.74 .559 .648 r
.57151 .2827 .57887 .31382 .59195 .28887 .58464 .26061 Mtetra
.742 .57 .66 r
.58464 .26061 .59195 .28887 .60495 .26507 .59772 .24033 Mtetra
.741 .583 .679 r
.59772 .24033 .60495 .26507 .61794 .24402 .61081 .22288 Mtetra
.737 .601 .706 r
.61081 .22288 .61794 .24402 .63096 .22637 .62396 .2085 Mtetra
.729 .624 .74 r
.62396 .2085 .63096 .22637 .64406 .21204 .63719 .19689 Mtetra
.72 .649 .778 r
.63719 .19689 .64406 .21204 .65726 .20054 .65051 .18748 Mtetra
.709 .675 .814 r
.65051 .18748 .65726 .20054 .67058 .19123 .66393 .17968 Mtetra
.698 .697 .846 r
.66393 .17968 .67058 .19123 .68401 .18351 .67745 .17297 Mtetra
.687 .715 .87 r
.67745 .17297 .68401 .18351 .69754 .17688 .69106 .16696 Mtetra
.678 .727 .887 r
.69106 .16696 .69754 .17688 .71116 .17096 .70475 .16139 Mtetra
.672 .734 .897 r
.70475 .16139 .71116 .17096 .72487 .16547 .71852 .15607 Mtetra
.668 .738 .903 r
.71852 .15607 .72487 .16547 .73867 .16022 .73237 .15089 Mtetra
.666 .74 .906 r
.73237 .15089 .73867 .16022 .75254 .1551 .74629 .14577 Mtetra
.664 .741 .907 r
.74629 .14577 .75254 .1551 .76648 .15002 .76028 .14067 Mtetra
.664 .741 .908 r
.76028 .14067 .76648 .15002 .78049 .14495 .77434 .13557 Mtetra
.663 .741 .908 r
.13846 .35543 .14652 .36294 .15773 .3589 .1497 .35135 Mtetra
.1497 .35135 .15773 .3589 .16898 .35488 .16098 .34727 Mtetra
.662 .74 .908 r
.16098 .34727 .16898 .35488 .18028 .35088 .17231 .3432 Mtetra
.66 .738 .908 r
.17231 .3432 .18028 .35088 .19162 .34696 .18369 .33916 Mtetra
.657 .735 .907 r
.18369 .33916 .19162 .34696 .20299 .34318 .1951 .33519 Mtetra
.652 .73 .906 r
.1951 .33519 .20299 .34318 .2144 .33961 .20656 .33133 Mtetra
.644 .721 .904 r
.20656 .33133 .2144 .33961 .22582 .33641 .21805 .3277 Mtetra
.629 .705 .901 r
.21805 .3277 .22582 .33641 .23724 .33385 .22955 .32447 Mtetra
.602 .68 .896 r
.22955 .32447 .23724 .33385 .24863 .33237 .24104 .32198 Mtetra
.558 .638 .887 r
.24104 .32198 .24863 .33237 .25994 .33261 .25249 .32071 Mtetra
.49 .574 .867 r
.25249 .32071 .25994 .33261 .27114 .33537 .26386 .32128 Mtetra
.402 .485 .83 r
.26386 .32128 .27114 .33537 .28218 .34143 .27512 .32434 Mtetra
.313 .385 .776 r
.27512 .32434 .28218 .34143 .29307 .35128 .28626 .3304 Mtetra
.25 .299 .719 r
.28626 .3304 .29307 .35128 .30387 .3648 .29731 .33957 Mtetra
.231 .25 .674 r
.29731 .33957 .30387 .3648 .31468 .38099 .30833 .35131 Mtetra
.257 .241 .649 r
.30833 .35131 .31468 .38099 .32565 .39787 .31945 .36433 Mtetra
.317 .265 .64 r
.31945 .36433 .32565 .39787 .33696 .4127 .3308 .37664 Mtetra
.396 .312 .643 r
.3308 .37664 .33696 .4127 .34874 .42253 .3425 .3859 Mtetra
.481 .37 .65 r
.3425 .3859 .34874 .42253 .36106 .42504 .35464 .39002 Mtetra
.563 .431 .659 r
.35464 .39002 .36106 .42504 .37387 .41933 .36721 .38786 Mtetra
.634 .49 .67 r
.36721 .38786 .37387 .41933 .38705 .40632 .38014 .37965 Mtetra
.691 .545 .683 r
.38014 .37965 .38705 .40632 .40039 .38859 .39327 .36707 Mtetra
.732 .595 .703 r
.39327 .36707 .40039 .38859 .41374 .36968 .40646 .35274 Mtetra
.751 .639 .736 r
.40646 .35274 .41374 .36968 .42696 .35312 .4196 .33951 Mtetra
.738 .67 .784 r
.4196 .33951 .42696 .35312 .44 .34158 .43263 .32961 Mtetra
.672 .671 .841 r
.43263 .32961 .44 .34158 .45291 .33631 .44557 .32412 Mtetra
.561 .618 .866 r
.44557 .32412 .45291 .33631 .46576 .33689 .45847 .32268 Mtetra
.489 .544 .84 r
.45847 .32268 .46576 .33689 .47866 .34139 .47142 .32367 Mtetra
.505 .504 .789 r
.47142 .32367 .47866 .34139 .49168 .34682 .48448 .32466 Mtetra
.564 .497 .738 r
.48448 .32466 .49168 .34682 .50487 .3499 .49768 .32315 Mtetra
.619 .502 .698 r
.49768 .32315 .50487 .3499 .51819 .34789 .51098 .31727 Mtetra
.66 .512 .671 r
.51098 .31727 .51819 .34789 .53159 .33935 .52433 .30634 Mtetra
.688 .521 .655 r
.52433 .30634 .53159 .33935 .54498 .32445 .53768 .29094 Mtetra
.707 .531 .649 r
.53768 .29094 .54498 .32445 .55829 .30478 .55097 .27263 Mtetra
.718 .542 .651 r
.55097 .27263 .55829 .30478 .57151 .2827 .5642 .25334 Mtetra
.725 .555 .66 r
.5642 .25334 .57151 .2827 .58464 .26061 .57739 .23483 Mtetra
.728 .571 .678 r
.57739 .23483 .58464 .26061 .59772 .24033 .59056 .21831 Mtetra
.728 .591 .703 r
.59056 .21831 .59772 .24033 .61081 .22288 .60375 .20432 Mtetra
.724 .615 .736 r
.60375 .20432 .61081 .22288 .62396 .2085 .61701 .19282 Mtetra
.716 .641 .773 r
.61701 .19282 .62396 .2085 .63719 .19689 .63034 .18342 Mtetra
.706 .668 .81 r
.63034 .18342 .63719 .19689 .65051 .18748 .64376 .1756 Mtetra
.696 .691 .842 r
.64376 .1756 .65051 .18748 .66393 .17968 .65727 .16888 Mtetra
.686 .71 .866 r
.65727 .16888 .66393 .17968 .67745 .17297 .67087 .16285 Mtetra
.678 .723 .884 r
.67087 .16285 .67745 .17297 .69106 .16696 .68454 .15725 Mtetra
.672 .731 .895 r
.68454 .15725 .69106 .16696 .70475 .16139 .6983 .15189 Mtetra
.668 .736 .901 r
.6983 .15189 .70475 .16139 .71852 .15607 .71212 .14667 Mtetra
.666 .739 .905 r
.71212 .14667 .71852 .15607 .73237 .15089 .72602 .14151 Mtetra
.665 .74 .906 r
.72602 .14151 .73237 .15089 .74629 .14577 .73999 .13638 Mtetra
.664 .741 .907 r
.73999 .13638 .74629 .14577 .76028 .14067 .75403 .13125 Mtetra
.664 .741 .908 r
.75403 .13125 .76028 .14067 .77434 .13557 .76814 .1261 Mtetra
.663 .741 .908 r
.13033 .34786 .13846 .35543 .1497 .35135 .14159 .34374 Mtetra
.14159 .34374 .1497 .35135 .16098 .34727 .15291 .33961 Mtetra
.662 .74 .908 r
.15291 .33961 .16098 .34727 .17231 .3432 .16427 .33548 Mtetra
.662 .739 .908 r
.16427 .33548 .17231 .3432 .18369 .33916 .17568 .33136 Mtetra
.66 .738 .907 r
.17568 .33136 .18369 .33916 .1951 .33519 .18714 .32726 Mtetra
.657 .735 .906 r
.18714 .32726 .1951 .33519 .20656 .33133 .19864 .32322 Mtetra
.653 .729 .905 r
.19864 .32322 .20656 .33133 .21805 .3277 .21017 .31929 Mtetra
.643 .72 .904 r
.21017 .31929 .21805 .3277 .22955 .32447 .22174 .31562 Mtetra
.627 .704 .901 r
.22174 .31562 .22955 .32447 .24104 .32198 .23332 .31241 Mtetra
.597 .676 .895 r
.23332 .31241 .24104 .32198 .25249 .32071 .24489 .31001 Mtetra
.552 .631 .883 r
.24489 .31001 .25249 .32071 .26386 .32128 .25641 .30886 Mtetra
.49 .565 .859 r
.25641 .30886 .26386 .32128 .27512 .32434 .26786 .30947 Mtetra
.419 .483 .819 r
.26786 .30947 .27512 .32434 .28626 .3304 .27923 .3123 Mtetra
.359 .402 .769 r
.27923 .3123 .28626 .3304 .29731 .33957 .29052 .31756 Mtetra
.327 .34 .721 r
.29052 .31756 .29731 .33957 .30833 .35131 .30179 .32505 Mtetra
.33 .31 .685 r
.30179 .32505 .30833 .35131 .31945 .36433 .31309 .33402 Mtetra
.361 .309 .664 r
.31309 .33402 .31945 .36433 .3308 .37664 .32455 .34313 Mtetra
.413 .332 .655 r
.32455 .34313 .3308 .37664 .3425 .3859 .33625 .35068 Mtetra
.474 .368 .654 r
.33625 .35068 .3425 .3859 .35464 .39002 .34829 .35499 Mtetra
.536 .412 .658 r
.34829 .35499 .35464 .39002 .36721 .38786 .36068 .3549 Mtetra
.593 .457 .666 r
.36068 .3549 .36721 .38786 .38014 .37965 .37338 .35023 Mtetra
.64 .502 .678 r
.37338 .35023 .38014 .37965 .39327 .36707 .3863 .34187 Mtetra
.675 .542 .695 r
.3863 .34187 .39327 .36707 .40646 .35274 .39933 .33158 Mtetra
.693 .576 .719 r
.39933 .33158 .40646 .35274 .4196 .33951 .41236 .3214 Mtetra
.687 .598 .75 r
.41236 .3214 .4196 .33951 .43263 .32961 .42536 .31302 Mtetra
.654 .597 .778 r
.42536 .31302 .43263 .32961 .44557 .32412 .43831 .30728 Mtetra
.607 .57 .787 r
.43831 .30728 .44557 .32412 .45847 .32268 .45126 .30393 Mtetra
.579 .534 .769 r
.45126 .30393 .45847 .32268 .47142 .32367 .46425 .30175 Mtetra
.585 .51 .737 r
.46425 .30175 .47142 .32367 .48448 .32466 .47734 .299 Mtetra
.61 .502 .706 r
.47734 .299 .48448 .32466 .49768 .32315 .49053 .29401 Mtetra
.639 .503 .681 r
.49053 .29401 .49768 .32315 .51098 .31727 .5038 .28571 Mtetra
.664 .51 .665 r
.5038 .28571 .51098 .31727 .52433 .30634 .51712 .27392 Mtetra
.684 .52 .658 r
.51712 .27392 .52433 .30634 .53768 .29094 .53043 .25938 Mtetra
.698 .531 .658 r
.53043 .25938 .53768 .29094 .55097 .27263 .54372 .24339 Mtetra
.708 .545 .666 r
.54372 .24339 .55097 .27263 .5642 .25334 .55697 .22736 Mtetra
.714 .562 .681 r
.55697 .22736 .5642 .25334 .57739 .23483 .5702 .21246 Mtetra
.717 .583 .704 r
.5702 .21246 .57739 .23483 .59056 .21831 .58345 .19938 Mtetra
.716 .608 .735 r
.58345 .19938 .59056 .21831 .60375 .20432 .59673 .18831 Mtetra
.711 .636 .771 r
.59673 .18831 .60375 .20432 .61701 .19282 .61008 .17909 Mtetra
.703 .663 .807 r
.61008 .17909 .61701 .19282 .63034 .18342 .6235 .17134 Mtetra
.694 .687 .84 r
.6235 .17134 .63034 .18342 .64376 .1756 .63701 .16464 Mtetra
.684 .707 .865 r
.63701 .16464 .64376 .1756 .65727 .16888 .65059 .15862 Mtetra
.677 .72 .882 r
.65059 .15862 .65727 .16888 .67087 .16285 .66425 .15302 Mtetra
.672 .73 .893 r
.66425 .15302 .67087 .16285 .68454 .15725 .67798 .14765 Mtetra
.668 .735 .9 r
.67798 .14765 .68454 .15725 .6983 .15189 .69179 .14241 Mtetra
.666 .738 .904 r
.69179 .14241 .6983 .15189 .71212 .14667 .70567 .13722 Mtetra
.665 .74 .906 r
.70567 .13722 .71212 .14667 .72602 .14151 .71961 .13206 Mtetra
.664 .741 .907 r
.71961 .13206 .72602 .14151 .73999 .13638 .73363 .1269 Mtetra
.664 .741 .908 r
.73363 .1269 .73999 .13638 .75403 .13125 .74772 .12173 Mtetra
.74772 .12173 .75403 .13125 .76814 .1261 .76188 .11654 Mtetra
.663 .741 .908 r
.12213 .34022 .13033 .34786 .14159 .34374 .13343 .33607 Mtetra
.13343 .33607 .14159 .34374 .15291 .33961 .14477 .3319 Mtetra
.14477 .3319 .15291 .33961 .16427 .33548 .15616 .32772 Mtetra
.663 .74 .908 r
.15616 .32772 .16427 .33548 .17568 .33136 .1676 .32353 Mtetra
.662 .739 .907 r
.1676 .32353 .17568 .33136 .18714 .32726 .17909 .31935 Mtetra
.66 .738 .907 r
.17909 .31935 .18714 .32726 .19864 .32322 .19063 .31518 Mtetra
.658 .735 .906 r
.19063 .31518 .19864 .32322 .21017 .31929 .20221 .31108 Mtetra
.652 .729 .905 r
.20221 .31108 .21017 .31929 .22174 .31562 .21383 .30711 Mtetra
.642 .719 .904 r
.21383 .30711 .22174 .31562 .23332 .31241 .22548 .30342 Mtetra
.624 .702 .901 r
.22548 .30342 .23332 .31241 .24489 .31001 .23714 .30022 Mtetra
.596 .672 .894 r
.23714 .30022 .24489 .31001 .25641 .30886 .24879 .29782 Mtetra
.554 .627 .878 r
.24879 .29782 .25641 .30886 .26786 .30947 .2604 .29658 Mtetra
.503 .565 .851 r
.2604 .29658 .26786 .30947 .27923 .3123 .27197 .29688 Mtetra
.452 .495 .813 r
.27197 .29688 .27923 .3123 .29052 .31756 .28348 .29895 Mtetra
.415 .431 .768 r
.28348 .29895 .29052 .31756 .30179 .32505 .29497 .30279 Mtetra
.4 .386 .728 r
.29497 .30279 .30179 .32505 .31309 .33402 .30648 .30802 Mtetra
.41 .365 .698 r
.30648 .30802 .31309 .33402 .32455 .34313 .31808 .31384 Mtetra
.438 .367 .679 r
.31808 .31384 .32455 .34313 .33625 .35068 .32985 .31909 Mtetra
.479 .384 .67 r
.32985 .31909 .33625 .35068 .34829 .35499 .34186 .32253 Mtetra
.524 .412 .668 r
.34186 .32253 .34829 .35499 .36068 .3549 .35413 .32319 Mtetra
.568 .444 .672 r
.35413 .32319 .36068 .3549 .37338 .35023 .36667 .32066 Mtetra
.606 .478 .68 r
.36667 .32066 .37338 .35023 .3863 .34187 .37941 .31529 Mtetra
.636 .511 .694 r
.37941 .31529 .3863 .34187 .39933 .33158 .39229 .30808 Mtetra
.653 .538 .711 r
.39229 .30808 .39933 .33158 .41236 .3214 .40522 .30033 Mtetra
.655 .556 .731 r
.40522 .30033 .41236 .3214 .42536 .31302 .41817 .2932 Mtetra
.643 .559 .745 r
.41817 .2932 .42536 .31302 .43831 .30728 .43112 .28727 Mtetra
.625 .548 .748 r
.43112 .28727 .43831 .30728 .45126 .30393 .44409 .2824 Mtetra
.615 .531 .736 r
.44409 .2824 .45126 .30393 .46425 .30175 .45712 .27782 Mtetra
.62 .517 .716 r
.45712 .27782 .46425 .30175 .47734 .299 .47022 .27246 Mtetra
.634 .511 .696 r
.47022 .27246 .47734 .299 .49053 .29401 .48341 .26534 Mtetra
.651 .512 .681 r
.48341 .26534 .49053 .29401 .5038 .28571 .49665 .25598 Mtetra
.668 .518 .673 r
.49665 .25598 .5038 .28571 .51712 .27392 .50994 .24452 Mtetra
.682 .528 .671 r
.50994 .24452 .51712 .27392 .53043 .25938 .52323 .23164 Mtetra
.692 .541 .677 r
.52323 .23164 .53043 .25938 .54372 .24339 .53651 .21828 Mtetra
.7 .559 .69 r
.53651 .21828 .54372 .24339 .55697 .22736 .54978 .20539 Mtetra
.706 .58 .711 r
.54978 .20539 .55697 .22736 .5702 .21246 .56306 .19363 Mtetra
.707 .605 .74 r
.56306 .19363 .5702 .21246 .58345 .19938 .57638 .18333 Mtetra
.705 .633 .773 r
.57638 .18333 .58345 .19938 .59673 .18831 .58974 .17451 Mtetra
.7 .661 .808 r
.58974 .17451 .59673 .18831 .61008 .17909 .60316 .16693 Mtetra
.691 .686 .84 r
.60316 .16693 .61008 .17909 .6235 .17134 .61665 .1603 Mtetra
.683 .705 .864 r
.61665 .1603 .6235 .17134 .63701 .16464 .63022 .15432 Mtetra
.676 .719 .882 r
.63022 .15432 .63701 .16464 .65059 .15862 .64387 .14873 Mtetra
.671 .729 .893 r
.64387 .14873 .65059 .15862 .66425 .15302 .65758 .14336 Mtetra
.668 .734 .9 r
.65758 .14336 .66425 .15302 .67798 .14765 .67137 .13811 Mtetra
.666 .738 .903 r
.67137 .13811 .67798 .14765 .69179 .14241 .68523 .13291 Mtetra
.665 .739 .906 r
.68523 .13291 .69179 .14241 .70567 .13722 .69915 .12773 Mtetra
.664 .74 .907 r
.69915 .12773 .70567 .13722 .71961 .13206 .71315 .12254 Mtetra
.664 .741 .907 r
.71315 .12254 .71961 .13206 .73363 .1269 .72722 .11735 Mtetra
.664 .741 .908 r
.72722 .11735 .73363 .1269 .74772 .12173 .74135 .11214 Mtetra
.74135 .11214 .74772 .12173 .76188 .11654 .75556 .1069 Mtetra
.663 .741 .908 r
.11387 .33253 .12213 .34022 .13343 .33607 .12519 .32834 Mtetra
.12519 .32834 .13343 .33607 .14477 .3319 .13656 .32413 Mtetra
.13656 .32413 .14477 .3319 .15616 .32772 .14798 .3199 Mtetra
.14798 .3199 .15616 .32772 .1676 .32353 .15946 .31567 Mtetra
.663 .74 .908 r
.15946 .31567 .1676 .32353 .17909 .31935 .17098 .31142 Mtetra
.662 .739 .907 r
.17098 .31142 .17909 .31935 .19063 .31518 .18255 .30718 Mtetra
.661 .738 .907 r
.18255 .30718 .19063 .31518 .20221 .31108 .19417 .30295 Mtetra
.658 .735 .906 r
.19417 .30295 .20221 .31108 .21383 .30711 .20584 .2988 Mtetra
.652 .729 .906 r
.20584 .2988 .21383 .30711 .22548 .30342 .21754 .29479 Mtetra
.642 .719 .904 r
.21754 .29479 .22548 .30342 .23714 .30022 .22927 .29106 Mtetra
.624 .7 .9 r
.22927 .29106 .23714 .30022 .24879 .29782 .24101 .28781 Mtetra
.599 .671 .89 r
.24101 .28781 .24879 .29782 .2604 .29658 .25275 .28528 Mtetra
.565 .628 .873 r
.25275 .28528 .2604 .29658 .27197 .29688 .26448 .28373 Mtetra
.526 .574 .846 r
.26448 .28373 .27197 .29688 .28348 .29895 .27618 .2834 Mtetra
.49 .516 .811 r
.27618 .2834 .28348 .29895 .29497 .30279 .28787 .28437 Mtetra
.467 .466 .773 r
.28787 .28437 .29497 .30279 .30648 .30802 .29957 .28648 Mtetra
.461 .432 .739 r
.29957 .28648 .30648 .30802 .31808 .31384 .31133 .28931 Mtetra
.472 .416 .714 r
.31133 .28931 .31808 .31384 .32985 .31909 .3232 .29215 Mtetra
.494 .417 .697 r
.3232 .29215 .32985 .31909 .34186 .32253 .33523 .29416 Mtetra
.524 .429 .689 r
.33523 .29416 .34186 .32253 .35413 .32319 .34746 .29459 Mtetra
.557 .45 .688 r
.34746 .29459 .35413 .32319 .36667 .32066 .3599 .29298 Mtetra
.587 .474 .692 r
.3599 .29298 .36667 .32066 .37941 .31529 .37252 .28934 Mtetra
.612 .499 .701 r
.37252 .28934 .37941 .31529 .39229 .30808 .38527 .28415 Mtetra
.629 .521 .712 r
.38527 .28415 .39229 .30808 .40522 .30033 .39812 .2781 Mtetra
.637 .537 .725 r
.39812 .2781 .40522 .30033 .41817 .2932 .41102 .27189 Mtetra
.638 .544 .733 r
.41102 .27189 .41817 .2932 .43112 .28727 .42396 .26588 Mtetra
.634 .543 .733 r
.42396 .26588 .43112 .28727 .44409 .2824 .43695 .26005 Mtetra
.634 .536 .725 r
.43695 .26005 .44409 .2824 .45712 .27782 .44999 .254 Mtetra
.639 .529 .713 r
.44999 .254 .45712 .27782 .47022 .27246 .4631 .24717 Mtetra
.649 .526 .701 r
.4631 .24717 .47022 .27246 .48341 .26534 .47628 .23914 Mtetra
.66 .529 .693 r
.47628 .23914 .48341 .26534 .49665 .25598 .4895 .22978 Mtetra
.671 .536 .691 r
.4895 .22978 .49665 .25598 .50994 .24452 .50276 .21935 Mtetra
.681 .547 .695 r
.50276 .21935 .50994 .24452 .52323 .23164 .51603 .20838 Mtetra
.689 .562 .706 r
.51603 .20838 .52323 .23164 .53651 .21828 .52932 .19749 Mtetra
.695 .583 .725 r
.52932 .19749 .53651 .21828 .54978 .20539 .54262 .18722 Mtetra
.699 .607 .75 r
.54262 .18722 .54978 .20539 .56306 .19363 .55594 .1779 Mtetra
.698 .634 .781 r
.55594 .1779 .56306 .19363 .57638 .18333 .56931 .16965 Mtetra
.695 .661 .813 r
.56931 .16965 .57638 .18333 .58974 .17451 .58273 .16238 Mtetra
.688 .686 .842 r
.58273 .16238 .58974 .17451 .60316 .16693 .59622 .15589 Mtetra
.681 .705 .866 r
.59622 .15589 .60316 .16693 .61665 .1603 .60977 .14996 Mtetra
.675 .719 .883 r
.60977 .14996 .61665 .1603 .63022 .15432 .6234 .14439 Mtetra
.67 .728 .893 r
.6234 .14439 .63022 .15432 .64387 .14873 .6371 .13903 Mtetra
.667 .734 .9 r
.6371 .13903 .64387 .14873 .65758 .14336 .65086 .13377 Mtetra
.666 .737 .904 r
.65086 .13377 .65758 .14336 .67137 .13811 .6647 .12856 Mtetra
.665 .739 .906 r
.6647 .12856 .67137 .13811 .68523 .13291 .67861 .12337 Mtetra
.664 .74 .907 r
.67861 .12337 .68523 .13291 .69915 .12773 .69258 .11816 Mtetra
.664 .741 .907 r
.69258 .11816 .69915 .12773 .71315 .12254 .70663 .11295 Mtetra
.664 .741 .908 r
.70663 .11295 .71315 .12254 .72722 .11735 .72074 .10771 Mtetra
.72074 .10771 .72722 .11735 .74135 .11214 .73493 .10245 Mtetra
.73493 .10245 .74135 .11214 .75556 .1069 .74918 .09717 Mtetra
.10554 .32477 .11387 .33253 .12519 .32834 .11689 .32054 Mtetra
.663 .741 .908 r
.11689 .32054 .12519 .32834 .13656 .32413 .12829 .3163 Mtetra
.12829 .3163 .13656 .32413 .14798 .3199 .13974 .31203 Mtetra
.13974 .31203 .14798 .3199 .15946 .31567 .15124 .30775 Mtetra
.15124 .30775 .15946 .31567 .17098 .31142 .16279 .30346 Mtetra
.663 .74 .908 r
.16279 .30346 .17098 .31142 .18255 .30718 .1744 .29916 Mtetra
.662 .74 .907 r
.1744 .29916 .18255 .30718 .19417 .30295 .18605 .29485 Mtetra
.661 .738 .907 r
.18605 .29485 .19417 .30295 .20584 .2988 .19776 .29057 Mtetra
.658 .735 .907 r
.19776 .29057 .20584 .2988 .21754 .29479 .20951 .28636 Mtetra
.652 .729 .906 r
.20951 .28636 .21754 .29479 .22927 .29106 .22129 .2823 Mtetra
.642 .718 .903 r
.22129 .2823 .22927 .29106 .24101 .28781 .23311 .2785 Mtetra
.627 .7 .898 r
.23311 .2785 .24101 .28781 .25275 .28528 .24495 .27512 Mtetra
.606 .673 .888 r
.24495 .27512 .25275 .28528 .26448 .28373 .25679 .27233 Mtetra
.579 .635 .871 r
.25679 .27233 .26448 .28373 .27618 .2834 .26864 .27031 Mtetra
.552 .59 .846 r
.26864 .27031 .27618 .2834 .28787 .28437 .28049 .26918 Mtetra
.528 .544 .815 r
.28049 .26918 .28787 .28437 .29957 .28648 .29236 .2689 Mtetra
.513 .504 .784 r
.29236 .2689 .29957 .28648 .31133 .28931 .30427 .26929 Mtetra
.511 .477 .756 r
.30427 .26929 .31133 .28931 .3232 .29215 .31625 .26994 Mtetra
.52 .464 .734 r
.31625 .26994 .3232 .29215 .33523 .29416 .32835 .27034 Mtetra
.537 .463 .721 r
.32835 .27034 .33523 .29416 .34746 .29459 .34059 .26996 Mtetra
.558 .472 .714 r
.34059 .26996 .34746 .29459 .3599 .29298 .35299 .2684 Mtetra
.58 .487 .713 r
.35299 .2684 .3599 .29298 .37252 .28934 .36553 .26549 Mtetra
.601 .504 .717 r
.36553 .26549 .37252 .28934 .38527 .28415 .37821 .26137 Mtetra
.618 .522 .723 r
.37821 .26137 .38527 .28415 .39812 .2781 .391 .25633 Mtetra
.629 .536 .73 r
.391 .25633 .39812 .2781 .41102 .27189 .40386 .25073 Mtetra
.637 .545 .734 r
.40386 .25073 .41102 .27189 .42396 .26588 .41679 .24478 Mtetra
.641 .549 .734 r
.41679 .24478 .42396 .26588 .43695 .26005 .42978 .23852 Mtetra
.646 .548 .73 r
.42978 .23852 .43695 .26005 .44999 .254 .44283 .23181 Mtetra
.652 .547 .723 r
.44283 .23181 .44999 .254 .4631 .24717 .45594 .22448 Mtetra
.659 .548 .718 r
.45594 .22448 .4631 .24717 .47628 .23914 .4691 .21641 Mtetra
.667 .553 .716 r
.4691 .21641 .47628 .23914 .4895 .22978 .48231 .20768 Mtetra
.675 .562 .719 r
.48231 .20768 .4895 .22978 .50276 .21935 .49555 .19854 Mtetra
.682 .575 .729 r
.49555 .19854 .50276 .21935 .51603 .20838 .50882 .18935 Mtetra
.688 .593 .745 r
.50882 .18935 .51603 .20838 .52932 .19749 .52211 .18047 Mtetra
.691 .615 .767 r
.52211 .18047 .52932 .19749 .54262 .18722 .53544 .17217 Mtetra
.692 .64 .793 r
.53544 .17217 .54262 .18722 .55594 .1779 .54881 .16458 Mtetra
.69 .665 .821 r
.54881 .16458 .55594 .1779 .56931 .16965 .56222 .15769 Mtetra
.685 .688 .847 r
.56222 .15769 .56931 .16965 .58273 .16238 .5757 .1514 Mtetra
.679 .707 .869 r
.5757 .1514 .58273 .16238 .59622 .15589 .58924 .14556 Mtetra
.674 .72 .884 r
.58924 .14556 .59622 .15589 .60977 .14996 .60285 .14002 Mtetra
.669 .729 .894 r
.60285 .14002 .60977 .14996 .6234 .14439 .61653 .13467 Mtetra
.667 .734 .9 r
.61653 .13467 .6234 .14439 .6371 .13903 .63027 .12941 Mtetra
.665 .737 .904 r
.63027 .12941 .6371 .13903 .65086 .13377 .64409 .12419 Mtetra
.664 .739 .906 r
.64409 .12419 .65086 .13377 .6647 .12856 .65797 .11898 Mtetra
.664 .74 .907 r
.65797 .11898 .6647 .12856 .67861 .12337 .67193 .11376 Mtetra
.664 .741 .907 r
.67193 .11376 .67861 .12337 .69258 .11816 .68595 .10852 Mtetra
.664 .741 .908 r
.68595 .10852 .69258 .11816 .70663 .11295 .70004 .10327 Mtetra
.70004 .10327 .70663 .11295 .72074 .10771 .71421 .09799 Mtetra
.71421 .09799 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31269 Mtetra
.10852 .31269 .11689 .32054 .12829 .3163 .11995 .3084 Mtetra
.663 .741 .908 r
.11995 .3084 .12829 .3163 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30775 .14296 .29978 Mtetra
.14296 .29978 .15124 .30775 .16279 .30346 .15454 .29545 Mtetra
.15454 .29545 .16279 .30346 .1744 .29916 .16618 .29109 Mtetra
.663 .74 .908 r
.16618 .29109 .1744 .29916 .18605 .29485 .17786 .28673 Mtetra
.662 .74 .908 r
.17786 .28673 .18605 .29485 .19776 .29057 .1896 .28237 Mtetra
.661 .738 .907 r
.1896 .28237 .19776 .29057 .20951 .28636 .20139 .27804 Mtetra
.658 .735 .907 r
.20139 .27804 .20951 .28636 .22129 .2823 .21322 .27377 Mtetra
.652 .729 .905 r
.21322 .27377 .22129 .2823 .23311 .2785 .2251 .26963 Mtetra
.644 .719 .902 r
.2251 .26963 .23311 .2785 .24495 .27512 .23701 .26571 Mtetra
.632 .702 .897 r
.23701 .26571 .24495 .27512 .25679 .27233 .24895 .26213 Mtetra
.615 .678 .886 r
.24895 .26213 .25679 .27233 .26864 .27031 .2609 .25901 Mtetra
.596 .647 .871 r
.2609 .25901 .26864 .27031 .28049 .26918 .27288 .25644 Mtetra
.577 .611 .85 r
.27288 .25644 .28049 .26918 .29236 .2689 .28488 .25446 Mtetra
.561 .575 .825 r
.28488 .25446 .29236 .2689 .30427 .26929 .29692 .25301 Mtetra
.552 .544 .799 r
.29692 .25301 .30427 .26929 .31625 .26994 .30902 .25188 Mtetra
.551 .522 .777 r
.30902 .25188 .31625 .26994 .32835 .27034 .3212 .25078 Mtetra
.558 .511 .759 r
.3212 .25078 .32835 .27034 .34059 .26996 .33348 .24937 Mtetra
.57 .509 .748 r
.33348 .24937 .34059 .26996 .35299 .2684 .34588 .24734 Mtetra
.585 .515 .742 r
.34588 .24734 .35299 .2684 .36553 .26549 .35841 .24449 Mtetra
.601 .525 .741 r
.35841 .24449 .36553 .26549 .37821 .26137 .37105 .24074 Mtetra
.616 .537 .743 r
.37105 .24074 .37821 .26137 .391 .25633 .3838 .23619 Mtetra
.629 .549 .746 r
.3838 .23619 .391 .25633 .40386 .25073 .39664 .23095 Mtetra
.639 .558 .747 r
.39664 .23095 .40386 .25073 .41679 .24478 .40956 .22515 Mtetra
.647 .565 .748 r
.40956 .22515 .41679 .24478 .42978 .23852 .42254 .21887 Mtetra
.654 .569 .746 r
.42254 .21887 .42978 .23852 .44283 .23181 .43559 .21211 Mtetra
.661 .572 .744 r
.43559 .21211 .44283 .23181 .45594 .22448 .4487 .2049 Mtetra
.667 .577 .744 r
.4487 .2049 .45594 .22448 .4691 .21641 .46185 .19729 Mtetra
.673 .584 .748 r
.46185 .19729 .4691 .21641 .48231 .20768 .47505 .18943 Mtetra
.678 .596 .756 r
.47505 .18943 .48231 .20768 .49555 .19854 .48829 .18151 Mtetra
.683 .611 .769 r
.48829 .18151 .49555 .19854 .50882 .18935 .50156 .17376 Mtetra
.685 .63 .788 r
.50156 .17376 .50882 .18935 .52211 .18047 .51487 .16635 Mtetra
.686 .651 .81 r
.51487 .16635 .52211 .18047 .53544 .17217 .52823 .1594 Mtetra
.684 .673 .833 r
.52823 .1594 .53544 .17217 .54881 .16458 .54164 .15291 Mtetra
.681 .693 .855 r
.54164 .15291 .54881 .16458 .56222 .15769 .5551 .14685 Mtetra
.676 .71 .873 r
.5551 .14685 .56222 .15769 .5757 .1514 .56862 .14112 Mtetra
.672 .722 .887 r
.56862 .14112 .5757 .1514 .58924 .14556 .58221 .13564 Mtetra
.669 .73 .896 r
.58221 .13564 .58924 .14556 .60285 .14002 .59587 .1303 Mtetra
.666 .735 .901 r
.59587 .1303 .60285 .14002 .61653 .13467 .6096 .12503 Mtetra
.665 .738 .904 r
.6096 .12503 .61653 .13467 .63027 .12941 .62339 .1198 Mtetra
.664 .739 .906 r
.62339 .1198 .63027 .12941 .64409 .12419 .63725 .11458 Mtetra
.664 .74 .907 r
.63725 .11458 .64409 .12419 .65797 .11898 .65119 .10934 Mtetra
.664 .741 .907 r
.65119 .10934 .65797 .11898 .67193 .11376 .66519 .10408 Mtetra
.664 .741 .908 r
.66519 .10408 .67193 .11376 .68595 .10852 .67926 .0988 Mtetra
.67926 .0988 .68595 .10852 .70004 .10327 .6934 .0935 Mtetra
.6934 .0935 .70004 .10327 .71421 .09799 .70762 .08817 Mtetra
.70762 .08817 .71421 .09799 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08867 .30906 .09714 .31695 .10852 .31269 .10008 .30476 Mtetra
.10008 .30476 .10852 .31269 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.663 .741 .908 r
.1346 .29175 .14296 .29978 .15454 .29545 .14622 .28737 Mtetra
.14622 .28737 .15454 .29545 .16618 .29109 .15788 .28298 Mtetra
.15788 .28298 .16618 .29109 .17786 .28673 .1696 .27857 Mtetra
.1696 .27857 .17786 .28673 .1896 .28237 .18137 .27415 Mtetra
.662 .74 .908 r
.18137 .27415 .1896 .28237 .20139 .27804 .1932 .26973 Mtetra
.661 .738 .907 r
.1932 .26973 .20139 .27804 .21322 .27377 .20507 .26534 Mtetra
.658 .735 .906 r
.20507 .26534 .21322 .27377 .2251 .26963 .21699 .26099 Mtetra
.654 .73 .905 r
.21699 .26099 .2251 .26963 .23701 .26571 .22896 .25676 Mtetra
.647 .72 .902 r
.22896 .25676 .23701 .26571 .24895 .26213 .24096 .2527 Mtetra
.638 .706 .896 r
.24096 .2527 .24895 .26213 .2609 .25901 .253 .24889 Mtetra
.626 .686 .887 r
.253 .24889 .2609 .25901 .27288 .25644 .26508 .2454 Mtetra
.612 .662 .874 r
.26508 .2454 .27288 .25644 .28488 .25446 .27718 .24229 Mtetra
.599 .634 .857 r
.27718 .24229 .28488 .25446 .29692 .25301 .28933 .23954 Mtetra
.589 .606 .837 r
.28933 .23954 .29692 .25301 .30902 .25188 .30153 .23707 Mtetra
.584 .583 .818 r
.30153 .23707 .30902 .25188 .3212 .25078 .31379 .23474 Mtetra
.584 .566 .8 r
.31379 .23474 .3212 .25078 .33348 .24937 .32613 .23234 Mtetra
.589 .557 .787 r
.32613 .23234 .33348 .24937 .34588 .24734 .33856 .22964 Mtetra
.598 .555 .777 r
.33856 .22964 .34588 .24734 .35841 .24449 .3511 .22646 Mtetra
.609 .558 .772 r
.3511 .22646 .35841 .24449 .37105 .24074 .36374 .22268 Mtetra
.621 .565 .77 r
.36374 .22268 .37105 .24074 .3838 .23619 .37648 .21826 Mtetra
.633 .573 .769 r
.37648 .21826 .3838 .23619 .39664 .23095 .38931 .21322 Mtetra
.644 .581 .769 r
.38931 .21322 .39664 .23095 .40956 .22515 .40222 .20762 Mtetra
.653 .589 .77 r
.40222 .20762 .40956 .22515 .42254 .21887 .41521 .20154 Mtetra
.661 .595 .771 r
.41521 .20154 .42254 .21887 .43559 .21211 .42825 .19506 Mtetra
.667 .602 .773 r
.42825 .19506 .43559 .21211 .4487 .2049 .44136 .18827 Mtetra
.672 .61 .777 r
.44136 .18827 .4487 .2049 .46185 .19729 .45451 .18131 Mtetra
.676 .62 .785 r
.45451 .18131 .46185 .19729 .47505 .18943 .46771 .17429 Mtetra
.679 .633 .796 r
.46771 .17429 .47505 .18943 .48829 .18151 .48096 .16737 Mtetra
.681 .649 .811 r
.48096 .16737 .48829 .18151 .50156 .17376 .49425 .16066 Mtetra
.681 .666 .829 r
.49425 .16066 .50156 .17376 .51487 .16635 .50758 .15423 Mtetra
.68 .684 .847 r
.50758 .15423 .51487 .16635 .52823 .1594 .52097 .1481 Mtetra
.677 .7 .864 r
.52097 .1481 .52823 .1594 .54164 .15291 .53442 .14227 Mtetra
.674 .714 .879 r
.53442 .14227 .54164 .15291 .5551 .14685 .54792 .13666 Mtetra
.67 .724 .89 r
.54792 .13666 .5551 .14685 .56862 .14112 .56149 .13123 Mtetra
.668 .731 .897 r
.56149 .13123 .56862 .14112 .58221 .13564 .57513 .1259 Mtetra
.666 .736 .902 r
.57513 .1259 .58221 .13564 .59587 .1303 .58883 .12064 Mtetra
.665 .738 .905 r
.58883 .12064 .59587 .1303 .6096 .12503 .60261 .11539 Mtetra
.664 .74 .906 r
.60261 .11539 .6096 .12503 .62339 .1198 .61645 .11015 Mtetra
.664 .74 .907 r
.61645 .11015 .62339 .1198 .63725 .11458 .63036 .10489 Mtetra
.664 .741 .907 r
.63036 .10489 .63725 .11458 .65119 .10934 .64434 .09962 Mtetra
.664 .741 .908 r
.64434 .09962 .65119 .10934 .66519 .10408 .65839 .09432 Mtetra
.65839 .09432 .66519 .10408 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28805 Mtetra
.11459 .28805 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.663 .741 .908 r
.13782 .27924 .14622 .28737 .15788 .28298 .14952 .2748 Mtetra
.14952 .2748 .15788 .28298 .1696 .27857 .16127 .27035 Mtetra
.16127 .27035 .1696 .27857 .18137 .27415 .17307 .26588 Mtetra
.17307 .26588 .18137 .27415 .1932 .26973 .18493 .26141 Mtetra
.662 .74 .908 r
.18493 .26141 .1932 .26973 .20507 .26534 .19684 .25693 Mtetra
.661 .738 .907 r
.19684 .25693 .20507 .26534 .21699 .26099 .2088 .25246 Mtetra
.659 .735 .906 r
.2088 .25246 .21699 .26099 .22896 .25676 .22081 .24804 Mtetra
.655 .731 .905 r
.22081 .24804 .22896 .25676 .24096 .2527 .23287 .24369 Mtetra
.65 .723 .902 r
.23287 .24369 .24096 .2527 .253 .24889 .24497 .23948 Mtetra
.643 .712 .897 r
.24497 .23948 .253 .24889 .26508 .2454 .25712 .23543 Mtetra
.635 .696 .889 r
.25712 .23543 .26508 .2454 .27718 .24229 .26931 .2316 Mtetra
.626 .677 .879 r
.26931 .2316 .27718 .24229 .28933 .23954 .28154 .228 Mtetra
.618 .657 .866 r
.28154 .228 .28933 .23954 .30153 .23707 .29382 .2246 Mtetra
.612 .637 .851 r
.29382 .2246 .30153 .23707 .31379 .23474 .30616 .22134 Mtetra
.609 .62 .837 r
.30616 .22134 .31379 .23474 .32613 .23234 .31856 .21811 Mtetra
.61 .607 .824 r
.31856 .21811 .32613 .23234 .33856 .22964 .33104 .21475 Mtetra
.614 .6 .813 r
.33104 .21475 .33856 .22964 .3511 .22646 .34361 .21112 Mtetra
.621 .598 .806 r
.34361 .21112 .3511 .22646 .36374 .22268 .35627 .20711 Mtetra
.63 .6 .801 r
.35627 .20711 .36374 .22268 .37648 .21826 .36902 .20265 Mtetra
.64 .605 .798 r
.36902 .20265 .37648 .21826 .38931 .21322 .38186 .19769 Mtetra
.65 .611 .797 r
.38186 .19769 .38931 .21322 .40222 .20762 .39477 .19229 Mtetra
.658 .618 .798 r
.39477 .19229 .40222 .20762 .41521 .20154 .40776 .18649 Mtetra
.665 .626 .801 r
.40776 .18649 .41521 .20154 .42825 .19506 .42081 .18039 Mtetra
.67 .635 .805 r
.42081 .18039 .42825 .19506 .44136 .18827 .43391 .1741 Mtetra
.674 .645 .812 r
.43391 .1741 .44136 .18827 .45451 .18131 .44708 .16774 Mtetra
.677 .656 .822 r
.44708 .16774 .45451 .18131 .46771 .17429 .46029 .16142 Mtetra
.678 .669 .834 r
.46029 .16142 .46771 .17429 .48096 .16737 .47355 .15521 Mtetra
.678 .682 .847 r
.47355 .15521 .48096 .16737 .49425 .16066 .48686 .14918 Mtetra
.676 .696 .861 r
.48686 .14918 .49425 .16066 .50758 .15423 .50023 .14334 Mtetra
.674 .708 .874 r
.50023 .14334 .50758 .15423 .52097 .1481 .51365 .13768 Mtetra
.671 .719 .885 r
.51365 .13768 .52097 .1481 .53442 .14227 .52714 .13219 Mtetra
.669 .727 .893 r
.52714 .13219 .53442 .14227 .54792 .13666 .54069 .1268 Mtetra
.667 .733 .899 r
.54069 .1268 .54792 .13666 .56149 .13123 .5543 .12149 Mtetra
.665 .736 .903 r
.5543 .12149 .56149 .13123 .57513 .1259 .56799 .11623 Mtetra
.665 .739 .905 r
.56799 .11623 .57513 .1259 .58883 .12064 .58174 .11097 Mtetra
.664 .74 .907 r
.58174 .11097 .58883 .12064 .60261 .11539 .59555 .10571 Mtetra
.664 .741 .907 r
.59555 .10571 .60261 .11539 .61645 .11015 .60944 .10043 Mtetra
.664 .741 .908 r
.60944 .10043 .61645 .11015 .63036 .10489 .6234 .09514 Mtetra
.6234 .09514 .63036 .10489 .64434 .09962 .63743 .08982 Mtetra
.63743 .08982 .64434 .09962 .65839 .09432 .65152 .08447 Mtetra
.65152 .08447 .65839 .09432 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28805 .10606 .27992 Mtetra
.10606 .27992 .11459 .28805 .12618 .28365 .11768 .27549 Mtetra
.11768 .27549 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.663 .741 .908 r
.15286 .26207 .16127 .27035 .17307 .26588 .1647 .25756 Mtetra
.1647 .25756 .17307 .26588 .18493 .26141 .17659 .25303 Mtetra
.17659 .25303 .18493 .26141 .19684 .25693 .18853 .24849 Mtetra
.662 .74 .908 r
.18853 .24849 .19684 .25693 .2088 .25246 .20053 .24395 Mtetra
.661 .739 .907 r
.20053 .24395 .2088 .25246 .22081 .24804 .21258 .23941 Mtetra
.66 .736 .906 r
.21258 .23941 .22081 .24804 .23287 .24369 .22468 .2349 Mtetra
.657 .732 .905 r
.22468 .2349 .23287 .24369 .24497 .23948 .23683 .23045 Mtetra
.653 .726 .902 r
.23683 .23045 .24497 .23948 .25712 .23543 .24903 .22607 Mtetra
.649 .717 .898 r
.24903 .22607 .25712 .23543 .26931 .2316 .26129 .22181 Mtetra
.643 .706 .893 r
.26129 .22181 .26931 .2316 .28154 .228 .27358 .21768 Mtetra
.638 .693 .885 r
.27358 .21768 .28154 .228 .29382 .2246 .28593 .21367 Mtetra
.633 .678 .875 r
.28593 .21367 .29382 .2246 .30616 .22134 .29834 .20977 Mtetra
.63 .664 .865 r
.29834 .20977 .30616 .22134 .31856 .21811 .31081 .2059 Mtetra
.629 .653 .855 r
.31081 .2059 .31856 .21811 .33104 .21475 .32334 .20199 Mtetra
.63 .644 .845 r
.32334 .20199 .33104 .21475 .34361 .21112 .33595 .19794 Mtetra
.635 .639 .837 r
.33595 .19794 .34361 .21112 .35627 .20711 .34864 .19365 Mtetra
.641 .638 .832 r
.34864 .19365 .35627 .20711 .36902 .20265 .36141 .18906 Mtetra
.648 .64 .828 r
.36141 .18906 .36902 .20265 .38186 .19769 .37426 .18413 Mtetra
.655 .644 .827 r
.37426 .18413 .38186 .19769 .39477 .19229 .38719 .17888 Mtetra
.662 .65 .828 r
.38719 .17888 .39477 .19229 .40776 .18649 .40019 .17334 Mtetra
.667 .658 .831 r
.40019 .17334 .40776 .18649 .42081 .18039 .41325 .1676 Mtetra
.671 .666 .837 r
.41325 .1676 .42081 .18039 .43391 .1741 .42637 .16175 Mtetra
.674 .676 .844 r
.42637 .16175 .43391 .1741 .44708 .16774 .43954 .15586 Mtetra
.675 .686 .853 r
.43954 .15586 .44708 .16774 .46029 .16142 .45277 .15002 Mtetra
.675 .697 .863 r
.45277 .15002 .46029 .16142 .47355 .15521 .46606 .14428 Mtetra
.673 .707 .873 r
.46606 .14428 .47355 .15521 .48686 .14918 .4794 .13864 Mtetra
.672 .716 .882 r
.4794 .13864 .48686 .14918 .50023 .14334 .49281 .13313 Mtetra
.67 .724 .89 r
.49281 .13313 .50023 .14334 .51365 .13768 .50627 .12771 Mtetra
.668 .73 .896 r
.50627 .12771 .51365 .13768 .52714 .13219 .5198 .12237 Mtetra
.666 .734 .901 r
.5198 .12237 .52714 .13219 .54069 .1268 .53339 .11707 Mtetra
.665 .737 .904 r
.53339 .11707 .54069 .1268 .5543 .12149 .54705 .1118 Mtetra
.664 .739 .906 r
.54705 .1118 .5543 .12149 .56799 .11623 .56078 .10653 Mtetra
.664 .74 .907 r
.56078 .10653 .56799 .11623 .58174 .11097 .57457 .10125 Mtetra
.664 .741 .907 r
.57457 .10125 .58174 .11097 .59555 .10571 .58844 .09595 Mtetra
.664 .741 .908 r
.58844 .09595 .59555 .10571 .60944 .10043 .60237 .09064 Mtetra
.60237 .09064 .60944 .10043 .6234 .09514 .61637 .08529 Mtetra
.61637 .08529 .6234 .09514 .63743 .08982 .63045 .07993 Mtetra
.63045 .07993 .63743 .08982 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27549 .10911 .26725 Mtetra
.10911 .26725 .11768 .27549 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25756 .15625 .24917 Mtetra
.663 .741 .908 r
.15625 .24917 .1647 .25756 .17659 .25303 .16817 .2446 Mtetra
.16817 .2446 .17659 .25303 .18853 .24849 .18015 .24001 Mtetra
.18015 .24001 .18853 .24849 .20053 .24395 .19218 .23541 Mtetra
.663 .74 .908 r
.19218 .23541 .20053 .24395 .21258 .23941 .20427 .23079 Mtetra
.662 .739 .907 r
.20427 .23079 .21258 .23941 .22468 .2349 .21641 .22618 Mtetra
.661 .737 .906 r
.21641 .22618 .22468 .2349 .23683 .23045 .2286 .22159 Mtetra
.659 .734 .905 r
.2286 .22159 .23683 .23045 .24903 .22607 .24085 .21702 Mtetra
.656 .729 .903 r
.24085 .21702 .24903 .22607 .26129 .22181 .25315 .21251 Mtetra
.653 .723 .9 r
.25315 .21251 .26129 .22181 .27358 .21768 .2655 .20805 Mtetra
.65 .715 .896 r
.2655 .20805 .27358 .21768 .28593 .21367 .27791 .20366 Mtetra
.646 .706 .89 r
.27791 .20366 .28593 .21367 .29834 .20977 .29038 .19933 Mtetra
.644 .696 .884 r
.29038 .19933 .29834 .20977 .31081 .2059 .3029 .19503 Mtetra
.643 .687 .877 r
.3029 .19503 .31081 .2059 .32334 .20199 .31548 .19072 Mtetra
.643 .68 .869 r
.31548 .19072 .32334 .20199 .33595 .19794 .32814 .18632 Mtetra
.646 .674 .863 r
.32814 .18632 .33595 .19794 .34864 .19365 .34087 .18179 Mtetra
.649 .672 .858 r
.34087 .18179 .34864 .19365 .36141 .18906 .35367 .17706 Mtetra
.654 .672 .855 r
.35367 .17706 .36141 .18906 .37426 .18413 .36654 .17212 Mtetra
.659 .675 .854 r
.36654 .17212 .37426 .18413 .38719 .17888 .37949 .16696 Mtetra
.663 .679 .855 r
.37949 .16696 .38719 .17888 .40019 .17334 .3925 .16162 Mtetra
.667 .686 .858 r
.3925 .16162 .40019 .17334 .41325 .1676 .40558 .15615 Mtetra
.67 .693 .863 r
.40558 .15615 .41325 .1676 .42637 .16175 .41872 .1506 Mtetra
.671 .701 .869 r
.41872 .1506 .42637 .16175 .43954 .15586 .43192 .14504 Mtetra
.671 .709 .876 r
.43192 .14504 .43954 .15586 .45277 .15002 .44518 .13951 Mtetra
.671 .716 .883 r
.44518 .13951 .45277 .15002 .46606 .14428 .4585 .13403 Mtetra
.669 .723 .889 r
.4585 .13403 .46606 .14428 .4794 .13864 .47188 .12861 Mtetra
.668 .729 .895 r
.47188 .12861 .4794 .13864 .49281 .13313 .48532 .12325 Mtetra
.667 .733 .899 r
.48532 .12325 .49281 .13313 .50627 .12771 .49882 .11793 Mtetra
.666 .736 .903 r
.49882 .11793 .50627 .12771 .5198 .12237 .51239 .11264 Mtetra
.665 .738 .905 r
.51239 .11264 .5198 .12237 .53339 .11707 .52603 .10736 Mtetra
.664 .74 .906 r
.52603 .10736 .53339 .11707 .54705 .1118 .53973 .10207 Mtetra
.664 .74 .907 r
.53973 .10207 .54705 .1118 .56078 .10653 .5535 .09677 Mtetra
.664 .741 .907 r
.5535 .09677 .56078 .10653 .57457 .10125 .56734 .09146 Mtetra
.664 .741 .908 r
.56734 .09146 .57457 .10125 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09064 .59523 .08075 Mtetra
.59523 .08075 .60237 .09064 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07993 .62341 .06994 Mtetra
.62341 .06994 .63045 .07993 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .2446 .15968 .23609 Mtetra
.663 .741 .908 r
.15968 .23609 .16817 .2446 .18015 .24001 .17169 .23146 Mtetra
.17169 .23146 .18015 .24001 .19218 .23541 .18376 .22681 Mtetra
.18376 .22681 .19218 .23541 .20427 .23079 .19588 .22214 Mtetra
.663 .74 .908 r
.19588 .22214 .20427 .23079 .21641 .22618 .20805 .21747 Mtetra
.662 .739 .907 r
.20805 .21747 .21641 .22618 .2286 .22159 .22029 .21278 Mtetra
.661 .738 .907 r
.22029 .21278 .2286 .22159 .24085 .21702 .23258 .2081 Mtetra
.66 .736 .906 r
.23258 .2081 .24085 .21702 .25315 .21251 .24492 .20343 Mtetra
.658 .732 .904 r
.24492 .20343 .25315 .21251 .2655 .20805 .25732 .19878 Mtetra
.657 .728 .902 r
.25732 .19878 .2655 .20805 .27791 .20366 .26978 .19416 Mtetra
.655 .723 .899 r
.26978 .19416 .27791 .20366 .29038 .19933 .28229 .18957 Mtetra
.653 .717 .895 r
.28229 .18957 .29038 .19933 .3029 .19503 .29486 .18498 Mtetra
.652 .711 .891 r
.29486 .18498 .3029 .19503 .31548 .19072 .3075 .18038 Mtetra
.652 .705 .886 r
.3075 .18038 .31548 .19072 .32814 .18632 .32019 .17574 Mtetra
.653 .701 .882 r
.32019 .17574 .32814 .18632 .34087 .18179 .33296 .17101 Mtetra
.655 .699 .878 r
.33296 .17101 .34087 .18179 .35367 .17706 .3458 .16617 Mtetra
.658 .698 .876 r
.3458 .16617 .35367 .17706 .36654 .17212 .3587 .1612 Mtetra
.661 .7 .875 r
.3587 .1612 .36654 .17212 .37949 .16696 .37167 .15609 Mtetra
.664 .703 .876 r
.37167 .15609 .37949 .16696 .3925 .16162 .38471 .15087 Mtetra
.666 .707 .878 r
.38471 .15087 .3925 .16162 .40558 .15615 .39782 .14556 Mtetra
.668 .712 .882 r
.39782 .14556 .40558 .15615 .41872 .1506 .41099 .1402 Mtetra
.668 .718 .886 r
.41099 .1402 .41872 .1506 .43192 .14504 .42422 .13482 Mtetra
.668 .723 .89 r
.42422 .13482 .43192 .14504 .44518 .13951 .43751 .12946 Mtetra
.668 .728 .895 r
.43751 .12946 .44518 .13951 .4585 .13403 .45086 .12411 Mtetra
.667 .732 .899 r
.45086 .12411 .4585 .13403 .47188 .12861 .46427 .11879 Mtetra
.666 .735 .902 r
.46427 .11879 .47188 .12861 .48532 .12325 .47775 .11349 Mtetra
.665 .737 .904 r
.47775 .11349 .48532 .12325 .49882 .11793 .4913 .10819 Mtetra
.664 .739 .906 r
.4913 .10819 .49882 .11793 .51239 .11264 .50491 .1029 Mtetra
.664 .74 .907 r
.50491 .1029 .51239 .11264 .52603 .10736 .51859 .0976 Mtetra
.664 .741 .907 r
.51859 .0976 .52603 .10736 .53973 .10207 .53234 .09228 Mtetra
.664 .741 .908 r
.53234 .09228 .53973 .10207 .5535 .09677 .54616 .08694 Mtetra
.54616 .08694 .5535 .09677 .56734 .09146 .56005 .08158 Mtetra
.56005 .08158 .56734 .09146 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22285 Mtetra
.663 .741 .908 r
.16316 .22285 .17169 .23146 .18376 .22681 .17526 .21815 Mtetra
.17526 .21815 .18376 .22681 .19588 .22214 .18742 .21344 Mtetra
.18742 .21344 .19588 .22214 .20805 .21747 .19963 .2087 Mtetra
.663 .74 .908 r
.19963 .2087 .20805 .21747 .22029 .21278 .21189 .20396 Mtetra
.663 .74 .907 r
.21189 .20396 .22029 .21278 .23258 .2081 .22422 .1992 Mtetra
.662 .739 .907 r
.22422 .1992 .23258 .2081 .24492 .20343 .2366 .19443 Mtetra
.661 .737 .906 r
.2366 .19443 .24492 .20343 .25732 .19878 .24904 .18967 Mtetra
.66 .735 .905 r
.24904 .18967 .25732 .19878 .26978 .19416 .26154 .1849 Mtetra
.659 .732 .903 r
.26154 .1849 .26978 .19416 .28229 .18957 .2741 .18014 Mtetra
.658 .729 .901 r
.2741 .18014 .28229 .18957 .29486 .18498 .28672 .17538 Mtetra
.658 .725 .899 r
.28672 .17538 .29486 .18498 .3075 .18038 .29939 .17059 Mtetra
.658 .722 .896 r
.29939 .17059 .3075 .18038 .32019 .17574 .31214 .16578 Mtetra
.658 .719 .894 r
.31214 .16578 .32019 .17574 .33296 .17101 .32494 .16091 Mtetra
.659 .717 .891 r
.32494 .16091 .33296 .17101 .3458 .16617 .33781 .15598 Mtetra
.661 .717 .89 r
.33781 .15598 .3458 .16617 .3587 .1612 .35075 .15096 Mtetra
.662 .717 .889 r
.35075 .15096 .3587 .1612 .37167 .15609 .36376 .14587 Mtetra
.664 .719 .89 r
.36376 .14587 .37167 .15609 .38471 .15087 .37683 .1407 Mtetra
.665 .722 .891 r
.37683 .1407 .38471 .15087 .39782 .14556 .38997 .13547 Mtetra
.666 .725 .893 r
.38997 .13547 .39782 .14556 .41099 .1402 .40316 .1302 Mtetra
.666 .729 .896 r
.40316 .1302 .41099 .1402 .42422 .13482 .41643 .12492 Mtetra
.666 .732 .899 r
.41643 .12492 .42422 .13482 .43751 .12946 .42975 .11962 Mtetra
.666 .735 .901 r
.42975 .11962 .43751 .12946 .45086 .12411 .44315 .11433 Mtetra
.665 .737 .903 r
.44315 .11433 .45086 .12411 .46427 .11879 .4566 .10903 Mtetra
.665 .738 .905 r
.4566 .10903 .46427 .11879 .47775 .11349 .47012 .10373 Mtetra
.664 .74 .906 r
.47012 .10373 .47775 .11349 .4913 .10819 .48371 .09843 Mtetra
.664 .74 .907 r
.48371 .09843 .4913 .10819 .50491 .1029 .49737 .09311 Mtetra
.664 .741 .907 r
.49737 .09311 .50491 .1029 .51859 .0976 .51109 .08777 Mtetra
.664 .741 .908 r
.51109 .08777 .51859 .0976 .53234 .09228 .52489 .08241 Mtetra
.52489 .08241 .53234 .09228 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22357 Mtetra
.13047 .22357 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22285 .15456 .21416 Mtetra
.15456 .21416 .16316 .22285 .17526 .21815 .16669 .20942 Mtetra
.663 .741 .908 r
.16669 .20942 .17526 .21815 .18742 .21344 .17888 .20466 Mtetra
.17888 .20466 .18742 .21344 .19963 .2087 .19112 .19988 Mtetra
.19112 .19988 .19963 .2087 .21189 .20396 .20343 .19508 Mtetra
.20343 .19508 .21189 .20396 .22422 .1992 .21579 .19027 Mtetra
.663 .74 .907 r
.21579 .19027 .22422 .1992 .2366 .19443 .22821 .18543 Mtetra
.662 .739 .907 r
.22821 .18543 .2366 .19443 .24904 .18967 .24068 .18059 Mtetra
.662 .738 .907 r
.24068 .18059 .24904 .18967 .26154 .1849 .25322 .17573 Mtetra
.662 .737 .906 r
.25322 .17573 .26154 .1849 .2741 .18014 .26582 .17086 Mtetra
.661 .735 .905 r
.26582 .17086 .2741 .18014 .28672 .17538 .27848 .16598 Mtetra
.661 .733 .903 r
.27848 .16598 .28672 .17538 .29939 .17059 .2912 .16108 Mtetra
.661 .731 .902 r
.2912 .16108 .29939 .17059 .31214 .16578 .30398 .15615 Mtetra
.661 .73 .901 r
.30398 .15615 .31214 .16578 .32494 .16091 .31683 .15118 Mtetra
.661 .729 .899 r
.31683 .15118 .32494 .16091 .33781 .15598 .32974 .14617 Mtetra
.662 .728 .899 r
.32974 .14617 .33781 .15598 .35075 .15096 .34271 .14111 Mtetra
.663 .729 .898 r
.34271 .14111 .35075 .15096 .36376 .14587 .35575 .136 Mtetra
.664 .729 .898 r
.35575 .136 .36376 .14587 .37683 .1407 .36886 .13083 Mtetra
.664 .731 .899 r
.36886 .13083 .37683 .1407 .38997 .13547 .38203 .12563 Mtetra
.665 .733 .901 r
.38203 .12563 .38997 .13547 .40316 .1302 .39526 .12039 Mtetra
.665 .735 .902 r
.39526 .12039 .40316 .1302 .41643 .12492 .40856 .11513 Mtetra
.665 .736 .903 r
.40856 .11513 .41643 .12492 .42975 .11962 .42193 .10986 Mtetra
.665 .738 .905 r
.42193 .10986 .42975 .11962 .44315 .11433 .43536 .10456 Mtetra
.664 .739 .906 r
.43536 .10456 .44315 .11433 .4566 .10903 .44886 .09926 Mtetra
.664 .74 .907 r
.44886 .09926 .4566 .10903 .47012 .10373 .46242 .09394 Mtetra
.664 .741 .907 r
.46242 .09394 .47012 .10373 .48371 .09843 .47605 .0886 Mtetra
.47605 .0886 .48371 .09843 .49737 .09311 .48975 .08324 Mtetra
.664 .741 .908 r
.48975 .08324 .49737 .09311 .51109 .08777 .50352 .07786 Mtetra
.50352 .07786 .51109 .08777 .52489 .08241 .51736 .07245 Mtetra
.51736 .07245 .52489 .08241 .53875 .07702 .53127 .06702 Mtetra
.53127 .06702 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.7322 .46942 m
.758 .47287 L
.76029 .4742 L
.78091 .5 L
.7838 .50796 L
.78788 .5258 L
.7886 .5516 L
.78462 .5774 L
.7838 .58157 L
.7777 .6032 L
.76368 .629 L
.758 .6364 L
.73994 .6548 L
.7322 .66017 L
.7064 .66775 L
.6806 .65678 L
.67789 .6548 L
.66185 .629 L
.6584 .6032 L
.6592 .5774 L
.66404 .5516 L
.67389 .5258 L
.6806 .51335 L
.68628 .5 L
.7064 .48229 L
.71904 .4742 L
.7322 .46942 L
s
.5774 .2517 m
.6032 .24416 L
.629 .24616 L
.6548 .25552 L
.6766 .2678 L
.6806 .27154 L
.70436 .2936 L
.7064 .29553 L
.72348 .3194 L
.7322 .33808 L
.73478 .3452 L
.73912 .371 L
.7322 .39641 L
.73196 .3968 L
.7064 .41617 L
.6806 .41665 L
.6548 .40939 L
.6298 .3968 L
.629 .39533 L
.6032 .37399 L
.60031 .371 L
.58007 .3452 L
.5774 .34032 L
.56744 .3194 L
.56196 .2936 L
.56643 .2678 L
.5774 .2517 L
s
.242 .47182 m
.25105 .4742 L
.2678 .48322 L
.28514 .5 L
.2936 .51046 L
.30391 .5258 L
.31583 .5516 L
.3194 .56782 L
.32169 .5774 L
.32461 .6032 L
.32096 .629 L
.3194 .63458 L
.30187 .6548 L
.2936 .65773 L
.27208 .6548 L
.2678 .65298 L
.242 .63238 L
.2386 .629 L
.21954 .6032 L
.2162 .59357 L
.20966 .5774 L
.20199 .5516 L
.19877 .5258 L
.20062 .5 L
.2162 .47833 L
.22433 .4742 L
.242 .47182 L
s
.4484 .65186 m
.4742 .64379 L
.5 .64212 L
.5258 .64543 L
.5516 .65408 L
.55327 .6548 L
.5774 .66769 L
.59011 .6806 L
.6032 .70084 L
.60533 .7064 L
.60697 .7322 L
.6032 .74328 L
.59336 .758 L
.5774 .77155 L
.5516 .78077 L
.5258 .78346 L
.5 .78194 L
.4742 .77574 L
.4484 .76264 L
.442 .758 L
.4226 .74126 L
.41837 .7322 L
.41011 .7064 L
.41581 .6806 L
.4226 .67086 L
.44242 .6548 L
.4484 .65186 L
s
.3452 .2611 m
.371 .25005 L
.3968 .24677 L
.4226 .2539 L
.43668 .2678 L
.4438 .2936 L
.44156 .3194 L
.43243 .3452 L
.4226 .36411 L
.41712 .371 L
.3968 .39384 L
.39397 .3968 L
.371 .41377 L
.35326 .4226 L
.3452 .42573 L
.3194 .43065 L
.2936 .42524 L
.28732 .4226 L
.26986 .3968 L
.26818 .371 L
.2736 .3452 L
.28591 .3194 L
.2936 .30718 L
.30466 .2936 L
.3194 .2792 L
.33331 .2678 L
.3452 .2611 L
s
0 g
.03 w
.72388 .56809 Mdot
.65065 .33059 Mdot
.26242 .56483 Mdot
.50904 .71301 Mdot
.3557 .33876 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.5 .69462 m
.51961 .69591 L
.52014 .69608 L
.53912 .71569 L
.51961 .73168 L
.5 .72945 L
.48388 .71569 L
.49478 .69608 L
.5 .69462 L
s
.26471 .54894 m
.26644 .55882 L
.26471 .56369 L
.25698 .55882 L
.26471 .54894 L
s
.73529 .51327 m
.74424 .51961 L
.75147 .53922 L
.75138 .55882 L
.74649 .57843 L
.73566 .59804 L
.73529 .59853 L
.71569 .61202 L
.69909 .59804 L
.69655 .57843 L
.6995 .55882 L
.70665 .53922 L
.71569 .52391 L
.72029 .51961 L
.73529 .51327 L
s
.5 .67506 m
.5186 .67647 L
.51961 .67665 L
.53922 .6796 L
.55882 .69478 L
.55976 .69608 L
.56969 .71569 L
.56133 .73529 L
.55882 .73889 L
.53922 .7509 L
.51961 .75255 L
.5 .75057 L
.48039 .74294 L
.47005 .73529 L
.46078 .72466 L
.45622 .71569 L
.4579 .69608 L
.46078 .69187 L
.48039 .67875 L
.48889 .67647 L
.5 .67506 L
s
.71569 .49502 m
.73529 .48202 L
.7549 .49457 L
.75926 .5 L
.76616 .51961 L
.76728 .53922 L
.76546 .55882 L
.76061 .57843 L
.7549 .59329 L
.75222 .59804 L
.74023 .61765 L
.73529 .62174 L
.71569 .63449 L
.69608 .63313 L
.68533 .61765 L
.68011 .59804 L
.68158 .57843 L
.68533 .55882 L
.69166 .53922 L
.69608 .52864 L
.70038 .51961 L
.70993 .5 L
.71569 .49502 L
s
.2451 .49211 m
.26378 .5 L
.26471 .50101 L
.27571 .51961 L
.28352 .53922 L
.28431 .54163 L
.29004 .55882 L
.29561 .57843 L
.28824 .59804 L
.28431 .60501 L
.26471 .60308 L
.25848 .59804 L
.2451 .58226 L
.24228 .57843 L
.23437 .55882 L
.22981 .53922 L
.22948 .51961 L
.23603 .5 L
.2451 .49211 L
s
.36275 .30257 m
.38229 .30392 L
.38235 .30396 L
.39477 .32353 L
.38645 .34314 L
.38235 .34905 L
.37039 .36275 L
.36275 .36971 L
.34314 .37726 L
.32353 .37337 L
.3164 .36275 L
.32072 .34314 L
.32353 .33749 L
.32873 .32353 L
.34314 .3105 L
.35908 .30392 L
.36275 .30257 L
s
.46078 .66954 m
.48039 .6631 L
.5 .66128 L
.51961 .6628 L
.53922 .66741 L
.55882 .67538 L
.56091 .67647 L
.57843 .68447 L
.58755 .69608 L
.59495 .71569 L
.58771 .73529 L
.57843 .74912 L
.56388 .7549 L
.55882 .75724 L
.53922 .76315 L
.51961 .76475 L
.5 .76275 L
.48039 .75694 L
.47544 .7549 L
.46078 .74758 L
.44771 .73529 L
.44118 .72664 L
.43596 .71569 L
.43573 .69608 L
.44118 .68566 L
.45009 .67647 L
.46078 .66954 L
s
.71569 .46066 m
.73529 .4471 L
.7549 .45975 L
.75626 .46078 L
.77118 .48039 L
.77426 .5 L
.77451 .50262 L
.7771 .51961 L
.77753 .53922 L
.77556 .55882 L
.77451 .56641 L
.77149 .57843 L
.76459 .59804 L
.7549 .61617 L
.7543 .61765 L
.73895 .63725 L
.73529 .64033 L
.71569 .6537 L
.7063 .65686 L
.69608 .65801 L
.68955 .65686 L
.67647 .64729 L
.67177 .63725 L
.66874 .61765 L
.66897 .59804 L
.67116 .57843 L
.67507 .55882 L
.67647 .55298 L
.68025 .53922 L
.6872 .51961 L
.69576 .5 L
.69608 .49938 L
.70229 .48039 L
.71554 .46078 L
.71569 .46066 L
s
.2451 .46011 m
.26038 .46078 L
.26471 .46386 L
.27528 .48039 L
.28316 .5 L
.28431 .50325 L
.29036 .51961 L
.29683 .53922 L
.30193 .55882 L
.30392 .5726 L
.30489 .57843 L
.30648 .59804 L
.30392 .61472 L
.30283 .61765 L
.28431 .6305 L
.26471 .62282 L
.25825 .61765 L
.2451 .60367 L
.24055 .59804 L
.22852 .57843 L
.22549 .5688 L
.22209 .55882 L
.21693 .53922 L
.21463 .51961 L
.21574 .5 L
.22335 .48039 L
.22549 .47736 L
.2435 .46078 L
.2451 .46011 L
s
.36275 .28305 m
.38235 .27951 L
.39959 .28431 L
.40196 .2859 L
.41329 .30392 L
.41224 .32353 L
.4049 .34314 L
.40196 .34947 L
.39249 .36275 L
.38235 .37382 L
.37292 .38235 L
.36275 .38876 L
.34314 .39841 L
.32996 .40196 L
.32353 .40305 L
.30739 .40196 L
.30392 .40045 L
.29333 .38235 L
.29527 .36275 L
.30182 .34314 L
.30392 .33755 L
.31233 .32353 L
.32353 .30921 L
.32844 .30392 L
.34314 .29267 L
.35946 .28431 L
.36275 .28305 L
s
.46078 .65525 m
.48039 .65077 L
.5 .64956 L
.51961 .65109 L
.53922 .65499 L
.5463 .65686 L
.55882 .66066 L
.57843 .6678 L
.59804 .67619 L
.59867 .67647 L
.61765 .68574 L
.62664 .69608 L
.6248 .71569 L
.61765 .72915 L
.61334 .73529 L
.59804 .75285 L
.59307 .7549 L
.57843 .76411 L
.55882 .77162 L
.54567 .77451 L
.53922 .77549 L
.51961 .77644 L
.50008 .77451 L
.5 .7745 L
.48039 .76972 L
.46078 .76141 L
.44996 .7549 L
.44118 .7491 L
.42804 .73529 L
.42157 .72606 L
.41665 .71569 L
.4148 .69608 L
.42157 .68075 L
.42512 .67647 L
.44118 .66318 L
.45597 .65686 L
.46078 .65525 L
s
.61765 .28911 m
.63725 .28646 L
.65686 .29455 L
.67381 .30392 L
.67647 .30792 L
.69142 .32353 L
.69608 .32868 L
.70518 .34314 L
.71569 .36235 L
.71589 .36275 L
.72844 .38235 L
.73529 .39698 L
.73976 .40196 L
.75341 .42157 L
.7549 .42359 L
.76845 .44118 L
.77451 .45721 L
.77609 .46078 L
.78282 .48039 L
.78667 .5 L
.78828 .51961 L
.78792 .53922 L
.78565 .55882 L
.78139 .57843 L
.77495 .59804 L
.77451 .59918 L
.76617 .61765 L
.7549 .63552 L
.75385 .63725 L
.73618 .65686 L
.73529 .65761 L
.71569 .67185 L
.70622 .67647 L
.69608 .68019 L
.67647 .68326 L
.65686 .67827 L
.65532 .67647 L
.65191 .65686 L
.65307 .63725 L
.655 .61765 L
.65686 .60027 L
.65743 .59804 L
.6606 .57843 L
.6648 .55882 L
.67012 .53922 L
.67643 .51961 L
.67647 .51948 L
.68297 .5 L
.68946 .48039 L
.69466 .46078 L
Mistroke
.69608 .4523 L
.69687 .44118 L
.69608 .43095 L
.69339 .42157 L
.68117 .40196 L
.67647 .3976 L
.65831 .38235 L
.65686 .38145 L
.63725 .36485 L
.63501 .36275 L
.6179 .34314 L
.61765 .34257 L
.6069 .32353 L
.60274 .30392 L
.61765 .28911 L
Mfstroke
.38235 .26239 m
.40196 .2632 L
.40699 .26471 L
.42157 .27187 L
.42851 .28431 L
.43166 .30392 L
.42821 .32353 L
.42157 .34058 L
.42035 .34314 L
.40842 .36275 L
.40196 .37121 L
.3917 .38235 L
.38235 .39077 L
.36737 .40196 L
.36275 .40477 L
.34314 .41537 L
.33018 .42157 L
.32353 .42427 L
.30392 .43556 L
.30006 .44118 L
.29263 .46078 L
.2934 .48039 L
.29698 .5 L
.30166 .51961 L
.30392 .52908 L
.30672 .53922 L
.31183 .55882 L
.31629 .57843 L
.31956 .59804 L
.32101 .61765 L
.3167 .63725 L
.30392 .65009 L
.28431 .64969 L
.26471 .63957 L
.26079 .63725 L
.2451 .62104 L
.24215 .61765 L
.22859 .59804 L
.22549 .5917 L
.21909 .57843 L
.21176 .55882 L
.207 .53922 L
.20588 .53182 L
.20455 .51961 L
.20462 .5 L
.20588 .49004 L
.20732 .48039 L
.21441 .46078 L
.22549 .44654 L
.23039 .44118 L
Mistroke
.2451 .42728 L
.2491 .42157 L
.26435 .40196 L
.26471 .40117 L
.27123 .38235 L
.27786 .36275 L
.28431 .34583 L
.28604 .34314 L
.29688 .32353 L
.30392 .31317 L
.31149 .30392 L
.32353 .2917 L
.33206 .28431 L
.34314 .27692 L
.36275 .26722 L
.37076 .26471 L
.38235 .26239 L
Mfstroke
.61765 .26425 m
.62314 .26471 L
.63725 .2675 L
.65686 .2756 L
.67174 .28431 L
.67647 .28814 L
.69444 .30392 L
.69608 .30559 L
.71184 .32353 L
.71569 .32842 L
.72621 .34314 L
.73529 .35691 L
.73908 .36275 L
.7517 .38235 L
.7549 .3877 L
.76405 .40196 L
.77451 .42079 L
.77493 .42157 L
.78425 .44118 L
.79093 .46078 L
.79412 .47394 L
.79535 .48039 L
.79794 .5 L
.79875 .51961 L
.7979 .53922 L
.79543 .55882 L
.79412 .5666 L
.79129 .57843 L
.78527 .59804 L
.77712 .61765 L
.77451 .62298 L
.76655 .63725 L
.7549 .65378 L
.75261 .65686 L
.73529 .67487 L
.73387 .67647 L
.71569 .69014 L
.70696 .69608 L
.69608 .70168 L
.67647 .71179 L
.66941 .71569 L
.65686 .72429 L
.64347 .73529 L
.63725 .74109 L
.62055 .7549 L
.61765 .75718 L
.59804 .76994 L
.58855 .77451 L
.57843 .77867 L
.55882 .78444 L
Mistroke
.53922 .78743 L
.51961 .78792 L
.5 .786 L
.48039 .78158 L
.46094 .77451 L
.46078 .77444 L
.44118 .76417 L
.42819 .7549 L
.42157 .74985 L
.40804 .73529 L
.40196 .72727 L
.3952 .71569 L
.38984 .69608 L
.39964 .67647 L
.40196 .66938 L
.42157 .65725 L
.42246 .65686 L
.44118 .64805 L
.46078 .64204 L
.48039 .63883 L
.5 .6381 L
.51961 .63959 L
.53922 .64292 L
.55882 .64751 L
.57843 .65231 L
.59804 .65543 L
.61765 .65253 L
.63378 .63725 L
.63725 .62788 L
.64074 .61765 L
.64572 .59804 L
.6501 .57843 L
.65472 .55882 L
.65686 .55041 L
.65995 .53922 L
.66575 .51961 L
.67162 .5 L
.67647 .481 L
.67656 .48039 L
.67909 .46078 L
.6776 .44118 L
.67647 .43663 L
.66956 .42157 L
.65686 .40524 L
.65352 .40196 L
.63725 .38674 L
.63241 .38235 L
.61765 .36805 L
.61274 .36275 L
.59804 .3444 L
Mistroke
.59722 .34314 L
.58593 .32353 L
.57964 .30392 L
.58055 .28431 L
.59804 .26611 L
.60844 .26471 L
.61765 .26425 L
Mfstroke
.34314 .26221 m
.36275 .25258 L
.38235 .24687 L
.40196 .24536 L
.42157 .24899 L
.44118 .2626 L
.44261 .26471 L
.44998 .28431 L
.44916 .30392 L
.44376 .32353 L
.44118 .33127 L
.43505 .34314 L
.42327 .36275 L
.42157 .36525 L
.40797 .38235 L
.40196 .38881 L
.38778 .40196 L
.38235 .4063 L
.36275 .42001 L
.36036 .42157 L
.34314 .43193 L
.32947 .44118 L
.32353 .44583 L
.31286 .46078 L
.30819 .48039 L
.30896 .5 L
.31233 .51961 L
.31693 .53922 L
.32191 .55882 L
.32353 .5651 L
.32676 .57843 L
.33131 .59804 L
.33531 .61765 L
.33808 .63725 L
.33692 .65686 L
.32353 .67084 L
.30392 .67256 L
.28431 .6671 L
.26667 .65686 L
.26471 .65544 L
.24512 .63725 L
.2451 .63721 L
.22973 .61765 L
.22549 .61069 L
.21828 .59804 L
.20918 .57843 L
.20588 .5699 L
.2023 .55882 L
.19728 .53922 L
.19425 .51961 L
Mistroke
.19341 .5 L
.19514 .48039 L
.20015 .46078 L
.20588 .44749 L
.20903 .44118 L
.22313 .42157 L
.22549 .41871 L
.23879 .40196 L
.2451 .3929 L
.25133 .38235 L
.26132 .36275 L
.26471 .35571 L
.27108 .34314 L
.28228 .32353 L
.28431 .3203 L
.29609 .30392 L
.30392 .29464 L
.31396 .28431 L
.32353 .27594 L
.33893 .26471 L
.34314 .26221 L
Mfstroke
.36275 .23796 m
.38235 .23163 L
.40196 .22861 L
.42157 .22924 L
.44118 .23433 L
.45885 .2451 L
.46078 .24583 L
.47193 .26471 L
.47353 .28431 L
.46828 .30392 L
.46078 .32352 L
.46076 .32353 L
.45033 .34314 L
.44118 .35859 L
.43831 .36275 L
.4237 .38235 L
.42157 .38493 L
.40564 .40196 L
.40196 .40543 L
.38263 .42157 L
.38235 .42177 L
.36275 .43567 L
.35489 .44118 L
.34314 .44996 L
.33281 .46078 L
.32353 .47939 L
.32327 .48039 L
.32138 .5 L
.32337 .51961 L
.32353 .52096 L
.32728 .53922 L
.33226 .55882 L
.33789 .57843 L
.34314 .59503 L
.34404 .59804 L
.35084 .61765 L
.36215 .63725 L
.36275 .63755 L
.38235 .64839 L
.40196 .64585 L
.42157 .63973 L
.42968 .63725 L
.44118 .6337 L
.46078 .62923 L
.48039 .6268 L
.5 .62642 L
.51961 .62789 L
.53922 .63079 L
.55882 .63436 L
.57843 .6372 L
Mistroke
.59804 .63659 L
.61765 .62585 L
.62427 .61765 L
.63295 .59804 L
.63725 .58357 L
.63873 .57843 L
.64411 .55882 L
.64949 .53922 L
.65494 .51961 L
.65686 .51313 L
.66007 .5 L
.66385 .48039 L
.66471 .46078 L
.6607 .44118 L
.65686 .43145 L
.64986 .42157 L
.63725 .40694 L
.63221 .40196 L
.61765 .38785 L
.61204 .38235 L
.59804 .36771 L
.59373 .36275 L
.57843 .34324 L
.57836 .34314 L
.56592 .32353 L
.55882 .31323 L
.55659 .30392 L
.55191 .28431 L
.55577 .26471 L
.55882 .25798 L
.57843 .2473 L
.58869 .2451 L
.59804 .24408 L
.6163 .2451 L
.61765 .2453 L
.63725 .25025 L
.65686 .25872 L
.66776 .26471 L
.67647 .27061 L
.69392 .28431 L
.69608 .28625 L
.71384 .30392 L
.71569 .30595 L
.73041 .32353 L
.73529 .32985 L
.74503 .34314 L
.7549 .35737 L
.75852 .36275 L
.77113 .38235 L
.77451 .38803 L
Mistroke
.7824 .40196 L
.7918 .42157 L
.79412 .42731 L
.79907 .44118 L
.80432 .46078 L
.80768 .48039 L
.80938 .5 L
.80956 .51961 L
.80829 .53922 L
.80559 .55882 L
.80144 .57843 L
.79575 .59804 L
.79412 .60287 L
.78825 .61765 L
.77867 .63725 L
.77451 .64457 L
.76667 .65686 L
.7549 .67235 L
.75151 .67647 L
.73529 .69306 L
.73214 .69608 L
.71569 .70944 L
.70724 .71569 L
.69608 .72339 L
.67853 .73529 L
.67647 .73672 L
.65686 .75065 L
.65087 .7549 L
.63725 .76441 L
.62081 .77451 L
.61765 .77629 L
.59804 .78576 L
.57843 .79263 L
.57348 .79412 L
.55882 .79712 L
.53922 .79939 L
.51961 .79956 L
.5 .79766 L
.48176 .79412 L
.48039 .79364 L
.46078 .7873 L
.44118 .77844 L
.434 .77451 L
.42157 .76677 L
.40595 .7549 L
.40196 .75178 L
.38464 .73529 L
.38235 .73375 L
.36443 .71569 L
.36275 .71428 L
Mistroke
.34314 .70342 L
.32353 .69808 L
.3149 .69608 L
.30392 .69274 L
.28431 .68426 L
.27018 .67647 L
.26471 .67146 L
.2481 .65686 L
.2451 .65338 L
.23151 .63725 L
.22549 .62864 L
.21847 .61765 L
.20782 .59804 L
.20588 .594 L
.1993 .57843 L
.19247 .55882 L
.18737 .53922 L
.18627 .53637 L
.18411 .51961 L
.18271 .5 L
.18346 .48039 L
.18627 .463 L
.18678 .46078 L
.19323 .44118 L
.20363 .42157 L
.20588 .41807 L
.21737 .40196 L
.22549 .39109 L
.23173 .38235 L
.2443 .36275 L
.2451 .3614 L
.25572 .34314 L
.26471 .32793 L
.26748 .32353 L
.28095 .30392 L
.28431 .2995 L
.29729 .28431 L
.30392 .2775 L
.31815 .26471 L
.32353 .26052 L
.34314 .2475 L
.34711 .2451 L
.36275 .23796 L
Mfstroke
.5 .30815 m
.51961 .30626 L
.53922 .32186 L
.54144 .32353 L
.55805 .34314 L
.55882 .34436 L
.57449 .36275 L
.57843 .36738 L
.59238 .38235 L
.59804 .38818 L
.61188 .40196 L
.61765 .40767 L
.6304 .42157 L
.63725 .42995 L
.64356 .44118 L
.64984 .46078 L
.6506 .48039 L
.64788 .5 L
.64328 .51961 L
.63787 .53922 L
.63725 .54138 L
.63237 .55882 L
.626 .57843 L
.61765 .5966 L
.61701 .59804 L
.59804 .61665 L
.59579 .61765 L
.57843 .62123 L
.55882 .6203 L
.53922 .61767 L
.53907 .61765 L
.51961 .61524 L
.5 .61385 L
.48039 .61396 L
.46078 .61572 L
.44793 .61765 L
.44118 .61902 L
.42157 .62311 L
.40196 .62584 L
.38235 .62258 L
.37452 .61765 L
.36275 .60388 L
.35911 .59804 L
.35022 .57843 L
.34393 .55882 L
.34314 .55637 L
.33873 .53922 L
.33529 .51961 L
.33486 .5 L
.33986 .48039 L
Mistroke
.34314 .47346 L
.35431 .46078 L
.36275 .45322 L
.37858 .44118 L
.38235 .4383 L
.40196 .42255 L
.40309 .42157 L
.42157 .4039 L
.42339 .40196 L
.44028 .38235 L
.44118 .38123 L
.45482 .36275 L
.46078 .35456 L
.4679 .34314 L
.48039 .32723 L
.4833 .32353 L
.5 .30815 L
Mfstroke
.36275 .2224 m
.38235 .21561 L
.40196 .21147 L
.42157 .21009 L
.44118 .21157 L
.46078 .21596 L
.48039 .22294 L
.48674 .22549 L
.5 .22892 L
.51961 .23109 L
.53922 .22888 L
.55817 .22549 L
.55882 .22537 L
.57843 .22334 L
.59804 .22396 L
.60901 .22549 L
.61765 .22725 L
.63725 .23324 L
.65686 .24192 L
.66296 .2451 L
.67647 .2534 L
.69216 .26471 L
.69608 .26789 L
.71435 .28431 L
.71569 .28563 L
.73283 .30392 L
.73529 .30675 L
.74906 .32353 L
.7549 .33108 L
.76382 .34314 L
.77451 .35845 L
.77735 .36275 L
.78942 .38235 L
.79412 .39091 L
.7996 .40196 L
.80773 .42157 L
.81373 .44088 L
.8138 .44118 L
.81794 .46078 L
.82042 .48039 L
.82142 .5 L
.82107 .51961 L
.81946 .53922 L
.81665 .55882 L
.81373 .57392 L
.8126 .57843 L
.80702 .59804 L
.79998 .61765 L
.79412 .63147 L
.79132 .63725 L
Mistroke
.78059 .65686 L
.77451 .66655 L
.76762 .67647 L
.7549 .69253 L
.75186 .69608 L
.73529 .71325 L
.73276 .71569 L
.71569 .73064 L
.70994 .73529 L
.69608 .74597 L
.68381 .7549 L
.67647 .76005 L
.65686 .773 L
.65442 .77451 L
.63725 .78441 L
.61765 .79393 L
.61721 .79412 L
.59804 .8014 L
.57843 .80692 L
.55882 .81052 L
.53922 .81226 L
.51961 .81216 L
.5 .81023 L
.48039 .80644 L
.46078 .80073 L
.4436 .79412 L
.44118 .79303 L
.42157 .78305 L
.40744 .77451 L
.40196 .77094 L
.38235 .75697 L
.37956 .7549 L
.36275 .74285 L
.35102 .73529 L
.34314 .73083 L
.32353 .72151 L
.31039 .71569 L
.30392 .71278 L
.28431 .70229 L
.2744 .69608 L
.26471 .68857 L
.25078 .67647 L
.2451 .67056 L
.23297 .65686 L
.22549 .64709 L
.21866 .63725 L
.20671 .61765 L
.20588 .61614 L
.19692 .59804 L
.1886 .57843 L
Mistroke
.18627 .57225 L
.18204 .55882 L
.1769 .53922 L
.17327 .51961 L
.17134 .5 L
.17133 .48039 L
.17353 .46078 L
.17834 .44118 L
.18624 .42157 L
.18627 .4215 L
.19762 .40196 L
.20588 .39008 L
.21156 .38235 L
.22549 .36307 L
.22572 .36275 L
.23883 .34314 L
.2451 .33335 L
.2515 .32353 L
.26471 .30423 L
.26493 .30392 L
.28037 .28431 L
.28431 .27979 L
.29894 .26471 L
.30392 .26012 L
.32249 .2451 L
.32353 .24436 L
.34314 .23193 L
.35545 .22549 L
.36275 .2224 L
Mfstroke
.51961 .34169 m
.52393 .34314 L
.53922 .35253 L
.55219 .36275 L
.55882 .37053 L
.57076 .38235 L
.57843 .39032 L
.59011 .40196 L
.59804 .40988 L
.60916 .42157 L
.61765 .43122 L
.6244 .44118 L
.63302 .46078 L
.63548 .48039 L
.63387 .5 L
.6299 .51961 L
.62451 .53922 L
.61781 .55882 L
.61765 .55925 L
.60968 .57843 L
.59804 .59266 L
.59056 .59804 L
.57843 .60272 L
.55882 .60424 L
.53922 .60274 L
.51961 .60071 L
.5 .59935 L
.48039 .59923 L
.46078 .60048 L
.44118 .60285 L
.42157 .60529 L
.40196 .60522 L
.38353 .59804 L
.38235 .59721 L
.36607 .57843 L
.36275 .57061 L
.35784 .55882 L
.35207 .53922 L
.34941 .51961 L
.35102 .5 L
.35993 .48039 L
.36275 .47636 L
.37877 .46078 L
.38235 .45771 L
.40196 .44174 L
.40265 .44118 L
.42157 .42426 L
.42435 .42157 L
.44118 .404 L
.44295 .40196 L
Mistroke
.45966 .38235 L
.46078 .38104 L
.47595 .36275 L
.48039 .35855 L
.5 .34349 L
.50081 .34314 L
.51961 .34169 L
Mfstroke
.36275 .20469 m
.38235 .19751 L
.40196 .19245 L
.42157 .18953 L
.44118 .18868 L
.46078 .18971 L
.48039 .19209 L
.5 .19485 L
.51961 .19691 L
.53922 .19796 L
.55882 .19876 L
.57843 .20032 L
.59804 .20327 L
.61085 .20588 L
.61765 .208 L
.63725 .21478 L
.65686 .22362 L
.66055 .22549 L
.67647 .23483 L
.69165 .2451 L
.69608 .24844 L
.71566 .26471 L
.71569 .26473 L
.73529 .28381 L
.73578 .28431 L
.75349 .30392 L
.7549 .30557 L
.76955 .32353 L
.77451 .32992 L
.78421 .34314 L
.79412 .35765 L
.79732 .36275 L
.80852 .38235 L
.81373 .39291 L
.8176 .40196 L
.82459 .42157 L
.8297 .44118 L
.83307 .46078 L
.83333 .46286 L
.83481 .48039 L
.83522 .5 L
.83445 .51961 L
.83333 .53542 L
.83258 .53922 L
.82947 .55882 L
.82524 .57843 L
.81989 .59804 L
.81373 .61702 L
.81348 .61765 L
.8053 .63725 L
Mistroke
.79576 .65686 L
.79412 .65998 L
.78431 .67647 L
.77451 .69119 L
.77096 .69608 L
.75529 .71569 L
.7549 .71614 L
.73702 .73529 L
.73529 .73699 L
.71569 .7549 L
.71568 .7549 L
.69608 .77037 L
.69033 .77451 L
.67647 .78371 L
.65873 .79412 L
.65686 .79511 L
.63725 .80459 L
.61765 .81237 L
.61374 .81373 L
.59804 .81835 L
.57843 .82273 L
.55882 .82555 L
.53922 .8268 L
.51961 .82646 L
.5 .82453 L
.48039 .821 L
.46078 .8159 L
.45378 .81373 L
.44118 .80903 L
.42157 .80039 L
.40909 .79412 L
.40196 .79021 L
.38235 .77869 L
.37546 .77451 L
.36275 .76674 L
.34314 .75535 L
.34232 .7549 L
.32353 .74484 L
.30554 .73529 L
.30392 .73441 L
.28431 .72253 L
.27434 .71569 L
.26471 .70811 L
.25102 .69608 L
.2451 .69014 L
.23265 .67647 L
.22549 .66764 L
.21756 .65686 L
.20588 .6393 L
.20469 .63725 L
Mistroke
.19386 .61765 L
.18627 .60236 L
.18446 .59804 L
.17667 .57843 L
.16993 .55882 L
.16667 .54774 L
.16474 .53922 L
.16103 .51961 L
.1587 .5 L
.15803 .48039 L
.15926 .46078 L
.16266 .44118 L
.16667 .42683 L
.16865 .42157 L
.17777 .40196 L
.18627 .38778 L
.18996 .38235 L
.20429 .36275 L
.20588 .36062 L
.21886 .34314 L
.22549 .33383 L
.23279 .32353 L
.2451 .30604 L
.24665 .30392 L
.26163 .28431 L
.26471 .28052 L
.27871 .26471 L
.28431 .25891 L
.29907 .2451 L
.30392 .24101 L
.32353 .22621 L
.32458 .22549 L
.34314 .21428 L
.35991 .20588 L
.36275 .20469 L
Mfstroke
.5 .37611 m
.51961 .37371 L
.53864 .38235 L
.53922 .38273 L
.55882 .39856 L
.56271 .40196 L
.57843 .41708 L
.5829 .42157 L
.59804 .43834 L
.60017 .44118 L
.61173 .46078 L
.61633 .48039 L
.61599 .5 L
.61259 .51961 L
.60671 .53922 L
.59804 .55745 L
.59746 .55882 L
.57843 .57786 L
.57726 .57843 L
.55882 .58345 L
.53922 .58367 L
.51961 .58232 L
.5 .58109 L
.48039 .58073 L
.46078 .58141 L
.44118 .58275 L
.42157 .58337 L
.40196 .57984 L
.39881 .57843 L
.38235 .56479 L
.37841 .55882 L
.37045 .53922 L
.36858 .51961 L
.37324 .5 L
.38235 .48381 L
.38707 .48039 L
.40196 .46602 L
.40834 .46078 L
.42157 .44899 L
.43015 .44118 L
.44118 .43045 L
.44973 .42157 L
.46078 .41001 L
.46768 .40196 L
.48039 .38998 L
.4896 .38235 L
.5 .37611 L
s
.42157 .16469 m
.44118 .16215 L
.46078 .16109 L
.48039 .16136 L
.5 .16268 L
.51961 .1647 L
.53525 .16667 L
.53922 .16722 L
.55882 .17029 L
.57843 .17408 L
.59804 .17885 L
.61765 .18476 L
.62217 .18627 L
.63725 .19226 L
.65686 .20138 L
.66559 .20588 L
.67647 .2123 L
.69608 .22516 L
.69656 .22549 L
.71569 .24035 L
.72137 .2451 L
.73529 .25769 L
.74259 .26471 L
.7549 .27722 L
.76151 .28431 L
.77451 .29885 L
.7788 .30392 L
.79412 .32279 L
.79468 .32353 L
.80877 .34314 L
.81373 .35064 L
.82088 .36275 L
.831 .38235 L
.83333 .38753 L
.8388 .40196 L
.84474 .42157 L
.84898 .44118 L
.8516 .46078 L
.85278 .48039 L
.85266 .5 L
.85137 .51961 L
.84901 .53922 L
.84565 .55882 L
.84137 .57843 L
.83632 .59804 L
.83333 .60868 L
.83021 .61765 L
.82261 .63725 L
.81419 .65686 L
.81373 .6579 L
Mistroke
.80396 .67647 L
.79412 .69364 L
.79258 .69608 L
.77935 .71569 L
.77451 .72241 L
.76445 .73529 L
.7549 .74665 L
.74742 .7549 L
.73529 .76723 L
.72749 .77451 L
.71569 .78451 L
.70304 .79412 L
.69608 .79885 L
.67647 .81063 L
.67064 .81373 L
.65686 .82016 L
.63725 .82796 L
.62087 .83333 L
.61765 .83421 L
.59804 .83885 L
.57843 .84224 L
.55882 .84435 L
.53922 .84513 L
.51961 .84455 L
.5 .84261 L
.48039 .83934 L
.46078 .83481 L
.45524 .83333 L
.44118 .8287 L
.42157 .82116 L
.40433 .81373 L
.40196 .8126 L
.38235 .80278 L
.3656 .79412 L
.36275 .79258 L
.34314 .78203 L
.32902 .77451 L
.32353 .77148 L
.30392 .76022 L
.29521 .7549 L
.28431 .7476 L
.26776 .73529 L
.26471 .73276 L
.24589 .71569 L
.2451 .71489 L
.22788 .69608 L
.22549 .69321 L
.21268 .67647 L
.20588 .66687 L
.19959 .65686 L
Mistroke
.1878 .63725 L
.18627 .63455 L
.17802 .61765 L
.16884 .59804 L
.16667 .59305 L
.16151 .57843 L
.15491 .55882 L
.14931 .53922 L
.14706 .53001 L
.14535 .51961 L
.14279 .5 L
.14157 .48039 L
.14194 .46078 L
.1441 .44118 L
.14706 .42598 L
.14837 .42157 L
.15539 .40196 L
.16512 .38235 L
.16667 .37967 L
.17794 .36275 L
.18627 .3515 L
.1928 .34314 L
.20588 .32637 L
.20811 .32353 L
.22313 .30392 L
.22549 .30074 L
.2383 .28431 L
.2451 .27572 L
.25445 .26471 L
.26471 .25327 L
.27263 .2451 L
.28431 .23398 L
.29399 .22549 L
.30392 .21759 L
.32007 .20588 L
.32353 .20366 L
.34314 .19208 L
.35428 .18627 L
.36275 .18251 L
.38235 .17485 L
.40196 .16886 L
.4104 .16667 L
.42157 .16469 L
Mfstroke
.5 .4199 m
.51961 .41641 L
.53447 .42157 L
.53922 .42412 L
.55882 .4399 L
.56017 .44118 L
.57663 .46078 L
.57843 .46428 L
.5853 .48039 L
.58701 .5 L
.58256 .51961 L
.57843 .53008 L
.57294 .53922 L
.55882 .54821 L
.53922 .55297 L
.51961 .55324 L
.5 .55245 L
.48039 .5518 L
.46078 .55157 L
.44118 .5512 L
.42157 .54451 L
.41252 .53922 L
.40641 .51961 L
.41481 .5 L
.42157 .49164 L
.43197 .48039 L
.44118 .47048 L
.45173 .46078 L
.46078 .45176 L
.47138 .44118 L
.48039 .43341 L
.49682 .42157 L
.5 .4199 L
s
.42157 .12681 m
.44118 .12294 L
.46078 .12042 L
.48039 .11939 L
.5 .11991 L
.51961 .1219 L
.53922 .1252 L
.55003 .12745 L
.55882 .12971 L
.57843 .1354 L
.59804 .1419 L
.61266 .14706 L
.61765 .1491 L
.63725 .1577 L
.65643 .16667 L
.65686 .1669 L
.67647 .17804 L
.69035 .18627 L
.69608 .19014 L
.71569 .20405 L
.71821 .20588 L
.73529 .21978 L
.74208 .22549 L
.7549 .23708 L
.76344 .2451 L
.77451 .25595 L
.78306 .26471 L
.79412 .27636 L
.80126 .28431 L
.81373 .29867 L
.81791 .30392 L
.83279 .32353 L
.83333 .32429 L
.84518 .34314 L
.85294 .35692 L
.85563 .36275 L
.86388 .38235 L
.87061 .40196 L
.87255 .40869 L
.87516 .42157 L
.87816 .44118 L
.87987 .46078 L
.88029 .48039 L
.87953 .5 L
.87776 .51961 L
.87522 .53922 L
.87255 .55707 L
.87217 .55882 L
.86748 .57843 L
.86206 .59804 L
Mistroke
.85627 .61765 L
.85294 .62924 L
.84985 .63725 L
.84174 .65686 L
.83358 .67647 L
.83333 .67709 L
.82347 .69608 L
.81373 .71459 L
.81307 .71569 L
.80089 .73529 L
.79412 .74597 L
.78782 .7549 L
.77451 .77274 L
.77308 .77451 L
.75579 .79412 L
.7549 .79504 L
.73529 .81327 L
.73476 .81373 L
.71569 .82786 L
.70725 .83333 L
.69608 .83953 L
.67647 .849 L
.66696 .85294 L
.65686 .85636 L
.63725 .86214 L
.61765 .86681 L
.59804 .87037 L
.58155 .87255 L
.57843 .87279 L
.55882 .87393 L
.53922 .87414 L
.51961 .87342 L
.50594 .87255 L
.5 .87159 L
.48039 .86838 L
.46078 .86404 L
.44118 .85877 L
.42157 .85294 L
.42156 .85294 L
.40196 .84543 L
.38235 .83745 L
.37224 .83333 L
.36275 .82894 L
.34314 .81961 L
.33088 .81373 L
.32353 .80978 L
.30392 .79863 L
.29635 .79412 L
.28431 .78595 L
.26869 .77451 L
Mistroke
.26471 .77124 L
.24619 .7549 L
.2451 .75384 L
.22733 .73529 L
.22549 .73321 L
.21118 .71569 L
.20588 .70885 L
.1971 .69608 L
.18627 .68026 L
.1842 .67647 L
.17277 .65686 L
.16667 .64631 L
.16267 .63725 L
.15306 .61765 L
.14706 .60513 L
.14473 .59804 L
.13744 .57843 L
.13032 .55882 L
.12745 .55 L
.1252 .53922 L
.12115 .51961 L
.1179 .5 L
.11593 .48039 L
.11543 .46078 L
.11651 .44118 L
.11926 .42157 L
.12372 .40196 L
.12745 .38944 L
.13032 .38235 L
.1399 .36275 L
.14706 .35048 L
.15211 .34314 L
.16667 .32403 L
.16708 .32353 L
.1837 .30392 L
.18627 .30085 L
.20043 .28431 L
.20588 .27764 L
.21692 .26471 L
.22549 .25448 L
.23385 .2451 L
.2451 .23279 L
.25221 .22549 L
.26471 .21341 L
.27297 .20588 L
.28431 .19642 L
.29711 .18627 L
.30392 .1815 L
.32353 .16831 L
.32613 .16667 L
Mistroke
.34314 .15728 L
.36275 .14728 L
.36321 .14706 L
.38235 .13933 L
.40196 .13236 L
.41875 .12745 L
.42157 .12681 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0_l00012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`00
0011ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Pooo
ool3o`0000;ooooo1?nY_NP00ol0003oooooo`000010ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0P?ooool3o`0000;ooooo1onY_NP00ol0003oooooo`00
0010ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0O_oo
ool2o`0000?ooooo2OnY_NP01?l0003oZKgXooooool0000oooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0Noooool3o`0000;ooooo3?nY_NP01Ol0003oZKgX
oooooooooooo000003kooooo0009ooooo`0400000?ooooooooooooooodP000000_l00004000000l0
6ATID0000004ooooo`0300000?oooooooooo07Wooooo0_l00003ooooo`koZKgX00Go0000ojVmj?nY
_NSoooooo`00000nooooo`002Oooool01000003ooooooooooooooom7000001X06ATIC0000004oooo
o`0300000?oooooooooo07Kooooo0ol00002oooooa7oZKgX00Ko0000ojVmj?nY_NSoZKgXooooool0
000mooooo`002Oooool01000003ooooooooooooooom4000002006ATIB@000004ooooo`0300000?oo
oooooooo07Cooooo0_l00002oooooaCoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003ooooooooo
o`0kooooo`002Oooool01000003ooooooooooooooom3000002@06ATIAP000004ooooo`0300000?oo
oooooooo077ooooo0ol00002oooooaKoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003ooooooooo
o`0jooooo`002Oooool01000003ooooooooooooooom0000002X06ATI00?o0000000000000000@000
0004ooooo`0300000?oooooooooo06kooooo0ol00002oooooaWoZKgX00?o0000ojVmj?nY_NP00onY
_NP00ooooooo0000ooooo`0jooooo`002Oooool01000003ooooooooooooooolm000003006ATI@000
0004ooooo`0300000?oooooooooo06cooooo0_l00003oooooacoZKgX00?o0000ojVmj?nY_NP00onY
_NP00ol0003oooooooooo`0iooooo`002Oooool01000003oooooooooooooooll000001806ATI2000
000I01TI6Ch000001?ooool00`00003oooooooooo`1Yooooo`?o00000_oooolOojVmj003o`000?nY
_NSoZKgX00?oZKgX00?oooooo`000?ooool0>Oooool000Wooooo00@00000oooooooooooooooo>P00
000<01TI6@P00000200c<c<700000003o`00000I6AT06ATI01806ATI>`000004ooooo`0300000?oo
oooooooo06Oooooo0_l00003ooooob7oZKgX00?o0000ojVmj?nY_NP01?nY_NP00ooooooo0000oooo
o`0hooooo`002Oooool01000003ooooooooooooooolg00000003o`00000I6AT06ATI00X06ATI0P00
000G03<c<`L00000400I6ATi000000Cooooo00<00000ooooooooool0I?ooool3o`0000;ooooo9?nY
_NP00ol0003oZKgXojVmj004ojVmj003ooooool0003ooooo03Sooooo0009ooooo`0400000?oooooo
ooooooooocH000002P0I6AT400000200<c<c0`00000?01TI6CL000001?ooool00`00003ooooooooo
o`1Rooooo`;o00000ooooolVojVmj003o`000?nY_NSoZKgX00GoZKgX00?oooooo`000?ooool0=ooo
ool000Wooooo00@00000oooooooooooooooo=@00000901TI6@8000009`0c<c<4000000`06ATI=P00
0004ooooo`0300000?oooooooooo05oooooo0ol00002ooooobWoZKgX00?o0000ojVmj?nY_NP01_nY
_NP00ooooooo0000ooooo`0fooooo`002Oooool01000003ooooooooooooooolc00000003o`00000I
6AT06ATI00H06ATI00<00000o`00000c<c<0200c<c<8000001`0<c<c00Co00000000000000000000
2@0I6AT00ol0000000000000000b000000Cooooo00<00000ooooooooool0GOooool2o`0000?ooooo
:onY_NP00ol0003oZKgXojVmj007ojVmj003o`000?oooooooooo03Gooooo0009ooooo`0400000?oo
oooooooooooooc800000200I6AT2000000P0<c<c0`00000804a<C0X000005P0c<c<2000000P06ATI
=0000004ooooo`0300000?oooooooooo05[ooooo0ol00002ooooo`;oZKgW1OnY_NP00onY_NOoZKgX
ojVmj00TojVmj003o`000?nY_NSoZKgX00SoZKgX00?o0000ooooooooool0=?ooool000Wooooo00@0
0000oooooooooooooooo<@00000701TI6@8000001P0c<c<4000001D0C4a<3P00000:03<c<`030000
000I6AT06ATI00L06ATI<P000004ooooo`0300000?oooooooooo05Oooooo0ol00003ooooo`03ojZl
ionY_NOoZKgW00;oZKgW00?oZKgXojZlionY_NL00onY_NL01?nY_NSoZKgWojVmionY_NL4ojVmj0;o
ZKgW00?oZKgXojVmionY_NL06?nY_NP00ol0003oZKgXojVmj008ojVmj003ooooool0003ooooo03Co
oooo0009ooooo`0400000?ooooooooooooooobl000001`0I6AT2000000D0<c<c00<00000o`000000
00009`1<C4`300000003o`00000c<c<0<c<c00D0<c<c0`00000801TI6C0000001?ooool00`00003o
ooooooooo`1Eooooo`;o00000oooool5ojZli`;oZKgW1?nZ_>L2ojVmi`;oZ[cW0_nY_NL5ojZli`03
ojVmionZ_>OoZKgW00?oZKgW00?oZKgXojZmionZ_NL01OnY_NP00onY_NOoZKgXojVmj00<ojVmj003
o`000?nY_NSoZKgX00WoZKgX00?o0000ooooooooool0<oooool000Wooooo00@00000oooooooooooo
oooo;`00000601TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`01@1<C4`;000001`0
C4a<0`00000703<c<`030000000I6AT06ATI00H06ATI;`000004ooooo`0300000?oooooooooo05;o
oooo0ol00003ooooo`03ojZli_nZ_>OoZ[cW00?oZ[cW0_nZ_>H4ojZli`?oZ[cV00?oZ[cWojZki_nZ
^nH01OnZ_>L01?nZ^nKoZ[cWojZlionZ_>L2ojVmi`03ojZlionZ_NOoZ[gW00;oZ[gW00?oZKgXojZl
ionY_NL00onY_NL00onY_NSoZKgWojVmi`0:ojVmj003o`000?nY_NSoZKgX00WoZKgX00?oooooo`00
0?ooool0<oooool000Wooooo00@00000oooooooooooooooo;P00000601TI6@030000000c<c<0<c<c
00<0<c<c0P00000404a<C0@000002`1VIVH4000001/0C4a<0`00000503<c<`8000001`0I6AT^0000
00Cooooo00<00000ooooooooool0D?ooool2o`0000Cooooo00CoZ[_VojZli_nZ_>KoZ[cV0_nZ_>L0
0onZ^nKoZ[cVojZliP02ojZliP03ojZlionZ^nKoZ[_V00;oZ[cV00?oZk[UojZki_nZ^nH00_nZ^nH0
0onZ_>OoZk[UojZkiP03ojZkiP03ojZlionZ^nKoZ[_V00?oZ[cW0_nZ_NL01?nZ_>KoZ[cWojZlionZ
_>L2ojVmi`03ojZlionY_NOoZKgW00;oZKgW00?oZKgXojVmionY_NL00_nY_NP01OnZ_NOoZKgXojVm
j?nY_NSo000000coZKgX00?o0000ooooooooool0<_ooool000Wooooo00@00000oooooooooooooooo
;@00000601TI6@030000000c<c<0<c<c0080<c<c0P00000404a<C003o`0000000000IVIV0180IVIV
00?o000004a<C01<C4`03@1<C4`4000000X0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI
01TI6@0501TI6@03o`0000000000000002X000001?ooool00`00003oooooooooo`1=ooooo`?o0000
0oooool2ojVkiP?oZ[_V00?oZ[cVojZjiOnZ^^D00onZ^nH2ojZliP;oZk[U00?oZ[_Voj^ihon[^N<0
0on[^^D2ojZkiP04oj^ihon[^^GoZk[Uoj^ji@;oZ[_V00?oZk[TojZki_nZ^nH00_nZ^nH00onZ_>Oo
Zk_UojZliP03ojZliP04ojZlionZ_>KoZ[cVojZliP;oZ[cW0_nY_NL2ojZli`03ojVmionZ_>OoZ[gW
00?oZ[gW0_nY_NP00ol0003oZKgXojVmj00:ojVmj003ooooool0003ooooo03;ooooo0009ooooo`04
00000?ooooooooooooooob`000001@0I6AT2000000@0<c<c00<0000004a<C01<C4`00P1<C4`00`00
003o000006IVIP0506IVIP@00000301VIVH5000000<0C4a<1`00000406IVIP<0000000Co00000000
000000000000101<C4`00ol0000000000000000403<c<`8000001P0I6AT/000000Cooooo00<00000
ooooooooool0Boooool2o`0000Cooooo00?oZK[UojVki_nY^nH00_nY^nH00onZ^nKoZ[WTojZii003
ojZji@06ojZki_n[^N?oZkWSoj^ihon[^^GoZkOR1?n[^N<00on[^^Go[;OQojbgh@03oj^ih`03oj^j
iOn[^>;oZkSR00?oZk[T0_nZ^nH01?n[^N?oZk_Uoj^kiOn[^nD2ojZliP;oZk[U0_nZ_>H01?n[^^Co
Z[_VojZki_nZ^nH2ojZli`04ojZki_nZ_>OoZ[cWojZli`;oZ[gW00OoZ[cWojZmionZ_NOo0000ojZm
ionY_NSoZ[gW00[oZKgX00?oooooo`000?ooool0<Oooool000Wooooo00@00000oooooooooooooooo
:P00000601TI6@030000000c<c<0<c<c00<0<c<c00@0000004a<C01<C4`0C4a<0P00000406IVIP@0
0000101oOgl6000000/0IVIV0`00000B06IVIP<00000101<C4`00`000000<c<c03<c<`0303<c<`80
00001P0I6ATZ000000Cooooo00<00000ooooooooool0B?ooool3o`0000?ooooo1OnY^^D2ojVkiP;o
Z[ST00?oZ[WToj^fhOn[]^400on[]n82oj^ih`04oj^eh?n[]n;oZkORoj^ghP;oZkWS00?o[;COojbg
hOn/]n400_n/]n400on[^N?o[;GOoj^hhP03oj^hhP03oj^ji?n/]^7oZkWS00?oZkWS00KoZk_Uojbh
hon/^>?o[;SSoj^jiOn/^>84oj^ji003ojZki_n[^^CoZk[T00?oZ[_V00?oZ[cWoj^ki_n[^nH00onZ
_>L00onZ_NOo0000ojZli`03ojZmi`;oZKgX0_nZ_NL6ojVmj003o`000?oooooooooo033ooooo0009
ooooo`0400000?ooooooooooooooobT000001P0I6AT00`000000<c<c03<c<`0303<c<`030000001<
C4`0C4a<008000000`1VIVH3000000h0Ogmo00<0000006IVIP1VIVH0801VIVH00`000000C4a<04a<
C00204a<C08000001@0c<c<00ol000006ATI01TI6@0401TI6@03o`0000000000000002H000001?oo
ool00`00003oooooooooo`15ooooo`?o00001?ooool2ojVjiPCoZK[U0onY^><00onZ^>CoZ[CPoj^f
h@03oj^fh@03oj^gh_n[/mkoZk?N00?oZkGP00?oZkORojbbg?n//]`00on/]=l2ojbgh@04ojfbg?n/
]Moo[;GOojbeg`;oZkSR00Co[K?MojbfhOn/]^7o[;KQ0_n[^N<01On]]Moo[;SSojbhhon/^>?o[KCN
00?o[;SR0_n[^^@00on/^>;oZk[Toj^ji002oj^ji003ojZki_n[^^CoZk_V00?oZk_V00CoZ[cWoj^l
i_nZ_>Oo00000_nZ_>L6ojZmi`KoZKgX00?oooooo`000?ooool0<?ooool000Wooooo00@00000oooo
oooooooooooo:000000601TI6@030000000c<c<0<c<c0080<c<c00Go00000000001<C4`0C4a<0000
000306IVIP8000001`1oOgl4000000L0Ogmo00?o00000000001VIVH04`1VIVH9000000@0IVIV00?o
00000000000000000`1<C4`00ol00000<c<c03<c<`0303<c<`030000000I6AT06ATI00@06ATI:000
0004ooooo`0300000?oooooooooo04?ooooo0_l00002ooooo`KoZK[V1OnY]n<2ojVhh`04ojVch?nZ
]>3oZ[CPojZdh0;oZkKQ00?oZk7Loj^cg_n[/mh00_n[/mh00on[]N3o[:oJojbbg003ojbbg003ojbd
gon][]So[K;L00?o[K;L00?o[;GOojj_f?n^[mP00on]/md00on/]^7o[[7JojjafP03ojfeg`05ojbh
hon]]=ko[KCNojfdg_n/^>800_n^]=d3ojbhhP;oZk[T00Co[KSQoj^ji?n[^^CoZk[T0_n[^nH01_n/
^^CoZkcVoj^li_n[_>Ko0000ojZli`;oZkcV0_nZ_NL01?n[_>OoZ[gWojZmionZ_NL2ojVmj006ojZm
ionY_NSoZKgXojVmj?oooooo0000<?ooool000Wooooo00@00000oooooooooooooooo:000000601TI
6@050000000c<c<0<c<c03<c<`0000000`1<C4`01P000000IVIV06IVIP1VIVH00000o`0000@0Ogmo
1000000409VIV@<000001@1oOgl00`000000IVIV06IVIP0@06IVIP8000002@1oOgl3000000@0IVIV
00@0000004a<C01<C4`0C4a<0P00000303<c<`030000000I6AT06ATI00D06ATI9`000004ooooo`03
00000?oooooooooo043ooooo0ol00002ooooo`03ojVki_nY^^KoZK[V00?oZK[V0_nX]n@4ojVgh`;o
ZK?O0onY/n000onZ]>3oZZoKojZ_f`03oj^ag0;oZk?N00Co[:gHojb_f_n/[m[o[:oJ0_n//]`01?n]
ZmGo[JkHojf^f?n][]P2ojfbg003ojjZe?n^[mSo[ZoH00;o[ZoH00?o[K?Mojn/eOn^/MX00on^/MX0
0on]]Moo[k3Hojn`f002ojfdgP03ok2_eon^]=go[[CM00;o[[CM00?o[;SRojjdgOn]^>400on]^>40
0on[^^Co[KSQojbji003ojbji006oj^li_n/^nGo0000ojbkiOn[_>Ko[;_U1?n[_>L6ojZmi`;oZKgX
00?oooooo`000?ooool0;oooool000Wooooo00@00000oooooooooooooooo9`00000601TI6@050000
000c<c<0<c<c03<c<`0000000`1<C4`00`000000IVIV06IVIP02000000<0Ogmo0`00000;09VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH03`1VIVH00`000000Ogmo07moO`0<07moO`03
0000001VIVH0IVIV0080IVIV0P00000304a<C0050000000c<c<0<c<c03<c<`0000001`0I6ATV0000
00Cooooo00<00000ooooooooool0?_ooool2o`0000?ooooo00CoZK_WojVki_nY^nKoZK_V0_nY^^H0
0onX^>CoZ;OTojRgi002ojRgi003ojVghonX/^3oZK?O00?oZK?O00?oZK?PojV]f_nZ[m/00onZ[m/0
0on[/McoZj[Fojb]f003ojb]f003ojb_f_n]Ym;o[J_E00?o[J_E00?o[JkHojjVcon^Z]@00on^Z]@2
ojj_f004ojnVcon_[=Go[jcEojn/e@;o[[7J00Co/:[Bojn`f?n_/=So[k3H1?n`[mL2ojjdg@04ok2_
eon^]=go[[CMojjdg@;o[KSQ00Co[kCMojfhhOn]^>7o[KSQ0_n/^^@2ojfihP03ojbkiOl0003o[K[S
00?o[;_U0_n[_>L00on[_>KoZ[gWojZmi`04ojZmi`?oZKgX00?oooooo`000?ooool0;_ooool000Wo
oooo00@00000oooooooooooooooo9P00000601TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`0
10000000IVIV06IVIP00000307moO`03o`0000000000VIVI00<0VIVI1000000709VIV@03o`00001o
Ogl0Ogmo0080Ogmo00<0000006IVIP1VIVH03@1VIVH00`000000Ogmo07moO`0>07moO`800000101V
IVH01@000000C4a<04a<C01<C4`0000000<0<c<c00?o000001TI6@0I6AT01@0I6ATU000000Cooooo
00<00000ooooooooool0>oooool3o`0000;ooooo0_nY_>L3ojVki`03ojVki_nX^>GoZ;SU00?oZ;ST
0_nX]n@01?nW/^3oZ;;PojRbh?nX/^02ojVcg`04ojR/f_nY[M[oZJgJojV]fP;oZZoK00CoZZSDoj^Z
e_n[Z]KoZj[F0on/[MP3ojfWdP?o[J_E0on^Y/l3ojjZe0Co[jK?00?o[jcEok6SbonaXl/00on`Z]80
0on_/=So/JW@ok6Yd007ok2_e`03ojjdgOna[mOo[kCM00?o[kCM00So[KSQojnegOn_]Mgo[kGMojfi
h_n_]mko[K[So`0000;o[K[S00?o[;_Uojfki?n[_>H00on[_>H00onZ_NOoZkgWojZmi`03ojZmi`05
ojVmj?nZ_NSoZ[gXooooool00000;_ooool000Wooooo00@00000oooooooooooooooo9@00000601TI
6@050000000c<c<0<c<c03<c<ol000000P1<C4`01@00003o000006IVIP1VIVKo00000080Ogmo00@0
0000o`00002IVIT0VIVI100000040;>c/`04o`00000000000000000000<0VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0<06IVIP03o`00001oOgl0Ogmo00D0Ogmo0P000002o`0000D0
00000`1oOgl2000000<0IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`8000001P0I6ATT0000
00Cooooo00<00000ooooooooool0>Oooool2o`0000?ooooo1OnY_>L00onY^nOoZ;WVojRiiP03ojRh
i@03ojRhi?nW/n7oYk?Q00?oYk;P00?oZ;;PojN/f_nW[=X00onX[=X00onY[M[oZJKCojZXe003ojZX
e0?oZj[F00?o[:gHojbUcon/YLl00on]Ym800on]ZmGo[J;;ojfRb`03ojjVc`03ojjZe?n_XLWo[j79
00;o[jK?00?o/9g4ok6SbonaXl/00_naXl/00on`Z];o/Z;7ok6Yd003ok6Yd003ok2_eoncZLko/jW>
00;o/:oG00Co/jW>ok6_eona[mOo/JoG0_n_]=d01Onb/=Oo[kGMojnegOn_]Mgo/[;H00?o[kON00?o
0000ojfjhon_^>000on]^n@2oj^liP;o[;cU0_n[_NL4ojZmi`04ojZmj?nZ_NOoZ[gWo`0002kooooo
0009ooooo`0400000?ooooooooooooooob@000001P0I6AT00`000000<c<c03<c<`0203<c<`030000
001<C4`0000000<0IVIV00@0000007moO`1oOgl000000`2IVIT00`000000/k>c0;>c/`0:0;>c/`04
0000002IVIT0VIVI000000@0Ogmo00<0000006IVIP1VIVH0301VIVH00`000000Ogmo07moO`0407mo
O`030000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl00P1oOgl200000080IVIV00D0000004a<
C01<C4`0C4a<0000000403<c<`030000000I6AT06ATI00@06ATI8`000004ooooo`0300000?oooooo
oooo03Kooooo0ol00003ooooo`03ojVlj?nY_>OoZKcW00?oZKcW00?oZ;[VojRii_nX^NH00_nX^NH0
0onX^>GoY[CRojNch@03ojNch@03ojNbh?nV[=_oYjcJ00?oYjcJ00?oZ:cJojNTdonYY]<00_nYY]<3
ojZXe0;oZj[F00CoZj;>ojbUcon/YLoo[:G?0_n]Ym801?n]W/So[J;;ojfRbon]X//2ojjVc`05ojjL
a?n_XLWo[j79ojnQbOn_Y/l00on`WL@2ok6Sb`04ok:K_onbX/Oo/Z;7ok:Ra`;o/JW@00Go]:;5ok>Y
c_ncZLko/jW>ok2_e`03ok>YcP03ok6_eondZloo]:_?00?o/[3G00Oo[kGMok:bf?nb/]So/[;Hojng
g_nb]=[o000000?o[kSP00?o[K_Tojnjh_n_^^800_n/_>D01?n^_>Co[;gVojbmi_n/_NH2ojZmi`03
oj^mionZ_NOoZ[gW00;oZ[gW00?o0000ooooooooool0:oooool000Wooooo00@00000oooooooooooo
oooo8`00000601TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C00000000`1VIVH010000000
Ogmo07moO`00000209VIV@800000102c/k<5o`0000@0/k>c00D0000009VIV@2IVIT0VIVI00000004
07moO`030000001VIVH0IVIV00/0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@09
09VIV@<000000`1oOgl010000000IVIV06IVIP00000304a<C0030000000c<c<0<c<c0080<c<c00?o
000001TI6@0I6AT0100I6AT00ol0000000000000000O000000Cooooo00<00000ooooooooool0<ooo
ool3o`0000Cooooo0_nY_NP2ojVlj0;oZKcW0_nX^nL2ojRjiP;oZ;WV00CoY[KTojJdh_nV]>;oY[CR
0_nW/n401?nU[=coYZcKojJ/fonV[=/2ojN/fP04ojFSdonWY=?oYjCCojNTd`?oZJKC00?oZZSDojZP
cOn[X/h00on[X/h00on/YLoo[9c6ojfNb003ojfNb003ojfRbon]V<7o[Yc400?o[Yc400?o[j79ok2G
__n`WL@00on`WL@01?naXl_o/Y^ook:K_onbVkl2ok:Ra`Co]:;500?o/jW>okJRaOnfX/D00oncZLh4
okB[c`03ok:`eone[=3o/[;H00;o/[;H00Co]ZoBok:df_nb]=[o00000_n_^>001Onb]mgo[k[Rojnj
h_n_^^;o/K[P00?o[[cT0on/_NH3oj^mi`?oZ[gW00?o0000ooooooooool0:oooool000Wooooo00@0
0000oooooooooooooooo8@0000000ol000006ATI01TI6@0401TI6@06o`00000c<c<0<c<c03<c<ol0
000000000P1<C4`01?l00000IVIV06IVI_l0000207moO`04o`00002IVIT0VIVI000000<0/k>c0ol0
00050<c<c003o`00002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`030000
001VIVH0IVIV00/0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0=09VIV@05o`00
001oOgl0Ogmo07moOol000000P1VIVH01Ol00000C4a<04a<C01<C4`0000000@0<c<c00<0000001TI
6@0I6AT0100I6ATQ000000Cooooo00<00000ooooooooool0<Oooool2o`0000Cooooo1?nY_NP2ojVl
i`?oZ;cW00?oZ;_WojNii_nW^NH00onW]nD2ojJfi003ojJdh_nT[]koY:kN00?oYJcL00?oYZcKojBS
e?nUXm<00onUXm<2ojNTd`;oZJKC00CoZ9k<ojZPcOnZX<goZZ3=0_n[X/h01?nZV/Go[9c6ojbLa_n/
W<H3ojfNb0?o[IS10on^W<@3ok2G_P?o/9g41?nbVkl00onbX/Oo]9ZmokBJ_@03okBRa@Co]Z;500?o
/jW>okNTaOngY<D00_ndZll01OnhY/Oo]Jc@okF/d?ne[=3o/[;H00?o]ZoB00?o/[CJokJbeOl00000
0onb]md01_n_^^;o/K[Pok6jh?na^^3o[[cTok2lh`Co[;gV0_n[_NL4ojZmi`03o`000?oooooooooo
02[ooooo0009ooooo`0400000?ooooooooooooooob8000001P0I6AT01@000000<c<c03<c<`0c<c<0
000000<0C4a<00<0000006IVIP0000000P1oOgl010000000VIVI09VIV@0000030;>c/`03o`00003<
c<`0c<c<00H0c<c<00?o00000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo
00<0000006IVIP1VIVH02`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI
1`00000409VIV@040000001oOgl0Ogmo000000<0IVIV00@0000004a<C01<C4`00000100c<c<00`00
00006ATI01TI6@0401TI6B4000001?ooool00`00003oooooooooo`0^ooooo`?o00000_ooool7ojVm
j0CoZKcW00?oZ;cWojRji_nW^NH00onW^NH00onW]nGoY;;RojB_h002ojB_h0?oY:kN00?oYJcLoj:S
e_nTXm@00_nTXm@3ojFSd`03ojNTdonVW<coZ9k<00?oZ9k<0_nZX<d4ojZJa@?o[9c600?o[Ik8ojbE
_on]V<400on]V<400on^W<Co[Y>jok2G_P03ok2G_P03ok2Ma?naUKWo/IFi00;o/Y^o00?o]9BfokBJ
_OndV[d00_ndV[d00ondX/Go]i^lokNK_002okJRa@05okVM_?ngY<Go]jC5okNTaOndZll00onhY/L0
0one[=3o^JS9okVXb@03okJ_dP;o][;E00?o0000okJbeOnb]md00_nf]]T2ok6jh004okBjg_n`_>?o
/;cSok2lh`;o[;gV0_n^_ND2oj^mi`CoZ[gW00?o0000ooooooooool0:Oooool000Wooooo00@00000
oooooooooooooooo8@00000601TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`00`000000IVIV
0000000207moO`040000002IVIT0VIVI00000080/k>c0_l000090<c<c003o`00002c/k<0/k>c0080
/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`030000001VIVH0IVIV00/0IVIV00<0000007mo
O`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c0P00000309VI
V@040000001oOgl0Ogmo000000<0IVIV00@0000004a<C01<C4`00000100c<c<00`0000006ATI01TI
6@0401TI6B0000001?ooool00`00003oooooooooo`0/ooooo`;o00000oooool:ojVmj0;oZKcW00Co
Z;_WojRji_nX^^KoZ;[V0_nW^NH01?nU]>?oY;;RojBbh_nT/^83ojB_h003ojB^g_nQY=SoXZ?F00;o
XZ?F0onTXm@00onUXm?oXi[<ojJLc002ojJLc0?oZ9k<00?oZZ3=ojVHaOnYV<D00onZV/D2ojbLaP04
ojZC__n/UKoo[9FoojbE_`;o[IS100Co[8nhojjC^_n^Tk[o[Y>j0_n`Ukh01On`SkCo/IFiok6E^Ona
UKWo/Y^o00;o]9Bf1?ndV[d3okNK_004okJRaOniWKco^IflokVM_0;o]jC500Co^YnmokRVaonhY/Oo
^:K71?niZ<T01_nf[m;o^Zc<okZ/c?nf/]Go0000ok^ad0?o][KI1?nd^]h00on`_>?o/[cRok:lhP02
ojjmi@04ojnmiOn/_NKo[;gVojbmiP;oZ[gW00?oZkgWo`000?ooool0:_ooool000Wooooo00@00000
oooooooooooooooo8000000601TI6@030000000c<c<0<c<c0080<c<c00H0000004a<C01<C4`00000
06IVIP00000207moO`040000002IVIT0VIVI00000080/k>c00?o00000<c<c03<c<`02P3<c<`01Ol0
0000/k>c0;>c/`2c/k<000000080VIVI00D0000007moO`1oOgl0Ogmo0000000>06IVIP030000001o
Ogl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`070;>c/`050000002I
VIT0VIVI09VIV@0000000P1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00<0000003<c<`0c
<c<00P0c<c<00ol000006ATI01TI6@0401TI6@03o`0000000000000001`000001?ooool00`00003o
ooooooooo`0Yooooo`?o00000_ooool<ojVmj0;oZ;cW0onX^nL00onX^^KoY[OUojJgi@03ojFdh`03
ojBbh_nQZMgoXJOJ00;oXJOJ0onQY=P2oj:SeP;oY:?D00CoXIW=oj>Jc?nSV/coXi[<0onVW<`00onX
W/coYiK5ojVHa@03ojVHa@03ojZJaOnYT[koZY>n00?oZY>n0_n/UKl00on]V<7o[8nhojb?^003ojjC
^P03ok2G__n`SkCo/8nd00?o/IFi1?ndU;H2okBJ_@04okNE]?ngVkco]i^lokNK_0Co^Ifl00Go]jC5
okZO_OnjWkgo^YnmokRVa`02okbR_`;o^JS900Ko_JK2okZ/c?nj[<co^Zc<ok^ad?l00002ok^ad003
okJffOnj]]Ko^[KF00;o];[N00Co^;_Lok:lh_nb_>;o/[cR1?n__ND00on/_NKo[;kVoj^mi`03oj^m
i`03o`000?oooooooooo02Sooooo0009ooooo`0400000?oooooooooooooooah0000000?o000001TI
6@0I6AT0100I6AT01_l00000<c<c03<c<`0c<c?o000000000080C4a<00H0000006IVIP1VIVKo0000
07moO`00000209VIV@040000002c/k<0/k>co`0000<0c<c<00<00000o`000?l00000100000040<c<
c004o`00002c/k<0/k>c00000080VIVI00D0000007moO`1oOgl0Ogmo0000000606IVIP<000001@1V
IVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@0000002`2c/k<01Ol000000000
09VIV@2IVIT000000080Ogmo00Go00000000001VIVH0IVIV0000000204a<C003o`0000000000<c<c
0080<c<c00<0000001TI6@0I6AT0100I6ATN000000Cooooo00<00000ooooooooool09oooool2o`00
00?ooooo3?nY_NP3ojVlj0;oZ;cW00?oZ;_WojNii_nW^NH00onV]nD00onU]>?oXZgOoj6Yg@02oj6Y
g@?oXJOJ00?oXJCHoifId?nNVLh00_nNVLh3oj6Ic@;oXi[<0_nVW<`01?nTU<CoYiK5ojNFaOnWU/D2
ojVHa@03ojNA__nYT[koZI:n00CoZY>n00?o[9FoojZ=]on/SkP00on/SkP2ojjC^PCo/8nd0_naUKT0
1OncSk3o]9BfokBD]_ndU;Ko]9Zm00?o]iFd0_ngVk`01?njUk?o^IflokVM_?niWK`4okZO_@?o_::o
00Go^JS9okfV`_nmY/;o_JK2okZ/c002okj[aP03o`000?nk/M3o_k7;00?o^[KF1?nh^m`00onb_>;o
];gQokBmh@02ojnmi@04ok2ni?n/_^Ko[;kVojbniP;oZkgW0_n[_^L00ol0003oooooooooo`0Woooo
o`002Oooool01000003ooooooooooooooolN000000L06ATI00D0000003<c<`0c<c<0<c<c00000002
04a<C0040000001VIVH0IVIV00000080Ogmo00<0000009VIVOl000000P2c/k<00ol00000c<c<0<c<
c002000000H0i^KV00<000000<c<c03<c<`00P3<c<`01?l00000/k>c0;>c/`00000209VIV@050000
001oOgl0Ogmo07moO`000000101VIVH2000000<0C4a<00<0000006IVIP1VIVH00`1VIVH01Ol00000
Ogmo07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<02P2c/k<01@000000VIVI09VIV@2IVIT0
00000080Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C0030000000c<c<0<c<c0080<c<c00<0
000001TI6@0I6AT00`0I6ATN000000Cooooo00<00000ooooooooool09?ooool3o`0000?ooooo3_nY
_NP2ojVlj004ojRkionW^^OoYk[WojNji`?oYkWV00?oY[OUoj>ah_nR[Ml00_nR[Ml3oj6Yg@03oj6W
f_nLVm;oWIW@00;oWIW@0onNVLh2oj6Ic@03oj>Jc?nRT/CoY9C400?oY9C40_nWU/D00onYV<GoYi6n
ojNA_P03ojVB_P;oZY>n00CoZ8bgojZ=]onZSKOoZXfg0on/SkP00on^Tk[o[Xbaojj</@03ok2?]003
ok6E^OncSk3o/hn`00?o]9Bf1?ngUK@01OngVkco^YNcokZG/onjUk?o^Ifl00;o_9Vd0_njWkd01?nn
W;Ko_::ookbR_onlX[l4okfV`P?o_Z_600Go0000oknabono/L_o_k7;okZfeP02okngdP;o^;_L0_nk
_=X00ond_N7o][kPok2ni003ok2ni003ojbni_n]_^Ko[KkV00?oZkkW00?o0000ooooooooool09ooo
ool000Wooooo00@00000oooooooooooooooo7@00000701TI6@050000000c<c<0<c<c03<c<`000000
0P1<C4`010000000IVIV06IVIP00000207moO`030000002IVIT000000080/k>c00Co00000<c<c03<
c<`000002@3Vi^H01@000000c<c<0<c<c03<c<co00000080/k>c00@0000009VIV@2IVIT000000P1o
Ogl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1V
IVH00`000000Ogmo07moO`0207moO`040000002IVIT0VIVI000000d0/k>c00D0000009VIV@2IVIT0
VIVI0000000207moO`050000001VIVH0IVIV06IVIP0000000P1<C4`00`000000<c<c03<c<`0203<c
<`030000000I6AT06ATI00<06ATI7@000004ooooo`0300000?oooooooooo02;ooooo0_l00004oooo
o`ooZKgX0_nY_>L3ojRki`03ojNjionV]nGoY[OU00?oY;CT0_nS/N800onR[MooW:?Ioi^NeP02oi^N
eP?oW9_B0onMVM001?nNVLkoVhk5oij@aOnNT<D3oj:Ba0?oY9C400?oYiK5ojF@_onWTKh00onWTKh2
ojVB_P03ojZC__nXS;OoZ8bg00?oZXfg0on/SkP3ojj</@?o/8nd1?ncSk000ondU;Ko]Xn^okNE]003
okNE]0Co^YNc0onlVK@01?njWkgo_YbfokjL]_nnW;H2okbR_`03oknP^?nmY/;o_JK200;o`ZBl0_nn
ZlH01?l0003o_k7;oknaboo5//L3okngdP?o^kcJ00Co_kkIokJnh?nf_^3o][kP0_n`_^@2ok6oi0;o
[KkV1?n[_^L00ol0003oooooooooo`0Vooooo`002Oooool01000003ooooooooooooooolL000000L0
6ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV00000080Ogmo00<00000
09VIV@0000000P2c/k<01?l00000c<c<0<c<c000000;0>KViP040000003<c<`0c<c<o`000080/k>c
00@0000009VIV@2IVIT000000P1oOgl01@000000IVIV06IVIP1VIVH0000000P0C4a<00?o00000000
001VIVH00P1VIVH01@000000Ogmo07moO`1oOgl000000080VIVI00<000000;>c/`2c/k<0302c/k<0
1Ol00000VIVI09VIV@2IVIWo00000080Ogmo00Go000006IVIP1VIVH0IVIV0000000204a<C003o`00
000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT00`0I6AT00ol0000000000000000I000000Cooooo
00<00000ooooooooool07oooool3o`000003oooooonY_NSoZKgX01;oZKgX0onY_>L00onX^nOoYkWV
ojNiiP03ojJgi@03ojBdi?nP[N7oWZSM00;oWZSM0_nLXmT3oi^NeP;oW9_B0_nMVM000onIS/KoVhk5
oi^>a@03oij@a@?oXY;400?oY9C4oj>>_onUT;l00_nUT;l3ojNA_P03ojVB__nVS;WoZ8bg00?oZ8bg
0onZSKL00on/SkSoZhV`ojj</@03ojj</@03ok2?]?naRZgo/hn`00?o/hn`0onfSjh2okNE]003okZB
[OnjUk?o^YNc00;o^YNc0onlVK@4okjL]P04okbR_onoX;So_j2hokfV`P?o`ZBl00Co_Z_6olBZ`Ol0
003o_k7;0oo5//L01?no]m;oa;W@olBid?nk_=X3oknnf@03okJnh?nh`>3o^<3P00;o/KoT00Co//3U
ojfni_n]_^Ko[KkV0on[_^L00ooooooo0000ooooo`0Vooooo`002Oooool01000003ooooooooooooo
oolL000000H06ATI00?o000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000206IVIP06o`00
001oOgl0Ogmo0000002IVIT000000P2c/k<01?l00000c<c<0<c<c000000;0>KViP040000003<c<`0
c<c<o`000080/k>c00@0000009VIV@2IVIT000000P1oOgl010000000IVIV06IVI_l0000:04a<C005
0000001VIVH0IVIV06IVIP0000000`1oOgl010000000VIVI09VIV@00000?0;>c/`050000002IVIT0
VIVI09VIV@0000000P1oOgl010000000IVIV06IVIP00000304a<C0050000000c<c<0<c<c03<c<`00
00001P0I6ATK000000Cooooo00<00000ooooooooool07?ooool3o`0000;ooooo5onY_NP00onY_>Oo
Z;_WojRki`03ojNiiP03ojJgiOnR/^?oX:gQ00;oX:gQ0onNZ=d2oibSf@04oi^Ne_nET<coUXk9oiJ>
b@CoVHk60_nKS/D2oij@a@;oXY;400CoXHbnoj>>_onSS[ooXhjo0onUT;l00onWTKkoYHbjojJ<^@02
ojJ<^@?oZ8bg0_nZSKL01?nXQk7oZhV`oj^9/?n[RK02ojj</@04ojj7ZonaRZgo/HZ]ok6:[@;o/hn`
00Go]H^ZokJ?[_nfSjko]Xn^okNE]003okZB[@;o^YNc0_nmUJd2okbI]0Co_Ybf0onoX;P4ol:T_0;o
a:[100?o0000olV/_?o5//L00_o5//L3olBid004olVlc_no_]Wo_kkIoknnf@?o^<3P1?nb`>D00on]
_^Ko[KoWojfoi`03oj^ni`03o`000?oooooooooo02Gooooo0009ooooo`0400000?oooooooooooooo
oa/000001`0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00L0000006IVIP1VIVH0IVIV0000
001oOgl000000080VIVI00<000000;>c/ol000000P3<c<`00`000000i^KV0>KViP090>KViP070000
003<c<`0c<c<0<c<c?l00000/k>c0000000209VIV@040000001oOgl0Ogmo000000<0IVIV00<00000
04a<C01<C4`02@1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00@0000009VIV@2IVIT00000
3P2c/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<
C0030000000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT0100I6ATJ000000Cooooo00<00000oooo
ooooool06_ooool2o`0000?ooooo5onY_NP3ojRli`03ojRkionV^NKoY[WV00;oY;KU0onR/^<00onP
[N7oVJ;KoiJKeP02oiJKeP;oUIGA0onET<`2oiJ>b@?oVHk60_nKS/D00onNT<GoWHVnoj6<_P03oj6<
_P;oXhjo0_nUT;l00onTS;_oYHbjojF<^P03ojJ<^@?oZ8bg0onXQk43oj^9/003ojj</On^Qj_o[XN[
00?o/HZ]00Co/hn`okF;Z_neRj[o]H^Z0_nfSjh4okZB[@05okZG/onmUJgo_IF]okfE[OnlVK@00_o0
V:l2okjL]P;o`Y^a0_noX;P01oo4Wk?o`ZBlol:T_?o2Y;coaZBgolBZ`Ol000000_o9[;`01?o5//Oo
bkC4ol^da?o4^M03olVlcP04oknnfOo3`MSo`l7HokS0h0;o^/;P0_nb`>D2ok;1i@;o[KoW1?n[_^L0
0ol0003oooooooooo`0Tooooo`002Oooool01000003ooooooooooooooolK000000H06ATI00<00000
03<c<`0c<c<00P0c<c<010000000C4a<04a<C000000206IVIP060000001oOgl0Ogmo0000002IVIT0
00000P2c/k<01?l00000c<c<0<c<c000000;0>KViP040000003<c<`0c<c<o`000080/k>c00Co0000
09VIV@2IVIT000000P1oOgl010000000IVIV06IVIP00000604a<C08000001@1<C4`020000000IVIV
06IVIP000000Ogmoo`00001oOgl000000P2IVIT00`000000/k>c0;>c/`0=0;>c/`050000002IVIT0
VIVI09VIV@0000000P1oOgl010000000IVIV06IVIP00000304a<C0050000000c<c<0<c<c03<c<`00
00001P0I6ATJ000000Cooooo00<00000ooooooooool05oooool3o`0000?ooooo6_nY_NP00onX_>Oo
Yk_WojNki`03ojJiiP;oY;KU00?oX[;SoibYgonLZMl00_nIX]/3oiJKeP;oUIGA0_nET<`3oiJ>b@04
oiV>a_nEPkgoVHJmoiV6_@?oWHVn0onQS;h00onSS[ooXh^kojB<^`02ojB<^`?oYHbj0onVS;T00onX
S;OoYXJcojR7/@03ojR7/@;oZhV`1?n^Qj/2ok6:[@Co]H^Z0_nfSjh01?niSZSo^Y:]okZB[OnjTZd4
okfE[@?o`9R_00Go_Ybfol:K/Oo2Vk7o`Y^aoknP^003olBO/`03ol:T_?o6Y;OoaZBg00;o00000_o9
[;`3ol^da0?obKc>0_o>`<d01?o3`MSoaLCIolG4fOnj`^03ok_4h@03ok;1iOnb`^Go[KoW00;o[KoW
0_n[_^L00on[_^Soooooo`00000Uooooo`002Oooool01000003ooooooooooooooolJ000000H06ATI
00<0000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000206IVIP090000001oOgl0Ogmo0000
002IVIWo00000000002c/k?o000000<0c<c<00?o00000>KViP3Vi^H0203Vi^H01ol00000c<c<0<c<
c03<c<co00000;>c/`0000000P2IVIT010000000Ogmo07moO`00000206IVIP060000001<C4`0C4a<
04a<C000003o00000P00000203<c<`800000101<C4`010000000IVIV06IVIP00000307moO`040000
002IVIT0VIVI000000l0/k>c00D0000009VIV@2IVIT0VIVI0000000207moO`040000001VIVH0IVIV
000000<0C4a<00D0000003<c<`0c<c<0<c<co`00000601TI6AT000001?ooool00`00003ooooooooo
o`0Fooooo`;o00000ooooolKojVmj003ojRlionW^nOoYk_W00;oYk_W00CoY[WVoj>diOnP[n?oX:oS
1?nLZMl2oiVRf`;oUY_F00CoUIGAohf5a_n>P/;oSX;20onAP[l2oiF3_@?oVHJm0onMRKh00onQS;ko
XHVjoj>;^`02oj>;^`?oY8bk0_nUS;X2ojJ<^@04oj>7]_nVQ[?oYXJcojJ6/`?oZ8Na00?oZhV`oj^4
[?n[Q:`00on^Qj/2ok6:[@05ok:7Z?neRj[o]H^ZokF;Z_nfSjh00_niSZP3okZB[@Co_IF]0oo0V:l4
ol:K/@Coa9nc0ol000001Oo9[;co0000olV/_?o9[;cocjji00;obkC400?od;O2olVlc_o>`<d00_o>
`<d3olG4f@?o^lCQ00Co^lKRok;2iOnb`^Go//;U0on]_nL3oj^nj003o`000?oooooooooo02?ooooo
0009ooooo`0400000?oooooooooooooooaP0000000?o000001TI6@0I6AT0100I6AT00ol00000<c<c
03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000P1VIVH01P000000Ogmo07moO`000000VIVI
00000080/k>c00Go00000<c<c03<c<`0c<c<0000000:0>KViP040000003<c<`0c<c<o`000080/k>c
00H0000009VIV@2IVIT0000007moO`00000306IVIP040000001<C4`0C4a<000000P0<c<c0P000003
04a<C0040000001VIVH0IVIV00000080Ogmo00D0000009VIV@2IVIT0VIVI0000000>0;>c/`050000
002IVIT0VIVI09VIV@0000000`1oOgl010000000IVIV06IVIP00000304a<C0050000000c<c<0<c<c
03<c<`0000001@0I6ATI000000Cooooo00<00000ooooooooool05_ooool00ol0003oZKgXojVmj00K
ojVmj0;oZKcX0_nX_>L2ojNki`04ojFhi_nS]>GoXkCUoj>di@;oX:oS0_nLZMl00onCW=WoSi?CohnC
d`02ohf;c0;oSHG60on>P/82oi62_`?oUH>m0_nIQ[d2oif9_P03oij5^OnQRK[oXHVj00?oXh^k0onT
S;/00onUS;[oXXVioj>7]P02oj>7]P?oYXJc0_nXQk401?nVPjkoZhB/oj^4[?n[Q:`3ojj7Z`03ok6:
[OnbQjSo/XNX00?o]H^Z1?niSZP00onjTZgo_I6XokfAZ002okfE[@;o`IFY0_o0V:l01Oo4VJ_o`Y^a
ol:K/Oo2Vk7oa9nc00?o000000Kob:2_olJT]oo6Y;OobjJcolV/_?l00002oln^^@03ol^da?o@]l;o
d;O200?oc/3=0_oBa<d01?o5a=Wob<OIolS7fOnka>43ok_6hP03ok;2iOnb`^Ko//;V00;o[KoW1?n[
_^P00ol0003oooooooooo`0Rooooo`002Oooool01000003ooooooooooooooolI000000D06ATI00<0
000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00H0000007moO`1oOgl0
000009VIV@0000020;>c/`05o`00003<c<`0c<c<0<c<c00000002P3Vi^H010000000c<c<0<c<c?l0
00020;>c/`060000002IVIT0VIVI0000001oOgoo00000P1VIVH200000080C4a<00<0000003<c<`0c
<c<02@0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00@0000007moO`1oOgl000000`2IVIT0
0`000000/k>c0;>c/`0<0;>c/`050000002IVIT0VIVI09VIVOl000000`1oOgl01?l00000IVIV06IV
I_l0000304a<C004o`00000c<c<0<c<c000000H06ATI00?o00000000000000005@000004ooooo`03
00000?oooooooooo01Kooooo00?o0000ojVmj?nY_NP06onY_NP00onY_>SoZ;cWojRli`03ojNji`;o
YKSV00?oXkCUoif]h_nM[N800_nHYMh3oi>Lf@;oSi?C0_n=Rl`2ohf5aP;oSX;20onAP[l2oiF3_@03
oiV6_OnIPKOoWXFi00;oWXFi0onQRKX3oj>;^`03ojB<^onRRk_oXXVi00;oXXVi0onSQkH2ojJ6/`03
ojR7/OnVPjkoYX>^00?oZhB/0on^Qj/3ok:7Z0?o]H^Z1?niSZP3okfAZ005okfE[Oo1UJWo`IFYol6E
ZOo0V:l00_o4VJ/01?o2Vk7o0000o`000?l00002olBO/`;ob:2_00OoaZBgol^V/oo;Y[?obJbloln^
^Ol0003ocjji00?od;O200Coe[c0olk0cOoBa<god/C=0_oFbLd00oo8amWobL_KolW;f`02ok_6hP;o
^lOS00?o//;Vok72ion]_nL00_n]_nL3oj^nj003o`000?oooooooooo02;ooooo0009ooooo`040000
0?oooooooooooooooaP000001@0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<
C00000000P1VIVH010000000Ogmo07moOol0000209VIV@040000002c/k<0/k>co`0000<0c<c<00<0
00000>KViP3Vi^H01P3Vi^H200000080c<c<00Co00000;>c/`2c/k<000000P2IVIT01_l00000Ogmo
07moO`000000IVIV000000<0C4a<00?o000003<c<`0c<c<02`0c<c<01@000000C4a<04a<C01<C4co
00000080IVIV00@0000007moO`1oOgl000000`2IVIT00`000000/k>c0;>c/`0<0;>c/`050000002I
VIT0VIVI09VIV@0000000P1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00D0000003<c<`0c
<c<0<c<c0000000501TI6AP000001?ooool00`00003oooooooooo`0Fooooo`03o`000?nY_NSoZKgX
01[oZKgX0_nY_>P3ojRli`03ojNjionT^>KoXK?U00;oXK?U0onM[N82oiRUgP;oTicI0_n?Tm<2ohf;
c0;oSHG60on>P/82oi62_`03oiF3_OnDO;KoVH6g00;oVH6g0onNQKT2oj69^P?oXh^k0_nRRk/3oj:9
^@?oXhNf00?oYXJcoj:2/_nVPjh00_nVPjh4oj^4[0;o[XN[1?nbQjP00oneRj[o]hZVokN:YP03okV>
Z0?o_I6X1?o1UJT01Oo4VJ_o0000o`000?l0003o`Y^a00;oaYb]00Coa9ncolRP[oo8X:oob:2_0oo;
Y[<01_o@ZK3ocjjioln^^Ol0003oe;:fom2g`P;oe[c000?og<6nom;4cOoFbLd00_oFbLd3olW;f`?o
^lOS00Go^/OTok72iona`^Oo/L;Wojfoi`02ojboj0?oZkkX00?o0000ooooooooool08Oooool000Wo
oooo00@00000oooooooooooooooo6000000501TI6@030000000c<c<0<c<c0080<c<c00D0000004a<
C01<C4`0C4a<0000000206IVIP040000001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k?o0000
0`3<c<`00`000000i^KV0>KViP040>KViP800000103<c<`01?l00000/k>c0;>c/`00000209VIV@06
0000001oOgl0Ogmo0000001VIVH000000`1<C4`00`000000<c<c03<c<`0;03<c<`050000001<C4`0
C4a<04a<C00000000`1VIVH01?l00000Ogmo07moOol0000309VIV@03o`0000000000/k>c00/0/k>c
00D0000009VIV@2IVIT0VIVI0000000207moO`050000001VIVH0IVIV06IVIP0000000P1<C4`01@00
0000<c<c03<c<`0c<c<0000000D06ATI60000004ooooo`0300000?oooooooooo01Gooooo00Co0000
oooooooooooooooo6_nY_NP3ojVlj003ojRlionV^^OoY;SV00;oY;SV00?oXK?Uoi^/honK[><00_nD
X]h2ohfGf0;oQh_@0_n3PLP2oh9j`@;oQGJk0on9M[P2ohih]P;oU7bf0onIPKL3oij5^@03oj69^_nS
RKWoXh^k00;oXh^k0onRRk/3oj:9^@03oj>7]_nNQ;OoXX:b00;oXX:b0onVPjh3oj^4[003ojj7Zon_
QJSo/XNX00?o/XNX0ongRZH2okV>Z0;o_HnU0_nmTJP00oo2TjKo`IFYo`000002o`0000?oa9V[0oo6
W:d4olRP[`03olfR[Oo;Y[?objJc00;od:V`00?ocjjio`000?oD/[H00ooF_<000ooL`KkohLNnomK9
c@02omK9c@05omW>c_o9bm_obLgLolW=g?nkan<00onjan@00ona`^Oo/<;Wok32i`02ojboj0CoZ[kX
00?o0000ooooooooool08?ooool000Wooooo00@00000oooooooooooooooo5`00000501TI6@030000
000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP040000001oOgl0Ogmo0000
00<0VIVI00@000000;>c/`2c/k?o0000103<c<`300000080i^KV00<000000<c<c03<c<`00`3<c<`0
1?l00000/k>c0;>c/`00000209VIV@060000001oOgl0Ogmo0000001VIVH000000`1<C4`00`000000
<c<c03<c<`0403<c<`Co00001@0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00D0000007mo
O`1oOgl0Ogmo0000000409VIV@030000002c/k<0/k>c00X0/k>c00D0000009VIV@2IVIT0VIVI0000
000207moO`050000001VIVH0IVIV06IVIP0000000P1<C4`01@000000<c<c03<c<`0c<c<0000000D0
6ATI5`000004ooooo`0300000?oooooooooo01Gooooo00Co0000oooooooooooooooo6OnY_NP2ojVl
j0?oZ;cX0_nV^^L00onT^>KoX;?Uoj2ci@03oi^/h`;oU:;N0_n=UmP2ohN;d0;oPh7800CoPW[1ohEf
^on5M[_oQGJk0_n9M[P2ohih]P?oU7bf0_nIPKL3oij5^@?oXhVi0onSRk/2oj:;^`;oXXVi00?oWHNl
oij4]onNQ;L00onRP[83ojJ3[P;oZhB/00CoZH:Zojn5Z?n_QJSo[hFX0onbQjP3okN:YP05okV>Z?nm
SjGo_HnUokf?YOnmTJP00ol000000oo1UJWoaYRWolJHY`03olBIZ`?oaYb]00?obYj[olRP[oo8X:l0
0_o=XZd01?o;Y[?od:V`om2Y/?o@ZK02omBb]P03o`000?oK][Coe[c000;og<6n0_oQakh01OoFbLgo
fLk>omW>c_oKd]3obLgL00;obLoN0_njan@2okW7i@03ok32ion_`^Oo[;oX00;o[;oX0onZ_^P00ol0
003oooooooooo`0Pooooo`002Oooool01000003ooooooooooooooolG000000@06ATI00<0000003<c
<`0c<c<00`0c<c<010000000C4a<04a<C000000306IVIP040000001oOgl0Ogmo00000080VIVI00D0
00000;>c/`2c/k<0/k>co`0000070<c<c08000001@3<c<`01?l00000/k>c0;>c/`00000209VIV@06
0000001oOgl0Ogmo0000001VIVH000000`1<C4`00`000000<c<c03<c<`0303<c<`;o0000100I6AT0
0ol00000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000P1VIVH01@000000Ogmo07mo
O`1oOgl0000000@0VIVI00<000000;>c/`2c/k<02@2c/k<01@000000VIVI09VIV@2IVIT0000000<0
Ogmo00@0000006IVIP1VIVH000000P1<C4`01@000000<c<c03<c<`0c<c<0000000D06ATI5`000004
ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool00_oooolHojVmj0?oZKcX00?oZ;cX
ojJjionT]nL00onT]nL2oj2ci@04oi^/hon@X=ooQY;HohJBf0;oOHC?0_n7Rm02oh>1b0;oPW[10_n5
M[/3ohUf^0;oSWRf0_nDO;H3oiV1]`03oij5^OnQQKKoXhVi00;oXhVi0onSRk/00onRRk_oWhbooif7
_002oif7_0?oWXBg0_nRP[83ojJ3[P03oj^4[?nYPZ[oZH:Z00?o[hFX0_nbQjP01?ndQjKo]hZVokN:
Y_ngRZH2okf?Y@?o00000_o2TjH2ol6EZ@;oaYRW0_o4VJ/2olRKZ@05olJL[Oo:WZ_obYj[olZNZoo8
X:l00_o=XZd4om2Y/004omJ/[_oD/[KofkJdo`0000;og<6n0ooQakh01?oUcKkofLk>om_Bd?oKd]03
olW?gP04olO?hOnianGo^LOUokO7iP?o[l;W00?o[;oXoj^oj?n[_nP00onZ_^P00ol0003ooooooooo
o`0Oooooo`002Oooool01000003ooooooooooooooolF000000D06ATI00?o000003<c<`0c<c<00P0c
<c<010000000C4a<04a<C000000306IVIP040000001oOgl0Ogmo000000<0VIVI00D000000;>c/`2c
/k<0/k>co`00000<0<c<c0;o00000P2c/k<01?l00000VIVI09VIVOl0000207moO`040000001VIVH0
IVIVo`000080C4a<00?o000003<c<`0c<c<00P0c<c<2o`0000L06ATI0_l0000403<c<`05o`00001<
C4`0C4a<04a<C?l000000P1VIVH01P000000Ogmo07moO`1oOgl00000o`0000<0VIVI00?o00000000
002c/k<02@2c/k<01@000000VIVI09VIV@2IVIWo000000<0Ogmo00Co000006IVIP1VIVKo00000P1<
C4`01@000000<c<c03<c<`0c<c?o000000D06ATI5P000004ooooo`0300000?oooooooooo01Gooooo
00?o0000ooooooooool01?oooolGojVmj003ojVlj?nX_>SoZ;cX00;oY[[W0_nT]nL00onO/nKoVJ_S
oiV[h`03oi2Pg`;oQY;H00?oOHC?ogMgaOmgMlD00_mfK[d2ogQZ]P?oQGJk0_n9M[P2ohih]P03oiAl
]_nFNK7oW7nc00;oW7nc0onQQKH3oj>9^@03oj>;^onTSkkoWhbo00;oWhbo0onMQk`2oij4]`?oXX:b
00?oYX>^oj>0[_nYPZX00_nYPZX3ojn5Z005ok:7Z?ndQjKo]8NVokB7Y_ngRZH00ol00002okf?Y@Co
`Y>V00Co`IFYolJHYoo6V:Ooa9V[0oo8VjT01?o6W:gobYj[olZNZoo:WZ/3olfR[@?od:V`0_oF[:h0
1OoD/[KofkJdom^f]?l0003og<6n00?ohLNn00KoiLfnom_Bd?oKd]3ofm;@om_Fd_o9cmh2olO?h@Co
]lOV00Go[l;Wojk1j?n^`NSoZkoXoj^nj004ojZnj003o`000?oooooooooo01kooooo0009ooooo`04
00000?oooooooooooooooa@0000000?o000001TI6@0I6AT0100I6AT01@000000<c<c03<c<`0c<c?o
00000080C4a<00Go000006IVIP1VIVH0IVIVo`00000307moO`050000002IVIT0VIVI09VIV@000000
0`2c/k<00ol00000c<c<0<c<c0080<c<c0;o00000P2c/k<200000080VIVI00@0000007moO`1oOgl0
00000P1VIVH010000000C4a<04a<C000000403<c<`03o`00000I6AT06ATI00T06ATI00?o000003<c
<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00?o00000000001oOgl00P1oOgl0
0`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT00P2IVIT0
10000000Ogmo07moO`00000306IVIP030000001<C4`0000000@0<c<c00<0000001TI6@0I6AT00P0I
6ATF000000Cooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`05oooooaCoZKgX0onY
_>P00onX_>SoY[[WojJji`03ojBhi`;oWk?V0_nIZn<2oi2Pg`;oQY;H0_mmQ<l01OmgMlGoMVjmogI^
_OmfK[goN6Zf00?oOVZb0_n6KK02ohic/0?oUWVa0_nLOk<3oj65]P;oXhVi00?oYhjkojB?__nTSkh0
0onOS;l3oif7_0;oWXBg0_nRP[800onLP;CoXh2^oj>0[P04ojV2ZP;o[hFX0ondQjH2o`0000;o^hfU
0onmSjD4ol:CYP?oaYRW1?o8VjT4olZNZ`;ocJ:]0_oAYJ/01?o@ZK3oeZb^omJ/[_oF[:h2om^f]003
on6l/_l0003ohLNn00;ohLNn0_oUcKh01_oYd[kofm;@om_Fd_oKe];of]SEolO?h@;oa<oS0_nganH2
okC6i`03ojk1j?n]`>SoZkkX00;oZkkX0onZ_^P00ol0003oooooooooo`0Nooooo`002Oooool01000
003ooooooooooooooolE000000D06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001V
IVH0IVIV000000<0Ogmo00D0000009VIV@2IVIT0VIVI000000050;>c/`03o`00003<c<`0c<c<00@0
c<c<0ol000030;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl010000000IVIV06IVIP000002
04a<C0030000000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT02`0I6AT00ol00000<c<c03<c<`02
03<c<`050000001<C4`0C4a<04a<C00000000`1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI
00<000000;>c/`2c/k<01`2c/k<01Ol00000VIVI09VIV@2IVIT0000000<0Ogmo00@0000006IVIP1V
IVH000000P1<C4`01Ol00000<c<c03<c<`0c<c<0000000D06ATI5@000004ooooo`0300000?oooooo
oooo01Gooooo00?o0000ooooooooool01_oooolDojVmj003ojVlj?nX_>OoZ;cW00?oY[[W00CoY;SW
oinci_nH[>CoV:cT0_n=X>02oh2@f@;oLgk@0_mZK/@2ogMga@;oMVjm0_mhJ[H2ogiZ/P;oQVf`0_n>
Lk03oiIi/@?oW7nc0_nQQKH3ojN>^`?oY8nn0onOS;l2oif7_003oij4]onEP[coW82d00;oW82d0_nS
P:h4ojV2ZP;o[hFX0ol000001?ndQjKo]hZVok^=YOnkSJD2okf?Y@03ol:BYOo2TjKo`Y>V00;o`Y>V
0oo6V:L01?o;W:Oob9^YolRKZOo8VjT3olZNZ`;ocZ6Y00CocJ:]om6UZooAYJ_od:V`0ooF[:h01_oL
/JcofkJdon6l/_oQ_;;o0000on77_P;oiLfn0_oYd[h01_o/f;oofmKBom[HeOoJf=Gof=[IolC?h`;o
`LkT0_nda^L2ok;4i`;o[L3X0on[_^P2ojZnj003ojZmj?l0003ooooo01kooooo0009ooooo`040000
0?oooooooooooooooaD00000100I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IV
IP1VIVH000000`1oOgl00ol00000VIVI09VIV@0209VIV@030000002c/k<0/k>c00@0/k>c1_l00005
0;>c/`05o`00002IVIT0VIVI09VIVOl000000P1oOgl01?l00000IVIV06IVIP00000204a<C0030000
000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT03@0I6AT2o`0000<0<c<c00D0000004a<C01<C4`0
C4a<o`00000306IVIP050000001oOgl0Ogmo07moO`000000102IVIT00ol00000/k>c0;>c/`070;>c
/`050000002IVIT0VIVI09VIV@0000000`1oOgl010000000IVIV06IVIP00000204a<C0050000000c
<c<0<c<c03<c<`000000100I6AT00ol0000000000000000B000000Cooooo00<00000ooooooooool0
5?ooool00ol0003oooooooooo`08oooooa;oZKgX0onY_>P2ojRli`03ojJjionT^>OoWk?V00;oWk?V
0_nH[>@2ohfPh0;oP93I0_mcO]000omZK/CoIV:jofIR^P02ogI^_@;oN6Zf0omnJ[801?n6KK3oSW>`
ohic/?n>Lk02oiIi/@?oW7nc00?oXHFfojN9]_nWRKH00onWS[/2ojB?_P;oWhbo00?oVi79oiB8a?nD
R<@00onEP[`2oib0]0?oXh2^0_nYPZX3o`000004ok25YondQjKo]8NVokB7YPCo^hfU00?o_HnUol:B
YOo2TZD00_o2TjH2olNHYP03olJHYoo;W:OobibW00;ob9^Y0_o<WZP01Oo:WZ_ocZ6YoljQZOo>XJWo
cJ:]00;odJF[0ooF[:h2omba[0;ohKbb0_oW`K001?l0003oiLfnonWB__oYd[h2oncH_`06ongM`_oJ
f=Gof=[IomSJfOoDf]go`LkT0_nmc>H2ok;4i`06ok33j?n/`>So[<3Xojc0j?n[_^SoZ[kX1?nZ_NP0
0ol0003oooooooooo`0Looooo`002Oooool01000003ooooooooooooooolE000000@06ATI00D00000
03<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV000000<0Ogmo00<0000009VIV@2IVIT0
0P2IVIT00`000000/k>c0;>c/`0=0;>c/`8000000P2IVIT200000080Ogmo00@0000006IVIP1VIVH0
00000`1<C4`00`000000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00h06ATI00?o000003<c<`0c
<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00Co000007moO`1oOgoo0000102IVIT0
0`000000/k>c0;>c/`070;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl010000000IVIV06IV
IP00000204a<C0050000000c<c<0<c<c03<c<`000000100I6ATE000000Cooooo00<00000oooooooo
ool05?ooool00ol0003oooooooooo`0:oooooa3oZKgX0_nY_>P01?nX_>OoY[[WojJjionV^^L2ojBh
i`03oinci_nH[NGoV:gU00;oSJ7R00GoOI3Kof]kdOm[Nm7oJg_Aog=nd002ofY^a005ofIR^_mXGK;o
J5fbofQM/_mhJ[H00omnJ[82ohI]/0;oSW>`0onFNK400onLOk?oXX:aojN9]P02ojN9]P?oYhjk00?o
Y8nnojNHaonKTLT00_nKTLT2oiB8a0?oUH:l0onLP;@01OnSP:ko0000o`000?l0003oZ8>[00?o/8FW
0ondQjH4ok^=Y@04okf?YOo2TZGo`Y:Uol:CYP?oaiRV00GoaYRWol^LYoo;W:OobibWolRKZ@02olbN
Z004olZNZoo>XJWocZ6YoljQZ@?odJF[00?oeZRYomJ/[_oF[:h00_oL/J`01ooR]ZWohKbbonO1/?oW
`K3ok<N_o`000?oYd[h00_o/f;l2ongM`P04oncQa_oHf]Woe=[MomCJg@?o_LcV1?n``nP00on/`>So
ZkoXoj^oj002ojZnj0;oZ[gX00?oZKgXo`000?ooool07Oooool000Wooooo00@00000oooooooooooo
oooo5@00000401TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP000003
07moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<03@2c/k<00`000000VIVI09VIV@02
000000<0Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`0203<c<`03o`00000I
6AT06ATI01006ATI00?o000003<c<`0c<c<00P0c<c<01@000000C4a<04a<C01<C4`000000080IVIV
00D0000007moO`1oOgl0Ogmo0000000409VIV@030000002c/k<0/k>c00L0/k>c00D0000009VIV@2I
VIT0VIVI0000000207moO`040000001VIVH0IVIV00000080C4a<00D0000003<c<`0c<c<0<c<c0000
000401TI6AD000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo3onY
_NP2ojRlj0?oZ;cW00?oY[[WojBhionT^>L00onP]>H2oiR]i@;oSJ7R00?oOI3Kof]kdOm[Nm400_mK
I/@00omZK/CoIV:jofIR^P02ofQM/P;oL5f]0_mnJ[82ohI]/0;oSW>`0_nFNK400onKNZkoXX:aoj:2
/@04ojN9]P03ojN>^on_VKooYiS700;oYiS70onKTLT2oiB8a0;oUH:l00KoW82do`000?l0003o0000
oj>0[_nYPZX2ojR3Z`Co/8FW00?o]8NVokR;Y_nkSJD00onkSJD3ol:BY@05ol:CY_o7V:KoaiRVolNH
Y_o6V:L00oo;W:L3olbNZ0CocZ6Y0_oAYJ/3omJXZ@06omJ/[_oL/Jcoh[JYon:fZOoQ_;;oil6`0_o/
ajl00ol0003omMB/oncH_`02ongM`P;ok>7600Goj^C;omCJgOo?fN3ocmWPokg<iP02okW:i`;o/<?X
00Co[l;Xoj^oj?n[_nSoZkkX0onZ_^P3ojVmj003o`000?oooooooooo01_ooooo0009ooooo`040000
0?oooooooooooooooa@00000100I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00<0000006IV
IP0000000`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00`0/k>c0P00000209VI
V@03o`00001oOgl0Ogmo0080Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`02
03<c<`03o`00000I6AT06ATI00@06ATI1ol0000701TI6@03o`00000c<c<0<c<c0080<c<c00D00000
04a<C01<C4`0C4a<0000000206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT00`000000/k>c
0;>c/`070;>c/`030000002IVIT0VIVI0080VIVI00Co000007moO`1oOgl000000P1VIVH010000000
C4a<04a<C000000303<c<`030000000I6AT06ATI00806ATI50000004ooooo`0300000?oooooooooo
01Cooooo00?o0000ooooooooool02oooool?ojVmj0;oZ;cX00?oZ;cWojNjionW^^L00onT^>L01?nP
]>KoVZkUohjShon>Xn<2ogfBg@;oIWcD0_m[Nm401?mKI/CoDeNhoe=G^?mVH[X2ofQM/P;oL5f]0_mj
HZ/2ohIYZ`03ohic/?nALJcoVgZ^00;oVgZ^0onRP[42ojN9]P04ok6C^?n_VKoo[iVoojnI_`?oYiS7
0_nKTLT2oiB8a0?o00000_nLP;@00onSP:koWX2bojR3Z`02ojR3Z`Co/8FW00?o]8NVokR;Y_nhRjH0
0onkSJD3ol:BY@CoaiRV1?o;W:L3olbNZ003om2RZOo>XJWocZ6Y00;odJ>Y00CodJF[omJXZOoFZ:Wo
eZRY0_oL/J`2on:fZ@03onNkYooW`K3ok<N_00;olLj]00?o0000ooSK[?o]gL800_o/hLH2on[Tb`05
onGVdOo?fN3obMKSolWFhonib^L00_nfb>P00on_`^So[L7Xoj^nj003oj^nj0;oZ[kX0onY_NP00ooo
oooo0000ooooo`0Kooooo`002Oooool01000003ooooooooooooooolD000000@06ATI00D0000003<c
<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIVo`000080Ogmo00?o000009VIV@2IVIT00P2I
VIT00`000000/k>c0;>c/`090;>c/`80000000?o00000000002IVIT00P2IVIT200000080Ogmo0P00
000206IVIP030000001<C4`0C4a<008000000`0c<c<2o`0000H06ATI0_l00006000000;o00001P0I
6AT00ol00000<c<c03<c<`0203<c<`05o`00001<C4`0C4a<04a<C?l000000P1VIVH01@000000Ogmo
07moO`1oOgl0000000<0VIVI00<000000;>c/`2c/k<01`2c/k<01Ol00000000009VIV@2IVIT00000
0080Ogmo00Co000006IVIP1VIVH000000P1<C4`01@000000<c<c03<c<`0c<c<0000000@06ATI5000
0004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool03Oooool<ojVmj005ojRlj?nX
_>OoZ;cWojRlionW^^L00_nT^>L2oj6diP?oVZkU0_n>Xn<2ogfBg@04ofIle?m@H/KoD6;6oe]Va0;o
DeNh00GoE4n_ofQM/_mXGK;oJ5fbog1M[@02ogYRZ`;oQVV[0onALJ`3oi]j[P;oXX:a00?oYhVfok6C
^?naTkP00on_VKl2ojNHa`03ojb[eon?W]go000000;o00000on1PLT2oi1o_0?oWX2b0onXPj/3ok25
Y`?o^8^V0_nkSJD2ol6BYP;o`Y:U00Cob9VVolNHY_o7V:KoaiRV0oo;W:L2olnRZ003olbNZ?o@XZWo
d::Y00;ocZ6Y0_oAXjT01_oAYJ_oeZRYomJXZOoFZ:WofZbWomba[0;oh[JY00Coik^Wonc7[oo/ajoo
lLj]0_oee:`00ol0003onN6]oncQaP02on[Tb`04onGVdOoOiMSognGHolWFh`;o`m;V00?o]/SXok;5
j?nbaNP00_n]`NP2oj^nj0CoZ[kX0onY_NP00ol0003oooooooooo`0Jooooo`002Oooool01000003o
oooooooooooooolD000000@06ATI00@0000003<c<`0c<c?o00000`1<C4`010000000IVIV06IVIP00
000207moO`050000002IVIT0VIVI09VIVOl000002`2c/k<00`000000VIVI09VIV@0209VIV@<00000
0P1oOgl2000000<0IVIV00@0000004a<C01<C4`00000100c<c<00ol000006ATI01TI6@0501TI6@03
o`0000000000000000P0000000?o000001TI6@0I6AT0100I6AT00ol00000<c<c03<c<`0203<c<`05
0000001<C4`0C4a<04a<C00000000P1VIVH01?l00000Ogmo07moO`00000309VIV@03o`00002c/k<0
/k>c00P0/k>c00@0000009VIV@2IVIT000000`1oOgl00`000000IVIV0000000204a<C0050000000c
<c<0<c<c03<c<`000000100I6ATD000000Cooooo00<00000ooooooooool05?ooool00ol0003ooooo
ooooo`0=ooooo`coZKgX0_nX_>P00onX_>OoY[[WojJji`03ojBhi`;oXKCV00CoVZkUoi6Uhon0U]oo
P9KO0_mXOmL2ofIle004oe1Ra_loC;SoFfK4oe=G^0;oE4n_0_mXGK800om`GJgoNV:[ogYRZ`02ohIY
Z`?oTG6/0onKNZh2oj:2/@Co/I>h0_n_VKl01?nlZlSo0000o`000?l00002ohnNg@;oOH_G0_n1PLT2
oi1o_0?oWX2b0onXPj/2ok25Y`05ok68Z_nhRjKo^8^VokR;Y_nkSJD00oo1TZH00oo2TZGob9VVolRI
YP02olNHYP;ocYnW00GobibWolnRZ?o?XZSocj:XolbNZ003om2RZ@03oljQZOoAXjWodJ>Y00?oeZRY
0_oJ[:L2on:fZ@;oik^W00[okL6Uonc7[ooacZgomMB/ooSK[?l0003onN6]ooSV/?oZi<_oiNKA0_oO
iMP2omSRgP05ol?Bi_nmcnOo_LoWok;5j?n``nP00on/`>P3ojZnj0GoZKgX00?oooooo`000?ooool0
6_ooool000Wooooo00@00000oooooooooooooooo5000000301TI6@050000000c<c<0<c<c03<c<`00
00000P1<C4`010000000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VIV@0000002`2c/k<0
0ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P1VIVH0
10000000C4a<04a<C000000403<c<`03o`00000I6AT06ATI00@06ATI0_l0000<00000003o`00000I
6AT06ATI00@06ATI00?o000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000206IVIP050000
001oOgl0Ogmo07moO`0000000P2IVIT00`000000/k>c0;>c/`090;>c/`040000002IVIT0VIVI0000
0080Ogmo00@0000006IVIP1VIVH000000P1<C4`010000000<c<c03<c<`00000401TI6A@000001?oo
ool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo2_nY_NP5ojRlj0;oY[[W00?o
Y;SWoj6ei_nK[nD00_nK[nD2oi6Uh`;oP9KO00CoJ7oGod]SbOm;HlWoD6;60_loC;P2oe=G^003oeA?
[omLCjWoG4nY00;oL5f]0_mjHZ/2ohIYZ`;oTG6/0onKNZh00onRP[7o[8Zaojb:/@03ok6C^0?o0000
00Co_:_8ojb[eon^c>oo[/c_0_mT[OT2obioj0;oPH790_n@Ok`2oij0/P?oZ8>[00?o/8FWok68Z_na
R:X00onhRjH4ol6BYP03ol:BYOo8VJKob9VV00;oaiRV0_o>WjL01Oo;W:Oocj:XolnRZ?o?XZSoc9jX
00?od::Y0ooAXjT00ooDYZSoeZRYomZ/Y`02omZ/Y`;oh[JY0_oW^jL02oo]`JGollNRoo7>[Ooee:co
n=^/ooWQ[Ol0003on>J`ooK/]_obkkkognGH00;of>;N00CocmkSokg?ionmcnOo_LoW0on``nP00on/
`>SoZkoXoj^oj003ojZnj0GoZKgX00?o0000ooooooooool06Oooool000Wooooo00@00000oooooooo
oooooooo5000000301TI6@070000000c<c<0<c<c03<c<`000000C4a<0000000206IVIP040000001o
Ogl0Ogmo000000<0VIVI00<000000;>c/`2c/k<02@2c/k<00`000000VIVI09VIV@0209VIV@03o`00
001oOgl0Ogmo0080Ogmo00H0000006IVIP1VIVH00000o`000000000204a<C0030000000c<c<0<c<c
0080<c<c00?o000001TI6@0I6AT0100I6AT00ol0000000000000000=00000003o`00000I6AT06ATI
00@06ATI00?o000003<c<`0c<c<00P0c<c<010000000C4a<04a<C000000206IVIP040000001oOgl0
Ogmoo`000080VIVI00<000000;>c/`2c/k<02P2c/k<01P000000VIVI09VIV@000000Ogmo00000080
IVIV00@0000004a<C01<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6A@000001?ooool00`00
003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo2?nY_NP4ojRlj004ojJkj?nT^>OoY;SW
ojBhi`;oXKGV00CoVjoUoi:Wi?nBYnCoQ9WP0_m_QMT2ofQoe`07od]SbOl_A[WoD6;6ocm<^?lk?jco
DeNhoeA?[`02oea?Z@04ofUDYom`GJgoNV:[ogYRZ`;oQVV[0onALJ`00onKNZkoXh2]ojb:/@02ojb:
/@03ok6C^?l0003o000000?o_:_80_o>am@01_n^c>ooV^_ioi[[nOnJjoWo07flobioj0;o?gCM0_n@
Ok`3oij0/P03ojR3ZonVQ[;o/HRZ00?o/HRZ0_nhRjH01?nmTZ[o`I:Vol6BY_o1TZH4olRIYP03olNH
Y_o>WjOocYnW00Cocj:X1?o@XZT2om6SZ@;oe:JX00OoeZRYomZ/YooJ[:OofZbWomn`Y_oR]ZWoik^W
00;okL6U00_ollNRooS>Wooee:con=^/ooWQ[Oohi[3o0000ooK/]_obkkkokO79omSRgP03oloNh`04
okg?ionhbnSo^<_Xok33j0;o[/;X00?oZkoXoj^nj?nZ_^P00onZ_^P5ojVmj003o`000?oooooooooo
01Sooooo0009ooooo`0400000?oooooooooooooooa@000000`0I6AT01`000000<c<c03<c<`0c<c<0
000004a<C00000000P1VIVH00`000000Ogmoo`00000309VIV@03o`00002c/k<0/k>c00X0/k>c00D0
000009VIV@2IVIT0VIVI0000000407moO`040000001VIVH0IVIV000000@0C4a<00<0000003<c<`0c
<c<00P0c<c<00ol000006ATI01TI6@0501TI6@03o`0000000000000000d0000000?o000001TI6@0I
6AT0100I6AT00ol00000<c<c03<c<`0203<c<`040000001<C4`0C4a<00000080IVIV00@0000007mo
O`1oOgl000000P2IVIT00`000000/k>c0;>c/`040;>c/`;o0000102c/k<01P000000VIVI09VIV@00
0000Ogmo00000080IVIV00@0000004a<C01<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6A@0
00001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo2?nY_NP3ojRlj0;o
Y[_X00?oY;SWoj6fionQ]^L00onK/>H2oi:Wi004ohBIh?m_QMWoKhGIoe1YcP;oBf?900Co;dJiocm<
^?lk?jco>cn/0_mDCjl00omLCjWoJEBWofUDY`02ogYRZ`;oQVV[0_nALJ`01?nGM:[oXh2]oj>0[On/
R[43o`000004ok6C^?o0Xkco`:>lokb[b0?oc/OD00Gog^WKomkmdOoNoM7oc?biomSgY002om[m^003
ocmdgOm_NlooKg_?00?oTh:n0onVQ[83ok68ZP03okR;Y_nmTZ[o_I:Z00?o`I:V1?o8VJH3oljOY`04
omBY[?o?XZSocj:XolnRZ0?od::Y0_oBYJX00ooAXjWoe:JXomBVZ003omZ/Y`;ogk2V0_oW^jL03Oo]
`JGollNRoo?7X_ohcYooo=JKooSK[?oihJgon>J`ooK/]_l0003ol^nnongabOoUkmD00_o?g^<00oo7
f>Ko^<_XokS;j002okC7j003ojk2j?n]`>SoZkkX00;oZkkX0_nZ_^P2ojZmj0GoZKgX00?o0000oooo
ooooool05oooool000Wooooo00@00000oooooooooooooooo5000000301TI6@070000000c<c<0<c<c
03<c<`000000C4a<0000000206IVIP030000001oOgl0000000<0VIVI00<000000;>c/`2c/k<02P2c
/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00@0000006IVIP1VIVH00000101<C4`00`000000
<c<c03<c<`0203<c<`03o`00000I6AT06ATI00D06ATI00?o00000000000000003`0000000ol00000
6ATI01TI6@0401TI6@05o`00000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP000002
07moO`040000002IVIT0VIVI000000D0/k>c00?o00000<c<c03<c<`00_l000030;>c/`050000002I
VIT0000007moO`0000000P1VIVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI0080
6ATI50000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04oooool5ojVmj0?o
Z;gX00?oZ;cXojJkj?nV^nP00onT^NP2oj6fi`04oi^`i_nCZNKoQYgRohJMhP;oM8_K0_m_QMT2ob]8
_007obm6^OlO<JWo?dbhoc/o[?m1?JKoE4n_oea?Z@02ofUDY`;oNEjW0_n9JJP3oiMdZP?o00000on/
R[43ol2S_008om>j`Oo>amCoc/ODolk7e?oNjM_og_gAolcl^OoLm9/2om[m^003omcnc_oEm^Co?gCM
00;oKg_?0_nCP[h3ojJ6/P?o/HRZ00?o^8^VokfBZ_nmTZX00_o1TZH2olRLZ`?ob9VV0_o>WjL2omBY
[0;ocj:X0_oCZ:`01Oo@XZWodZFZom:UZ_oBYJ[odJ>Y00;oe:JX00?oeZRXomZ/YooJ[:L00_oO/:H0
0ooT]:Coik^Wong1Y@02oo?7XP07ooS>WooleY_oo]bHoogRUOohi[3om^bfo`000002ongab@03onG_
eOoKjMkoamSV00;o_m7X0_ndanP2ok74j0;o[L3X00?oZkkXojZnj?nZ_^P00_nZ_NP6ojVmj003o`00
0?oooooooooo01Oooooo0009ooooo`0400000?oooooooooooooooa<00000100I6AT010000000<c<c
03<c<`00000204a<C0050000001VIVH0000007moO`0000000`2IVIT010000000/k>c0;>c/`2c/k<3
o`0000H0/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`050000001VIVH0IVIV06IVIP000000
0`1<C4`00`000000<c<c03<c<`0203<c<`03o`00000I6AT06ATI00D06ATI00?o0000000000000000
4@0000000ol000006ATI01TI6@0301TI6@03o`00000c<c<0<c<c0080<c<c00@0000004a<C01<C4`0
00000P1VIVH00`000000Ogmo0000000209VIV@030000002c/k<0/k>c0080/k>c00?o00000<c<c03<
c<`00`3<c<`01?l00000/k>c0;>c/ol0000209VIV@030000001oOgl000000080IVIV00<0000004a<
C00000000`0c<c<00`0000006ATI01TI6@0201TI6A<000001?ooool00`00003oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo1OnY_NP00onX_NSoZ;cXojRlj003ojJkj003ojBij?nQ^>WoVk;X
00;oVk;X0_nCZNH2ohJMhP06ogB;fomJL]7oFW;AocIB`_l[B;co;dJi0_lO<JT00olk?jco@CfVod4m
YP02oea?Z@03ofUDYomiGZOoNEjW00;oRFVX0ol00003oj>0[@;o[8Za0_nkV;<2ol2S_0;odk[100Go
c/ODomkYfooNoM7olOF^onKeX002omCaU004omSj[ooFm>?oe_CSolWNj0;oKg_?0onCP[h2ojJ6/P?o
/HRZ1?nmTZX00oo1TZKob9b[olRLZ`02olRIYP;od:F[00GocYnWomBY[?oDZJcoe:V/olnRZ002om>X
[004om2RZOoBYJ[odZFZom:UZP;oe:JX0_oFZ:P2omZ/Y`;ogk2V00Coi;BTong1YOo]`JGollNR0_oh
cYl02?oleY_oo]bHoogRUOokiiGomnbJooCbY?l0003oiNoE0_oKjMh01?o@h^Co_m7XokW<jOnic>T2
ok74j004ojo2j?n/_nSo[;oXojboj0;oZ[kX2OnY_NP00ol0003oooooooooo`0Fooooo`002Oooool0
1000003ooooooooooooooolC000000@06ATI00@0000003<c<`0c<c<000000P1<C4`01@000000IVIV
0000001oOgl000000080VIVI00@000000;>c/`2c/k<0/k>c0_l000020<c<c0;o0000102c/k<01000
0000VIVI09VIV@00000307moO`050000001VIVH0IVIV06IVIP0000000P1<C4`00`00003o000003<c
<`0203<c<`;o00001P0I6AT2o`0001D0000000?o000001TI6@0I6AT00`0I6AT01Ol00000<c<c03<c
<`0c<c<000000080C4a<00H0000006IVIP1VIVH0000007moO`00000209VIV@050000002c/k<0/k>c
0;>c/ol000001P3<c<`01?l00000/k>c0;>c/`00000209VIV@030000001oOgl000000080IVIV00@0
000004a<C?l0000000000P0c<c<00`0000006ATI01TI6@0201TI6A<000001?ooool00`00003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01Gooooo1OnY_NP00onX_>SoYkcXojNlj003ojFkj@;oXKSY
00CoVk;Xoi>]jOn6XNGoQZ7U0_mfT=l2ogB;f`;oFW;A00Co=U;2ob]8_?l_A[Wo7c6Y0_lk?j`01Om1
?JKoDD>Soea?ZOmYE:OoNEjW00?o00001?nGM:X2oj>0[@05ojb:/OnkV;?o^iRcok^H/oo0Xk`00ooC
^/402OoWe<?oln^moo7e[_oamJkog?BKomCaU?oHnZoof_kBomKdh`02olWNj003okc5hOnd_=oo057=
00;oTh:n0onVQ[800onaR:[o]96cokfBZP03okfBZP04ol6BY_o8W:_ob9b[olRIYP?od:F[00CocYnW
omBY[?oDZJcoe:V/0ooCZ:`4om:UZP;oe:JX0ooFZ:P2omn`YP;oi;BT00Koj[ZQoo?7X_ocaj;on<jO
oocFVoong9P2oogRU@07oo_WUOogk9[om?:Too3f]?l0003ofnWNom3Ri002olKJj003okW<jOndb>Wo
]<SY00?o[l;X00?o[;oXoj^oj?n[_nP00_nZ_^P9ojVmj003o`000?oooooooooo01Gooooo0009oooo
o`0400000?oooooooooooooooa<00000100I6AT010000000<c<c03<c<`00000204a<C0050000001V
IVH0000007moO`0000000P2IVIT010000000/k>c0;>c/ol000050<c<c003o`00002c/k<0/k>c0080
/k>c00@0000009VIV@2IVIT000000`1oOgl010000000IVIV06IVIP00000204a<C0030000000c<c<0
<c<c0080<c<c00?o000001TI6@0I6AT01@0I6AT00ol0000000000000000E00000003o`00000I6AT0
6ATI00<06ATI00Go000003<c<`0c<c<0<c<c0000000204a<C0060000001VIVH0IVIV0000001oOgl0
00000P2IVIT010000000/k>c0;>c/ol000080<c<c003o`00002c/k<000000080VIVI00<0000007mo
O`0000000P1VIVH010000000C4a<04a<C000000203<c<`030000000I6AT06ATI00806ATI4`000004
ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool05oooool3ojVmj0?oZ;gX0_nW_>P0
0onU^nWoX[[Yoibej@02oibej@;oTjgY0_n6XND00omfT=ooH7WEof1ie@02odANb008ocIB`_l=;Zko
32VYoalaZOlO:J3o>cn/od4mY_mA@j<3o`0000;oNEjW0_n9JJP3oiMdZP;oXh2]1?nkV;<3om>j`@;o
imC300Woln^moo7e[_oVmJ3oe?6DolCXQOoAnJ_of_kBomG]iOo6d>800onlaN400ol0DLgoJHCJofV4
fP02ojJ6/P04oj2@`ondTK?o]96cokBA/`?o_I:Z0oo8W:/4om2UZ`Coe:V/0ooCZ:`00ooC[;7odZFZ
om:UZP02om:V[004omBVZ?oFZ:SoeZRXomJXZ0;ogk2V0_oT]:@02OoZ^Z7ollNRoo?7X_ohcYooo=JK
ookLV?omhYGonnNEooO/VP02ooCbY005oo3f]?o[n<Oo0000omS/h_o6f^P00_nnd^T00ondb>Wo/LGY
ojg1j003ojg1j003oj^oj?n[_^SoZ[kX00;oZ[kX2?nY_NP00ol0003oooooooooo`0Eooooo`002Ooo
ool01000003ooooooooooooooolC000000@06ATI00X0000003<c<`0c<c<0000004a<C0000000IVIV
0000001oOgl000000P2IVIT010000000/k>c0;>c/ol000070<c<c007o`00002c/k<0/k>c0;>c/`00
0000VIVI0000000307moO`040000001VIVH0IVIV00000080C4a<00<0000003<c<`0c<c<00P0c<c<0
0ol000006ATI01TI6@0501TI6@03o`0000000000000001L0000000?o000001TI6@0I6AT00`0I6AT0
1?l00000<c<c03<c<`00000204a<C0080000001VIVH0IVIV0000001oOgl0000009VIV@0000020;>c
/`03o`00003<c<`0c<c<00P0c<c<00?o00000;>c/`0000000P2IVIT01Ol00000Ogmo0000001VIVH0
00000080C4a<00@0000003<c<`0c<c<00000100I6ATC000000Cooooo00<00000ooooooooool04_oo
ool00ol0003oooooooooo`0Hooooo`?oZKgX0_nX_NP3ojJlj@;oX[[Y00?oW;GYoiFbjonE/^/00_n7
YnX00omcUNGoGGkKoeenf`02of1ie@04odANb?lO?KOo=U;2o`d^[P;o7c6Y0ol000000omA@j?oIDnT
ofUDY`02ogUNY`;oRFVX0onGM:X00onSP:go/8^^ok2;[P02ok^H/`;ocZ^g00_odk[1onOD`ooWe<?o
ln^moo7e[_oakiKoh^b8olCXQOoAnJ_of_kBomG]i@03olK@hP05okc5hOn`[MGo[:SCo`1AcOmYQ=X0
0onPT<<3okBA/`;o_I:Z00Goa:6dolRLZoo8W:_ob9b[om:_]P03om2UZ`03omZg]_oDZJcoe:V/00;o
fKBd00GodjR/om>//OoC[;7odjbaom:UZP02om:V[0CoeZRX00?ofJZWomn`Y_oT]:@00_oZ^Z404Ooa
`Ikon<jOooS>WooleY_oo]bHoogRUOokiiGomnbJooCbY?o`m[CojoS7on?deol0003of>cRolgRionn
d^Wo^<cY00?o/LGY0_n]`NP01On/_nSoZkkXoj^nj?n[_^SoZ[kX00;oZ[gX2?nY_NP00ol0003ooooo
ooooo`0Dooooo`002Oooool01000003ooooooooooooooolC000000@06ATI00X0000003<c<`0c<c<0
000004a<C0000000IVIV0000001oOgl000000P2IVIT00`000000/k>co`0000090<c<c006o`00002c
/k<0/k>c0000002IVIT000000P1oOgl010000000IVIV06IVI_l0000304a<C005o`00000c<c<0<c<c
03<c<ol000001`0I6AT00ol0000000000000000I00000003o`00000I6AT06ATI00806ATI00Co0000
03<c<`0c<c<000000P1<C4`02P000000IVIV06IVIP000000Ogmo0000002IVIT000000;>c/ol00005
0<c<c0;o00001@3<c<`02Ol00000/k>c0000002IVIT0000007moO`000000IVIV0000000204a<C004
0000000c<c<0<c<c000000@06ATI4`000004ooooo`0300000?oooooooooo01;ooooo00?o0000oooo
ooooool06Oooool3ojVmj0;oZ;gX00?oY[cYojBkjOnT^nT00onO^>X2oiFbj`;oQjOZ00GoLiGUoeen
fom7ILgoAfG=odANb002oalm]`?o000000Co7bVPod4mY_m1?JKoDD>S0_mUCj@2ogUNY`;oRFVX0_nG
M:X01OnROJ_o/8^^ok2;[_n`Rjko^iRc00?ocZ^g0_oS`kP02OoWe<?oln^moo7_U_oakiKo`Me_okOT
POoDo;Oog_SJom?JgP02olK@hP05okRde_n`[MGo/:gEok2]eOn/Z=<00_mYQ=X3oj2@``;o]96c00Go
_I:ZolBQ]?o4XKCoa:6dolRLZ`02om:_]P;od:F[0_oJ]kH01OoDZJcofKBdomVd]?oI];CodjR/00?o
djba0ooBYZ`3omJXZ0;ofJZW0_oT]:@2onZjX@04oo71W_ohb9Woo=JKookLV0;ooN:E00WonnNEonST
NOoVjXGoio>LonSj]ooUn/kof>cRo`000?o=h^L00onhc>T01OnaaNWo[/;Xojk2j?n/_nSoZkoX00Co
Z[kX00?oZ[gXojVmj?nY_NP02?nY_NP00ol0003oooooooooo`0Cooooo`002Oooool01000003ooooo
oooooooooolC000000@06ATI00X0000003<c<`0c<c<0000004a<C0000000IVIV0000001oOgl00000
0P2IVIT00`000000/k>co`0000090<c<c006o`00002c/k<0/k>c0000002IVIT000000P1oOgl01000
0000IVIV06IVIP00000304a<C0050000000c<c<0<c<c03<c<ol000001`0I6AT00ol0000000000000
000I00000003o`00000I6AT06ATI00806ATI00Co000003<c<`0c<c<000000P1<C4`02P000000IVIV
06IVIP000000Ogmo0000002IVIT000000;>c/ol000040<c<c004o`00003Vi^H0i^KVo`0000@0c<c<
00Wo00000;>c/`000000VIVI0000001oOgl0000006IVIP0000000P1<C4`010000000<c<c03<c<`00
000401TI6A<000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o
ZKgXojRmj?nX_NP00onW_>T2ojBkj@03oinhj_nK]ncoS:o]00;oS:o]00KoMIk[oeN5homGQN?oGGkK
odMUcOl^B[h2o`000007o`d^[_l03YSo01FJoalYX?l];Iko@CfVoe53X`02ofE?Y0;oNejV00?oRFVX
oi1^Z?nROJ/00_nROJ/3ok2;[PCocZ^g0_oS`kP01?odfkCon^^Woo7_U_oRk8P2okOTP@04omkhf_oC
f]kodm[NolBld`?o^;CF00Go/:gEojNIaonUU/GoYIK5o`0bW@03oj2@``03okBA/onfYl[oa:6d00?o
a:6d00Gob9b[om:_]_oB[kKodZnfom2UZ`02omZg]PCofKBd1?oC[;43om:V[003om2V[OoFZ:SofJZW
00;ofJZW0_oT]:@04ooZ^Z7olL6Noo71W_ohb9WooM2CoooHRoomg8;ommmjonoPM_oXi7Woi^Z5onOc
W?oXn[OoiO[>omccg_o=h^Oo0000ol?HjOnhc>T00_ncb>T00on^`^So[L7Xojg1j002oj^oj0CoZ[kX
2_nY_NP00ol0003oooooooooo`0Cooooo`002Oooool01000003ooooooooooooooolD000000<06ATI
00h0000003<c<`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VIV@000000/k>co`0000@0
c<c<0ol000040<c<c003o`00002c/k<000000080VIVI00D0000007moO`000000IVIV0000000304a<
C0050000000c<c<0<c<c03<c<ol000001P0I6AT2o`0001`0000000?o000001TI6@0I6AT00P0I6AT0
1?l00000<c<c03<c<`00000204a<C0090000001VIVH0000007moO`000000VIVI0000002c/k?o0000
00@0c<c<00?o00000>KViP3Vi^H00P3Vi^H03Ol00000c<c<0<c<c03<c<co00000;>c/`000000VIVI
0000001oOgl0000006IVIP0000000P1<C4`010000000<c<c03<c<`00000401TI6A<000001?ooool0
0`00003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo0_nX_NP3ojNlj@;oXk_Z0_nK]n`0
1On<[ngoPJ[_oebBjomLT^_oEhGS00?o000000Ko;TZnoalm]ol06J7o3Bj^o`0EV_lO:J02obd]WP;o
DD>S00?oIDnTog]NY_mkGZH00on@KZP3oj9mZ`;o/8^^00?o`Ybaolj[]oo>ZkL00ooS`kP02?odfkCo
lNnFon;/R?nTcEco]nB1onOjcOoOg=?odm[N0oo4_=<00onh]=Ko[Ik8ojNIa`02ojNIa`;oYIK500?o
Y9C4ogJTkomfY>l00onfYlX3olBQ]0CodZnf0ooJ]kH01OoPdLWofKBdomVd]?oI];Coeko200;odjba
0_o?[KH01?oBYZcod:J]om2V[OoFZ:P3omVZY`03omf]YOoZ^Z7oj[ZQ00;olL6N00_on<RIoog@Tooo
f8_ooMb2ooOON_oXi7Woi^Z5onOcW?oXn[OoiO[>omccgP02om3Yi`04ol?HjOl0003o^m7Zok?8j@;o
/<CY00?o[L7Xojc0j?n[_^P00_n[_^P3ojZnj0_oZKgX00?o0000ooooooooool04_ooool000Wooooo
00@00000oooooooooooooooo5000000301TI6@0>0000000c<c<0<c<c0000001<C4`0000006IVIP00
0000Ogmo0000002IVIWo00000;>c/ol000030<c<c004o`00003Vi^H0i^KV0>KViP;o00000P3<c<`0
0ol00000/k>c0000000209VIV@050000001oOgl0000006IVIP0000000P1<C4`01@000000<c<c03<c
<`0c<c?o000000H06ATI00?o0000000000000000700000000ol000006ATI01TI6@0201TI6@04o`00
000c<c<0<c<c00000080C4a<00T0000006IVIP000000Ogmo0000002IVIT000000;>c/ol000000P3<
c<`2o`0000H0i^KV00co00000<c<c03<c<co00000;>c/`000000VIVI0000001oOgl0000006IVIP00
000204a<C0040000000c<c<0<c<c000000@06ATI4`000004ooooo`0300000?oooooooooo01;ooooo
00?o0000ooooooooool07?ooool3ojRmj003ojNljOnV_>WoXK[[00;oXK[[0_nF]^d03on1Z^oo0000
o`000?l0003o;FcLoc]We?lVC<?o;TZno`h][OlO?KOo01VQo`0EV_l04YCo7bVPobd]WP02oe53X`03
ofE?Y?mkGZKoNejV00?oT6jX0onROJ/01On`Rjko`Ybaol:L/Oo2W;7ocZ^g00;ohl>h00Kom=^doo[[
YooakiKognIkoi_<GooWn/d2omoLd`;od;k900?oa;cCokRUa_n]W/P00_n]W/P2ojNIa`04ojFFaOnO
QkWoX8Jhoj26^0;oMZC_0onfYlX00oo4XKCoc/;>olk2cP02om:_]P;og]?=00Gof[Nfon3AbOoPdLWo
h=79omVd]002omNo`P05om>//Oo?[KKocjffoln]]_oBYZ`00_o@YZd3omVZY`;ogJfU0_oZ^Z403?oa
`Ikon<RIooS8VOomd9?oomR;oogLP_o_h7Koj>AionKZQOoDjXGog_RXom_ig0;od>WW00?oa]k[ok_A
j_l000000_nebnX00on`a>Wo[/;Yojk2j@02ojc0j003oj^nj?nZ_^SoZ[kX00;oZ[kX2onY_NP00ol0
003oooooooooo`0Booooo`002Oooool01000003ooooooooooooooolD000000<06ATI00h0000003<c
<`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VIV@000000/k>co`0000<0c<c<00?o0000
0>KViP3Vi^H00P3Vi^H01_l00000c<c<0<c<c?l00000/k>c00000080VIVI00D0000007moO`000000
IVIV0000000204a<C0050000000c<c<0<c<c03<c<ol000001P0I6AT00ol0000000000000000L0000
0003o`00000I6AT06ATI00806ATI00Co000003<c<`0c<c<000000P1<C4`02@000000IVIV0000001o
Ogl0000009VIV@000000/k>co`0000020<c<c003o`00003Vi^H0i^KV00D0i^KV00co00000<c<c03<
c<co00000;>c/`000000VIVI0000001oOgl0000006IVIP00000204a<C0040000000c<c<0<c<c0000
00@06ATI4`000004ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool3ojRm
j0;oY[cY00?oXK[[oinjk?l000000_l000001?nA]>ooLjGaocZ2j?l]K=`2o`M5a@0:oaLg/ol^B[ko
3Rf]o`0IXOl03YSo01FJoalYX?l];IkoAS^Poe53X`;oIDnT00CoNejVoi1^Z?n@KZSoT6jX0onROJ/0
1?n`Rjko`Ybaol:L/Oo2W;42on?3^0;om=^d00Kon^^WomoVNoo;gFgol??2onKC`ooOg=<2om2nb@06
olF[_onhYLKo^:G6okRUa_n]W/SoY8jm0_nPRK/3oin7^@?oX8Jh0_nfYlX01On@f?ooc/;>olk2c_o>
`/kodZnf00?og]?=0ooPdLT01?o=k^[oeko2omNo`_oG_l84oln]]P?od:J]00?ocjB]omVZYooIZZL0
0_oM[JD01?oS/Z?oj[ZQoo71W_ohb9T2oog@T`0:oooHRooggg[okn1fonSTNOo;ffOoe>Z5on7naooK
nMcodNoWolKNj`;o_MG/00Ko]L_Zo`000?naa^[o/LKZojk2jOn/`NT3oj^oj0;oZ[kX3_nY_NP00ol0
003oooooooooo`0Aooooo`002Oooool01000003ooooooooooooooolD000000<06ATI00h0000003<c
<`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VIV@000000/k>co`0000<0c<c<00?o0000
0>KViP3Vi^H00P3Vi^H01_l00000c<c<0<c<c?l00000/k>c00000080VIVI00D0000007moO`000000
IVIV0000000204a<C0050000000c<c<0<c<c03<c<ol000001P0I6AT00ol0000000000000000L0000
0003o`00000I6AT06ATI00806ATI00Co000003<c<`0c<c<000000P1<C4`200000080Ogmo00L00000
09VIV@000000/k>co`00003<c<co000000T0i^KV00_o00000<c<c?l00000/k>c0000002IVIT00000
07moO`000000IVIV0000000204a<C0040000000c<c<0<c<c000000@06ATI4`000004ooooo`030000
0?oooooooooo017ooooo00?o0000ooooooooool07oooool3ojRmj0?o00000_nO^^`03onA]>ooSK?`
ofBPl_mTX?;o>X;Xo`17b?l7ALGo9Tc3oaLg/ol>;Jgo01VQo`00R_l05I[o01:Dobd]WP02odHkX0;o
IDnT0_mkGZH3oi1^Z0;oXWf[1?o2W;402ooH/kCohl>hooCK]?odfkCom>bBol_MKOoAlIKol??2onKC
`ooI^k_od;k900?oaJ^o00Co^:G6ojnE_?nTS[goY8jm0onPRK/2oin7^@?oX8Jh00GoXHJhoi3Hoon@
f?ooT=Soolk2cP03oj;dk004omkCcOnenn?o]O_Son3Ab@?ocNkZ00?oeko2olRod_o8_m800oo?[KH0
1?o6Yk[od:J]olnT[Oo?Y:d2omVZY`;ogJfU00Cohk:Soo71W_oa`Ikon<RI0_omd9<02?oof8_ommmj
onSTNOo8d5Koe>Z5on7naooKnMcodNoW0_o6hn`01_nmeNco]/k[okK>jonaa^[o0000ojk3j@?o[<7Y
00?oZkoXojZnj?nZ_^P00_nZ_^P>ojVmj003o`000?oooooooooo013ooooo0009ooooo`0400000?oo
oooooooooooooa@00000100I6AT00`000000<c<c0000000204a<C080000000H0Ogmo0000002IVIT0
00000;>c/ol000020<c<c003o`00003Vi^H0i^KV00@0i^KV00co00000<c<c03<c<co00000;>c/`00
0000VIVI0000001oOgl0000006IVIP00000204a<C0040000000c<c<0<c<co`0000H06ATI00?o0000
000000000000700000000ol000006ATI01TI6@0201TI6@04o`00000c<c<0<c<c00000080C4a<00T0
000006IVIP000000Ogmo0000002IVIT000000;>c/ol000000P3<c<`01?l00000i^KV0>KViP3Vi^H3
o`0000<0i^KV00Go00000<c<c03<c<co00000;>c/`020000000407moO`000000IVIV00000080C4a<
00@0000003<c<`0c<c<000000`0I6ATD000000Cooooo00<00000ooooooooool04Oooool00ol0003o
ooooooooo`0Oooooo`?o000000CoZ;gXojFljOnU_>[oYKcZ0_nN^^`2ohfcl0;oI:3b00Wo46_Mo`0F
YOl7ALGo5cNco`h][Ol03IWo01VQo`00R_l04Y@00_l];Ih00om6>j3oHdjTofE?Y002og]NYP?oT6jX
00?oXWf[ok6<[_naS:h00_o2W;42omRc]0;ok/jc00ConnFXomoVNonfcUKol??20_oVdl<00ooI^k_o
aJ^oolF[_`02olF[_`?o[iFl0_nTS[d2oj29^`?oWhNi00CoX8Jhoial[_nNOJkoWWf^0onNOJl2oiYl
/@?oSgNd0_maIkP00ol_@;;o/C00og3Dn`04olRodP04oln]]_o6Yk[oaZNjom2V[@?ocjB]0_oM[JD2
on>bX`;olL6N00con<RIoog@Tooof8_ooMb2onoPM_o?cU7obm]WolodWOoHo/;oeogKolocjOo6hn`2
okgHk@05okK>jonab>_o/LS[ojk3jOl000001?n[_nP3ojZnj0ooZKgX00?o0000ooooooooool04?oo
ool000Wooooo00@00000oooooooooooooooo5000000401TI6@030000000c<c<000000080C4a<0P00
00001P1oOgl0000009VIV@000000/k>co`000080c<c<00?o00000>KViP3Vi^H01@3Vi^H02ol00000
c<c<o`00002c/k<0000009VIV@000000Ogmo0000001VIVH000000080C4a<00@0000003<c<`0c<c?o
00001P0I6AT00ol0000000000000000L00000003o`00000I6AT06ATI00806ATI00Co000003<c<`0c
<c<000000P1<C4`02`000000IVIVo`00001oOgl0000009VIV@000000/k>co`00003<c<co000000<0
i^KV00Go00000?ooo`3oool0ooooo`0000030>KViP04o`00003<c<co00000;>c/`80000000@0Ogmo
0000001VIVH000000P1<C4`010000000<c<c03<c<`00000301TI6A@000001?ooool00`00003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01cooooo0ol00002ooooo`?oZ;gX0_nU_>X3oifjk@;oRK?a
0_mFVo802ol0D/co01JUo`0]/_lG=k?o3Rf]o`0=VOl008[o01:DoaHMV?l];IkoAS^P00;oHdjT0_mk
GZH2oi1^Z005oi]i[?naS:ko/Hb^ok6<[_o2W;400ooH/k@2onk>/`05ooC/T_nfcUKol??2oo3c`_oV
dl<00_oI^k/01?oA[KCoaJ^oolF[_oo5Zkl3ojnE_0;oY8jm00?oX8VkoiYm/_nJNk000_nJNk02oial
[P?oWWf^0_nNOJl2oiYl/@?oSgNd0_maIkP01?l_@;;o0021ok4`0?l8O>42olRodP04ojV/f?o6Yk[o
aZNjolJW^PCocjB]0_oM[JD2on>bX`0<onZiXOohb9Won<RIoog@Tooof8_ommmjomgBF?o8d5KoZlUB
omSn`_oGoM_oco?Y0_o4iNh01?nmf>go]/o]okK?kOnab>/2ojk4jP04o`000?n/`NWoZkoXoj^oj0Co
Z[kX4?nY_NP00ol0003oooooooooo`0?ooooo`002Oooool01000003ooooooooooooooolD000000@0
6ATI00<0000003<c<`0000000P1<C4`20000000607moO`000000VIVI0000002c/k?o00000P3<c<`0
0ol00000i^KV0>KViP050>KViP0;o`00003<c<co00000;>c/`000000VIVI0000001oOgl0000006IV
IP0000000P1<C4`010000000<c<c03<c<ol0000601TI6@03o`0000000000000001`0000000?o0000
01TI6@0I6AT00P0I6AT01?l00000<c<c03<c<`00000204a<C00;0000001VIVH0000007moO`000000
VIVI0000002c/k?o00000<c<c?l000000P3Vi^H00ol00000oooo0?ooo`020?ooo`08o`00003Vi^H0
i^KV0>KVi_l00000c<c<o`00002c/k<20000000407moO`000000IVIV00000080C4a<00@0000003<c
<`0c<c<000000`0I6ATD000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0I
ooooo`?o00001_ooool00onX_NSoZ;gYojRmj@02ojFljPCoWK[]0_n8/o802om=VO;o01JUo`0]/_l0
9:So1BBVo`0=VOl008[o0028o`0BU?lF7ISoAS^P00;oHdjT0_n1I:P3oi]i[0?o/Hb^0ooH/k@2onk>
/`05oo_UZ?odk9;oXlE>oo?R^OoWa[D00_oI^k/3om6]]003olF[_onmW[So_Ijh00;o[iFl0_nMPK@3
oiYm/P;oVW^`0onLO:h2oiim[P;oWWf_00?oVWbaoiahZOnDM:`00_nDM:`2ogmZ/004obm0/_l008ko
001Go`13a@CoZJcH0_o6YkX4olnT[@06olnT[?oM[JGohk:Son>bXooZ^J7oll:L0_omd9<02Ooof8_o
kmQWolo>DOo8d5Ko_NjGol_m__o>o]cob?C/olCUkP02ok_Ik`08okK?kOnab>co/LS/ojk4j_n/`NWo
ZkoYo`000?n[_nT6ojZnj13oZKgX00?o0000ooooooooool03_ooool000Wooooo00@00000oooooooo
oooooooo5@00000301TI6@090000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo00800000
00D0/k>co`00003<c<`0c<c<o`0000080>KViP0=o`00003<c<co00000;>c/ol00000VIVI0000001o
Ogl0000006IVIP000000C4a<0000000303<c<`03o`00000I6AT06ATI00@06ATI00?o000000000000
00006P0000000ol000006ATI01TI6@0201TI6@0Ao`00000c<c<0<c<c03<c<`000000C4a<0000001V
IVH0000007moO`000000VIVI0000002c/k?o00000<c<c?l000000P3Vi^H00ol00000oooo0?ooo`04
0?ooo`0=o`00003Vi^H0i^KVo`00003<c<co00000000002IVIT0000007moO`000000IVIV00000002
04a<C0030000000c<c<0000000@06ATI50000004ooooo`0300000?oooooooooo017ooooo00?o0000
ooooooooool05_ooool3o`0000[ooooo1?nX_NT2ojFljP03oifjkOnM^ngoRKCb00;oRKCb00WoBi[c
o`0FYOl0;K;o02BXo`0=VOl008;o002:o`0BU?lF7IP00_m6>j001?mSCZCoPFBXoh5TZ?n1I:P3oi]i
[0;o/Hb^00?oaj:comRc]?oH/k@00_o^c[<01oodk9;o]/iFoo?R^Ooch[WoilJeomfd[_oI^k/00ooA
[K@3okfN^004ojnE_?nWRKKoWH6doif1]0?oVWfb0onJNk02oial[P;oWWf^00?oWWf_oiihZ?nLN:T0
0_nLN:T2oiAd[0;oOfZ`00GoCTjaobm0/_l005Oo001Bo`13a@03ojV/f003olJW^_nkWK[o^ifj00;o
cjB]0_o?Y:`2on>bX`;oj[VQ00[oll:Loo_=UOokcIGoomJ9onoHIoo?cU7oZ=I]ol_m__o>o]cob?C/
0_noiO401?nkfNoo]<o^okC?k_nab>`2ojk4jP;o[<7Y00GoZkoYo`000?nZ_^SoZ[kXojVnj00CojVm
j003o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooooooooaD000000`0I6AT02ol0
0000<c<c03<c<`000000C4a<0000001VIVH0000007moO`000000VIVI00;o00000P3<c<`00ol00000
i^KV0>KViP060>KViP0=o`00003<c<co00000;>c/`000000VIVI0000001oOgl0000006IVIP000000
C4a<0000000303<c<`03o`00000I6AT06ATI00@06ATI0_l0000J00000003o`00000I6AT06ATI00<0
6ATI013o000003<c<`0c<c<0<c<c0000001<C4co000006IVIP000000Ogmo0000002IVIT00000o`00
003<c<co00000P3Vi^H00ol00000oooo0?ooo`050?ooo`0Bo`00003Vi^H0i^KVo`00003<c<co0000
0000002IVIT0000007moO`000000IVIV0000001<C4`00000o`00000c<c<00000100I6ATD000000Co
oooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`;o00003oooool2ojRmj@?o
YKcZ0_nM^nd03_n9]?;oS;Kboe:OmOmBWoGo00BGo`0TZ?l03ISo00fIo`00R_l008So5QfHocTeXOm6
>j3oHdjT0on1I:P3oi]i[00;ok6<[_o7X[?oaj:colNR/ooH/kCok/jcoo_UZ?odkIOo0000oo?R^OoW
a[D00_oM]:h3om6]]0;oc:B`0_nmW[P3ojN9]P;oWH6d0_nJOK83oiYk/0;oW7b^00CoWWf^oiagYonN
N:SoWWRX0onLN:T3oiAd[0;oOfZ`00CoCTjao`00S_l005Oo02fc0on:SM03ok^M^P04olnT[Oo?Y:co
cjB/olnT[0;ohk:S0_oZ^J402Ooc`YconlfEoo_=UOooeXWogM9Ho`000?nWiY3o`okPol7bl@02okoU
l@;o]mO`00Co]<o^ojo8k?n_b>co[/CZ0_n/`NT2oj^oj@03ojZnj?l0003oZ[kX00;oZKkX3onY_NP3
ooooo`03o`000?oooooooooo00kooooo0009ooooo`0400000?oooooooooooooooaD000000`0I6AT0
3@000000<c<c03<c<`000000C4a<0000001VIVH0000007moO`000000VIVI00000?l000000P3<c<`0
0ol00000i^KV0>KViP060>KViP0=o`00003<c<co00000;>c/`000000VIVI0000001oOgl0000006IV
IP000000C4a<0000000303<c<`03o`00000I6AT06ATI00H06ATI0_l0000G00000003o`00000I6AT0
6ATI00@06ATI013o000003<c<`0c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0000002IVIT0
0000o`00003<c<co00000P3Vi^H00ol00000oooo0?ooo`050?ooo`0?o`00003Vi^H0i^KVo`00003<
c<co00000000002IVIT0000007moO`000000IVIV0000001<C4`000000080<c<c00<0000001TI6@0I
6AT00P0I6ATD000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`?o
00004_ooool2ojRmj@?oYKcZ0_nN^nd2ohbflP08oe:OmOl019Oo02BXo`4OXol03ISo0022o`00R?lF
7IP2ocTeX@;oHdjT0_n1I:P3oi]i[006ok6<[_o7X[?oaj:colNR/ooQ`;Ook/jc0_odkIL00ooch[Wo
ilJeonO6]@02omfd[P03omR/Z_oA[KCoc:B`00;oc:B`00?o_IjhokNE]?nWRKH00_nWRKH2oif1]0?o
VWfb0_nJNk001?nLO:koVGFXoiagYonLMjL2oiihZ0?oW7RY0onDM:`2ogmZ/005odi>/Ol008ko001G
o`00J?l0;K<00on:SM02ok^M^PCocjB/00?odjN[on>bXooZ^J400_oc`Y`2oo_=U@05oooFROo?cU7o
0000okWkjOo1l_400_njhO<2okOGl0;o/Lg^00Go[lS/ojg3j_n]`n[o[<7Yoj^oj@03ojZnj003o`00
0?nY_^SoZKgX00koZKgX1Oooool00ol0003oooooooooo`0>ooooo`002Oooool01000003ooooooooo
oooooolE000000<06ATI00d0000003<c<`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VI
V@00003o00000080c<c<00?o00000>KViP3Vi^H00`3Vi^H03?l00000i^KV0>KVi_l00000c<c<o`00
002c/k<0000009VIV@000000Ogmo00000080IVIV0P00000303<c<`03o`00000I6AT06ATI00P06ATI
00?o00000000000000004@000003o`0000L06ATI00Co000003<c<`0c<c<000000P1<C4`010000000
IVIV00000000000209VIV@0400000?l00000c<c<o`000080i^KV00?o00000?ooo`3oool01@3oool0
3ol00000i^KV0>KVi_l00000c<c<o`0000000000VIVI0000001oOgl0000006IVIP000000C4a<0000
000203<c<`030000000I6AT06ATI00806ATI50000004ooooo`0300000?oooooooooo013ooooo00?o
0000ooooooooool03oooool3o`0001Gooooo0onX_NT01?nU_>[oY[gYojJmjOnV_NT2oj2lk0;oT;Sb
00[o00BGo`0TZ?l03ISo0022o`00R?l03I?o5QfHocTeXOmTDjWoHdjT0on1I:P2oi]i[0Coaj:c00Co
hL2gooOO/?odkIOo00000_oS^J/01?oWa[GogKB^omR/Z_oH[:X4olbT/0?o]iFd0_nWRKH00onMPKCo
UWN_oiAd[002oiAd[0;oUW>Z0_nIMJP2oiagY`?oWWRX0onLN:T2oiAd[0;oOfZ`0_m>C[401?l008ko
001Ho`0]/ol0;K<2ohZ=d003ok^M^_neU[Oo]IJg00;ocjB/0_oCYj/2onZiX@;oll:L00KonlfEoooF
ROokfWWo0000okWkjOnik?D2okCJl`;o/m?a0_nacNh00on^a^co[L?Zojg3jP02oj_0j@;oZkoY0onZ
_^P00ol0003oZKkXojVmj009ojVmj0[ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000
oooooooooooooooo5@00000401TI6@030000000c<c<000000080C4a<00@0000006IVIP000000Ogmo
0P000000102c/k?o00000<c<c?l000040>KViP;o00000`3Vi^H03Ol00000c<c<o`00002c/k<00000
09VIV@000000Ogmo0000001VIVH0000004a<C00000000`0c<c<00ol000006ATI01TI6@0801TI6A?o
00002@0I6AT03_l00000<c<c03<c<`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VIV@00
0000/k>c0_l000020>KViP03o`00003oool0oooo00H0oooo00?o00000>KViP3Vi^H00_l000002P2c
/k<0000009VIV@000000Ogmo0000001VIVH0000004a<C000000203<c<`040000000I6AT06ATI01TI
6AD000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo0ol0000Ioooo
o`06ojRmjOnX_NSoZ;gXojRmj?nV_NWoYkgY0onR_>`2oiJjl007o`0<V_l03ISo0027o`00K_l008So
5QfHocTeX@02ofACZ@?oPFBX00?oVgV/ojj</_n^S;800_o7X[<2on70]`03ooC]UooFhG;ok/fb00;o
hkV[0_oM]:h2omR/ZP05omNYZ?o<Y;3oc:B`olbT/?o9X:h00_ngUK@00onWRKKoWh2aoiIg[`02oiIg
[`;oU7B/0_nFLjX2oiUeZ0?oW7NW0_nNN:P2oiahZ@03oimgYOnJMJOoVWFW00;oS6j/0om[G;000ol0
05Oo0RJZo`0]/`02ogUga0?o]IJg0_o?Y:`2om>WZ`;oj[VQ0_oc`Y`01?okcIGoomJ9omgBF?l00002
ok?Qm`03okCJlon_cNoo[lg_00;o[lW]00?o[/K/ojc2j_n/`^X00_n[`>T00onZ_nWoZ[kXojZnj002
ojZnj0;oZKgX00?o0000ojVmj?nY_NP01OnY_NP=ooooo`03o`000?oooooooooo00gooooo0009oooo
o`0400000?oooooooooooooooaH000000`0I6AT02@000000<c<c03<c<`000000C4a<0000001VIVH0
000007moO`02000000040;>c/ol00000c<c<o`0000<0i^KV0ol000030>KViP0=o`00003<c<co0000
0;>c/`000000VIVIo`00001oOgl0000006IVI_l00000C4a<0000000303<c<`03o`00000I6AT06ATI
02<06ATI0_l0000203<c<`0=0000001<C4`0C4a<0000001VIVH0000007moO`000000VIVI00000?l0
0000c<c<o`0000020>KViP03o`00003oool0oooo00H0oooo00?o00000>KViP3Vi^H00_l000002P2c
/k<0000009VIVOl00000Ogmo0000001VIVH0000004a<C000000203<c<`040000000I6AT06ATI01TI
6AD000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo0ol0000Noooo
o`?oZ;gX0_nW_NT02onR_>coY;g[ojBmjonK^noo00bJo`4OXol03ISo0022o`00R?l03I?o>CFQ00;o
I5>Y0on<LK03ojj</P06olNR/ooQ`;OohL2gooOO/?odkIOoaMe]0ooS^J/00ooN[jKogKB^omR/ZP02
omNYZ0;oc:B`0_o9X:h01?ngUKCo/Hnboin0/OnOP;43oiIg[`;oU7B/0_nFLjX3oiUeZ0;oW7NW0_nN
N:P00onLN:WoWgNUoimgY@02oiYeY`;oS6j/0om[G;001Ol04igo001go`8VZ_l0;K?oNGO400Co]IJg
00CocjB/om>WZooCYj_ofjjY0_oc`Y`2oo_=U@04oooFROo3`d7o/>Shok?Qm`;o[m7b00?o[lg_ojc6
k?n/a^`00_n/a>/00on/`^[oZ[oYojZoj@02ojZoj@;oZ[kX0_nY_^P2ojVmj004o`000?nY_NSoZKgX
ojVmj17ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5P000003
01TI6@090000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0080000000@0/k>co`00003<
c<co00001@3Vi^H04Ol00000i^KV0>KViP3Vi^Ko00000<c<c?l00000/k>c0000002IVIT0000007mo
O`000000IVIV0000001<C4`0000000@0<c<c0_l0000R01TI6@03o`00000c<c<0<c<c0080<c<c00d0
000004a<C01<C4`0000006IVIP000000Ogmo0000002IVIT00000o`00003<c<co00000080i^KV00?o
00000?ooo`3oool01P3oool00ol00000i^KV0>KViP02o`00000:0;>c/`000000VIVI0000001oOgl0
000006IVIP000000C4a<00000080<c<c00@0000001TI6@0I6AT06ATI5@000004ooooo`0300000?oo
oooooooo013ooooo00?o0000ooooooooool01_ooool3o`0002;ooooo0onX_NP2ojNmj@09ojBmjonU
_N[oYKgZo`00POl07J;o01ZOo`00Qol006ko00fC00;o>CFQ00CoI5>Yohaa/?n<LK3oS76`0on^S;80
1_o:[;cohL2gon70]ooggk3oaMe]onk=/P;ohkV[0_oN[jH2omR/ZP?oejVX00?oc:B`olVP[_o9X:h0
0_naSk83oin0/@;oUWN_0onDM:`2oiIcZP;oVGFX0_nLMjL00onNN:SoWgJToimgY@02oimgY@?oVWFW
0_n<KZ`2of]L/004ob0c[?l007;o0RJZo`8VZP;oNGO40_neU[L00oneU;KodjN[om>WZ`02om^^Z@06
onNjY_oc`YconlfEoo_=UOooeXWo00000_n_e_@01On_dO;o[<S^ojc8k_n/a^coZl7Z00?oZl3Y00?o
Z[oYojZnj?nZ_^P00_nZ_^P2ojVnj0CoZKgX00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0=ooooo`002Oooool01000003ooooooooooooooolG000000<06ATI00L0000003<c<`0c<c<00000
04a<C0000000IVIV0080000000H0VIVI0000002c/k?o00000<c<c?l000090>KViP04o`00003<c<co
00000;>c/`8000000P1oOgl01@000000IVIV0000001<C4`0000000D0<c<c00?o000001TI6@0I6AT0
7P0I6AT00ol00000<c<c03<c<`0203<c<`0@0000001<C4`0C4a<0000001VIVH0000007moO`000000
VIVI0000002c/k?o00000<c<c?l00000i^KVo`0000P0oooo00Oo00000>KViP3Vi^Ko00000<c<c?l0
000000000080VIVI0P000000101VIVH0000004a<C000000203<c<`030000000I6AT06ATI00806ATI
5@000004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool00oooool3o`0002Kooooo
00?oZ;gXojVmj?nY_NP00onX_NT02OnU_N[oYkgYo`0<V_l07J;o0027o`00K_l03I?o:S:VocTeX@02
ofACZ@?oS76`0_n^S;82olZ/_004on70]oodkIOoaMe]onk=/P;ohkV[0_oN[jH00ooLZjCof:bZomNY
Z002omNYZ0?obJ2^0onaSk82oin0/@?oUWN_0_nDM:`2oiIcZP;oVGFX00CoW7NWoiacY?nOMZCoWgJT
1?nOMjD2oiYeY`;oS6j/0om[G;000ol04igo0RJZo`8VZP02ogA^_@05okFF]oneU;Ko]IBfokFD]_oC
Yj/00_oK[ZT2onNjYP;onlfE00?onmYiojgJmon_e_@00_n/b^l00on/b>koZl;[oj_2j`02oj_1jP05
oj_0jOnZ_nWoZ[oYojZnj?nY_^P01?nY_NP5ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03Oooool000Wooooo00@00000oooooooooooooooo5`00000301TI6@0=0000000c<c<0<c<c
0000001<C4co000006IVIP000000Ogmoo`00002IVIT00000o`0000020<c<c003o`00003Vi^H0i^KV
00H0i^KV00_o00000<c<c?l00000/k>c0000002IVIT0000007moO`000000IVIV0000000204a<C003
o`00000c<c<0<c<c00<0<c<c00?o000001TI6@0I6AT06`0I6AT2o`0000D0<c<c0100000004a<C01<
C4`0000006IVIP000000Ogmo0000002IVIT000000;>c/ol00000c<c<o`00003Vi^Ko0000203oool0
3ol00000i^KV0>KVi_l00000c<c<o`0000000000VIVI0000001oOgl0000006IVIP000000C4a<0000
000203<c<`030000000I6AT06ATI00806ATI5@000004ooooo`0300000?oooooooooo00oooooo00Co
0000oooooooooooooooo0ol0000[ooooo`;oZKgX00_oZ;gYojRmj?nX_NSoYkgYo`00POl07J;o6BnZ
o`00Qol006Oo00fCobXbYP02ofACZ@?oS76`00Go[XbbolZ/_?o:[;cobZblon_H`002olGMK@;ohkV[
0ooN[jH00ooLZjCoejVXomNYZ003omNYZ003olVP[_o6WZooaYj_00;o/Hnb0_nOP;43oiIg[`;oU7B/
0_nFLjX01?nIMJSoUg6UoiacY?nLLj@3oimfY0?oWgNU0_nJMJL2oha^[0?oJeb`00?o83>/o`00L_l2
9ZX00_mdK[d4okFD]P03om>WZooK[ZWoikZV00;oikZV00GomLVQoooFROoigWco[<c`oj_4k003oj_3
k003oj_2jonZ_nWoZ[oY00?oZ[oY1?nY_^P00onY_NSoooooooooo`06ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5`00000301TI
6@0=0000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0000002IVIT00000o`0000020<c<
c003o`00003Vi^H0i^KV00H0i^KV00_o00000<c<c?l00000/k>c0000002IVIT0000007moO`000000
IVIV0000000204a<C0030000000c<c<0<c<c00<0<c<c7_l0000703<c<`0@0000001<C4`0C4a<0000
001VIVKo000007moO`000000VIVI0000002c/k?o00000<c<c?l00000i^KVo`0000P0oooo00oo0000
0>KViP3Vi^Ko00000<c<c?l00000000009VIV@000000Ogmo0000001VIVH0000004a<C00000000P0c
<c<00`0000006ATI01TI6@0201TI6AD000001?ooool00`00003oooooooooo`0?ooooo`Co0000;ooo
ool2ojVmj005ojRmj?nY_NSoZKgXo`00POl07J800_lI;jX00ol006ko00fCobXbYP02ofUR]`;oS76`
00?oXXfnolZ/_?o:[;`00_o:[;`00oo[f<3oaMe]onBj[002on>iZ`;ogZnV0_oLZj@5omNYZ005olVP
[_o6WZooaYj_ok6?/_nZR[<00_nFNK03ohe_[0;oSFfY0_nBKZH2oiMaY@?oW7>T0_nOMZ@3oimgY@;o
VWFW0_nHM:T3oh9[/004ob0c[?l007;o1B>Vo`8VZP;oM6jm0oneU;H2om^^Z@?oikZV00?omLVQookH
U?oigW`00on[a>`01On[`ncoZ/3Yoj[0jOnZ_nWoZ[kX00CoZKkX3?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooaP000000`0I6AT0
3@000000<c<c03<c<`000000C4a<0000001VIVH0000007moO`000000VIVI00000?l000000P3<c<`0
0ol00000i^KV0>KViP050>KViP07o`00003<c<co00000;>c/`000000VIVI0000000207moO`030000
001VIVH000000080C4a<00<0000003<c<`0c<c<09P0c<c<010000000C4a<04a<C000000206IVIP0;
0000001oOgl0000009VIV@000000/k>co`00003<c<co00000>KVi_l000001`3oool04?l00000i^KV
0>KVi_l00000c<c<o`00002c/k<0000009VIV@000000Ogmo0000001VIVH0000004a<C000000203<c
<`030000000I6AT06ATI00806ATI5@000004ooooo`0300000?oooooooooo00oooooo0_l0000aoooo
o`GoZKgX00KoZ;gXo`0IX?l07J;o6BnZo`00L?l006L2obXbYP03ofUR]onRSKkoXXfn00;oXXfn0_o:
[;`01_o[f<3ol_>Woj7EK_oT^ZcogZnVon>iZ`;ogZnV0_oLZj@00ooN[:?oejVXomNYZ002omNYZ0?o
aYj_0_nZR[<3oiIi/0;oSFn/0_n=KJT2oi9^YP;oUg6U0onLLj@2oimfY0?oWgNU00?oVWFWoj5hYOnH
M:T00_nHM:T2oh9[/004oe1C]_lP<jco001bo`DSYP;oM6jm0oneU;H01?nkV[GofjjYonNjY_oW^ZH2
ooG9X@03ookHU?nZ`N[oZ/7Z00?oZ/3Z00?oZ/3YojVnjOnY_^T00_nZ_^P00onY_^Soooooooooo`0=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooo
oooooooooooo6000000301TI6@0=0000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0000
002IVIT00000o`0000030<c<c003o`00003Vi^H0i^KV00<0i^KV00Ko00000<c<c03<c<co00000;>c
/`00000209VIV@050000001oOgoo000006IVIP0000000`1<C4`00`000000<c<c03<c<`0T03<c<`0?
o`00001<C4`0C4a<04a<C0000000IVIV0000001oOgl0000009VIV@000000/k>co`00003<c<co0000
00<0i^KV00?o00000?ooo`3oool0103oool03ol00000i^KV0>KVi_l00000c<c<o`0000000000VIVI
0000001oOgl0000006IVIP000000C4a<0000000203<c<`030000000I6AT06ATI00806ATI5P000004
ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool0;oooool5ojVmj005o`00POl06J3o
6BnZob8m]_l006L00_l@=K@2ofUR]`?oXXfn00GobZblon_H`?o[f<3oXME^onBj[002omj_YP03omf[
XooN[jKogZnV00;og:^T00?ogZbSomNYZ?oGZJP00_oGZJP00ooH[:[oaYj_olJN[`03ojZ:/`;oUWV`
0_n=Kj`2ohe]Z@;oTVjV0onGLJD2oiacY0?oWgJT0_nOMjD2oj5hY@?oV7BY0on2Jk000om@DkKo001b
o`DSYP03ogI^_003okFD]_nkV[Go^iZe00?oikZV0_oebJ400ooigWcoZ/7ZojVnj@05ojVnjACooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooo
oooooolI000000<06ATI00go000003<c<`0c<c<0000004a<C0000000IVIVo`00001oOgl00000o`00
002c/k?o000000<0c<c<00?o00000>KViP3Vi^H00P3Vi^H01_l00000c<c<0<c<c?l00000/k>c0000
0080VIVI00<0000007moO`0000000P1VIVH010000000C4a<04a<C01<C4`3000000T0<c<c3`000009
03<c<`8000000`1<C4`030000000IVIV06IVIP000000Ogmo0000002IVIT000000;>c/ol00000c<c<
o`0000<0i^KV0_l000030?ooo`;o00000P3Vi^H03Ol00000c<c<o`00002c/k<0000009VIV@000000
Ogmoo`00001VIVH0000004a<C00000000P0c<c<00`0000006ATI01TI6@0201TI6AH000001?ooool0
0`00003oooooooooo`0Booooo`03o`000?oooooooooo02oooooo1OnY_NP01Ol06J3o>DFcoaT_Z_lR
?KKo001W00;o43Fd00CoJF:goj:=__nRSKkoXXfn0_o8`M@00oo[f<3oi;Z/onBj[002omj_YP;ogJ^S
0_oLZj@2omj/X`?oejVX0_oH[:X00oo6WZoo`ijcol>N/`02ojZ:/`;oUWV`0on=Kj`2ohe]Z@;oTVjV
0_nGLJD3oiacY0;oWgJT00?oWgNUoj=hY?nQN:D00_nQN:D2oiQdZ@?oPV^`00?oD5>fo`0OZ_l07jD0
0omfK[`3ok^J]@;oikZV0_oebJ401?onf9ConMilojVojOnY_^TJooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo600000001Ol00000
6ATI01TI6@0I6AT000000080<c<c00[o000004a<C0000000IVIV0000001oOgl0000009VIV@000000
/k>c0_l000020<c<c0Co00000`3<c<`00ol00000/k>c0000000209VIV@030000001oOgl000000080
IVIV00?o000004a<C01<C4`0101<C4`9000000l0C4a<2@00000404a<C00=0000001VIVH0IVIV06IV
IP000000Ogmo0000002IVIT000000;>c/ol00000c<c<o`0000050>KViP03o`00003ooooo000000@0
i^KV00go00000<c<c?l00000/k>c0000002IVIT0000007moO`000000IVIV0000001<C4`000000080
<c<c00<0000001TI6@0I6AT00P0I6ATF000000Cooooo00<00000ooooooooool04oooool00ol0003o
ooooooooo`0`ooooo`?oZKgX00Go01VPocU5/oliAK?o8SffoaQAb`02oa0e]0;oNHSF00GoXXfnolS1
e?o8`MCohoc;onc@^002onBj[0;ogZnV0_oMZj<2omb[Y0;ogZbS00?ohK6TomNYZ?oH[:X00_oH[:X3
ol>N/`;oZXZc0onFNK02ohe_[0;oSFfY0_nBKZH2oiMaY@?oW7>T00CoWgJToj5fXonSN:CoXgRT0onQ
N:D3oiQdZ@06oh9[/?nGN[7oNG:nogUb__l007;o1B>V0_mfK[`3ok^J]@06olVX]ooW^ZKomLVQooG9
XOonf9ConMil7?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0009oooo
o`0400000?oooooooooooooooaT00000100I6AT00`000000<c<c0000000204a<C0070000001VIVH0
000007moO`000000VIVI000000020;>c/`03o`00003<c<`0c<c<00H0c<c<00Ko00000;>c/`2c/k<0
000009VIV@00000207moO`040000001VIVH0IVIV000002T0C4a<00L0000006IVIP1VIVH0IVIV0000
001oOgl000000080VIVI00<000000;>c/ol000000P3<c<`00ol00000i^KV0>KViP030>KViP03o`00
003Vi^H0i^KV0080i^KV00Oo00000<c<c?l00000/k>c0000002IVIT000000080Ogmo0P0000000`1<
C4`0000003<c<`0203<c<`04o`00000I6AT06ATI01TI6AL000001?ooool00`00003oooooooooo`0D
ooooo`;o0000<Oooool3ojVmj005o`0IX?liAK?oIFS1ofEX`OlHDL/00_l@=K@2ogV8eP03olS1e?oS
o<_ohoc;00;ofJf[0_oN[jH3omf[X`06omn/X_oLZjCogZbSomj/XooQ/JCoejVX0ooH[:X3ol>N/`03
ojZ:/onOQkWoRG:c00;oRG:c0_n1J:d2ohe]Z@;oTVjV0_nGLJD2oiacY003oiacXonQMZ?oXGJS00?o
XgRT0_nQN:D2oiQdZ@03ojEnZ_nGN[7oUgZa00;oNG:n00?o<Eo@o`0OYOmfK[`00_mfK[`01?nkV[Go
bJRgolVX]ooW^ZH2ooG9X@03ookHU?oooooooooo01cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolJ000000<06ATI00H0000003<c
<`0c<c<0000004a<C000000206IVIP050000001oOgoo000009VIV@0000000P2c/k<00ol00000c<c<
0<c<c0040<c<c0;o00000P2c/k<00`000000VIVI0000000207moO`040000001VIVH0IVIV06IVIP80
00002`1<C4`00ol0000000000000000@000000H0C4a<0P0000001Ol00000IVIV06IVIP1VIVH00000
0080Ogmo00H0000009VIV@2IVIT000000;>c/ol000020<c<c003o`00003Vi^H0i^KV00L0i^KV00ko
00000<c<c03<c<co00000;>c/`000000VIVIo`00001oOgl0000006IVIP000000C4a<00000080<c<c
00<0000001TI6@0I6AT00P0I6ATG000000Cooooo00<00000ooooooooool05_ooool00ol0003ooooo
ooooo`0_ooooo`;oZKgX00Co00VHocU5/oliAK?oIFS10_n8TMH01?l0A<?oNHSFohoOo_n?goh2omZf
]@;ofJf[0_oN[jH2omf[X`;ogjbR0_oN[:<2on6aY0?of:bZ0_oJ/[02ol>N/`?oWhNi0_n9L[<2oh5X
[@;oQFNY0_nBKZH00onGLJGoUFnToiacX`02oiacX`;oXGJS0onSN:@2oj5hY@?oYGjZ0onGN[42ogUb
_P05o`0OYOmnN<;oOWS2ogih`_nkV[D00_o9Z;L2omjo^@03ookHU?oigWcooooo01kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooooooooooooolJ
000000<06ATI00H0000003<c<`0c<c<0000004a<C000000206IVIP050000001oOgl0000009VIVOl0
00000`2c/k<2o`0000<0c<c<00?o00000;>c/`2c/k<00P2c/k<00`000000VIVI0000000207moO`03
0000001VIVH0IVIV00<0IVIV0`00000204a<C0H000004`1VIVH6000000H0IVIV00@0000007moO`1o
Ogl000000P2IVIT00`000000/k>co`0000020<c<c003o`00003Vi^H0i^KV00D0i^KV0_l000030<c<
c004o`00002c/k<0000000000080Ogmo00D0000006IVIP000000C4a<0000000203<c<`030000000I
6AT06ATI00806ATI5`000004ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool0;ooo
ool01?nY_NSo00VHoe1E^Om@EKT2ofEX`@06ohRAe_nfXL?o]Z73ohoOo_oGal_of[Je0ooI[J/01?oI
ZJKogZnVomf[XooMZj<2omn/XP;ogZbS0_oQ/J@00ooV^JOof:bZomR/ZP02omZb/003ol>N/onoXkco
_j>l00;oWhNi0_n9L[<2oh5X[@;oQFNY0_n=JjH2oiE_Y0?oW7>S0onQMZ<2oj=hY0;oXGRU00CoZGnV
ojEnZ_nUOZ[oYGjZ0_nGN[42ogUb_P04oc5Od?l07jGoOWS2ogih`P?obJRg0_oN_kT00ooeg[?olnfC
ooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool000Wooooo00@0
0000oooooooooooooooo6`00000301TI6@060000000c<c<0<c<c0000001<C4`000000P1VIVH01@00
0000Ogmo0000002IVIT0000000@0/k>c00?o00000<c<c?l000001@2c/k<00`000000VIVI00000003
07moO`030000001VIVH0IVIV00D0IVIV0P00000706IVIPl000003@1VIVH2000000<0Ogmo00H00000
09VIV@2IVIT000000;>c/ol000030<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`0
0P3<c<`02Ol00000/k>c0000002IVIT0000007moO`000000IVIV0000000204a<C0040000000c<c<0
<c<c000000<06ATI60000004ooooo`0300000?oooooooooo01Sooooo00?o0000ooooooooool0;ooo
ool00onY_NSoD5Fioe1E^@02oi20_PCo]Z730_oJ][D2omV]Z`;ofJVV0ooMZj<2omn/XP04on>aX_oN
[:?ohK6Ton6aY0;oi[VW00?of:bZomZb/?oJ/[000onoXk`3oin7^@;oRG:c00?oPFR]ohEWZOn5IjT0
0_n=JjH3oiE_Y0;oW7>S0onQMZ<2oj=hY003oj5hYOnYOjKoZGnV00?oYGjZ0_nGN[43oinDb005o`0J
YOmnN<;oOWS2ogih`_o9Z;L00ooN_kT00ooeg[?oooooooooo`0Oooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo6`00000401TI6@03
0000000c<c<000000080C4a<00D0000006IVIP000000Ogmo0000000209VIV@030000002c/k<0/k>c
0080/k>c00?o00000;>c/`2c/k<00`2c/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00<00000
06IVIP1VIVH02`1VIVH3000000l0Ogmo1`00000506IVIP030000001oOgl0Ogmo00<0Ogmo00@00000
09VIV@2IVIT000000P2c/k<01?l00000c<c<0<c<c03<c<`5o`0000@0c<c<00?o00000;>c/`2c/k<0
0P00000207moO`050000001VIVKo000004a<C00000000P0c<c<00`0000006ATI01TI6@0201TI6AP0
00001?ooool00`00003oooooooooo`0Iooooo`;o0000<?ooool00ol02ISoD5Fioi20_P02oi20_P?o
]Z7300CoaJ:eomZf]OoI[J_ofJf[0_oIZJH2omf[X`;ogjbR0_oS/J82on6aY0?oi[VW0ooJ/[000ooM
`Kco_j>lokF`e003ohV5b005ofiX_?n9L[?oPFR]oh5X[On5IjT00_n=JjH3oiE_Y0?oW7>S0_nQMZ<2
oj=hY0?oZGnV0onUOZX00onGN[7o[Y2gojj@]`02oinDb005o`0?Wol06ZGoOWS2ogih`_o9Z;L00_oN
_kT00ooeg[?oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool000Wooooo00@00000oooooooooooooooo7000000301TI6@04o`00000c<c<0<c<c00000080C4a<
00@0000006IVIP000000Ogmo0P000000102IVIT00000o`00000000070;>c/`050000002IVIT0VIVI
09VIV@0000000`1oOgl2000000L0IVIV0P0000000ol00000000007moO`0607moO`/000001`1oOgl5
000000D0Ogmo00D0000009VIV@2IVIT0VIVI000000020;>c/`03o`00003<c<`0c<c<00P0c<c<0_l0
00002@2c/k<00000o`00002IVIT0000007moOol00000IVIV0000000204a<C0040000000c<c<0<c<c
000000<06ATI6@000004ooooo`0300000?oooooooooo01_ooooo00?o0000ooooooooool0;_ooool2
oe1E^@?oT82n00?o]Z73olFR]Oo5X[D00_oI[J/3omVYYP04om^ZY?oMZj?ogjbRomn/XP;ohk6R0_oQ
/J@3onJiY`04ong8[OoJ/[3ogL6lomg1_0?o]K3D0_n9QLP2ofiX_0;oPFR]0_n5IjT2ohe[YP;oUFnT
0onLLj<2oj5fX`03oj=hY?nYOZGoZGjU00?oZGnV0_nUOZX3ojj@]`04oinDb?o:aMGob/GEo`0?W`;o
S8oA0_oN_kT00ooeg[?olnfCooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool000Wooooo00@00000oooooooooooooooo6`0000001Ol000006ATI01TI6@0I6AT00000
0080<c<c00H0000004a<C01<C4`0000006IVIP00000307moO`050000002IVIT0VIVI09VIV@000000
1@2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo0P00000206IVIP<00000
1`1oOgl4000000/0VIVI0`00000=07moO`030000002IVIT0VIVI0080VIVI00@000000;>c/`2c/k?o
00002@3<c<`01?l00000/k>c0;>c/`00000309VIV@8000000P1VIVH010000000C4a<04a<C0000002
03<c<`040000000I6AT06ATI01TI6AT000001?ooool00`00003oooooooooo`0Looooo`03o`000?oo
oooooooo02gooooo0_mFGKh2oi20_P06ojF<^_o5X[GoaJ:eolFR]Oo;XZkofJf[0ooIZJH01?oKZZCo
gJ^Somn/X_oO[:82on>aXP04onZkY?oQ/JCoi[VWonJiY`;okLR]0ooM`K`01?oNhMOo]K3DokF`e?ne
/=@2ohV5b003ofiX_?mYG[?oJEjc00;oQFNY0_n=JjH2oiE_Y0?oW7>S0_nQMZ<3ojUnY@?oZGnV00?o
YGjZokF?[_neSjh00_n^T;L01Oo=]<7ob/GEonClb_oooooo00nO00;oS8oA00?og[niooGN/oooool0
9Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oo
oooooooooooooa`00000100I6AT010000000<c<c03<c<`00000204a<C0030000001VIVH0000000<0
Ogmo00@0000009VIV@2IVIT0VIVI1@00000509VIV@030000001oOgl0Ogmo00D0Ogmo0P00000707mo
O`<00000102IVIT;000000<0VIVI1`00000507moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<00P2c/k<2o`0000H0c<c<00Co00000;>c/`2c/k<000000`2IVIT01@000000Ogmo0000001V
IVH000000080C4a<00@0000003<c<`0c<c<000000`0I6ATJ000000Cooooo00<00000ooooooooool0
7Oooool00ol0003oooooooooo`0]ooooo`03oeIM__nUS;[oYHbj00;oYHbj00CoaJ:eol^R[_o;XZko
fJf[0_oIZJH2om^ZY0;ogjbR0ooS/J800ooZ^jCoi[VWonJiY`03ong8[@03ooCS^OoM`Kcog^7G00?o
KMg500CoIl7nob]ah?l[LN3oKVRl0_mYG[<01?meHJkoQFNYohe[Y_n=JjH3oiE_Y0;oW7>S00?oXGJS
ojEkYOnYOZD00_nYOZD3ojUoYP?o]Hn^00Go[Y2golfd`Oo=]<7okno5o`000002ooooo`?oYL;^00?o
Z?SPooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo0009
ooooo`0400000?oooooooooooooooad00000100I6AT010000000<c<c03<c<`00000204a<C004o`00
001VIVH00000o`000080Ogmo0P00000;09VIV@030000001oOgl0Ogmo00/0Ogmo0`00000309VIV@04
00000?l0003o0000000000/0/k>c1000000609VIV@D000001@2IVIT00`000000/k>c0;>c/`040;>c
/`03o`00003<c<co000000?o00000P2c/k<02@000000VIVI09VIV@00003o000007moO`000000IVIV
0000000204a<C004o`00000c<c<0<c<c000000@06ATI6P000004ooooo`0300000?oooooooooo01ko
oooo0_l0000]ooooo`;oEUfn0onUS;X00oo5X[Gobj:^ol^R[P03omVYYP;ofjZT00Coh;2Uomn/X_oS
/J;ohk6R0_oZ^j@01?occ:Soi[VWong8[Oo]b:d2ooCS^@OoZKgX00Co:g7Poa16a?m^J;coJEjc0_me
HJh2ohe[YP?oUFnT00CoW7>SoiifY_nUNjGoYG^U1?nYOZD2ojUoYP?o]Hn^0oo=]<400oo_klGooooo
ooooo`02ooooo`03ojG2k_nXn>3ooooo02Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`002Oooool01000003ooooooooooooooolM000000@06ATI00L0000003<c<`0c<c<0
<c<c0000001<C4`0000000<0IVIV00D0000007moO`1oOgl0Ogmo0000000909VIV@030000001oOgl0
Ogmo00/0Ogmo00<0000009VIV@2IVIT00P2IVIT2000000@0/k>c2ol000040;>c/`<000003@2IVIT0
0`000000/k>c0;>c/`050;>c/`03o`00002c/k<0/k>c00<0/k>c00@0000009VIV@2IVIT000000`1o
Ogl00`000000IVIV0000000204a<C0040000000c<c<0<c<c000000@06ATI6P000004ooooo`030000
0?oooooooooo023ooooo00?o0000ooooooooool0:_ooool2od1Ja@?oYHbj0oo;XZh00oo@YJcofJVV
omVYYP02om^ZY004on2`YOoO[:;ohk6Ron>aXP;oj[^T00GollbXoo[XZoojj:_okLR]ooCS^@0:ojVm
j004oa16a?mYG[?oJEjcogEQ[P;oQ6R[0onCL:P2oiifYP?oYG^U0onYOZD00onYOjKo]hf[okN=Z`02
okF?[P03olj]^?o=]<7okno5033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:
ooooo`002Oooool01000003ooooooooooooooolN000000@06ATI00L0000003<c<`0c<c<0<c<c0000
001<C4`0000000<0IVIV00@0000007moO`1oOgl0Ogmo0`00000509VIV@030000001oOgl0Ogmo00/0
Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00T0
c<c<0_l000050;>c/`8000002`2IVIT00`000000/k>c0;>c/`0:0;>c/`040000002IVIT0VIVI0000
00<0Ogmo00<0000006IVIP0000000`1<C4`00`000000<c<c0000000501TI6AX000001?ooool00`00
003oooooooooo`0Qooooo`03o`000?oooooooooo02[ooooo0_m0F/D01?nUS;[o/9Bjok2D^_o;XZh3
om2U[0;ofjZT0_oP/:D3on>aXP03onZkY?occ:SollbX00;on^R[00?o`nV8ojVmj?nY_NP02OnY_NP0
1?l@A/Co7T6kofUN/omeHJh2ohAXZ`?oTg2X0_nNMZH3ojEkY@?oZGjU0ongSJ/01OneSjkocZfholj]
^?objkookno5037ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Ooo
ool01000003ooooooooooooooolO000000@06ATI00@0000003<c<`0c<c<000000P1<C4`01@000000
IVIV06IVIP1VIVH0000000D0Ogmo1@00000=07moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<00P2c/k<2o`0000h0c<c<0_l000050;>c/`8000002P2IVIT00`000000/k>c0;>c/`070;>c
/`8000000P2IVIT01Ol00000Ogmo07moO`1oOgoo00000080IVIV00@0000004a<C01<C4`000000P0c
<c<00`0000006ATI01TI6@0201TI6A/000001?ooool00`00003oooooooooo`0Rooooo`03o`000?oo
oooooooo02[ooooo00Go@5[5ok2D^_n`U;[o/9Bjol^R[P03om2U[0;ofjZT0_oP/:D01OoX_:Oohk6R
on>aX_oZ^jCollbX00?on^R[2OnY_NP4ooooo`04oa16a?lN@K_oMF6^ogEQ[P;oQ6R[0_nCL:P3oiif
YP;oYG^U0_nYOZD01OndRj[o]hf[okN=ZongSJ_o]Hn^00;ocZfh00?ol^^oooooooooool0<?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooo
ooooob000000100I6AT010000000<c<c03<c<`00000204a<C006o`0000000000IVIV06IVI_l00000
00005@1oOgl01Ol00000VIVI09VIV@2IVIT0000000<0/k>c0_l000030<c<c0go00000P3<c<`3o`00
00@0/k>c0`00000709VIV@<000000`2c/k<4000000<0VIVI0P00000207moO`040000001VIVH0IVIV
00000080C4a<00@0000003<c<`0c<c<000001@0I6ATK000000Cooooo00<00000ooooooooool08ooo
ool00ol0003oooooooooo`0Yooooo`04o`0]]_m0F/Go/9Bjok2D^PCod:F/00CoeZb^om^ZY?oP/:Go
h;2U0_oX_:L2onZkY003oo?<Z?ojj:_on^R[00KoZKgX2Oooool00olN@K_oAE:jogEQ[P02ohAXZ`?o
Tg2X0_nNMZH2ojEkY@04ojUnYOndRj[o]8^ZokB;ZP;o]hf[0_o>[KP2oo;[_c?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolP0000
00@06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV06IVIP8000004`1o
Ogl01@000000VIVI09VIV@2IVIWo00000080/k>c00?o00000<c<c03<c<`00P3<c<`00ol00000i^KV
0>KViP0;0>KViP03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<0102c/k<00`000000VIVI
09VIV@0709VIV@<000001P2IVIT01@000000Ogmo07moO`1oOgl0000000<0IVIV00<0000004a<C000
00000`0c<c<00`0000006ATI01TI6@0301TI6A/000001?ooool00`00003oooooooooo`0Tooooo`;o
0000:_ooool00ol0;KKo/9BjokFM`003om2U[0;oeZb^0_oP/:D3onRlY`04ooCB[Oocc:SollbXoo[X
Z`CoZKgX3?ooool00olN@K_oAE:jodEB^P02ohAXZ`?oTg2X0_nNMZH2ojEkY@Co]8^Z0_ngSJ/00oo>
ZkKocZfhoo;[_`0eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wo
oooo00@00000oooooooooooooooo8@00000401TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`0
0`000000IVIV06IVIP0206IVIP800000401oOgl01@000000VIVI09VIV@2IVIT0000000<0/k>c00Go
00000<c<c03<c<`0c<c<o`00000?0>KViP03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<0
102c/k<00`000000VIVI09VIV@0=09VIV@8000000`1oOgl01`000000IVIV06IVIP1VIVH0000004a<
C?l000000`0c<c<00`0000006ATI01TI6@0301TI6A`000001?ooool00`00003oooooooooo`0Voooo
o`03o`000?oooooooooo02Oooooo00Go02ffokFM`?neWL3o]Ig0om2U[003omJ/[P;oh;2U0ooX_:L0
0ooddZgolo>Yoo[XZ`03ojVmj0oooooo00Go7T6kodEB^_m^I[SoKVJhohAXZ`02oi=`Z0;oWWJV00?o
YG^Uojf7[?n]Qj`00ondRjX01?ngSJ_ocZ^folj[]_obkkhfooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo8P00000401TI6@060000
000c<c<0<c<c03<c<ol0000000000P1<C4`00ol00000000006IVIP0306IVIP<00000301oOgl01@00
0000VIVI09VIV@2IVIT0000000<0/k>c00Go00000<c<c03<c<`0c<c<o`0000060>KViPGo00001P3V
i^H00ol00000c<c<0<c<c0020<c<c003o`00002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT02P2I
VIT2000000@0Ogmo00L0000006IVIP1VIVH00000o`00001<C4`0000000<0<c<c00<00000o`00000I
6AT00`0I6ATM000000Cooooo00<00000ooooooooool09oooool00ol0003oooooooooo`0Wooooo`04
o`0]]_neWL3o]Ig0om2U[0?oeZb^00Cog[^don2`YOoX_:Ooj;bW0_oddZd00oocljWoooooooooo`0B
ooooo`;oAE:j0_m^I[P2oi=`Z003oiifY_nQP:oo[HN/00;o[HN/0ondRjX3olj[]P03oo;___oooooo
oooo03Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`002Oooool01000
003ooooooooooooooolR000000@06ATI00<0000003<c<`0c<c<00`0c<c<010000000C4a<04a<C01<
C4`2000000D0IVIV00?o00000000000000002@1oOgl01@000000VIVI09VIV@2IVIT0000000<0/k>c
00Go00000<c<c03<c<`0c<c<o`0000060>KViP05o`00003oool0oooo0?ooool000001P3Vi^H00ol0
0000c<c<0<c<c0020<c<c003o`00002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0202IVIT20000
00D0Ogmo00@0000006IVIP1VIVH000000`1<C4`01@000000<c<c03<c<`0c<c<0000000D06ATI7@00
0004ooooo`0300000?oooooooooo02Sooooo00?o0000ooooooooool09oooool00oneWL3o]:oDomJ/
[P02omJ/[P;og[^d0_oX_:L2ooCB[@03oo?cZOoooooooooo01Cooooo00?oAE:jofiV^?m^I[P00_n=
M[@2oj60[`?o[HN/0ondRjX00oo;Z[WocZ^foo;__P0iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo8`00000401TI6@030000000c
<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<C4`2000000H0IVIV1000000507moO`050000002I
VIT0VIVI09VIV@0000000`2c/k<01Ol00000c<c<0<c<c03<c<co000000D0i^KV00?o00000?ooo`3o
ool00`3oool00ol00000i^KV0>KViP040>KViP05o`00003<c<`0c<c<0<c<c?l000001P2c/k<00`00
0000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00@0Ogmo00@0000006IVIP1VIVH000000`1<C4`0
1@000000<c<c03<c<`0c<c<0000000D06ATI7P000004ooooo`0300000?oooooooooo02Wooooo0_l0
000Wooooo`?o]:oD00KoeZb^omjk]?oN^kCog[^doncNa?oX_:L2ooCB[ASooooo0_m^I[P2ohef]0?o
XH2_0on]Qj`01OndRj[objZiol^Z^Oo>ZkKol^nn03[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`002Oooool01000003ooooooooooooooolS000000D06ATI00<0000003<c
<`0c<c<00P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00L0IVIV00<0000007mo
O`1oOgl00`1oOgl01@000000VIVI09VIV@2IVIT000000080/k>c00Go00000<c<c03<c<`0c<c<o`00
00050>KViP03o`00003oool0oooo00@0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<
c0020<c<c003o`00002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT01@2IVIT2000000D0Ogmo0P00
000206IVIP03o`00001<C4`0C4a<0080C4a<00D0000003<c<`0c<c<0<c<c0000000501TI6Ah00000
1?ooool00`00003oooooooooo`0[ooooo`03o`000?oooooooooo02Gooooo0_nd[m@01_oF[:kog[^d
omjk]?oN^kCok=k4oicWW1_ooooo0_m^I[P2ohef]0;oXH2_0_n]Qj`01Oo1ZL7objZiol^Z^Oo;Z[Wo
j?_303_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool01000
003ooooooooooooooolS00000003o`00000I6AT06ATI00<06ATI0P00000303<c<`8000001@1<C4`0
0ol00000000006IVIP0606IVIP03o`0000000000Ogmo00<0Ogmo00D0000009VIV@2IVIT0VIVI0000
00020;>c/`05o`00003<c<`0c<c<0<c<c?l00000103Vi^H00ol00000oooo0?ooo`060?ooo`03o`00
003Vi^H0i^KV00<0i^KV00Go00000<c<c03<c<`0c<c<o`0000050;>c/`030000002IVIT0VIVI00<0
VIVI0P00000507moO`8000000`1VIVH200000080C4a<0P00000303<c<`03o`00000I6AT06ATI00<0
6ATI7`000004ooooo`0300000?oooooooooo02cooooo00?o0000ooooooooool0:?ooool00ooN^kCo
k=k4oncNa00Mooooo`03o`0n`On=M[CoSGJd00;oXH2_00Co[HN/ol6Y`Oo1ZL7o`JW10_o;Z[Tmoooo
o`05o`000?ooooooooooooooool000002oooool000Wooooo00@00000oooooooooooooooo9@000006
01TI6@030000000c<c<0<c<c0080<c<c0P00000504a<C0<000001P1VIVH01@000000Ogmo07moO`1o
Ogl0000000<0VIVI00@000000;>c/`2c/k?o0000103<c<`00ol00000i^KV0>KViP020>KViP03o`00
003oool0oooo00@0oooo00?o00000>KViP3Vi^H0103Vi^H01Ol00000c<c<0<c<c03<c<co000000@0
/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`800000101VIVH01@000000
C4a<04a<C01<C4`0000000@0<c<c00<0000001TI6@0I6AT0100I6ATO000000Cooooo00<00000oooo
ooooool0;Oooool00ol0003oooooooooo`0Xooooo`03oncNa?oooooooooo01gooooo0_mXSN800onQ
P:ooZJCAol6Y`@03ol6Y`@03ol^Z^Ooooooooooo03gooooo00Co0000oooooooooooo00002oooool0
00Wooooo00@00000oooooooooooooooo9P00000601TI6@030000000c<c<0<c<c00<0<c<c0P000006
04a<C08000001@1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00@000000;>c/`2c/k?o0000
0`3<c<`00ol00000i^KV0>KViP030>KViP?o00000P3oool00ol00000i^KV0>KViP040>KViP05o`00
003<c<`0c<c<0<c<c?l00000102c/k<00ol00000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0
Ogmo00<0000006IVIP1VIVH00`1VIVH01Ol00000C4a<04a<C01<C4`0000000@0<c<c00<0000001TI
6@0I6AT0100I6ATP000000Cooooo00<00000ooooooooool0;_ooool2o`0002Sooooo00?o0000oooo
ooooool07_ooool01?mXSN;oZJCAojVTdOnYY=42ol6Y`@03oj7`]?oooooooooo03oooooo00?o0000
ooooool000002oooool000Wooooo00@00000oooooooooooooooo9`00000601TI6@8000001@0c<c<2
000000H0C4a<00?o000006IVIP1VIVH00`1VIVH01@000000Ogmo07moO`1oOgoo000000<0VIVI00?o
00000;>c/`2c/k<00_l000020<c<c003o`00003Vi^H0i^KV00D0i^KV0_l000060>KViP03o`00003<
c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@03o`00001o
Ogl0Ogmo0080Ogmo0P00000406IVIP8000000`1<C4`00`000000<c<c03<c<`0203<c<`030000000I
6AT06ATI00@06ATI8@000004ooooo`0300000?oooooooooo033ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Pooooo`;oZJCA00?o`JW1ooooooooool0@Oooool00ol0003oooooo`00
000;ooooo`002Oooool01000003ooooooooooooooolX000000L06ATI00<0000003<c<`0c<c<0100c
<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00D0000007moO`1oOgl0Ogmo
0000000209VIV@030000002c/k<0/k>c0080/k>c00Co00000<c<c03<c<co00003@3Vi^H2o`0000@0
c<c<00Go00000;>c/`2c/k<0/k>c0000000409VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c0080<c<c00<0000001TI
6@0I6AT0100I6ATQ000000Cooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooool000002_ooool000Wooooo00@00000oooooooo
oooooooo:@00000701TI6@030000000c<c<0<c<c00@0<c<c0P00000504a<C0800000101VIVH01@00
0000Ogmo07moO`1oOgl000000080VIVI00<000000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c003
o`0000P0i^KV0_l000050<c<c005o`00002c/k<0/k>c0;>c/`000000102IVIT00`000000Ogmo07mo
O`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0203<c<`030000000I6AT06ATI00@06ATI8P000004ooooo`0300000?oooooooooo03;ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`1Xooooo`;o00002_ooool000Wooooo00@00000
oooooooooooooooo:P00000701TI6@030000000c<c<0<c<c00D0<c<c0P00000504a<C0030000001V
IVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000209VIV@8000000`2c/k<00ol00000c<c<
0<c<c0020<c<c0So00001@3<c<`2o`0000<0/k>c00?o000009VIV@2IVIT00P2IVIT00`000000Ogmo
07moO`0207moO`03o`00001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00ol000000000
03<c<`0303<c<`030000000I6AT06ATI00@06ATI8`000004ooooo`0300000?oooooooooo03?ooooo
0_l0000Sooooo`03o`000?oooooooooo06Oooooo0ol0000:ooooo`002Oooool01000003ooooooooo
oooooolY00000003o`00000000006ATI00H06ATI0P00000703<c<`800000101<C4`00`00003o0000
06IVIP0206IVIP06o`0000000000Ogmo07moOol0000000000P2IVIT200000080/k>c1?l000090<c<
c0Co00000`2c/k<200000080VIVI0P0000001?l00000Ogmo07moO`1oOgl2000000D0IVIV00?o0000
04a<C01<C4`00P1<C4`2000000@0<c<c00<0000001TI6@0I6AT0100I6ATT000000Cooooo00<00000
ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06?ooooo1?l0000=
ooooo`002Oooool01000003oooooooooooooool/000000P06ATI0P00000703<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH010000000Ogmo07moO`1oOgl200000080VIVI0`00
00030;>c/`Wo0000102c/k<3000000<0VIVI00<0000007moO`1oOgl00P1oOgl2000000D0IVIV0P00
000304a<C08000001@0c<c<00`0000006ATI01TI6@0501TI6B@000001?ooool00`00003ooooooooo
o`0fooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00017ooooo0009
ooooo`0400000?ooooooooooooooobd000002@0I6AT00`000000<c<c03<c<`0503<c<`800000101<
C4`00`000000IVIV06IVIP0206IVIP8000000`1oOgl2000000<0VIVI0`00000<0;>c/`030000002I
VIT0VIVI0080VIVI0P00000407moO`030000001VIVH0IVIV00<0IVIV0P00000404a<C003o`00000c
<c<0<c<c00@0<c<c00?o000001TI6@0I6AT01@0I6ATU000000Cooooo00<00000ooooooooool0=ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l0000Dooooo`002Oooool0
1000003oooooooooooooool_000000P06ATI00@00000o`000000000000001@0c<c<2000000<0C4a<
00<00000o`00000000000`1VIVH00`000000Ogmo07moO`0207moO`<000000`2IVIT<000000<0VIVI
0P00000307moO`80000000?o000006IVIP1VIVH00P1VIVH2000000D0C4a<00<0000003<c<`0c<c<0
100c<c<00`0000006ATI01TI6@0501TI6BH000001?ooool00`00003oooooooooo`0hooooo`;o0000
7_ooool00ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo00@00000oooooooooooooooo
<000000;01TI6@8000001@0c<c<2000000@0C4a<00D0000006IVIP1VIVH0IVIVo`000002000000@0
Ogmo0`00000=09VIV@800000101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0601TI6BH000001?ooool00`00003o
ooooooooo`0jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0001co
oooo0009ooooo`0400000?oooooooooooooooc400000300I6AT00`000000<c<c03<c<`0403<c<`03
0000001<C4`0C4a<0080C4a<0`00000306IVIP<00000101oOgl3000000<0VIVI1`00000307moO`<0
00001@1VIVH2000000D0C4a<0P00000503<c<`800000200I6ATW000000Cooooo00<00000oooooooo
ool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0000Pooooo`00
2Oooool01000003ooooooooooooooolb000000`06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl3000000P0
Ogmo00?o00000000001VIVH01@1VIVH2000000H0C4a<00<0000003<c<`0c<c<0100c<c<00`000000
6ATI01TI6@0701TI6BP000001?ooool00`00003oooooooooo`0looooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0COooool4o`0002?ooooo0009ooooo`0400000?ooooooooooooooocH0
00002@0I6AT00ol0000000000000000403<c<`03o`0000000000000000<0C4a<00?o000000000000
0000101VIVH6000000H0Ogmo1@00000606IVIP8000001@1<C4`200000003o`00000c<c<0<c<c00<0
<c<c00<00000o`00000I6AT01`0I6ATZ000000Cooooo00<00000ooooooooool0?Oooool2o`0001Wo
oooo00?o0000ooooooooool0BOooool4o`0002Oooooo0009ooooo`0400000?ooooooooooooooocL0
00002`0I6AT2000000D0<c<c0`00000304a<C0@000001P1VIVH6000000L0IVIV1000000404a<C0<0
00001`0c<c<00`0000006ATI01TI6@0701TI6B/000001?ooool00`00003oooooooooo`0oooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0002_ooooo0009ooooo`040000
0?ooooooooooooooocT000002`0I6AT00`000000<c<c03<c<`0503<c<`8000001@1<C4`6000000X0
IVIV0`00000604a<C08000002@0c<c<00`0000006ATI01TI6@0701TI6B`000001?ooool00`00003o
ooooooooo`10ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0002oo
oooo0009ooooo`0400000?oooooooooooooooc/000002P0I6AT01000003o000000000000000503<c
<`D000001P1<C4`:000000L0C4a<0P00000803<c<`80000000?o000001TI6@0I6AT01`0I6AT]0000
00Cooooo00<00000ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03oooooo1?l0000booooo`002Oooool01000003ooooooooooooooolm000000`06ATI0P00000803<c
<`<00000401<C4`4000000L0<c<c0`00000;01TI6Bh000001?ooool00`00003oooooooooo`12oooo
o`;o00004oooool00ol0003oooooooooo`0kooooo`Co0000=_ooool000Wooooo00@00000oooooooo
oooooooo?P00000=01TI6@030000000c<c<0<c<c00P0<c<c4000000:03<c<`030000000I6AT06ATI
00/06ATI;`000004ooooo`0300000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0gooooo`Co0000>_ooool000Wooooo00@00000oooooooooooooooo@000000<01TI
6@<000007`0c<c<2000000`06ATI<@000004ooooo`0300000?oooooooooo04Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool000Wooooo00@00000oooooooo
ooooooooA000000;01TI6@0400000?l000000000000001L0<c<c0P0000000ol00000000001TI6@0;
01TI6C<000001?ooool00`00003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0<?ooool3o`0004;ooooo0009ooooo`0400000?ooooooooooooooodD000003P0I6AT6
000000X0<c<c1`00000>01TI6CD000001?ooool00`00003oooooooooo`17ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0;?ooool4o`0004Gooooo0009ooooo`0400000?oooooooooo
ooooodP000004@0I6AT:000001806ATI>0000004ooooo`0300000?oooooooooo04Sooooo0_l0000=
ooooo`03o`000?oooooooooo02Sooooo1?l00019ooooo`002Oooool01000003ooooooooooooooom<
000002L06ATI>P000004ooooo`0300000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Tooooo`Co0000COooool000Wooooo00@00000ooooooooooooooooC`00000R
01TI6C`000001?ooool00`00003oooooooooo`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool08Oooool3o`00057ooooo0009ooooo`0400000?oooooooooooooooe<000005`0I6AU3
000000Cooooo00<00000ooooooooool0C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01gooooo1?l0001Dooooo`002Oooool01000003ooooooooooooooomH000000l06ATIAP000004
ooooo`0300000?oooooooooo04gooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001H
ooooo`002Oooool01000003ooooooooooooooomU00000003o`0000000000000004D000001?ooool0
0`00003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4
o`0005cooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1@
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Aooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool4o`0006?ooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0003oooooooooo`0:
ooooo`Co0000Ioooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo05Cooooo00Co0000oooooooooooo00002?ooool4o`0006_ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo000000Gooooo0ol0
001_ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0E_oo
ool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo05Oooooo0_l0001fooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo
]P00003Aooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonfo`00017ooooo]_l0000:oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0BooooolC000005Cooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo04Sooooo00<00000o`00000000004oooool300000003o`000?oooooooooo04kooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04Cooooo1000000Jooooo`<00000COooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0@Oooool30000027ooooo10000019ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`10ooooo`03
00000?oooooooooo02Kooooo0`000016ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0nooooo`800000
;?ooool00ol00000000000000013ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`800000<Ooo
ool00`00003oooooooooo`10ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`8000003oooool<
000001Wooooo0`00000oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
04cooooo6@3o]/5=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>?ooool20000
00gooooo100000000oooool0okK10?nf`@090?nf`@L0000000Co000000000000000000000`3o]/4>
ooooo`<00000??ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`19oooo
oal0okK1B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Oooooo00<00000o`00
0?ooool02_ooool200000003o`000?oooooooooo01T0okK10`0000030?nf`@kooooo00<00000oooo
ooooool0>Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`16ooooobD0
okK1Aoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo0P00000:ooooo`<0
00000_oooolO0?nf`@@000000P3o]/4<ooooo`800000>Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`13ooooob/0okK1A?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03Cooooo00<00000ooooooooool01oooool3000000;ooooo9P3o]/4300000080okK1
2oooool00`00003oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo043ooooo<@3o]/51ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<_oo
ool00`00003o0000ooooo`07ooooo`8000000_ooool80?nf`@/000006@3o]/401@00003o00000000
00000000okK100Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0mooooocL0okK1?_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo037ooooo00<00000ooooooooool01_ooool200000003ooooo`3o]/40okK100D0okK11000
000;0?nf`@L000005P3o]/4200000080okK11oooool2000003Gooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0>_oooolk0?nf`Cgooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0_ooooo`8000002?ooool00`000000okK10?nf`@050?nf`@<000005P3o]/4?
000000T0okK10P0000000`3o]/7oooooooooo`06ooooo`0300000?oooooooooo03;ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>Ooooolm0?nf`Ccooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0^ooooo`0300000?oooooooooo00Kooooo00?o00000000
003o]/400`3o]/401000003o0000o`000000000X0?nf`@@000001`3o]/400ol000000000ooooo`07
ooooo`03o`000000003ooooo037ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0=ooooom20?nf`CWooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^oooo
o`0300000?oooooooooo00Gooooo00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@050?nf
`@`000007@3o]/43000000H0okK100<000000?nf`@3o]/401oooool00`00003oooooooooo`0_oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03GoooooAP3o]/4gooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool00`00003oooooooooo`05ooooo`03
0000003o]/40okK10080okK10P0000050?nf`@<00000303o]/43000001d0okK10P0000050?nf`@80
00000P3o]/46ooooo`0300000?oooooooooo02kooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0=?oooom80?nf`CKooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0/ooooo`0300000?oooooooooo00Cooooo0P0000040?nf`@030000003o]/40okK10080okK1
0`00000B0?nf`@0300000?l00000okK101`0okK10P0000050?nf`@80000000<0okK1ooooooooool0
1?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo03?oooooBP3o]/4eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_oo
ool2000000Gooooo0P0000040?nf`@8000000`3o]/42000000H0okK11@00000<0?nf`@8000002P3o
]/4?000000@0okK10P0000050?nf`@030000003o]/7ooooo00Gooooo0P00000]ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo03;oooooC03o]/4dooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0:Oooool00`00003oooooooooo`04ooooo`0300000?ooool0
okK100<0okK100@000000?nf`@3o]/40okK10P0000050?nf`@<000001@3o]/43000000/0okK12P00
000?0?nf`@800000103o]/400`000000okK10?nf`@030?nf`@030000003o]/7ooooo00Kooooo00<0
0000ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0`
oooooe00okK1<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00<00000
ooooooooool01?ooool00`000000okK10?nf`@030?nf`@050000003o]/40okK10?nf`@000000103o
]/43000000/0okK11000000R0?nf`@8000000`3o]/43000000<0okK100<000000?nf`@3o]/401_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo02oooooo>P3o]/45o`00oa<0okK1<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Oooooo00<00000ooooooooool01?ooool00`000000okK10?nf`@020?nf`@06o`0000000000
okK10?nf`Ol0000000000`3o]/4200000180okK100?o00000?nf`@3o]/40503o]/4500000003o`00
003o]/40okK100D0okK100?o00000000003o]/400`3o]/401ol00000okK10?nf`@3o]/7o00000000
003o]/401_ooool00`00003oooooooooo`0Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo02kooooo4@3o]/49o`00oah0okK10ol00?l50?nf`@Co003o403o]/4`ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00`00003oooooooooo`04ooooo`05
0000003o]/40okK10?nf`@0000000`3o]/401P000000okK10?nf`@3o]/400000o`0000D0okK12P00
00050?nf`@030000003o]/40okK10180okK100<00000o`00003o]/401@3o]/45000000@0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@030000003o]/7ooooo00Gooooo00<0
0000ooooooooool09oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0]
oooooa00okK10_l00?l90?nf`@;o003o6`3o]/400ol00?l0okK10?nf`@0:0?nf`@?o003o3P3o]/4_
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool00`00003oooooooooo`04
ooooo`050000003o]/40okK10?nf`@0000000`3o]/401@000000okK10?nf`@3o]/40000000@0okK1
0`00000:0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40403o]/42000000d0okK1
0P0000030?nf`@8000000`3o]/400`000000okK10?nf`@020?nf`@030000003o]/7ooooo00Gooooo
00<00000ooooooooool09_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0/ooooo`l0okK10_l00?l=0?nf`@03o`00o`3o]/40okK101P0okK100?o003o0?nf`@3o]/403@3o
]/400ol00?l0okK10?nf`@0<0?nf`Bkooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Uooooo`0300000?oooooooooo00Cooooo00D000000?nf`@3o]/40okK1000000030?nf`@050000
003o]/40okK10?nf`@0000000`3o]/42000000h0okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@0>0?nf`@030000003o]/40okK100l0okK10P0000030?nf`@050000003o]/40okK10?nf
`@000000103o]/400ol00000okK1ooooo`05ooooo`0300000?oooooooooo02Gooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0:oooool?0?nf`@03o`00o`3o]/40okK100h0
okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK100`0
okK1;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00<00000oooooooo
ool01?ooool01@000000okK10?nf`@3o]/7o000000<0okK100Go00000?nf`@3o]/400000o`000002
0?nf`@;o00000P3o]/400`00003o00000000000500000003o`0000000000000000@0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@0=0?nf`@03o`00003o]/40okK100@0okK11`000006
0?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/42000000<0okK10P000006ooooo`0300000?oo
oooooooo02Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:_ooool?
0?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0A
0?nf`@;o003o303o]/4]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool0
0`00003oooooooooo`04ooooo`030000003o]/40okK10080okK100@000000?nf`@3o]/4000000P3o
]/401@000000okK10?nf`@3o]/4000000080okK10P00000;0?nf`@050000003o]/40okK10?nf`@00
0000103o]/400`000000okK10?nf`@0=0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/40103o]/43000000@0okK10P0000020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o
]/400P3o]/400`00003oooooooooo`04ooooo`0300000?oooooooooo02?ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0:_ooool>0?nf`@03o`00o`3o]/40okK10140okK1
00?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100X0okK1
;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00<00000ooooooooool0
1?ooool00`000000okK10?nf`@020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o
]/40okK1000000020?nf`@030000003o]/40okK100/0okK100D000000?nf`@3o]/40okK100000004
0?nf`@030000003o]/40okK100d0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@08
0?nf`@<000000`3o]/4010000000okK10?nf`@0000040?nf`@030000003o]/40okK10080okK100<0
0000ooooooooool01?ooool00`00003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02Wooooo3@3o]/42o`00oa@0okK100?o003o0?nf`@3o]/40503o]/40
0ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100X0okK1:oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02;ooooo00<00000ooooooooool01?ooool01@000000okK10?nf`@3o
]/4000000080okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1000000@0
okK100?o00000000000000000`0000050?nf`@050000003o]/40okK10?nf`@000000103o]/400`00
0000okK10?nf`@0;0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40303o]/401@00
0000okK10?nf`@3o]/4000000080okK100<000000?nf`@3o]/400P3o]/401Ol00000okK10?nf`@3o
]/40000000Kooooo00<00000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Xooooo`d0okK100?o003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@0C
0?nf`@03o`00o`3o]/40okK101D0okK100?o003o0?nf`@3o]/402P3o]/4Zooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool08Oooool00`00003oooooooooo`04ooooo`050000003o]/40
okK10?nf`Ol000000`3o]/401Ol00000okK1000000000000okK1008000000P3o]/401P000000okK1
0?nf`@3o]/400000o`0000H0okK100?o00000000003o]/400`3o]/4010000000okK10?nf`@000004
0?nf`@030000003o]/40okK100/0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@04
0?nf`@H00000103o]/4200000080okK100<000000?nf`@3o]/400P0000020?nf`@030000003o]/40
okK10080okK100<00000ooooooooool01?ooool00`00003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02Oooooo3@3o]/400ol00?l0okK10?nf`@0F0?nf
`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0:0?nf
`BWooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`0300000?oooooooooo
00?ooooo00<0okK10000003o]/400P3o]/401P000000okK10?nf`@000000okK100000080okK100H0
00000?nf`@3o]/400000o`00003o]/43000000T0okK100<000000?nf`@3o]/400P3o]/4010000000
okK10?nf`@0000040?nf`@030000003o]/40okK100/0okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK100@0okK10`0000030?nf`@040000003o]/40okK1
000000<0okK100@000000?nf`@3o]/400000103o]/400`00003oooooooooo`04ooooo`0300000?oo
oooooooo023ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09_ooool>
0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@0G
0?nf`@03o`00o`3o]/40okK100T0okK1:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo023ooooo00<00000ooooooooool00oooool00`3o]/4000000?nf`@020?nf`@060000003o]/40
okK10000003o]/4000000`3o]/400`000000okK1000000020?nf`@030000003o]/40okK100/0okK1
00D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000003`3o]/401@00
0000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/40203o]/401@000000okK10?nf`@3o
]/4000000080okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK10080okK1
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02Kooooo3@3o]/400ol00?l0okK10?nf`@0G0?nf`@03o`00o`3o
]/40okK101<0okK100?o003o0?nf`@3o]/405`3o]/400ol00?l0okK10?nf`@0:0?nf`BSooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000000003ooooo00Cooooo00Ko
00000000003o]/40okK1o`00000000020?nf`@040000003o]/40okK1o`000080okK100<000000?nf
`@0000000P3o]/400`000000okK10?nf`@020?nf`@0300000?l0003o000000<000001@3o]/401000
0000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000003`3o]/401@000000okK10?nf
`@3o]/40000000<0okK100<000000?nf`@3o]/402P3o]/401Ol00000okK10?nf`@3o]/4000000080
okK100D000000?nf`@3o]/40okK1o`0000020?nf`@03o`0000000000okK10080okK100<00000oooo
ooooool01?ooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo02Gooooo3@3o]/400ol00?l0okK10?nf`@0H0?nf`@03o`00o`3o]/40okK101@0
okK100?o003o0?nf`@3o]/405`3o]/400ol00?l0okK10?nf`@0:0?nf`BOooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Nooooo`0300000?oooooooooo00Cooooo00D000000?nf`@3o
]/40okK1000000030?nf`@060000003o]/40okK10000003o]/4000000P3o]/4010000000okK10?nf
`Ol000020?nf`@8000001@3o]/400`000000okK10?nf`@030?nf`@040000003o]/40okK100000080
okK100D000000?nf`@3o]/40okK1000000040?nf`@H000001@3o]/401@000000okK10?nf`@3o]/40
000000<0okK100<000000?nf`@3o]/402P3o]/401@000000okK10?nf`@3o]/4000000080okK100D0
00000?nf`@3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@0000001_ooool00`00003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Cooooo
3P3o]/400ol00?l0okK10?nf`@0H0?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/40
603o]/400ol00?l0okK10?nf`@090?nf`BOooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Mooooo`0300000?oooooooooo00Cooooo00D000000?nf`@3o]/40okK1000000030?nf`@06
0000003o]/40okK10000003o]/4000000P3o]/401@000000okK10?nf`@3o]/4000000080okK100<0
00000?nf`@3o]/401@3o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK100000080okK1
00@000000?nf`@3o]/400000103o]/400`000000okK10?nf`@040?nf`@8000000`3o]/401@000000
okK10?nf`@3o]/40000000<0okK100<000000?nf`@3o]/402`3o]/401@000000okK10?nf`@3o]/40
00000080okK100@000000?nf`@3o]/400000103o]/401@000000okK10?nf`@3o]/40000000Kooooo
00<00000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Tooooo`d0okK100?o003o0?nf`@3o]/406@3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o
]/40okK100/0okK10ol0000;0?nf`@03o`00o`3o]/40okK100T0okK19_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01cooooo00<00000ooooooooool01Oooool01@000000okK10?nf
`@3o]/40000000<0okK100D000000?nf`@000000okK1000000030?nf`@040000003o]/40okK10000
0080okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@020?nf`@030000003o]/400000
0080okK100D000000?nf`@3o]/40okK1000000030?nf`@030000003o]/40okK100L0okK100Co0000
0?nf`@3o]/400000103o]/401@000000okK10?nf`@3o]/40000000d0okK100D000000?nf`@3o]/40
okK1000000020?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/400P3o]/400`00
003oooooooooo`04ooooo`0300000?oooooooooo01cooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool08oooool>0?nf`@03o`00o`3o]/40okK101T0okK100?o003o0?nf`@3o
]/40503o]/400ol00?l0okK10?nf`@0:0?nf`@Go00002P3o]/400ol00?l0okK10?nf`@090?nf`BKo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`0300000?oooooooooo00Co
oooo00?o00000000003o]/400P3o]/400`000000okK10?nf`@02000000050?nf`@000000okK10?nf
`Ol000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK100P0okK100L00000
0?nf`@3o]/40okK10000003o]/4000000080okK100Co00000?nf`@3o]/4000000`3o]/400`000000
okK10?nf`@080?nf`@050000003o]/40okK10?nf`@0000000`3o]/401@000000okK10?nf`@3o]/40
000000h0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@03o`00003o]/40okK1008000000P3o
]/401_l00000okK10?nf`@3o]/7ooooo000000Kooooo00<00000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Sooooo`d0okK100?o003o0?nf`@3o]/40
2@3o]/43o`0000d0okK100?o003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@0:0?nf`@Go0000
2`3o]/400ol00?l0okK10?nf`@090?nf`BGooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Kooooo`0300000?oooooooooo00Cooooo00<000000?nf`@3o]/400P3o]/400`000000okK1
000000030?nf`@040000003o]/40okK100000080okK100<000000?nf`@0000000`3o]/400`000000
okK10?nf`@080?nf`@070000003o]/40okK10?nf`@000000okK1000000020?nf`@040000003o]/40
okK1000000<0okK100<000000?nf`@3o]/402@3o]/401@000000okK10?nf`@3o]/4000000080okK1
00D000000?nf`@3o]/40okK10000000?0?nf`@040000003o]/40okK1000000<0okK100D000000?nf
`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000001_ooool00`00003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02;ooooo3P3o]/40
0ol00?l0okK10?nf`@080?nf`@Go0000303o]/400ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40
okK100T0okK11Ol0000;0?nf`@03o`00o`3o]/40okK100X0okK19?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01[ooooo00<00000ooooooooool01?ooool00`000000okK10?nf`@02
0?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/400`000000okK1
000000030?nf`@030000003o]/40okK100P0okK100L000000?nf`@3o]/40okK10000003o]/400000
00<0okK100<000000?nf`@0000000`3o]/400`000000okK10?nf`@0;0?nf`@050000003o]/40okK1
0?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40000000l0okK100@000000?nf`@3o]/400000
0`3o]/4010000000okK10?nf`@0000030?nf`@050000003o]/40okK10?nf`@0000001_ooool00`00
003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027o
oooo3`3o]/400ol00?l0okK10?nf`@080?nf`@Go0000303o]/400ol00?l0okK10?nf`@0F0?nf`@03
o`00o`3o]/40okK100X0okK10ol0000<0?nf`@03o`00o`3o]/40okK100X0okK19?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00<00000ooooooooool01?ooool00`000000
okK10?nf`@020?nf`@04o`00003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/40
10000000okK10?nf`Ol000020?nf`@03o`00003o]/40okK100T0okK100Co00000?nf`@3o]/7o0000
0P3o]/401P000000okK10?nf`@000000okK1000000<0okK100<000000?nf`@3o]/400P3o]/400ol0
0000000000000004000000@0okK100D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40
okK10?nf`@0000003`3o]/4010000000okK10?nf`@0000030?nf`@040000003o]/40okK1000000<0
okK100D000000?nf`@3o]/7ooooo00000006ooooo`0300000?oooooooooo01Wooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool08Oooool>0?nf`@03o`00o`3o]/40okK100T0
okK11Ol0000;0?nf`@03o`00o`3o]/40okK101P0okK100?o003o0?nf`@3o]/406@3o]/400ol00?l0
okK10?nf`@0:0?nf`B?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03
00000?oooooooooo00Cooooo00D000000?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK1
00000080okK100<000000?nf`Ol000000`3o]/4010000000okK10?nf`@00000:0?nf`@050000003o
]/40okK10?nf`@0000000P3o]/401P000000okK10?nf`@000000okK100000080okK100<000000?nf
`@3o]/400P3o]/400`000000okK10?nf`@050?nf`@050000003o]/40okK10?nf`@0000000`3o]/40
10000000okK10?nf`@0000030?nf`@030000003o]/40okK100d0okK100@000000?nf`@3o]/400000
0`3o]/4010000000okK10?nf`@0000030?nf`@050000003o]/40okK10?nf`@0000001_ooool00`00
003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo023o
oooo3`3o]/400ol00?l0okK10?nf`@0:0?nf`@?o0000303o]/400ol00?l0okK10?nf`@0I0?nf`@03
o`00o`3o]/40okK101P0okK100?o003o0?nf`@3o]/402P3o]/4Sooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06?ooool00`00003oooooooooo`04ooooo`050000003o]/40okK10?nf
`@0000000`3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK100000080okK100D0
00000?nf`@3o]/40okK10000000:0?nf`@070000003o]/40okK10?nf`@000000okK1000000020?nf
`@030000003o]/4000000080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@070?nf
`@050000003o]/40okK10?nf`@0000000`3o]/4010000000okK10?nf`@0000030?nf`@030000003o
]/40okK100`0okK100D000000?nf`@3o]/40okK1000000030?nf`@040000003o]/40okK1000000<0
okK100D000000?nf`@3o]/7ooooo00000006ooooo`0300000?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool08?ooool?0?nf`@03o`00o`3o]/40okK101P0
okK100?o003o0?nf`@3o]/406`3o]/400ol00?l0okK10?nf`@0G0?nf`@03o`00o`3o]/40okK100/0
okK18_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00<00000oooooooo
ool01?ooool01@00003ooooo0?nf`@3o]/40000000@0okK100<000000?nf`@0000000`3o]/400`00
0000okK1000000030?nf`@040000003o]/40okK1000000X0okK100D000000?nf`@3o]/40okK10000
00020?nf`@060000003o]/40okK10000003o]/7o00000P3o]/401@000000okK10?nf`@3o]/400000
00/0okK100D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000000`3o
]/400`000000okK10?nf`@0<0?nf`@050000003o]/40okK10?nf`Ol000000`3o]/401?l00000okK1
0?nf`Ol000030?nf`@04o`00003o]/40okK1000000Kooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Oooooo`l0okK100?o003o0?nf`@3o
]/40603o]/400ol00?l0okK10?nf`@0M0?nf`@03o`00o`3o]/40okK101L0okK100?o003o0?nf`@3o
]/402`3o]/4Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00`00003o
ooooooooo`04ooooo`0300000?ooool0okK10080okK100Go00000?nf`@3o]/40okK1000000020?nf
`@04o`00003o]/40okK100000080okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf
`@070?nf`@05o`00003o]/40okK10?nf`@0000000P3o]/401_l00000okK100000?l00000okK10000
0080okK100D000000?nf`@3o]/40okK1o`00000=0?nf`@05o`00003o]/40okK10?nf`Ol000000P3o
]/401@000000okK10?nf`@3o]/40000000<0okK10P00000<0?nf`@030000003o]/40okK10080okK1
00@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@0000030?nf`@0300000?oooooooooo
00Cooooo00<00000ooooooooool05oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Noooooa00okK100?o003o0?nf`@3o]/405`3o]/400ol00?l0okK10?nf`@0O0?nf`@03
o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/402`3o]/4Qooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05_ooool00`00003oooooooooo`04ooooo`050000003o]/40okK10?nf
`@0000000`3o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000P3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK10`0000030?nf`@040000003o
]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@00000?0?nf
`@050000003o]/40okK10?nf`@0000000P3o]/401Ol0000000000?nf`@3o]/7o000000@0okK100<0
00000?nf`@3o]/402P3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40
okK1000000020?nf`@050000003o]/40okK10?nf`@0000001_ooool00`00003oooooooooo`0Goooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01kooooo403o]/400ol00?l0
okK10?nf`@0G0?nf`@03o`00o`3o]/40okK101l0okK10_l00?lG0?nf`@03o`00o`3o]/40okK100`0
okK18?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00<00000oooooooo
ool01?ooool01@00003ooooo0?nf`@3o]/40000000<0okK100D000000?nf`@3o]/40okK100000002
0?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/400`3o]/45000000D0okK100Co
00000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK10000
00D0okK100?o0000000000000000100000050?nf`@050000003o]/40okK10?nf`@0000000`3o]/40
10000000okK10?nf`@0000040?nf`@030000003o]/40okK100X0okK100D000000?nf`@3o]/40okK1
000000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/400000
00Kooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Moooooa40okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0R0?nf`@03
o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/403@3o]/4Pooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05Oooool00`00003oooooooooo`03ooooo`0500000?ooool0okK10?nf
`@0000000`3o]/401@000000okK10?nf`@3o]/40000000<0okK100@000000?nf`@3o]/4000000`3o
]/400`000000okK10?nf`@0;0?nf`@8000000P3o]/4010000000okK10?nf`Ol000020?nf`@04o`00
003o]/40okK100000080okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@050?nf`@03
o`0000000000okK100<0okK100D000000?nf`@3o]/40okK1o`0000030?nf`@040000003o]/40okK1
000000@0okK100<000000?nf`@3o]/402P3o]/401@000000okK10?nf`@3o]/7o00000080okK100Go
00000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK1ooooool000001Oooool00`00003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01gooooo
4@3o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK100/0okK11`3ooolB0?nf`@03o`00
o`3o]/40okK10180okK100?o003o0?nf`@3o]/403@3o]/4Pooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05Oooool00`00003oooooooooo`03ooooo`0500000?ooool0okK10?nf`Ol0
00000`3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK100000003
0?nf`@030000003o]/40okK100T0okK10P0000030?nf`@040000003o]/40okK100000080okK100D0
00000?nf`@3o]/40okK1000000020?nf`@060000003o]/40okK10?nf`@3oool000001@3oool50?nf
`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1000000030?nf`@04o`00003o]/40
okK1o`0000@0okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@020?nf`@040000003o
]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/42ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Moooooa40okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@080?nf`@l0oooo
3`3o]/400ol00?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK100h0okK17oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Cooooo00<00000ooooooooool00oooool00`00003ooooo
ooooo`020?nf`@040000003o]/40okK1000000<0okK100@000000?nf`@3o]/400000103o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK100H0okK10P0000040?nf`@040000003o]/40okK1
00000080okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003oool0oooo0080oooo00<0
00000?ooo`3oool0203oool20?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1
000000020?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@090?nf`@05
0000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/4000000080okK100D00000
0?nf`@3o]/7ooooo00000004ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool07?oooolB0?nf`@03o`00o`3o]/40okK10180okK10_l00?l9
0?nf`A<0oooo3P3o]/42o`00o`l0okK10_l00?lA0?nf`Aoooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Dooooo`0300000?oooooooooo00?ooooo00D00000ooooo`3o]/40okK10000
00030?nf`@040000003o]/40okK1000000<0okK100D000000?nf`@3o]/40okK1000000050?nf`@03
0000003o]/40okK100@0okK10P0000050?nf`@040000003o]/40okK100000080okK100D000000?nf
`@3o]/40okK1000000020?nf`@030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`3o]/7o00000?nf`@030?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf
`@3o]/40000000@0okK100<000000?nf`@3o]/40203o]/400ol00000okK10?nf`@020?nf`@040000
003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/42ooooo`0300000?oooooooooo
00;ooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Loooooa80okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@070?nf`AL0
oooo3P3o]/42o`00o``0okK100?o003o0?nf`@3o]/404@3o]/4Oooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04oooool00`00003oooooooooo`03ooooo`0500000?oooooooooo0?nf
`@0000000`3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/40103o]/400`00003o00000000000200000003o`00003o]/40okK10080okK10P000000
1Ol00000okK10?nf`Ol00000okK1008000000P3o]/401Ol0000000000?nf`@3oool0000000<0oooo
0P00000@0?ooo`030000003o]/40okK10080okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@06
0000003o]/40okK10?nf`@00003o00000`3o]/400ol00000okK10?nf`@080?nf`@050000003o]/40
okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`Ooooooo
oooo00000004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool07?oooolC0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/40
1`3o]/4J0?ooo`h0okK11?l00?l70?nf`@03o`00o`3o]/40okK101<0okK17_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01?ooooo00<00000ooooooooool00oooool01@00003ooooo
ooooo`3o]/40000000<0okK100@000000?nf`@3o]/4000000`3o]/401@000000okK10?nf`@3o]/40
000000l0okK10P0000030?nf`@80000000<0okK10000003o]/400P3o]/401@000000okK10?nf`@3o
ool0000000<0oooo00<000000?ooo`3oool04@3oool00`000000okK10?nf`@020?nf`@050000003o
]/40okK10?nf`@0000000P3o]/401Ol0000000000?nf`@3o]/40000000<0okK100<000000?nf`@3o
]/40203o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK100000002
0?nf`@050000003o]/40okK1ooooo`0000001Oooool00`00003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo5@3o]/400ol00?l0okK10?nf`@0<
0?nf`@;o003o2@3o]/4L0?oooa40okK11ol00?lF0?nf`Akooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Cooooo`0300000?oooooooooo00;ooooo00D00000ooooooooool0okK10000
00030?nf`@040000003o]/40okK1000000<0okK100D000000?nf`@3o]/40okK10000000>0?nf`@80
0000103o]/4010000000okK10?nf`@0000030?nf`@050000003o]/40okK10?ooo`0000000`3oool0
0`000000oooo0?ooo`070?ooo`D000001`3oool00`000000okK10?nf`@020?nf`@050000003o]/40
okK10?nf`@0000000`3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK100P0okK1
00D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@00
0000okK1ooooooooool0000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0KoooooaD0okK100?o003o0?nf`@3o]/402`3o]/400ol0
0?l0okK10?nf`@080?nf`Ah0oooo;@3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04oooool00`00003oooooooooo`02ooooo`0500000?oooooooooo0?nf`@0000000P3o]/40
10000000okK10?nf`@0000020?nf`@03o`0000000000okK10080okK100<000000?nf`@3o]/40303o
]/401?l00000okK10?nf`@3o]/4200000004o`00003o]/40okK1000000<0okK100D000000?nf`@3o
]/40oooo000000030?ooo`030000003oool0oooo00D0oooo00<00000o`00000000001@3oool00ol0
0000oooo0?ooo`050?ooo`030000003o]/40okK10080okK100D000000?nf`@3o]/40okK100000003
0?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/40203o]/401Ol00000okK10?nf
`@3o]/4000000080okK100Co00000?nf`@3o]/4000000P3o]/401@000000okK1ooooooooool00000
00Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0KoooooaH0okK11Ol00?l40?nf`@Co003o2P3o]/4P0?ooob`0okK17_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00<00000ooooooooool00_ooool01?l0003o
ooooooooool000030?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK1o`00
000=0?nf`@8000000`3o]/400`000000okK10?nf`@020?nf`@090000003o]/40okK10?nf`@00003o
00000?nf`@3ooooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00D0oooo00<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@000003
0?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/402@3o]/4010000000okK10?nf
`@0000030?nf`@030000003o]/4000000080okK100D000000?nf`Ooooooooooo00000004ooooo`03
00000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6ooooolK0?nf`@Co003o3P3o]/4P0?ooob`0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01?ooooo00<00000ooooooooool00_ooool01000003oooooooooo`0000020?nf`@04
0000003o]/40okK100000080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@090?nf
`@800000103o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK1008000000`3o]/400`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`030000003o]/40okK10080okK100@000000?nf`@3o]/4000000`3o]/40
10000000okK10?nf`@0000030?nf`@030000003o]/40okK100P0okK100D000000?nf`@3o]/40okK1
000000020?nf`@030000003o]/4000000080okK100D000000?nf`Ooooooooooo00000004ooooo`03
00000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6oooool[0?nf`B<0oooo:`3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4_ooool00`00003oooooooooo`02ooooo`0500000?ooooooooooooooo`0000000P3o]/4010000000
okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000002`3o]/400ol00000okK10?nf`@03
0?nf`@040000003o]/40okK10?nf`@8000000P3o]/401P000000okK10?nf`@3o]/40oooo000000@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo00Go00000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/40
1@000000okK10?nf`@3o]/40000000/0okK100@000000?nf`@3o]/4000000`3o]/400`000000okK1
000000020?nf`@0500000?ooooooooooooooo`0000001?ooool00`00003oooooooooo`0Cooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo:P3o]/4U0?ooob/0okK1
7Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00<00000ooooooooool0
0_ooool01`00003oooooooooooooool000000?nf`@0000000P3o]/4010000000okK10?nf`@000003
0?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@02
000000<0okK100@00000o`00003o]/40okK10P0000030?ooo`8000001P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00D0oooo00D000000?nf`@3o]/40okK1000000020?nf`@050000
003o]/40okK10?nf`@0000000P3o]/401?l00000okK10?nf`@00000<0?nf`@040000003o]/40okK1
00000080okK100<000000?nf`@0000000P3o]/401@000000okK1ooooooooool0000000Cooooo00<0
0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0J
ooooob/0okK19@3oool[0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0B
ooooo`0300000?oooooooooo00;ooooo00L00000ooooooooool0okK10000003o]/4000000080okK1
00<000000?nf`Ol000000`3o]/400ol00000okK10?nf`@0:0?nf`@030000003o]/40okK10080okK1
00@000000?nf`@3o]/400000103o]/401@000000okK10?nf`@3o]/40000000@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00D000000?nf
`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf
`@0000050?nf`@<00000103o]/4010000000okK10?nf`@0000020?nf`@030000003o]/4000000080
okK100D000000?nf`Ooooooooooo00000004ooooo`0300000?oooooooooo01?ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool06_oooolZ0?nf`BL0oooo:P3o]/4Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04_ooool00`00003oooooooooo`02ooooo`06
00000?oooooooooo0000003o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o
]/40okK100X0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@0000030?nf`@800000
0`3o]/400`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`040?ooo`050000003o]/40okK10?nf`@0000000P3o]/4010000000
okK10?nf`@0000020?nf`@040000003o]/40okK1000000<0okK10P0000030?nf`@8000000`3o]/40
1P000000okK10?nf`@000000okK100000080okK100@000000?nf`@3o]/4000000_ooool00`00003o
ooooooooo`02ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool06_oooolZ0?nf`BL0oooo:P3o]/4Mooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04_ooool00`00003oooooooooo`02ooooo`0600000?oooooooooo0000003o
]/4000000P3o]/400`000000okK1000000020?nf`@030000003o]/40okK10080okK100Co00000000
0000003o00001@3o]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/40okK1
000000040?nf`@030000003o]/40oooo0080oooo00<000000?ooo`3oool01@3oool00ol00000oooo
0?ooo`0C0?ooo`03o`00003oool0oooo00<0oooo00<0okK10000003o]/400P3o]/401P000000okK1
0?nf`@000000okK100000080okK100@000000?nf`@3o]/7o00000P3o]/400ol00000okK10?nf`@05
0?nf`@040000003o]/40okK100000080okK100<000000?nf`@0000000P3o]/4010000000okK10?nf
`Ol00002ooooo`0300000?oooooooooo00;ooooo00<00000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0JooooobT0okK1:@3ooolY0?nf`Agooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`0300000?oooooooooo00;ooooo00H0
0000ooooooooool000000?nf`@0000020?nf`@03o`00003o]/4000000080okK100D000000?nf`@3o
]/40okK1000000040?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK100000002
0?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`000000okK10?ooo`020?ooo`03o`00003o
ool0oooo00D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`050000003o
]/40okK10?nf`@0000000P3o]/400`000000okK1000000020?nf`@040000003o]/40okK100000080
okK100<000000?nf`@3o]/401@3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/400000
0080okK100@000000?nf`@3o]/4000000_ooool00`00003oooooooooo`02ooooo`0300000?oooooo
oooo01?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool>0?nf
`@;o003o6@3o]/4Y0?oooa@0okK11Ol00?l@0?nf`Agooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Booooo`0300000?oooooooooo00;ooooo00H00000ooooooooool000000?nf`@00
00020?nf`@030000003o]/4000000080okK100@000000?nf`@3o]/4000001@3o]/400`000000okK1
0?nf`@020?nf`@050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000030?nf
`@030000003o]/40okK10080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00<0oooo00D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40
00000080okK100H000000?nf`@3o]/4000000?nf`@0000090?nf`@040000003o]/40okK100000080
okK10P0000020?nf`@040000003o]/40okK1000000;ooooo00<00000ooooooooool00_ooool00`00
003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[o
oooo2`3o]/43o`00o`80okK10ol00?lF0?nf`BT0oooo4P3o]/42o`00o`D0okK10ol00?l=0?nf`Ago
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`0300000?oooooooooo00;o
oooo00X00000ooooooooool000000?nf`@000000okK10000003o]/4000000P3o]/4010000000okK1
0?nf`@0000070?nf`@050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@000002
0?nf`@050000003o]/40okK10?nf`@0000000`3o]/400`3oool000000?ooo`060?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool00P3oool01@000000okK10?nf`@3o]/4000000080okK1
00D000000?nf`@000000okK1000000020?nf`@040000003o]/40okK1000000T0okK100@000000?nf
`@3o]/4000000P3o]/401Ol00000okK10000003o]/4000000080okK100@00000ooooooooool00000
1?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo01[ooooo2P3o]/400ol00?l0okK10?nf`@060?nf`@;o003o503o]/4Y0?oooa40okK100?o
003o0?nf`@3o]/401`3o]/400ol00?l0okK10?nf`@0;0?nf`Agooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Booooo`0300000?oooooooooo00;ooooo00X00000ooooooooool00000
0?nf`@000000okK10000003o]/4000000P3o]/400`000000okK1o`0000090?nf`@040000003o]/40
okK100000080okK100@000000?nf`@3o]/4000000P3o]/401?l00000okK10?nf`Ol000040?nf`@03
0000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`05
0000003o]/40okK10?nf`@0000000P3o]/401@000000okK10000003o]/4000000080okK100<00000
0?nf`@000000103o]/43o`0000@0okK100X000000?nf`@3o]/4000000?nf`@000000okK10000003o
]/4000000P3o]/401000003oooooooooo`000004ooooo`0300000?oooooooooo01?ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool:0?nf`@03o`00o`3o]/40okK1
00L0okK100?o003o0?nf`@3o]/404@3o]/4[0?ooo`l0okK100?o003o0?nf`@3o]/402@3o]/400ol0
0?l0okK10?nf`@0:0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Boooo
o`0300000?oooooooooo00;ooooo00X00000ooooooooool000000?nf`@000000okK10000003o]/40
00000P3o]/400`000000okK1000000090?nf`@040000003o]/40okK100000080okK100@000000?nf
`@3o]/4000000P3o]/4010000000okK10?nf`@0000030?nf`@03o`00003oool0oooo00D0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`020?ooo`050000003o]/40okK10?nf`@000000
0P3o]/401@000000okK10000003o]/4000000080okK100<000000?nf`@0000000`3o]/401Ol00000
okK10?nf`@3o]/7o000000<0okK100X000000?nf`@3o]/4000000?nf`@000000okK10000003o]/40
00000P3o]/401000003oooooooooo`000004ooooo`0300000?oooooooooo01?ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool90?nf`@03o`00o`3o]/40okK100T0
okK100?o003o0?nf`@3o]/40403o]/4[0?ooo`h0okK100?o003o0?nf`@3o]/402`3o]/400ol00?l0
okK10?nf`@090?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03
00000?oooooooooo00;ooooo00`00000ooooooooool000000?nf`@000000okK10000003o]/400000
0?nf`@0000020?nf`@040000003o]/40okK10?nf`@;o0000103o]/4010000000okK10?nf`@000002
0?nf`@040000003o]/40okK100000080okK100@000000?nf`@3o]/4000000`3o]/400`000000oooo
0?ooo`040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool01@000000okK1
0?nf`@3o]/4000000080okK100D000000?nf`@000000okK1000000020?nf`@8000000`3o]/400ol0
0000okK10?nf`@030?nf`@04o`00003o]/40okK100000080okK100L000000?nf`@000000okK10000
003o]/4000000080okK100@00000ooooooooool000001?ooool00`00003oooooooooo`0Cooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo2@3o]/400ol00?l0okK1
0?nf`@0;0?nf`@03o`00o`3o]/40okK100l0okK1:`3oool=0?nf`@03o`00o`3o]/40okK100`0okK1
00?o003o0?nf`@3o]/402@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4_ooool00`00003oooooooooo`02ooooo`0>00000?ooool0okK10000003o]/4000000?nf`@000000
okK10000003o]/4000000?nf`@0000040?nf`@04o`00003o]/7o0000o`0000<0okK100P000000?nf
`@3o]/4000000?nf`@000000okK100000080okK100@000000?nf`@3o]/4000000`3o]/400`000000
oooo0?ooo`050?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool02`000000
okK10?nf`@3o]/4000000?nf`@000000okK10000003o]/4000000080okK100<000000?nf`@000000
0P3o]/400ol00000okK10?nf`@050?nf`@0:o`00003o]/40okK10000003o]/4000000?nf`@000000
okK100000080okK100<000000?nf`@0000000_ooool00`00003oooooooooo`02ooooo`0300000?oo
oooooooo01?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06Oooool8
0?nf`@03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/403P3o]/4[0?ooo``0okK100?o003o
0?nf`@3o]/403P3o]/400ol00?l0okK10?nf`@080?nf`Agooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Booooo`0300000?oooooooooo00;ooooo00h00000ooooo`3o]/4000000?nf
`@000000okK10000003o]/4000000?nf`@000000okK1000000<0okK100?o00000?nf`@3o]/400P3o
]/401?l00000okK10?nf`@0000020?nf`@050000003o]/4000000?nf`@0000000P3o]/4010000000
okK10?nf`@0000030?nf`@030000003oool0oooo00@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`020?ooo`0;0000003o]/40okK10?nf`@000000okK10000003o]/4000000?nf`@00
00000P3o]/401@000000okK1o`00003o]/7o000000P0okK100[o00000?nf`@3o]/4000000?nf`@00
0000okK10000003o]/4000000P3o]/400`000000okK100000002ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Iooooo`P0okK100?o003o0?nf`@3o]/403P3o]/400ol00?l0okK10?nf`@0=0?nf`B/0oooo
303o]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK100L0okK17Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01;ooooo00<00000ooooooooool00_ooool03P00003ooooo
0?nf`@000000okK10000003o]/4000000?nf`@000000okK10000003o]/4000000`3o]/400ol00000
okK10?nf`@020?nf`@04o`00003o]/40okK100000080okK100D000000?nf`@000000okK100000002
0?nf`@040000003o]/40okK1000000<0okK100<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo0080oooo00/000000?nf`@3o]/40okK10000003o]/4000000?nf
`@000000okK1000000020?nf`@050000003o]/4000000?nf`Ol00000203o]/402_l00000okK10?nf
`@000000okK10000003o]/4000000?nf`@0000020?nf`@030000003o]/40000000;ooooo00<00000
ooooooooool00_ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01Wooooo203o]/400ol00?l0okK10?nf`@0>0?nf`@03o`00o`3o]/40okK1
00d0okK1:`3oool;0?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/401`3o]/4Moooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool04P00003oooooooooooooool0
0000ooooo`3o]/4000000?nf`@000000okK10000003o]/4000000?nf`@000000okK100000080okK1
00?o00000?nf`@3o]/40103o]/401?l00000okK10?nf`@0000020?nf`@090000003o]/4000000?nf
`@000000okK10000003o]/40000000<0okK100<000000?nf`@3oool0103oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00<0oooo00H000000?nf`@3o]/4000000?nf`@0000020?nf`@80
00000P3o]/401@000000okK10000003o]/7o000000@0okK10ol000030?nf`@05o`00003o]/40okK1
0000003o]/400P000000103o]/4000000?nf`@0000020?nf`@0400000?oooooooooo000000Cooooo
00<00000ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Jooooo`L0okK100?o003o0?nf`@3o]/403`3o]/400ol00?l0okK10?nf`@0<0?nf`B/0oooo2`3o
]/400ol00?l0okK10?nf`@0@0?nf`@03o`00o`3o]/40okK100L0okK17Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01?ooooo00D00000oooooooooooooooo00000002ooooo`0;0000
003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000000P3o]/400ol00000okK10?nf
`@050?nf`@0>o`00003o]/40okK10000003o]/4000000?nf`@000000okK10000003o]/4000000?nf
`@0000030?nf`@030000003o]/40oooo00@0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`030?ooo`0>0000003o]/40okK10000003o]/4000000?nf`Ol00000okK10000003o]/400000
0?nf`@0000020?nf`@03o`00003o]/40okK100;o00000`3o]/402?l00000okK10?nf`@3o]/7o0000
0?nf`@000000okK10P000000103o]/4000000?nf`@0000020?nf`@0400000?oooooooooo000000Co
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Jooooo`L0okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@0;0?nf`B/0oooo
2P3o]/400ol00?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK100L0okK17Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01?ooooo00D00000oooooooooooooooo00000002ooooo`0;
0000003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@0000000P3o]/400ol00000okK1
0?nf`@050?nf`@0>o`00003o]/40okK10000003o]/4000000?nf`@000000okK10000003o]/400000
0?nf`@0000030?nf`@030000003o]/40oooo00@0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`030?ooo`0>0000003o]/40okK10000003o]/4000000?nf`@000000okK10000003o]/40
00000?nf`@0000020?nf`@03o`00003o]/7o000000D0okK100So00000?nf`@3o]/40okK1o`00003o
]/4000000?nf`@80000000@0okK10000003o]/4000000P3o]/401000003oooooooooo`000004oooo
o`0300000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool06_ooool70?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/40303o]/4Y0?ooo`/0
okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@070?nf`Agooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Cooooo`0300000?oooooooooo00;ooooo00D00000ooooo`00
0000okK1000000020?nf`@80000000@0okK10000003o]/4000000P3o]/400ol00000okK10?nf`@05
0?nf`@0>o`00003o]/40okK10000003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@00
00030?nf`@030000003o]/40okK100@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`030?ooo`0@0000003o]/40okK10000003o]/4000000?nf`@000000okK10000003o]/4000000?nf
`@000000okK1o`000080okK100?o00000?nf`@3o]/400`3o]/402?l00000okK10?nf`@3o]/7o0000
0?nf`@000000okK10P000000103o]/4000000?nf`@0000020?nf`@0400000?oooooooooo000000Co
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Jooooo`L0okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@0;0?nf`BT0oooo
2P3o]/400ol00?l0okK10?nf`@0B0?nf`@03o`00o`3o]/40okK100L0okK17Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Cooooo00d00000oooooooooooooooo00000?ooool0okK1
0000003o]/4000000?nf`@000000okK10080000000D0okK10000003o]/40okK1o`0000080?nf`@03
o`00003o]/40okK10080000000H0okK10000003o]/4000000?nf`@0000020?nf`@040000003o]/40
okK100000080okK11@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00h0
00000?nf`@3o]/4000000?nf`@000000okK10000003o]/4000000?nf`@000000okK100000080okK1
00?o00000?nf`Ol000001`3o]/401Ol00000okK10?nf`Ol00000okK10080000000H0okK10000003o
]/4000000?nf`@0000020?nf`@04o`000?oooooooooo000000?ooooo00<00000ooooooooool05?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`P0okK100?o003o
0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@0;0?nf`BT0oooo2P3o]/400ol00?l0okK10?nf`@0C
0?nf`@03o`00o`3o]/40okK100H0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Cooooo00l00000oooooooooooooooo00000?ooool0okK10000003o]/4000000?nf`Ol00000
okK10000003o]/400P0000020?nf`@03o`00003o]/40okK100H0okK100Go00000?nf`@3o]/400000
0?nf`@02000000040?nf`@000000okK100000080okK100@000000?nf`@3o]/4000000P3o]/450?oo
o`030000003oool0oooo01T0oooo0P0000050?ooo`0@0000003o]/40okK10000003o]/4000000?nf
`@000000okK10000003o]/4000000?nf`@000000okK1o`000080okK100?o00000?nf`@3o]/401@3o
]/401Ol00000okK10?nf`Ol00000okK10080000000H0okK10000003o]/4000000?nf`@0000020?nf
`@0400000?oooooooooo000000?ooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Jooooo`P0okK100?o003o0?nf`@3o]/40403o]/400ol0
0?l0okK10?nf`@0;0?nf`BT0oooo2P3o]/400ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK1
00H0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00l00000oooo
oooooooooooo00000?ooool0okK1o`00003o]/4000000?nf`@000000okK10000003o]/400P000002
0?nf`@03o`00003o]/40okK100<0okK100Co00000?nf`@3o]/7o00000P3o]/4020000000okK10000
00000000okK10000003o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@H0oooo00?o0000
0000000000005@3oool3000000L0oooo010000000?nf`@3o]/4000000?nf`@000000okK10000003o
]/4000000?nf`@000000okK10000003o]/7o00000P3o]/400ol00000okK10?nf`@050?nf`@05o`00
003o]/40okK1o`00003o]/400P0000001P3o]/4000000?nf`@000000okK100000080okK100@00000
ooooooooool000000oooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo01[ooooo203o]/400ol00?l0okK10?nf`@060?nf`@?o0000203o]/40
0ol00?l0okK10?nf`@0;0?nf`BL0oooo2P3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40
okK100H0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00<00000
ooooooooool00_ooool00`000000okK1000000020?nf`@040000003o]/4000000?nf`@80000000@0
okK10000003o]/7o00001@3o]/401Ol00000okK10?nf`@3o]/7o00000080okK10P0000001P3o]/40
00000?nf`@000000okK100000080okK100@000000?nf`@3o]/4000000P3o]/480?oooaD000002@3o
ool01P000000okK10?nf`@000000okK100000080okK100P000000?nf`@00000000000?nf`@000000
okK1o`000080okK100?o00000?nf`@3o]/401P3o]/404_l00000okK1o`00003o]/4000000?nf`@00
0000okK10000003o]/4000000?nf`@000000okK10000003o]/7ooooo000000Cooooo00<00000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Jooooo`P0
okK100?o003o0?nf`@3o]/401@3o]/45o`0000L0okK100?o003o0?nf`@3o]/402`3o]/4W0?ooo`X0
okK100?o003o0?nf`@3o]/401`3o]/43o`0000X0okK100?o003o0?nf`@3o]/401P3o]/4Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool01Ol0003oooooooooooooool00000
0080okK100H000000?nf`@000000okK10000003o]/42000000040?nf`@000000okK1o`0000@0okK1
0_l000040?nf`@0:o`00003o]/4000000000003o]/7o00000?nf`@000000okK100000080okK100H0
00000?nf`@3o]/40okK10000003o]/4U0?ooo`070000003oool0okK10?nf`@000000okK100000002
0?nf`@0800000?l00000okK10000003o]/7o00000?nf`Ol000020?nf`@03o`00003o]/40okK100H0
okK101;o00000?nf`Ol00000okK10000003o]/4000000?nf`@000000okK10000003o]/4000000?nf
`@000000okK1ooooo`000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool06_ooool80?nf`@03o`00o`3o]/40okK100D0okK11Ol00008
0?nf`@03o`00o`3o]/40okK100/0okK19@3oool;0?nf`@03o`00o`3o]/40okK100H0okK11Ol00009
0?nf`@03o`00o`3o]/40okK100H0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Gooooo00D00000oooooooooooooooo000000020?nf`@060000003o]/4000000?nf`@000000
okK10P000000103o]/4000000?nf`Ol000050?nf`@03o`00003o]/40okK10080okK100Co00000?nf
`@00000000000P3o]/42000000050?nf`@000000okK10?nf`@0000000`3o]/400ol00000okK10?nf
`@0T0?ooo`070000003o]/40okK10?nf`@000000okK1000000020?nf`@80000000H0okK10000003o
]/4000000?nf`Ol000020?nf`@03o`00003o]/40okK100H0okK101;o00000?nf`Ol00000okK10000
003o]/4000000?nf`@000000okK10000003o]/4000000?nf`@000000okK1ooooo`000004ooooo`03
00000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6oooool80?nf`@03o`00o`3o]/40okK100@0okK11Ol000080?nf`@03o`00o`3o]/40okK100d0okK1
8`3oool:0?nf`@03o`00o`3o]/40okK100L0okK11Ol000080?nf`@03o`00o`3o]/40okK100L0okK1
7Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00P00000oooooooooooo
oooo00000?ooool0okK100000080okK10P000000203o]/4000000?nf`@000000okK10000003o]/7o
00002@3o]/401?l00000okK10000000000020?nf`@80000000<0okK10000003o]/400P3o]/401@00
0000okK10?nf`@3o]/40000000<0okK18@3oool01@000000oooo0?nf`@3o]/4000000080okK100<0
00000?nf`@3o]/400P0000001P3o]/4000000?nf`@000000okK1o`000080okK100?o00000?nf`@3o
]/401P3o]/402_l00000okK1o`00003o]/4000000?nf`@000000okK10000003o]/4200000080okK1
00@000000?nf`Oooool000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo01_ooooo203o]/400ol00?l0okK10?nf`@050?nf`@?o0000
2@3o]/400ol00?l0okK10?nf`@0=0?nf`B80oooo2`3o]/400ol00?l0okK10?nf`@070?nf`@Go0000
203o]/400ol00?l0okK10?nf`@060?nf`Akooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Fooooo`0500000?ooooooooooooooo`0000000P3o]/4010000000okK10000003o]/420000
00060?nf`@000000okK10000003o]/7o00002P3o]/42o`0000080?nf`@000000okK10000003o]/40
00000?nf`@0000020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40803oool00`00
0000oooo0?nf`@020?nf`@030000003o]/4000000080okK100P000000?nf`@00000000000?nf`@00
0000okK1o`000080okK100?o00000?nf`@3o]/401P3o]/401Ol00000okK10?nf`Ol00000okK10080
00000P3o]/42000000070?nf`Ol00000okK10000003o]/7ooooo00000004ooooo`0300000?oooooo
oooo01Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool80?nf
`@03o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/403P3o]/4P0?ooo``0okK100?o003o0?nf
`@3o]/40203o]/43o`0000T0okK100?o003o0?nf`@3o]/401P3o]/4Nooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05_ooool01@00003oooooooooooooool000000080okK100P00000
0?nf`Ol00000okK10000003o]/4000000?nf`@8000000P3o]/400ol00000okK10?nf`@070?nf`@0:
o`0000000000okK10000003o]/4000000?nf`@000000okK100000080okK100<000000?nf`@3o]/40
0`3o]/401000003o00000000000000020?oooa<000001P3oool200000003o`00003oool0okK10080
okK100@000000?nf`@3o]/4000000P3o]/4020000000okK1000000000000okK10000003o]/7o0000
0P3o]/400ol00000okK10?nf`@060?nf`@05o`00003o]/40okK1o`00003o]/400P0000002`3o]/40
00000?nf`@000000okK10000003o]/4000000?nf`Oooool0000000Cooooo00<00000ooooooooool0
5Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`P0okK100?o
003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@0?0?nf`Ah0oooo3@3o]/400ol00?l0okK10?nf
`@0D0?nf`@03o`00o`3o]/40okK100H0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Kooooo00D00000oooooooooooooooo000000020?nf`@0;0000003o]/4000000?nf`@00
0000okK10000003o]/4000000?nf`@0000000P3o]/400ol00000okK10?nf`@060?nf`@0:o`000000
0000okK10000003o]/4000000?nf`@000000okK1000000<0okK100<000000?nf`@3o]/401P3o]/42
000001<0oooo1P0000030?ooo`<0okK100L000000?nf`@3o]/40okK10000003o]/7o00000080okK1
0P000000103o]/4000000?nf`Ol000020?nf`@03o`00003o]/40okK100H0okK100Go00000?nf`@3o
]/7o00000?nf`@020000000;0?nf`@000000okK10000003o]/4000000?nf`@000000okK1ooooo`00
00001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01_ooooo2@3o]/400ol00?l0okK10?nf`@0@0?nf`@03o`00o`3o]/40okK10100okK1
703oool>0?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/401P3o]/4Nooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05oooool01@00003oooooooooooooool000000080
okK100/000000?nf`@000000okK10000003o]/4000000?nf`@000000okK1000000020?nf`@03o`00
003o]/40okK100@0okK100co00000?nf`@3o]/4000000?nf`@000000okK10000003o]/4000000?nf
`@0000030?nf`@030000003o]/40okK100H0okK1703oool30?nf`@05o`00003o]/40okK10?nf`@00
00000P3o]/402@000000okK10000003o]/4000000?nf`@000000okK1o`0000020?nf`@03o`00003o
]/40okK100D0okK100Go00000?nf`@3o]/7o00000?nf`@02000000080?nf`@000000okK10000003o
]/4000000?nf`@0000020?nf`@0300000?oooooooooo00;ooooo00<00000ooooooooool05_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`P0okK100?o003o0?nf
`@3o]/404@3o]/400ol00?l0okK10?nf`@0@0?nf`AT0oooo403o]/400ol00?l0okK10?nf`@0C0?nf
`@03o`00o`3o]/40okK100L0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Oooooo00<00000ooooooooool00_ooool00ol00000okK1000000020?nf`@80000000Co00000?nf
`@00003o00000P3o]/4010000000okK10?nf`Ol000040?nf`@0;o`00003o]/40okK10?nf`@000000
okK10000003o]/4000000?nf`@0000000P3o]/4010000000okK10?nf`@3o]/42000000L0okK11`3o
ool8000000X0oooo0`3o]/42000000@0okK100<000000?nf`@0000000P3o]/401`000000okK10000
003o]/4000000?nf`Ol000000P3o]/400ol00000okK10?nf`@030?nf`@;o00000P3o]/403Ol00000
okK10000003o]/4000000?nf`@000000okK1o`00003o]/4000000?nf`@0000000P3o]/400`00003o
ooooooooo`02ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool07?ooool90?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/40
4P3o]/4E0?oooa80okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@060?nf`Aoooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`0300000?oooooooooo00;ooooo
00T000000?nf`@3o]/7o00000?nf`@000000okK10000003o]/400P0000020?nf`@04o`00003o]/40
okK10?nf`@?o000000<0okK1o`00003o]/400P3o]/401`000000okK10000003o]/4000000?nf`@00
00000`3o]/400ol00000okK10?nf`@020?nf`@8000001@3o]/47000000P0oooo3@0000050?nf`@04
0000003o]/40okK100000080okK100L000000?nf`Ol00000okK10000003o]/7o000000<0okK100Go
00000?nf`@3o]/40okK1o`0000040?nf`@0@o`00003o]/4000000?nf`@000000okK10000003o]/40
00000?nf`@000000okK10000003o]/7ooooo000000Cooooo00<00000ooooooooool05_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`T0okK100?o003o0?nf`@3o
]/40403o]/400ol00?l0okK10?nf`@0D0?nf`A40oooo503o]/400ol00?l0okK10?nf`@0C0?nf`@03
o`00o`3o]/40okK100H0okK17oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01So
oooo00D00000oooooooooooooooo000000020?nf`@030000003o]/4000000080okK100@000000?nf
`@00000000000P3o]/400`000000okK10?nf`@030?nf`@05o`00003o]/40okK10?nf`@0000000P3o
]/400`000000okK1000000020?nf`@040000003o]/40okK1000000H0okK11@0000040?nf`A40oooo
2`3o]/401@000000okK10?nf`@3o]/4000000080okK100L000000?nf`@000000okK10000003o]/7o
000000@0okK100?o00000?nf`Ol00000103o]/404Ol00000okK10?nf`@000000okK10000003o]/40
00000?nf`@000000okK10000003o]/4000000?nf`Oooool0000000Cooooo00<00000ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`T0okK100?o
003o0?nf`@3o]/403`3o]/400ol00?l0okK10?nf`@0F0?nf`@d0oooo5P3o]/400ol00?l0okK10?nf
`@0B0?nf`@03o`00o`3o]/40okK100L0okK17oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Sooooo00<00000ooooooooool00_ooool030000000okK10?nf`@000000okK10000003o
]/4000000?nf`@000000okK100000080okK100<000000?nf`@3o]/401P3o]/401?l00000okK10?nf
`@0000020?nf`@030000003o]/40000000<0okK100<000000?nf`@3o]/40303o]/4?000000`0okK1
00D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/4000000080okK100@000000?nf`@3o
]/7o0000103o]/400ol00000okK10?nf`@030?nf`@0=o`00003o]/4000000?nf`@000000okK10000
003o]/4000000?nf`@000000okK1000000020?nf`@03ooooo`00003ooooo00;ooooo00<00000oooo
ooooool05oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Mooooo`X0
okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0K0?nf`@D0oooo6`3o]/400ol00?l0
okK10?nf`@0@0?nf`@03o`00o`3o]/40okK100L0okK18?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01Wooooo00D00000oooooooooooooooo000000020?nf`@030000003o]/400000
0080okK100D000000?nf`Ol00000okK1000000020?nf`@030000003o]/40okK100@0okK10P000002
0?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK1000000090?nf`@<00000
00?o00000?nf`@3o]/40103o]/450?ooo`@0okK1300000040?nf`@060000003o]/40okK10000003o
]/4000000P3o]/4010000000okK10?nf`Ol000090?nf`@0Ao`00003o]/400000o`00003o]/400000
0?nf`Ol00000okK10000003o]/4000000?nf`@000000okK1ooooo`0000001?ooool00`00003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01gooooo2P3o
]/400ol00?l0okK10?nf`@0=0?nf`@03o`00o`3o]/40okK103/0okK100?o003o0?nf`@3o]/40403o
]/400ol00?l0okK10?nf`@070?nf`B3ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Iooooo`0500000?ooooooooooooooo`0000000P3o]/4020000000okK10?nf`@000000okK10000
003o]/4000000P3o]/4010000000okK10?nf`Ol00002000000030?nf`@000000000000@0okK100@0
00000?nf`@3o]/4000000P3o]/400`000000okK10?nf`@020?nf`@03o`0000000000000000H00000
1`3o]/4800000180okK100<00000o`00003o]/400P3o]/400`000000okK1000000020?nf`@040000
003o]/40okK1o`0000L0okK10_l000020?nf`@030000003o]/40okK1008000000P3o]/4020000000
okK10000003o]/4000000?nf`Oooool000001?ooool00`00003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo01kooooo2P3o]/43o`00o``0okK100?o003o
0?nf`@3o]/40>`3o]/400ol00?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK100P0okK18?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00D00000oooooooooooooooo0000
00020?nf`@080000003o]/40okK10000003o]/4000000?nf`@0000020?nf`@030000003o]/40okK1
0080okK100<000000?nf`@3o]/400`3o]/401@000000okK10?nf`@3o]/40000000<0okK100<00000
0?nf`@3o]/403P3o]/43000000P0okK1200000080?nf`@800000103o]/4010000000okK10?nf`@00
00030?nf`@040000003o]/40okK1o`0000@0okK10_l000030?nf`@0<0000003o]/40okK10000003o
]/4000000?nf`@000000okK1o`00003o]/4000000P3o]/400`00003oooooooooo`02ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_oo
ool=0?nf`@03o`00o`3o]/40okK100T0okK100?o003o0?nf`@3o]/40>`3o]/400ol00?l0okK10?nf
`@0>0?nf`@03o`00o`3o]/40okK100P0okK18Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01_ooooo00D00000ooooooooool0okK1000000020?nf`@0;0000003o]/40okK10000003o
]/7o00000?nf`@00003o00000?nf`@0000002@3o]/401@000000okK10?nf`@3o]/40000000@0okK1
0P0000090?nf`@D000001`3o]/44000000P0okK1200000060?nf`@04o`00003o]/40okK1000000<0
okK100@000000?nf`@3o]/40okK11?l000040?nf`@0:o`00003o]/400000o`00003o]/4000000?nf
`@000000okK100000080okK100@000000?nf`Oooool000001?ooool00`00003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01oooooo3@3o]/400ol00?l0
okK10?nf`@070?nf`@03o`00o`3o]/40okK101`0okK11_l00?lK0?nf`@03o`00o`3o]/40okK100`0
okK100?o003o0?nf`@3o]/402@3o]/4Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool06oooool01@00003oooooooooooooool000000080okK100Ko00000?nf`@3o]/4000000?nf`@00
00020?nf`@050000003o]/40okK1o`00000000001`3o]/401@000000okK10?nf`@3o]/40000000H0
okK100<000000?nf`@3o]/40103o]/42000000D0okK11`0000040?nf`@P000003@3o]/401@000000
okK10?nf`@3o]/40000000<0okK100<000000?nf`@3o]/401`3o]/4200000080okK100P000000?nf
`@3o]/4000000?nf`@000000okK100000080okK100@000000?nf`Oooool000001?ooool00`00003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo023ooooo
3@3o]/400ol00?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK101T0okK11?l00?l60?nf`@Go003o
5`3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK100T0okK18_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01_ooooo00<00000ooooooooool00_ooool00`000000okK1
000000030?nf`@030000003o]/4000000080okK100D000000?nf`@3o]/40okK1000000050?nf`@03
0000003o]/40okK10080okK100<000000?nf`@3o]/401@3o]/46000000@0okK10`00000C0?nf`@<0
00002@3o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK10?nf`@8000001P3o]/420000
00<0okK100P000000?nf`@3o]/4000000?nf`@000000okK100000080okK100@000000?nf`Oooool0
00001?ooool00`00003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo023ooooo3P3o]/43o`00o`80okK10_l00?lG0?nf`@Go003o3`3o]/43o`00oaD0okK1
00?o003o0?nf`@3o]/401`3o]/42o`00o`/0okK18oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01_ooooo00<00000ooooooooool00_ooool010000000okK10?nf`@0000020?nf`@04
0000003o]/40okK100000080okK100@000000?nf`@3o]/40okK11@0000050?nf`@030000003o]/40
okK100d0okK10P0000060?nf`@`000001`3o]/4400000080okK10`0000050?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@040000003o]/40
okK1o`000080okK100<000000?nf`@0000000P3o]/401000003oooooooooo`000004ooooo`030000
0?oooooooooo01Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08Ooo
ool@0?nf`@;o003o603o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK10180okK10_l0
0?l60?nf`@;o003o3@3o]/4Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?oo
ool00`00003oooooooooo`02ooooo`040000003o]/40okK100000080okK100@000000?nf`@3o]/7o
00000P3o]/42000000/0okK100<000000?nf`@3o]/402`3o]/42000000D0okK100<00000o`000000
0000303o]/401000003o00000000000000070?nf`@800000203o]/400`000000okK10?nf`@040?nf
`@0400000?l000000000000000<0okK10P0000020?nf`@060000003o]/40okK10000003o]/400000
0P3o]/4010000000okK1ooooo`000004ooooo`0300000?oooooooooo01[ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool08OoooolY0?nf`@03o`00o`3o]/40okK101L0okK1
00?o003o0?nf`@3o]/404`3o]/43o`00o`030?nf`Ol00?oo003o00h0okK19?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01cooooo00<00000ooooooooool00_ooool01@000000okK1
0?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@070?nf
`@030000003o]/40okK100/0okK100<000000?nf`@3o]/400P3o]/43000000<0okK1300000040?nf
`@<000003P3o]/400`000000okK10?nf`@0:0?nf`@050000003o]/40okK10?nf`@0000000`3o]/40
0`000000okK1000000020?nf`@0400000?oooooooooo000000Cooooo00<00000ooooooooool06_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0QooooobP0okK100?o003o
0?nf`@3o]/406@3o]/42o`00oaH0okK100?o003o0?nf`@3o]/403P3o]/4Tooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool07Oooool01@00003oooooooooooooool0okK1008000000P3o
]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK10?nf`@<000000`3o]/43000000d0
okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@3o]/43000000`0okK1100000030?nf
`@@000002`3o]/400`000000okK10?nf`@080?nf`@050000003o]/40okK10?nf`@0000000`3o]/40
0`000000okK1o`0000020?nf`@040000003o]/7ooooo000000Cooooo00<00000ooooooooool06ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0RooooobL0okK100?o003o
0?nf`@3o]/406`3o]/400ol00?l0okK10?nf`@0T0?nf`BCooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Nooooo`0400000?ooooooooooooooo`80okK100@000000?nf`@3o]/7o0000
0P3o]/401Ol00000okK10?nf`@00003o000000@0okK10`00000?0?nf`@03o`00003o]/40okK10080
okK100D000000?nf`@3o]/40okK1000000060?nf`@Wo0000103o]/42000000D0okK10P0000090?nf
`@030000003o]/40okK100D0okK10P0000000ol00000okK10?nf`@0200000080okK100@00000o`00
003o]/4000000P3o]/4010000000okK10?nf`@000005ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08ooooolU0?nf`@03o`00o`3o]/40
okK101d0okK100?o003o0?nf`@3o]/408P3o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07oooool01_l0003oooooooooooooool0okK100000080okK100D000000?nf`@3o]/40
okK1000000030?nf`@030000003o]/40okK101<0okK100D000000?nf`@3o]/40okK1o`0000040?nf
`@030000003o]/40okK10080okK10_l000090?nf`@;o0000103o]/42000000D0okK10P0000070?nf
`@03o`000000000000000080okK10`0000040?nf`@050000003o]/40okK10?nf`@0000000`3o]/40
1`000000okK10?nf`@000000okK1ooooo`0000001Oooool00`00003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02?ooooo9@3o]/400ol00?l0okK10?nf
`@0M0?nf`@03o`00o`3o]/40okK10240okK19_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01oooooo00@00000oooooooooooooooo0P3o]/4010000000okK10?nf`@0000030?nf`@04
0000003o]/40okK10?nf`@<000004P3o]/401@000000okK10?nf`@3o]/40000000<0okK100@00000
0?nf`@3o]/40okK10_l0000=0?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@070?nf`@8000001P3o]/401@000000okK10?nf`@3o]/40000000<0okK1
00D000000?nf`@3o]/4000000?nf`@02ooooo`0300000?oooooooooo00?ooooo00<00000oooooooo
ool06oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Tooooob@0okK1
00?o003o0?nf`@3o]/407P3o]/400ol00?l0okK10?nf`@0P0?nf`BKooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Pooooo`0400000?ooooooooooooooo`80okK100@000000?nf`@3o
]/4000000`3o]/42000000@0okK10`00000>0?nf`@050000003o]/40okK10?nf`@000000103o]/40
10000000okK10?nf`Ol0000@0?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@0>0?nf`@05o`00003o]/40okK10?nf`Ol000000`3o]/401?l00000okK1
0?nf`Ol000020?nf`@03ooooo`00003ooooo00Cooooo00<00000ooooooooool07?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Tooooob<0okK100?o003o0?nf`@3o]/40
7`3o]/400ol00?l0okK10?nf`@0O0?nf`BOooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Qooooo`0300000?oooooooooo0080okK100Ko00000?nf`@3o]/40okK1o`00000000030?nf
`@030000003o]/40okK100@0okK11@0000090?nf`@050000003o]/40okK10?nf`@0000000`3o]/40
1@000000okK10?nf`@3o]/7o000000H0okK11Ol000060?nf`@03o`00003o]/40okK10080okK100<0
00000?nf`@3o]/40103o]/400`000000okK10?nf`@0;0?nf`@8000000P3o]/42000000<0okK100@0
00000?nf`@3o]/4000000P3o]/400oooool00000o`000004ooooo`0300000?oooooooooo01gooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09OoooolR0?nf`@03o`00o`3o
]/40okK100h0okK10ol0000?0?nf`@03o`00o`3o]/40okK101h0okK19oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo027ooooo00@00000oooooooooooooooo0P3o]/400`000000okK1
0?nf`@020?nf`@060000003o]/40okK10?nf`Ol0000000002@3o]/42000000L0okK100D000000?nf
`@3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`Ol000001P3o]/400ol00000okK10?nf
`@020?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/400P3o]/400`000000okK10?nf
`@040?nf`@030000003o]/40okK100T0okK10P0000030?nf`@030000003o]/40okK10080okK100D0
00000?nf`@3o]/40okK1000000020?nf`@03ooooo`00003ooooo00Cooooo00<00000ooooooooool0
7Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Vooooob40okK100?o
003o0?nf`@3o]/403@3o]/45o`0000l0okK100?o003o0?nf`@3o]/40703o]/4Xooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool08_ooool01000003oooooooooooooool20?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/42000000T0okK10P0000050?nf`@050000
003o]/40okK10?nf`@0000000`3o]/401@000000okK10?nf`@3o]/7o000000D0okK100?o00000?nf
`@3o]/40103o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK10080okK100<000000?nf
`@3o]/400`3o]/400`000000okK10?nf`@070?nf`@800000103o]/400`000000okK10?nf`@020?nf
`@050000003o]/40okK10?nf`@0000000P3o]/400oooool00000ooooo`04ooooo`0300000?oooooo
oooo01kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09ooooolP0?nf
`@03o`00o`3o]/40okK100d0okK11Ol0000?0?nf`@03o`00o`3o]/40okK101/0okK1:Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00<00000ooooooooool00_ooool20?nf
`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@080?nf
`@030000003o]/40okK100<0okK100@000000?nf`@3o]/4000000`3o]/401@000000okK10?nf`@3o
]/7o000000D0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@020?nf`@03o`00003o
]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@060?nf`@03o`00003o
]/40okK100@0okK100D000000?nf`@3o]/40okK1o`0000040?nf`@050000003o]/7oooooooooo`00
00001?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02Sooooo803o]/400ol00?l0okK10?nf`@0<0?nf`@Go00003`3o]/400ol00?l0okK1
0?nf`@0J0?nf`B[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`030000
0?oooooooooo00;ooooo0P3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40okK100<0okK1
00?o00000000000000001`3o]/400ol00000okK10?nf`@030?nf`@040000003o]/40okK1000000<0
okK100D000000?nf`@3o]/40okK1o`0000040?nf`@03o`00003o]/40okK100H0okK10_l000040?nf
`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf
`@8000001@3o]/42000000<0okK10P0000020?nf`@80000000@0okK1oooooooooooo00001Oooool0
0`00003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
02Sooooo803o]/400ol00?l0okK10?nf`@0=0?nf`@?o0000403o]/400ol00?l0okK10?nf`@0I0?nf
`B_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`0400000?oooooooooo
ooooo`<0okK100<000000?nf`@3o]/400P3o]/400ol0000000000?nf`@050?nf`@<000001@3o]/40
0`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`Ol000000`3o]/401?l00000okK10?nf
`Ol000050?nf`@03o`00003o]/40okK100<0okK10_l000060?nf`@03o`00003o]/40okK10080okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@8000001@3o]/42000000<0okK1
0P0000030?nf`@030000003o]/40okK100;ooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Wooooo803o
]/400ol00?l0okK10?nf`@0O0?nf`@03o`00o`3o]/40okK101T0okK1:oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo02Gooooo00@00000oooooooooooooooo0`3o]/400`000000okK1
0?nf`@030?nf`@8000001`3o]/42000000@0okK100<000000?nf`@3o]/400P3o]/4010000000okK1
0?nf`@0000030?nf`@050000003o]/40okK10?nf`Ol000001@3o]/45o`0000L0okK100?o00000?nf
`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100H000000?nf
`@3o]/40okK1ooooo`000006ooooo`0300000?oooooooooo023ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0:_oooolO0?nf`@03o`00o`3o]/40okK101l0okK100?o003o
0?nf`@3o]/40603o]/4/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool0
1000003oooooooooooooool30?nf`@0300000?l00000okK100@0okK10P0000070?nf`@8000000`3o
]/400`00003o00000?nf`@020?nf`@04o`00003o]/40okK1000000<0okK100@000000?nf`@3o]/40
okK10_l0000?0?nf`@05o`00003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@020?nf
`@03o`00003o]/40okK100<0okK100<00000o`00003o]/400`3o]/400`000000okK10?nf`@020?nf
`@060000003o]/40okK10?nf`Oooool000001_ooool00`00003oooooooooo`0Qooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo02_ooooo7P3o]/42o`00oal0okK100?o003o
0?nf`@3o]/40603o]/4]ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool0
1000003oooooooooooooool40?nf`@030000003o]/40okK100@0okK10P0000070?nf`@030000003o
]/40okK10080okK100@000000?nf`@3o]/4000000`3o]/401@000000okK10?nf`@3o]/40000000@0
okK10_l0000;0?nf`@;o0000103o]/401@000000okK10?nf`@3o]/40000000@0okK100<000000?nf
`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100@000000?nf
`@3o]/40okK10_ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo027ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;?oooolO0?nf`@03o`00o`3o]/40okK1
01`0okK100?o003o0?nf`@3o]/405`3o]/4^ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0:?ooool01000003oooooooooooooool40?nf`@030000003o]/40okK100D0okK10P000006
0?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf
`@3o]/42000000@0okK100?o00000?nf`@3o]/401`3o]/400ol00000okK10?nf`@030?nf`@050000
003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0
okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@3o]/42ooooo`0300000?oooooooooo
00Cooooo00<00000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0]oooooal0okK100?o003o0?nf`@3o]/406P3o]/400ol00?l0okK10?nf`@0F0?nf`C3o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Yooooo`0400000?oooooooooooooo
o`@0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
0080okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK10080okK12Ol000050?nf`@8000000P3o]/400ol00000okK10?nf`@020?nf`@030000003o]/40
okK100<0okK100?o00000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100?ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo02kooooo7`3o]/400ol00?l0okK10?nf`@0H0?nf
`@03o`00o`3o]/40okK101H0okK1<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02[ooooo00Co0000oooooooooooooooo103o]/42000000L0okK10P0000050?nf`@8000000P3o]/40
1Ol0000000000?nf`@3o]/7o00000080000000<0okK1o`00000000000`3o]/401000003o00000000
0000000:0?nf`@80000000Co00000000003o]/40okK10P0000030?nf`@800000103o]/42000000@0
okK10P0000030?nf`@8000000P3o]/43ooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool09?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0`oooooah0okK1
0_l00?lG0?nf`@03o`00o`3o]/40okK101H0okK1<_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02_ooooo00<00000ooooooooool00_ooool40?nf`@8000001`3o]/42000000D0okK1
0P0000020?nf`@030000003o]/40okK10080okK10P000000103o]/4000000000000000040?nf`@X0
0000103o]/42000000<0okK10P0000030?nf`@<00000103o]/42000000@0okK100@000000?nf`@3o
]/40okK10oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo02Cooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0<OoooolO0?nf`@?o003o4`3o]/400ol00?l0
okK10?nf`@0F0?nf`C?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03
00000?oooooooooo00;ooooo1@3o]/42000000L0okK10P0000050?nf`@030000003o]/40okK100<0
00000`3o]/4010000000okK10?nf`@3o]/44000000`0okK10P0000030?nf`@800000103o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100Co00000?nf`@3o]/40okK10oooool0
0ol0003oooooooooo`05ooooo`0300000?oooooooooo02Gooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0<_oooolQ0?nf`@?o003o3@3o]/43o`00oaP0okK1=?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00<00000o`000?ooool00_ooool60?nf
`@0300000?l00000000000H0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf
`@040000003o]/40okK10?nf`@<00000103o]/4900000003o`0000000000000000@0okK100?o0000
0?nf`@3o]/400P3o]/42000000@0okK10P0000000ol00000okK10?nf`@020?nf`@8000000`3o]/42
ooooo`8000001oooool00`00003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo03?ooooo8`3o]/45o`00o`@0okK11?l00?lJ0?nf`CGooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0_ooooo`0400000?ooooooooooooooo`P0okK10P000005
0?nf`@03o`0000000000okK100<0okK100<000000?nf`@3o]/400P3o]/400ol00000000000000003
0?nf`@@000003@3o]/43000000<0okK10P0000050?nf`@030000003o]/40okK100@0okK100<00000
0?nf`@3o]/400P3o]/42ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool09_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0eooooobH0okK11?l00?lL0?nf
`COooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`8000000oooool80?nf
`@8000001@3o]/42000000<0okK10`0000040?nf`@8000001@3o]/43000000<0okK11`0000040?nf
`@8000001@3o]/42000000D0okK10P0000030?nf`@?ooooo00<00000ooooooooool01oooool00`00
003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03Ko
ooooA03o]/4hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool01000003o
ooooooooooooool90?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/420000
00@0okK10P0000060?nf`@<000002@3o]/400ol0000000000?nf`@050?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/400P3o]/43ooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool0:?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0hoooood00
okK1>_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00<00000o`000000
00000_ooool70?nf`@03o`0000000000000000D0okK100?o00000000003o]/400`3o]/400ol00000
0000000000040?nf`@H000001`3o]/45000000D0okK10`0000050?nf`@8000000`3o]/44ooooo`03
o`000?oooooooooo00Kooooo0P00000[ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo03[ooooo?03o]/4looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
=_ooool01000003oooooooooooooool80?nf`@8000001@3o]/43000000@0okK10`0000070?nf`@L0
00001`3o]/43000000H0okK10P0000030?nf`@Cooooo0P000008ooooo`0300000?oooooooooo02_o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>ooooolj0?nf`Cgooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0gooooo`0400000?ooooooooooooooo`T0
okK10P0000060?nf`@<00000103o]/44000000d0okK1100000070?nf`@800000103o]/43ooooo`80
00002Oooool00`00003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo03kooooo=@3o]/4oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
>?ooool00`00003o000000000003ooooo`P0okK10P0000070?nf`@030000003o]/40okK100D0okK1
3@0000070?nf`@80000000?o00000000003o]/400`3o]/42ooooo`80000000?o0000ooooooooool0
1oooool2000002oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0@Ooo
ool_0?nf`D;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0kooooo`8000001?oo
ool70?nf`@030000003o]/40okK100D0okK100?o00000000000000005@3o]/43000000D0okK10ooo
ool2000000_ooooo00<00000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`14ooooobT0okK1AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03gooooo0P000005ooooo`D0okK10`0000070?nf`@L000001`3o]/47000000D0okK11?ooool2
000000cooooo00<00000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`17ooooob<0okK1B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03oooooo00<00000ooooooooool01Oooool50?nf`@<000002`3o]/47000000T0okK11Oooool20000
00gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`1:oooooad0okK1Boooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo043o
oooo00?o000000000?ooool01oooool50?nf`@0400000?l000000000000001@0okK11?ooool40000
00gooooo0P00000dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04go
oooo5`3o]/5>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@_ooool3000000So
oooo1P3o]/47000000X0okK11`00000?ooooo`800000=_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1Fooooo`@0okK1F?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04Gooooo1000000=ooooo`@0okK12P00000Dooooo`800000>?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0BOooool3000002Wooooo0P0000000ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1<ooooo`@000008_ooool3000003gooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
053ooooo0`00000Looooo`<00000@?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Doooool40000017o
oooo1`000013ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Goooooa400000B_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Ooooonfo`00017ooooo]_l0000:ooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.0231258 0.000646446 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15079 -0.0125 -3 -9 ]
[.15079 -0.0125 3 0 ]
[.27778 -0.0125 -3 -9 ]
[.27778 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.53175 -0.0125 -3 -9 ]
[.53175 -0.0125 3 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.78571 -0.0125 -6 -9 ]
[.78571 -0.0125 6 0 ]
[.9127 -0.0125 -6 -9 ]
[.9127 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02313 -6 -4.5 ]
[-0.0125 .02313 0 4.5 ]
[-0.0125 .15241 -18 -4.5 ]
[-0.0125 .15241 0 4.5 ]
[-0.0125 .2817 -18 -4.5 ]
[-0.0125 .2817 0 4.5 ]
[-0.0125 .41099 -18 -4.5 ]
[-0.0125 .41099 0 4.5 ]
[-0.0125 .54028 -18 -4.5 ]
[-0.0125 .54028 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.15079 0 m
.15079 .61803 L
s
.27778 0 m
.27778 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.53175 0 m
.53175 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.78571 0 m
.78571 .61803 L
s
.9127 0 m
.9127 .61803 L
s
0 .15241 m
1 .15241 L
s
0 .2817 m
1 .2817 L
s
0 .41099 m
1 .41099 L
s
0 .54028 m
1 .54028 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15079 0 m
.15079 .00625 L
s
[(2)] .15079 -0.0125 0 1 Mshowa
.27778 0 m
.27778 .00625 L
s
[(4)] .27778 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(6)] .40476 -0.0125 0 1 Mshowa
.53175 0 m
.53175 .00625 L
s
[(8)] .53175 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(10)] .65873 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(12)] .78571 -0.0125 0 1 Mshowa
.9127 0 m
.9127 .00625 L
s
[(14)] .9127 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.5 0 m
.5 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02313 m
.00625 .02313 L
s
[(0)] -0.0125 .02313 1 0 Mshowa
0 .15241 m
.00625 .15241 L
s
[(200)] -0.0125 .15241 1 0 Mshowa
0 .2817 m
.00625 .2817 L
s
[(400)] -0.0125 .2817 1 0 Mshowa
0 .41099 m
.00625 .41099 L
s
[(600)] -0.0125 .41099 1 0 Mshowa
0 .54028 m
.00625 .54028 L
s
[(800)] -0.0125 .54028 1 0 Mshowa
.125 Mabswid
0 .05545 m
.00375 .05545 L
s
0 .08777 m
.00375 .08777 L
s
0 .12009 m
.00375 .12009 L
s
0 .18474 m
.00375 .18474 L
s
0 .21706 m
.00375 .21706 L
s
0 .24938 m
.00375 .24938 L
s
0 .31403 m
.00375 .31403 L
s
0 .34635 m
.00375 .34635 L
s
0 .37867 m
.00375 .37867 L
s
0 .44332 m
.00375 .44332 L
s
0 .47564 m
.00375 .47564 L
s
0 .50796 m
.00375 .50796 L
s
0 .5726 m
.00375 .5726 L
s
0 .60493 m
.00375 .60493 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15079 .61178 m
.15079 .61803 L
s
.27778 .61178 m
.27778 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.53175 .61178 m
.53175 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.9127 .61178 m
.9127 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02313 m
1 .02313 L
s
.99375 .15241 m
1 .15241 L
s
.99375 .2817 m
1 .2817 L
s
.99375 .41099 m
1 .41099 L
s
.99375 .54028 m
1 .54028 L
s
.125 Mabswid
.99625 .05545 m
1 .05545 L
s
.99625 .08777 m
1 .08777 L
s
.99625 .12009 m
1 .12009 L
s
.99625 .18474 m
1 .18474 L
s
.99625 .21706 m
1 .21706 L
s
.99625 .24938 m
1 .24938 L
s
.99625 .31403 m
1 .31403 L
s
.99625 .34635 m
1 .34635 L
s
.99625 .37867 m
1 .37867 L
s
.99625 .44332 m
1 .44332 L
s
.99625 .47564 m
1 .47564 L
s
.99625 .50796 m
1 .50796 L
s
.99625 .5726 m
1 .5726 L
s
.99625 .60493 m
1 .60493 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.0873 .45798 L
.15079 .50227 L
.21429 .52406 L
.27778 .53836 L
.34127 .54861 L
.40476 .55699 L
.46825 .5652 L
.53175 .57416 L
.59524 .58349 L
.65873 .59122 L
.72222 .59618 L
.78571 .59924 L
.84921 .60121 L
.9127 .60249 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.0873 .45798 Mdot
.15079 .50227 Mdot
.21429 .52406 Mdot
.27778 .53836 Mdot
.34127 .54861 Mdot
.40476 .55699 Mdot
.46825 .5652 Mdot
.53175 .57416 Mdot
.59524 .58349 Mdot
.65873 .59122 Mdot
.72222 .59618 Mdot
.78571 .59924 Mdot
.84921 .60121 Mdot
.9127 .60249 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006_ooool2o`0001kooooo1Ol0000Oooooo`?o00007Oooool3o`0001oooooo0ol0000Loooo
o`?o00001?ooool2o`0001Sooooo0ol00002ooooo`Go00006?ooool3o`0000Cooooo0ol0000Doooo
o`006Oooool01?l0003oooooooooool0000Nooooo`04o`000?ooooooooooo`00023ooooo00?o0000
ooooooooool06oooool01Ol0003ooooooooooooooooo000001gooooo00Go0000oooooooooooooooo
o`00000Looooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00006?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Cooooo`006Oooool01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo
01gooooo1Ol0000Looooo`05o`000?ooooooooooooooool000007Oooool01Ol0003ooooooooooooo
oooo000001cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooooooool5o`0001Co
oooo000Iooooo`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool07?ooool01?l0003o
ooooooooool0000Mooooo`Co00007oooool3o`0001gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool04oooool001Wooooo00Co0000
oooooooooooo00007Oooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooool00000
7Oooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool000007?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0001Sooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000E
ooooo`006Oooool01?l0003oooooooooool0000Mooooo`05o`000?ooooooooooooooool000007ooo
ool2o`0001kooooo00?o0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000001_ooooo
0_l00004ooooo`04o`000?ooooooooooo`0001Oooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000006?ooool2o`0000Gooooo0_l0000Eooooo`006_ooool2o`0001oooooo0ol0000Qooooo`03
o`000?oooooooooo01gooooo0_l0000Oooooo`?o00007Oooool00ol0003oooooooooo`03ooooo`;o
00006Oooool00ol0003oooooooooo`02ooooo`?o00006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01?ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo000Eooooo`0300000?l0003o00000?oo00001ol000010000007ooooo000Eooooo`030000
0?oooooooooo00?ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool10000007ooooo000Eooooo`0300000?oo
oooooooo00;ooooo0ooo000Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Cooooo0@000001ooooo`005Oooool0
1000003oooooooooooooool5ool001oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000>
ooooo`;o00001Oooool01000003oooooooooooooool5ool001oooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?oo
ool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00@00000oooooooooooooooo
1Ooo000Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`003Oooool01?l0003ooooooooo
ool00004ooooo`0300000?l0003ooooo00;ooooo0ooo000Pooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01?ooooo
0Ol000010000007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
0oooool00`00003oooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`003Ooo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Dooooo`4000000Oooool000gooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
5?ooool10000007ooooo000>ooooo`;o00001Oooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool0
01Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo00Cooooo
00<00000ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<0
0000o`000?ooool01Oooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01?ooooo0Ol0
00010000007ooooo000Eooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool07Oooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool01Oooool00`00
003oooooooooo`0Mooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`05ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007o
oooo000Eooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool07Oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool01Oooool00`00003ooooooooo
o`0Mooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo01gooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eoooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Doooo
o`4000000Oooool001Gooooo00<00000o`000?ooool01_ooool00`00003oooooooooo`0Looooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01?ooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool07?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`0Looooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo01cooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo00Kooooo00<00000oooo
ooooool07?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000oooooooo
ool01_ooool00`00003oooooooooo`0Looooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
5?ooool10000007ooooo000Eooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool06ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`0Kooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00
003o0000ooooo`07ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool04oooool1o`00
004000000Oooool001Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`0Kooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo01_ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool06oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0Jooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo
01[ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool05?ooool10000007ooooo0005o`0000?ooooo0_l00004ooooo`;o
00001Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01[ooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool05?ooool10000007ooooo00001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool06_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool000;ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`0Jooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@00
0001ooooo`000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o00P0001o00<000000000O`0007l0
nP0007l1o`00004000000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`0Jooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`0000Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo01Wooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?oo
ool10000007ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01Wooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo00Wooooo00<00000oooo
ooooool06Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000oooooooo
ool02Oooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01Wooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
5?ooool10000007ooooo000Eooooo`0300000?l0003ooooo00Wooooo00<00000ooooooooool06Ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Cooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0:
ooooo`0300000?oooooooooo01Sooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eoooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Doooo
o`4000000Oooool001Gooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Hooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0:ooooo`030000
0?oooooooooo01Sooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Hooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo
01Sooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool05oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo
00<00000o`000?ooool02oooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01?ooooo
0Ol000010000007ooooo000Eooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool05ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0Gooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0;ooooo`0300000?oooooooooo01Oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000
007ooooo000Eooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool05oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`0Gooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo01Kooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000E
ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0D
ooooo`4000000Oooool001Gooooo00<00000o`000?ooool03?ooool00`00003oooooooooo`0Foooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01?ooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`0Fooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo01Kooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo00cooooo00<00000
ooooooooool05_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000oooo
ooooool03Oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001oooo
o`000_ooool3o`0000?ooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0=ooooo`03
00000?oooooooooo01Gooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo0003ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01Cooooo0@000001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo01Gooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool05?ooool10000007ooooo00001?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o00000000O`0=0000O`030000
000007l0001o0?D0001o0Ol000010000007ooooo00001?oooooo0000ooooool00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0=oooo
o`0300000?oooooooooo01Gooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo0002ooooo`;o
00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool03Oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001
ooooo`000oooool00ol0003oooooooooo`02ooooo`;o00001?ooool2o`0000Gooooo00<00000oooo
ooooool03_ooool00`00003oooooooooo`0Dooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01Cooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo00kooooo00<00000ooooooooool0
5?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool03_oo
ool00`00003oooooooooo`0Dooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0>ooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool1
0000007ooooo000Eooooo`0300000?oooooooooo00kooooo00<00000ooooooooool05?ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000o`000?ooool03_ooool00`00003o
ooooooooo`0Dooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01?ooooo0Ol000010000007ooooo000Eooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`400000
0Oooool001Gooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Cooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo01?ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo
00oooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Go
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Co
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01?ooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool04oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000
o`000?ooool04?ooool00`00003oooooooooo`0Booooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01?ooooo0Ol00001
0000007ooooo000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool04_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool04?ooool00`00003o
ooooooooo`0Booooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`0@ooooo`0300000?oooooooooo01;ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo
000Eooooo`0300000?oooooooooo013ooooo00<00000ooooooooool04_ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0B
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0@oooo
o`0300000?oooooooooo01;ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eooooo`03
00000?oooooooooo017ooooo00<00000ooooooooool04Oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`40
00000Oooool001Gooooo00<00000ooooooooool04Oooool00`00003oooooooooo`0Aooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0Aooooo`0300000?oo
oooooooo017ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool04oooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool04Oooool00`00003oooooooooo`0Aooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001
ooooo`005Oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo017ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo017ooooo00<00000oooooooo
ool04Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool0
4Oooool00`00003oooooooooo`0Aooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0Booooo`0300000?oooooooooo013ooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?oo
ool10000007ooooo00001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<0
0000ooooooooool04_ooool00`00003oooooooooo`0@ooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@00
0001ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo013o
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool05?ooool10000007ooooo00001Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000
001o0180001o00<000000000O`0007l0l00007l1o`00004000000Oooool000Co00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool04_oo
ool00`00003oooooooooo`0@ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`0000?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool04_ooool00`00003oooooooooo`0@ooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo
0@000001ooooo`0000?oooooo`000?ooool01?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool04_ooool00`00003oooooooooo`0@ooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01Cooooo0@000001ooooo`000_ooool2o`0000Cooooo0_l00004ooooo`;o0000
1Oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
5?ooool10000007ooooo000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool03ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool04oooool0
0`00003oooooooooo`0?ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0Cooooo`0300000?oooooooooo00oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000
007ooooo000Eooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool03oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000o`000?ooool04oooool00`00003ooooo
ooooo`0?ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01?ooooo0Ol000010000007ooooo000Eooooo`0300000?oo
oooooooo01?ooooo00<00000ooooooooool03oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool04oooool3ool000oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool1
0000007ooooo000Eooooo`0300000?oooooooooo01;ooooo1Ooo000>ooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Booooo`Goo`003_ooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool04_ooool5ool000kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo01?ooooo0ooo
00000oooool000000000000<ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Iooooo`0300000?oooooooooo00Wooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool1
0000007ooooo000Eooooo`0300000?l0003ooooo01[ooooo00<00000ooooooooool02?ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Cooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`0Kooooo`80
00002?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool0
7Oooool00`00003oooooooooo`05ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0Nooooo`8000001Oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool08?ooool00`00003oooooooooo`02ooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Qooooo`0500000?oooooooooo
ooooo`0007l08Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo02;ooooo0P000003ool0
023ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Sooooo`Goo`007oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007o
oooo000Eooooo`0300000?oooooooooo02?ooooo1Ooo000Oooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<0
0000o`000?ooool08oooool5ool000<000007?ooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool04oooool1o`00004000000Oooool001Gooooo00<00000
ooooooooool09?ooool3ool000Cooooo1000000Hooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000oooo
ooooool09Oooool00`0007ooooooooooo`07ooooo`<000000oooool3ool000oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo00[ooooo0P000005ool000ko
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Co
oooo0@000001ooooo`005Oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo00cooooo
1Ooo000>ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool09Oooool00`0007oooooooooo
o`0<ooooo`Goo`001000000:ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Dooooo`4000000Oooool00004ooooool0003o0000o`0000Cooooo0_l0
0004ooooo`;o00001Oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo00gooooo0ooo
0005ooooo`D000000oooool3ool0023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Dooooo`4000000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool09Oooool00`0007oo
ooooooooo`0Jooooo`8000001Ooo000Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool05?ooool10000007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo02Gooooo00<0001o
ooooooooool07?ooool5ool0008000007Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01Cooooo0@000001ooooo`0000Coooooo`000?l0003o00000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l0A00007l5ool00080001o
1@0000060000O`?oo`00[00007l1o`00004000000Oooool00005o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooo
ooooool09Oooool00`0007ooooooooooo`0Mooooo`?oo`002?ooool5000000Goo`003_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`0000Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0Uooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02ooo
ool5ool0008000002oooool3ool0023ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007ooooo0000
1?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool09Ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00_ooooo1Ooo0002ooooo`T0000000?o
ooooool00?oo00000ooo000Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`0Uooooo`030000Oooooooooooo01oooooo00<0001oooooooooool03?ooool3
ool000cooooo00<00000ool00?oo00000ooo0002000000_ooooo0ooo000?ooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07?ooool5ool000;ooooo2@0000000oooooooo`00ool00003ool0
00kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo02Go
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Mooooo`?oo`003?ooool00`00003o
o`00ool00003ool0000300000?oooooooooo00_ooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool05?ooool10000007o
oooo000Eooooo`0300000?oooooooooo02Gooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo00cooooo1Ooo00000oooool0000000000004000000Kooooo
0ooo000Pooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Dooooo`4000000Oooool001Gooooo00<00000o`000?ooool09Oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool03Oooool3ool000Sooooo1@00
0005ool001oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01?ooooo0Ol000010000007ooooo000Eooooo`0300000?oooooooooo02Gooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01gooooo1Ooo0002
000000_ooooo0ooo000?ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo00<00000ooooooooool09Oooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07Oooool5ool0
00;ooooo2@0000000oooooooo`00ool00003ool000kooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`0Uooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oo
ooooooooo`0Nooooo`?oo`003?ooool00`00003oo`00ool00003ool0008000002oooool3ool001oo
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Dooooo`4000000Oooool001Gooooo
00<00000ooooooooool09Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0<ooooo`Goo`000_ooool900000003oooo
oooo003oo`0000?oo`007_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Cooooo
0@000001ooooo`005Oooool00`00003oooooooooo`0Uooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00gooooo0ooo
000<ooooo`0300000?oo003oo`0000?oo`001`000005ooooo`?oo`003_ooool3ool0023ooooo00<0
001oooooooooool05?ooool10000007ooooo000Eooooo`0300000?oooooooooo02Gooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07Oooool5ool000Oooooo10000005ool000L000001Oooool5ool000gooooo0ooo000>
ooooo`?oo`003_ooool3ool000Cooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Uoooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo0ooo000<ooooo`Goo`001oooool5000000Goo`001`000005oooo
o`Goo`003?ooool5ool000cooooo1Ooo0003ooooo`4000000Oooool001Gooooo00<00000oooooooo
ool09Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00_ooooo1Ooo000<ooooo`Go
o`001oooool5000000Goo`0030000005ool000`000001Ooo0003ooooo`4000000Oooool001Gooooo
00<00000o`000?ooool09Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00cooooo
0ooo000>ooooo`?oo`003Oooool5ool000cooooo1Ooo000<ooooo`Goo`000_ooool1o`0000400000
0Oooool001Gooooo00<00000ooooooooool09Oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool03Oooool3ool000kooooo0ooo000>ooooo`?oo`001?oo
ool10000007ooooo000Eooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool1
0000007ooooo000Eooooool000002`000001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.63954, -108.99, \
0.0593102, 5.82528}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(goodInitialization = \ em;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation", "Subsection"],

Cell[BoxData[
    \(\(\(AnnularAllPlot[c1, rr1, rr2, #] &\)\  /@ \ 
        goodInitialization;\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
EM experiment #2: slightly bad initialization (full \
covariances)\
\>", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes scalar covariances", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 5;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initBad = 
        ReplacePart[initFull, \ Table[ .1\ IdentityMatrix[2], {k}], 
          2];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data1, initBad, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.5199999999999996`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.3 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.2 g
.01923 .65292 m
.01952 .65385 L
.02605 .67308 L
.03355 .69231 L
.03846 .70368 L
.04208 .71154 L
.0517 .73077 L
.05769 .7417 L
.06252 .75 L
.07463 .76923 L
.07692 .77265 L
.08817 .78846 L
.09615 .79886 L
.10333 .80769 L
.11538 .82155 L
.12034 .82692 L
.13462 .84146 L
.13952 .84615 L
.15385 .85908 L
.16132 .86538 L
.17308 .87475 L
.18642 .88462 L
.19231 .88873 L
.21154 .9012 L
.21591 .90385 L
.23077 .91232 L
.25 .92221 L
.25181 .92308 L
.26923 .93095 L
.28846 .93863 L
.29867 .94231 L
.30769 .94532 L
.32692 .95106 L
.34615 .95591 L
.36538 .95991 L
.37458 .96154 L
.38462 .96308 L
.40385 .96545 L
.42308 .96705 L
.44231 .96791 L
.46154 .96803 L
.48077 .96743 L
.5 .96612 L
.51923 .96413 L
.53783 .96154 L
.53846 .96144 L
.55769 .95807 L
.57692 .95402 L
.59615 .94929 L
.61538 .94389 L
.62059 .94231 L
.63462 .9378 L
.65385 .93103 L
.67308 .92356 L
.67427 .92308 L
.69231 .91539 L
.71154 .9065 L
.71698 .90385 L
.73077 .89686 L
.75 .88646 L
.75326 .88462 L
.76923 .87525 L
.78509 .86538 L
.78846 .86321 L
.80769 .85027 L
.81354 .84615 L
.82692 .83638 L
.83926 .82692 L
.84615 .82144 L
.86269 .80769 L
.86538 .80537 L
.88413 .78846 L
.88462 .78801 L
.90381 .76923 L
.90385 .76919 L
.92189 .75 L
.92308 .74868 L
.93851 .73077 L
.94231 .72613 L
.95376 .71154 L
.96154 .70106 L
.96775 .69231 L
.98053 .67308 L
.98077 .6727 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .65292 m
.01952 .65385 L
.02605 .67308 L
.03355 .69231 L
.03846 .70368 L
.04208 .71154 L
.0517 .73077 L
.05769 .7417 L
.06252 .75 L
.07463 .76923 L
.07692 .77265 L
.08817 .78846 L
.09615 .79886 L
.10333 .80769 L
.11538 .82155 L
.12034 .82692 L
.13462 .84146 L
.13952 .84615 L
.15385 .85908 L
.16132 .86538 L
.17308 .87475 L
.18642 .88462 L
.19231 .88873 L
.21154 .9012 L
.21591 .90385 L
.23077 .91232 L
.25 .92221 L
.25181 .92308 L
.26923 .93095 L
.28846 .93863 L
.29867 .94231 L
.30769 .94532 L
.32692 .95106 L
.34615 .95591 L
.36538 .95991 L
.37458 .96154 L
.38462 .96308 L
.40385 .96545 L
.42308 .96705 L
.44231 .96791 L
.46154 .96803 L
.48077 .96743 L
.5 .96612 L
.51923 .96413 L
.53783 .96154 L
.53846 .96144 L
.55769 .95807 L
.57692 .95402 L
.59615 .94929 L
.61538 .94389 L
Mistroke
.62059 .94231 L
.63462 .9378 L
.65385 .93103 L
.67308 .92356 L
.67427 .92308 L
.69231 .91539 L
.71154 .9065 L
.71698 .90385 L
.73077 .89686 L
.75 .88646 L
.75326 .88462 L
.76923 .87525 L
.78509 .86538 L
.78846 .86321 L
.80769 .85027 L
.81354 .84615 L
.82692 .83638 L
.83926 .82692 L
.84615 .82144 L
.86269 .80769 L
.86538 .80537 L
.88413 .78846 L
.88462 .78801 L
.90381 .76923 L
.90385 .76919 L
.92189 .75 L
.92308 .74868 L
.93851 .73077 L
.94231 .72613 L
.95376 .71154 L
.96154 .70106 L
.96775 .69231 L
.98053 .67308 L
.98077 .6727 L
Mfstroke
.2 g
.01923 .37221 m
.0214 .36538 L
.02811 .34615 L
.03577 .32692 L
.03846 .32068 L
.04441 .30769 L
.05409 .28846 L
.05769 .28182 L
.06489 .26923 L
.07689 .25 L
.07692 .24995 L
.09019 .23077 L
.09615 .22274 L
.10491 .21154 L
.11538 .19897 L
.12122 .19231 L
.13462 .17788 L
.13932 .17308 L
.15385 .159 L
.15946 .15385 L
.17308 .14196 L
.18199 .13462 L
.19231 .12651 L
.20738 .11538 L
.21154 .11246 L
.23077 .09965 L
.23634 .09615 L
.25 .08796 L
.26923 .0773 L
.26994 .07692 L
.28846 .06757 L
.30769 .05871 L
.31002 .05769 L
.32692 .05066 L
.34615 .04338 L
.36038 .03846 L
.36538 .03682 L
.38462 .03096 L
.40385 .02575 L
.42308 .02118 L
.43215 .01923 L
.01923 .01923 L
F
0 g
.01923 .37221 m
.0214 .36538 L
.02811 .34615 L
.03577 .32692 L
.03846 .32068 L
.04441 .30769 L
.05409 .28846 L
.05769 .28182 L
.06489 .26923 L
.07689 .25 L
.07692 .24995 L
.09019 .23077 L
.09615 .22274 L
.10491 .21154 L
.11538 .19897 L
.12122 .19231 L
.13462 .17788 L
.13932 .17308 L
.15385 .159 L
.15946 .15385 L
.17308 .14196 L
.18199 .13462 L
.19231 .12651 L
.20738 .11538 L
.21154 .11246 L
.23077 .09965 L
.23634 .09615 L
.25 .08796 L
.26923 .0773 L
.26994 .07692 L
.28846 .06757 L
.30769 .05871 L
.31002 .05769 L
.32692 .05066 L
.34615 .04338 L
.36038 .03846 L
.36538 .03682 L
.38462 .03096 L
.40385 .02575 L
.42308 .02118 L
.43215 .01923 L
s
.1 g
.01923 .22532 m
.02821 .21154 L
.03846 .19684 L
.04178 .19231 L
.05664 .17308 L
.05769 .17178 L
.07295 .15385 L
.07692 .14941 L
.09085 .13462 L
.09615 .12925 L
.11056 .11538 L
.11538 .11095 L
.13234 .09615 L
.13462 .09426 L
.15385 .07897 L
.15655 .07692 L
.17308 .06494 L
.18368 .05769 L
.19231 .05204 L
.21154 .04017 L
.21444 .03846 L
.23077 .02923 L
.24989 .01923 L
.01923 .01923 L
F
0 g
.01923 .22532 m
.02821 .21154 L
.03846 .19684 L
.04178 .19231 L
.05664 .17308 L
.05769 .17178 L
.07295 .15385 L
.07692 .14941 L
.09085 .13462 L
.09615 .12925 L
.11056 .11538 L
.11538 .11095 L
.13234 .09615 L
.13462 .09426 L
.15385 .07897 L
.15655 .07692 L
.17308 .06494 L
.18368 .05769 L
.19231 .05204 L
.21154 .04017 L
.21444 .03846 L
.23077 .02923 L
.24989 .01923 L
s
.1 g
.01923 .79868 m
.02518 .80769 L
.03846 .82642 L
.03884 .82692 L
.05392 .84615 L
.05769 .85068 L
.0706 .86538 L
.07692 .87218 L
.08913 .88462 L
.09615 .89139 L
.10982 .90385 L
.11538 .90866 L
.13312 .92308 L
.13462 .92423 L
.15385 .93831 L
.15969 .94231 L
.17308 .95103 L
.19059 .96154 L
.19231 .96252 L
.21154 .97288 L
.22771 .98077 L
.01923 .98077 L
F
0 g
.01923 .79868 m
.02518 .80769 L
.03846 .82642 L
.03884 .82692 L
.05392 .84615 L
.05769 .85068 L
.0706 .86538 L
.07692 .87218 L
.08913 .88462 L
.09615 .89139 L
.10982 .90385 L
.11538 .90866 L
.13312 .92308 L
.13462 .92423 L
.15385 .93831 L
.15969 .94231 L
.17308 .95103 L
.19059 .96154 L
.19231 .96252 L
.21154 .97288 L
.22771 .98077 L
s
.01923 .0982 m
.0211 .09615 L
.03846 .07799 L
.03952 .07692 L
.05769 .05946 L
.05962 .05769 L
.07692 .04241 L
.08161 .03846 L
.09615 .02667 L
.1058 .01923 L
.01923 .01923 L
F
.01923 .0982 m
.0211 .09615 L
.03846 .07799 L
.03952 .07692 L
.05769 .05946 L
.05962 .05769 L
.07692 .04241 L
.08161 .03846 L
.09615 .02667 L
.1058 .01923 L
s
.01923 .92431 m
.03687 .94231 L
.03846 .94385 L
.05758 .96154 L
.05769 .96164 L
.07692 .97788 L
.08053 .98077 L
.01923 .98077 L
F
.01923 .92431 m
.03687 .94231 L
.03846 .94385 L
.05758 .96154 L
.05769 .96164 L
.07692 .97788 L
.08053 .98077 L
s
.4 g
.98077 .54075 m
.97536 .55769 L
.96824 .57692 L
.96154 .5928 L
.96002 .59615 L
.95069 .61538 L
.94231 .63092 L
.9402 .63462 L
.92849 .65385 L
.92308 .66211 L
.91551 .67308 L
.90385 .68886 L
.90118 .69231 L
.8854 .71154 L
.88462 .71244 L
.86805 .73077 L
.86538 .73357 L
.84899 .75 L
.84615 .75271 L
.82801 .76923 L
.82692 .77017 L
.80769 .7862 L
.80484 .78846 L
.78846 .80094 L
.77911 .80769 L
.76923 .81454 L
.75024 .82692 L
.75 .82708 L
.73077 .83864 L
.71735 .84615 L
.71154 .84928 L
.69231 .85904 L
.67883 .86538 L
.67308 .86797 L
.65385 .87608 L
.63462 .88341 L
.63125 .88462 L
.61538 .88996 L
.59615 .89575 L
.57692 .90078 L
.56355 .90385 L
.55769 .90506 L
.53846 .90859 L
.51923 .91136 L
.5 .91337 L
.48077 .91461 L
.46154 .91507 L
.44231 .91472 L
.42308 .91356 L
.40385 .91156 L
.38462 .90869 L
.36538 .90491 L
.36064 .90385 L
.34615 .9002 L
.32692 .89448 L
.30769 .88772 L
.29976 .88462 L
.28846 .87984 L
.26923 .87075 L
.25899 .86538 L
.25 .86035 L
.23077 .84849 L
.22725 .84615 L
.21154 .83502 L
.20106 .82692 L
.19231 .81971 L
.17881 .80769 L
.17308 .80224 L
.15957 .78846 L
.15385 .7822 L
.14276 .76923 L
.13462 .75892 L
.128 .75 L
.11538 .73138 L
.115 .73077 L
.10355 .71154 L
.09615 .69764 L
.0935 .69231 L
.08472 .67308 L
.07713 .65385 L
.07692 .65329 L
.07064 .63462 L
.06519 .61538 L
.06074 .59615 L
.05769 .57977 L
.05724 .57692 L
.05468 .55769 L
.05302 .53846 L
.05226 .51923 L
.05239 .5 L
.05339 .48077 L
.05529 .46154 L
.05769 .44457 L
.05808 .44231 L
.06179 .42308 L
.06644 .40385 L
.07204 .38462 L
.07692 .37013 L
.07866 .36538 L
.08632 .34615 L
.09509 .32692 L
.09615 .32474 L
.10504 .30769 L
.11538 .28988 L
.11626 .28846 L
.12886 .26923 L
.13462 .26112 L
.14297 .25 L
.15385 .23653 L
.15877 .23077 L
.17308 .21508 L
.17649 .21154 L
.19231 .19609 L
.19642 .19231 L
.21154 .17915 L
.21898 .17308 L
.23077 .16394 L
.24473 .15385 L
.25 .15023 L
.26923 .13785 L
.27458 .13462 L
.28846 .12665 L
.30769 .11654 L
.31001 .11538 L
.32692 .10741 L
.34615 .0992 L
.35386 .09615 L
.36538 .09185 L
.38462 .0853 L
.40385 .07953 L
.41341 .07692 L
.42308 .07448 L
.44231 .07014 L
.46154 .06649 L
.48077 .0635 L
.5 .06117 L
.51923 .05948 L
.53846 .05844 L
.55769 .05804 L
.57692 .05829 L
.59615 .0592 L
.61538 .06077 L
.63462 .06303 L
.65385 .066 L
.67308 .0697 L
.69231 .07418 L
.7027 .07692 L
.71154 .07946 L
.73077 .0856 L
.75 .09266 L
.75867 .09615 L
.76923 .1007 L
.78846 .10983 L
.7991 .11538 L
.80769 .12015 L
.82692 .1318 L
.83125 .13462 L
.84615 .14495 L
.85792 .15385 L
.86538 .15986 L
.88057 .17308 L
.88462 .17684 L
.90007 .19231 L
.90385 .19638 L
.91697 .21154 L
.92308 .21921 L
.93167 .23077 L
.94231 .24658 L
.94445 .25 L
.95552 .26923 L
.96154 .28102 L
.96505 .28846 L
.97316 .30769 L
.97995 .32692 L
.98077 .32951 L
F
0 g
.98077 .54075 m
.97536 .55769 L
.96824 .57692 L
.96154 .5928 L
.96002 .59615 L
.95069 .61538 L
.94231 .63092 L
.9402 .63462 L
.92849 .65385 L
.92308 .66211 L
.91551 .67308 L
.90385 .68886 L
.90118 .69231 L
.8854 .71154 L
.88462 .71244 L
.86805 .73077 L
.86538 .73357 L
.84899 .75 L
.84615 .75271 L
.82801 .76923 L
.82692 .77017 L
.80769 .7862 L
.80484 .78846 L
.78846 .80094 L
.77911 .80769 L
.76923 .81454 L
.75024 .82692 L
.75 .82708 L
.73077 .83864 L
.71735 .84615 L
.71154 .84928 L
.69231 .85904 L
.67883 .86538 L
.67308 .86797 L
.65385 .87608 L
.63462 .88341 L
.63125 .88462 L
.61538 .88996 L
.59615 .89575 L
.57692 .90078 L
.56355 .90385 L
.55769 .90506 L
.53846 .90859 L
.51923 .91136 L
.5 .91337 L
.48077 .91461 L
.46154 .91507 L
.44231 .91472 L
.42308 .91356 L
.40385 .91156 L
Mistroke
.38462 .90869 L
.36538 .90491 L
.36064 .90385 L
.34615 .9002 L
.32692 .89448 L
.30769 .88772 L
.29976 .88462 L
.28846 .87984 L
.26923 .87075 L
.25899 .86538 L
.25 .86035 L
.23077 .84849 L
.22725 .84615 L
.21154 .83502 L
.20106 .82692 L
.19231 .81971 L
.17881 .80769 L
.17308 .80224 L
.15957 .78846 L
.15385 .7822 L
.14276 .76923 L
.13462 .75892 L
.128 .75 L
.11538 .73138 L
.115 .73077 L
.10355 .71154 L
.09615 .69764 L
.0935 .69231 L
.08472 .67308 L
.07713 .65385 L
.07692 .65329 L
.07064 .63462 L
.06519 .61538 L
.06074 .59615 L
.05769 .57977 L
.05724 .57692 L
.05468 .55769 L
.05302 .53846 L
.05226 .51923 L
.05239 .5 L
.05339 .48077 L
.05529 .46154 L
.05769 .44457 L
.05808 .44231 L
.06179 .42308 L
.06644 .40385 L
.07204 .38462 L
.07692 .37013 L
.07866 .36538 L
.08632 .34615 L
Mistroke
.09509 .32692 L
.09615 .32474 L
.10504 .30769 L
.11538 .28988 L
.11626 .28846 L
.12886 .26923 L
.13462 .26112 L
.14297 .25 L
.15385 .23653 L
.15877 .23077 L
.17308 .21508 L
.17649 .21154 L
.19231 .19609 L
.19642 .19231 L
.21154 .17915 L
.21898 .17308 L
.23077 .16394 L
.24473 .15385 L
.25 .15023 L
.26923 .13785 L
.27458 .13462 L
.28846 .12665 L
.30769 .11654 L
.31001 .11538 L
.32692 .10741 L
.34615 .0992 L
.35386 .09615 L
.36538 .09185 L
.38462 .0853 L
.40385 .07953 L
.41341 .07692 L
.42308 .07448 L
.44231 .07014 L
.46154 .06649 L
.48077 .0635 L
.5 .06117 L
.51923 .05948 L
.53846 .05844 L
.55769 .05804 L
.57692 .05829 L
.59615 .0592 L
.61538 .06077 L
.63462 .06303 L
.65385 .066 L
.67308 .0697 L
.69231 .07418 L
.7027 .07692 L
.71154 .07946 L
.73077 .0856 L
.75 .09266 L
Mistroke
.75867 .09615 L
.76923 .1007 L
.78846 .10983 L
.7991 .11538 L
.80769 .12015 L
.82692 .1318 L
.83125 .13462 L
.84615 .14495 L
.85792 .15385 L
.86538 .15986 L
.88057 .17308 L
.88462 .17684 L
.90007 .19231 L
.90385 .19638 L
.91697 .21154 L
.92308 .21921 L
.93167 .23077 L
.94231 .24658 L
.94445 .25 L
.95552 .26923 L
.96154 .28102 L
.96505 .28846 L
.97316 .30769 L
.97995 .32692 L
.98077 .32951 L
Mfstroke
.5 g
.46154 .11491 m
.48077 .11168 L
.5 .10919 L
.51923 .10744 L
.53846 .10642 L
.55769 .10612 L
.57692 .10657 L
.59615 .10776 L
.61538 .10971 L
.63462 .11245 L
.65076 .11538 L
.65385 .11602 L
.67308 .12045 L
.69231 .12579 L
.71154 .1321 L
.71844 .13462 L
.73077 .13947 L
.75 .14798 L
.76184 .15385 L
.76923 .15777 L
.78846 .16899 L
.79486 .17308 L
.80769 .18186 L
.82155 .19231 L
.82692 .19666 L
.84376 .21154 L
.84615 .21382 L
.86254 .23077 L
.86538 .23397 L
.87855 .25 L
.88462 .25816 L
.89221 .26923 L
.90385 .28846 L
.90385 .28846 L
.91368 .30769 L
.92188 .32692 L
.92308 .33004 L
.92858 .34615 L
.93389 .36538 L
.93787 .38462 L
.9406 .40385 L
.94211 .42308 L
.94231 .42822 L
.94243 .44231 L
.94231 .44802 L
.94161 .46154 L
.93963 .48077 L
.93652 .5 L
.93227 .51923 L
.92687 .53846 L
.92308 .55001 L
.9203 .55769 L
.91252 .57692 L
.90385 .5955 L
.90352 .59615 L
.89322 .61538 L
.88462 .62982 L
.88158 .63462 L
.86852 .65385 L
.86538 .65816 L
.85393 .67308 L
.84615 .68254 L
.83769 .69231 L
.82692 .70402 L
.81963 .71154 L
.80769 .72321 L
.79954 .73077 L
.78846 .74053 L
.77709 .75 L
.76923 .75625 L
.75186 .76923 L
.75 .77056 L
.73077 .78362 L
.72316 .78846 L
.71154 .79552 L
.69231 .80637 L
.68983 .80769 L
.67308 .81622 L
.65385 .82511 L
.64967 .82692 L
.63462 .83309 L
.61538 .84019 L
.59705 .84615 L
.59615 .84643 L
.57692 .85181 L
.55769 .85635 L
.53846 .86005 L
.51923 .86291 L
.5 .86492 L
.49381 .86538 L
.48077 .86607 L
.46154 .86635 L
.44231 .86574 L
.43486 .86538 L
.42308 .86421 L
.40385 .86173 L
.38462 .85826 L
.36538 .85374 L
.34615 .84813 L
.34017 .84615 L
.32692 .84135 L
.30769 .8333 L
.29435 .82692 L
.28846 .82388 L
.26923 .81294 L
.26092 .80769 L
.25 .80028 L
.23424 .78846 L
.23077 .78567 L
.21207 .76923 L
.21154 .76873 L
.19324 .75 L
.19231 .74897 L
.17706 .73077 L
.17308 .72557 L
.16308 .71154 L
.15385 .69713 L
.15098 .69231 L
.14052 .67308 L
.13462 .66077 L
.13155 .65385 L
.12393 .63462 L
.11757 .61538 L
.11538 .60782 L
.11239 .59615 L
.10833 .57692 L
.10534 .55769 L
.1034 .53846 L
.10248 .51923 L
.10257 .5 L
.10367 .48077 L
.10578 .46154 L
.10891 .44231 L
.11308 .42308 L
.11538 .41408 L
.11833 .40385 L
.1247 .38462 L
.13224 .36538 L
.13462 .35988 L
.14102 .34615 L
.15113 .32692 L
.15385 .32217 L
.16268 .30769 L
.17308 .29228 L
.17582 .28846 L
.19072 .26923 L
.19231 .26732 L
.20763 .25 L
.21154 .24588 L
.22687 .23077 L
.23077 .22716 L
.24889 .21154 L
.25 .21064 L
.26923 .19596 L
.27438 .19231 L
.28846 .18286 L
.30438 .17308 L
.30769 .17115 L
.32692 .16069 L
.34079 .15385 L
.34615 .15135 L
.36538 .14305 L
.38462 .13571 L
.38769 .13462 L
.40385 .12926 L
.42308 .12368 L
.44231 .1189 L
.45902 .11538 L
F
0 g
.46154 .11491 m
.48077 .11168 L
.5 .10919 L
.51923 .10744 L
.53846 .10642 L
.55769 .10612 L
.57692 .10657 L
.59615 .10776 L
.61538 .10971 L
.63462 .11245 L
.65076 .11538 L
.65385 .11602 L
.67308 .12045 L
.69231 .12579 L
.71154 .1321 L
.71844 .13462 L
.73077 .13947 L
.75 .14798 L
.76184 .15385 L
.76923 .15777 L
.78846 .16899 L
.79486 .17308 L
.80769 .18186 L
.82155 .19231 L
.82692 .19666 L
.84376 .21154 L
.84615 .21382 L
.86254 .23077 L
.86538 .23397 L
.87855 .25 L
.88462 .25816 L
.89221 .26923 L
.90385 .28846 L
.90385 .28846 L
.91368 .30769 L
.92188 .32692 L
.92308 .33004 L
.92858 .34615 L
.93389 .36538 L
.93787 .38462 L
.9406 .40385 L
.94211 .42308 L
.94231 .42822 L
.94243 .44231 L
.94231 .44802 L
.94161 .46154 L
.93963 .48077 L
.93652 .5 L
.93227 .51923 L
.92687 .53846 L
Mistroke
.92308 .55001 L
.9203 .55769 L
.91252 .57692 L
.90385 .5955 L
.90352 .59615 L
.89322 .61538 L
.88462 .62982 L
.88158 .63462 L
.86852 .65385 L
.86538 .65816 L
.85393 .67308 L
.84615 .68254 L
.83769 .69231 L
.82692 .70402 L
.81963 .71154 L
.80769 .72321 L
.79954 .73077 L
.78846 .74053 L
.77709 .75 L
.76923 .75625 L
.75186 .76923 L
.75 .77056 L
.73077 .78362 L
.72316 .78846 L
.71154 .79552 L
.69231 .80637 L
.68983 .80769 L
.67308 .81622 L
.65385 .82511 L
.64967 .82692 L
.63462 .83309 L
.61538 .84019 L
.59705 .84615 L
.59615 .84643 L
.57692 .85181 L
.55769 .85635 L
.53846 .86005 L
.51923 .86291 L
.5 .86492 L
.49381 .86538 L
.48077 .86607 L
.46154 .86635 L
.44231 .86574 L
.43486 .86538 L
.42308 .86421 L
.40385 .86173 L
.38462 .85826 L
.36538 .85374 L
.34615 .84813 L
.34017 .84615 L
Mistroke
.32692 .84135 L
.30769 .8333 L
.29435 .82692 L
.28846 .82388 L
.26923 .81294 L
.26092 .80769 L
.25 .80028 L
.23424 .78846 L
.23077 .78567 L
.21207 .76923 L
.21154 .76873 L
.19324 .75 L
.19231 .74897 L
.17706 .73077 L
.17308 .72557 L
.16308 .71154 L
.15385 .69713 L
.15098 .69231 L
.14052 .67308 L
.13462 .66077 L
.13155 .65385 L
.12393 .63462 L
.11757 .61538 L
.11538 .60782 L
.11239 .59615 L
.10833 .57692 L
.10534 .55769 L
.1034 .53846 L
.10248 .51923 L
.10257 .5 L
.10367 .48077 L
.10578 .46154 L
.10891 .44231 L
.11308 .42308 L
.11538 .41408 L
.11833 .40385 L
.1247 .38462 L
.13224 .36538 L
.13462 .35988 L
.14102 .34615 L
.15113 .32692 L
.15385 .32217 L
.16268 .30769 L
.17308 .29228 L
.17582 .28846 L
.19072 .26923 L
.19231 .26732 L
.20763 .25 L
.21154 .24588 L
.22687 .23077 L
Mistroke
.23077 .22716 L
.24889 .21154 L
.25 .21064 L
.26923 .19596 L
.27438 .19231 L
.28846 .18286 L
.30438 .17308 L
.30769 .17115 L
.32692 .16069 L
.34079 .15385 L
.34615 .15135 L
.36538 .14305 L
.38462 .13571 L
.38769 .13462 L
.40385 .12926 L
.42308 .12368 L
.44231 .1189 L
.45902 .11538 L
.46154 .11491 L
Mfstroke
.6 g
.51923 .1534 m
.53846 .15241 L
.55769 .15227 L
.57692 .15296 L
.59061 .15385 L
.59615 .15452 L
.61538 .15698 L
.63462 .16035 L
.65385 .1647 L
.67308 .17009 L
.68233 .17308 L
.69231 .1766 L
.71154 .18434 L
.72855 .19231 L
.73077 .19343 L
.75 .20407 L
.76192 .21154 L
.76923 .21649 L
.78811 .23077 L
.78846 .23105 L
.80769 .24828 L
.80944 .25 L
.82692 .26901 L
.8271 .26923 L
.84184 .28846 L
.84615 .29481 L
.85412 .30769 L
.86427 .32692 L
.86538 .32927 L
.87254 .34615 L
.87909 .36538 L
.88405 .38462 L
.88462 .38703 L
.88753 .40385 L
.88959 .42308 L
.8903 .44231 L
.88968 .46154 L
.88775 .48077 L
.88462 .49966 L
.88454 .5 L
.88003 .51923 L
.87421 .53846 L
.86706 .55769 L
.86538 .56174 L
.85853 .57692 L
.84857 .59615 L
.84615 .60043 L
.8371 .61538 L
.82692 .63056 L
.82402 .63462 L
.80921 .65385 L
.80769 .65569 L
.79249 .67308 L
.78846 .67738 L
.77362 .69231 L
.76923 .69646 L
.75226 .71154 L
.75 .71344 L
.73077 .72865 L
.72791 .73077 L
.71154 .74232 L
.69978 .75 L
.69231 .75463 L
.67308 .76569 L
.66645 .76923 L
.65385 .7756 L
.63462 .78442 L
.62495 .78846 L
.61538 .7922 L
.59615 .79899 L
.57692 .8048 L
.56596 .80769 L
.55769 .80965 L
.53846 .81356 L
.51923 .81652 L
.5 .81852 L
.48077 .81956 L
.46154 .81962 L
.44231 .81867 L
.42308 .81666 L
.40385 .81357 L
.38462 .80932 L
.37836 .80769 L
.36538 .80385 L
.34615 .79706 L
.32692 .78884 L
.32612 .78846 L
.30769 .77902 L
.29126 .76923 L
.28846 .76742 L
.26923 .75374 L
.26448 .75 L
.25 .73759 L
.24277 .73077 L
.23077 .71837 L
.22471 .71154 L
.21154 .69509 L
.20949 .69231 L
.1966 .67308 L
.19231 .6659 L
.18569 .65385 L
.17653 .63462 L
.17308 .62636 L
.16894 .61538 L
.16278 .59615 L
.15797 .57692 L
.15443 .55769 L
.15385 .55451 L
.15211 .53846 L
.15097 .51923 L
.15099 .5 L
.15217 .48077 L
.15385 .46527 L
.15451 .46154 L
.15803 .44231 L
.16275 .42308 L
.16873 .40385 L
.17308 .39195 L
.17603 .38462 L
.18473 .36538 L
.19231 .35081 L
.19493 .34615 L
.20678 .32692 L
.21154 .31991 L
.22046 .30769 L
.23077 .29481 L
.23622 .28846 L
.25 .27364 L
.25441 .26923 L
.26923 .25542 L
.27551 .25 L
.28846 .23954 L
.30028 .23077 L
.30769 .2256 L
.32692 .21333 L
.32993 .21154 L
.34615 .2025 L
.36538 .19297 L
.36681 .19231 L
.38462 .18461 L
.40385 .17734 L
.4166 .17308 L
.42308 .17108 L
.44231 .16578 L
.46154 .16139 L
.48077 .15787 L
.5 .15522 L
.51291 .15385 L
F
0 g
.51923 .1534 m
.53846 .15241 L
.55769 .15227 L
.57692 .15296 L
.59061 .15385 L
.59615 .15452 L
.61538 .15698 L
.63462 .16035 L
.65385 .1647 L
.67308 .17009 L
.68233 .17308 L
.69231 .1766 L
.71154 .18434 L
.72855 .19231 L
.73077 .19343 L
.75 .20407 L
.76192 .21154 L
.76923 .21649 L
.78811 .23077 L
.78846 .23105 L
.80769 .24828 L
.80944 .25 L
.82692 .26901 L
.8271 .26923 L
.84184 .28846 L
.84615 .29481 L
.85412 .30769 L
.86427 .32692 L
.86538 .32927 L
.87254 .34615 L
.87909 .36538 L
.88405 .38462 L
.88462 .38703 L
.88753 .40385 L
.88959 .42308 L
.8903 .44231 L
.88968 .46154 L
.88775 .48077 L
.88462 .49966 L
.88454 .5 L
.88003 .51923 L
.87421 .53846 L
.86706 .55769 L
.86538 .56174 L
.85853 .57692 L
.84857 .59615 L
.84615 .60043 L
.8371 .61538 L
.82692 .63056 L
.82402 .63462 L
Mistroke
.80921 .65385 L
.80769 .65569 L
.79249 .67308 L
.78846 .67738 L
.77362 .69231 L
.76923 .69646 L
.75226 .71154 L
.75 .71344 L
.73077 .72865 L
.72791 .73077 L
.71154 .74232 L
.69978 .75 L
.69231 .75463 L
.67308 .76569 L
.66645 .76923 L
.65385 .7756 L
.63462 .78442 L
.62495 .78846 L
.61538 .7922 L
.59615 .79899 L
.57692 .8048 L
.56596 .80769 L
.55769 .80965 L
.53846 .81356 L
.51923 .81652 L
.5 .81852 L
.48077 .81956 L
.46154 .81962 L
.44231 .81867 L
.42308 .81666 L
.40385 .81357 L
.38462 .80932 L
.37836 .80769 L
.36538 .80385 L
.34615 .79706 L
.32692 .78884 L
.32612 .78846 L
.30769 .77902 L
.29126 .76923 L
.28846 .76742 L
.26923 .75374 L
.26448 .75 L
.25 .73759 L
.24277 .73077 L
.23077 .71837 L
.22471 .71154 L
.21154 .69509 L
.20949 .69231 L
.1966 .67308 L
.19231 .6659 L
Mistroke
.18569 .65385 L
.17653 .63462 L
.17308 .62636 L
.16894 .61538 L
.16278 .59615 L
.15797 .57692 L
.15443 .55769 L
.15385 .55451 L
.15211 .53846 L
.15097 .51923 L
.15099 .5 L
.15217 .48077 L
.15385 .46527 L
.15451 .46154 L
.15803 .44231 L
.16275 .42308 L
.16873 .40385 L
.17308 .39195 L
.17603 .38462 L
.18473 .36538 L
.19231 .35081 L
.19493 .34615 L
.20678 .32692 L
.21154 .31991 L
.22046 .30769 L
.23077 .29481 L
.23622 .28846 L
.25 .27364 L
.25441 .26923 L
.26923 .25542 L
.27551 .25 L
.28846 .23954 L
.30028 .23077 L
.30769 .2256 L
.32692 .21333 L
.32993 .21154 L
.34615 .2025 L
.36538 .19297 L
.36681 .19231 L
.38462 .18461 L
.40385 .17734 L
.4166 .17308 L
.42308 .17108 L
.44231 .16578 L
.46154 .16139 L
.48077 .15787 L
.5 .15522 L
.51291 .15385 L
.51923 .1534 L
Mfstroke
.7 g
.46154 .20781 m
.48077 .20394 L
.5 .20107 L
.51923 .19918 L
.53846 .19827 L
.55769 .19833 L
.57692 .19939 L
.59615 .20147 L
.61538 .20461 L
.63462 .20888 L
.64453 .21154 L
.65385 .21436 L
.67308 .22116 L
.69231 .22943 L
.69511 .23077 L
.71154 .23937 L
.72886 .25 L
.73077 .25128 L
.75 .26558 L
.75437 .26923 L
.76923 .28296 L
.77455 .28846 L
.78846 .30463 L
.79083 .30769 L
.80401 .32692 L
.80769 .33311 L
.8146 .34615 L
.82296 .36538 L
.82692 .37654 L
.82933 .38462 L
.83387 .40385 L
.83672 .42308 L
.83796 .44231 L
.83766 .46154 L
.83584 .48077 L
.83253 .5 L
.82772 .51923 L
.82692 .52197 L
.8214 .53846 L
.81351 .55769 L
.80769 .56989 L
.80401 .57692 L
.79279 .59615 L
.78846 .60285 L
.77973 .61538 L
.76923 .62905 L
.76464 .63462 L
.75 .651 L
.74728 .65385 L
.73077 .66991 L
.72727 .67308 L
.71154 .68643 L
.70406 .69231 L
.69231 .70098 L
.6767 .71154 L
.67308 .71384 L
.65385 .7252 L
.64344 .73077 L
.63462 .73519 L
.61538 .74391 L
.60009 .75 L
.59615 .75144 L
.57692 .75782 L
.55769 .76309 L
.53846 .76726 L
.52733 .76923 L
.51923 .77035 L
.5 .77234 L
.48077 .77322 L
.46154 .77297 L
.44231 .77155 L
.42472 .76923 L
.42308 .76891 L
.40385 .76497 L
.38462 .75965 L
.36538 .75281 L
.35855 .75 L
.34615 .74431 L
.32692 .73391 L
.32176 .73077 L
.30769 .72133 L
.29492 .71154 L
.28846 .70608 L
.27386 .69231 L
.26923 .68747 L
.25678 .67308 L
.25 .66425 L
.24276 .65385 L
.23123 .63462 L
.23077 .63377 L
.2218 .61538 L
.21423 .59615 L
.21154 .5881 L
.20834 .57692 L
.20401 .55769 L
.20113 .53846 L
.19967 .51923 L
.19957 .5 L
.20082 .48077 L
.20344 .46154 L
.20744 .44231 L
.21154 .42727 L
.21287 .42308 L
.2198 .40385 L
.22833 .38462 L
.23077 .37971 L
.23859 .36538 L
.25 .34727 L
.25076 .34615 L
.26511 .32692 L
.26923 .32193 L
.28198 .30769 L
.28846 .30108 L
.30192 .28846 L
.30769 .28346 L
.32573 .26923 L
.32692 .26836 L
.34615 .25532 L
.35486 .25 L
.36538 .24403 L
.38462 .23426 L
.39225 .23077 L
.40385 .22586 L
.42308 .21871 L
.44231 .21272 L
.44653 .21154 L
F
0 g
.46154 .20781 m
.48077 .20394 L
.5 .20107 L
.51923 .19918 L
.53846 .19827 L
.55769 .19833 L
.57692 .19939 L
.59615 .20147 L
.61538 .20461 L
.63462 .20888 L
.64453 .21154 L
.65385 .21436 L
.67308 .22116 L
.69231 .22943 L
.69511 .23077 L
.71154 .23937 L
.72886 .25 L
.73077 .25128 L
.75 .26558 L
.75437 .26923 L
.76923 .28296 L
.77455 .28846 L
.78846 .30463 L
.79083 .30769 L
.80401 .32692 L
.80769 .33311 L
.8146 .34615 L
.82296 .36538 L
.82692 .37654 L
.82933 .38462 L
.83387 .40385 L
.83672 .42308 L
.83796 .44231 L
.83766 .46154 L
.83584 .48077 L
.83253 .5 L
.82772 .51923 L
.82692 .52197 L
.8214 .53846 L
.81351 .55769 L
.80769 .56989 L
.80401 .57692 L
.79279 .59615 L
.78846 .60285 L
.77973 .61538 L
.76923 .62905 L
.76464 .63462 L
.75 .651 L
.74728 .65385 L
.73077 .66991 L
Mistroke
.72727 .67308 L
.71154 .68643 L
.70406 .69231 L
.69231 .70098 L
.6767 .71154 L
.67308 .71384 L
.65385 .7252 L
.64344 .73077 L
.63462 .73519 L
.61538 .74391 L
.60009 .75 L
.59615 .75144 L
.57692 .75782 L
.55769 .76309 L
.53846 .76726 L
.52733 .76923 L
.51923 .77035 L
.5 .77234 L
.48077 .77322 L
.46154 .77297 L
.44231 .77155 L
.42472 .76923 L
.42308 .76891 L
.40385 .76497 L
.38462 .75965 L
.36538 .75281 L
.35855 .75 L
.34615 .74431 L
.32692 .73391 L
.32176 .73077 L
.30769 .72133 L
.29492 .71154 L
.28846 .70608 L
.27386 .69231 L
.26923 .68747 L
.25678 .67308 L
.25 .66425 L
.24276 .65385 L
.23123 .63462 L
.23077 .63377 L
.2218 .61538 L
.21423 .59615 L
.21154 .5881 L
.20834 .57692 L
.20401 .55769 L
.20113 .53846 L
.19967 .51923 L
.19957 .5 L
.20082 .48077 L
.20344 .46154 L
Mistroke
.20744 .44231 L
.21154 .42727 L
.21287 .42308 L
.2198 .40385 L
.22833 .38462 L
.23077 .37971 L
.23859 .36538 L
.25 .34727 L
.25076 .34615 L
.26511 .32692 L
.26923 .32193 L
.28198 .30769 L
.28846 .30108 L
.30192 .28846 L
.30769 .28346 L
.32573 .26923 L
.32692 .26836 L
.34615 .25532 L
.35486 .25 L
.36538 .24403 L
.38462 .23426 L
.39225 .23077 L
.40385 .22586 L
.42308 .21871 L
.44231 .21272 L
.44653 .21154 L
.46154 .20781 L
Mfstroke
.8 g
.5 .24881 m
.51923 .24684 L
.53846 .24606 L
.55769 .24646 L
.57692 .24807 L
.59119 .25 L
.59615 .25096 L
.61538 .25519 L
.63462 .26089 L
.65385 .26822 L
.65618 .26923 L
.67308 .27743 L
.69165 .28846 L
.69231 .28889 L
.71154 .30316 L
.71682 .30769 L
.73077 .32125 L
.73588 .32692 L
.75 .34521 L
.75064 .34615 L
.76205 .36538 L
.76923 .3809 L
.77068 .38462 L
.77691 .40385 L
.78097 .42308 L
.78305 .44231 L
.78324 .46154 L
.78162 .48077 L
.77821 .5 L
.77302 .51923 L
.76923 .53034 L
.766 .53846 L
.75708 .55769 L
.75 .57058 L
.74614 .57692 L
.73301 .59615 L
.73077 .59913 L
.71741 .61538 L
.71154 .62186 L
.69893 .63462 L
.69231 .64078 L
.67691 .65385 L
.67308 .65686 L
.65385 .67067 L
.65018 .67308 L
.63462 .68256 L
.61629 .69231 L
.61538 .69275 L
.59615 .70141 L
.57692 .70864 L
.56805 .71154 L
.55769 .71451 L
.53846 .71907 L
.51923 .72233 L
.5 .72429 L
.48077 .72494 L
.46154 .72424 L
.44231 .72213 L
.42308 .71851 L
.40385 .71327 L
.39856 .71154 L
.38462 .70623 L
.36538 .69715 L
.3567 .69231 L
.34615 .68568 L
.32911 .67308 L
.32692 .67126 L
.30851 .65385 L
.30769 .65298 L
.29246 .63462 L
.28846 .62903 L
.2798 .61538 L
.26986 .59615 L
.26923 .59479 L
.26222 .57692 L
.25661 .55769 L
.25287 .53846 L
.25087 .51923 L
.25055 .5 L
.25187 .48077 L
.25484 .46154 L
.2595 .44231 L
.26592 .42308 L
.26923 .41479 L
.27422 .40385 L
.28458 .38462 L
.28846 .37831 L
.29726 .36538 L
.30769 .35194 L
.31264 .34615 L
.32692 .33111 L
.33131 .32692 L
.34615 .314 L
.35423 .30769 L
.36538 .2997 L
.38322 .28846 L
.38462 .28766 L
.40385 .2775 L
.42251 .26923 L
.42308 .269 L
.44231 .26199 L
.46154 .25633 L
.48077 .25196 L
.49142 .25 L
F
0 g
.5 .24881 m
.51923 .24684 L
.53846 .24606 L
.55769 .24646 L
.57692 .24807 L
.59119 .25 L
.59615 .25096 L
.61538 .25519 L
.63462 .26089 L
.65385 .26822 L
.65618 .26923 L
.67308 .27743 L
.69165 .28846 L
.69231 .28889 L
.71154 .30316 L
.71682 .30769 L
.73077 .32125 L
.73588 .32692 L
.75 .34521 L
.75064 .34615 L
.76205 .36538 L
.76923 .3809 L
.77068 .38462 L
.77691 .40385 L
.78097 .42308 L
.78305 .44231 L
.78324 .46154 L
.78162 .48077 L
.77821 .5 L
.77302 .51923 L
.76923 .53034 L
.766 .53846 L
.75708 .55769 L
.75 .57058 L
.74614 .57692 L
.73301 .59615 L
.73077 .59913 L
.71741 .61538 L
.71154 .62186 L
.69893 .63462 L
.69231 .64078 L
.67691 .65385 L
.67308 .65686 L
.65385 .67067 L
.65018 .67308 L
.63462 .68256 L
.61629 .69231 L
.61538 .69275 L
.59615 .70141 L
.57692 .70864 L
Mistroke
.56805 .71154 L
.55769 .71451 L
.53846 .71907 L
.51923 .72233 L
.5 .72429 L
.48077 .72494 L
.46154 .72424 L
.44231 .72213 L
.42308 .71851 L
.40385 .71327 L
.39856 .71154 L
.38462 .70623 L
.36538 .69715 L
.3567 .69231 L
.34615 .68568 L
.32911 .67308 L
.32692 .67126 L
.30851 .65385 L
.30769 .65298 L
.29246 .63462 L
.28846 .62903 L
.2798 .61538 L
.26986 .59615 L
.26923 .59479 L
.26222 .57692 L
.25661 .55769 L
.25287 .53846 L
.25087 .51923 L
.25055 .5 L
.25187 .48077 L
.25484 .46154 L
.2595 .44231 L
.26592 .42308 L
.26923 .41479 L
.27422 .40385 L
.28458 .38462 L
.28846 .37831 L
.29726 .36538 L
.30769 .35194 L
.31264 .34615 L
.32692 .33111 L
.33131 .32692 L
.34615 .314 L
.35423 .30769 L
.36538 .2997 L
.38322 .28846 L
.38462 .28766 L
.40385 .2775 L
.42251 .26923 L
.42308 .269 L
Mistroke
.44231 .26199 L
.46154 .25633 L
.48077 .25196 L
.49142 .25 L
.5 .24881 L
Mfstroke
.9 g
.48077 .30539 m
.5 .30178 L
.51923 .29972 L
.53846 .29918 L
.55769 .3002 L
.57692 .30285 L
.59615 .30724 L
.5978 .30769 L
.61538 .31358 L
.63462 .32221 L
.64322 .32692 L
.65385 .33365 L
.67001 .34615 L
.67308 .3489 L
.68865 .36538 L
.69231 .36999 L
.70207 .38462 L
.71154 .40372 L
.71159 .40385 L
.71794 .42308 L
.72153 .44231 L
.72263 .46154 L
.72139 .48077 L
.71786 .5 L
.71204 .51923 L
.71154 .52063 L
.70385 .53846 L
.6931 .55769 L
.69231 .55896 L
.67952 .57692 L
.67308 .58475 L
.66258 .59615 L
.65385 .60462 L
.64137 .61538 L
.63462 .62066 L
.61538 .63382 L
.61409 .63462 L
.59615 .64464 L
.57692 .65341 L
.57586 .65385 L
.55769 .66035 L
.53846 .66557 L
.51923 .66913 L
.5 .67104 L
.48077 .67128 L
.46154 .66978 L
.44231 .66642 L
.42308 .661 L
.40512 .65385 L
.40385 .65324 L
.38462 .64268 L
.37299 .63462 L
.36538 .6285 L
.35168 .61538 L
.34615 .60917 L
.33628 .59615 L
.32692 .58073 L
.32498 .57692 L
.31687 .55769 L
.31146 .53846 L
.30844 .51923 L
.30769 .50746 L
.30764 .5 L
.30769 .49759 L
.30899 .48077 L
.31248 .46154 L
.3182 .44231 L
.32629 .42308 L
.32692 .42177 L
.33701 .40385 L
.34615 .39058 L
.35082 .38462 L
.36538 .36838 L
.36843 .36538 L
.38462 .35119 L
.39119 .34615 L
.40385 .33746 L
.42207 .32692 L
.42308 .32641 L
.44231 .31754 L
.46154 .3106 L
.47131 .30769 L
F
0 g
.48077 .30539 m
.5 .30178 L
.51923 .29972 L
.53846 .29918 L
.55769 .3002 L
.57692 .30285 L
.59615 .30724 L
.5978 .30769 L
.61538 .31358 L
.63462 .32221 L
.64322 .32692 L
.65385 .33365 L
.67001 .34615 L
.67308 .3489 L
.68865 .36538 L
.69231 .36999 L
.70207 .38462 L
.71154 .40372 L
.71159 .40385 L
.71794 .42308 L
.72153 .44231 L
.72263 .46154 L
.72139 .48077 L
.71786 .5 L
.71204 .51923 L
.71154 .52063 L
.70385 .53846 L
.6931 .55769 L
.69231 .55896 L
.67952 .57692 L
.67308 .58475 L
.66258 .59615 L
.65385 .60462 L
.64137 .61538 L
.63462 .62066 L
.61538 .63382 L
.61409 .63462 L
.59615 .64464 L
.57692 .65341 L
.57586 .65385 L
.55769 .66035 L
.53846 .66557 L
.51923 .66913 L
.5 .67104 L
.48077 .67128 L
.46154 .66978 L
.44231 .66642 L
.42308 .661 L
.40512 .65385 L
.40385 .65324 L
Mistroke
.38462 .64268 L
.37299 .63462 L
.36538 .6285 L
.35168 .61538 L
.34615 .60917 L
.33628 .59615 L
.32692 .58073 L
.32498 .57692 L
.31687 .55769 L
.31146 .53846 L
.30844 .51923 L
.30769 .50746 L
.30764 .5 L
.30769 .49759 L
.30899 .48077 L
.31248 .46154 L
.3182 .44231 L
.32629 .42308 L
.32692 .42177 L
.33701 .40385 L
.34615 .39058 L
.35082 .38462 L
.36538 .36838 L
.36843 .36538 L
.38462 .35119 L
.39119 .34615 L
.40385 .33746 L
.42207 .32692 L
.42308 .32641 L
.44231 .31754 L
.46154 .3106 L
.47131 .30769 L
.48077 .30539 L
Mfstroke
1 g
.46154 .381 m
.48077 .37357 L
.5 .36886 L
.51923 .36664 L
.53846 .36684 L
.55769 .36958 L
.57692 .37523 L
.59615 .38456 L
.59624 .38462 L
.61538 .39906 L
.62007 .40385 L
.63395 .42308 L
.63462 .42402 L
.64197 .44231 L
.64553 .46154 L
.64529 .48077 L
.64148 .5 L
.63462 .5183 L
.63404 .51923 L
.62262 .53846 L
.61538 .54789 L
.60627 .55769 L
.59615 .5669 L
.58269 .57692 L
.57692 .58058 L
.55769 .5906 L
.54331 .59615 L
.53846 .59757 L
.51923 .60192 L
.5 .6037 L
.48077 .60287 L
.46154 .5992 L
.45129 .59615 L
.44231 .59222 L
.42308 .58085 L
.41805 .57692 L
.40385 .56264 L
.4001 .55769 L
.38919 .53846 L
.38462 .52737 L
.38309 .51923 L
.38082 .5 L
.38203 .48077 L
.38462 .46842 L
.38667 .46154 L
.39496 .44231 L
.40385 .42793 L
.4076 .42308 L
.42308 .40645 L
.42602 .40385 L
.44231 .39159 L
.45415 .38462 L
F
0 g
.46154 .381 m
.48077 .37357 L
.5 .36886 L
.51923 .36664 L
.53846 .36684 L
.55769 .36958 L
.57692 .37523 L
.59615 .38456 L
.59624 .38462 L
.61538 .39906 L
.62007 .40385 L
.63395 .42308 L
.63462 .42402 L
.64197 .44231 L
.64553 .46154 L
.64529 .48077 L
.64148 .5 L
.63462 .5183 L
.63404 .51923 L
.62262 .53846 L
.61538 .54789 L
.60627 .55769 L
.59615 .5669 L
.58269 .57692 L
.57692 .58058 L
.55769 .5906 L
.54331 .59615 L
.53846 .59757 L
.51923 .60192 L
.5 .6037 L
.48077 .60287 L
.46154 .5992 L
.45129 .59615 L
.44231 .59222 L
.42308 .58085 L
.41805 .57692 L
.40385 .56264 L
.4001 .55769 L
.38919 .53846 L
.38462 .52737 L
.38309 .51923 L
.38082 .5 L
.38203 .48077 L
.38462 .46842 L
.38667 .46154 L
.39496 .44231 L
.40385 .42793 L
.4076 .42308 L
.42308 .40645 L
.42602 .40385 L
Mistroke
.44231 .39159 L
.45415 .38462 L
.46154 .381 L
Mfstroke
.1 g
.98077 .77492 m
.96866 .78846 L
.96154 .7961 L
.95031 .80769 L
.94231 .81564 L
.93051 .82692 L
.92308 .83378 L
.90914 .84615 L
.90385 .8507 L
.88603 .86538 L
.88462 .86652 L
.86538 .88134 L
.86096 .88462 L
.84615 .89525 L
.83363 .90385 L
.82692 .90831 L
.80769 .92057 L
.80361 .92308 L
.78846 .93208 L
.77026 .94231 L
.76923 .94287 L
.75 .95297 L
.73257 .96154 L
.73077 .96239 L
.71154 .97117 L
.69231 .9793 L
.68867 .98077 L
.98077 .98077 L
F
0 g
.98077 .77492 m
.96866 .78846 L
.96154 .7961 L
.95031 .80769 L
.94231 .81564 L
.93051 .82692 L
.92308 .83378 L
.90914 .84615 L
.90385 .8507 L
.88603 .86538 L
.88462 .86652 L
.86538 .88134 L
.86096 .88462 L
.84615 .89525 L
.83363 .90385 L
.82692 .90831 L
.80769 .92057 L
.80361 .92308 L
.78846 .93208 L
.77026 .94231 L
.76923 .94287 L
.75 .95297 L
.73257 .96154 L
.73077 .96239 L
.71154 .97117 L
.69231 .9793 L
.68867 .98077 L
s
.2 g
.98077 .19902 m
.97585 .19231 L
.96154 .17425 L
.96055 .17308 L
.94323 .15385 L
.94231 .15289 L
.92357 .13462 L
.92308 .13417 L
.90385 .1176 L
.9011 .11538 L
.88462 .10283 L
.87516 .09615 L
.86538 .08962 L
.84615 .07777 L
.8447 .07692 L
.82692 .06713 L
.8079 .05769 L
.80769 .05759 L
.78846 .04906 L
.76923 .04144 L
.76104 .03846 L
.75 .03469 L
.73077 .02874 L
.71154 .02355 L
.693 .01923 L
.98077 .01923 L
F
0 g
.98077 .19902 m
.97585 .19231 L
.96154 .17425 L
.96055 .17308 L
.94323 .15385 L
.94231 .15289 L
.92357 .13462 L
.92308 .13417 L
.90385 .1176 L
.9011 .11538 L
.88462 .10283 L
.87516 .09615 L
.86538 .08962 L
.84615 .07777 L
.8447 .07692 L
.82692 .06713 L
.8079 .05769 L
.80769 .05759 L
.78846 .04906 L
.76923 .04144 L
.76104 .03846 L
.75 .03469 L
.73077 .02874 L
.71154 .02355 L
.693 .01923 L
s
.98077 .88216 m
.97806 .88462 L
.96154 .89917 L
.95604 .90385 L
.94231 .9152 L
.93243 .92308 L
.92308 .93033 L
.90707 .94231 L
.90385 .94465 L
.88462 .9582 L
.87971 .96154 L
.86538 .97103 L
.85003 .98077 L
.98077 .98077 L
F
.98077 .88216 m
.97806 .88462 L
.96154 .89917 L
.95604 .90385 L
.94231 .9152 L
.93243 .92308 L
.92308 .93033 L
.90707 .94231 L
.90385 .94465 L
.88462 .9582 L
.87971 .96154 L
.86538 .97103 L
.85003 .98077 L
s
.1 g
.98077 .09866 m
.97815 .09615 L
.96154 .0811 L
.95664 .07692 L
.94231 .0653 L
.93231 .05769 L
.92308 .05101 L
.90448 .03846 L
.90385 .03805 L
.88462 .02629 L
.87212 .01923 L
.98077 .01923 L
F
0 g
.98077 .09866 m
.97815 .09615 L
.96154 .0811 L
.95664 .07692 L
.94231 .0653 L
.93231 .05769 L
.92308 .05101 L
.90448 .03846 L
.90385 .03805 L
.88462 .02629 L
.87212 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.455 .774 .997 r
.39871 .60651 .40491 .60972 .4151 .60894 .40892 .60592 Mtetra
.434 .774 .997 r
.40892 .60592 .4151 .60894 .42534 .60821 .41918 .60539 Mtetra
.413 .773 .995 r
.41918 .60539 .42534 .60821 .43563 .60754 .42949 .60492 Mtetra
.391 .772 .991 r
.42949 .60492 .43563 .60754 .44598 .6069 .43986 .60449 Mtetra
.368 .769 .985 r
.43986 .60449 .44598 .6069 .45637 .60627 .45029 .60408 Mtetra
.346 .766 .976 r
.45029 .60408 .45637 .60627 .46683 .60565 .46077 .60368 Mtetra
.324 .763 .966 r
.46077 .60368 .46683 .60565 .47734 .60501 .47131 .60326 Mtetra
.304 .759 .954 r
.47131 .60326 .47734 .60501 .48791 .60434 .48191 .6028 Mtetra
.285 .755 .941 r
.48191 .6028 .48791 .60434 .49853 .60362 .49256 .60229 Mtetra
.268 .751 .926 r
.49256 .60229 .49853 .60362 .50921 .60281 .50328 .60169 Mtetra
.254 .748 .912 r
.50328 .60169 .50921 .60281 .51995 .60192 .51405 .601 Mtetra
.244 .745 .897 r
.51405 .601 .51995 .60192 .53074 .60091 .52489 .60018 Mtetra
.236 .744 .883 r
.52489 .60018 .53074 .60091 .54159 .59976 .53578 .59922 Mtetra
.232 .745 .87 r
.53578 .59922 .54159 .59976 .55249 .59846 .54672 .59809 Mtetra
.232 .747 .858 r
.54672 .59809 .55249 .59846 .56345 .59699 .55773 .59678 Mtetra
.235 .751 .849 r
.55773 .59678 .56345 .59699 .57446 .59533 .56878 .59527 Mtetra
.242 .757 .841 r
.56878 .59527 .57446 .59533 .58552 .59347 .57989 .59353 Mtetra
.253 .764 .836 r
.57989 .59353 .58552 .59347 .59663 .59139 .59105 .59156 Mtetra
.267 .774 .833 r
.59105 .59156 .59663 .59139 .60778 .58909 .60225 .58935 Mtetra
.284 .785 .832 r
.60225 .58935 .60778 .58909 .61898 .58655 .61351 .58688 Mtetra
.303 .798 .834 r
.61351 .58688 .61898 .58655 .63022 .58376 .6248 .58415 Mtetra
.325 .812 .837 r
.6248 .58415 .63022 .58376 .6415 .58074 .63614 .58115 Mtetra
.349 .826 .842 r
.63614 .58115 .6415 .58074 .65283 .57746 .64751 .57788 Mtetra
.375 .841 .849 r
.64751 .57788 .65283 .57746 .66418 .57394 .65892 .57435 Mtetra
.402 .857 .856 r
.65892 .57435 .66418 .57394 .67557 .57018 .67037 .57055 Mtetra
.429 .872 .865 r
.67037 .57055 .67557 .57018 .687 .56618 .68185 .56649 Mtetra
.457 .886 .875 r
.68185 .56649 .687 .56618 .69845 .56195 .69336 .56219 Mtetra
.485 .9 .885 r
.69336 .56219 .69845 .56195 .70994 .55751 .70489 .55765 Mtetra
.512 .913 .894 r
.70489 .55765 .70994 .55751 .72145 .55285 .71646 .55288 Mtetra
.539 .924 .904 r
.71646 .55288 .72145 .55285 .73299 .54801 .72805 .54789 Mtetra
.564 .933 .913 r
.72805 .54789 .73299 .54801 .74456 .54298 .73967 .54272 Mtetra
.587 .941 .922 r
.73967 .54272 .74456 .54298 .75615 .53779 .75131 .53736 Mtetra
.609 .947 .93 r
.75131 .53736 .75615 .53779 .76777 .53245 .76297 .53184 Mtetra
.629 .951 .937 r
.76297 .53184 .76777 .53245 .77941 .52699 .77466 .52618 Mtetra
.647 .954 .943 r
.77466 .52618 .77941 .52699 .79109 .5214 .78638 .52039 Mtetra
.663 .954 .948 r
.78638 .52039 .79109 .5214 .80278 .51573 .79812 .5145 Mtetra
.677 .953 .952 r
.79812 .5145 .80278 .51573 .81451 .50997 .80988 .50852 Mtetra
.689 .951 .955 r
.80988 .50852 .81451 .50997 .82626 .50415 .82168 .50247 Mtetra
.699 .947 .958 r
.82168 .50247 .82626 .50415 .83804 .49828 .8335 .49637 Mtetra
.707 .942 .959 r
.8335 .49637 .83804 .49828 .84986 .49238 .84535 .49023 Mtetra
.714 .936 .96 r
.84535 .49023 .84986 .49238 .8617 .48646 .85723 .48407 Mtetra
.719 .929 .96 r
.85723 .48407 .8617 .48646 .87358 .48054 .86914 .4779 Mtetra
.723 .922 .96 r
.86914 .4779 .87358 .48054 .8855 .47462 .88108 .47174 Mtetra
.725 .914 .959 r
.88108 .47174 .8855 .47462 .89745 .46873 .89307 .46561 Mtetra
.727 .906 .957 r
.89307 .46561 .89745 .46873 .90944 .46286 .90509 .4595 Mtetra
.728 .897 .956 r
.90509 .4595 .90944 .46286 .92147 .45703 .91714 .45343 Mtetra
.728 .889 .954 r
.91714 .45343 .92147 .45703 .93354 .45125 .92925 .44742 Mtetra
.727 .88 .952 r
.92925 .44742 .93354 .45125 .94566 .44552 .94139 .44146 Mtetra
.726 .871 .949 r
.94139 .44146 .94566 .44552 .95782 .43985 .95358 .43556 Mtetra
.724 .863 .947 r
.95358 .43556 .95782 .43985 .97003 .43424 .96581 .42974 Mtetra
.427 .766 .996 r
.39244 .60337 .39871 .60651 .40892 .60592 .40267 .60298 Mtetra
.403 .764 .994 r
.40267 .60298 .40892 .60592 .41918 .60539 .41296 .60266 Mtetra
.378 .762 .99 r
.41296 .60266 .41918 .60539 .42949 .60492 .42329 .60241 Mtetra
.353 .758 .983 r
.42329 .60241 .42949 .60492 .43986 .60449 .43369 .60219 Mtetra
.327 .753 .973 r
.43369 .60219 .43986 .60449 .45029 .60408 .44414 .60201 Mtetra
.301 .747 .962 r
.44414 .60201 .45029 .60408 .46077 .60368 .45465 .60183 Mtetra
.276 .741 .948 r
.45465 .60183 .46077 .60368 .47131 .60326 .46522 .60164 Mtetra
.253 .734 .932 r
.46522 .60164 .47131 .60326 .48191 .6028 .47585 .60141 Mtetra
.232 .727 .915 r
.47585 .60141 .48191 .6028 .49256 .60229 .48654 .60112 Mtetra
.214 .721 .897 r
.48654 .60112 .49256 .60229 .50328 .60169 .49729 .60075 Mtetra
.199 .716 .879 r
.49729 .60075 .50328 .60169 .51405 .601 .5081 .60027 Mtetra
.187 .712 .861 r
.5081 .60027 .51405 .601 .52489 .60018 .51897 .59966 Mtetra
.179 .71 .845 r
.51897 .59966 .52489 .60018 .53578 .59922 .5299 .5989 Mtetra
.176 .709 .83 r
.5299 .5989 .53578 .59922 .54672 .59809 .5409 .59795 Mtetra
.176 .711 .817 r
.5409 .59795 .54672 .59809 .55773 .59678 .55194 .59681 Mtetra
.18 .715 .806 r
.55194 .59681 .55773 .59678 .56878 .59527 .56305 .59545 Mtetra
.189 .721 .798 r
.56305 .59545 .56878 .59527 .57989 .59353 .57421 .59386 Mtetra
.2 .729 .793 r
.57421 .59386 .57989 .59353 .59105 .59156 .58541 .59201 Mtetra
.216 .74 .79 r
.58541 .59201 .59105 .59156 .60225 .58935 .59667 .58989 Mtetra
.235 .753 .79 r
.59667 .58989 .60225 .58935 .61351 .58688 .60798 .5875 Mtetra
.256 .767 .792 r
.60798 .5875 .61351 .58688 .6248 .58415 .61933 .58483 Mtetra
.281 .783 .796 r
.61933 .58483 .6248 .58415 .63614 .58115 .63072 .58186 Mtetra
.307 .799 .803 r
.63072 .58186 .63614 .58115 .64751 .57788 .64215 .57861 Mtetra
.335 .817 .811 r
.64215 .57861 .64751 .57788 .65892 .57435 .65362 .57506 Mtetra
.365 .835 .821 r
.65362 .57506 .65892 .57435 .67037 .57055 .66512 .57123 Mtetra
.395 .853 .832 r
.66512 .57123 .67037 .57055 .68185 .56649 .67665 .56712 Mtetra
.426 .87 .843 r
.67665 .56712 .68185 .56649 .69336 .56219 .68822 .56274 Mtetra
.457 .887 .855 r
.68822 .56274 .69336 .56219 .70489 .55765 .69981 .5581 Mtetra
.487 .902 .867 r
.69981 .5581 .70489 .55765 .71646 .55288 .71143 .55321 Mtetra
.516 .916 .879 r
.71143 .55321 .71646 .55288 .72805 .54789 .72307 .54809 Mtetra
.545 .928 .891 r
.72307 .54809 .72805 .54789 .73967 .54272 .73474 .54276 Mtetra
.571 .938 .902 r
.73474 .54276 .73967 .54272 .75131 .53736 .74643 .53723 Mtetra
.596 .946 .912 r
.74643 .53723 .75131 .53736 .76297 .53184 .75814 .53153 Mtetra
.618 .953 .921 r
.75814 .53153 .76297 .53184 .77466 .52618 .76988 .52567 Mtetra
.639 .957 .929 r
.76988 .52567 .77466 .52618 .78638 .52039 .78164 .51967 Mtetra
.657 .959 .936 r
.78164 .51967 .78638 .52039 .79812 .5145 .79343 .51355 Mtetra
.673 .959 .942 r
.79343 .51355 .79812 .5145 .80988 .50852 .80523 .50734 Mtetra
.687 .958 .947 r
.80523 .50734 .80988 .50852 .82168 .50247 .81707 .50105 Mtetra
.698 .955 .951 r
.81707 .50105 .82168 .50247 .8335 .49637 .82892 .4947 Mtetra
.708 .951 .953 r
.82892 .4947 .8335 .49637 .84535 .49023 .84081 .48831 Mtetra
.716 .946 .955 r
.84081 .48831 .84535 .49023 .85723 .48407 .85273 .4819 Mtetra
.722 .939 .956 r
.85273 .4819 .85723 .48407 .86914 .4779 .86467 .47548 Mtetra
.727 .932 .957 r
.86467 .47548 .86914 .4779 .88108 .47174 .87665 .46907 Mtetra
.73 .924 .957 r
.87665 .46907 .88108 .47174 .89307 .46561 .88866 .46267 Mtetra
.732 .916 .956 r
.88866 .46267 .89307 .46561 .90509 .4595 .90071 .45631 Mtetra
.733 .907 .955 r
.90071 .45631 .90509 .4595 .91714 .45343 .9128 .45 Mtetra
.733 .898 .953 r
.9128 .45 .91714 .45343 .92925 .44742 .92493 .44374 Mtetra
.732 .889 .952 r
.92493 .44374 .92925 .44742 .94139 .44146 .9371 .43754 Mtetra
.731 .88 .95 r
.9371 .43754 .94139 .44146 .95358 .43556 .94932 .43141 Mtetra
.729 .871 .947 r
.94932 .43141 .95358 .43556 .96581 .42974 .96158 .42535 Mtetra
.397 .756 .993 r
.38613 .60029 .39244 .60337 .40267 .60298 .39637 .60011 Mtetra
.37 .752 .989 r
.39637 .60011 .40267 .60298 .41296 .60266 .40668 .60001 Mtetra
.341 .747 .982 r
.40668 .60001 .41296 .60266 .42329 .60241 .41703 .59998 Mtetra
.312 .741 .972 r
.41703 .59998 .42329 .60241 .43369 .60219 .42745 .6 Mtetra
.283 .733 .959 r
.42745 .6 .43369 .60219 .44414 .60201 .43793 .60005 Mtetra
.254 .724 .943 r
.43793 .60005 .44414 .60201 .45465 .60183 .44846 .60011 Mtetra
.226 .715 .925 r
.44846 .60011 .45465 .60183 .46522 .60164 .45906 .60016 Mtetra
.201 .705 .905 r
.45906 .60016 .46522 .60164 .47585 .60141 .46972 .60017 Mtetra
.178 .696 .884 r
.46972 .60017 .47585 .60141 .48654 .60112 .48045 .60012 Mtetra
.159 .688 .863 r
.48045 .60012 .48654 .60112 .49729 .60075 .49123 .59998 Mtetra
.143 .681 .842 r
.49123 .59998 .49729 .60075 .5081 .60027 .50208 .59972 Mtetra
.131 .675 .822 r
.50208 .59972 .5081 .60027 .51897 .59966 .513 .59933 Mtetra
.123 .672 .804 r
.513 .59933 .51897 .59966 .5299 .5989 .52397 .59877 Mtetra
.12 .671 .787 r
.52397 .59877 .5299 .5989 .5409 .59795 .535 .59803 Mtetra
.121 .672 .773 r
.535 .59803 .5409 .59795 .55194 .59681 .5461 .59706 Mtetra
.127 .676 .762 r
.5461 .59706 .55194 .59681 .56305 .59545 .55725 .59587 Mtetra
.136 .683 .754 r
.55725 .59587 .56305 .59545 .57421 .59386 .56846 .59442 Mtetra
.15 .692 .748 r
.56846 .59442 .57421 .59386 .58541 .59201 .57972 .5927 Mtetra
.167 .704 .746 r
.57972 .5927 .58541 .59201 .59667 .58989 .59103 .59069 Mtetra
.188 .718 .746 r
.59103 .59069 .59667 .58989 .60798 .5875 .60239 .58839 Mtetra
.211 .734 .75 r
.60239 .58839 .60798 .5875 .61933 .58483 .6138 .58578 Mtetra
.238 .752 .755 r
.6138 .58578 .61933 .58483 .63072 .58186 .62524 .58286 Mtetra
.266 .771 .763 r
.62524 .58286 .63072 .58186 .64215 .57861 .63673 .57962 Mtetra
.297 .791 .773 r
.63673 .57962 .64215 .57861 .65362 .57506 .64826 .57607 Mtetra
.329 .811 .785 r
.64826 .57607 .65362 .57506 .66512 .57123 .65982 .57221 Mtetra
.362 .832 .797 r
.65982 .57221 .66512 .57123 .67665 .56712 .67141 .56804 Mtetra
.396 .852 .811 r
.67141 .56804 .67665 .56712 .68822 .56274 .68303 .56359 Mtetra
.429 .871 .825 r
.68303 .56359 .68822 .56274 .69981 .5581 .69468 .55885 Mtetra
.462 .889 .839 r
.69468 .55885 .69981 .5581 .71143 .55321 .70635 .55384 Mtetra
.495 .906 .853 r
.70635 .55384 .71143 .55321 .72307 .54809 .71805 .54859 Mtetra
.526 .92 .867 r
.71805 .54859 .72307 .54809 .73474 .54276 .72977 .5431 Mtetra
.555 .933 .88 r
.72977 .5431 .73474 .54276 .74643 .53723 .74152 .53739 Mtetra
.582 .944 .893 r
.74152 .53739 .74643 .53723 .75814 .53153 .75328 .5315 Mtetra
.607 .952 .904 r
.75328 .5315 .75814 .53153 .76988 .52567 .76507 .52543 Mtetra
.63 .958 .914 r
.76507 .52543 .76988 .52567 .78164 .51967 .77687 .51921 Mtetra
.651 .962 .923 r
.77687 .51921 .78164 .51967 .79343 .51355 .7887 .51287 Mtetra
.669 .964 .93 r
.7887 .51287 .79343 .51355 .80523 .50734 .80055 .50642 Mtetra
.684 .964 .937 r
.80055 .50642 .80523 .50734 .81707 .50105 .81243 .49988 Mtetra
.697 .962 .942 r
.81243 .49988 .81707 .50105 .82892 .4947 .82433 .49328 Mtetra
.709 .959 .946 r
.82433 .49328 .82892 .4947 .84081 .48831 .83625 .48663 Mtetra
.718 .954 .949 r
.83625 .48663 .84081 .48831 .85273 .4819 .8482 .47995 Mtetra
.725 .949 .952 r
.8482 .47995 .85273 .4819 .86467 .47548 .86018 .47326 Mtetra
.73 .942 .953 r
.86018 .47326 .86467 .47548 .87665 .46907 .8722 .46659 Mtetra
.734 .934 .954 r
.8722 .46659 .87665 .46907 .88866 .46267 .88424 .45993 Mtetra
.737 .926 .954 r
.88424 .45993 .88866 .46267 .90071 .45631 .89632 .4533 Mtetra
.738 .917 .953 r
.89632 .4533 .90071 .45631 .9128 .45 .90844 .44673 Mtetra
.739 .908 .952 r
.90844 .44673 .9128 .45 .92493 .44374 .9206 .44021 Mtetra
.738 .899 .951 r
.9206 .44021 .92493 .44374 .9371 .43754 .93279 .43376 Mtetra
.737 .889 .949 r
.93279 .43376 .9371 .43754 .94932 .43141 .94504 .42738 Mtetra
.735 .88 .947 r
.94504 .42738 .94932 .43141 .96158 .42535 .95732 .42109 Mtetra
.365 .744 .989 r
.37975 .59725 .38613 .60029 .39637 .60011 .39001 .59729 Mtetra
.334 .738 .981 r
.39001 .59729 .39637 .60011 .40668 .60001 .40034 .59742 Mtetra
.302 .73 .971 r
.40034 .59742 .40668 .60001 .41703 .59998 .41071 .59762 Mtetra
.27 .721 .958 r
.41071 .59762 .41703 .59998 .42745 .6 .42115 .59788 Mtetra
.237 .71 .941 r
.42115 .59788 .42745 .6 .43793 .60005 .43165 .59818 Mtetra
.206 .698 .921 r
.43165 .59818 .43793 .60005 .44846 .60011 .44222 .59849 Mtetra
.176 .686 .9 r
.44222 .59849 .44846 .60011 .45906 .60016 .45284 .59878 Mtetra
.149 .674 .876 r
.45284 .59878 .45906 .60016 .46972 .60017 .46353 .59904 Mtetra
.125 .662 .852 r
.46353 .59904 .46972 .60017 .48045 .60012 .47429 .59924 Mtetra
.104 .652 .827 r
.47429 .59924 .48045 .60012 .49123 .59998 .48511 .59934 Mtetra
.088 .643 .804 r
.48511 .59934 .49123 .59998 .50208 .59972 .496 .59933 Mtetra
.077 .636 .782 r
.496 .59933 .50208 .59972 .513 .59933 .50695 .59916 Mtetra
.07 .632 .762 r
.50695 .59916 .513 .59933 .52397 .59877 .51797 .59882 Mtetra
.067 .631 .745 r
.51797 .59882 .52397 .59877 .535 .59803 .52905 .59828 Mtetra
.07 .633 .73 r
.52905 .59828 .535 .59803 .5461 .59706 .54019 .59751 Mtetra
.076 .637 .719 r
.54019 .59751 .5461 .59706 .55725 .59587 .55139 .59649 Mtetra
.087 .645 .71 r
.55139 .59649 .55725 .59587 .56846 .59442 .56265 .5952 Mtetra
.102 .656 .706 r
.56265 .5952 .56846 .59442 .57972 .5927 .57396 .59362 Mtetra
.121 .669 .704 r
.57396 .59362 .57972 .5927 .59103 .59069 .58533 .59173 Mtetra
.144 .684 .705 r
.58533 .59173 .59103 .59069 .60239 .58839 .59675 .58952 Mtetra
.169 .702 .709 r
.59675 .58952 .60239 .58839 .6138 .58578 .60821 .58698 Mtetra
.198 .722 .716 r
.60821 .58698 .6138 .58578 .62524 .58286 .61971 .5841 Mtetra
.229 .743 .725 r
.61971 .5841 .62524 .58286 .63673 .57962 .63126 .58089 Mtetra
.261 .765 .737 r
.63126 .58089 .63673 .57962 .64826 .57607 .64284 .57734 Mtetra
.296 .788 .75 r
.64284 .57734 .64826 .57607 .65982 .57221 .65446 .57345 Mtetra
.331 .81 .764 r
.65446 .57345 .65982 .57221 .67141 .56804 .66611 .56924 Mtetra
.368 .833 .779 r
.66611 .56924 .67141 .56804 .68303 .56359 .67779 .56471 Mtetra
.404 .855 .795 r
.67779 .56471 .68303 .56359 .69468 .55885 .6895 .55988 Mtetra
.439 .875 .812 r
.6895 .55988 .69468 .55885 .70635 .55384 .70123 .55475 Mtetra
.474 .894 .828 r
.70123 .55475 .70635 .55384 .71805 .54859 .71299 .54936 Mtetra
.508 .912 .843 r
.71299 .54936 .71805 .54859 .72977 .5431 .72476 .54371 Mtetra
.54 .927 .858 r
.72476 .54371 .72977 .5431 .74152 .53739 .73656 .53783 Mtetra
.569 .939 .873 r
.73656 .53783 .74152 .53739 .75328 .5315 .74838 .53174 Mtetra
.597 .95 .886 r
.74838 .53174 .75328 .5315 .76507 .52543 .76021 .52546 Mtetra
.622 .958 .898 r
.76021 .52546 .76507 .52543 .77687 .51921 .77207 .51902 Mtetra
.645 .964 .908 r
.77207 .51902 .77687 .51921 .7887 .51287 .78395 .51244 Mtetra
.665 .967 .918 r
.78395 .51244 .7887 .51287 .80055 .50642 .79584 .50574 Mtetra
.682 .969 .926 r
.79584 .50574 .80055 .50642 .81243 .49988 .80776 .49894 Mtetra
.697 .968 .933 r
.80776 .49894 .81243 .49988 .82433 .49328 .8197 .49208 Mtetra
.709 .966 .938 r
.8197 .49208 .82433 .49328 .83625 .48663 .83167 .48516 Mtetra
.72 .962 .942 r
.83167 .48516 .83625 .48663 .8482 .47995 .84366 .47821 Mtetra
.728 .957 .946 r
.84366 .47821 .8482 .47995 .86018 .47326 .85567 .47125 Mtetra
.734 .95 .948 r
.85567 .47125 .86018 .47326 .8722 .46659 .86772 .4643 Mtetra
.739 .943 .95 r
.86772 .4643 .8722 .46659 .88424 .45993 .8798 .45736 Mtetra
.742 .935 .95 r
.8798 .45736 .88424 .45993 .89632 .4533 .89191 .45046 Mtetra
.744 .926 .951 r
.89191 .45046 .89632 .4533 .90844 .44673 .90406 .44362 Mtetra
.745 .917 .95 r
.90406 .44362 .90844 .44673 .9206 .44021 .91624 .43683 Mtetra
.744 .908 .949 r
.91624 .43683 .9206 .44021 .93279 .43376 .92847 .43011 Mtetra
.743 .898 .948 r
.92847 .43011 .93279 .43376 .94504 .42738 .94074 .42348 Mtetra
.742 .889 .946 r
.94074 .42348 .94504 .42738 .95732 .42109 .95305 .41693 Mtetra
.332 .73 .982 r
.37331 .59425 .37975 .59725 .39001 .59729 .38359 .59451 Mtetra
.298 .721 .972 r
.38359 .59451 .39001 .59729 .40034 .59742 .39393 .59487 Mtetra
.262 .71 .958 r
.39393 .59487 .40034 .59742 .41071 .59762 .40433 .59532 Mtetra
.227 .698 .941 r
.40433 .59532 .41071 .59762 .42115 .59788 .4148 .59583 Mtetra
.191 .684 .921 r
.4148 .59583 .42115 .59788 .43165 .59818 .42532 .59638 Mtetra
.157 .669 .897 r
.42532 .59638 .43165 .59818 .44222 .59849 .43591 .59694 Mtetra
.126 .654 .872 r
.43591 .59694 .44222 .59849 .45284 .59878 .44656 .5975 Mtetra
.097 .64 .845 r
.44656 .5975 .45284 .59878 .46353 .59904 .45728 .59802 Mtetra
.072 .626 .818 r
.45728 .59802 .46353 .59904 .47429 .59924 .46807 .59847 Mtetra
.052 .614 .791 r
.46807 .59847 .47429 .59924 .48511 .59934 .47893 .59883 Mtetra
.036 .604 .766 r
.47893 .59883 .48511 .59934 .496 .59933 .48985 .59906 Mtetra
.025 .597 .742 r
.48985 .59906 .496 .59933 .50695 .59916 .50084 .59913 Mtetra
.019 .593 .722 r
.50084 .59913 .50695 .59916 .51797 .59882 .5119 .59902 Mtetra
0 0 0 r
.5119 .59902 .51797 .59882 .52905 .59828 .52303 .59869 Mtetra
.52303 .59869 .52905 .59828 .54019 .59751 .53421 .59813 Mtetra
.53421 .59813 .54019 .59751 .55139 .59649 .54546 .59729 Mtetra
.54546 .59729 .55139 .59649 .56265 .5952 .55677 .59616 Mtetra
.55677 .59616 .56265 .5952 .57396 .59362 .56814 .59473 Mtetra
.56814 .59473 .57396 .59362 .58533 .59173 .57956 .59296 Mtetra
.57956 .59296 .58533 .59173 .59675 .58952 .59103 .59086 Mtetra
.59103 .59086 .59675 .58952 .60821 .58698 .60256 .5884 Mtetra
.60256 .5884 .60821 .58698 .61971 .5841 .61412 .58558 Mtetra
.195 .716 .691 r
.61412 .58558 .61971 .5841 .63126 .58089 .62573 .58239 Mtetra
.23 .74 .704 r
.62573 .58239 .63126 .58089 .64284 .57734 .63737 .57885 Mtetra
.267 .765 .718 r
.63737 .57885 .64284 .57734 .65446 .57345 .64905 .57494 Mtetra
.304 .79 .734 r
.64905 .57494 .65446 .57345 .66611 .56924 .66076 .57068 Mtetra
.343 .815 .751 r
.66076 .57068 .66611 .56924 .67779 .56471 .6725 .56608 Mtetra
.381 .839 .768 r
.6725 .56608 .67779 .56471 .6895 .55988 .68427 .56115 Mtetra
.419 .862 .786 r
.68427 .56115 .6895 .55988 .70123 .55475 .69606 .55591 Mtetra
.457 .883 .804 r
.69606 .55591 .70123 .55475 .71299 .54936 .70787 .55038 Mtetra
.492 .903 .821 r
.70787 .55038 .71299 .54936 .72476 .54371 .71971 .54457 Mtetra
.526 .92 .838 r
.71971 .54457 .72476 .54371 .73656 .53783 .73156 .53851 Mtetra
.559 .935 .853 r
.73156 .53851 .73656 .53783 .74838 .53174 .74343 .53222 Mtetra
.588 .947 .868 r
.74343 .53222 .74838 .53174 .76021 .52546 .75532 .52573 Mtetra
.615 .957 .882 r
.75532 .52573 .76021 .52546 .77207 .51902 .76723 .51906 Mtetra
.64 .964 .894 r
.76723 .51906 .77207 .51902 .78395 .51244 .77915 .51224 Mtetra
.661 .969 .905 r
.77915 .51224 .78395 .51244 .79584 .50574 .7911 .50529 Mtetra
.68 .972 .914 r
.7911 .50529 .79584 .50574 .80776 .49894 .80306 .49823 Mtetra
.697 .973 .922 r
.80306 .49823 .80776 .49894 .8197 .49208 .81504 .4911 Mtetra
.711 .971 .929 r
.81504 .4911 .8197 .49208 .83167 .48516 .82705 .4839 Mtetra
.722 .968 .935 r
.82705 .4839 .83167 .48516 .84366 .47821 .83908 .47667 Mtetra
.731 .964 .939 r
.83908 .47667 .84366 .47821 .85567 .47125 .85113 .46943 Mtetra
.738 .958 .942 r
.85113 .46943 .85567 .47125 .86772 .4643 .86321 .46219 Mtetra
.744 .951 .945 r
.86321 .46219 .86772 .4643 .8798 .45736 .87532 .45497 Mtetra
.747 .943 .946 r
.87532 .45497 .8798 .45736 .89191 .45046 .88747 .44778 Mtetra
.75 .934 .947 r
.88747 .44778 .89191 .45046 .90406 .44362 .89965 .44065 Mtetra
.751 .925 .947 r
.89965 .44065 .90406 .44362 .91624 .43683 .91186 .43359 Mtetra
.751 .916 .947 r
.91186 .43359 .91624 .43683 .92847 .43011 .92412 .4266 Mtetra
.75 .906 .946 r
.92412 .4266 .92847 .43011 .94074 .42348 .93641 .41969 Mtetra
.748 .896 .945 r
.93641 .41969 .94074 .42348 .95305 .41693 .94875 .41289 Mtetra
.299 .714 .974 r
.36682 .59127 .37331 .59425 .38359 .59451 .37712 .59176 Mtetra
.261 .702 .961 r
.37712 .59176 .38359 .59451 .39393 .59487 .38747 .59236 Mtetra
.222 .688 .944 r
.38747 .59236 .39393 .59487 .40433 .59532 .39789 .59305 Mtetra
.183 .673 .923 r
.39789 .59305 .40433 .59532 .4148 .59583 .40837 .59381 Mtetra
.146 .656 .899 r
.40837 .59381 .4148 .59583 .42532 .59638 .41892 .59462 Mtetra
.11 .639 .872 r
.41892 .59462 .42532 .59638 .43591 .59694 .42953 .59546 Mtetra
.077 .621 .844 r
.42953 .59546 .43591 .59694 .44656 .5975 .44021 .59628 Mtetra
.048 .605 .814 r
.44021 .59628 .44656 .5975 .45728 .59802 .45096 .59706 Mtetra
.023 .59 .785 r
.45096 .59706 .45728 .59802 .46807 .59847 .46178 .59778 Mtetra
.003 .577 .756 r
.46178 .59778 .46807 .59847 .47893 .59883 .47267 .5984 Mtetra
0 .567 .73 r
.47267 .5984 .47893 .59883 .48985 .59906 .48364 .59889 Mtetra
.022 0 0 r
.48364 .59889 .48985 .59906 .50084 .59913 .49467 .59921 Mtetra
.026 0 0 r
.49467 .59921 .50084 .59913 .5119 .59902 .50577 .59933 Mtetra
.50577 .59933 .5119 .59902 .52303 .59869 .51694 .59923 Mtetra
.021 0 0 r
.51694 .59923 .52303 .59869 .53421 .59813 .52817 .59887 Mtetra
.011 0 0 r
.52817 .59887 .53421 .59813 .54546 .59729 .53947 .59823 Mtetra
0 0 0 r
.53947 .59823 .54546 .59729 .55677 .59616 .55083 .59728 Mtetra
.55083 .59728 .55677 .59616 .56814 .59473 .56225 .596 Mtetra
.56225 .596 .56814 .59473 .57956 .59296 .57373 .59437 Mtetra
.57373 .59437 .57956 .59296 .59103 .59086 .58526 .59237 Mtetra
.58526 .59237 .59103 .59086 .60256 .5884 .59684 .59 Mtetra
.59684 .59 .60256 .5884 .61412 .58558 .60846 .58724 Mtetra
.60846 .58724 .61412 .58558 .62573 .58239 .62013 .58409 Mtetra
.62013 .58409 .62573 .58239 .63737 .57885 .63184 .58056 Mtetra
.242 .746 .691 r
.63184 .58056 .63737 .57885 .64905 .57494 .64358 .57663 Mtetra
.282 .773 .708 r
.64358 .57663 .64905 .57494 .66076 .57068 .65535 .57233 Mtetra
.322 .799 .726 r
.65535 .57233 .66076 .57068 .6725 .56608 .66716 .56767 Mtetra
.363 .825 .745 r
.66716 .56767 .6725 .56608 .68427 .56115 .67898 .56265 Mtetra
.403 .85 .764 r
.67898 .56265 .68427 .56115 .69606 .55591 .69084 .55729 Mtetra
.442 .873 .783 r
.69084 .55729 .69606 .55591 .70787 .55038 .70271 .55162 Mtetra
.48 .895 .801 r
.70271 .55162 .70787 .55038 .71971 .54457 .7146 .54565 Mtetra
.516 .914 .819 r
.7146 .54565 .71971 .54457 .73156 .53851 .72651 .53941 Mtetra
.55 .93 .836 r
.72651 .53941 .73156 .53851 .74343 .53222 .73844 .53293 Mtetra
.582 .944 .852 r
.73844 .53293 .74343 .53222 .75532 .52573 .75038 .52622 Mtetra
.61 .956 .867 r
.75038 .52622 .75532 .52573 .76723 .51906 .76234 .51932 Mtetra
.636 .965 .88 r
.76234 .51932 .76723 .51906 .77915 .51224 .77432 .51225 Mtetra
.66 .971 .892 r
.77432 .51225 .77915 .51224 .7911 .50529 .78631 .50504 Mtetra
.68 .975 .903 r
.78631 .50504 .7911 .50529 .80306 .49823 .79832 .49772 Mtetra
.698 .976 .912 r
.79832 .49772 .80306 .49823 .81504 .4911 .81035 .49031 Mtetra
.713 .976 .92 r
.81035 .49031 .81504 .4911 .82705 .4839 .8224 .48283 Mtetra
.725 .974 .927 r
.8224 .48283 .82705 .4839 .83908 .47667 .83447 .47531 Mtetra
.735 .97 .932 r
.83447 .47531 .83908 .47667 .85113 .46943 .84656 .46777 Mtetra
.743 .964 .936 r
.84656 .46777 .85113 .46943 .86321 .46219 .85868 .46024 Mtetra
.749 .958 .939 r
.85868 .46024 .86321 .46219 .87532 .45497 .87082 .45272 Mtetra
.753 .95 .942 r
.87082 .45272 .87532 .45497 .88747 .44778 .883 .44525 Mtetra
.756 .942 .943 r
.883 .44525 .88747 .44778 .89965 .44065 .89521 .43783 Mtetra
.757 .933 .944 r
.89521 .43783 .89965 .44065 .91186 .43359 .90746 .43047 Mtetra
.757 .923 .944 r
.90746 .43047 .91186 .43359 .92412 .4266 .91974 .4232 Mtetra
.756 .914 .944 r
.91974 .4232 .92412 .4266 .93641 .41969 .93206 .41602 Mtetra
.755 .904 .943 r
.93206 .41602 .93641 .41969 .94875 .41289 .94443 .40894 Mtetra
.265 .697 .964 r
.36026 .58828 .36682 .59127 .37712 .59176 .37058 .58901 Mtetra
.224 .682 .948 r
.37058 .58901 .37712 .59176 .38747 .59236 .38095 .58985 Mtetra
.183 .665 .928 r
.38095 .58985 .38747 .59236 .39789 .59305 .39139 .5908 Mtetra
.142 .647 .904 r
.39139 .5908 .39789 .59305 .40837 .59381 .40189 .59182 Mtetra
.102 .627 .877 r
.40189 .59182 .40837 .59381 .41892 .59462 .41246 .59289 Mtetra
.065 .608 .847 r
.41246 .59289 .41892 .59462 .42953 .59546 .42309 .594 Mtetra
.032 .589 .816 r
.42309 .594 .42953 .59546 .44021 .59628 .4338 .59509 Mtetra
.002 .571 .784 r
.4338 .59509 .44021 .59628 .45096 .59706 .44458 .59615 Mtetra
0 .555 .753 r
.44458 .59615 .45096 .59706 .46178 .59778 .45543 .59714 Mtetra
0 .541 .724 r
.45543 .59714 .46178 .59778 .47267 .5984 .46635 .59803 Mtetra
.055 0 0 r
.46635 .59803 .47267 .5984 .48364 .59889 .47735 .59878 Mtetra
.064 0 0 r
.47735 .59878 .48364 .59889 .49467 .59921 .48842 .59935 Mtetra
.067 0 0 r
.48842 .59935 .49467 .59921 .50577 .59933 .49956 .59972 Mtetra
.065 0 0 r
.49956 .59972 .50577 .59933 .51694 .59923 .51077 .59985 Mtetra
.058 0 0 r
.51077 .59985 .51694 .59923 .52817 .59887 .52206 .59971 Mtetra
.047 0 0 r
.52206 .59971 .52817 .59887 .53947 .59823 .5334 .59927 Mtetra
.031 0 0 r
.5334 .59927 .53947 .59823 .55083 .59728 .54482 .5985 Mtetra
.011 0 0 r
.54482 .5985 .55083 .59728 .56225 .596 .55629 .59738 Mtetra
0 0 0 r
.55629 .59738 .56225 .596 .57373 .59437 .56783 .59589 Mtetra
.56783 .59589 .57373 .59437 .58526 .59237 .57941 .59402 Mtetra
.57941 .59402 .58526 .59237 .59684 .59 .59105 .59174 Mtetra
.59105 .59174 .59684 .59 .60846 .58724 .60274 .58905 Mtetra
.60274 .58905 .60846 .58724 .62013 .58409 .61447 .58594 Mtetra
.61447 .58594 .62013 .58409 .63184 .58056 .62624 .58242 Mtetra
.62624 .58242 .63184 .58056 .64358 .57663 .63804 .57849 Mtetra
.265 .759 .688 r
.63804 .57849 .64358 .57663 .65535 .57233 .64988 .57416 Mtetra
.307 .787 .707 r
.64988 .57416 .65535 .57233 .66716 .56767 .66175 .56943 Mtetra
.349 .815 .726 r
.66175 .56943 .66716 .56767 .67898 .56265 .67364 .56432 Mtetra
.391 .841 .746 r
.67364 .56432 .67898 .56265 .69084 .55729 .68555 .55885 Mtetra
.432 .866 .766 r
.68555 .55885 .69084 .55729 .70271 .55162 .69749 .55304 Mtetra
.472 .888 .785 r
.69749 .55304 .70271 .55162 .7146 .54565 .70944 .54692 Mtetra
.51 .909 .804 r
.70944 .54692 .7146 .54565 .72651 .53941 .72141 .5405 Mtetra
.545 .927 .822 r
.72141 .5405 .72651 .53941 .73844 .53293 .7334 .53381 Mtetra
.578 .942 .838 r
.7334 .53381 .73844 .53293 .75038 .52622 .7454 .52689 Mtetra
.608 .955 .854 r
.7454 .52689 .75038 .52622 .76234 .51932 .75741 .51976 Mtetra
.635 .965 .868 r
.75741 .51976 .76234 .51932 .77432 .51225 .76944 .51244 Mtetra
.66 .972 .881 r
.76944 .51244 .77432 .51225 .78631 .50504 .78148 .50497 Mtetra
.681 .977 .892 r
.78148 .50497 .78631 .50504 .79832 .49772 .79354 .49738 Mtetra
.7 .979 .902 r
.79354 .49738 .79832 .49772 .81035 .49031 .80562 .48969 Mtetra
.716 .98 .911 r
.80562 .48969 .81035 .49031 .8224 .48283 .81771 .48192 Mtetra
.729 .978 .918 r
.81771 .48192 .8224 .48283 .83447 .47531 .82982 .47411 Mtetra
.74 .975 .924 r
.82982 .47411 .83447 .47531 .84656 .46777 .84195 .46627 Mtetra
.748 .97 .929 r
.84195 .46627 .84656 .46777 .85868 .46024 .85411 .45844 Mtetra
.755 .964 .933 r
.85411 .45844 .85868 .46024 .87082 .45272 .86629 .45062 Mtetra
.759 .957 .936 r
.86629 .45062 .87082 .45272 .883 .44525 .8785 .44284 Mtetra
.762 .948 .939 r
.8785 .44284 .883 .44525 .89521 .43783 .89075 .43512 Mtetra
.764 .94 .94 r
.89075 .43512 .89521 .43783 .90746 .43047 .90302 .42747 Mtetra
.764 .93 .941 r
.90302 .42747 .90746 .43047 .91974 .4232 .91534 .4199 Mtetra
.763 .921 .941 r
.91534 .4199 .91974 .4232 .93206 .41602 .92769 .41244 Mtetra
.761 .911 .941 r
.92769 .41244 .93206 .41602 .94443 .40894 .94008 .40507 Mtetra
.232 .678 .954 r
.35365 .58527 .36026 .58828 .37058 .58901 .36398 .58623 Mtetra
.188 .661 .935 r
.36398 .58623 .37058 .58901 .38095 .58985 .37437 .58733 Mtetra
.145 .641 .912 r
.37437 .58733 .38095 .58985 .39139 .5908 .38482 .58853 Mtetra
.102 .62 .885 r
.38482 .58853 .39139 .5908 .40189 .59182 .39534 .58981 Mtetra
.061 .599 .855 r
.39534 .58981 .40189 .59182 .41246 .59289 .40593 .59116 Mtetra
.024 .577 .823 r
.40593 .59116 .41246 .59289 .42309 .594 .41659 .59253 Mtetra
0 .557 .79 r
.41659 .59253 .42309 .594 .4338 .59509 .42732 .59391 Mtetra
0 .538 .757 r
.42732 .59391 .4338 .59509 .44458 .59615 .43813 .59524 Mtetra
0 .522 .725 r
.43813 .59524 .44458 .59615 .45543 .59714 .44901 .59651 Mtetra
.081 0 0 r
.44901 .59651 .45543 .59714 .46635 .59803 .45996 .59767 Mtetra
.093 0 0 r
.45996 .59767 .46635 .59803 .47735 .59878 .47099 .59869 Mtetra
.1 0 0 r
.47099 .59869 .47735 .59878 .48842 .59935 .4821 .59953 Mtetra
.102 0 0 r
.4821 .59953 .48842 .59935 .49956 .59972 .49328 .60015 Mtetra
.099 0 0 r
.49328 .60015 .49956 .59972 .51077 .59985 .50454 .60052 Mtetra
.09 0 0 r
.50454 .60052 .51077 .59985 .52206 .59971 .51587 .6006 Mtetra
.077 0 0 r
.51587 .6006 .52206 .59971 .5334 .59927 .52727 .60037 Mtetra
.059 0 0 r
.52727 .60037 .5334 .59927 .54482 .5985 .53873 .59979 Mtetra
.037 0 0 r
.53873 .59979 .54482 .5985 .55629 .59738 .55026 .59884 Mtetra
.011 0 0 r
.55026 .59884 .55629 .59738 .56783 .59589 .56185 .5975 Mtetra
0 0 0 r
.56185 .5975 .56783 .59589 .57941 .59402 .5735 .59575 Mtetra
.5735 .59575 .57941 .59402 .59105 .59174 .5852 .59357 Mtetra
.5852 .59357 .59105 .59174 .60274 .58905 .59694 .59096 Mtetra
.59694 .59096 .60274 .58905 .61447 .58594 .60874 .5879 Mtetra
.60874 .5879 .61447 .58594 .62624 .58242 .62057 .58441 Mtetra
.62057 .58441 .62624 .58242 .63804 .57849 .63244 .58047 Mtetra
.253 .749 .675 r
.63244 .58047 .63804 .57849 .64988 .57416 .64434 .57611 Mtetra
.297 .779 .694 r
.64434 .57611 .64988 .57416 .66175 .56943 .65627 .57132 Mtetra
.341 .808 .714 r
.65627 .57132 .66175 .56943 .67364 .56432 .66823 .56613 Mtetra
.385 .835 .734 r
.66823 .56613 .67364 .56432 .68555 .55885 .68021 .56055 Mtetra
.427 .861 .754 r
.68021 .56055 .68555 .55885 .69749 .55304 .69221 .55461 Mtetra
.468 .885 .774 r
.69221 .55461 .69749 .55304 .70944 .54692 .70423 .54833 Mtetra
.507 .906 .793 r
.70423 .54833 .70944 .54692 .72141 .5405 .71626 .54173 Mtetra
.544 .925 .811 r
.71626 .54173 .72141 .5405 .7334 .53381 .7283 .53485 Mtetra
.578 .941 .828 r
.7283 .53485 .7334 .53381 .7454 .52689 .74036 .52771 Mtetra
.609 .954 .844 r
.74036 .52771 .7454 .52689 .75741 .51976 .75243 .52035 Mtetra
.637 .965 .858 r
.75243 .52035 .75741 .51976 .76944 .51244 .76451 .51278 Mtetra
.662 .973 .871 r
.76451 .51278 .76944 .51244 .78148 .50497 .77661 .50505 Mtetra
.684 .979 .883 r
.77661 .50505 .78148 .50497 .79354 .49738 .78872 .49718 Mtetra
.704 .982 .893 r
.78872 .49718 .79354 .49738 .80562 .48969 .80084 .4892 Mtetra
.72 .983 .903 r
.80084 .4892 .80562 .48969 .81771 .48192 .81298 .48115 Mtetra
.734 .982 .911 r
.81298 .48115 .81771 .48192 .82982 .47411 .82513 .47304 Mtetra
.745 .979 .917 r
.82513 .47304 .82982 .47411 .84195 .46627 .83731 .4649 Mtetra
.754 .974 .923 r
.83731 .4649 .84195 .46627 .85411 .45844 .8495 .45675 Mtetra
.761 .969 .927 r
.8495 .45675 .85411 .45844 .86629 .45062 .86172 .44863 Mtetra
.766 .962 .931 r
.86172 .44863 .86629 .45062 .8785 .44284 .87397 .44054 Mtetra
.769 .954 .934 r
.87397 .44054 .8785 .44284 .89075 .43512 .88625 .43252 Mtetra
.77 .945 .936 r
.88625 .43252 .89075 .43512 .90302 .42747 .89856 .42456 Mtetra
.771 .936 .937 r
.89856 .42456 .90302 .42747 .91534 .4199 .9109 .4167 Mtetra
.77 .926 .938 r
.9109 .4167 .91534 .4199 .92769 .41244 .92328 .40893 Mtetra
.768 .917 .938 r
.92328 .40893 .92769 .41244 .94008 .40507 .9357 .40128 Mtetra
.2 .659 .943 r
.34697 .58223 .35365 .58527 .36398 .58623 .35732 .58342 Mtetra
.154 .639 .922 r
.35732 .58342 .36398 .58623 .37437 .58733 .36772 .58476 Mtetra
.109 .617 .896 r
.36772 .58476 .37437 .58733 .38482 .58853 .37819 .58622 Mtetra
.065 .594 .867 r
.37819 .58622 .38482 .58853 .39534 .58981 .38873 .58777 Mtetra
.024 .571 .835 r
.38873 .58777 .39534 .58981 .40593 .59116 .39934 .58939 Mtetra
0 .548 .801 r
.39934 .58939 .40593 .59116 .41659 .59253 .41002 .59104 Mtetra
0 .527 .767 r
.41002 .59104 .41659 .59253 .42732 .59391 .42077 .59269 Mtetra
0 .508 .733 r
.42077 .59269 .42732 .59391 .43813 .59524 .4316 .59431 Mtetra
0 .492 .702 r
.4316 .59431 .43813 .59524 .44901 .59651 .44251 .59586 Mtetra
.115 0 0 r
.44251 .59586 .44901 .59651 .45996 .59767 .4535 .59729 Mtetra
.126 0 0 r
.4535 .59729 .45996 .59767 .47099 .59869 .46457 .59858 Mtetra
.132 0 0 r
.46457 .59858 .47099 .59869 .4821 .59953 .47571 .59969 Mtetra
.47571 .59969 .4821 .59953 .49328 .60015 .48694 .60056 Mtetra
.127 0 0 r
.48694 .60056 .49328 .60015 .50454 .60052 .49824 .60118 Mtetra
.117 0 0 r
.49824 .60118 .50454 .60052 .51587 .6006 .50961 .60149 Mtetra
.102 0 0 r
.50961 .60149 .51587 .6006 .52727 .60037 .52106 .60147 Mtetra
.082 0 0 r
.52106 .60147 .52727 .60037 .53873 .59979 .53257 .60109 Mtetra
.058 0 0 r
.53257 .60109 .53873 .59979 .55026 .59884 .54415 .60032 Mtetra
.03 0 0 r
.54415 .60032 .55026 .59884 .56185 .5975 .5558 .59914 Mtetra
0 0 0 r
.5558 .59914 .56185 .5975 .5735 .59575 .5675 .59752 Mtetra
.5675 .59752 .5735 .59575 .5852 .59357 .57926 .59545 Mtetra
.57926 .59545 .5852 .59357 .59694 .59096 .59107 .59292 Mtetra
.59107 .59292 .59694 .59096 .60874 .5879 .60293 .58992 Mtetra
.60293 .58992 .60874 .5879 .62057 .58441 .61483 .58645 Mtetra
.61483 .58645 .62057 .58441 .63244 .58047 .62677 .58252 Mtetra
.248 .745 .669 r
.62677 .58252 .63244 .58047 .64434 .57611 .63873 .57813 Mtetra
.294 .776 .689 r
.63873 .57813 .64434 .57611 .65627 .57132 .65073 .57329 Mtetra
.339 .806 .709 r
.65073 .57329 .65627 .57132 .66823 .56613 .66276 .56802 Mtetra
.384 .834 .729 r
.66276 .56802 .66823 .56613 .68021 .56055 .6748 .56234 Mtetra
.428 .861 .749 r
.6748 .56234 .68021 .56055 .69221 .55461 .68687 .55627 Mtetra
.47 .885 .768 r
.68687 .55627 .69221 .55461 .70423 .54833 .69895 .54984 Mtetra
.51 .907 .787 r
.69895 .54984 .70423 .54833 .71626 .54173 .71104 .54307 Mtetra
.547 .926 .805 r
.71104 .54307 .71626 .54173 .7283 .53485 .72315 .536 Mtetra
.581 .942 .821 r
.72315 .536 .7283 .53485 .74036 .52771 .73527 .52864 Mtetra
.613 .956 .837 r
.73527 .52864 .74036 .52771 .75243 .52035 .7474 .52104 Mtetra
.642 .966 .851 r
.7474 .52104 .75243 .52035 .76451 .51278 .75953 .51323 Mtetra
.667 .975 .864 r
.75953 .51323 .76451 .51278 .77661 .50505 .77168 .50524 Mtetra
.69 .981 .876 r
.77168 .50524 .77661 .50505 .78872 .49718 .78384 .49709 Mtetra
.709 .984 .886 r
.78384 .49709 .78872 .49718 .80084 .4892 .79602 .48883 Mtetra
.726 .985 .895 r
.79602 .48883 .80084 .4892 .81298 .48115 .8082 .48048 Mtetra
.74 .985 .904 r
.8082 .48048 .81298 .48115 .82513 .47304 .8204 .47207 Mtetra
.751 .982 .911 r
.8204 .47207 .82513 .47304 .83731 .4649 .83262 .46362 Mtetra
.761 .978 .916 r
.83262 .46362 .83731 .4649 .8495 .45675 .84486 .45517 Mtetra
.768 .973 .921 r
.84486 .45517 .8495 .45675 .86172 .44863 .85712 .44673 Mtetra
.773 .966 .925 r
.85712 .44673 .86172 .44863 .87397 .44054 .8694 .43833 Mtetra
.776 .958 .928 r
.8694 .43833 .87397 .44054 .88625 .43252 .88171 .42999 Mtetra
.778 .95 .931 r
.88171 .42999 .88625 .43252 .89856 .42456 .89405 .42173 Mtetra
.778 .941 .933 r
.89405 .42173 .89856 .42456 .9109 .4167 .90643 .41356 Mtetra
.777 .931 .934 r
.90643 .41356 .9109 .4167 .92328 .40893 .91884 .40549 Mtetra
.775 .922 .934 r
.91884 .40549 .92328 .40893 .9357 .40128 .93129 .39755 Mtetra
.17 .639 .933 r
.34024 .57911 .34697 .58223 .35732 .58342 .3506 .58055 Mtetra
.123 .617 .909 r
.3506 .58055 .35732 .58342 .36772 .58476 .36102 .58213 Mtetra
.077 .593 .881 r
.36102 .58213 .36772 .58476 .37819 .58622 .3715 .58385 Mtetra
.032 .569 .85 r
.3715 .58385 .37819 .58622 .38873 .58777 .38205 .58566 Mtetra
0 .545 .817 r
.38205 .58566 .38873 .58777 .39934 .58939 .39268 .58755 Mtetra
0 .521 .782 r
.39268 .58755 .39934 .58939 .41002 .59104 .40338 .58948 Mtetra
0 .5 .748 r
.40338 .58948 .41002 .59104 .42077 .59269 .41416 .59141 Mtetra
0 .481 .714 r
.41416 .59141 .42077 .59269 .4316 .59431 .42502 .59331 Mtetra
.128 0 0 r
.42502 .59331 .4316 .59431 .44251 .59586 .43595 .59514 Mtetra
.144 0 0 r
.43595 .59514 .44251 .59586 .4535 .59729 .44697 .59685 Mtetra
.153 0 0 r
.44697 .59685 .4535 .59729 .46457 .59858 .45807 .59842 Mtetra
.157 0 0 r
.45807 .59842 .46457 .59858 .47571 .59969 .46925 .59979 Mtetra
.156 0 0 r
.46925 .59979 .47571 .59969 .48694 .60056 .48051 .60092 Mtetra
.149 0 0 r
.48051 .60092 .48694 .60056 .49824 .60118 .49186 .60178 Mtetra
.137 0 0 r
.49186 .60178 .49824 .60118 .50961 .60149 .50328 .60233 Mtetra
.121 0 0 r
.50328 .60233 .50961 .60149 .52106 .60147 .51477 .60254 Mtetra
.099 0 0 r
.51477 .60254 .52106 .60147 .53257 .60109 .52634 .60236 Mtetra
.073 0 0 r
.52634 .60236 .53257 .60109 .54415 .60032 .53797 .60177 Mtetra
.044 0 0 r
.53797 .60177 .54415 .60032 .5558 .59914 .54967 .60074 Mtetra
.01 0 0 r
.54967 .60074 .5558 .59914 .5675 .59752 .56144 .59926 Mtetra
0 0 0 r
.56144 .59926 .5675 .59752 .57926 .59545 .57326 .5973 Mtetra
.57326 .5973 .57926 .59545 .59107 .59292 .58513 .59486 Mtetra
.58513 .59486 .59107 .59292 .60293 .58992 .59705 .59193 Mtetra
.59705 .59193 .60293 .58992 .61483 .58645 .60901 .5885 Mtetra
.60901 .5885 .61483 .58645 .62677 .58252 .62102 .58457 Mtetra
.249 .746 .671 r
.62102 .58457 .62677 .58252 .63873 .57813 .63305 .58017 Mtetra
.297 .778 .691 r
.63305 .58017 .63873 .57813 .65073 .57329 .64512 .57528 Mtetra
.344 .808 .711 r
.64512 .57528 .65073 .57329 .66276 .56802 .65721 .56995 Mtetra
.39 .837 .73 r
.65721 .56995 .66276 .56802 .6748 .56234 .66932 .56417 Mtetra
.434 .864 .75 r
.66932 .56417 .6748 .56234 .68687 .55627 .68145 .55798 Mtetra
.477 .888 .768 r
.68145 .55798 .68687 .55627 .69895 .54984 .6936 .5514 Mtetra
.517 .91 .786 r
.6936 .5514 .69895 .54984 .71104 .54307 .70576 .54446 Mtetra
.555 .929 .803 r
.70576 .54446 .71104 .54307 .72315 .536 .71793 .53719 Mtetra
.589 .945 .819 r
.71793 .53719 .72315 .536 .73527 .52864 .73011 .52963 Mtetra
.621 .958 .834 r
.73011 .52963 .73527 .52864 .7474 .52104 .7423 .5218 Mtetra
.65 .969 .847 r
.7423 .5218 .7474 .52104 .75953 .51323 .7545 .51375 Mtetra
.675 .977 .86 r
.7545 .51375 .75953 .51323 .77168 .50524 .7667 .50549 Mtetra
.697 .983 .871 r
.7667 .50549 .77168 .50524 .78384 .49709 .77892 .49707 Mtetra
.717 .986 .881 r
.77892 .49707 .78384 .49709 .79602 .48883 .79114 .48853 Mtetra
.733 .988 .89 r
.79114 .48853 .79602 .48883 .8082 .48048 .80337 .47988 Mtetra
.747 .987 .898 r
.80337 .47988 .8082 .48048 .8204 .47207 .81562 .47116 Mtetra
.759 .985 .905 r
.81562 .47116 .8204 .47207 .83262 .46362 .82788 .46241 Mtetra
.768 .981 .911 r
.82788 .46241 .83262 .46362 .84486 .45517 .84016 .45364 Mtetra
.775 .976 .916 r
.84016 .45364 .84486 .45517 .85712 .44673 .85246 .44489 Mtetra
.78 .969 .92 r
.85246 .44489 .85712 .44673 .8694 .43833 .86479 .43618 Mtetra
.783 .962 .923 r
.86479 .43618 .8694 .43833 .88171 .42999 .87713 .42752 Mtetra
.785 .954 .926 r
.87713 .42752 .88171 .42999 .89405 .42173 .88951 .41894 Mtetra
.785 .945 .928 r
.88951 .41894 .89405 .42173 .90643 .41356 .90192 .41046 Mtetra
.784 .935 .929 r
.90192 .41046 .90643 .41356 .91884 .40549 .91436 .4021 Mtetra
.782 .926 .93 r
.91436 .4021 .91884 .40549 .93129 .39755 .92684 .39385 Mtetra
.144 .62 .923 r
.33345 .57591 .34024 .57911 .3506 .58055 .34382 .57758 Mtetra
.095 .596 .897 r
.34382 .57758 .3506 .58055 .36102 .58213 .35425 .57941 Mtetra
.048 .571 .868 r
.35425 .57941 .36102 .58213 .3715 .58385 .36475 .58138 Mtetra
.003 .546 .836 r
.36475 .58138 .3715 .58385 .38205 .58566 .37532 .58345 Mtetra
0 .521 .802 r
.37532 .58345 .38205 .58566 .39268 .58755 .38596 .58561 Mtetra
0 .497 .767 r
.38596 .58561 .39268 .58755 .40338 .58948 .39668 .58781 Mtetra
0 .476 .733 r
.39668 .58781 .40338 .58948 .41416 .59141 .40748 .59002 Mtetra
0 .457 .701 r
.40748 .59002 .41416 .59141 .42502 .59331 .41836 .5922 Mtetra
.153 0 0 r
.41836 .5922 .42502 .59331 .43595 .59514 .42933 .59431 Mtetra
.167 0 0 r
.42933 .59431 .43595 .59514 .44697 .59685 .44037 .5963 Mtetra
.175 0 0 r
.44037 .5963 .44697 .59685 .45807 .59842 .4515 .59814 Mtetra
.178 0 0 r
.4515 .59814 .45807 .59842 .46925 .59979 .46272 .59978 Mtetra
.175 0 0 r
.46272 .59978 .46925 .59979 .48051 .60092 .47402 .60117 Mtetra
.166 0 0 r
.47402 .60117 .48051 .60092 .49186 .60178 .4854 .60228 Mtetra
.152 0 0 r
.4854 .60228 .49186 .60178 .50328 .60233 .49687 .60307 Mtetra
.134 0 0 r
.49687 .60307 .50328 .60233 .51477 .60254 .50841 .60349 Mtetra
.111 0 0 r
.50841 .60349 .51477 .60254 .52634 .60236 .52002 .60352 Mtetra
.083 0 0 r
.52002 .60352 .52634 .60236 .53797 .60177 .53171 .60312 Mtetra
.051 0 0 r
.53171 .60312 .53797 .60177 .54967 .60074 .54347 .60226 Mtetra
.015 0 0 r
.54347 .60226 .54967 .60074 .56144 .59926 .55529 .60092 Mtetra
0 0 0 r
.55529 .60092 .56144 .59926 .57326 .5973 .56717 .59908 Mtetra
.56717 .59908 .57326 .5973 .58513 .59486 .57911 .59674 Mtetra
.57911 .59674 .58513 .59486 .59705 .59193 .59109 .59387 Mtetra
.59109 .59387 .59705 .59193 .60901 .5885 .60312 .59049 Mtetra
.60312 .59049 .60901 .5885 .62102 .58457 .61519 .58658 Mtetra
.257 .753 .681 r
.61519 .58658 .62102 .58457 .63305 .58017 .6273 .58216 Mtetra
.306 .785 .7 r
.6273 .58216 .63305 .58017 .64512 .57528 .63943 .57724 Mtetra
.355 .816 .72 r
.63943 .57724 .64512 .57528 .65721 .56995 .65159 .57184 Mtetra
.402 .845 .739 r
.65159 .57184 .65721 .56995 .66932 .56417 .66377 .56597 Mtetra
.447 .872 .757 r
.66377 .56597 .66932 .56417 .68145 .55798 .67597 .55967 Mtetra
.49 .895 .775 r
.67597 .55967 .68145 .55798 .6936 .5514 .68818 .55295 Mtetra
.53 .916 .791 r
.68818 .55295 .6936 .5514 .70576 .54446 .70041 .54585 Mtetra
.567 .935 .807 r
.70041 .54585 .70576 .54446 .71793 .53719 .71264 .5384 Mtetra
.602 .95 .821 r
.71264 .5384 .71793 .53719 .73011 .52963 .72489 .53063 Mtetra
.633 .963 .835 r
.72489 .53063 .73011 .52963 .7423 .5218 .73714 .52257 Mtetra
.661 .973 .847 r
.73714 .52257 .7423 .5218 .7545 .51375 .7494 .51428 Mtetra
.686 .98 .858 r
.7494 .51428 .7545 .51375 .7667 .50549 .76166 .50576 Mtetra
.708 .985 .868 r
.76166 .50576 .7667 .50549 .77892 .49707 .77393 .49708 Mtetra
.727 .988 .878 r
.77393 .49708 .77892 .49707 .79114 .48853 .78621 .48824 Mtetra
.743 .989 .886 r
.78621 .48824 .79114 .48853 .80337 .47988 .79849 .4793 Mtetra
.756 .989 .893 r
.79849 .4793 .80337 .47988 .81562 .47116 .81079 .47029 Mtetra
.767 .986 .9 r
.81079 .47029 .81562 .47116 .82788 .46241 .8231 .46123 Mtetra
.776 .983 .905 r
.8231 .46123 .82788 .46241 .84016 .45364 .83542 .45215 Mtetra
.783 .977 .91 r
.83542 .45215 .84016 .45364 .85246 .44489 .84776 .44308 Mtetra
.788 .971 .915 r
.84776 .44308 .85246 .44489 .86479 .43618 .86013 .43405 Mtetra
.791 .964 .918 r
.86013 .43405 .86479 .43618 .87713 .42752 .87251 .42508 Mtetra
.793 .956 .921 r
.87251 .42508 .87713 .42752 .88951 .41894 .88492 .41618 Mtetra
.793 .947 .923 r
.88492 .41618 .88951 .41894 .90192 .41046 .89737 .40739 Mtetra
.792 .938 .925 r
.89737 .40739 .90192 .41046 .91436 .4021 .90984 .39871 Mtetra
.79 .929 .926 r
.90984 .39871 .91436 .4021 .92684 .39385 .92235 .39017 Mtetra
.12 .602 .914 r
.32661 .5726 .33345 .57591 .34382 .57758 .33698 .5745 Mtetra
.071 .577 .887 r
.33698 .5745 .34382 .57758 .35425 .57941 .34743 .57656 Mtetra
.023 .551 .857 r
.34743 .57656 .35425 .57941 .36475 .58138 .35794 .57878 Mtetra
0 .525 .825 r
.35794 .57878 .36475 .58138 .37532 .58345 .36852 .58111 Mtetra
0 .5 .791 r
.36852 .58111 .37532 .58345 .38596 .58561 .37918 .58353 Mtetra
0 .476 .757 r
.37918 .58353 .38596 .58561 .39668 .58781 .38992 .586 Mtetra
0 .455 .724 r
.38992 .586 .39668 .58781 .40748 .59002 .40074 .58848 Mtetra
0 .438 .692 r
.40074 .58848 .40748 .59002 .41836 .5922 .41164 .59094 Mtetra
.172 0 0 r
.41164 .59094 .41836 .5922 .42933 .59431 .42263 .59332 Mtetra
.185 0 0 r
.42263 .59332 .42933 .59431 .44037 .5963 .43371 .59559 Mtetra
.191 0 0 r
.43371 .59559 .44037 .5963 .4515 .59814 .44487 .5977 Mtetra
.192 0 0 r
.44487 .5977 .4515 .59814 .46272 .59978 .45612 .59961 Mtetra
.188 0 0 r
.45612 .59961 .46272 .59978 .47402 .60117 .46745 .60126 Mtetra
.177 0 0 r
.46745 .60126 .47402 .60117 .4854 .60228 .47888 .60262 Mtetra
.162 0 0 r
.47888 .60262 .4854 .60228 .49687 .60307 .49038 .60365 Mtetra
.141 0 0 r
.49038 .60365 .49687 .60307 .50841 .60349 .50197 .60429 Mtetra
.116 0 0 r
.50197 .60429 .50841 .60349 .52002 .60352 .51364 .60453 Mtetra
.086 0 0 r
.51364 .60453 .52002 .60352 .53171 .60312 .52538 .60431 Mtetra
.052 0 0 r
.52538 .60431 .53171 .60312 .54347 .60226 .53719 .60362 Mtetra
.013 0 0 r
.53719 .60362 .54347 .60226 .55529 .60092 .54907 .60243 Mtetra
0 0 0 r
.54907 .60243 .55529 .60092 .56717 .59908 .56101 .60072 Mtetra
.56101 .60072 .56717 .59908 .57911 .59674 .57301 .59847 Mtetra
.57301 .59847 .57911 .59674 .59109 .59387 .58506 .59569 Mtetra
.58506 .59569 .59109 .59387 .60312 .59049 .59715 .59235 Mtetra
.221 .731 .68 r
.59715 .59235 .60312 .59049 .61519 .58658 .60929 .58847 Mtetra
.272 .765 .699 r
.60929 .58847 .61519 .58658 .6273 .58216 .62146 .58404 Mtetra
.322 .798 .718 r
.62146 .58404 .6273 .58216 .63943 .57724 .63366 .5791 Mtetra
.372 .829 .737 r
.63366 .5791 .63943 .57724 .65159 .57184 .64589 .57364 Mtetra
.42 .857 .754 r
.64589 .57364 .65159 .57184 .66377 .56597 .65814 .56769 Mtetra
.465 .883 .771 r
.65814 .56769 .66377 .56597 .67597 .55967 .67041 .56127 Mtetra
.508 .906 .787 r
.67041 .56127 .67597 .55967 .68818 .55295 .68269 .55442 Mtetra
.548 .926 .801 r
.68269 .55442 .68818 .55295 .70041 .54585 .69498 .54717 Mtetra
.584 .943 .815 r
.69498 .54717 .70041 .54585 .71264 .5384 .70729 .53954 Mtetra
.618 .957 .828 r
.70729 .53954 .71264 .5384 .72489 .53063 .71959 .53157 Mtetra
.648 .968 .839 r
.71959 .53157 .72489 .53063 .73714 .52257 .73191 .5233 Mtetra
.675 .977 .85 r
.73191 .5233 .73714 .52257 .7494 .51428 .74423 .51477 Mtetra
.699 .984 .859 r
.74423 .51477 .7494 .51428 .76166 .50576 .75655 .50601 Mtetra
.72 .988 .868 r
.75655 .50601 .76166 .50576 .77393 .49708 .76888 .49705 Mtetra
.738 .99 .876 r
.76888 .49705 .77393 .49708 .78621 .48824 .78121 .48794 Mtetra
.754 .991 .884 r
.78121 .48794 .78621 .48824 .79849 .4793 .79355 .47871 Mtetra
.767 .99 .89 r
.79355 .47871 .79849 .4793 .81079 .47029 .8059 .4694 Mtetra
.777 .987 .896 r
.8059 .4694 .81079 .47029 .8231 .46123 .81825 .46003 Mtetra
.785 .983 .901 r
.81825 .46003 .8231 .46123 .83542 .45215 .83062 .45064 Mtetra
.792 .978 .906 r
.83062 .45064 .83542 .45215 .84776 .44308 .84301 .44126 Mtetra
.796 .972 .91 r
.84301 .44126 .84776 .44308 .86013 .43405 .85541 .43191 Mtetra
.799 .965 .913 r
.85541 .43191 .86013 .43405 .87251 .42508 .86784 .42262 Mtetra
.8 .957 .916 r
.86784 .42262 .87251 .42508 .88492 .41618 .88029 .41341 Mtetra
.8 .949 .918 r
.88029 .41341 .88492 .41618 .89737 .40739 .89277 .40431 Mtetra
.799 .94 .92 r
.89277 .40431 .89737 .40739 .90984 .39871 .90528 .39532 Mtetra
.797 .931 .922 r
.90528 .39532 .90984 .39871 .92235 .39017 .91782 .38647 Mtetra
.1 .585 .906 r
.3197 .56915 .32661 .5726 .33698 .5745 .33009 .57127 Mtetra
.051 .559 .879 r
.33009 .57127 .33698 .5745 .34743 .57656 .34054 .57357 Mtetra
.003 .533 .849 r
.34054 .57357 .34743 .57656 .35794 .57878 .35107 .57602 Mtetra
0 .507 .817 r
.35107 .57602 .35794 .57878 .36852 .58111 .36166 .5786 Mtetra
0 .482 .784 r
.36166 .5786 .36852 .58111 .37918 .58353 .37234 .58128 Mtetra
0 .459 .751 r
.37234 .58128 .37918 .58353 .38992 .586 .38309 .58401 Mtetra
0 .439 .719 r
.38309 .58401 .38992 .586 .40074 .58848 .39393 .58676 Mtetra
0 .423 .69 r
.39393 .58676 .40074 .58848 .41164 .59094 .40486 .58948 Mtetra
.185 0 0 r
.40486 .58948 .41164 .59094 .42263 .59332 .41587 .59214 Mtetra
.197 0 0 r
.41587 .59214 .42263 .59332 .43371 .59559 .42697 .59468 Mtetra
.202 0 0 r
.42697 .59468 .43371 .59559 .44487 .5977 .43816 .59705 Mtetra
.201 0 0 r
.43816 .59705 .44487 .5977 .45612 .59961 .44944 .59922 Mtetra
.195 0 0 r
.44944 .59922 .45612 .59961 .46745 .60126 .46082 .60113 Mtetra
.183 0 0 r
.46082 .60113 .46745 .60126 .47888 .60262 .47228 .60274 Mtetra
.166 0 0 r
.47228 .60274 .47888 .60262 .49038 .60365 .48382 .604 Mtetra
.143 0 0 r
.48382 .604 .49038 .60365 .50197 .60429 .49546 .60487 Mtetra
.116 0 0 r
.49546 .60487 .50197 .60429 .51364 .60453 .50717 .60531 Mtetra
.083 0 0 r
.50717 .60531 .51364 .60453 .52538 .60431 .51896 .60528 Mtetra
.046 0 0 r
.51896 .60528 .52538 .60431 .53719 .60362 .53083 .60477 Mtetra
.005 0 0 r
.53083 .60477 .53719 .60362 .54907 .60243 .54276 .60373 Mtetra
0 0 0 r
.54276 .60373 .54907 .60243 .56101 .60072 .55476 .60214 Mtetra
.55476 .60214 .56101 .60072 .57301 .59847 .56682 .6 Mtetra
.56682 .6 .57301 .59847 .58506 .59569 .57894 .5973 Mtetra
.189 .712 .688 r
.57894 .5973 .58506 .59569 .59715 .59235 .5911 .59402 Mtetra
.241 .748 .707 r
.5911 .59402 .59715 .59235 .60929 .58847 .6033 .59016 Mtetra
.294 .783 .725 r
.6033 .59016 .60929 .58847 .62146 .58404 .61554 .58575 Mtetra
.346 .815 .743 r
.61554 .58575 .62146 .58404 .63366 .5791 .62781 .58078 Mtetra
.396 .846 .76 r
.62781 .58078 .63366 .5791 .64589 .57364 .64011 .57527 Mtetra
.444 .873 .776 r
.64011 .57527 .64589 .57364 .65814 .56769 .65243 .56925 Mtetra
.489 .897 .791 r
.65243 .56925 .65814 .56769 .67041 .56127 .66477 .56274 Mtetra
.531 .919 .804 r
.66477 .56274 .67041 .56127 .68269 .55442 .67712 .55576 Mtetra
.57 .937 .817 r
.67712 .55576 .68269 .55442 .69498 .54717 .68948 .54836 Mtetra
.606 .952 .828 r
.68948 .54836 .69498 .54717 .70729 .53954 .70185 .54056 Mtetra
.638 .965 .838 r
.70185 .54056 .70729 .53954 .71959 .53157 .71423 .53241 Mtetra
.667 .974 .847 r
.71423 .53241 .71959 .53157 .73191 .5233 .72661 .52393 Mtetra
.692 .982 .856 r
.72661 .52393 .73191 .5233 .74423 .51477 .73899 .51517 Mtetra
.715 .987 .863 r
.73899 .51517 .74423 .51477 .75655 .50601 .75137 .50616 Mtetra
.735 .99 .87 r
.75137 .50616 .75655 .50601 .76888 .49705 .76376 .49695 Mtetra
.751 .992 .877 r
.76376 .49695 .76888 .49705 .78121 .48794 .77615 .48757 Mtetra
.766 .992 .883 r
.77615 .48757 .78121 .48794 .79355 .47871 .78854 .47805 Mtetra
.778 .99 .888 r
.78854 .47805 .79355 .47871 .8059 .4694 .80094 .46845 Mtetra
.787 .987 .893 r
.80094 .46845 .8059 .4694 .81825 .46003 .81335 .45878 Mtetra
.795 .983 .898 r
.81335 .45878 .81825 .46003 .83062 .45064 .82577 .44908 Mtetra
.801 .978 .902 r
.82577 .44908 .83062 .45064 .84301 .44126 .8382 .43939 Mtetra
.805 .972 .905 r
.8382 .43939 .84301 .44126 .85541 .43191 .85065 .42973 Mtetra
.807 .965 .908 r
.85065 .42973 .85541 .43191 .86784 .42262 .86311 .42012 Mtetra
.808 .957 .911 r
.86311 .42012 .86784 .42262 .88029 .41341 .8756 .4106 Mtetra
.808 .949 .913 r
.8756 .4106 .88029 .41341 .89277 .40431 .88812 .40118 Mtetra
.806 .94 .915 r
.88812 .40118 .89277 .40431 .90528 .39532 .90066 .39189 Mtetra
.804 .931 .917 r
.90066 .39189 .90528 .39532 .91782 .38647 .91324 .38273 Mtetra
.084 .57 .9 r
.31275 .56554 .3197 .56915 .33009 .57127 .32314 .56787 Mtetra
.035 .544 .874 r
.32314 .56787 .33009 .57127 .34054 .57357 .33361 .57039 Mtetra
0 .517 .844 r
.33361 .57039 .34054 .57357 .35107 .57602 .34414 .57307 Mtetra
0 .491 .813 r
.34414 .57307 .35107 .57602 .36166 .5786 .35475 .57589 Mtetra
0 .467 .781 r
.35475 .57589 .36166 .5786 .37234 .58128 .36544 .57881 Mtetra
0 .445 .75 r
.36544 .57881 .37234 .58128 .38309 .58401 .37621 .5818 Mtetra
0 .426 .72 r
.37621 .5818 .38309 .58401 .39393 .58676 .38706 .5848 Mtetra
0 .412 .693 r
.38706 .5848 .39393 .58676 .40486 .58948 .39801 .58779 Mtetra
.193 0 0 r
.39801 .58779 .40486 .58948 .41587 .59214 .40904 .59071 Mtetra
.203 0 0 r
.40904 .59071 .41587 .59214 .42697 .59468 .42017 .59351 Mtetra
.207 0 0 r
.42017 .59351 .42697 .59468 .43816 .59705 .43139 .59614 Mtetra
.204 0 0 r
.43139 .59614 .43816 .59705 .44944 .59922 .4427 .59857 Mtetra
.196 0 0 r
.4427 .59857 .44944 .59922 .46082 .60113 .45411 .60073 Mtetra
.183 0 0 r
.45411 .60073 .46082 .60113 .47228 .60274 .4656 .60258 Mtetra
.163 0 0 r
.4656 .60258 .47228 .60274 .48382 .604 .47719 .60407 Mtetra
.139 0 0 r
.47719 .60407 .48382 .604 .49546 .60487 .48887 .60515 Mtetra
.109 0 0 r
.48887 .60515 .49546 .60487 .50717 .60531 .50063 .6058 Mtetra
.074 0 0 r
.50063 .6058 .50717 .60531 .51896 .60528 .51247 .60597 Mtetra
.034 0 0 r
.51247 .60597 .51896 .60528 .53083 .60477 .52439 .60562 Mtetra
0 0 0 r
.52439 .60562 .53083 .60477 .54276 .60373 .53638 .60473 Mtetra
.53638 .60473 .54276 .60373 .55476 .60214 .54844 .60328 Mtetra
.54844 .60328 .55476 .60214 .56682 .6 .56056 .60125 Mtetra
.16 .696 .705 r
.56056 .60125 .56682 .6 .57894 .5973 .57273 .59863 Mtetra
.214 .733 .723 r
.57273 .59863 .57894 .5973 .5911 .59402 .58496 .59541 Mtetra
.269 .77 .742 r
.58496 .59541 .5911 .59402 .6033 .59016 .59723 .5916 Mtetra
.322 .805 .759 r
.59723 .5916 .6033 .59016 .61554 .58575 .60954 .5872 Mtetra
.375 .837 .775 r
.60954 .5872 .61554 .58575 .62781 .58078 .62188 .58221 Mtetra
.425 .865 .79 r
.62188 .58221 .62781 .58078 .64011 .57527 .63424 .57667 Mtetra
.473 .891 .803 r
.63424 .57667 .64011 .57527 .65243 .56925 .64664 .57058 Mtetra
.517 .914 .815 r
.64664 .57058 .65243 .56925 .66477 .56274 .65904 .56398 Mtetra
.558 .933 .826 r
.65904 .56398 .66477 .56274 .67712 .55576 .67146 .5569 Mtetra
.596 .949 .835 r
.67146 .5569 .67712 .55576 .68948 .54836 .6839 .54936 Mtetra
.63 .962 .844 r
.6839 .54936 .68948 .54836 .70185 .54056 .69634 .5414 Mtetra
.66 .973 .851 r
.69634 .5414 .70185 .54056 .71423 .53241 .70878 .53307 Mtetra
.687 .981 .858 r
.70878 .53307 .71423 .53241 .72661 .52393 .72122 .52439 Mtetra
.711 .986 .864 r
.72122 .52439 .72661 .52393 .73899 .51517 .73367 .51541 Mtetra
.732 .99 .869 r
.73367 .51541 .73899 .51517 .75137 .50616 .74612 .50617 Mtetra
.75 .992 .874 r
.74612 .50617 .75137 .50616 .76376 .49695 .75857 .49671 Mtetra
.766 .993 .879 r
.75857 .49671 .76376 .49695 .77615 .48757 .77101 .48706 Mtetra
.779 .992 .884 r
.77101 .48706 .77615 .48757 .78854 .47805 .78346 .47728 Mtetra
.789 .99 .888 r
.78346 .47728 .78854 .47805 .80094 .46845 .79592 .46738 Mtetra
.798 .986 .891 r
.79592 .46738 .80094 .46845 .81335 .45878 .80838 .45742 Mtetra
.805 .982 .895 r
.80838 .45742 .81335 .45878 .82577 .44908 .82085 .44743 Mtetra
.81 .976 .898 r
.82085 .44743 .82577 .44908 .8382 .43939 .83332 .43743 Mtetra
.813 .97 .901 r
.83332 .43743 .8382 .43939 .85065 .42973 .84582 .42746 Mtetra
.815 .963 .904 r
.84582 .42746 .85065 .42973 .86311 .42012 .85833 .41754 Mtetra
.816 .956 .907 r
.85833 .41754 .86311 .42012 .8756 .4106 .87085 .40771 Mtetra
.815 .948 .909 r
.87085 .40771 .8756 .4106 .88812 .40118 .88341 .39798 Mtetra
.813 .94 .911 r
.88341 .39798 .88812 .40118 .90066 .39189 .89599 .38838 Mtetra
.81 .931 .912 r
.89599 .38838 .90066 .39189 .91324 .38273 .90861 .37893 Mtetra
.072 .557 .897 r
.30574 .56175 .31275 .56554 .32314 .56787 .31614 .56427 Mtetra
.024 .531 .87 r
.31614 .56427 .32314 .56787 .33361 .57039 .32661 .567 Mtetra
0 .504 .842 r
.32661 .567 .33361 .57039 .34414 .57307 .33716 .5699 Mtetra
0 .479 .812 r
.33716 .5699 .34414 .57307 .35475 .57589 .34778 .57295 Mtetra
0 .456 .782 r
.34778 .57295 .35475 .57589 .36544 .57881 .35848 .5761 Mtetra
0 .435 .753 r
.35848 .5761 .36544 .57881 .37621 .5818 .36926 .57933 Mtetra
0 .418 .726 r
.36926 .57933 .37621 .5818 .38706 .5848 .38014 .58258 Mtetra
0 .405 .701 r
.38014 .58258 .38706 .5848 .39801 .58779 .3911 .58581 Mtetra
.195 0 0 r
.3911 .58581 .39801 .58779 .40904 .59071 .40215 .58898 Mtetra
.203 0 0 r
.40215 .58898 .40904 .59071 .42017 .59351 .4133 .59203 Mtetra
.206 0 0 r
.4133 .59203 .42017 .59351 .43139 .59614 .42455 .59492 Mtetra
.202 0 0 r
.42455 .59492 .43139 .59614 .4427 .59857 .43589 .59759 Mtetra
.192 0 0 r
.43589 .59759 .4427 .59857 .45411 .60073 .44733 .59999 Mtetra
.176 0 0 r
.44733 .59999 .45411 .60073 .4656 .60258 .45886 .60207 Mtetra
.155 0 0 r
.45886 .60207 .4656 .60258 .47719 .60407 .47049 .60379 Mtetra
.128 0 0 r
.47049 .60379 .47719 .60407 .48887 .60515 .4822 .60509 Mtetra
.095 0 0 r
.4822 .60509 .48887 .60515 .50063 .6058 .49401 .60594 Mtetra
.057 0 0 r
.49401 .60594 .50063 .6058 .51247 .60597 .5059 .60629 Mtetra
.015 0 0 r
.5059 .60629 .51247 .60597 .52439 .60562 .51787 .60612 Mtetra
0 0 0 r
.51787 .60612 .52439 .60562 .53638 .60473 .52991 .60538 Mtetra
.082 .641 .71 r
.52991 .60538 .53638 .60473 .54844 .60328 .54203 .60407 Mtetra
.136 .681 .729 r
.54203 .60407 .54844 .60328 .56056 .60125 .55421 .60215 Mtetra
.191 .721 .747 r
.55421 .60215 .56056 .60125 .57273 .59863 .56645 .59962 Mtetra
.247 .759 .765 r
.56645 .59962 .57273 .59863 .58496 .59541 .57874 .59647 Mtetra
.303 .795 .782 r
.57874 .59647 .58496 .59541 .59723 .5916 .59107 .5927 Mtetra
.357 .829 .798 r
.59107 .5927 .59723 .5916 .60954 .5872 .60345 .58831 Mtetra
.41 .86 .812 r
.60345 .58831 .60954 .5872 .62188 .58221 .61586 .58333 Mtetra
.46 .887 .824 r
.61586 .58333 .62188 .58221 .63424 .57667 .62829 .57775 Mtetra
.506 .91 .834 r
.62829 .57775 .63424 .57667 .64664 .57058 .64075 .57162 Mtetra
.549 .93 .843 r
.64075 .57162 .64664 .57058 .65904 .56398 .65323 .56494 Mtetra
.589 .947 .85 r
.65323 .56494 .65904 .56398 .67146 .5569 .66573 .55775 Mtetra
.624 .961 .857 r
.66573 .55775 .67146 .5569 .6839 .54936 .67823 .55009 Mtetra
.656 .971 .862 r
.67823 .55009 .6839 .54936 .69634 .5414 .69074 .54199 Mtetra
.685 .98 .866 r
.69074 .54199 .69634 .5414 .70878 .53307 .70325 .53349 Mtetra
.71 .986 .87 r
.70325 .53349 .70878 .53307 .72122 .52439 .71576 .52462 Mtetra
.731 .99 .874 r
.71576 .52462 .72122 .52439 .73367 .51541 .72827 .51544 Mtetra
.75 .992 .877 r
.72827 .51544 .73367 .51541 .74612 .50617 .74078 .50597 Mtetra
.767 .993 .88 r
.74078 .50597 .74612 .50617 .75857 .49671 .75329 .49627 Mtetra
.78 .992 .882 r
.75329 .49627 .75857 .49671 .77101 .48706 .7658 .48638 Mtetra
.792 .99 .885 r
.7658 .48638 .77101 .48706 .78346 .47728 .77831 .47632 Mtetra
.801 .987 .888 r
.77831 .47632 .78346 .47728 .79592 .46738 .79082 .46616 Mtetra
.809 .984 .89 r
.79082 .46616 .79592 .46738 .80838 .45742 .80334 .45591 Mtetra
.815 .979 .893 r
.80334 .45591 .80838 .45742 .82085 .44743 .81585 .44562 Mtetra
.819 .973 .895 r
.81585 .44562 .82085 .44743 .83332 .43743 .82838 .43533 Mtetra
.822 .967 .898 r
.82838 .43533 .83332 .43743 .84582 .42746 .84092 .42506 Mtetra
.823 .961 .9 r
.84092 .42506 .84582 .42746 .85833 .41754 .85348 .41484 Mtetra
.823 .953 .902 r
.85348 .41484 .85833 .41754 .87085 .40771 .86605 .4047 Mtetra
.822 .946 .904 r
.86605 .4047 .87085 .40771 .88341 .39798 .87864 .39468 Mtetra
.82 .937 .906 r
.87864 .39468 .88341 .39798 .89599 .38838 .89126 .38478 Mtetra
.817 .929 .907 r
.89126 .38478 .89599 .38838 .90861 .37893 .90392 .37502 Mtetra
.065 .546 .895 r
.29868 .55774 .30574 .56175 .31614 .56427 .30909 .56045 Mtetra
.018 .52 .869 r
.30909 .56045 .31614 .56427 .32661 .567 .31957 .56337 Mtetra
0 .494 .843 r
.31957 .56337 .32661 .567 .33716 .5699 .33012 .56648 Mtetra
0 .47 .815 r
.33012 .56648 .33716 .5699 .34778 .57295 .34075 .56974 Mtetra
0 .448 .787 r
.34075 .56974 .34778 .57295 .35848 .5761 .35146 .57311 Mtetra
0 .428 .76 r
.35146 .57311 .35848 .5761 .36926 .57933 .36226 .57656 Mtetra
0 .413 .736 r
.36226 .57656 .36926 .57933 .38014 .58258 .37315 .58004 Mtetra
0 .401 .714 r
.37315 .58004 .38014 .58258 .3911 .58581 .38413 .58351 Mtetra
0 .394 .696 r
.38413 .58351 .3911 .58581 .40215 .58898 .3952 .58691 Mtetra
0 .392 .681 r
.3952 .58691 .40215 .58898 .4133 .59203 .40638 .5902 Mtetra
.198 0 0 r
.40638 .5902 .4133 .59203 .42455 .59492 .41765 .59333 Mtetra
.192 0 0 r
.41765 .59333 .42455 .59492 .43589 .59759 .42901 .59623 Mtetra
.181 0 0 r
.42901 .59623 .43589 .59759 .44733 .59999 .44048 .59886 Mtetra
.163 0 0 r
.44048 .59886 .44733 .59999 .45886 .60207 .45205 .60117 Mtetra
.139 0 0 r
.45205 .60117 .45886 .60207 .47049 .60379 .46371 .6031 Mtetra
.109 0 0 r
.46371 .6031 .47049 .60379 .4822 .60509 .47547 .60461 Mtetra
.074 0 0 r
.47547 .60461 .4822 .60509 .49401 .60594 .48732 .60566 Mtetra
.034 0 0 r
.48732 .60566 .49401 .60594 .5059 .60629 .49925 .60619 Mtetra
.012 .587 .721 r
.49925 .60619 .5059 .60629 .51787 .60612 .51127 .60618 Mtetra
.062 .627 .739 r
.51127 .60618 .51787 .60612 .52991 .60538 .52337 .6056 Mtetra
.115 .667 .758 r
.52337 .6056 .52991 .60538 .54203 .60407 .53554 .60442 Mtetra
.171 .708 .777 r
.53554 .60442 .54203 .60407 .55421 .60215 .54778 .60262 Mtetra
.228 .748 .795 r
.54778 .60262 .55421 .60215 .56645 .59962 .56007 .60018 Mtetra
.285 .786 .812 r
.56007 .60018 .56645 .59962 .57874 .59647 .57243 .5971 Mtetra
.342 .822 .827 r
.57243 .5971 .57874 .59647 .59107 .5927 .58483 .59339 Mtetra
.397 .854 .84 r
.58483 .59339 .59107 .5927 .60345 .58831 .59727 .58903 Mtetra
.449 .882 .851 r
.59727 .58903 .60345 .58831 .61586 .58333 .60975 .58405 Mtetra
.498 .907 .86 r
.60975 .58405 .61586 .58333 .62829 .57775 .62225 .57846 Mtetra
.543 .928 .867 r
.62225 .57846 .62829 .57775 .64075 .57162 .63478 .57227 Mtetra
.584 .945 .872 r
.63478 .57227 .64075 .57162 .65323 .56494 .64733 .56553 Mtetra
.621 .959 .876 r
.64733 .56553 .65323 .56494 .66573 .55775 .6599 .55826 Mtetra
.654 .97 .879 r
.6599 .55826 .66573 .55775 .67823 .55009 .67247 .55048 Mtetra
.683 .979 .88 r
.67247 .55048 .67823 .55009 .69074 .54199 .68505 .54225 Mtetra
.709 .985 .882 r
.68505 .54225 .69074 .54199 .70325 .53349 .69763 .53359 Mtetra
.732 .989 .883 r
.69763 .53359 .70325 .53349 .71576 .52462 .71021 .52456 Mtetra
.751 .991 .884 r
.71021 .52456 .71576 .52462 .72827 .51544 .72279 .51518 Mtetra
.768 .992 .884 r
.72279 .51518 .72827 .51544 .74078 .50597 .73537 .50551 Mtetra
.783 .991 .885 r
.73537 .50551 .74078 .50597 .75329 .49627 .74794 .49558 Mtetra
.795 .989 .886 r
.74794 .49558 .75329 .49627 .7658 .48638 .76051 .48544 Mtetra
.805 .987 .887 r
.76051 .48544 .7658 .48638 .77831 .47632 .77308 .47514 Mtetra
.813 .983 .888 r
.77308 .47514 .77831 .47632 .79082 .46616 .78565 .46471 Mtetra
.819 .979 .889 r
.78565 .46471 .79082 .46616 .80334 .45591 .79822 .45419 Mtetra
.824 .974 .891 r
.79822 .45419 .80334 .45591 .81585 .44562 .81079 .44362 Mtetra
.827 .969 .893 r
.81079 .44362 .81585 .44562 .82838 .43533 .82337 .43304 Mtetra
.829 .963 .894 r
.82337 .43304 .82838 .43533 .84092 .42506 .83596 .42248 Mtetra
.83 .956 .896 r
.83596 .42248 .84092 .42506 .85348 .41484 .84856 .41197 Mtetra
.83 .949 .898 r
.84856 .41197 .85348 .41484 .86605 .4047 .86117 .40154 Mtetra
.828 .942 .899 r
.86117 .40154 .86605 .4047 .87864 .39468 .87381 .39122 Mtetra
.826 .934 .901 r
.87381 .39122 .87864 .39468 .89126 .38478 .88647 .38103 Mtetra
.823 .926 .903 r
.88647 .38103 .89126 .38478 .90392 .37502 .89916 .37098 Mtetra
.062 .537 .894 r
.29157 .5535 .29868 .55774 .30909 .56045 .30199 .55638 Mtetra
.016 .511 .871 r
.30199 .55638 .30909 .56045 .31957 .56337 .31247 .55948 Mtetra
0 .487 .846 r
.31247 .55948 .31957 .56337 .33012 .56648 .32303 .56277 Mtetra
0 .464 .82 r
.32303 .56277 .33012 .56648 .34075 .56974 .33367 .56622 Mtetra
0 .443 .795 r
.33367 .56622 .34075 .56974 .35146 .57311 .3444 .5698 Mtetra
0 .425 .772 r
.3444 .5698 .35146 .57311 .36226 .57656 .35521 .57346 Mtetra
0 .411 .75 r
.35521 .57346 .36226 .57656 .37315 .58004 .36611 .57715 Mtetra
0 .402 .731 r
.36611 .57715 .37315 .58004 .38413 .58351 .3771 .58083 Mtetra
0 .397 .716 r
.3771 .58083 .38413 .58351 .3952 .58691 .3882 .58446 Mtetra
0 .397 .705 r
.3882 .58446 .3952 .58691 .40638 .5902 .39939 .58797 Mtetra
0 .402 .697 r
.39939 .58797 .40638 .5902 .41765 .59333 .41068 .59132 Mtetra
0 .412 .694 r
.41068 .59132 .41765 .59333 .42901 .59623 .42208 .59444 Mtetra
0 .427 .695 r
.42208 .59444 .42901 .59623 .44048 .59886 .43357 .59729 Mtetra
0 .447 .7 r
.43357 .59729 .44048 .59886 .45205 .60117 .44517 .59981 Mtetra
0 .472 .709 r
.44517 .59981 .45205 .60117 .46371 .6031 .45687 .60195 Mtetra
0 .502 .721 r
.45687 .60195 .46371 .6031 .47547 .60461 .46866 .60365 Mtetra
0 .535 .735 r
.46866 .60365 .47547 .60461 .48732 .60566 .48055 .60489 Mtetra
0 .572 .753 r
.48055 .60489 .48732 .60566 .49925 .60619 .49253 .6056 Mtetra
.046 .612 .771 r
.49253 .6056 .49925 .60619 .51127 .60618 .5046 .60575 Mtetra
.098 .653 .791 r
.5046 .60575 .51127 .60618 .52337 .6056 .51675 .60532 Mtetra
.154 .695 .81 r
.51675 .60532 .52337 .6056 .53554 .60442 .52897 .60427 Mtetra
.212 .736 .829 r
.52897 .60427 .53554 .60442 .54778 .60262 .54126 .60258 Mtetra
.271 .776 .846 r
.54126 .60258 .54778 .60262 .56007 .60018 .55362 .60024 Mtetra
.329 .813 .861 r
.55362 .60024 .56007 .60018 .57243 .5971 .56603 .59724 Mtetra
.385 .846 .873 r
.56603 .59724 .57243 .5971 .58483 .59339 .5785 .59358 Mtetra
.439 .876 .883 r
.5785 .59358 .58483 .59339 .59727 .58903 .591 .58926 Mtetra
.49 .902 .89 r
.591 .58926 .59727 .58903 .60975 .58405 .60355 .58429 Mtetra
.537 .924 .896 r
.60355 .58429 .60975 .58405 .62225 .57846 .61612 .57869 Mtetra
.58 .942 .899 r
.61612 .57869 .62225 .57846 .63478 .57227 .62872 .57248 Mtetra
.618 .956 .9 r
.62872 .57248 .63478 .57227 .64733 .56553 .64134 .56568 Mtetra
.652 .968 .9 r
.64134 .56568 .64733 .56553 .6599 .55826 .65398 .55833 Mtetra
.683 .976 .899 r
.65398 .55833 .6599 .55826 .67247 .55048 .66662 .55046 Mtetra
.709 .982 .898 r
.66662 .55046 .67247 .55048 .68505 .54225 .67927 .54211 Mtetra
.733 .986 .896 r
.67927 .54211 .68505 .54225 .69763 .53359 .69192 .53332 Mtetra
.753 .988 .895 r
.69192 .53332 .69763 .53359 .71021 .52456 .70457 .52412 Mtetra
.77 .989 .893 r
.70457 .52412 .71021 .52456 .72279 .51518 .71722 .51457 Mtetra
.785 .988 .891 r
.71722 .51457 .72279 .51518 .73537 .50551 .72986 .5047 Mtetra
.798 .987 .89 r
.72986 .5047 .73537 .50551 .74794 .49558 .7425 .49457 Mtetra
.808 .985 .889 r
.7425 .49457 .74794 .49558 .76051 .48544 .75513 .48421 Mtetra
.817 .981 .889 r
.75513 .48421 .76051 .48544 .77308 .47514 .76776 .47367 Mtetra
.823 .978 .889 r
.76776 .47367 .77308 .47514 .78565 .46471 .78039 .46299 Mtetra
.829 .973 .889 r
.78039 .46299 .78565 .46471 .79822 .45419 .79302 .45221 Mtetra
.833 .968 .889 r
.79302 .45221 .79822 .45419 .81079 .44362 .80565 .44138 Mtetra
.835 .963 .89 r
.80565 .44138 .81079 .44362 .82337 .43304 .81828 .43052 Mtetra
.837 .957 .891 r
.81828 .43052 .82337 .43304 .83596 .42248 .83092 .41968 Mtetra
.837 .95 .892 r
.83092 .41968 .83596 .42248 .84856 .41197 .84356 .40889 Mtetra
.836 .944 .893 r
.84356 .40889 .84856 .41197 .86117 .40154 .85623 .39818 Mtetra
.834 .937 .895 r
.85623 .39818 .86117 .40154 .87381 .39122 .86891 .38757 Mtetra
.831 .929 .896 r
.86891 .38757 .87381 .39122 .88647 .38103 .88161 .3771 Mtetra
.828 .922 .898 r
.88161 .3771 .88647 .38103 .89916 .37098 .89434 .36678 Mtetra
.063 .53 .896 r
.28441 .54901 .29157 .5535 .30199 .55638 .29483 .55204 Mtetra
.019 .505 .874 r
.29483 .55204 .30199 .55638 .31247 .55948 .30533 .5553 Mtetra
0 .482 .851 r
.30533 .5553 .31247 .55948 .32303 .56277 .3159 .55876 Mtetra
0 .46 .828 r
.3159 .55876 .32303 .56277 .33367 .56622 .32655 .56238 Mtetra
0 .441 .806 r
.32655 .56238 .33367 .56622 .3444 .5698 .33728 .56614 Mtetra
0 .425 .786 r
.33728 .56614 .3444 .5698 .35521 .57346 .3481 .56998 Mtetra
0 .413 .767 r
.3481 .56998 .35521 .57346 .36611 .57715 .35902 .57387 Mtetra
0 .405 .752 r
.35902 .57387 .36611 .57715 .3771 .58083 .37003 .57775 Mtetra
0 .402 .74 r
.37003 .57775 .3771 .58083 .3882 .58446 .38114 .58158 Mtetra
0 .404 .732 r
.38114 .58158 .3882 .58446 .39939 .58797 .39235 .58529 Mtetra
0 .411 .728 r
.39235 .58529 .39939 .58797 .41068 .59132 .40366 .58884 Mtetra
0 .424 .729 r
.40366 .58884 .41068 .59132 .42208 .59444 .41508 .59217 Mtetra
0 .441 .733 r
.41508 .59217 .42208 .59444 .43357 .59729 .4266 .59522 Mtetra
0 .463 .741 r
.4266 .59522 .43357 .59729 .44517 .59981 .43823 .59793 Mtetra
0 .491 .752 r
.43823 .59793 .44517 .59981 .45687 .60195 .44996 .60026 Mtetra
0 .522 .767 r
.44996 .60026 .45687 .60195 .46866 .60365 .46179 .60216 Mtetra
0 .558 .784 r
.46179 .60216 .46866 .60365 .48055 .60489 .47372 .60357 Mtetra
.036 .596 .803 r
.47372 .60357 .48055 .60489 .49253 .6056 .48574 .60445 Mtetra
.087 .637 .823 r
.48574 .60445 .49253 .6056 .5046 .60575 .49785 .60476 Mtetra
.141 .679 .843 r
.49785 .60476 .5046 .60575 .51675 .60532 .51005 .60447 Mtetra
.199 .721 .862 r
.51005 .60447 .51675 .60532 .52897 .60427 .52232 .60355 Mtetra
.258 .761 .88 r
.52232 .60355 .52897 .60427 .54126 .60258 .53467 .60198 Mtetra
.317 .8 .895 r
.53467 .60198 .54126 .60258 .55362 .60024 .54708 .59974 Mtetra
.375 .835 .907 r
.54708 .59974 .55362 .60024 .56603 .59724 .55955 .59682 Mtetra
.43 .866 .916 r
.55955 .59682 .56603 .59724 .5785 .59358 .57208 .59322 Mtetra
.482 .893 .922 r
.57208 .59322 .5785 .59358 .591 .58926 .58465 .58894 Mtetra
.531 .916 .926 r
.58465 .58894 .591 .58926 .60355 .58429 .59726 .58399 Mtetra
.575 .935 .927 r
.59726 .58399 .60355 .58429 .61612 .57869 .6099 .57839 Mtetra
.615 .95 .926 r
.6099 .57839 .61612 .57869 .62872 .57248 .62257 .57216 Mtetra
.65 .962 .924 r
.62257 .57216 .62872 .57248 .64134 .56568 .63526 .56532 Mtetra
.682 .97 .921 r
.63526 .56532 .64134 .56568 .65398 .55833 .64796 .55791 Mtetra
.709 .977 .917 r
.64796 .55791 .65398 .55833 .66662 .55046 .66068 .54996 Mtetra
.733 .981 .913 r
.66068 .54996 .66662 .55046 .67927 .54211 .6734 .5415 Mtetra
.754 .983 .909 r
.6734 .5415 .67927 .54211 .69192 .53332 .68612 .53259 Mtetra
.772 .984 .904 r
.68612 .53259 .69192 .53332 .70457 .52412 .69884 .52325 Mtetra
.787 .983 .901 r
.69884 .52325 .70457 .52412 .71722 .51457 .71155 .51354 Mtetra
.8 .982 .897 r
.71155 .51354 .71722 .51457 .72986 .5047 .72426 .5035 Mtetra
.811 .98 .894 r
.72426 .5035 .72986 .5047 .7425 .49457 .73697 .49317 Mtetra
.82 .977 .892 r
.73697 .49317 .7425 .49457 .75513 .48421 .74967 .4826 Mtetra
.827 .973 .89 r
.74967 .4826 .75513 .48421 .76776 .47367 .76236 .47184 Mtetra
.833 .969 .888 r
.76236 .47184 .76776 .47367 .78039 .46299 .77505 .46093 Mtetra
.837 .965 .888 r
.77505 .46093 .78039 .46299 .79302 .45221 .78773 .44991 Mtetra
.84 .96 .887 r
.78773 .44991 .79302 .45221 .80565 .44138 .80042 .43883 Mtetra
.842 .955 .887 r
.80042 .43883 .80565 .44138 .81828 .43052 .8131 .42772 Mtetra
.843 .949 .887 r
.8131 .42772 .81828 .43052 .83092 .41968 .82579 .41662 Mtetra
.842 .943 .888 r
.82579 .41662 .83092 .41968 .84356 .40889 .83849 .40556 Mtetra
.841 .937 .889 r
.83849 .40556 .84356 .40889 .85623 .39818 .85121 .39458 Mtetra
.839 .93 .89 r
.85121 .39458 .85623 .39818 .86891 .38757 .86393 .3837 Mtetra
.836 .923 .891 r
.86393 .3837 .86891 .38757 .88161 .3771 .87668 .37295 Mtetra
.832 .916 .893 r
.87668 .37295 .88161 .3771 .89434 .36678 .88946 .36236 Mtetra
.069 .525 .898 r
.27721 .54424 .28441 .54901 .29483 .55204 .28764 .5474 Mtetra
.027 .501 .879 r
.28764 .5474 .29483 .55204 .30533 .5553 .29814 .5508 Mtetra
0 .479 .858 r
.29814 .5508 .30533 .5553 .3159 .55876 .30872 .5544 Mtetra
0 .459 .838 r
.30872 .5544 .3159 .55876 .32655 .56238 .31937 .55818 Mtetra
0 .441 .819 r
.31937 .55818 .32655 .56238 .33728 .56614 .33012 .5621 Mtetra
0 .427 .802 r
.33012 .5621 .33728 .56614 .3481 .56998 .34095 .56611 Mtetra
0 .417 .787 r
.34095 .56611 .3481 .56998 .35902 .57387 .35187 .57017 Mtetra
0 .411 .775 r
.35187 .57017 .35902 .57387 .37003 .57775 .3629 .57422 Mtetra
0 .41 .766 r
.3629 .57422 .37003 .57775 .38114 .58158 .37402 .57823 Mtetra
0 .414 .762 r
.37402 .57823 .38114 .58158 .39235 .58529 .38525 .58212 Mtetra
0 .423 .761 r
.38525 .58212 .39235 .58529 .40366 .58884 .39658 .58585 Mtetra
0 .437 .765 r
.39658 .58585 .40366 .58884 .41508 .59217 .40802 .58936 Mtetra
0 .457 .772 r
.40802 .58936 .41508 .59217 .4266 .59522 .41957 .5926 Mtetra
0 .481 .783 r
.41957 .5926 .4266 .59522 .43823 .59793 .43123 .59549 Mtetra
0 .51 .797 r
.43123 .59549 .43823 .59793 .44996 .60026 .44299 .598 Mtetra
0 .543 .814 r
.44299 .598 .44996 .60026 .46179 .60216 .45485 .60006 Mtetra
.031 .58 .833 r
.45485 .60006 .46179 .60216 .47372 .60357 .46681 .60164 Mtetra
.079 .619 .853 r
.46681 .60164 .47372 .60357 .48574 .60445 .47888 .60268 Mtetra
.132 .66 .873 r
.47888 .60268 .48574 .60445 .49785 .60476 .49103 .60314 Mtetra
.188 .702 .892 r
.49103 .60314 .49785 .60476 .51005 .60447 .50327 .60299 Mtetra
.247 .742 .91 r
.50327 .60299 .51005 .60447 .52232 .60355 .51559 .60219 Mtetra
.305 .781 .925 r
.51559 .60219 .52232 .60355 .53467 .60198 .52799 .60073 Mtetra
.364 .817 .937 r
.52799 .60073 .53467 .60198 .54708 .59974 .54046 .59859 Mtetra
.42 .849 .946 r
.54046 .59859 .54708 .59974 .55955 .59682 .55299 .59575 Mtetra
.473 .878 .952 r
.55299 .59575 .55955 .59682 .57208 .59322 .56558 .59221 Mtetra
.523 .902 .955 r
.56558 .59221 .57208 .59322 .58465 .58894 .57821 .58798 Mtetra
.568 .922 .955 r
.57821 .58798 .58465 .58894 .59726 .58399 .59088 .58307 Mtetra
.609 .938 .952 r
.59088 .58307 .59726 .58399 .6099 .57839 .60359 .57748 Mtetra
.646 .95 .948 r
.60359 .57748 .6099 .57839 .62257 .57216 .61633 .57124 Mtetra
.678 .96 .943 r
.61633 .57124 .62257 .57216 .63526 .56532 .62908 .56438 Mtetra
.707 .967 .937 r
.62908 .56438 .63526 .56532 .64796 .55791 .64186 .55692 Mtetra
.732 .971 .93 r
.64186 .55692 .64796 .55791 .66068 .54996 .65464 .5489 Mtetra
.753 .974 .924 r
.65464 .5489 .66068 .54996 .6734 .5415 .66743 .54036 Mtetra
.771 .975 .917 r
.66743 .54036 .6734 .5415 .68612 .53259 .68022 .53134 Mtetra
.787 .975 .911 r
.68022 .53134 .68612 .53259 .69884 .52325 .69301 .52188 Mtetra
.8 .974 .906 r
.69301 .52188 .69884 .52325 .71155 .51354 .70579 .51202 Mtetra
.812 .972 .901 r
.70579 .51202 .71155 .51354 .72426 .5035 .71857 .50182 Mtetra
.821 .97 .897 r
.71857 .50182 .72426 .5035 .73697 .49317 .73134 .49132 Mtetra
.829 .966 .893 r
.73134 .49132 .73697 .49317 .74967 .4826 .74411 .48057 Mtetra
.835 .963 .89 r
.74411 .48057 .74967 .4826 .76236 .47184 .75686 .46961 Mtetra
.84 .959 .888 r
.75686 .46961 .76236 .47184 .77505 .46093 .76961 .45849 Mtetra
.843 .955 .886 r
.76961 .45849 .77505 .46093 .78773 .44991 .78236 .44725 Mtetra
.846 .95 .885 r
.78236 .44725 .78773 .44991 .80042 .43883 .7951 .43593 Mtetra
.847 .945 .884 r
.7951 .43593 .80042 .43883 .8131 .42772 .80784 .42458 Mtetra
.847 .94 .884 r
.80784 .42458 .8131 .42772 .82579 .41662 .82059 .41323 Mtetra
.847 .934 .884 r
.82059 .41323 .82579 .41662 .83849 .40556 .83334 .40192 Mtetra
.845 .928 .884 r
.83334 .40192 .83849 .40556 .85121 .39458 .8461 .39069 Mtetra
.843 .922 .885 r
.8461 .39069 .85121 .39458 .86393 .3837 .85888 .37956 Mtetra
.84 .916 .886 r
.85888 .37956 .86393 .3837 .87668 .37295 .87168 .36856 Mtetra
.836 .909 .887 r
.87168 .36856 .87668 .37295 .88946 .36236 .88449 .35771 Mtetra
.078 .522 .902 r
.26996 .53918 .27721 .54424 .28764 .5474 .2804 .54245 Mtetra
.038 .5 .884 r
.2804 .54245 .28764 .5474 .29814 .5508 .29091 .54596 Mtetra
.002 .479 .867 r
.29091 .54596 .29814 .5508 .30872 .5544 .30149 .54969 Mtetra
0 .46 .849 r
.30149 .54969 .30872 .5544 .31937 .55818 .31216 .5536 Mtetra
0 .444 .833 r
.31216 .5536 .31937 .55818 .33012 .5621 .32291 .55765 Mtetra
0 .432 .819 r
.32291 .55765 .33012 .5621 .34095 .56611 .33375 .5618 Mtetra
0 .423 .807 r
.33375 .5618 .34095 .56611 .35187 .57017 .34469 .56601 Mtetra
0 .419 .798 r
.34469 .56601 .35187 .57017 .3629 .57422 .35572 .57022 Mtetra
0 .42 .793 r
.35572 .57022 .3629 .57422 .37402 .57823 .36686 .57437 Mtetra
0 .426 .792 r
.36686 .57437 .37402 .57823 .38525 .58212 .3781 .57843 Mtetra
0 .436 .794 r
.3781 .57843 .38525 .58212 .39658 .58585 .38946 .58232 Mtetra
0 .452 .8 r
.38946 .58232 .39658 .58585 .40802 .58936 .40092 .58599 Mtetra
0 .473 .81 r
.40092 .58599 .40802 .58936 .41957 .5926 .41249 .58938 Mtetra
0 .499 .823 r
.41249 .58938 .41957 .5926 .43123 .59549 .42417 .59244 Mtetra
0 .529 .839 r
.42417 .59244 .43123 .59549 .44299 .598 .43595 .5951 Mtetra
.032 .562 .857 r
.43595 .5951 .44299 .598 .45485 .60006 .44785 .59732 Mtetra
.077 .599 .877 r
.44785 .59732 .45485 .60006 .46681 .60164 .45985 .59905 Mtetra
.127 .638 .896 r
.45985 .59905 .46681 .60164 .47888 .60268 .47195 .60023 Mtetra
.181 .678 .916 r
.47195 .60023 .47888 .60268 .49103 .60314 .48414 .60083 Mtetra
.237 .718 .933 r
.48414 .60083 .49103 .60314 .50327 .60299 .49642 .6008 Mtetra
.295 .756 .949 r
.49642 .6008 .50327 .60299 .51559 .60219 .50879 .60013 Mtetra
.352 .793 .961 r
.50879 .60013 .51559 .60219 .52799 .60073 .52124 .59878 Mtetra
.408 .826 .97 r
.52124 .59878 .52799 .60073 .54046 .59859 .53376 .59673 Mtetra
.462 .855 .976 r
.53376 .59673 .54046 .59859 .55299 .59575 .54635 .59398 Mtetra
.512 .88 .978 r
.54635 .59398 .55299 .59575 .56558 .59221 .55899 .59051 Mtetra
.559 .901 .977 r
.55899 .59051 .56558 .59221 .57821 .58798 .57168 .58633 Mtetra
.601 .919 .974 r
.57168 .58633 .57821 .58798 .59088 .58307 .58442 .58145 Mtetra
.638 .932 .969 r
.58442 .58145 .59088 .58307 .60359 .57748 .59719 .57589 Mtetra
.672 .943 .962 r
.59719 .57589 .60359 .57748 .61633 .57124 .60999 .56965 Mtetra
.701 .951 .955 r
.60999 .56965 .61633 .57124 .62908 .56438 .62282 .56277 Mtetra
.727 .956 .947 r
.62282 .56277 .62908 .56438 .64186 .55692 .63566 .55528 Mtetra
.749 .96 .938 r
.63566 .55528 .64186 .55692 .65464 .5489 .64851 .54721 Mtetra
.768 .961 .93 r
.64851 .54721 .65464 .5489 .66743 .54036 .66136 .5386 Mtetra
.785 .962 .922 r
.66136 .5386 .66743 .54036 .68022 .53134 .67422 .52949 Mtetra
.799 .962 .915 r
.67422 .52949 .68022 .53134 .69301 .52188 .68708 .51993 Mtetra
.811 .961 .908 r
.68708 .51993 .69301 .52188 .70579 .51202 .69994 .50996 Mtetra
.82 .959 .902 r
.69994 .50996 .70579 .51202 .71857 .50182 .71278 .49962 Mtetra
.829 .956 .897 r
.71278 .49962 .71857 .50182 .73134 .49132 .72562 .48897 Mtetra
.835 .953 .893 r
.72562 .48897 .73134 .49132 .74411 .48057 .73845 .47805 Mtetra
.841 .95 .889 r
.73845 .47805 .74411 .48057 .75686 .46961 .75127 .46691 Mtetra
.845 .946 .886 r
.75127 .46691 .75686 .46961 .76961 .45849 .76409 .4556 Mtetra
.848 .942 .883 r
.76409 .4556 .76961 .45849 .78236 .44725 .77689 .44416 Mtetra
.85 .938 .881 r
.77689 .44416 .78236 .44725 .7951 .43593 .7897 .43263 Mtetra
.851 .934 .88 r
.7897 .43263 .7951 .43593 .80784 .42458 .8025 .42106 Mtetra
.85 .929 .88 r
.8025 .42106 .80784 .42458 .82059 .41323 .8153 .40948 Mtetra
.85 .924 .879 r
.8153 .40948 .82059 .41323 .83334 .40192 .8281 .39794 Mtetra
.848 .918 .88 r
.8281 .39794 .83334 .40192 .8461 .39069 .84092 .38647 Mtetra
.845 .913 .88 r
.84092 .38647 .8461 .39069 .85888 .37956 .85374 .37511 Mtetra
.842 .907 .881 r
.85374 .37511 .85888 .37956 .87168 .36856 .86659 .36387 Mtetra
.838 .901 .882 r
.86659 .36387 .87168 .36856 .88449 .35771 .87945 .35279 Mtetra
.09 .52 .906 r
.26268 .53381 .26996 .53918 .2804 .54245 .27312 .53716 Mtetra
.053 .499 .891 r
.27312 .53716 .2804 .54245 .29091 .54596 .28364 .54077 Mtetra
.019 .48 .875 r
.28364 .54077 .29091 .54596 .30149 .54969 .29423 .5446 Mtetra
0 .463 .861 r
.29423 .5446 .30149 .54969 .31216 .5536 .3049 .54861 Mtetra
0 .449 .847 r
.3049 .54861 .31216 .5536 .32291 .55765 .31566 .55277 Mtetra
0 .438 .836 r
.31566 .55277 .32291 .55765 .33375 .5618 .32651 .55704 Mtetra
0 .431 .827 r
.32651 .55704 .33375 .5618 .34469 .56601 .33746 .56136 Mtetra
0 .429 .821 r
.33746 .56136 .34469 .56601 .35572 .57022 .3485 .5657 Mtetra
0 .431 .819 r
.3485 .5657 .35572 .57022 .36686 .57437 .35965 .56998 Mtetra
0 .438 .82 r
.35965 .56998 .36686 .57437 .3781 .57843 .37091 .57417 Mtetra
0 .45 .825 r
.37091 .57417 .3781 .57843 .38946 .58232 .38228 .57819 Mtetra
0 .467 .833 r
.38228 .57819 .38946 .58232 .40092 .58599 .39376 .582 Mtetra
0 .488 .845 r
.39376 .582 .40092 .58599 .41249 .58938 .40535 .58553 Mtetra
.003 .515 .859 r
.40535 .58553 .41249 .58938 .42417 .59244 .41705 .58873 Mtetra
.038 .545 .876 r
.41705 .58873 .42417 .59244 .43595 .5951 .42887 .59153 Mtetra
.08 .578 .894 r
.42887 .59153 .43595 .5951 .44785 .59732 .44079 .59389 Mtetra
.126 .614 .913 r
.44079 .59389 .44785 .59732 .45985 .59905 .45282 .59574 Mtetra
.176 .651 .931 r
.45282 .59574 .45985 .59905 .47195 .60023 .46495 .59706 Mtetra
.23 .689 .948 r
.46495 .59706 .47195 .60023 .48414 .60083 .47719 .59778 Mtetra
.285 .726 .964 r
.47719 .59778 .48414 .60083 .49642 .6008 .48951 .59787 Mtetra
.34 .762 .976 r
.48951 .59787 .49642 .6008 .50879 .60013 .50192 .59731 Mtetra
.395 .795 .985 r
.50192 .59731 .50879 .60013 .52124 .59878 .51442 .59606 Mtetra
.448 .824 .991 r
.51442 .59606 .52124 .59878 .53376 .59673 .52699 .59411 Mtetra
.498 .851 .993 r
.52699 .59411 .53376 .59673 .54635 .59398 .53962 .59143 Mtetra
.545 .873 .993 r
.53962 .59143 .54635 .59398 .55899 .59051 .55232 .58804 Mtetra
.588 .891 .989 r
.55232 .58804 .55899 .59051 .57168 .58633 .56507 .58392 Mtetra
.626 .907 .984 r
.56507 .58392 .57168 .58633 .58442 .58145 .57787 .57908 Mtetra
.661 .918 .977 r
.57787 .57908 .58442 .58145 .59719 .57589 .5907 .57355 Mtetra
.691 .928 .968 r
.5907 .57355 .59719 .57589 .60999 .56965 .60356 .56733 Mtetra
.718 .934 .959 r
.60356 .56733 .60999 .56965 .62282 .56277 .61645 .56045 Mtetra
.741 .939 .95 r
.61645 .56045 .62282 .56277 .63566 .55528 .62936 .55294 Mtetra
.761 .942 .941 r
.62936 .55294 .63566 .55528 .64851 .54721 .64228 .54483 Mtetra
.778 .944 .932 r
.64228 .54483 .64851 .54721 .66136 .5386 .6552 .53617 Mtetra
.793 .945 .923 r
.6552 .53617 .66136 .5386 .67422 .52949 .66813 .527 Mtetra
.806 .944 .915 r
.66813 .527 .67422 .52949 .68708 .51993 .68106 .51735 Mtetra
.817 .943 .908 r
.68106 .51735 .68708 .51993 .69994 .50996 .69398 .50728 Mtetra
.826 .942 .901 r
.69398 .50728 .69994 .50996 .71278 .49962 .7069 .49683 Mtetra
.833 .94 .895 r
.7069 .49683 .71278 .49962 .72562 .48897 .7198 .48605 Mtetra
.839 .937 .89 r
.7198 .48605 .72562 .48897 .73845 .47805 .7327 .47499 Mtetra
.844 .935 .886 r
.7327 .47499 .73845 .47805 .75127 .46691 .74558 .46369 Mtetra
.848 .931 .883 r
.74558 .46369 .75127 .46691 .76409 .4556 .75846 .45221 Mtetra
.85 .928 .88 r
.75846 .45221 .76409 .4556 .77689 .44416 .77133 .44059 Mtetra
.852 .924 .877 r
.77133 .44059 .77689 .44416 .7897 .43263 .7842 .42887 Mtetra
.852 .921 .876 r
.7842 .42887 .7897 .43263 .8025 .42106 .79705 .4171 Mtetra
.852 .916 .875 r
.79705 .4171 .8025 .42106 .8153 .40948 .80991 .40533 Mtetra
.851 .912 .875 r
.80991 .40533 .8153 .40948 .8281 .39794 .82278 .39358 Mtetra
.849 .907 .875 r
.82278 .39358 .8281 .39794 .84092 .38647 .83564 .38189 Mtetra
.847 .903 .875 r
.83564 .38189 .84092 .38647 .85374 .37511 .84852 .37031 Mtetra
.844 .898 .876 r
.84852 .37031 .85374 .37511 .86659 .36387 .86142 .35885 Mtetra
.84 .892 .877 r
.86142 .35885 .86659 .36387 .87945 .35279 .87433 .34755 Mtetra
.106 .52 .91 r
.25535 .52811 .26268 .53381 .27312 .53716 .2658 .53153 Mtetra
.072 .5 .897 r
.2658 .53153 .27312 .53716 .28364 .54077 .27632 .5352 Mtetra
.04 .482 .884 r
.27632 .5352 .28364 .54077 .29423 .5446 .28692 .5391 Mtetra
.013 .467 .872 r
.28692 .5391 .29423 .5446 .3049 .54861 .2976 .5432 Mtetra
0 .454 .861 r
.2976 .5432 .3049 .54861 .31566 .55277 .30837 .54744 Mtetra
0 .445 .852 r
.30837 .54744 .31566 .55277 .32651 .55704 .31923 .55179 Mtetra
0 .44 .846 r
.31923 .55179 .32651 .55704 .33746 .56136 .33019 .55621 Mtetra
0 .439 .843 r
.33019 .55621 .33746 .56136 .3485 .5657 .34124 .56064 Mtetra
0 .442 .843 r
.34124 .56064 .3485 .5657 .35965 .56998 .35241 .56503 Mtetra
0 .45 .846 r
.35241 .56503 .35965 .56998 .37091 .57417 .36368 .56932 Mtetra
0 .463 .852 r
.36368 .56932 .37091 .57417 .38228 .57819 .37506 .57345 Mtetra
0 .48 .862 r
.37506 .57345 .38228 .57819 .39376 .582 .38656 .57737 Mtetra
.018 .502 .874 r
.38656 .57737 .39376 .582 .40535 .58553 .39817 .58101 Mtetra
.05 .528 .889 r
.39817 .58101 .40535 .58553 .41705 .58873 .40989 .58432 Mtetra
.086 .557 .905 r
.40989 .58432 .41705 .58873 .42887 .59153 .42173 .58724 Mtetra
.128 .589 .922 r
.42173 .58724 .42887 .59153 .44079 .59389 .43368 .58971 Mtetra
.174 .623 .939 r
.43368 .58971 .44079 .59389 .45282 .59574 .44574 .59168 Mtetra
.224 .658 .955 r
.44574 .59168 .45282 .59574 .46495 .59706 .4579 .59311 Mtetra
.276 .692 .969 r
.4579 .59311 .46495 .59706 .47719 .59778 .47017 .59394 Mtetra
.329 .726 .982 r
.47017 .59394 .47719 .59778 .48951 .59787 .48253 .59414 Mtetra
.381 .758 .991 r
.48253 .59414 .48951 .59787 .50192 .59731 .49498 .59368 Mtetra
.433 .788 .997 r
.49498 .59368 .50192 .59731 .51442 .59606 .50752 .59253 Mtetra
.482 .814 1 r
.50752 .59253 .51442 .59606 .52699 .59411 .52014 .59066 Mtetra
.528 .837 .999 r
.52014 .59066 .52699 .59411 .53962 .59143 .53282 .58807 Mtetra
.571 .857 .996 r
.53282 .58807 .53962 .59143 .55232 .58804 .54557 .58474 Mtetra
.61 .874 .991 r
.54557 .58474 .55232 .58804 .56507 .58392 .55838 .58069 Mtetra
.645 .887 .984 r
.55838 .58069 .56507 .58392 .57787 .57908 .57123 .5759 Mtetra
.676 .898 .976 r
.57123 .5759 .57787 .57908 .5907 .57355 .58412 .5704 Mtetra
.704 .906 .967 r
.58412 .5704 .5907 .57355 .60356 .56733 .59705 .56421 Mtetra
.728 .913 .957 r
.59705 .56421 .60356 .56733 .61645 .56045 .61 .55734 Mtetra
.75 .917 .948 r
.61 .55734 .61645 .56045 .62936 .55294 .62297 .54983 Mtetra
.768 .921 .938 r
.62297 .54983 .62936 .55294 .64228 .54483 .63595 .54171 Mtetra
.784 .923 .929 r
.63595 .54171 .64228 .54483 .6552 .53617 .64895 .53301 Mtetra
.798 .924 .92 r
.64895 .53301 .6552 .53617 .66813 .527 .66194 .52379 Mtetra
.81 .924 .912 r
.66194 .52379 .66813 .527 .68106 .51735 .67494 .51408 Mtetra
.819 .924 .905 r
.67494 .51408 .68106 .51735 .69398 .50728 .68792 .50393 Mtetra
.828 .923 .898 r
.68792 .50393 .69398 .50728 .7069 .49683 .70091 .49339 Mtetra
.835 .921 .892 r
.70091 .49339 .7069 .49683 .7198 .48605 .71388 .48251 Mtetra
.84 .919 .887 r
.71388 .48251 .7198 .48605 .7327 .47499 .72684 .47132 Mtetra
.845 .917 .882 r
.72684 .47132 .7327 .47499 .74558 .46369 .7398 .4599 Mtetra
.848 .915 .878 r
.7398 .4599 .74558 .46369 .75846 .45221 .75274 .44827 Mtetra
.851 .912 .875 r
.75274 .44827 .75846 .45221 .77133 .44059 .76567 .4365 Mtetra
.852 .909 .873 r
.76567 .4365 .77133 .44059 .7842 .42887 .7786 .42461 Mtetra
.853 .906 .871 r
.7786 .42461 .7842 .42887 .79705 .4171 .79152 .41267 Mtetra
.852 .903 .87 r
.79152 .41267 .79705 .4171 .80991 .40533 .80444 .40072 Mtetra
.851 .899 .869 r
.80444 .40072 .80991 .40533 .82278 .39358 .81736 .38878 Mtetra
.85 .895 .869 r
.81736 .38878 .82278 .39358 .83564 .38189 .83028 .37691 Mtetra
.847 .891 .87 r
.83028 .37691 .83564 .38189 .84852 .37031 .84321 .36513 Mtetra
.844 .887 .871 r
.84321 .36513 .84852 .37031 .86142 .35885 .85616 .35347 Mtetra
.84 .883 .872 r
.85616 .35347 .86142 .35885 .87433 .34755 .86913 .34198 Mtetra
.125 .521 .914 r
.24799 .52208 .25535 .52811 .2658 .53153 .25845 .52554 Mtetra
.093 .503 .903 r
.25845 .52554 .2658 .53153 .27632 .5352 .26898 .52925 Mtetra
.064 .486 .892 r
.26898 .52925 .27632 .5352 .28692 .5391 .27958 .5332 Mtetra
.04 .472 .882 r
.27958 .5332 .28692 .5391 .2976 .5432 .29027 .53734 Mtetra
.02 .46 .873 r
.29027 .53734 .2976 .5432 .30837 .54744 .30105 .54164 Mtetra
.005 .453 .867 r
.30105 .54164 .30837 .54744 .31923 .55179 .31192 .54605 Mtetra
0 .448 .863 r
.31192 .54605 .31923 .55179 .33019 .55621 .32288 .55053 Mtetra
0 .448 .861 r
.32288 .55053 .33019 .55621 .34124 .56064 .33395 .55503 Mtetra
0 .453 .863 r
.33395 .55503 .34124 .56064 .35241 .56503 .34512 .55949 Mtetra
.003 .461 .867 r
.34512 .55949 .35241 .56503 .36368 .56932 .35641 .56385 Mtetra
.018 .474 .874 r
.35641 .56385 .36368 .56932 .37506 .57345 .36781 .56806 Mtetra
.039 .492 .884 r
.36781 .56806 .37506 .57345 .38656 .57737 .37932 .57206 Mtetra
.065 .513 .896 r
.37932 .57206 .38656 .57737 .39817 .58101 .39095 .57579 Mtetra
.097 .537 .91 r
.39095 .57579 .39817 .58101 .40989 .58432 .40269 .57919 Mtetra
.134 .565 .925 r
.40269 .57919 .40989 .58432 .42173 .58724 .41455 .5822 Mtetra
.176 .595 .94 r
.41455 .5822 .42173 .58724 .43368 .58971 .42652 .58476 Mtetra
.221 .626 .954 r
.42652 .58476 .43368 .58971 .44574 .59168 .43861 .58683 Mtetra
.268 .657 .967 r
.43861 .58683 .44574 .59168 .4579 .59311 .4508 .58835 Mtetra
.317 .689 .979 r
.4508 .58835 .4579 .59311 .47017 .59394 .4631 .58928 Mtetra
.367 .719 .988 r
.4631 .58928 .47017 .59394 .48253 .59414 .47549 .58957 Mtetra
.416 .747 .994 r
.47549 .58957 .48253 .59414 .49498 .59368 .48798 .5892 Mtetra
.463 .773 .997 r
.48798 .5892 .49498 .59368 .50752 .59253 .50056 .58813 Mtetra
.508 .797 .998 r
.50056 .58813 .50752 .59253 .52014 .59066 .51322 .58635 Mtetra
.551 .817 .995 r
.51322 .58635 .52014 .59066 .53282 .58807 .52595 .58383 Mtetra
.589 .835 .991 r
.52595 .58383 .53282 .58807 .54557 .58474 .53875 .58058 Mtetra
.625 .85 .985 r
.53875 .58058 .54557 .58474 .55838 .58069 .5516 .57659 Mtetra
.657 .862 .978 r
.5516 .57659 .55838 .58069 .57123 .5759 .56451 .57186 Mtetra
.686 .872 .969 r
.56451 .57186 .57123 .5759 .58412 .5704 .57746 .5664 Mtetra
.711 .881 .96 r
.57746 .5664 .58412 .5704 .59705 .56421 .59044 .56024 Mtetra
.733 .887 .95 r
.59044 .56024 .59705 .56421 .61 .55734 .60345 .5534 Mtetra
.753 .892 .941 r
.60345 .5534 .61 .55734 .62297 .54983 .61649 .5459 Mtetra
.77 .896 .932 r
.61649 .5459 .62297 .54983 .63595 .54171 .62953 .53778 Mtetra
.785 .898 .923 r
.62953 .53778 .63595 .54171 .64895 .53301 .64259 .52907 Mtetra
.798 .9 .914 r
.64259 .52907 .64895 .53301 .66194 .52379 .65565 .51982 Mtetra
.809 .901 .906 r
.65565 .51982 .66194 .52379 .67494 .51408 .66871 .51007 Mtetra
.819 .901 .899 r
.66871 .51007 .67494 .51408 .68792 .50393 .68177 .49987 Mtetra
.827 .901 .892 r
.68177 .49987 .68792 .50393 .70091 .49339 .69482 .48926 Mtetra
.834 .901 .886 r
.69482 .48926 .70091 .49339 .71388 .48251 .70786 .47829 Mtetra
.839 .9 .881 r
.70786 .47829 .71388 .48251 .72684 .47132 .72089 .46701 Mtetra
.843 .899 .877 r
.72089 .46701 .72684 .47132 .7398 .4599 .73391 .45548 Mtetra
.847 .897 .873 r
.73391 .45548 .7398 .4599 .75274 .44827 .74691 .44374 Mtetra
.849 .895 .87 r
.74691 .44374 .75274 .44827 .76567 .4365 .75991 .43183 Mtetra
.85 .893 .868 r
.75991 .43183 .76567 .4365 .7786 .42461 .7729 .41981 Mtetra
.851 .891 .866 r
.7729 .41981 .7786 .42461 .79152 .41267 .78588 .40773 Mtetra
.851 .888 .865 r
.78588 .40773 .79152 .41267 .80444 .40072 .79886 .39562 Mtetra
.85 .885 .864 r
.79886 .39562 .80444 .40072 .81736 .38878 .81184 .38352 Mtetra
.849 .882 .864 r
.81184 .38352 .81736 .38878 .83028 .37691 .82482 .37148 Mtetra
.846 .879 .864 r
.82482 .37148 .83028 .37691 .84321 .36513 .83781 .35953 Mtetra
.843 .876 .865 r
.83781 .35953 .84321 .36513 .85616 .35347 .85081 .3477 Mtetra
.84 .872 .866 r
.85081 .3477 .85616 .35347 .86913 .34198 .86383 .33603 Mtetra
.145 .523 .917 r
.24059 .51572 .24799 .52208 .25845 .52554 .25106 .51918 Mtetra
.116 .506 .908 r
.25106 .51918 .25845 .52554 .26898 .52925 .2616 .52291 Mtetra
.09 .49 .899 r
.2616 .52291 .26898 .52925 .27958 .5332 .27221 .52687 Mtetra
.069 .477 .89 r
.27221 .52687 .27958 .5332 .29027 .53734 .28291 .53104 Mtetra
.051 .467 .884 r
.28291 .53104 .29027 .53734 .30105 .54164 .29369 .53536 Mtetra
.039 .46 .879 r
.29369 .53536 .30105 .54164 .31192 .54605 .30457 .5398 Mtetra
.032 .457 .876 r
.30457 .5398 .31192 .54605 .32288 .55053 .31554 .54431 Mtetra
.031 .458 .876 r
.31554 .54431 .32288 .55053 .33395 .55503 .32662 .54884 Mtetra
.036 .463 .879 r
.32662 .54884 .33395 .55503 .34512 .55949 .33781 .55334 Mtetra
.046 .471 .883 r
.33781 .55334 .34512 .55949 .35641 .56385 .3491 .55775 Mtetra
.062 .484 .891 r
.3491 .55775 .35641 .56385 .36781 .56806 .36051 .56201 Mtetra
.084 .501 .9 r
.36051 .56201 .36781 .56806 .37932 .57206 .37204 .56607 Mtetra
.111 .52 .911 r
.37204 .56607 .37932 .57206 .39095 .57579 .38368 .56985 Mtetra
.143 .543 .923 r
.38368 .56985 .39095 .57579 .40269 .57919 .39544 .57331 Mtetra
.18 .569 .936 r
.39544 .57331 .40269 .57919 .41455 .5822 .40732 .57639 Mtetra
.22 .596 .948 r
.40732 .57639 .41455 .5822 .42652 .58476 .41932 .57902 Mtetra
.263 .624 .96 r
.41932 .57902 .42652 .58476 .43861 .58683 .43142 .58116 Mtetra
.308 .652 .97 r
.43142 .58116 .43861 .58683 .4508 .58835 .44364 .58275 Mtetra
.354 .68 .978 r
.44364 .58275 .4508 .58835 .4631 .58928 .45597 .58375 Mtetra
.399 .706 .984 r
.45597 .58375 .4631 .58928 .47549 .58957 .4684 .58412 Mtetra
.444 .731 .988 r
.4684 .58412 .47549 .58957 .48798 .5892 .48092 .58383 Mtetra
.487 .754 .989 r
.48092 .58383 .48798 .5892 .50056 .58813 .49354 .58284 Mtetra
.528 .775 .988 r
.49354 .58284 .50056 .58813 .51322 .58635 .50623 .58113 Mtetra
.567 .793 .984 r
.50623 .58113 .51322 .58635 .52595 .58383 .51901 .57869 Mtetra
.602 .809 .979 r
.51901 .57869 .52595 .58383 .53875 .58058 .53185 .5755 Mtetra
.634 .823 .973 r
.53185 .5755 .53875 .58058 .5516 .57659 .54475 .57157 Mtetra
.664 .835 .965 r
.54475 .57157 .5516 .57659 .56451 .57186 .55771 .5669 Mtetra
.69 .844 .957 r
.55771 .5669 .56451 .57186 .57746 .5664 .57071 .5615 Mtetra
.713 .853 .948 r
.57071 .5615 .57746 .5664 .59044 .56024 .58375 .55538 Mtetra
.734 .859 .939 r
.58375 .55538 .59044 .56024 .60345 .5534 .59682 .54857 Mtetra
.753 .865 .93 r
.59682 .54857 .60345 .5534 .61649 .5459 .60991 .5411 Mtetra
.769 .869 .922 r
.60991 .5411 .61649 .5459 .62953 .53778 .62302 .53299 Mtetra
.783 .872 .913 r
.62302 .53299 .62953 .53778 .64259 .52907 .63614 .52429 Mtetra
.796 .875 .905 r
.63614 .52429 .64259 .52907 .65565 .51982 .64927 .51504 Mtetra
.806 .877 .898 r
.64927 .51504 .65565 .51982 .66871 .51007 .66239 .50527 Mtetra
.816 .878 .891 r
.66239 .50527 .66871 .51007 .68177 .49987 .67551 .49503 Mtetra
.823 .879 .885 r
.67551 .49503 .68177 .49987 .69482 .48926 .68863 .48438 Mtetra
.83 .879 .879 r
.68863 .48438 .69482 .48926 .70786 .47829 .70174 .47335 Mtetra
.835 .879 .875 r
.70174 .47335 .70786 .47829 .72089 .46701 .71483 .46201 Mtetra
.84 .879 .87 r
.71483 .46201 .72089 .46701 .73391 .45548 .72792 .4504 Mtetra
.843 .878 .867 r
.72792 .4504 .73391 .45548 .74691 .44374 .74099 .43856 Mtetra
.846 .877 .864 r
.74099 .43856 .74691 .44374 .75991 .43183 .75405 .42656 Mtetra
.847 .876 .862 r
.75405 .42656 .75991 .43183 .7729 .41981 .7671 .41443 Mtetra
.848 .875 .86 r
.7671 .41443 .7729 .41981 .78588 .40773 .78015 .40222 Mtetra
.848 .873 .859 r
.78015 .40222 .78588 .40773 .79886 .39562 .79319 .38998 Mtetra
.848 .871 .858 r
.79319 .38998 .79886 .39562 .81184 .38352 .80623 .37775 Mtetra
.846 .869 .858 r
.80623 .37775 .81184 .38352 .82482 .37148 .81927 .36557 Mtetra
.844 .866 .859 r
.81927 .36557 .82482 .37148 .83781 .35953 .83231 .35348 Mtetra
.842 .864 .86 r
.83231 .35348 .83781 .35953 .85081 .3477 .84537 .3415 Mtetra
.838 .861 .861 r
.84537 .3415 .85081 .3477 .86383 .33603 .85845 .32968 Mtetra
.167 .525 .92 r
.23316 .509 .24059 .51572 .25106 .51918 .24364 .51245 Mtetra
.141 .509 .912 r
.24364 .51245 .25106 .51918 .2616 .52291 .25419 .51617 Mtetra
.118 .495 .904 r
.25419 .51617 .2616 .52291 .27221 .52687 .26481 .52012 Mtetra
.099 .483 .897 r
.26481 .52012 .27221 .52687 .28291 .53104 .27551 .52427 Mtetra
.084 .474 .892 r
.27551 .52427 .28291 .53104 .29369 .53536 .28631 .52859 Mtetra
.074 .468 .888 r
.28631 .52859 .29369 .53536 .30457 .5398 .29719 .53303 Mtetra
.07 .466 .887 r
.29719 .53303 .30457 .5398 .31554 .54431 .30818 .53754 Mtetra
.071 .467 .887 r
.30818 .53754 .31554 .54431 .32662 .54884 .31927 .54208 Mtetra
.077 .471 .89 r
.31927 .54208 .32662 .54884 .33781 .55334 .33046 .54658 Mtetra
.089 .48 .895 r
.33046 .54658 .33781 .55334 .3491 .55775 .34177 .55101 Mtetra
.106 .492 .901 r
.34177 .55101 .3491 .55775 .36051 .56201 .35319 .55529 Mtetra
.128 .507 .91 r
.35319 .55529 .36051 .56201 .37204 .56607 .36473 .55936 Mtetra
.155 .525 .919 r
.36473 .55936 .37204 .56607 .38368 .56985 .37639 .56318 Mtetra
.187 .546 .929 r
.37639 .56318 .38368 .56985 .39544 .57331 .38816 .56667 Mtetra
.222 .569 .939 r
.38816 .56667 .39544 .57331 .40732 .57639 .40006 .56978 Mtetra
.26 .593 .949 r
.40006 .56978 .40732 .57639 .41932 .57902 .41207 .57246 Mtetra
.3 .617 .958 r
.41207 .57246 .41932 .57902 .43142 .58116 .4242 .57464 Mtetra
.342 .642 .965 r
.4242 .57464 .43142 .58116 .44364 .58275 .43644 .57629 Mtetra
.384 .667 .97 r
.43644 .57629 .44364 .58275 .45597 .58375 .4488 .57735 Mtetra
.426 .69 .974 r
.4488 .57735 .45597 .58375 .4684 .58412 .46125 .57778 Mtetra
.467 .712 .975 r
.46125 .57778 .4684 .58412 .48092 .58383 .47381 .57755 Mtetra
.506 .732 .975 r
.47381 .57755 .48092 .58383 .49354 .58284 .48646 .57662 Mtetra
.543 .751 .973 r
.48646 .57662 .49354 .58284 .50623 .58113 .49919 .57498 Mtetra
.578 .767 .969 r
.49919 .57498 .50623 .58113 .51901 .57869 .512 .57261 Mtetra
.61 .782 .963 r
.512 .57261 .51901 .57869 .53185 .5755 .52489 .56949 Mtetra
.639 .795 .957 r
.52489 .56949 .53185 .5755 .54475 .57157 .53783 .56562 Mtetra
.666 .806 .95 r
.53783 .56562 .54475 .57157 .55771 .5669 .55084 .56101 Mtetra
.691 .815 .942 r
.55084 .56101 .55771 .5669 .57071 .5615 .56389 .55567 Mtetra
.712 .824 .934 r
.56389 .55567 .57071 .5615 .58375 .55538 .57698 .5496 Mtetra
.732 .831 .926 r
.57698 .5496 .58375 .55538 .59682 .54857 .5901 .54284 Mtetra
.749 .837 .918 r
.5901 .54284 .59682 .54857 .60991 .5411 .60325 .5354 Mtetra
.765 .842 .91 r
.60325 .5354 .60991 .5411 .62302 .53299 .61642 .52733 Mtetra
.778 .846 .902 r
.61642 .52733 .62302 .53299 .63614 .52429 .6296 .51865 Mtetra
.79 .849 .895 r
.6296 .51865 .63614 .52429 .64927 .51504 .64279 .5094 Mtetra
.801 .852 .888 r
.64279 .5094 .64927 .51504 .66239 .50527 .65598 .49964 Mtetra
.81 .854 .882 r
.65598 .49964 .66239 .50527 .67551 .49503 .66916 .48939 Mtetra
.818 .856 .877 r
.66916 .48939 .67551 .49503 .68863 .48438 .68234 .47872 Mtetra
.824 .857 .872 r
.68234 .47872 .68863 .48438 .70174 .47335 .69551 .46767 Mtetra
.83 .858 .867 r
.69551 .46767 .70174 .47335 .71483 .46201 .70867 .45628 Mtetra
.835 .859 .863 r
.70867 .45628 .71483 .46201 .72792 .4504 .72182 .44461 Mtetra
.838 .859 .86 r
.72182 .44461 .72792 .4504 .74099 .43856 .73496 .43272 Mtetra
.841 .859 .857 r
.73496 .43272 .74099 .43856 .75405 .42656 .74809 .42064 Mtetra
.843 .859 .855 r
.74809 .42064 .75405 .42656 .7671 .41443 .76121 .40843 Mtetra
.844 .858 .854 r
.76121 .40843 .7671 .41443 .78015 .40222 .77431 .39613 Mtetra
.844 .857 .853 r
.77431 .39613 .78015 .40222 .79319 .38998 .78742 .38379 Mtetra
.844 .856 .852 r
.78742 .38379 .79319 .38998 .80623 .37775 .80052 .37146 Mtetra
.843 .855 .852 r
.80052 .37146 .80623 .37775 .81927 .36557 .81362 .35916 Mtetra
.841 .853 .853 r
.81362 .35916 .81927 .36557 .83231 .35348 .82672 .34695 Mtetra
.839 .851 .854 r
.82672 .34695 .83231 .35348 .84537 .3415 .83984 .33485 Mtetra
.836 .849 .855 r
.83984 .33485 .84537 .3415 .85845 .32968 .85297 .3229 Mtetra
.19 .528 .922 r
.2257 .50194 .23316 .509 .24364 .51245 .23619 .50535 Mtetra
.166 .513 .915 r
.23619 .50535 .24364 .51245 .25419 .51617 .24674 .50902 Mtetra
.146 .5 .908 r
.24674 .50902 .25419 .51617 .26481 .52012 .25738 .51293 Mtetra
.129 .489 .903 r
.25738 .51293 .26481 .52012 .27551 .52427 .26809 .51705 Mtetra
.117 .481 .898 r
.26809 .51705 .27551 .52427 .28631 .52859 .27889 .52133 Mtetra
.11 .475 .895 r
.27889 .52133 .28631 .52859 .29719 .53303 .28979 .52573 Mtetra
.107 .473 .894 r
.28979 .52573 .29719 .53303 .30818 .53754 .30078 .53022 Mtetra
.109 .474 .895 r
.30078 .53022 .30818 .53754 .31927 .54208 .31188 .53473 Mtetra
.117 .479 .897 r
.31188 .53473 .31927 .54208 .33046 .54658 .32309 .53921 Mtetra
.13 .487 .901 r
.32309 .53921 .33046 .54658 .34177 .55101 .3344 .54361 Mtetra
.148 .497 .907 r
.3344 .54361 .34177 .55101 .35319 .55529 .34584 .54788 Mtetra
.17 .511 .914 r
.34584 .54788 .35319 .55529 .36473 .55936 .35739 .55195 Mtetra
.196 .528 .921 r
.35739 .55195 .36473 .55936 .37639 .56318 .36906 .55576 Mtetra
.226 .546 .929 r
.36906 .55576 .37639 .56318 .38816 .56667 .38085 .55926 Mtetra
.26 .566 .936 r
.38085 .55926 .38816 .56667 .40006 .56978 .39276 .56238 Mtetra
.295 .587 .944 r
.39276 .56238 .40006 .56978 .41207 .57246 .40479 .56507 Mtetra
.333 .609 .95 r
.40479 .56507 .41207 .57246 .4242 .57464 .41694 .56728 Mtetra
.371 .631 .954 r
.41694 .56728 .4242 .57464 .43644 .57629 .4292 .56896 Mtetra
.41 .652 .958 r
.4292 .56896 .43644 .57629 .4488 .57735 .44158 .57005 Mtetra
.448 .672 .959 r
.44158 .57005 .4488 .57735 .46125 .57778 .45406 .57052 Mtetra
.484 .692 .959 r
.45406 .57052 .46125 .57778 .47381 .57755 .46664 .57034 Mtetra
.52 .71 .958 r
.46664 .57034 .47381 .57755 .48646 .57662 .47932 .56947 Mtetra
.553 .726 .955 r
.47932 .56947 .48646 .57662 .49919 .57498 .49209 .56788 Mtetra
.585 .741 .95 r
.49209 .56788 .49919 .57498 .512 .57261 .50494 .56556 Mtetra
.614 .755 .945 r
.50494 .56556 .512 .57261 .52489 .56949 .51786 .56251 Mtetra
.641 .767 .939 r
.51786 .56251 .52489 .56949 .53783 .56562 .53085 .5587 Mtetra
.666 .778 .933 r
.53085 .5587 .53783 .56562 .55084 .56101 .54389 .55416 Mtetra
.688 .787 .926 r
.54389 .55416 .55084 .56101 .56389 .55567 .55699 .54887 Mtetra
.709 .795 .918 r
.55699 .54887 .56389 .55567 .57698 .5496 .57013 .54287 Mtetra
.727 .803 .911 r
.57013 .54287 .57698 .5496 .5901 .54284 .58331 .53616 Mtetra
.744 .809 .904 r
.58331 .53616 .5901 .54284 .60325 .5354 .59651 .52877 Mtetra
.759 .815 .897 r
.59651 .52877 .60325 .5354 .61642 .52733 .60973 .52074 Mtetra
.772 .82 .89 r
.60973 .52074 .61642 .52733 .6296 .51865 .62297 .5121 Mtetra
.783 .824 .884 r
.62297 .5121 .6296 .51865 .64279 .5094 .63622 .50289 Mtetra
.794 .827 .878 r
.63622 .50289 .64279 .5094 .65598 .49964 .64946 .49315 Mtetra
.803 .83 .872 r
.64946 .49315 .65598 .49964 .66916 .48939 .66271 .48292 Mtetra
.811 .833 .867 r
.66271 .48292 .66916 .48939 .68234 .47872 .67596 .47225 Mtetra
.817 .835 .863 r
.67596 .47225 .68234 .47872 .69551 .46767 .68919 .46119 Mtetra
.823 .837 .859 r
.68919 .46119 .69551 .46767 .70867 .45628 .70242 .44979 Mtetra
.828 .839 .856 r
.70242 .44979 .70867 .45628 .72182 .44461 .71563 .4381 Mtetra
.832 .84 .853 r
.71563 .4381 .72182 .44461 .73496 .43272 .72883 .42617 Mtetra
.835 .841 .85 r
.72883 .42617 .73496 .43272 .74809 .42064 .74202 .41405 Mtetra
.837 .841 .849 r
.74202 .41405 .74809 .42064 .76121 .40843 .75521 .40178 Mtetra
.839 .841 .847 r
.75521 .40178 .76121 .40843 .77431 .39613 .76838 .38942 Mtetra
.76838 .38942 .77431 .39613 .78742 .38379 .78154 .37701 Mtetra
.839 .841 .846 r
.78154 .37701 .78742 .38379 .80052 .37146 .79471 .3646 Mtetra
.839 .84 .847 r
.79471 .3646 .80052 .37146 .81362 .35916 .80787 .35222 Mtetra
.837 .84 .847 r
.80787 .35222 .81362 .35916 .82672 .34695 .82104 .33992 Mtetra
.835 .839 .848 r
.82104 .33992 .82672 .34695 .83984 .33485 .83421 .32772 Mtetra
.833 .837 .85 r
.83421 .32772 .83984 .33485 .85297 .3229 .8474 .31567 Mtetra
.213 .532 .922 r
.21821 .49453 .2257 .50194 .23619 .50535 .22871 .49787 Mtetra
.192 .518 .916 r
.22871 .49787 .23619 .50535 .24674 .50902 .23928 .50148 Mtetra
.174 .505 .911 r
.23928 .50148 .24674 .50902 .25738 .51293 .24992 .50532 Mtetra
.16 .495 .906 r
.24992 .50532 .25738 .51293 .26809 .51705 .26064 .50937 Mtetra
.15 .487 .902 r
.26064 .50937 .26809 .51705 .27889 .52133 .27146 .51358 Mtetra
.144 .482 .9 r
.27146 .51358 .27889 .52133 .28979 .52573 .28236 .51792 Mtetra
.143 .48 .899 r
.28236 .51792 .28979 .52573 .30078 .53022 .29337 .52234 Mtetra
.147 .481 .899 r
.29337 .52234 .30078 .53022 .31188 .53473 .30447 .52679 Mtetra
.156 .485 .901 r
.30447 .52679 .31188 .53473 .32309 .53921 .31569 .53122 Mtetra
.169 .492 .904 r
.31569 .53122 .32309 .53921 .3344 .54361 .32702 .53557 Mtetra
.187 .502 .908 r
.32702 .53557 .3344 .54361 .34584 .54788 .33846 .53979 Mtetra
.208 .514 .913 r
.33846 .53979 .34584 .54788 .35739 .55195 .35002 .54382 Mtetra
.234 .528 .919 r
.35002 .54382 .35739 .55195 .36906 .55576 .36171 .5476 Mtetra
.262 .544 .924 r
.36171 .5476 .36906 .55576 .38085 .55926 .37351 .55107 Mtetra
.293 .562 .93 r
.37351 .55107 .38085 .55926 .39276 .56238 .38544 .55418 Mtetra
.326 .58 .934 r
.38544 .55418 .39276 .56238 .40479 .56507 .39748 .55686 Mtetra
.361 .599 .938 r
.39748 .55686 .40479 .56507 .41694 .56728 .40965 .55907 Mtetra
.395 .618 .941 r
.40965 .55907 .41694 .56728 .4292 .56896 .42193 .56075 Mtetra
.43 .637 .942 r
.42193 .56075 .4292 .56896 .44158 .57005 .43432 .56186 Mtetra
.465 .654 .942 r
.43432 .56186 .44158 .57005 .45406 .57052 .44683 .56235 Mtetra
.498 .671 .941 r
.44683 .56235 .45406 .57052 .46664 .57034 .45943 .5622 Mtetra
.53 .688 .939 r
.45943 .5622 .46664 .57034 .47932 .56947 .47214 .56136 Mtetra
.561 .702 .936 r
.47214 .56136 .47932 .56947 .49209 .56788 .48494 .55982 Mtetra
.589 .716 .931 r
.48494 .55982 .49209 .56788 .50494 .56556 .49782 .55756 Mtetra
.616 .729 .926 r
.49782 .55756 .50494 .56556 .51786 .56251 .51077 .55456 Mtetra
.641 .74 .921 r
.51077 .55456 .51786 .56251 .53085 .5587 .5238 .55081 Mtetra
.664 .751 .915 r
.5238 .55081 .53085 .5587 .54389 .55416 .53689 .54633 Mtetra
.685 .76 .909 r
.53689 .54633 .54389 .55416 .55699 .54887 .55003 .54111 Mtetra
.704 .768 .902 r
.55003 .54111 .55699 .54887 .57013 .54287 .56321 .53517 Mtetra
.721 .776 .896 r
.56321 .53517 .57013 .54287 .58331 .53616 .57643 .52852 Mtetra
.737 .783 .89 r
.57643 .52852 .58331 .53616 .59651 .52877 .58969 .5212 Mtetra
.751 .789 .884 r
.58969 .5212 .59651 .52877 .60973 .52074 .60296 .51323 Mtetra
.764 .794 .878 r
.60296 .51323 .60973 .52074 .62297 .5121 .61625 .50464 Mtetra
.775 .799 .872 r
.61625 .50464 .62297 .5121 .63622 .50289 .62955 .49548 Mtetra
.786 .803 .867 r
.62955 .49548 .63622 .50289 .64946 .49315 .64286 .48578 Mtetra
.795 .807 .862 r
.64286 .48578 .64946 .49315 .66271 .48292 .65617 .47558 Mtetra
.803 .811 .858 r
.65617 .47558 .66271 .48292 .67596 .47225 .66947 .46494 Mtetra
.809 .814 .854 r
.66947 .46494 .67596 .47225 .68919 .46119 .68277 .45391 Mtetra
.815 .816 .851 r
.68277 .45391 .68919 .46119 .70242 .44979 .69606 .44252 Mtetra
.82 .819 .848 r
.69606 .44252 .70242 .44979 .71563 .4381 .70934 .43083 Mtetra
.825 .821 .845 r
.70934 .43083 .71563 .4381 .72883 .42617 .7226 .41889 Mtetra
.828 .822 .843 r
.7226 .41889 .72883 .42617 .74202 .41405 .73586 .40676 Mtetra
.831 .824 .842 r
.73586 .40676 .74202 .41405 .75521 .40178 .74911 .39447 Mtetra
.832 .825 .841 r
.74911 .39447 .75521 .40178 .76838 .38942 .76234 .38208 Mtetra
.833 .825 .84 r
.76234 .38208 .76838 .38942 .78154 .37701 .77557 .36963 Mtetra
.834 .826 .84 r
.77557 .36963 .78154 .37701 .79471 .3646 .7888 .35716 Mtetra
.834 .826 .841 r
.7888 .35716 .79471 .3646 .80787 .35222 .80202 .34473 Mtetra
.833 .826 .842 r
.80202 .34473 .80787 .35222 .82104 .33992 .81525 .33237 Mtetra
.831 .826 .843 r
.81525 .33237 .82104 .33992 .83421 .32772 .82849 .32011 Mtetra
.829 .825 .845 r
.82849 .32011 .83421 .32772 .8474 .31567 .84174 .30798 Mtetra
.237 .536 .922 r
.21069 .48678 .21821 .49453 .22871 .49787 .2212 .49003 Mtetra
.218 .522 .917 r
.2212 .49003 .22871 .49787 .23928 .50148 .23178 .49354 Mtetra
.203 .511 .912 r
.23178 .49354 .23928 .50148 .24992 .50532 .24244 .49729 Mtetra
.19 .501 .908 r
.24244 .49729 .24992 .50532 .26064 .50937 .25317 .50124 Mtetra
.182 .494 .904 r
.25317 .50124 .26064 .50937 .27146 .51358 .264 .50536 Mtetra
.178 .489 .902 r
.264 .50536 .27146 .51358 .28236 .51792 .27491 .5096 Mtetra
.178 .487 .9 r
.27491 .5096 .28236 .51792 .29337 .52234 .28593 .51393 Mtetra
.183 .487 .9 r
.28593 .51393 .29337 .52234 .30447 .52679 .29705 .51829 Mtetra
.192 .49 .901 r
.29705 .51829 .30447 .52679 .31569 .53122 .30827 .52263 Mtetra
.205 .496 .903 r
.30827 .52263 .31569 .53122 .32702 .53557 .31961 .5269 Mtetra
.223 .505 .906 r
.31961 .5269 .32702 .53557 .33846 .53979 .33106 .53104 Mtetra
.243 .515 .909 r
.33106 .53104 .33846 .53979 .35002 .54382 .34264 .535 Mtetra
.267 .528 .913 r
.34264 .535 .35002 .54382 .36171 .5476 .35433 .53871 Mtetra
.294 .542 .917 r
.35433 .53871 .36171 .5476 .37351 .55107 .36615 .54213 Mtetra
.323 .557 .92 r
.36615 .54213 .37351 .55107 .38544 .55418 .37808 .54519 Mtetra
.353 .573 .923 r
.37808 .54519 .38544 .55418 .39748 .55686 .39014 .54783 Mtetra
.384 .589 .924 r
.39014 .54783 .39748 .55686 .40965 .55907 .40232 .55001 Mtetra
.416 .605 .926 r
.40232 .55001 .40965 .55907 .42193 .56075 .41462 .55167 Mtetra
.448 .622 .926 r
.41462 .55167 .42193 .56075 .43432 .56186 .42703 .55277 Mtetra
.479 .637 .925 r
.42703 .55277 .43432 .56186 .44683 .56235 .43956 .55327 Mtetra
.509 .652 .923 r
.43956 .55327 .44683 .56235 .45943 .5622 .45219 .55313 Mtetra
.538 .667 .92 r
.45219 .55313 .45943 .5622 .47214 .56136 .46492 .55232 Mtetra
.565 .68 .917 r
.46492 .55232 .47214 .56136 .48494 .55982 .47774 .55081 Mtetra
.592 .693 .913 r
.47774 .55081 .48494 .55982 .49782 .55756 .49065 .54859 Mtetra
.616 .705 .908 r
.49065 .54859 .49782 .55756 .51077 .55456 .50363 .54563 Mtetra
.639 .715 .903 r
.50363 .54563 .51077 .55456 .5238 .55081 .51669 .54194 Mtetra
.66 .725 .898 r
.51669 .54194 .5238 .55081 .53689 .54633 .52981 .53752 Mtetra
.68 .735 .892 r
.52981 .53752 .53689 .54633 .55003 .54111 .54299 .53237 Mtetra
.698 .743 .886 r
.54299 .53237 .55003 .54111 .56321 .53517 .55622 .52649 Mtetra
.714 .751 .881 r
.55622 .52649 .56321 .53517 .57643 .52852 .56949 .51992 Mtetra
.729 .758 .876 r
.56949 .51992 .57643 .52852 .58969 .5212 .58279 .51267 Mtetra
.743 .764 .87 r
.58279 .51267 .58969 .5212 .60296 .51323 .59611 .50477 Mtetra
.755 .77 .865 r
.59611 .50477 .60296 .51323 .61625 .50464 .60945 .49626 Mtetra
.767 .776 .86 r
.60945 .49626 .61625 .50464 .62955 .49548 .62281 .48716 Mtetra
.777 .781 .856 r
.62281 .48716 .62955 .49548 .64286 .48578 .63617 .47752 Mtetra
.786 .785 .852 r
.63617 .47752 .64286 .48578 .65617 .47558 .64954 .46738 Mtetra
.794 .789 .848 r
.64954 .46738 .65617 .47558 .66947 .46494 .6629 .4568 Mtetra
.801 .793 .845 r
.6629 .4568 .66947 .46494 .68277 .45391 .67626 .4458 Mtetra
.807 .796 .842 r
.67626 .4458 .68277 .45391 .69606 .44252 .68961 .43445 Mtetra
.812 .799 .84 r
.68961 .43445 .69606 .44252 .70934 .43083 .70295 .42279 Mtetra
.817 .802 .838 r
.70295 .42279 .70934 .43083 .7226 .41889 .71628 .41088 Mtetra
.82 .804 .836 r
.71628 .41088 .7226 .41889 .73586 .40676 .7296 .39875 Mtetra
.823 .807 .835 r
.7296 .39875 .73586 .40676 .74911 .39447 .74291 .38647 Mtetra
.825 .808 .834 r
.74291 .38647 .74911 .39447 .76234 .38208 .75621 .37408 Mtetra
.827 .81 .834 r
.75621 .37408 .76234 .38208 .77557 .36963 .7695 .36162 Mtetra
.828 .811 .834 r
.7695 .36162 .77557 .36963 .7888 .35716 .78279 .34914 Mtetra
.828 .812 .835 r
.78279 .34914 .7888 .35716 .80202 .34473 .79608 .33668 Mtetra
.827 .813 .836 r
.79608 .33668 .80202 .34473 .81525 .33237 .80937 .32428 Mtetra
.826 .813 .838 r
.80937 .32428 .81525 .33237 .82849 .32011 .82267 .31198 Mtetra
.824 .813 .839 r
.82267 .31198 .82849 .32011 .84174 .30798 .83598 .29981 Mtetra
.261 .54 .922 r
.20314 .4787 .21069 .48678 .2212 .49003 .21366 .48183 Mtetra
.244 .527 .917 r
.21366 .48183 .2212 .49003 .23178 .49354 .22426 .48522 Mtetra
.23 .516 .912 r
.22426 .48522 .23178 .49354 .24244 .49729 .23493 .48884 Mtetra
.22 .507 .908 r
.23493 .48884 .24244 .49729 .25317 .50124 .24568 .49267 Mtetra
.213 .5 .904 r
.24568 .49267 .25317 .50124 .264 .50536 .25651 .49666 Mtetra
.21 .495 .902 r
.25651 .49666 .264 .50536 .27491 .5096 .26744 .50078 Mtetra
.211 .492 .9 r
.26744 .50078 .27491 .5096 .28593 .51393 .27847 .50498 Mtetra
.217 .492 .899 r
.27847 .50498 .28593 .51393 .29705 .51829 .2896 .50922 Mtetra
.226 .495 .899 r
.2896 .50922 .29705 .51829 .30827 .52263 .30083 .51344 Mtetra
.239 .5 .9 r
.30083 .51344 .30827 .52263 .31961 .5269 .31218 .5176 Mtetra
.255 .507 .902 r
.31218 .5176 .31961 .5269 .33106 .53104 .32365 .52163 Mtetra
.275 .516 .903 r
.32365 .52163 .33106 .53104 .34264 .535 .33523 .52549 Mtetra
.297 .526 .905 r
.33523 .52549 .34264 .535 .35433 .53871 .34694 .52911 Mtetra
.322 .538 .907 r
.34694 .52911 .35433 .53871 .36615 .54213 .35876 .53244 Mtetra
.348 .551 .909 r
.35876 .53244 .36615 .54213 .37808 .54519 .37071 .53542 Mtetra
.376 .565 .91 r
.37071 .53542 .37808 .54519 .39014 .54783 .38278 .538 Mtetra
.404 .579 .91 r
.38278 .538 .39014 .54783 .40232 .55001 .39498 .54013 Mtetra
.433 .593 .91 r
.39498 .54013 .40232 .55001 .41462 .55167 .40729 .54175 Mtetra
.462 .608 .909 r
.40729 .54175 .41462 .55167 .42703 .55277 .41972 .54282 Mtetra
.49 .621 .908 r
.41972 .54282 .42703 .55277 .43956 .55327 .43226 .5433 Mtetra
.517 .635 .905 r
.43226 .5433 .43956 .55327 .45219 .55313 .4449 .54315 Mtetra
.544 .648 .902 r
.4449 .54315 .45219 .55313 .46492 .55232 .45765 .54235 Mtetra
.569 .66 .899 r
.45765 .54235 .46492 .55232 .47774 .55081 .4705 .54086 Mtetra
.593 .672 .895 r
.4705 .54086 .47774 .55081 .49065 .54859 .48343 .53866 Mtetra
.615 .683 .891 r
.48343 .53866 .49065 .54859 .50363 .54563 .49644 .53575 Mtetra
.636 .693 .886 r
.49644 .53575 .50363 .54563 .51669 .54194 .50953 .53211 Mtetra
.656 .703 .881 r
.50953 .53211 .51669 .54194 .52981 .53752 .52269 .52775 Mtetra
.674 .712 .876 r
.52269 .52775 .52981 .53752 .54299 .53237 .5359 .52266 Mtetra
.691 .72 .871 r
.5359 .52266 .54299 .53237 .55622 .52649 .54917 .51686 Mtetra
.707 .728 .867 r
.54917 .51686 .55622 .52649 .56949 .51992 .56247 .51036 Mtetra
.721 .735 .862 r
.56247 .51036 .56949 .51992 .58279 .51267 .57581 .50319 Mtetra
.734 .742 .857 r
.57581 .50319 .58279 .51267 .59611 .50477 .58918 .49538 Mtetra
.747 .748 .853 r
.58918 .49538 .59611 .50477 .60945 .49626 .60258 .48694 Mtetra
.758 .754 .849 r
.60258 .48694 .60945 .49626 .62281 .48716 .61598 .47793 Mtetra
.767 .759 .845 r
.61598 .47793 .62281 .48716 .63617 .47752 .6294 .46837 Mtetra
.776 .764 .842 r
.6294 .46837 .63617 .47752 .64954 .46738 .64282 .45831 Mtetra
.785 .769 .839 r
.64282 .45831 .64954 .46738 .6629 .4568 .65624 .4478 Mtetra
.792 .773 .836 r
.65624 .4478 .6629 .4568 .67626 .4458 .66965 .43687 Mtetra
.798 .777 .834 r
.66965 .43687 .67626 .4458 .68961 .43445 .68306 .42558 Mtetra
.804 .781 .832 r
.68306 .42558 .68961 .43445 .70295 .42279 .69646 .41398 Mtetra
.808 .784 .83 r
.69646 .41398 .70295 .42279 .71628 .41088 .70986 .40211 Mtetra
.812 .787 .829 r
.70986 .40211 .71628 .41088 .7296 .39875 .72324 .39003 Mtetra
.816 .79 .828 r
.72324 .39003 .7296 .39875 .74291 .38647 .73661 .37778 Mtetra
.818 .792 .828 r
.73661 .37778 .74291 .38647 .75621 .37408 .74997 .36542 Mtetra
.82 .795 .828 r
.74997 .36542 .75621 .37408 .7695 .36162 .76333 .35297 Mtetra
.821 .797 .829 r
.76333 .35297 .7695 .36162 .78279 .34914 .77669 .34051 Mtetra
.822 .798 .83 r
.77669 .34051 .78279 .34914 .79608 .33668 .79004 .32805 Mtetra
.821 .799 .831 r
.79004 .32805 .79608 .33668 .80937 .32428 .80339 .31565 Mtetra
.821 .801 .833 r
.80339 .31565 .80937 .32428 .82267 .31198 .81676 .30334 Mtetra
.819 .801 .835 r
.81676 .30334 .82267 .31198 .83598 .29981 .83013 .29116 Mtetra
.284 .544 .92 r
.19556 .4703 .20314 .4787 .21366 .48183 .2061 .47328 Mtetra
.269 .532 .915 r
.2061 .47328 .21366 .48183 .22426 .48522 .21671 .47653 Mtetra
.257 .521 .911 r
.21671 .47653 .22426 .48522 .23493 .48884 .2274 .48 Mtetra
.248 .512 .907 r
.2274 .48 .23493 .48884 .24568 .49267 .23816 .48367 Mtetra
.242 .505 .903 r
.23816 .48367 .24568 .49267 .25651 .49666 .24901 .48751 Mtetra
.241 .5 .9 r
.24901 .48751 .25651 .49666 .26744 .50078 .25995 .49147 Mtetra
.242 .498 .898 r
.25995 .49147 .26744 .50078 .27847 .50498 .27099 .49552 Mtetra
.248 .497 .897 r
.27099 .49552 .27847 .50498 .2896 .50922 .28213 .49961 Mtetra
.257 .499 .896 r
.28213 .49961 .2896 .50922 .30083 .51344 .29338 .50368 Mtetra
.27 .503 .896 r
.29338 .50368 .30083 .51344 .31218 .5176 .30474 .5077 Mtetra
.285 .508 .896 r
.30474 .5077 .31218 .5176 .32365 .52163 .31622 .51159 Mtetra
.303 .516 .896 r
.31622 .51159 .32365 .52163 .33523 .52549 .32781 .51532 Mtetra
.324 .525 .897 r
.32781 .51532 .33523 .52549 .34694 .52911 .33952 .51881 Mtetra
.347 .535 .897 r
.33952 .51881 .34694 .52911 .35876 .53244 .35136 .52203 Mtetra
.371 .546 .897 r
.35136 .52203 .35876 .53244 .37071 .53542 .36332 .52491 Mtetra
.396 .558 .897 r
.36332 .52491 .37071 .53542 .38278 .538 .3754 .5274 Mtetra
.422 .57 .896 r
.3754 .5274 .38278 .538 .39498 .54013 .38761 .52944 Mtetra
.448 .582 .895 r
.38761 .52944 .39498 .54013 .40729 .54175 .39993 .531 Mtetra
.474 .595 .894 r
.39993 .531 .40729 .54175 .41972 .54282 .41237 .53202 Mtetra
.499 .607 .891 r
.41237 .53202 .41972 .54282 .43226 .5433 .42493 .53246 Mtetra
.524 .619 .889 r
.42493 .53246 .43226 .5433 .4449 .54315 .43759 .53229 Mtetra
.548 .631 .886 r
.43759 .53229 .4449 .54315 .45765 .54235 .45036 .53147 Mtetra
.571 .642 .882 r
.45036 .53147 .45765 .54235 .4705 .54086 .46322 .52999 Mtetra
.593 .653 .878 r
.46322 .52999 .4705 .54086 .48343 .53866 .47617 .52781 Mtetra
.613 .663 .874 r
.47617 .52781 .48343 .53866 .49644 .53575 .48921 .52493 Mtetra
.633 .673 .87 r
.48921 .52493 .49644 .53575 .50953 .53211 .50233 .52134 Mtetra
.651 .682 .866 r
.50233 .52134 .50953 .53211 .52269 .52775 .51551 .51702 Mtetra
.669 .691 .862 r
.51551 .51702 .52269 .52775 .5359 .52266 .52876 .512 Mtetra
.685 .699 .857 r
.52876 .512 .5359 .52266 .54917 .51686 .54205 .50628 Mtetra
.699 .707 .853 r
.54205 .50628 .54917 .51686 .56247 .51036 .5554 .49986 Mtetra
.713 .714 .849 r
.5554 .49986 .56247 .51036 .57581 .50319 .56878 .49278 Mtetra
.726 .721 .845 r
.56878 .49278 .57581 .50319 .58918 .49538 .58219 .48506 Mtetra
.738 .727 .842 r
.58219 .48506 .58918 .49538 .60258 .48694 .59563 .47672 Mtetra
.748 .734 .838 r
.59563 .47672 .60258 .48694 .61598 .47793 .60908 .4678 Mtetra
.758 .739 .835 r
.60908 .4678 .61598 .47793 .6294 .46837 .62254 .45834 Mtetra
.767 .745 .832 r
.62254 .45834 .6294 .46837 .64282 .45831 .63602 .44838 Mtetra
.775 .75 .83 r
.63602 .44838 .64282 .45831 .65624 .4478 .64949 .43795 Mtetra
.783 .755 .828 r
.64949 .43795 .65624 .4478 .66965 .43687 .66296 .42712 Mtetra
.789 .759 .826 r
.66296 .42712 .66965 .43687 .68306 .42558 .67643 .41592 Mtetra
.795 .763 .824 r
.67643 .41592 .68306 .42558 .69646 .41398 .68989 .4044 Mtetra
.8 .767 .823 r
.68989 .4044 .69646 .41398 .70986 .40211 .70334 .39261 Mtetra
.804 .771 .822 r
.70334 .39261 .70986 .40211 .72324 .39003 .71678 .38059 Mtetra
.808 .774 .822 r
.71678 .38059 .72324 .39003 .73661 .37778 .73022 .36841 Mtetra
.81 .777 .822 r
.73022 .36841 .73661 .37778 .74997 .36542 .74365 .35609 Mtetra
.813 .78 .822 r
.74365 .35609 .74997 .36542 .76333 .35297 .75707 .3437 Mtetra
.814 .783 .823 r
.75707 .3437 .76333 .35297 .77669 .34051 .77049 .33127 Mtetra
.815 .785 .824 r
.77049 .33127 .77669 .34051 .79004 .32805 .7839 .31885 Mtetra
.815 .787 .826 r
.7839 .31885 .79004 .32805 .80339 .31565 .79732 .30647 Mtetra
.815 .788 .828 r
.79732 .30647 .80339 .31565 .81676 .30334 .81075 .29418 Mtetra
.814 .79 .83 r
.81075 .29418 .81676 .30334 .83013 .29116 .82419 .28201 Mtetra
.307 .548 .918 r
.18795 .46159 .19556 .4703 .2061 .47328 .19851 .4644 Mtetra
.293 .537 .913 r
.19851 .4644 .2061 .47328 .21671 .47653 .20914 .46748 Mtetra
.283 .526 .909 r
.20914 .46748 .21671 .47653 .2274 .48 .21984 .47077 Mtetra
.275 .518 .905 r
.21984 .47077 .2274 .48 .23816 .48367 .23062 .47427 Mtetra
.27 .511 .901 r
.23062 .47427 .23816 .48367 .24901 .48751 .24149 .47793 Mtetra
.269 .506 .898 r
.24149 .47793 .24901 .48751 .25995 .49147 .25245 .48171 Mtetra
.271 .503 .895 r
.25245 .48171 .25995 .49147 .27099 .49552 .2635 .48558 Mtetra
.277 .502 .893 r
.2635 .48558 .27099 .49552 .28213 .49961 .27465 .48948 Mtetra
.286 .503 .891 r
.27465 .48948 .28213 .49961 .29338 .50368 .28591 .49338 Mtetra
.298 .505 .89 r
.28591 .49338 .29338 .50368 .30474 .5077 .29728 .49722 Mtetra
.312 .51 .889 r
.29728 .49722 .30474 .5077 .31622 .51159 .30877 .50095 Mtetra
.329 .516 .888 r
.30877 .50095 .31622 .51159 .32781 .51532 .32037 .50451 Mtetra
.348 .523 .887 r
.32037 .50451 .32781 .51532 .33952 .51881 .3321 .50786 Mtetra
.369 .532 .887 r
.3321 .50786 .33952 .51881 .35136 .52203 .34394 .51093 Mtetra
.391 .541 .886 r
.34394 .51093 .35136 .52203 .36332 .52491 .35591 .51368 Mtetra
.413 .551 .885 r
.35591 .51368 .36332 .52491 .3754 .5274 .368 .51605 Mtetra
.437 .562 .883 r
.368 .51605 .3754 .5274 .38761 .52944 .38022 .51799 Mtetra
.46 .573 .881 r
.38022 .51799 .38761 .52944 .39993 .531 .39255 .51945 Mtetra
.484 .584 .879 r
.39255 .51945 .39993 .531 .41237 .53202 .40501 .5204 Mtetra
.507 .595 .876 r
.40501 .5204 .41237 .53202 .42493 .53246 .41757 .52078 Mtetra
.529 .605 .873 r
.41757 .52078 .42493 .53246 .43759 .53229 .43025 .52057 Mtetra
.551 .616 .87 r
.43025 .52057 .43759 .53229 .45036 .53147 .44303 .51973 Mtetra
.572 .626 .867 r
.44303 .51973 .45036 .53147 .46322 .52999 .45591 .51823 Mtetra
.592 .636 .863 r
.45591 .51823 .46322 .52999 .47617 .52781 .46888 .51606 Mtetra
.612 .646 .86 r
.46888 .51606 .47617 .52781 .48921 .52493 .48194 .51321 Mtetra
.63 .655 .856 r
.48194 .51321 .48921 .52493 .50233 .52134 .49508 .50965 Mtetra
.647 .664 .852 r
.49508 .50965 .50233 .52134 .51551 .51702 .50829 .50539 Mtetra
.663 .672 .848 r
.50829 .50539 .51551 .51702 .52876 .512 .52156 .50043 Mtetra
.678 .68 .845 r
.52156 .50043 .52876 .512 .54205 .50628 .53489 .49478 Mtetra
.692 .688 .841 r
.53489 .49478 .54205 .50628 .5554 .49986 .54826 .48845 Mtetra
.705 .695 .838 r
.54826 .48845 .5554 .49986 .56878 .49278 .56168 .48146 Mtetra
.718 .702 .834 r
.56168 .48146 .56878 .49278 .58219 .48506 .57513 .47383 Mtetra
.729 .709 .831 r
.57513 .47383 .58219 .48506 .59563 .47672 .58861 .4656 Mtetra
.74 .715 .829 r
.58861 .4656 .59563 .47672 .60908 .4678 .6021 .45679 Mtetra
.749 .721 .826 r
.6021 .45679 .60908 .4678 .62254 .45834 .61562 .44744 Mtetra
.758 .727 .824 r
.61562 .44744 .62254 .45834 .63602 .44838 .62914 .43759 Mtetra
.766 .732 .822 r
.62914 .43759 .63602 .44838 .64949 .43795 .64266 .42729 Mtetra
.773 .737 .82 r
.64266 .42729 .64949 .43795 .66296 .42712 .65619 .41656 Mtetra
.78 .742 .818 r
.65619 .41656 .66296 .42712 .67643 .41592 .66971 .40547 Mtetra
.786 .747 .817 r
.66971 .40547 .67643 .41592 .68989 .4044 .68323 .39405 Mtetra
.791 .751 .817 r
.68323 .39405 .68989 .4044 .70334 .39261 .69674 .38236 Mtetra
.796 .755 .816 r
.69674 .38236 .70334 .39261 .71678 .38059 .71024 .37044 Mtetra
.799 .759 .816 r
.71024 .37044 .71678 .38059 .73022 .36841 .72374 .35835 Mtetra
.803 .763 .816 r
.72374 .35835 .73022 .36841 .74365 .35609 .73723 .34612 Mtetra
.805 .766 .817 r
.73723 .34612 .74365 .35609 .75707 .3437 .75071 .3338 Mtetra
.807 .769 .818 r
.75071 .3338 .75707 .3437 .77049 .33127 .76419 .32144 Mtetra
.808 .772 .819 r
.76419 .32144 .77049 .33127 .7839 .31885 .77767 .30908 Mtetra
.809 .774 .821 r
.77767 .30908 .7839 .31885 .79732 .30647 .79116 .29676 Mtetra
.809 .777 .823 r
.79116 .29676 .79732 .30647 .81075 .29418 .80465 .28451 Mtetra
.808 .779 .826 r
.80465 .28451 .81075 .29418 .82419 .28201 .81816 .27238 Mtetra
.328 .553 .916 r
.18031 .45258 .18795 .46159 .19851 .4644 .1909 .45521 Mtetra
.316 .542 .911 r
.1909 .45521 .19851 .4644 .20914 .46748 .20155 .45809 Mtetra
.307 .532 .907 r
.20155 .45809 .20914 .46748 .21984 .47077 .21227 .46119 Mtetra
.3 .523 .902 r
.21227 .46119 .21984 .47077 .23062 .47427 .22306 .46448 Mtetra
.297 .516 .898 r
.22306 .46448 .23062 .47427 .24149 .47793 .23395 .46793 Mtetra
.296 .511 .895 r
.23395 .46793 .24149 .47793 .25245 .48171 .24492 .47151 Mtetra
.298 .508 .891 r
.24492 .47151 .25245 .48171 .2635 .48558 .25599 .47517 Mtetra
.304 .506 .889 r
.25599 .47517 .2635 .48558 .27465 .48948 .26715 .47887 Mtetra
.312 .506 .886 r
.26715 .47887 .27465 .48948 .28591 .49338 .27843 .48256 Mtetra
.323 .508 .884 r
.27843 .48256 .28591 .49338 .29728 .49722 .28981 .4862 Mtetra
.336 .511 .882 r
.28981 .4862 .29728 .49722 .30877 .50095 .30131 .48973 Mtetra
.352 .516 .88 r
.30131 .48973 .30877 .50095 .32037 .50451 .31292 .49311 Mtetra
.369 .522 .878 r
.31292 .49311 .32037 .50451 .3321 .50786 .32466 .49628 Mtetra
.388 .529 .877 r
.32466 .49628 .3321 .50786 .34394 .51093 .33651 .49918 Mtetra
.408 .537 .875 r
.33651 .49918 .34394 .51093 .35591 .51368 .34849 .50177 Mtetra
.429 .546 .873 r
.34849 .50177 .35591 .51368 .368 .51605 .36059 .504 Mtetra
.45 .555 .871 r
.36059 .504 .368 .51605 .38022 .51799 .37282 .50581 Mtetra
.471 .564 .868 r
.37282 .50581 .38022 .51799 .39255 .51945 .38516 .50716 Mtetra
.493 .574 .866 r
.38516 .50716 .39255 .51945 .40501 .5204 .39762 .50801 Mtetra
.514 .584 .863 r
.39762 .50801 .40501 .5204 .41757 .52078 .4102 .50832 Mtetra
.534 .593 .86 r
.4102 .50832 .41757 .52078 .43025 .52057 .42289 .50804 Mtetra
.554 .603 .857 r
.42289 .50804 .43025 .52057 .44303 .51973 .43568 .50716 Mtetra
.573 .612 .853 r
.43568 .50716 .44303 .51973 .45591 .51823 .44857 .50564 Mtetra
.592 .621 .85 r
.44857 .50564 .45591 .51823 .46888 .51606 .46156 .50347 Mtetra
.61 .63 .846 r
.46156 .50347 .46888 .51606 .48194 .51321 .47464 .50062 Mtetra
.626 .639 .843 r
.47464 .50062 .48194 .51321 .49508 .50965 .48779 .49709 Mtetra
.642 .647 .84 r
.48779 .49709 .49508 .50965 .50829 .50539 .50102 .49287 Mtetra
.658 .655 .836 r
.50102 .49287 .50829 .50539 .52156 .50043 .51432 .48797 Mtetra
.672 .663 .833 r
.51432 .48797 .52156 .50043 .53489 .49478 .52767 .48239 Mtetra
.685 .671 .83 r
.52767 .48239 .53489 .49478 .54826 .48845 .54108 .47615 Mtetra
.698 .678 .827 r
.54108 .47615 .54826 .48845 .56168 .48146 .55453 .46926 Mtetra
.71 .685 .824 r
.55453 .46926 .56168 .48146 .57513 .47383 .56801 .46174 Mtetra
.721 .692 .822 r
.56801 .46174 .57513 .47383 .58861 .4656 .58153 .45362 Mtetra
.731 .698 .819 r
.58153 .45362 .58861 .4656 .6021 .45679 .59506 .44493 Mtetra
.74 .704 .817 r
.59506 .44493 .6021 .45679 .61562 .44744 .60862 .43571 Mtetra
.749 .71 .815 r
.60862 .43571 .61562 .44744 .62914 .43759 .62218 .42599 Mtetra
.757 .716 .814 r
.62218 .42599 .62914 .43759 .64266 .42729 .63576 .41581 Mtetra
.765 .722 .812 r
.63576 .41581 .64266 .42729 .65619 .41656 .64933 .40522 Mtetra
.771 .727 .811 r
.64933 .40522 .65619 .41656 .66971 .40547 .66291 .39426 Mtetra
.777 .732 .811 r
.66291 .39426 .66971 .40547 .68323 .39405 .67648 .38297 Mtetra
.783 .736 .81 r
.67648 .38297 .68323 .39405 .69674 .38236 .69005 .3714 Mtetra
.787 .741 .81 r
.69005 .3714 .69674 .38236 .71024 .37044 .70361 .3596 Mtetra
.791 .745 .81 r
.70361 .3596 .71024 .37044 .72374 .35835 .71717 .34762 Mtetra
.795 .749 .811 r
.71717 .34762 .72374 .35835 .73723 .34612 .73072 .3355 Mtetra
.797 .753 .812 r
.73072 .3355 .73723 .34612 .75071 .3338 .74427 .32328 Mtetra
.8 .756 .813 r
.74427 .32328 .75071 .3338 .76419 .32144 .75781 .31101 Mtetra
.801 .76 .815 r
.75781 .31101 .76419 .32144 .77767 .30908 .77136 .29874 Mtetra
.802 .763 .817 r
.77136 .29874 .77767 .30908 .79116 .29676 .78491 .2865 Mtetra
.802 .765 .819 r
.78491 .2865 .79116 .29676 .80465 .28451 .79846 .27433 Mtetra
.802 .768 .822 r
.79846 .27433 .80465 .28451 .81816 .27238 .81203 .26227 Mtetra
.349 .557 .913 r
.17265 .4433 .18031 .45258 .1909 .45521 .18325 .44572 Mtetra
.339 .547 .908 r
.18325 .44572 .1909 .45521 .20155 .45809 .19392 .44839 Mtetra
.33 .537 .904 r
.19392 .44839 .20155 .45809 .21227 .46119 .20466 .45127 Mtetra
.324 .529 .899 r
.20466 .45127 .21227 .46119 .22306 .46448 .21548 .45433 Mtetra
.321 .522 .895 r
.21548 .45433 .22306 .46448 .23395 .46793 .22638 .45756 Mtetra
.321 .516 .891 r
.22638 .45756 .23395 .46793 .24492 .47151 .23737 .4609 Mtetra
.323 .512 .887 r
.23737 .4609 .24492 .47151 .25599 .47517 .24846 .46433 Mtetra
.328 .51 .884 r
.24846 .46433 .25599 .47517 .26715 .47887 .25964 .4678 Mtetra
.336 .51 .881 r
.25964 .4678 .26715 .47887 .27843 .48256 .27093 .47126 Mtetra
.346 .511 .878 r
.27093 .47126 .27843 .48256 .28981 .4862 .28233 .47467 Mtetra
.358 .513 .875 r
.28233 .47467 .28981 .4862 .30131 .48973 .29384 .47799 Mtetra
.373 .517 .872 r
.29384 .47799 .30131 .48973 .31292 .49311 .30546 .48115 Mtetra
.388 .522 .87 r
.30546 .48115 .31292 .49311 .32466 .49628 .31721 .48411 Mtetra
.405 .527 .867 r
.31721 .48411 .32466 .49628 .33651 .49918 .32907 .48683 Mtetra
.424 .534 .865 r
.32907 .48683 .33651 .49918 .34849 .50177 .34106 .48924 Mtetra
.442 .541 .862 r
.34106 .48924 .34849 .50177 .36059 .504 .35317 .4913 Mtetra
.461 .549 .86 r
.35317 .4913 .36059 .504 .37282 .50581 .3654 .49296 Mtetra
.481 .557 .857 r
.3654 .49296 .37282 .50581 .38516 .50716 .37775 .49418 Mtetra
.5 .566 .854 r
.37775 .49418 .38516 .50716 .39762 .50801 .39022 .49491 Mtetra
.519 .574 .851 r
.39022 .49491 .39762 .50801 .4102 .50832 .40281 .49511 Mtetra
.538 .583 .848 r
.40281 .49511 .4102 .50832 .42289 .50804 .4155 .49476 Mtetra
.556 .592 .844 r
.4155 .49476 .42289 .50804 .43568 .50716 .42831 .49382 Mtetra
.574 .6 .841 r
.42831 .49382 .43568 .50716 .44857 .50564 .44121 .49226 Mtetra
.591 .609 .838 r
.44121 .49226 .44857 .50564 .46156 .50347 .45421 .49007 Mtetra
.608 .617 .835 r
.45421 .49007 .46156 .50347 .47464 .50062 .4673 .48722 Mtetra
.623 .625 .832 r
.4673 .48722 .47464 .50062 .48779 .49709 .48047 .48371 Mtetra
.638 .633 .829 r
.48047 .48371 .48779 .49709 .50102 .49287 .49372 .47953 Mtetra
.653 .641 .826 r
.49372 .47953 .50102 .49287 .51432 .48797 .50704 .47469 Mtetra
.666 .648 .823 r
.50704 .47469 .51432 .48797 .52767 .48239 .52042 .46918 Mtetra
.679 .656 .82 r
.52042 .46918 .52767 .48239 .54108 .47615 .53385 .46302 Mtetra
.691 .663 .818 r
.53385 .46302 .54108 .47615 .55453 .46926 .54732 .45623 Mtetra
.702 .67 .815 r
.54732 .45623 .55453 .46926 .56801 .46174 .56084 .44882 Mtetra
.713 .677 .813 r
.56084 .44882 .56801 .46174 .58153 .45362 .57439 .44083 Mtetra
.723 .683 .811 r
.57439 .44083 .58153 .45362 .59506 .44493 .58796 .43227 Mtetra
.732 .689 .809 r
.58796 .43227 .59506 .44493 .60862 .43571 .60156 .42318 Mtetra
.741 .695 .808 r
.60156 .42318 .60862 .43571 .62218 .42599 .61516 .4136 Mtetra
.749 .701 .807 r
.61516 .4136 .62218 .42599 .63576 .41581 .62878 .40357 Mtetra
.756 .707 .806 r
.62878 .40357 .63576 .41581 .64933 .40522 .64241 .39313 Mtetra
.763 .712 .805 r
.64241 .39313 .64933 .40522 .66291 .39426 .65603 .38231 Mtetra
.769 .718 .805 r
.65603 .38231 .66291 .39426 .67648 .38297 .66966 .37117 Mtetra
.774 .723 .805 r
.66966 .37117 .67648 .38297 .69005 .3714 .68328 .35975 Mtetra
.779 .727 .805 r
.68328 .35975 .69005 .3714 .70361 .3596 .6969 .34809 Mtetra
.783 .732 .805 r
.6969 .34809 .70361 .3596 .71717 .34762 .71051 .33624 Mtetra
.787 .736 .806 r
.71051 .33624 .71717 .34762 .73072 .3355 .72413 .32425 Mtetra
.79 .741 .807 r
.72413 .32425 .73072 .3355 .74427 .32328 .73773 .31216 Mtetra
.792 .744 .809 r
.73773 .31216 .74427 .32328 .75781 .31101 .75134 .30002 Mtetra
.794 .748 .811 r
.75134 .30002 .75781 .31101 .77136 .29874 .76495 .28786 Mtetra
.795 .752 .813 r
.76495 .28786 .77136 .29874 .78491 .2865 .77857 .27573 Mtetra
.796 .755 .815 r
.77857 .27573 .78491 .2865 .79846 .27433 .79219 .26366 Mtetra
.796 .758 .818 r
.79219 .26366 .79846 .27433 .81203 .26227 .80583 .25168 Mtetra
.369 .562 .91 r
.16495 .43376 .17265 .4433 .18325 .44572 .17558 .43596 Mtetra
.36 .552 .905 r
.17558 .43596 .18325 .44572 .19392 .44839 .18628 .43839 Mtetra
.352 .542 .901 r
.18628 .43839 .19392 .44839 .20466 .45127 .19704 .44103 Mtetra
.347 .534 .896 r
.19704 .44103 .20466 .45127 .21548 .45433 .20788 .44386 Mtetra
.344 .527 .892 r
.20788 .44386 .21548 .45433 .22638 .45756 .2188 .44683 Mtetra
.344 .521 .887 r
.2188 .44683 .22638 .45756 .23737 .4609 .22981 .44992 Mtetra
.346 .517 .883 r
.22981 .44992 .23737 .4609 .24846 .46433 .24091 .45309 Mtetra
.351 .514 .879 r
.24091 .45309 .24846 .46433 .25964 .4678 .25211 .45631 Mtetra
.358 .513 .875 r
.25211 .45631 .25964 .4678 .27093 .47126 .26342 .45952 Mtetra
.367 .513 .872 r
.26342 .45952 .27093 .47126 .28233 .47467 .27483 .46268 Mtetra
.379 .515 .868 r
.27483 .46268 .28233 .47467 .29384 .47799 .28635 .46575 Mtetra
.391 .518 .865 r
.28635 .46575 .29384 .47799 .30546 .48115 .29799 .46868 Mtetra
.406 .521 .862 r
.29799 .46868 .30546 .48115 .31721 .48411 .30974 .47142 Mtetra
.421 .526 .859 r
.30974 .47142 .31721 .48411 .32907 .48683 .32162 .47391 Mtetra
.437 .532 .856 r
.32162 .47391 .32907 .48683 .34106 .48924 .33361 .47612 Mtetra
.454 .538 .853 r
.33361 .47612 .34106 .48924 .35317 .4913 .34573 .47799 Mtetra
.472 .544 .85 r
.34573 .47799 .35317 .4913 .3654 .49296 .35797 .47948 Mtetra
.489 .552 .847 r
.35797 .47948 .3654 .49296 .37775 .49418 .37033 .48054 Mtetra
.507 .559 .843 r
.37033 .48054 .37775 .49418 .39022 .49491 .38281 .48114 Mtetra
.525 .567 .84 r
.38281 .48114 .39022 .49491 .40281 .49511 .3954 .48123 Mtetra
.542 .574 .837 r
.3954 .48123 .40281 .49511 .4155 .49476 .4081 .48078 Mtetra
.559 .582 .834 r
.4081 .48078 .4155 .49476 .42831 .49382 .42091 .47976 Mtetra
.575 .59 .831 r
.42091 .47976 .42831 .49382 .44121 .49226 .43383 .47815 Mtetra
.591 .598 .828 r
.43383 .47815 .44121 .49226 .45421 .49007 .44684 .47592 Mtetra
.606 .605 .825 r
.44684 .47592 .45421 .49007 .4673 .48722 .45994 .47306 Mtetra
.621 .613 .822 r
.45994 .47306 .4673 .48722 .48047 .48371 .47312 .46956 Mtetra
.635 .621 .819 r
.47312 .46956 .48047 .48371 .49372 .47953 .48639 .46542 Mtetra
.648 .628 .816 r
.48639 .46542 .49372 .47953 .50704 .47469 .49972 .46062 Mtetra
.661 .635 .814 r
.49972 .46062 .50704 .47469 .52042 .46918 .51312 .45518 Mtetra
.673 .642 .811 r
.51312 .45518 .52042 .46918 .53385 .46302 .52657 .44911 Mtetra
.684 .649 .809 r
.52657 .44911 .53385 .46302 .54732 .45623 .54007 .44242 Mtetra
.695 .656 .807 r
.54007 .44242 .54732 .45623 .56084 .44882 .55362 .43513 Mtetra
.706 .663 .805 r
.55362 .43513 .56084 .44882 .57439 .44083 .5672 .42726 Mtetra
.715 .669 .804 r
.5672 .42726 .57439 .44083 .58796 .43227 .5808 .41884 Mtetra
.724 .676 .802 r
.5808 .41884 .58796 .43227 .60156 .42318 .59443 .4099 Mtetra
.733 .682 .801 r
.59443 .4099 .60156 .42318 .61516 .4136 .60808 .40047 Mtetra
.741 .688 .8 r
.60808 .40047 .61516 .4136 .62878 .40357 .62174 .3906 Mtetra
.748 .694 .8 r
.62174 .3906 .62878 .40357 .64241 .39313 .63541 .38032 Mtetra
.754 .699 .799 r
.63541 .38032 .64241 .39313 .65603 .38231 .64908 .36967 Mtetra
.761 .705 .799 r
.64908 .36967 .65603 .38231 .66966 .37117 .66276 .35869 Mtetra
.766 .71 .8 r
.66276 .35869 .66966 .37117 .68328 .35975 .67644 .34743 Mtetra
.771 .715 .8 r
.67644 .34743 .68328 .35975 .6969 .34809 .69011 .33594 Mtetra
.775 .72 .801 r
.69011 .33594 .6969 .34809 .71051 .33624 .70378 .32425 Mtetra
.779 .725 .802 r
.70378 .32425 .71051 .33624 .72413 .32425 .71745 .31242 Mtetra
.782 .729 .803 r
.71745 .31242 .72413 .32425 .73773 .31216 .73112 .30048 Mtetra
.785 .733 .805 r
.73112 .30048 .73773 .31216 .75134 .30002 .74479 .28848 Mtetra
.787 .737 .807 r
.74479 .28848 .75134 .30002 .76495 .28786 .75847 .27645 Mtetra
.788 .741 .809 r
.75847 .27645 .76495 .28786 .77857 .27573 .77214 .26445 Mtetra
.789 .745 .812 r
.77214 .26445 .77857 .27573 .79219 .26366 .78583 .2525 Mtetra
.79 .748 .815 r
.78583 .2525 .79219 .26366 .80583 .25168 .79954 .24064 Mtetra
.388 .567 .907 r
.15723 .42399 .16495 .43376 .17558 .43596 .16788 .42595 Mtetra
.38 .557 .902 r
.16788 .42595 .17558 .43596 .18628 .43839 .1786 .42813 Mtetra
.373 .548 .898 r
.1786 .42813 .18628 .43839 .19704 .44103 .18939 .43051 Mtetra
.368 .539 .893 r
.18939 .43051 .19704 .44103 .20788 .44386 .20025 .43307 Mtetra
.366 .532 .888 r
.20025 .43307 .20788 .44386 .2188 .44683 .2112 .43578 Mtetra
.365 .526 .883 r
.2112 .43578 .2188 .44683 .22981 .44992 .22223 .4386 Mtetra
.368 .522 .879 r
.22223 .4386 .22981 .44992 .24091 .45309 .23335 .4415 Mtetra
.372 .519 .875 r
.23335 .4415 .24091 .45309 .25211 .45631 .24457 .44444 Mtetra
.378 .517 .87 r
.24457 .44444 .25211 .45631 .26342 .45952 .25589 .44737 Mtetra
.387 .517 .866 r
.25589 .44737 .26342 .45952 .27483 .46268 .26731 .45027 Mtetra
.397 .517 .862 r
.26731 .45027 .27483 .46268 .28635 .46575 .27885 .45307 Mtetra
.408 .519 .859 r
.27885 .45307 .28635 .46575 .29799 .46868 .2905 .45574 Mtetra
.421 .522 .855 r
.2905 .45574 .29799 .46868 .30974 .47142 .30227 .45823 Mtetra
.435 .526 .851 r
.30227 .45823 .30974 .47142 .32162 .47391 .31415 .46049 Mtetra
.45 .53 .848 r
.31415 .46049 .32162 .47391 .33361 .47612 .32616 .46247 Mtetra
.465 .535 .844 r
.32616 .46247 .33361 .47612 .34573 .47799 .33828 .46414 Mtetra
.481 .541 .841 r
.33828 .46414 .34573 .47799 .35797 .47948 .35053 .46543 Mtetra
.497 .547 .838 r
.35053 .46543 .35797 .47948 .37033 .48054 .36289 .46632 Mtetra
.513 .554 .834 r
.36289 .46632 .37033 .48054 .38281 .48114 .37538 .46676 Mtetra
.529 .56 .831 r
.37538 .46676 .38281 .48114 .3954 .48123 .38798 .46672 Mtetra
.545 .567 .828 r
.38798 .46672 .3954 .48123 .4081 .48078 .40069 .46616 Mtetra
.56 .574 .825 r
.40069 .46616 .4081 .48078 .42091 .47976 .4135 .46505 Mtetra
.576 .581 .822 r
.4135 .46505 .42091 .47976 .43383 .47815 .42642 .46337 Mtetra
.59 .589 .819 r
.42642 .46337 .43383 .47815 .44684 .47592 .43944 .4611 Mtetra
.604 .596 .816 r
.43944 .4611 .44684 .47592 .45994 .47306 .45255 .45822 Mtetra
.618 .603 .813 r
.45255 .45822 .45994 .47306 .47312 .46956 .46575 .45472 Mtetra
.631 .61 .811 r
.46575 .45472 .47312 .46956 .48639 .46542 .47902 .4506 Mtetra
.644 .617 .808 r
.47902 .4506 .48639 .46542 .49972 .46062 .49237 .44585 Mtetra
.656 .624 .806 r
.49237 .44585 .49972 .46062 .51312 .45518 .50579 .44047 Mtetra
.667 .631 .804 r
.50579 .44047 .51312 .45518 .52657 .44911 .51926 .43448 Mtetra
.678 .638 .802 r
.51926 .43448 .52657 .44911 .54007 .44242 .53278 .42789 Mtetra
.689 .644 .8 r
.53278 .42789 .54007 .44242 .55362 .43513 .54635 .42072 Mtetra
.699 .651 .799 r
.54635 .42072 .55362 .43513 .5672 .42726 .55996 .41298 Mtetra
.708 .657 .797 r
.55996 .41298 .5672 .42726 .5808 .41884 .57359 .4047 Mtetra
.717 .664 .796 r
.57359 .4047 .5808 .41884 .59443 .4099 .58726 .39591 Mtetra
.725 .67 .795 r
.58726 .39591 .59443 .4099 .60808 .40047 .60094 .38665 Mtetra
.733 .676 .795 r
.60094 .38665 .60808 .40047 .62174 .3906 .61464 .37695 Mtetra
.74 .682 .795 r
.61464 .37695 .62174 .3906 .63541 .38032 .62835 .36684 Mtetra
.747 .687 .794 r
.62835 .36684 .63541 .38032 .64908 .36967 .64207 .35637 Mtetra
.753 .693 .795 r
.64207 .35637 .64908 .36967 .66276 .35869 .65579 .34557 Mtetra
.758 .699 .795 r
.65579 .34557 .66276 .35869 .67644 .34743 .66952 .33449 Mtetra
.763 .704 .796 r
.66952 .33449 .67644 .34743 .69011 .33594 .68325 .32318 Mtetra
.768 .709 .797 r
.68325 .32318 .69011 .33594 .70378 .32425 .69697 .31167 Mtetra
.772 .714 .798 r
.69697 .31167 .70378 .32425 .71745 .31242 .7107 .30001 Mtetra
.775 .719 .8 r
.7107 .30001 .71745 .31242 .73112 .30048 .72443 .28824 Mtetra
.778 .723 .802 r
.72443 .28824 .73112 .30048 .74479 .28848 .73816 .27641 Mtetra
.78 .727 .804 r
.73816 .27641 .74479 .28848 .75847 .27645 .7519 .26455 Mtetra
.782 .732 .806 r
.7519 .26455 .75847 .27645 .77214 .26445 .76564 .2527 Mtetra
.783 .735 .809 r
.76564 .2527 .77214 .26445 .78583 .2525 .7794 .24089 Mtetra
.783 .739 .812 r
.7794 .24089 .78583 .2525 .79954 .24064 .79316 .22917 Mtetra
.407 .572 .904 r
.14946 .41401 .15723 .42399 .16788 .42595 .16015 .41571 Mtetra
.399 .562 .9 r
.16015 .41571 .16788 .42595 .1786 .42813 .17089 .41763 Mtetra
.392 .553 .895 r
.17089 .41763 .1786 .42813 .18939 .43051 .18171 .41974 Mtetra
.388 .545 .89 r
.18171 .41974 .18939 .43051 .20025 .43307 .1926 .42202 Mtetra
.386 .538 .885 r
.1926 .42202 .20025 .43307 .2112 .43578 .20357 .42444 Mtetra
.386 .532 .88 r
.20357 .42444 .2112 .43578 .22223 .4386 .21462 .42697 Mtetra
.387 .527 .875 r
.21462 .42697 .22223 .4386 .23335 .4415 .22576 .42958 Mtetra
.391 .523 .87 r
.22576 .42958 .23335 .4415 .24457 .44444 .237 .43223 Mtetra
.397 .521 .866 r
.237 .43223 .24457 .44444 .25589 .44737 .24834 .43487 Mtetra
.405 .52 .861 r
.24834 .43487 .25589 .44737 .26731 .45027 .25979 .43748 Mtetra
.414 .52 .857 r
.25979 .43748 .26731 .45027 .27885 .45307 .27134 .44 Mtetra
.424 .521 .853 r
.27134 .44 .27885 .45307 .2905 .45574 .283 .4424 Mtetra
.436 .523 .849 r
.283 .4424 .2905 .45574 .30227 .45823 .29478 .44462 Mtetra
.448 .526 .845 r
.29478 .44462 .30227 .45823 .31415 .46049 .30668 .44662 Mtetra
.462 .529 .841 r
.30668 .44662 .31415 .46049 .32616 .46247 .31869 .44836 Mtetra
.476 .534 .837 r
.31869 .44836 .32616 .46247 .33828 .46414 .33082 .4498 Mtetra
.49 .538 .834 r
.33082 .4498 .33828 .46414 .35053 .46543 .34308 .45088 Mtetra
.504 .544 .83 r
.34308 .45088 .35053 .46543 .36289 .46632 .35545 .45158 Mtetra
.519 .549 .827 r
.35545 .45158 .36289 .46632 .37538 .46676 .36794 .45185 Mtetra
.534 .555 .823 r
.36794 .45185 .37538 .46676 .38798 .46672 .38054 .45165 Mtetra
.548 .561 .82 r
.38054 .45165 .38798 .46672 .40069 .46616 .39325 .45096 Mtetra
.562 .568 .817 r
.39325 .45096 .40069 .46616 .4135 .46505 .40608 .44975 Mtetra
.576 .574 .814 r
.40608 .44975 .4135 .46505 .42642 .46337 .419 .44799 Mtetra
.59 .581 .811 r
.419 .44799 .42642 .46337 .43944 .4611 .43203 .44566 Mtetra
.603 .588 .808 r
.43203 .44566 .43944 .4611 .45255 .45822 .44514 .44275 Mtetra
.616 .594 .806 r
.44514 .44275 .45255 .45822 .46575 .45472 .45835 .43925 Mtetra
.628 .601 .803 r
.45835 .43925 .46575 .45472 .47902 .4506 .47163 .43514 Mtetra
.64 .608 .801 r
.47163 .43514 .47902 .4506 .49237 .44585 .48499 .43042 Mtetra
.652 .614 .799 r
.48499 .43042 .49237 .44585 .50579 .44047 .49842 .42511 Mtetra
.662 .621 .797 r
.49842 .42511 .50579 .44047 .51926 .43448 .51191 .4192 Mtetra
.673 .627 .796 r
.51191 .4192 .51926 .43448 .53278 .42789 .52545 .41271 Mtetra
.683 .634 .794 r
.52545 .41271 .53278 .42789 .54635 .42072 .53904 .40565 Mtetra
.692 .64 .793 r
.53904 .40565 .54635 .42072 .55996 .41298 .55267 .39804 Mtetra
.701 .647 .792 r
.55267 .39804 .55996 .41298 .57359 .4047 .56634 .38991 Mtetra
.71 .653 .791 r
.56634 .38991 .57359 .4047 .58726 .39591 .58003 .38128 Mtetra
.718 .659 .79 r
.58003 .38128 .58726 .39591 .60094 .38665 .59375 .37219 Mtetra
.726 .665 .79 r
.59375 .37219 .60094 .38665 .61464 .37695 .60748 .36266 Mtetra
.733 .671 .79 r
.60748 .36266 .61464 .37695 .62835 .36684 .62123 .35274 Mtetra
.739 .677 .79 r
.62123 .35274 .62835 .36684 .64207 .35637 .635 .34246 Mtetra
.745 .683 .791 r
.635 .34246 .64207 .35637 .65579 .34557 .64876 .33186 Mtetra
.751 .688 .791 r
.64876 .33186 .65579 .34557 .66952 .33449 .66254 .32098 Mtetra
.756 .694 .792 r
.66254 .32098 .66952 .33449 .68325 .32318 .67632 .30986 Mtetra
.76 .699 .793 r
.67632 .30986 .68325 .32318 .69697 .31167 .6901 .29855 Mtetra
.764 .704 .795 r
.6901 .29855 .69697 .31167 .7107 .30001 .70388 .28708 Mtetra
.768 .709 .797 r
.70388 .28708 .7107 .30001 .72443 .28824 .71767 .2755 Mtetra
.771 .714 .799 r
.71767 .2755 .72443 .28824 .73816 .27641 .73146 .26385 Mtetra
.773 .718 .801 r
.73146 .26385 .73816 .27641 .7519 .26455 .74526 .25217 Mtetra
.775 .723 .804 r
.74526 .25217 .7519 .26455 .76564 .2527 .75906 .24049 Mtetra
.776 .727 .807 r
.75906 .24049 .76564 .2527 .7794 .24089 .77288 .22885 Mtetra
.777 .731 .81 r
.77288 .22885 .7794 .24089 .79316 .22917 .78672 .21728 Mtetra
.424 .578 .902 r
.14167 .40383 .14946 .41401 .16015 .41571 .15238 .40527 Mtetra
.416 .568 .897 r
.15238 .40527 .16015 .41571 .17089 .41763 .16316 .40691 Mtetra
.411 .559 .892 r
.16316 .40691 .17089 .41763 .18171 .41974 .174 .40874 Mtetra
.407 .551 .887 r
.174 .40874 .18171 .41974 .1926 .42202 .18492 .41072 Mtetra
.404 .544 .882 r
.18492 .41072 .1926 .42202 .20357 .42444 .19591 .41285 Mtetra
.404 .537 .877 r
.19591 .41285 .20357 .42444 .21462 .42697 .20699 .41508 Mtetra
.406 .532 .872 r
.20699 .41508 .21462 .42697 .22576 .42958 .21816 .41738 Mtetra
.409 .528 .867 r
.21816 .41738 .22576 .42958 .237 .43223 .22942 .41972 Mtetra
.414 .526 .862 r
.22942 .41972 .237 .43223 .24834 .43487 .24078 .42206 Mtetra
.421 .524 .857 r
.24078 .42206 .24834 .43487 .25979 .43748 .25224 .42436 Mtetra
.429 .523 .852 r
.25224 .42436 .25979 .43748 .27134 .44 .26381 .42658 Mtetra
.439 .523 .848 r
.26381 .42658 .27134 .44 .283 .4424 .27549 .42869 Mtetra
.449 .525 .843 r
.27549 .42869 .283 .4424 .29478 .44462 .28728 .43062 Mtetra
.46 .527 .839 r
.28728 .43062 .29478 .44462 .30668 .44662 .29919 .43236 Mtetra
.472 .529 .835 r
.29919 .43236 .30668 .44662 .31869 .44836 .31121 .43384 Mtetra
.485 .533 .831 r
.31121 .43384 .31869 .44836 .33082 .4498 .32335 .43503 Mtetra
.498 .537 .827 r
.32335 .43503 .33082 .4498 .34308 .45088 .33561 .43589 Mtetra
.511 .541 .824 r
.33561 .43589 .34308 .45088 .35545 .45158 .34799 .43638 Mtetra
.525 .546 .82 r
.34799 .43638 .35545 .45158 .36794 .45185 .36048 .43646 Mtetra
.538 .551 .817 r
.36048 .43646 .36794 .45185 .38054 .45165 .37309 .4361 Mtetra
.551 .557 .813 r
.37309 .4361 .38054 .45165 .39325 .45096 .38581 .43527 Mtetra
.564 .563 .81 r
.38581 .43527 .39325 .45096 .40608 .44975 .39864 .43394 Mtetra
.577 .569 .807 r
.39864 .43394 .40608 .44975 .419 .44799 .41157 .43209 Mtetra
.59 .575 .805 r
.41157 .43209 .419 .44799 .43203 .44566 .42459 .42969 Mtetra
.602 .581 .802 r
.42459 .42969 .43203 .44566 .44514 .44275 .43772 .42674 Mtetra
.614 .587 .799 r
.43772 .42674 .44514 .44275 .45835 .43925 .45093 .42321 Mtetra
.626 .593 .797 r
.45093 .42321 .45835 .43925 .47163 .43514 .46422 .41911 Mtetra
.637 .6 .795 r
.46422 .41911 .47163 .43514 .48499 .43042 .47759 .41443 Mtetra
.648 .606 .793 r
.47759 .41443 .48499 .43042 .49842 .42511 .49103 .40917 Mtetra
.658 .612 .792 r
.49103 .40917 .49842 .42511 .51191 .4192 .50453 .40333 Mtetra
.668 .619 .79 r
.50453 .40333 .51191 .4192 .52545 .41271 .51809 .39694 Mtetra
.678 .625 .789 r
.51809 .39694 .52545 .41271 .53904 .40565 .5317 .38999 Mtetra
.687 .631 .788 r
.5317 .38999 .53904 .40565 .55267 .39804 .54535 .38252 Mtetra
.695 .637 .787 r
.54535 .38252 .55267 .39804 .56634 .38991 .55904 .37454 Mtetra
.704 .643 .787 r
.55904 .37454 .56634 .38991 .58003 .38128 .57276 .36607 Mtetra
.711 .65 .786 r
.57276 .36607 .58003 .38128 .59375 .37219 .58651 .35715 Mtetra
.719 .656 .786 r
.58651 .35715 .59375 .37219 .60748 .36266 .60028 .34781 Mtetra
.726 .661 .786 r
.60028 .34781 .60748 .36266 .62123 .35274 .61406 .33809 Mtetra
.732 .667 .786 r
.61406 .33809 .62123 .35274 .635 .34246 .62786 .328 Mtetra
.738 .673 .787 r
.62786 .328 .635 .34246 .64876 .33186 .64167 .31761 Mtetra
.744 .679 .788 r
.64167 .31761 .64876 .33186 .66254 .32098 .65549 .30694 Mtetra
.749 .684 .789 r
.65549 .30694 .66254 .32098 .67632 .30986 .66932 .29603 Mtetra
.753 .69 .79 r
.66932 .29603 .67632 .30986 .6901 .29855 .68315 .28493 Mtetra
.757 .695 .792 r
.68315 .28493 .6901 .29855 .70388 .28708 .69699 .27367 Mtetra
.761 .7 .794 r
.69699 .27367 .70388 .28708 .71767 .2755 .71083 .2623 Mtetra
.764 .705 .796 r
.71083 .2623 .71767 .2755 .73146 .26385 .72468 .25085 Mtetra
.767 .71 .799 r
.72468 .25085 .73146 .26385 .74526 .25217 .73854 .23936 Mtetra
.769 .714 .802 r
.73854 .23936 .74526 .25217 .75906 .24049 .75241 .22787 Mtetra
.77 .719 .805 r
.75241 .22787 .75906 .24049 .77288 .22885 .7663 .21641 Mtetra
.771 .723 .808 r
.7663 .21641 .77288 .22885 .78672 .21728 .7802 .20502 Mtetra
.44 .583 .899 r
.13383 .39349 .14167 .40383 .15238 .40527 .14458 .39465 Mtetra
.433 .573 .894 r
.14458 .39465 .15238 .40527 .16316 .40691 .15538 .39601 Mtetra
.428 .565 .889 r
.15538 .39601 .16316 .40691 .174 .40874 .16626 .39754 Mtetra
.424 .557 .884 r
.16626 .39754 .174 .40874 .18492 .41072 .1772 .39922 Mtetra
.422 .549 .879 r
.1772 .39922 .18492 .41072 .19591 .41285 .18823 .40104 Mtetra
.422 .543 .874 r
.18823 .40104 .19591 .41285 .20699 .41508 .19933 .40295 Mtetra
.423 .538 .868 r
.19933 .40295 .20699 .41508 .21816 .41738 .21052 .40493 Mtetra
.426 .533 .863 r
.21052 .40493 .21816 .41738 .22942 .41972 .22181 .40695 Mtetra
.43 .53 .858 r
.22181 .40695 .22942 .41972 .24078 .42206 .23319 .40897 Mtetra
.436 .528 .853 r
.23319 .40897 .24078 .42206 .25224 .42436 .24467 .41096 Mtetra
.444 .527 .848 r
.24467 .41096 .25224 .42436 .26381 .42658 .25626 .41287 Mtetra
.452 .526 .843 r
.25626 .41287 .26381 .42658 .27549 .42869 .26795 .41467 Mtetra
.461 .527 .839 r
.26795 .41467 .27549 .42869 .28728 .43062 .27976 .41631 Mtetra
.471 .528 .834 r
.27976 .41631 .28728 .43062 .29919 .43236 .29168 .41776 Mtetra
.482 .53 .83 r
.29168 .41776 .29919 .43236 .31121 .43384 .30372 .41897 Mtetra
.494 .533 .826 r
.30372 .41897 .31121 .43384 .32335 .43503 .31587 .4199 Mtetra
.506 .536 .822 r
.31587 .4199 .32335 .43503 .33561 .43589 .32813 .42052 Mtetra
.518 .54 .818 r
.32813 .42052 .33561 .43589 .34799 .43638 .34052 .42079 Mtetra
.53 .544 .815 r
.34052 .42079 .34799 .43638 .36048 .43646 .35302 .42067 Mtetra
.542 .549 .811 r
.35302 .42067 .36048 .43646 .37309 .4361 .36563 .42014 Mtetra
.554 .554 .808 r
.36563 .42014 .37309 .4361 .38581 .43527 .37835 .41915 Mtetra
.566 .559 .805 r
.37835 .41915 .38581 .43527 .39864 .43394 .39118 .41769 Mtetra
.578 .564 .802 r
.39118 .41769 .39864 .43394 .41157 .43209 .40411 .41574 Mtetra
.59 .57 .799 r
.40411 .41574 .41157 .43209 .42459 .42969 .41715 .41326 Mtetra
.601 .575 .797 r
.41715 .41326 .42459 .42969 .43772 .42674 .43027 .41025 Mtetra
.613 .581 .794 r
.43027 .41025 .43772 .42674 .45093 .42321 .44349 .4067 Mtetra
.623 .587 .792 r
.44349 .4067 .45093 .42321 .46422 .41911 .45679 .4026 Mtetra
.634 .593 .79 r
.45679 .4026 .46422 .41911 .47759 .41443 .47016 .39794 Mtetra
.644 .599 .789 r
.47016 .39794 .47759 .41443 .49103 .40917 .48361 .39272 Mtetra
.654 .605 .787 r
.48361 .39272 .49103 .40917 .50453 .40333 .49712 .38696 Mtetra
.663 .611 .786 r
.49712 .38696 .50453 .40333 .51809 .39694 .51069 .38065 Mtetra
.673 .617 .785 r
.51069 .38065 .51809 .39694 .5317 .38999 .52432 .37382 Mtetra
.681 .623 .784 r
.52432 .37382 .5317 .38999 .54535 .38252 .53799 .36648 Mtetra
.69 .629 .783 r
.53799 .36648 .54535 .38252 .55904 .37454 .5517 .35865 Mtetra
.698 .635 .783 r
.5517 .35865 .55904 .37454 .57276 .36607 .56544 .35035 Mtetra
.705 .641 .783 r
.56544 .35035 .57276 .36607 .58651 .35715 .57922 .34161 Mtetra
.712 .647 .783 r
.57922 .34161 .58651 .35715 .60028 .34781 .59302 .33246 Mtetra
.719 .653 .783 r
.59302 .33246 .60028 .34781 .61406 .33809 .60684 .32293 Mtetra
.726 .659 .784 r
.60684 .32293 .61406 .33809 .62786 .328 .62068 .31305 Mtetra
.731 .665 .784 r
.62068 .31305 .62786 .328 .64167 .31761 .63453 .30287 Mtetra
.737 .67 .785 r
.63453 .30287 .64167 .31761 .65549 .30694 .64839 .29242 Mtetra
.742 .676 .787 r
.64839 .29242 .65549 .30694 .66932 .29603 .66227 .28173 Mtetra
.747 .682 .788 r
.66227 .28173 .66932 .29603 .68315 .28493 .67615 .27085 Mtetra
.751 .687 .79 r
.67615 .27085 .68315 .28493 .69699 .27367 .69004 .25981 Mtetra
.754 .692 .792 r
.69004 .25981 .69699 .27367 .71083 .2623 .70394 .24866 Mtetra
.757 .697 .794 r
.70394 .24866 .71083 .2623 .72468 .25085 .71784 .23742 Mtetra
.76 .702 .797 r
.71784 .23742 .72468 .25085 .73854 .23936 .73176 .22615 Mtetra
.762 .707 .8 r
.73176 .22615 .73854 .23936 .75241 .22787 .74569 .21486 Mtetra
.764 .712 .803 r
.74569 .21486 .75241 .22787 .7663 .21641 .75964 .2036 Mtetra
.765 .716 .807 r
.75964 .2036 .7663 .21641 .7802 .20502 .77361 .1924 Mtetra
.455 .588 .897 r
.12596 .38301 .13383 .39349 .14458 .39465 .13673 .38389 Mtetra
.449 .579 .892 r
.13673 .38389 .14458 .39465 .15538 .39601 .14757 .38495 Mtetra
.444 .571 .887 r
.14757 .38495 .15538 .39601 .16626 .39754 .15848 .38617 Mtetra
.441 .563 .882 r
.15848 .38617 .16626 .39754 .1772 .39922 .16946 .38755 Mtetra
.439 .555 .876 r
.16946 .38755 .1772 .39922 .18823 .40104 .18051 .38904 Mtetra
.438 .549 .871 r
.18051 .38904 .18823 .40104 .19933 .40295 .19164 .39063 Mtetra
.439 .543 .866 r
.19164 .39063 .19933 .40295 .21052 .40493 .20286 .39229 Mtetra
.442 .539 .86 r
.20286 .39229 .21052 .40493 .22181 .40695 .21417 .39398 Mtetra
.445 .535 .855 r
.21417 .39398 .22181 .40695 .23319 .40897 .22558 .39567 Mtetra
.451 .533 .85 r
.22558 .39567 .23319 .40897 .24467 .41096 .23708 .39733 Mtetra
.457 .531 .845 r
.23708 .39733 .24467 .41096 .25626 .41287 .24869 .39892 Mtetra
.464 .53 .84 r
.24869 .39892 .25626 .41287 .26795 .41467 .2604 .4004 Mtetra
.473 .53 .835 r
.2604 .4004 .26795 .41467 .27976 .41631 .27222 .40173 Mtetra
.482 .531 .831 r
.27222 .40173 .27976 .41631 .29168 .41776 .28416 .40288 Mtetra
.492 .532 .826 r
.28416 .40288 .29168 .41776 .30372 .41897 .2962 .40381 Mtetra
.502 .534 .822 r
.2962 .40381 .30372 .41897 .31587 .4199 .30836 .40448 Mtetra
.513 .537 .818 r
.30836 .40448 .31587 .4199 .32813 .42052 .32064 .40484 Mtetra
.524 .54 .814 r
.32064 .40484 .32813 .42052 .34052 .42079 .33303 .40488 Mtetra
.535 .543 .81 r
.33303 .40488 .34052 .42079 .35302 .42067 .34554 .40455 Mtetra
.546 .547 .807 r
.34554 .40455 .35302 .42067 .36563 .42014 .35815 .40383 Mtetra
.557 .551 .804 r
.35815 .40383 .36563 .42014 .37835 .41915 .37088 .40268 Mtetra
.568 .556 .8 r
.37088 .40268 .37835 .41915 .39118 .41769 .38371 .40108 Mtetra
.579 .561 .798 r
.38371 .40108 .39118 .41769 .40411 .41574 .39664 .399 Mtetra
.59 .566 .795 r
.39664 .399 .40411 .41574 .41715 .41326 .40968 .39644 Mtetra
.601 .571 .793 r
.40968 .39644 .41715 .41326 .43027 .41025 .42281 .39337 Mtetra
.611 .576 .79 r
.42281 .39337 .43027 .41025 .44349 .4067 .43603 .38978 Mtetra
.622 .582 .788 r
.43603 .38978 .44349 .4067 .45679 .4026 .44933 .38567 Mtetra
.631 .588 .786 r
.44933 .38567 .45679 .4026 .47016 .39794 .46271 .38102 Mtetra
.641 .593 .785 r
.46271 .38102 .47016 .39794 .48361 .39272 .47617 .37585 Mtetra
.65 .599 .784 r
.47617 .37585 .48361 .39272 .49712 .38696 .48969 .37015 Mtetra
.659 .605 .782 r
.48969 .37015 .49712 .38696 .51069 .38065 .50327 .36393 Mtetra
.668 .611 .781 r
.50327 .36393 .51069 .38065 .52432 .37382 .51691 .35721 Mtetra
.677 .616 .781 r
.51691 .35721 .52432 .37382 .53799 .36648 .5306 .35 Mtetra
.685 .622 .78 r
.5306 .35 .53799 .36648 .5517 .35865 .54432 .34231 Mtetra
.692 .628 .78 r
.54432 .34231 .5517 .35865 .56544 .35035 .55809 .33417 Mtetra
.7 .634 .78 r
.55809 .33417 .56544 .35035 .57922 .34161 .57189 .32561 Mtetra
.707 .64 .78 r
.57189 .32561 .57922 .34161 .59302 .33246 .58572 .31666 Mtetra
.713 .646 .781 r
.58572 .31666 .59302 .33246 .60684 .32293 .59957 .30733 Mtetra
.719 .652 .781 r
.59957 .30733 .60684 .32293 .62068 .31305 .61345 .29767 Mtetra
.725 .657 .782 r
.61345 .29767 .62068 .31305 .63453 .30287 .62734 .28771 Mtetra
.731 .663 .783 r
.62734 .28771 .63453 .30287 .64839 .29242 .64124 .27748 Mtetra
.736 .669 .785 r
.64124 .27748 .64839 .29242 .66227 .28173 .65516 .26702 Mtetra
.74 .674 .786 r
.65516 .26702 .66227 .28173 .67615 .27085 .66909 .25637 Mtetra
.744 .68 .788 r
.66909 .25637 .67615 .27085 .69004 .25981 .68303 .24556 Mtetra
.748 .685 .791 r
.68303 .24556 .69004 .25981 .70394 .24866 .69698 .23464 Mtetra
.751 .69 .793 r
.69698 .23464 .70394 .24866 .71784 .23742 .71094 .22363 Mtetra
.754 .695 .796 r
.71094 .22363 .71784 .23742 .73176 .22615 .72492 .21257 Mtetra
.756 .7 .799 r
.72492 .21257 .73176 .22615 .74569 .21486 .73891 .2015 Mtetra
.758 .705 .802 r
.73891 .2015 .74569 .21486 .75964 .2036 .75292 .19045 Mtetra
.759 .71 .806 r
.75292 .19045 .75964 .2036 .77361 .1924 .76695 .17945 Mtetra
.47 .594 .895 r
.11804 .37241 .12596 .38301 .13673 .38389 .12885 .37299 Mtetra
.464 .585 .89 r
.12885 .37299 .13673 .38389 .14757 .38495 .13973 .37375 Mtetra
.459 .577 .885 r
.13973 .37375 .14757 .38495 .15848 .38617 .15067 .37467 Mtetra
.456 .569 .88 r
.15067 .37467 .15848 .38617 .16946 .38755 .16168 .37572 Mtetra
.454 .562 .874 r
.16168 .37572 .16946 .38755 .18051 .38904 .17276 .37689 Mtetra
.453 .555 .869 r
.17276 .37689 .18051 .38904 .19164 .39063 .18392 .37815 Mtetra
.454 .549 .864 r
.18392 .37815 .19164 .39063 .20286 .39229 .19517 .37948 Mtetra
.456 .545 .858 r
.19517 .37948 .20286 .39229 .21417 .39398 .20651 .38083 Mtetra
.459 .541 .853 r
.20651 .38083 .21417 .39398 .22558 .39567 .21794 .38219 Mtetra
.464 .538 .847 r
.21794 .38219 .22558 .39567 .23708 .39733 .22946 .38351 Mtetra
.47 .535 .842 r
.22946 .38351 .23708 .39733 .24869 .39892 .24109 .38477 Mtetra
.476 .534 .837 r
.24109 .38477 .24869 .39892 .2604 .4004 .25282 .38593 Mtetra
.484 .533 .832 r
.25282 .38593 .2604 .4004 .27222 .40173 .26466 .38694 Mtetra
.492 .534 .828 r
.26466 .38694 .27222 .40173 .28416 .40288 .27661 .38779 Mtetra
.501 .534 .823 r
.27661 .38779 .28416 .40288 .2962 .40381 .28867 .38842 Mtetra
.51 .536 .819 r
.28867 .38842 .2962 .40381 .30836 .40448 .30084 .38881 Mtetra
.52 .538 .815 r
.30084 .38881 .30836 .40448 .32064 .40484 .31313 .38892 Mtetra
.53 .54 .811 r
.31313 .38892 .32064 .40484 .33303 .40488 .32553 .38872 Mtetra
.54 .543 .807 r
.32553 .38872 .33303 .40488 .34554 .40455 .33804 .38817 Mtetra
.55 .547 .803 r
.33804 .38817 .34554 .40455 .35815 .40383 .35066 .38724 Mtetra
.56 .55 .8 r
.35066 .38724 .35815 .40383 .37088 .40268 .36339 .38592 Mtetra
.571 .554 .797 r
.36339 .38592 .37088 .40268 .38371 .40108 .37622 .38417 Mtetra
.581 .559 .794 r
.37622 .38417 .38371 .40108 .39664 .399 .38916 .38197 Mtetra
.591 .563 .792 r
.38916 .38197 .39664 .399 .40968 .39644 .40219 .37931 Mtetra
.601 .568 .789 r
.40219 .37931 .40968 .39644 .42281 .39337 .41533 .37617 Mtetra
.611 .573 .787 r
.41533 .37617 .42281 .39337 .43603 .38978 .42855 .37253 Mtetra
.62 .578 .785 r
.42855 .37253 .43603 .38978 .44933 .38567 .44185 .3684 Mtetra
.629 .583 .784 r
.44185 .3684 .44933 .38567 .46271 .38102 .45524 .36376 Mtetra
.639 .589 .782 r
.45524 .36376 .46271 .38102 .47617 .37585 .4687 .35862 Mtetra
.647 .594 .781 r
.4687 .35862 .47617 .37585 .48969 .37015 .48223 .35298 Mtetra
.656 .6 .78 r
.48223 .35298 .48969 .37015 .50327 .36393 .49582 .34685 Mtetra
.664 .605 .779 r
.49582 .34685 .50327 .36393 .51691 .35721 .50947 .34023 Mtetra
.672 .611 .778 r
.50947 .34023 .51691 .35721 .5306 .35 .52317 .33314 Mtetra
.68 .617 .778 r
.52317 .33314 .5306 .35 .54432 .34231 .53692 .3256 Mtetra
.687 .622 .778 r
.53692 .3256 .54432 .34231 .55809 .33417 .5507 .31763 Mtetra
.694 .628 .778 r
.5507 .31763 .55809 .33417 .57189 .32561 .56453 .30925 Mtetra
.701 .634 .778 r
.56453 .30925 .57189 .32561 .58572 .31666 .57838 .30048 Mtetra
.708 .64 .779 r
.57838 .30048 .58572 .31666 .59957 .30733 .59226 .29136 Mtetra
.714 .645 .78 r
.59226 .29136 .59957 .30733 .61345 .29767 .60617 .28191 Mtetra
.719 .651 .781 r
.60617 .28191 .61345 .29767 .62734 .28771 .6201 .27218 Mtetra
.725 .657 .782 r
.6201 .27218 .62734 .28771 .64124 .27748 .63404 .26218 Mtetra
.73 .662 .783 r
.63404 .26218 .64124 .27748 .65516 .26702 .648 .25195 Mtetra
.734 .668 .785 r
.648 .25195 .65516 .26702 .66909 .25637 .66197 .24154 Mtetra
.738 .674 .787 r
.66197 .24154 .66909 .25637 .68303 .24556 .67596 .23097 Mtetra
.742 .679 .79 r
.67596 .23097 .68303 .24556 .69698 .23464 .68997 .22028 Mtetra
.745 .684 .792 r
.68997 .22028 .69698 .23464 .71094 .22363 .70398 .20951 Mtetra
.748 .689 .795 r
.70398 .20951 .71094 .22363 .72492 .21257 .71802 .19868 Mtetra
.75 .694 .798 r
.71802 .19868 .72492 .21257 .73891 .2015 .73207 .18784 Mtetra
.752 .699 .802 r
.73207 .18784 .73891 .2015 .75292 .19045 .74614 .17701 Mtetra
.754 .704 .805 r
.74614 .17701 .75292 .19045 .76695 .17945 .76023 .16622 Mtetra
.484 .6 .893 r
.11007 .36171 .11804 .37241 .12885 .37299 .12092 .362 Mtetra
.478 .591 .888 r
.12092 .362 .12885 .37299 .13973 .37375 .13183 .36246 Mtetra
.474 .583 .883 r
.13183 .36246 .13973 .37375 .15067 .37467 .14281 .36306 Mtetra
.471 .575 .878 r
.14281 .36306 .15067 .37467 .16168 .37572 .15385 .36379 Mtetra
.469 .568 .873 r
.15385 .36379 .16168 .37572 .17276 .37689 .16497 .36463 Mtetra
.468 .561 .867 r
.16497 .36463 .17276 .37689 .18392 .37815 .17617 .36556 Mtetra
.468 .556 .862 r
.17617 .36556 .18392 .37815 .19517 .37948 .18744 .36654 Mtetra
.47 .551 .856 r
.18744 .36654 .19517 .37948 .20651 .38083 .19881 .36755 Mtetra
.473 .546 .851 r
.19881 .36755 .20651 .38083 .21794 .38219 .21027 .36857 Mtetra
.477 .543 .846 r
.21027 .36857 .21794 .38219 .22946 .38351 .22182 .36955 Mtetra
.482 .54 .84 r
.22182 .36955 .22946 .38351 .24109 .38477 .23347 .37048 Mtetra
.487 .539 .835 r
.23347 .37048 .24109 .38477 .25282 .38593 .24522 .3713 Mtetra
.494 .538 .83 r
.24522 .3713 .25282 .38593 .26466 .38694 .25708 .372 Mtetra
.501 .537 .825 r
.25708 .372 .26466 .38694 .27661 .38779 .26904 .37253 Mtetra
.509 .537 .821 r
.26904 .37253 .27661 .38779 .28867 .38842 .28112 .37287 Mtetra
.518 .538 .816 r
.28112 .37287 .28867 .38842 .30084 .38881 .2933 .37297 Mtetra
.526 .54 .812 r
.2933 .37297 .30084 .38881 .31313 .38892 .3056 .37282 Mtetra
.535 .542 .808 r
.3056 .37282 .31313 .38892 .32553 .38872 .318 .37236 Mtetra
.545 .544 .805 r
.318 .37236 .32553 .38872 .33804 .38817 .33052 .37159 Mtetra
.554 .547 .801 r
.33052 .37159 .33804 .38817 .35066 .38724 .34314 .37046 Mtetra
.563 .55 .798 r
.34314 .37046 .35066 .38724 .36339 .38592 .35588 .36895 Mtetra
.573 .554 .795 r
.35588 .36895 .36339 .38592 .37622 .38417 .36871 .36704 Mtetra
.582 .558 .792 r
.36871 .36704 .37622 .38417 .38916 .38197 .38165 .36471 Mtetra
.592 .562 .789 r
.38165 .36471 .38916 .38197 .40219 .37931 .39469 .36194 Mtetra
.601 .566 .787 r
.39469 .36194 .40219 .37931 .41533 .37617 .40782 .35872 Mtetra
.61 .571 .785 r
.40782 .35872 .41533 .37617 .42855 .37253 .42105 .35503 Mtetra
.619 .575 .783 r
.42105 .35503 .42855 .37253 .44185 .3684 .43436 .35087 Mtetra
.628 .58 .781 r
.43436 .35087 .44185 .3684 .45524 .36376 .44775 .34624 Mtetra
.636 .585 .78 r
.44775 .34624 .45524 .36376 .4687 .35862 .46121 .34112 Mtetra
.645 .59 .779 r
.46121 .34112 .4687 .35862 .48223 .35298 .47475 .33553 Mtetra
.653 .596 .778 r
.47475 .33553 .48223 .35298 .49582 .34685 .48835 .32947 Mtetra
.661 .601 .777 r
.48835 .32947 .49582 .34685 .50947 .34023 .502 .32295 Mtetra
.668 .606 .777 r
.502 .32295 .50947 .34023 .52317 .33314 .51572 .31599 Mtetra
.676 .612 .776 r
.51572 .31599 .52317 .33314 .53692 .3256 .52948 .30859 Mtetra
.683 .618 .776 r
.52948 .30859 .53692 .3256 .5507 .31763 .54328 .30077 Mtetra
.69 .623 .777 r
.54328 .30077 .5507 .31763 .56453 .30925 .55713 .29257 Mtetra
.696 .629 .777 r
.55713 .29257 .56453 .30925 .57838 .30048 .57101 .284 Mtetra
.703 .634 .778 r
.57101 .284 .57838 .30048 .59226 .29136 .58492 .27508 Mtetra
.708 .64 .779 r
.58492 .27508 .59226 .29136 .60617 .28191 .59885 .26585 Mtetra
.714 .646 .78 r
.59885 .26585 .60617 .28191 .6201 .27218 .61281 .25634 Mtetra
.719 .651 .781 r
.61281 .25634 .6201 .27218 .63404 .26218 .62679 .24657 Mtetra
.724 .657 .783 r
.62679 .24657 .63404 .26218 .648 .25195 .64079 .23658 Mtetra
.729 .663 .785 r
.64079 .23658 .648 .25195 .66197 .24154 .65481 .22641 Mtetra
.733 .668 .787 r
.65481 .22641 .66197 .24154 .67596 .23097 .66885 .21608 Mtetra
.736 .674 .789 r
.66885 .21608 .67596 .23097 .68997 .22028 .6829 .20564 Mtetra
.739 .679 .792 r
.6829 .20564 .68997 .22028 .70398 .20951 .69697 .19511 Mtetra
.742 .684 .795 r
.69697 .19511 .70398 .20951 .71802 .19868 .71106 .18452 Mtetra
.745 .689 .798 r
.71106 .18452 .71802 .19868 .73207 .18784 .72517 .17391 Mtetra
.747 .694 .801 r
.72517 .17391 .73207 .18784 .74614 .17701 .7393 .16331 Mtetra
.748 .699 .805 r
.7393 .16331 .74614 .17701 .76023 .16622 .75345 .15274 Mtetra
.497 .606 .891 r
.10205 .35093 .11007 .36171 .12092 .362 .11294 .35093 Mtetra
.492 .597 .887 r
.11294 .35093 .12092 .362 .13183 .36246 .12389 .35108 Mtetra
.488 .589 .882 r
.12389 .35108 .13183 .36246 .14281 .36306 .13491 .35137 Mtetra
.484 .582 .877 r
.13491 .35137 .14281 .36306 .15385 .36379 .14599 .35178 Mtetra
.482 .574 .871 r
.14599 .35178 .15385 .36379 .16497 .36463 .15714 .35229 Mtetra
.481 .568 .866 r
.15714 .35229 .16497 .36463 .17617 .36556 .16837 .35287 Mtetra
.482 .562 .861 r
.16837 .35287 .17617 .36556 .18744 .36654 .17968 .35352 Mtetra
.483 .557 .855 r
.17968 .35352 .18744 .36654 .19881 .36755 .19107 .35419 Mtetra
.485 .552 .85 r
.19107 .35419 .19881 .36755 .21027 .36857 .20256 .35486 Mtetra
.489 .549 .844 r
.20256 .35486 .21027 .36857 .22182 .36955 .21414 .3555 Mtetra
.493 .546 .839 r
.21414 .3555 .22182 .36955 .23347 .37048 .22581 .35608 Mtetra
.498 .544 .834 r
.22581 .35608 .23347 .37048 .24522 .3713 .23759 .35658 Mtetra
.504 .542 .829 r
.23759 .35658 .24522 .3713 .25708 .372 .24946 .35695 Mtetra
.51 .541 .824 r
.24946 .35695 .25708 .372 .26904 .37253 .26145 .35717 Mtetra
.517 .541 .819 r
.26145 .35717 .26904 .37253 .28112 .37287 .27353 .3572 Mtetra
.525 .542 .815 r
.27353 .3572 .28112 .37287 .2933 .37297 .28573 .35702 Mtetra
.533 .542 .811 r
.28573 .35702 .2933 .37297 .3056 .37282 .29804 .35659 Mtetra
.541 .544 .807 r
.29804 .35659 .3056 .37282 .318 .37236 .31045 .35588 Mtetra
.549 .546 .803 r
.31045 .35588 .318 .37236 .33052 .37159 .32298 .35487 Mtetra
.558 .548 .8 r
.32298 .35487 .33052 .37159 .34314 .37046 .33561 .35353 Mtetra
.567 .551 .796 r
.33561 .35353 .34314 .37046 .35588 .36895 .34835 .35183 Mtetra
.575 .554 .793 r
.34835 .35183 .35588 .36895 .36871 .36704 .36119 .34976 Mtetra
.584 .557 .79 r
.36119 .34976 .36871 .36704 .38165 .36471 .37413 .34729 Mtetra
.593 .561 .788 r
.37413 .34729 .38165 .36471 .39469 .36194 .38717 .34441 Mtetra
.601 .565 .786 r
.38717 .34441 .39469 .36194 .40782 .35872 .4003 .3411 Mtetra
.61 .569 .784 r
.4003 .3411 .40782 .35872 .42105 .35503 .41353 .33735 Mtetra
.618 .574 .782 r
.41353 .33735 .42105 .35503 .43436 .35087 .42684 .33316 Mtetra
.627 .578 .78 r
.42684 .33316 .43436 .35087 .44775 .34624 .44023 .32852 Mtetra
.635 .583 .779 r
.44023 .32852 .44775 .34624 .46121 .34112 .4537 .32342 Mtetra
.643 .588 .778 r
.4537 .32342 .46121 .34112 .47475 .33553 .46724 .31788 Mtetra
.65 .593 .777 r
.46724 .31788 .47475 .33553 .48835 .32947 .48084 .31189 Mtetra
.658 .598 .776 r
.48084 .31189 .48835 .32947 .502 .32295 .49451 .30546 Mtetra
.665 .603 .776 r
.49451 .30546 .502 .32295 .51572 .31599 .50824 .29861 Mtetra
.672 .608 .776 r
.50824 .29861 .51572 .31599 .52948 .30859 .52201 .29134 Mtetra
.679 .614 .776 r
.52201 .29134 .52948 .30859 .54328 .30077 .53583 .28368 Mtetra
.686 .619 .776 r
.53583 .28368 .54328 .30077 .55713 .29257 .5497 .27565 Mtetra
.692 .625 .776 r
.5497 .27565 .55713 .29257 .57101 .284 .5636 .26727 Mtetra
.698 .63 .777 r
.5636 .26727 .57101 .284 .58492 .27508 .57753 .25855 Mtetra
.704 .636 .778 r
.57753 .25855 .58492 .27508 .59885 .26585 .59149 .24954 Mtetra
.709 .641 .779 r
.59149 .24954 .59885 .26585 .61281 .25634 .60549 .24025 Mtetra
.714 .647 .781 r
.60549 .24025 .61281 .25634 .62679 .24657 .6195 .23071 Mtetra
.719 .653 .783 r
.6195 .23071 .62679 .24657 .64079 .23658 .63354 .22096 Mtetra
.723 .658 .785 r
.63354 .22096 .64079 .23658 .65481 .22641 .6476 .21103 Mtetra
.727 .664 .787 r
.6476 .21103 .65481 .22641 .66885 .21608 .66168 .20095 Mtetra
.731 .669 .789 r
.66168 .20095 .66885 .21608 .6829 .20564 .67578 .19075 Mtetra
.734 .674 .792 r
.67578 .19075 .6829 .20564 .69697 .19511 .6899 .18046 Mtetra
.737 .68 .795 r
.6899 .18046 .69697 .19511 .71106 .18452 .70405 .17012 Mtetra
.739 .685 .798 r
.70405 .17012 .71106 .18452 .72517 .17391 .71821 .15975 Mtetra
.741 .69 .802 r
.71821 .15975 .72517 .17391 .7393 .16331 .7324 .14938 Mtetra
.743 .695 .806 r
.7324 .14938 .7393 .16331 .75345 .15274 .74662 .13904 Mtetra
.509 .612 .89 r
.09399 .34009 .10205 .35093 .11294 .35093 .10492 .3398 Mtetra
.504 .603 .885 r
.10492 .3398 .11294 .35093 .12389 .35108 .1159 .33965 Mtetra
.5 .596 .881 r
.1159 .33965 .12389 .35108 .13491 .35137 .12696 .33962 Mtetra
.497 .588 .876 r
.12696 .33962 .13491 .35137 .14599 .35178 .13807 .33971 Mtetra
.495 .581 .871 r
.13807 .33971 .14599 .35178 .15714 .35229 .14926 .33989 Mtetra
.494 .575 .865 r
.14926 .33989 .15714 .35229 .16837 .35287 .16053 .34014 Mtetra
.494 .569 .86 r
.16053 .34014 .16837 .35287 .17968 .35352 .17187 .34044 Mtetra
.495 .563 .854 r
.17187 .34044 .17968 .35352 .19107 .35419 .1833 .34077 Mtetra
.497 .559 .849 r
.1833 .34077 .19107 .35419 .20256 .35486 .19481 .34109 Mtetra
.5 .555 .844 r
.19481 .34109 .20256 .35486 .21414 .3555 .20642 .3414 Mtetra
.504 .552 .838 r
.20642 .3414 .21414 .3555 .22581 .35608 .21812 .34164 Mtetra
.508 .549 .833 r
.21812 .34164 .22581 .35608 .23759 .35658 .22992 .3418 Mtetra
.513 .547 .828 r
.22992 .3418 .23759 .35658 .24946 .35695 .24181 .34185 Mtetra
.519 .546 .823 r
.24181 .34185 .24946 .35695 .26145 .35717 .25382 .34175 Mtetra
.525 .545 .819 r
.25382 .34175 .26145 .35717 .27353 .3572 .26592 .34148 Mtetra
.532 .545 .814 r
.26592 .34148 .27353 .3572 .28573 .35702 .27813 .341 Mtetra
.539 .546 .81 r
.27813 .341 .28573 .35702 .29804 .35659 .29045 .3403 Mtetra
.546 .547 .806 r
.29045 .3403 .29804 .35659 .31045 .35588 .30288 .33934 Mtetra
.554 .548 .802 r
.30288 .33934 .31045 .35588 .32298 .35487 .31541 .33809 Mtetra
.562 .55 .799 r
.31541 .33809 .32298 .35487 .33561 .35353 .32805 .33653 Mtetra
.57 .552 .796 r
.32805 .33653 .33561 .35353 .34835 .35183 .34079 .33464 Mtetra
.578 .555 .793 r
.34079 .33464 .34835 .35183 .36119 .34976 .35363 .33239 Mtetra
.586 .558 .79 r
.35363 .33239 .36119 .34976 .37413 .34729 .36658 .32978 Mtetra
.594 .561 .787 r
.36658 .32978 .37413 .34729 .38717 .34441 .37962 .32678 Mtetra
.602 .565 .785 r
.37962 .32678 .38717 .34441 .4003 .3411 .39276 .32337 Mtetra
.61 .569 .783 r
.39276 .32337 .4003 .3411 .41353 .33735 .40598 .31956 Mtetra
.618 .573 .781 r
.40598 .31956 .41353 .33735 .42684 .33316 .4193 .31533 Mtetra
.626 .577 .78 r
.4193 .31533 .42684 .33316 .44023 .32852 .43269 .31067 Mtetra
.633 .581 .778 r
.43269 .31067 .44023 .32852 .4537 .32342 .44616 .30559 Mtetra
.641 .586 .777 r
.44616 .30559 .4537 .32342 .46724 .31788 .45971 .30008 Mtetra
.648 .591 .777 r
.45971 .30008 .46724 .31788 .48084 .31189 .47332 .29415 Mtetra
.655 .596 .776 r
.47332 .29415 .48084 .31189 .49451 .30546 .48699 .28781 Mtetra
.662 .601 .776 r
.48699 .28781 .49451 .30546 .50824 .29861 .50073 .28107 Mtetra
.669 .606 .775 r
.50073 .28107 .50824 .29861 .52201 .29134 .51451 .27393 Mtetra
.675 .611 .776 r
.51451 .27393 .52201 .29134 .53583 .28368 .52835 .26642 Mtetra
.682 .616 .776 r
.52835 .26642 .53583 .28368 .5497 .27565 .54223 .25856 Mtetra
.688 .622 .777 r
.54223 .25856 .5497 .27565 .5636 .26727 .55615 .25036 Mtetra
.694 .627 .777 r
.55615 .25036 .5636 .26727 .57753 .25855 .57011 .24184 Mtetra
.699 .632 .778 r
.57011 .24184 .57753 .25855 .59149 .24954 .5841 .23304 Mtetra
.704 .638 .78 r
.5841 .23304 .59149 .24954 .60549 .24025 .59812 .22397 Mtetra
.709 .643 .781 r
.59812 .22397 .60549 .24025 .6195 .23071 .61217 .21466 Mtetra
.714 .649 .783 r
.61217 .21466 .6195 .23071 .63354 .22096 .62625 .20515 Mtetra
.718 .654 .785 r
.62625 .20515 .63354 .22096 .6476 .21103 .64035 .19546 Mtetra
.722 .66 .788 r
.64035 .19546 .6476 .21103 .66168 .20095 .65447 .18563 Mtetra
.726 .665 .79 r
.65447 .18563 .66168 .20095 .67578 .19075 .66862 .17567 Mtetra
.729 .671 .793 r
.66862 .17567 .67578 .19075 .6899 .18046 .68279 .16563 Mtetra
.732 .676 .796 r
.68279 .16563 .6899 .18046 .70405 .17012 .69699 .15553 Mtetra
.734 .681 .799 r
.69699 .15553 .70405 .17012 .71821 .15975 .71121 .1454 Mtetra
.736 .686 .803 r
.71121 .1454 .71821 .15975 .7324 .14938 .72546 .13526 Mtetra
.738 .691 .806 r
.72546 .13526 .7324 .14938 .74662 .13904 .73973 .12515 Mtetra
.521 .618 .889 r
.08586 .32922 .09399 .34009 .10492 .3398 .09683 .32863 Mtetra
.516 .61 .885 r
.09683 .32863 .10492 .3398 .1159 .33965 .10786 .32818 Mtetra
.513 .602 .88 r
.10786 .32818 .1159 .33965 .12696 .33962 .11895 .32784 Mtetra
.51 .595 .875 r
.11895 .32784 .12696 .33962 .13807 .33971 .13011 .32761 Mtetra
.508 .588 .87 r
.13011 .32761 .13807 .33971 .14926 .33989 .14134 .32746 Mtetra
.506 .581 .865 r
.14134 .32746 .14926 .33989 .16053 .34014 .15264 .32738 Mtetra
.506 .576 .86 r
.15264 .32738 .16053 .34014 .17187 .34044 .16401 .32734 Mtetra
.507 .57 .854 r
.16401 .32734 .17187 .34044 .1833 .34077 .17547 .32733 Mtetra
.508 .565 .849 r
.17547 .32733 .1833 .34077 .19481 .34109 .18702 .32731 Mtetra
.511 .561 .844 r
.18702 .32731 .19481 .34109 .20642 .3414 .19865 .32727 Mtetra
.514 .558 .838 r
.19865 .32727 .20642 .3414 .21812 .34164 .21038 .32718 Mtetra
.518 .555 .833 r
.21038 .32718 .21812 .34164 .22992 .3418 .22221 .32701 Mtetra
.522 .553 .828 r
.22221 .32701 .22992 .3418 .24181 .34185 .23413 .32673 Mtetra
.527 .551 .823 r
.23413 .32673 .24181 .34185 .25382 .34175 .24615 .32632 Mtetra
.533 .55 .819 r
.24615 .32632 .25382 .34175 .26592 .34148 .25827 .32574 Mtetra
.539 .55 .814 r
.25827 .32574 .26592 .34148 .27813 .341 .2705 .32498 Mtetra
.545 .55 .81 r
.2705 .32498 .27813 .341 .29045 .3403 .28283 .324 Mtetra
.552 .55 .806 r
.28283 .324 .29045 .3403 .30288 .33934 .29527 .32278 Mtetra
.559 .552 .802 r
.29527 .32278 .30288 .33934 .31541 .33809 .30781 .32129 Mtetra
.566 .553 .799 r
.30781 .32129 .31541 .33809 .32805 .33653 .32046 .31951 Mtetra
.573 .555 .796 r
.32046 .31951 .32805 .33653 .34079 .33464 .33321 .31742 Mtetra
.581 .557 .793 r
.33321 .31742 .34079 .33464 .35363 .33239 .34605 .315 Mtetra
.588 .56 .79 r
.34605 .315 .35363 .33239 .36658 .32978 .359 .31224 Mtetra
.596 .563 .787 r
.359 .31224 .36658 .32978 .37962 .32678 .37205 .30911 Mtetra
.603 .566 .785 r
.37205 .30911 .37962 .32678 .39276 .32337 .38519 .30561 Mtetra
.61 .569 .783 r
.38519 .30561 .39276 .32337 .40598 .31956 .39841 .30172 Mtetra
.618 .573 .781 r
.39841 .30172 .40598 .31956 .4193 .31533 .41173 .29745 Mtetra
.625 .577 .78 r
.41173 .29745 .4193 .31533 .43269 .31067 .42512 .29277 Mtetra
.632 .581 .779 r
.42512 .29277 .43269 .31067 .44616 .30559 .4386 .28769 Mtetra
.639 .585 .778 r
.4386 .28769 .44616 .30559 .45971 .30008 .45215 .28221 Mtetra
.646 .59 .777 r
.45215 .28221 .45971 .30008 .47332 .29415 .46577 .27634 Mtetra
.653 .594 .776 r
.46577 .27634 .47332 .29415 .48699 .28781 .47945 .27008 Mtetra
.66 .599 .776 r
.47945 .27008 .48699 .28781 .50073 .28107 .49319 .26344 Mtetra
.666 .604 .776 r
.49319 .26344 .50073 .28107 .51451 .27393 .50699 .25643 Mtetra
.672 .609 .776 r
.50699 .25643 .51451 .27393 .52835 .26642 .52084 .24906 Mtetra
.678 .614 .777 r
.52084 .24906 .52835 .26642 .54223 .25856 .53474 .24135 Mtetra
.684 .619 .777 r
.53474 .24135 .54223 .25856 .55615 .25036 .54868 .23333 Mtetra
.69 .624 .778 r
.54868 .23333 .55615 .25036 .57011 .24184 .56266 .225 Mtetra
.695 .63 .779 r
.56266 .225 .57011 .24184 .5841 .23304 .57667 .2164 Mtetra
.7 .635 .781 r
.57667 .2164 .5841 .23304 .59812 .22397 .59072 .20755 Mtetra
.705 .641 .782 r
.59072 .20755 .59812 .22397 .61217 .21466 .6048 .19847 Mtetra
.709 .646 .784 r
.6048 .19847 .61217 .21466 .62625 .20515 .61892 .1892 Mtetra
.714 .651 .786 r
.61892 .1892 .62625 .20515 .64035 .19546 .63305 .17975 Mtetra
.717 .657 .789 r
.63305 .17975 .64035 .19546 .65447 .18563 .64722 .17015 Mtetra
.721 .662 .791 r
.64722 .17015 .65447 .18563 .66862 .17567 .66141 .16044 Mtetra
.724 .668 .794 r
.66141 .16044 .66862 .17567 .68279 .16563 .67563 .15065 Mtetra
.727 .673 .797 r
.67563 .15065 .68279 .16563 .69699 .15553 .68988 .14079 Mtetra
.729 .678 .8 r
.68988 .14079 .69699 .15553 .71121 .1454 .70415 .1309 Mtetra
.731 .683 .804 r
.70415 .1309 .71121 .1454 .72546 .13526 .71846 .121 Mtetra
.733 .688 .808 r
.71846 .121 .72546 .13526 .73973 .12515 .7328 .11111 Mtetra
.532 .624 .888 r
.07768 .31833 .08586 .32922 .09683 .32863 .08869 .31745 Mtetra
.528 .616 .884 r
.08869 .31745 .09683 .32863 .10786 .32818 .09976 .3167 Mtetra
.524 .609 .879 r
.09976 .3167 .10786 .32818 .11895 .32784 .11089 .31606 Mtetra
.521 .602 .875 r
.11089 .31606 .11895 .32784 .13011 .32761 .12209 .31551 Mtetra
.519 .595 .87 r
.12209 .31551 .13011 .32761 .14134 .32746 .13335 .31503 Mtetra
.518 .588 .865 r
.13335 .31503 .14134 .32746 .15264 .32738 .14469 .31462 Mtetra
.517 .583 .86 r
.14469 .31462 .15264 .32738 .16401 .32734 .15611 .31425 Mtetra
.518 .577 .854 r
.15611 .31425 .16401 .32734 .17547 .32733 .1676 .3139 Mtetra
.519 .572 .849 r
.1676 .3139 .17547 .32733 .18702 .32731 .17918 .31355 Mtetra
.521 .568 .844 r
.17918 .31355 .18702 .32731 .19865 .32727 .19085 .31318 Mtetra
.524 .564 .839 r
.19085 .31318 .19865 .32727 .21038 .32718 .2026 .31275 Mtetra
.527 .561 .834 r
.2026 .31275 .21038 .32718 .22221 .32701 .21445 .31225 Mtetra
.531 .559 .829 r
.21445 .31225 .22221 .32701 .23413 .32673 .2264 .31165 Mtetra
.535 .557 .824 r
.2264 .31165 .23413 .32673 .24615 .32632 .23844 .31092 Mtetra
.54 .556 .819 r
.23844 .31092 .24615 .32632 .25827 .32574 .25058 .31004 Mtetra
.546 .555 .815 r
.25058 .31004 .25827 .32574 .2705 .32498 .26283 .30899 Mtetra
.551 .555 .811 r
.26283 .30899 .2705 .32498 .28283 .324 .27518 .30773 Mtetra
.557 .555 .807 r
.27518 .30773 .28283 .324 .29527 .32278 .28763 .30625 Mtetra
.564 .555 .803 r
.28763 .30625 .29527 .32278 .30781 .32129 .30018 .30453 Mtetra
.57 .556 .8 r
.30018 .30453 .30781 .32129 .32046 .31951 .31283 .30253 Mtetra
.577 .558 .796 r
.31283 .30253 .32046 .31951 .33321 .31742 .32559 .30024 Mtetra
.584 .56 .793 r
.32559 .30024 .33321 .31742 .34605 .315 .33844 .29765 Mtetra
.59 .562 .791 r
.33844 .29765 .34605 .315 .359 .31224 .3514 .29473 Mtetra
.597 .565 .788 r
.3514 .29473 .359 .31224 .37205 .30911 .36444 .29148 Mtetra
.604 .567 .786 r
.36444 .29148 .37205 .30911 .38519 .30561 .37759 .28787 Mtetra
.611 .57 .784 r
.37759 .28787 .38519 .30561 .39841 .30172 .39082 .28391 Mtetra
.618 .574 .782 r
.39082 .28391 .39841 .30172 .41173 .29745 .40413 .27957 Mtetra
.625 .577 .781 r
.40413 .27957 .41173 .29745 .42512 .29277 .41753 .27487 Mtetra
.631 .581 .78 r
.41753 .27487 .42512 .29277 .4386 .28769 .43101 .26979 Mtetra
.638 .585 .779 r
.43101 .26979 .4386 .28769 .45215 .28221 .44456 .26434 Mtetra
.645 .589 .778 r
.44456 .26434 .45215 .28221 .46577 .27634 .45818 .25851 Mtetra
.651 .594 .777 r
.45818 .25851 .46577 .27634 .47945 .27008 .47187 .25232 Mtetra
.657 .598 .777 r
.47187 .25232 .47945 .27008 .49319 .26344 .48562 .24577 Mtetra
.663 .603 .777 r
.48562 .24577 .49319 .26344 .50699 .25643 .49943 .23888 Mtetra
.669 .608 .777 r
.49943 .23888 .50699 .25643 .52084 .24906 .5133 .23165 Mtetra
.675 .613 .778 r
.5133 .23165 .52084 .24906 .53474 .24135 .52721 .22409 Mtetra
.681 .618 .779 r
.52721 .22409 .53474 .24135 .54868 .23333 .54117 .21624 Mtetra
.686 .623 .779 r
.54117 .21624 .54868 .23333 .56266 .225 .55517 .2081 Mtetra
.691 .628 .781 r
.55517 .2081 .56266 .225 .57667 .2164 .56921 .1997 Mtetra
.696 .633 .782 r
.56921 .1997 .57667 .2164 .59072 .20755 .58329 .19106 Mtetra
.701 .639 .784 r
.58329 .19106 .59072 .20755 .6048 .19847 .5974 .1822 Mtetra
.705 .644 .786 r
.5974 .1822 .6048 .19847 .61892 .1892 .61154 .17315 Mtetra
.709 .649 .788 r
.61154 .17315 .61892 .1892 .63305 .17975 .62572 .16393 Mtetra
.713 .655 .79 r
.62572 .16393 .63305 .17975 .64722 .17015 .63993 .15458 Mtetra
.716 .66 .793 r
.63993 .15458 .64722 .17015 .66141 .16044 .65416 .14511 Mtetra
.719 .665 .796 r
.65416 .14511 .66141 .16044 .67563 .15065 .66843 .13555 Mtetra
.722 .671 .799 r
.66843 .13555 .67563 .15065 .68988 .14079 .68273 .12594 Mtetra
.724 .676 .802 r
.68273 .12594 .68988 .14079 .70415 .1309 .69706 .11628 Mtetra
.726 .681 .806 r
.69706 .11628 .70415 .1309 .71846 .121 .71142 .10661 Mtetra
.728 .686 .809 r
.71142 .10661 .71846 .121 .7328 .11111 .72581 .09696 Mtetra
.542 .63 .888 r
.06943 .30743 .07768 .31833 .08869 .31745 .08049 .30628 Mtetra
.538 .622 .884 r
.08049 .30628 .08869 .31745 .09976 .3167 .0916 .30523 Mtetra
.535 .615 .879 r
.0916 .30523 .09976 .3167 .11089 .31606 .10277 .30428 Mtetra
.532 .608 .875 r
.10277 .30428 .11089 .31606 .12209 .31551 .11401 .30342 Mtetra
.53 .602 .87 r
.11401 .30342 .12209 .31551 .13335 .31503 .12531 .30263 Mtetra
.529 .596 .865 r
.12531 .30263 .13335 .31503 .14469 .31462 .13669 .3019 Mtetra
.528 .59 .86 r
.13669 .3019 .14469 .31462 .15611 .31425 .14814 .3012 Mtetra
.528 .584 .855 r
.14814 .3012 .15611 .31425 .1676 .3139 .15967 .30052 Mtetra
.529 .579 .85 r
.15967 .30052 .1676 .3139 .17918 .31355 .17129 .29984 Mtetra
.531 .575 .845 r
.17129 .29984 .17918 .31355 .19085 .31318 .18298 .29913 Mtetra
.533 .571 .84 r
.18298 .29913 .19085 .31318 .2026 .31275 .19477 .29837 Mtetra
.536 .568 .835 r
.19477 .29837 .2026 .31275 .21445 .31225 .20665 .29755 Mtetra
.539 .565 .83 r
.20665 .29755 .21445 .31225 .2264 .31165 .21862 .29663 Mtetra
.543 .563 .825 r
.21862 .29663 .2264 .31165 .23844 .31092 .23069 .2956 Mtetra
.547 .562 .821 r
.23069 .2956 .23844 .31092 .25058 .31004 .24285 .29442 Mtetra
.552 .56 .816 r
.24285 .29442 .25058 .31004 .26283 .30899 .25511 .29308 Mtetra
.557 .56 .812 r
.25511 .29308 .26283 .30899 .27518 .30773 .26748 .29155 Mtetra
.563 .56 .808 r
.26748 .29155 .27518 .30773 .28763 .30625 .27994 .28982 Mtetra
.568 .56 .804 r
.27994 .28982 .28763 .30625 .30018 .30453 .29251 .28785 Mtetra
.574 .561 .801 r
.29251 .28785 .30018 .30453 .31283 .30253 .30517 .28563 Mtetra
.58 .562 .798 r
.30517 .28563 .31283 .30253 .32559 .30024 .31794 .28315 Mtetra
.587 .563 .795 r
.31794 .28315 .32559 .30024 .33844 .29765 .3308 .28038 Mtetra
.593 .565 .792 r
.3308 .28038 .33844 .29765 .3514 .29473 .34376 .27731 Mtetra
.599 .567 .79 r
.34376 .27731 .3514 .29473 .36444 .29148 .35681 .27392 Mtetra
.606 .57 .787 r
.35681 .27392 .36444 .29148 .37759 .28787 .36995 .27021 Mtetra
.612 .573 .786 r
.36995 .27021 .37759 .28787 .39082 .28391 .38319 .26616 Mtetra
.618 .576 .784 r
.38319 .26616 .39082 .28391 .40413 .27957 .39651 .26177 Mtetra
.625 .579 .782 r
.39651 .26177 .40413 .27957 .41753 .27487 .40991 .25703 Mtetra
.631 .582 .781 r
.40991 .25703 .41753 .27487 .43101 .26979 .42339 .25195 Mtetra
.637 .586 .78 r
.42339 .25195 .43101 .26979 .44456 .26434 .43695 .24651 Mtetra
.644 .59 .78 r
.43695 .24651 .44456 .26434 .45818 .25851 .45057 .24073 Mtetra
.65 .594 .779 r
.45057 .24073 .45818 .25851 .47187 .25232 .46427 .2346 Mtetra
.656 .599 .779 r
.46427 .2346 .47187 .25232 .48562 .24577 .47803 .22814 Mtetra
.661 .603 .779 r
.47803 .22814 .48562 .24577 .49943 .23888 .49185 .22135 Mtetra
.667 .608 .779 r
.49185 .22135 .49943 .23888 .5133 .23165 .50572 .21424 Mtetra
.673 .612 .78 r
.50572 .21424 .5133 .23165 .52721 .22409 .51965 .20683 Mtetra
.678 .617 .78 r
.51965 .20683 .52721 .22409 .54117 .21624 .53363 .19914 Mtetra
.683 .622 .781 r
.53363 .19914 .54117 .21624 .55517 .2081 .54765 .19118 Mtetra
.688 .627 .783 r
.54765 .19118 .55517 .2081 .56921 .1997 .56171 .18297 Mtetra
.693 .632 .784 r
.56171 .18297 .56921 .1997 .58329 .19106 .57582 .17453 Mtetra
.697 .637 .786 r
.57582 .17453 .58329 .19106 .5974 .1822 .58996 .16589 Mtetra
.701 .643 .788 r
.58996 .16589 .5974 .1822 .61154 .17315 .60414 .15706 Mtetra
.705 .648 .79 r
.60414 .15706 .61154 .17315 .62572 .16393 .61835 .14807 Mtetra
.709 .653 .792 r
.61835 .14807 .62572 .16393 .63993 .15458 .6326 .13894 Mtetra
.712 .658 .795 r
.6326 .13894 .63993 .15458 .65416 .14511 .64687 .12971 Mtetra
.715 .664 .798 r
.64687 .12971 .65416 .14511 .66843 .13555 .66119 .12039 Mtetra
.718 .669 .801 r
.66119 .12039 .66843 .13555 .68273 .12594 .67553 .11101 Mtetra
.72 .674 .804 r
.67553 .11101 .68273 .12594 .69706 .11628 .68991 .10159 Mtetra
.722 .679 .808 r
.68991 .10159 .69706 .11628 .71142 .10661 .70433 .09215 Mtetra
.724 .684 .812 r
.70433 .09215 .71142 .10661 .72581 .09696 .71878 .08272 Mtetra
.552 .636 .887 r
.06112 .29654 .06943 .30743 .08049 .30628 .07222 .29511 Mtetra
.548 .629 .883 r
.07222 .29511 .08049 .30628 .0916 .30523 .08337 .29378 Mtetra
.545 .622 .879 r
.08337 .29378 .0916 .30523 .10277 .30428 .09459 .29254 Mtetra
.543 .615 .875 r
.09459 .29254 .10277 .30428 .11401 .30342 .10587 .29137 Mtetra
.54 .609 .87 r
.10587 .29137 .11401 .30342 .12531 .30263 .11721 .29027 Mtetra
.539 .603 .866 r
.11721 .29027 .12531 .30263 .13669 .3019 .12863 .28922 Mtetra
.538 .597 .861 r
.12863 .28922 .13669 .3019 .14814 .3012 .14012 .2882 Mtetra
.538 .592 .856 r
.14012 .2882 .14814 .3012 .15967 .30052 .15169 .2872 Mtetra
.539 .587 .851 r
.15169 .2872 .15967 .30052 .17129 .29984 .16333 .2862 Mtetra
.54 .582 .846 r
.16333 .2862 .17129 .29984 .18298 .29913 .17506 .28516 Mtetra
.542 .578 .841 r
.17506 .28516 .18298 .29913 .19477 .29837 .18688 .28409 Mtetra
.544 .575 .836 r
.18688 .28409 .19477 .29837 .20665 .29755 .19879 .28295 Mtetra
.547 .572 .831 r
.19879 .28295 .20665 .29755 .21862 .29663 .21079 .28172 Mtetra
.551 .57 .827 r
.21079 .28172 .21862 .29663 .23069 .2956 .22288 .28038 Mtetra
.554 .568 .822 r
.22288 .28038 .23069 .2956 .24285 .29442 .23507 .27891 Mtetra
.559 .566 .818 r
.23507 .27891 .24285 .29442 .25511 .29308 .24735 .27729 Mtetra
.563 .566 .814 r
.24735 .27729 .25511 .29308 .26748 .29155 .25973 .2755 Mtetra
.568 .565 .81 r
.25973 .2755 .26748 .29155 .27994 .28982 .27221 .27351 Mtetra
.573 .565 .806 r
.27221 .27351 .27994 .28982 .29251 .28785 .28479 .2713 Mtetra
.579 .565 .803 r
.28479 .2713 .29251 .28785 .30517 .28563 .29747 .26887 Mtetra
.584 .566 .8 r
.29747 .26887 .30517 .28563 .31794 .28315 .31024 .26619 Mtetra
.59 .567 .797 r
.31024 .26619 .31794 .28315 .3308 .28038 .32311 .26324 Mtetra
.596 .569 .794 r
.32311 .26324 .3308 .28038 .34376 .27731 .33608 .26001 Mtetra
.601 .571 .792 r
.33608 .26001 .34376 .27731 .35681 .27392 .34913 .25649 Mtetra
.607 .573 .79 r
.34913 .25649 .35681 .27392 .36995 .27021 .36228 .25267 Mtetra
.613 .575 .788 r
.36228 .25267 .36995 .27021 .38319 .26616 .37552 .24853 Mtetra
.619 .578 .786 r
.37552 .24853 .38319 .26616 .39651 .26177 .38885 .24408 Mtetra
.625 .581 .785 r
.38885 .24408 .39651 .26177 .40991 .25703 .40225 .23931 Mtetra
.631 .584 .783 r
.40225 .23931 .40991 .25703 .42339 .25195 .41574 .23421 Mtetra
.637 .588 .782 r
.41574 .23421 .42339 .25195 .43695 .24651 .4293 .22878 Mtetra
.643 .592 .782 r
.4293 .22878 .43695 .24651 .45057 .24073 .44293 .22303 Mtetra
.648 .595 .781 r
.44293 .22303 .45057 .24073 .46427 .2346 .45664 .21696 Mtetra
.654 .599 .781 r
.45664 .21696 .46427 .2346 .47803 .22814 .4704 .21057 Mtetra
.66 .604 .781 r
.4704 .21057 .47803 .22814 .49185 .22135 .48423 .20388 Mtetra
.665 .608 .782 r
.48423 .20388 .49185 .22135 .50572 .21424 .49812 .19689 Mtetra
.67 .613 .782 r
.49812 .19689 .50572 .21424 .51965 .20683 .51206 .18962 Mtetra
.675 .617 .783 r
.51206 .18962 .51965 .20683 .53363 .19914 .52605 .18208 Mtetra
.68 .622 .784 r
.52605 .18208 .53363 .19914 .54765 .19118 .5401 .17429 Mtetra
.685 .627 .785 r
.5401 .17429 .54765 .19118 .56171 .18297 .55418 .16626 Mtetra
.689 .632 .787 r
.55418 .16626 .56171 .18297 .57582 .17453 .56831 .15802 Mtetra
.694 .637 .788 r
.56831 .15802 .57582 .17453 .58996 .16589 .58248 .14958 Mtetra
.698 .642 .79 r
.58248 .14958 .58996 .16589 .60414 .15706 .59669 .14096 Mtetra
.701 .647 .792 r
.59669 .14096 .60414 .15706 .61835 .14807 .61094 .13219 Mtetra
.705 .652 .795 r
.61094 .13219 .61835 .14807 .6326 .13894 .62522 .12329 Mtetra
.708 .658 .798 r
.62522 .12329 .6326 .13894 .64687 .12971 .63955 .11428 Mtetra
.711 .663 .8 r
.63955 .11428 .64687 .12971 .66119 .12039 .6539 .10519 Mtetra
.714 .668 .804 r
.6539 .10519 .66119 .12039 .67553 .11101 .6683 .09604 Mtetra
.716 .673 .807 r
.6683 .09604 .67553 .11101 .68991 .10159 .68273 .08684 Mtetra
.718 .678 .81 r
.68273 .08684 .68991 .10159 .70433 .09215 .6972 .07763 Mtetra
.719 .683 .814 r
.6972 .07763 .70433 .09215 .71878 .08272 .7117 .06842 Mtetra
.561 .642 .887 r
.05273 .28568 .06112 .29654 .07222 .29511 .06388 .28398 Mtetra
.558 .635 .883 r
.06388 .28398 .07222 .29511 .08337 .29378 .07508 .28237 Mtetra
.555 .628 .88 r
.07508 .28237 .08337 .29378 .09459 .29254 .08634 .28084 Mtetra
.552 .622 .875 r
.08634 .28084 .09459 .29254 .10587 .29137 .09766 .27938 Mtetra
.55 .616 .871 r
.09766 .27938 .10587 .29137 .11721 .29027 .10904 .27798 Mtetra
.549 .61 .866 r
.10904 .27798 .11721 .29027 .12863 .28922 .1205 .27662 Mtetra
.548 .604 .862 r
.1205 .27662 .12863 .28922 .14012 .2882 .13203 .27529 Mtetra
.548 .599 .857 r
.13203 .27529 .14012 .2882 .15169 .2872 .14364 .27397 Mtetra
.548 .594 .852 r
.14364 .27397 .15169 .2872 .16333 .2862 .15532 .27265 Mtetra
.549 .59 .847 r
.15532 .27265 .16333 .2862 .17506 .28516 .16708 .27131 Mtetra
.551 .586 .843 r
.16708 .27131 .17506 .28516 .18688 .28409 .17893 .26992 Mtetra
.553 .582 .838 r
.17893 .26992 .18688 .28409 .19879 .28295 .19087 .26847 Mtetra
.555 .579 .833 r
.19087 .26847 .19879 .28295 .21079 .28172 .2029 .26694 Mtetra
.558 .577 .829 r
.2029 .26694 .21079 .28172 .22288 .28038 .21502 .2653 Mtetra
.561 .575 .824 r
.21502 .2653 .22288 .28038 .23507 .27891 .22723 .26355 Mtetra
.565 .573 .82 r
.22723 .26355 .23507 .27891 .24735 .27729 .23953 .26165 Mtetra
.569 .572 .816 r
.23953 .26165 .24735 .27729 .25973 .2755 .25193 .25959 Mtetra
.573 .571 .812 r
.25193 .25959 .25973 .2755 .27221 .27351 .26443 .25736 Mtetra
.578 .571 .809 r
.26443 .25736 .27221 .27351 .28479 .2713 .27702 .25492 Mtetra
.583 .571 .805 r
.27702 .25492 .28479 .2713 .29747 .26887 .28971 .25227 Mtetra
.588 .571 .802 r
.28971 .25227 .29747 .26887 .31024 .26619 .3025 .24939 Mtetra
.593 .572 .799 r
.3025 .24939 .31024 .26619 .32311 .26324 .31538 .24627 Mtetra
.598 .573 .797 r
.31538 .24627 .32311 .26324 .33608 .26001 .32835 .24288 Mtetra
.604 .575 .794 r
.32835 .24288 .33608 .26001 .34913 .25649 .34142 .23923 Mtetra
.609 .577 .792 r
.34142 .23923 .34913 .25649 .36228 .25267 .35457 .2353 Mtetra
.615 .579 .79 r
.35457 .2353 .36228 .25267 .37552 .24853 .36782 .23107 Mtetra
.62 .581 .789 r
.36782 .23107 .37552 .24853 .38885 .24408 .38115 .22656 Mtetra
.626 .584 .787 r
.38115 .22656 .38885 .24408 .40225 .23931 .39456 .22174 Mtetra
.631 .587 .786 r
.39456 .22174 .40225 .23931 .41574 .23421 .40805 .21662 Mtetra
.637 .59 .785 r
.40805 .21662 .41574 .23421 .4293 .22878 .42162 .2112 Mtetra
.642 .594 .785 r
.42162 .2112 .4293 .22878 .44293 .22303 .43526 .20547 Mtetra
.648 .597 .784 r
.43526 .20547 .44293 .22303 .45664 .21696 .44897 .19945 Mtetra
.653 .601 .784 r
.44897 .19945 .45664 .21696 .4704 .21057 .46274 .19313 Mtetra
.658 .605 .784 r
.46274 .19313 .4704 .21057 .48423 .20388 .47658 .18653 Mtetra
.663 .609 .784 r
.47658 .18653 .48423 .20388 .49812 .19689 .49048 .17965 Mtetra
.668 .614 .785 r
.49048 .17965 .49812 .19689 .51206 .18962 .50444 .17251 Mtetra
.673 .618 .786 r
.50444 .17251 .51206 .18962 .52605 .18208 .51845 .16511 Mtetra
.678 .623 .787 r
.51845 .16511 .52605 .18208 .5401 .17429 .53251 .15748 Mtetra
.682 .628 .788 r
.53251 .15748 .5401 .17429 .55418 .16626 .54662 .14962 Mtetra
.686 .632 .79 r
.54662 .14962 .55418 .16626 .56831 .15802 .56077 .14156 Mtetra
.69 .637 .791 r
.56077 .14156 .56831 .15802 .58248 .14958 .57497 .13331 Mtetra
.694 .642 .793 r
.57497 .13331 .58248 .14958 .59669 .14096 .58921 .1249 Mtetra
.698 .647 .795 r
.58921 .1249 .59669 .14096 .61094 .13219 .60349 .11634 Mtetra
.701 .652 .798 r
.60349 .11634 .61094 .13219 .62522 .12329 .61782 .10765 Mtetra
.704 .657 .801 r
.61782 .10765 .62522 .12329 .63955 .11428 .63218 .09886 Mtetra
.707 .662 .803 r
.63218 .09886 .63955 .11428 .6539 .10519 .64658 .08999 Mtetra
.71 .667 .806 r
.64658 .08999 .6539 .10519 .6683 .09604 .66102 .08106 Mtetra
.712 .672 .81 r
.66102 .08106 .6683 .09604 .68273 .08684 .6755 .07208 Mtetra
.714 .677 .813 r
.6755 .07208 .68273 .08684 .6972 .07763 .69002 .06308 Mtetra
.715 .682 .817 r
.69002 .06308 .6972 .07763 .7117 .06842 .70458 .05408 Mtetra
.57 .648 .887 r
.04428 .27484 .05273 .28568 .06388 .28398 .05547 .27288 Mtetra
.567 .641 .884 r
.05547 .27288 .06388 .28398 .07508 .28237 .06671 .271 Mtetra
.564 .635 .88 r
.06671 .271 .07508 .28237 .08634 .28084 .07801 .2692 Mtetra
.562 .629 .876 r
.07801 .2692 .08634 .28084 .09766 .27938 .08938 .26745 Mtetra
.56 .623 .872 r
.08938 .26745 .09766 .27938 .10904 .27798 .10081 .26576 Mtetra
.558 .617 .867 r
.10081 .26576 .10904 .27798 .1205 .27662 .1123 .2641 Mtetra
.557 .612 .863 r
.1123 .2641 .1205 .27662 .13203 .27529 .12387 .26247 Mtetra
.557 .607 .858 r
.12387 .26247 .13203 .27529 .14364 .27397 .13552 .26085 Mtetra
.557 .602 .854 r
.13552 .26085 .14364 .27397 .15532 .27265 .14724 .25922 Mtetra
.558 .597 .849 r
.14724 .25922 .15532 .27265 .16708 .27131 .15904 .25757 Mtetra
.559 .593 .845 r
.15904 .25757 .16708 .27131 .17893 .26992 .17092 .25588 Mtetra
.56 .59 .84 r
.17092 .25588 .17893 .26992 .19087 .26847 .18289 .25413 Mtetra
.563 .587 .836 r
.18289 .25413 .19087 .26847 .2029 .26694 .19495 .25231 Mtetra
.565 .584 .831 r
.19495 .25231 .2029 .26694 .21502 .2653 .20709 .25039 Mtetra
.568 .582 .827 r
.20709 .25039 .21502 .2653 .22723 .26355 .21933 .24835 Mtetra
.571 .58 .823 r
.21933 .24835 .22723 .26355 .23953 .26165 .23166 .24619 Mtetra
.575 .578 .819 r
.23166 .24619 .23953 .26165 .25193 .25959 .24408 .24388 Mtetra
.579 .577 .815 r
.24408 .24388 .25193 .25959 .26443 .25736 .2566 .2414 Mtetra
.583 .577 .812 r
.2566 .2414 .26443 .25736 .27702 .25492 .26921 .23874 Mtetra
.587 .577 .808 r
.26921 .23874 .27702 .25492 .28971 .25227 .28191 .23587 Mtetra
.592 .577 .805 r
.28191 .23587 .28971 .25227 .3025 .24939 .29471 .2328 Mtetra
.596 .577 .803 r
.29471 .2328 .3025 .24939 .31538 .24627 .3076 .2295 Mtetra
.601 .578 .8 r
.3076 .2295 .31538 .24627 .32835 .24288 .32058 .22596 Mtetra
.606 .58 .798 r
.32058 .22596 .32835 .24288 .34142 .23923 .33366 .22218 Mtetra
.611 .581 .795 r
.33366 .22218 .34142 .23923 .35457 .2353 .34682 .21813 Mtetra
.616 .583 .794 r
.34682 .21813 .35457 .2353 .36782 .23107 .36007 .21382 Mtetra
.621 .585 .792 r
.36007 .21382 .36782 .23107 .38115 .22656 .37341 .20923 Mtetra
.627 .588 .791 r
.37341 .20923 .38115 .22656 .39456 .22174 .38682 .20437 Mtetra
.632 .59 .789 r
.38682 .20437 .39456 .22174 .40805 .21662 .40032 .19922 Mtetra
.637 .593 .789 r
.40032 .19922 .40805 .21662 .42162 .2112 .41389 .1938 Mtetra
.642 .597 .788 r
.41389 .1938 .42162 .2112 .43526 .20547 .42754 .18809 Mtetra
.647 .6 .788 r
.42754 .18809 .43526 .20547 .44897 .19945 .44126 .18211 Mtetra
.652 .604 .787 r
.44126 .18211 .44897 .19945 .46274 .19313 .45505 .17585 Mtetra
.657 .607 .787 r
.45505 .17585 .46274 .19313 .47658 .18653 .4689 .16933 Mtetra
.662 .611 .788 r
.4689 .16933 .47658 .18653 .49048 .17965 .48281 .16255 Mtetra
.666 .616 .788 r
.48281 .16255 .49048 .17965 .50444 .17251 .49678 .15552 Mtetra
.671 .62 .789 r
.49678 .15552 .50444 .17251 .51845 .16511 .51081 .14826 Mtetra
.675 .624 .79 r
.51081 .14826 .51845 .16511 .53251 .15748 .52489 .14077 Mtetra
.68 .629 .791 r
.52489 .14077 .53251 .15748 .54662 .14962 .53902 .13308 Mtetra
.684 .633 .793 r
.53902 .13308 .54662 .14962 .56077 .14156 .5532 .12519 Mtetra
.688 .638 .795 r
.5532 .12519 .56077 .14156 .57497 .13331 .56742 .11713 Mtetra
.691 .643 .797 r
.56742 .11713 .57497 .13331 .58921 .1249 .5817 .1089 Mtetra
.695 .648 .799 r
.5817 .1089 .58921 .1249 .60349 .11634 .59601 .10054 Mtetra
.698 .653 .801 r
.59601 .10054 .60349 .11634 .61782 .10765 .61037 .09206 Mtetra
.701 .658 .804 r
.61037 .09206 .61782 .10765 .63218 .09886 .62477 .08348 Mtetra
.704 .663 .807 r
.62477 .08348 .63218 .09886 .64658 .08999 .63921 .07482 Mtetra
.706 .667 .81 r
.63921 .07482 .64658 .08999 .66102 .08106 .6537 .0661 Mtetra
.708 .672 .813 r
.6537 .0661 .66102 .08106 .6755 .07208 .66823 .05733 Mtetra
.71 .677 .816 r
.66823 .05733 .6755 .07208 .69002 .06308 .6828 .04854 Mtetra
.711 .682 .82 r
.6828 .04854 .69002 .06308 .70458 .05408 .69742 .03974 Mtetra
.578 .653 .888 r
.03575 .26405 .04428 .27484 .05547 .27288 .04698 .26184 Mtetra
.575 .647 .884 r
.04698 .26184 .05547 .27288 .06671 .271 .05827 .2597 Mtetra
.573 .642 .881 r
.05827 .2597 .06671 .271 .07801 .2692 .06961 .25762 Mtetra
.57 .636 .877 r
.06961 .25762 .07801 .2692 .08938 .26745 .08102 .2556 Mtetra
.568 .63 .873 r
.08102 .2556 .08938 .26745 .10081 .26576 .09249 .25363 Mtetra
.567 .624 .869 r
.09249 .25363 .10081 .26576 .1123 .2641 .10403 .25169 Mtetra
.566 .619 .865 r
.10403 .25169 .1123 .2641 .12387 .26247 .11564 .24977 Mtetra
.565 .614 .86 r
.11564 .24977 .12387 .26247 .13552 .26085 .12733 .24785 Mtetra
.565 .609 .856 r
.12733 .24785 .13552 .26085 .14724 .25922 .13909 .24593 Mtetra
.566 .605 .851 r
.13909 .24593 .14724 .25922 .15904 .25757 .15092 .24399 Mtetra
.567 .601 .847 r
.15092 .24399 .15904 .25757 .17092 .25588 .16284 .242 Mtetra
.568 .597 .843 r
.16284 .242 .17092 .25588 .18289 .25413 .17484 .23997 Mtetra
.57 .594 .838 r
.17484 .23997 .18289 .25413 .19495 .25231 .18693 .23786 Mtetra
.572 .591 .834 r
.18693 .23786 .19495 .25231 .20709 .25039 .1991 .23566 Mtetra
.575 .589 .83 r
.1991 .23566 .20709 .25039 .21933 .24835 .21137 .23336 Mtetra
.577 .587 .826 r
.21137 .23336 .21933 .24835 .23166 .24619 .22372 .23093 Mtetra
.581 .585 .822 r
.22372 .23093 .23166 .24619 .24408 .24388 .23616 .22837 Mtetra
.584 .584 .818 r
.23616 .22837 .24408 .24388 .2566 .2414 .2487 .22565 Mtetra
.588 .583 .815 r
.2487 .22565 .2566 .2414 .26921 .23874 .26133 .22277 Mtetra
.592 .583 .812 r
.26133 .22277 .26921 .23874 .28191 .23587 .27405 .2197 Mtetra
.596 .583 .809 r
.27405 .2197 .28191 .23587 .29471 .2328 .28686 .21644 Mtetra
.6 .583 .806 r
.28686 .21644 .29471 .2328 .3076 .2295 .29977 .21297 Mtetra
.604 .584 .804 r
.29977 .21297 .3076 .2295 .32058 .22596 .31276 .20928 Mtetra
.609 .585 .801 r
.31276 .20928 .32058 .22596 .33366 .22218 .32584 .20536 Mtetra
.613 .586 .799 r
.32584 .20536 .33366 .22218 .34682 .21813 .33902 .2012 Mtetra
.618 .588 .797 r
.33902 .2012 .34682 .21813 .36007 .21382 .35228 .19679 Mtetra
.623 .59 .796 r
.35228 .19679 .36007 .21382 .37341 .20923 .36562 .19213 Mtetra
.628 .592 .794 r
.36562 .19213 .37341 .20923 .38682 .20437 .37904 .18722 Mtetra
.632 .594 .793 r
.37904 .18722 .38682 .20437 .40032 .19922 .39255 .18205 Mtetra
.637 .597 .792 r
.39255 .18205 .40032 .19922 .41389 .1938 .40613 .17661 Mtetra
.642 .6 .792 r
.40613 .17661 .41389 .1938 .42754 .18809 .41978 .17092 Mtetra
.647 .603 .791 r
.41978 .17092 .42754 .18809 .44126 .18211 .43351 .16497 Mtetra
.651 .607 .791 r
.43351 .16497 .44126 .18211 .45505 .17585 .44731 .15877 Mtetra
.656 .61 .791 r
.44731 .15877 .45505 .17585 .4689 .16933 .46117 .15232 Mtetra
.661 .614 .792 r
.46117 .15232 .4689 .16933 .48281 .16255 .4751 .14563 Mtetra
.665 .618 .792 r
.4751 .14563 .48281 .16255 .49678 .15552 .48908 .13871 Mtetra
.669 .622 .793 r
.48908 .13871 .49678 .15552 .51081 .14826 .50313 .13156 Mtetra
.673 .626 .794 r
.50313 .13156 .51081 .14826 .52489 .14077 .51723 .12421 Mtetra
.678 .631 .795 r
.51723 .12421 .52489 .14077 .53902 .13308 .53138 .11667 Mtetra
.681 .635 .797 r
.53138 .11667 .53902 .13308 .5532 .12519 .54558 .10894 Mtetra
.685 .64 .798 r
.54558 .10894 .5532 .12519 .56742 .11713 .55984 .10105 Mtetra
.689 .644 .8 r
.55984 .10105 .56742 .11713 .5817 .1089 .57414 .09301 Mtetra
.692 .649 .803 r
.57414 .09301 .5817 .1089 .59601 .10054 .58849 .08484 Mtetra
.695 .654 .805 r
.58849 .08484 .59601 .10054 .61037 .09206 .60288 .07655 Mtetra
.698 .659 .808 r
.60288 .07655 .61037 .09206 .62477 .08348 .61732 .06816 Mtetra
.7 .663 .81 r
.61732 .06816 .62477 .08348 .63921 .07482 .63181 .0597 Mtetra
.703 .668 .813 r
.63181 .0597 .63921 .07482 .6537 .0661 .64634 .05118 Mtetra
.705 .673 .816 r
.64634 .05118 .6537 .0661 .66823 .05733 .66092 .04261 Mtetra
.706 .678 .82 r
.66092 .04261 .66823 .05733 .6828 .04854 .67554 .03401 Mtetra
.708 .682 .823 r
.67554 .03401 .6828 .04854 .69742 .03974 .69021 .02541 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.9902 .64006 m
.97485 .6548 L
.9644 .66383 L
.94201 .6806 L
.9386 .68288 L
.9128 .69822 L
.89624 .7064 L
.887 .71041 L
.8612 .71987 L
.8354 .72683 L
.8096 .73148 L
.80399 .7322 L
.7838 .73392 L
.758 .7342 L
.7322 .73233 L
.73081 .7322 L
.7064 .72827 L
.6806 .72192 L
.6548 .71313 L
.6388 .7064 L
.629 .70168 L
.6032 .68722 L
.59303 .6806 L
.5774 .66922 L
.56015 .6548 L
.5516 .6468 L
.53466 .629 L
.5258 .61847 L
.5143 .6032 L
.5 .58101 L
.49793 .5774 L
.48483 .5516 L
.47458 .5258 L
.4742 .52474 L
.46688 .5 L
.46153 .4742 L
.45843 .4484 L
.4575 .4226 L
.45872 .3968 L
.46212 .371 L
.46776 .3452 L
.4742 .32382 L
.47579 .3194 L
.4864 .2936 L
.49991 .2678 L
.5 .26765 L
.51677 .242 L
.5258 .23018 L
.53773 .2162 L
.5516 .20184 L
Mistroke
.56404 .1904 L
.5774 .17943 L
.59821 .1646 L
.6032 .16143 L
.629 .14696 L
.64665 .1388 L
.6548 .13551 L
.6806 .12673 L
.7064 .12038 L
.7322 .11631 L
.758 .11444 L
.7838 .11472 L
.8096 .11716 L
.8354 .12181 L
.8612 .12878 L
.887 .13824 L
.88835 .1388 L
.9128 .15043 L
.93684 .1646 L
.9386 .16576 L
.9644 .18482 L
.97097 .1904 L
.9902 .20859 L
Mfstroke
.9902 .47799 m
.98156 .5 L
.96889 .5258 L
.9644 .53373 L
.95301 .5516 L
.9386 .57096 L
.93325 .5774 L
.9128 .59918 L
.90856 .6032 L
.887 .62151 L
.87691 .629 L
.8612 .63945 L
.8354 .65385 L
.83349 .6548 L
.8096 .66526 L
.7838 .674 L
.758 .6803 L
.75697 .6806 L
.7322 .68433 L
.7064 .68617 L
.6806 .68585 L
.6548 .68337 L
.637 .6806 L
.629 .67868 L
.6032 .67167 L
.5774 .66217 L
.56109 .6548 L
.5516 .64993 L
.5258 .63454 L
.51772 .629 L
.5 .61542 L
.48606 .6032 L
.4742 .59155 L
.46137 .5774 L
.4484 .56112 L
.44162 .5516 L
.42572 .5258 L
.4226 .52002 L
.41304 .5 L
.40315 .4742 L
.3968 .45263 L
.39579 .4484 L
.39076 .4226 L
.38796 .3968 L
.38732 .371 L
.38884 .3452 L
.39254 .3194 L
.3968 .29963 L
.39851 .2936 L
.40687 .2678 L
Mistroke
.41786 .242 L
.4226 .23252 L
.43179 .2162 L
.4484 .19144 L
.44918 .1904 L
.47078 .1646 L
.4742 .161 L
.49799 .1388 L
.5 .13713 L
.5258 .118 L
.53355 .113 L
.5516 .10261 L
.5774 .09037 L
.58514 .0872 L
.6032 .08087 L
.629 .07386 L
.6548 .06917 L
.6806 .06669 L
.7064 .06637 L
.7322 .06821 L
.758 .07224 L
.7838 .07855 L
.80937 .0872 L
.8096 .08729 L
.8354 .09869 L
.86104 .113 L
.8612 .1131 L
.887 .13104 L
.89664 .1388 L
.9128 .15336 L
.92385 .1646 L
.9386 .18158 L
.94545 .1904 L
.96282 .2162 L
.9644 .21883 L
.97674 .242 L
.98774 .2678 L
.9902 .27446 L
Mfstroke
.3194 .28997 m
.3452 .28669 L
.371 .28559 L
.3968 .28665 L
.4226 .28987 L
.44187 .2936 L
.4484 .29534 L
.4742 .30317 L
.5 .31358 L
.51212 .3194 L
.5258 .32684 L
.5516 .34342 L
.55406 .3452 L
.5774 .36403 L
.58498 .371 L
.6032 .38986 L
.60917 .3968 L
.62854 .4226 L
.629 .42328 L
.64413 .4484 L
.6548 .47014 L
.65655 .4742 L
.6662 .5 L
.67335 .5258 L
.67817 .5516 L
.6806 .57459 L
.68078 .5774 L
.68122 .6032 L
.6806 .61666 L
.67951 .629 L
.67562 .6548 L
.66945 .6806 L
.66085 .7064 L
.6548 .72116 L
.64962 .7322 L
.6354 .758 L
.629 .76799 L
.61769 .7838 L
.6032 .80139 L
.59565 .8096 L
.5774 .82723 L
.56784 .8354 L
.5516 .84783 L
.53127 .8612 L
.5258 .86441 L
.5 .87768 L
.47725 .887 L
.4742 .88807 L
.4484 .89591 L
.4226 .90138 L
Mistroke
.3968 .90461 L
.371 .90566 L
.3452 .90456 L
.3194 .90129 L
.2936 .89577 L
.2678 .88787 L
.26533 .887 L
.242 .87742 L
.2162 .86408 L
.2113 .8612 L
.1904 .84742 L
.17473 .8354 L
.1646 .82672 L
.14692 .8096 L
.1388 .80075 L
.12489 .7838 L
.113 .76714 L
.10717 .758 L
.09296 .7322 L
.0872 .71986 L
.08172 .7064 L
.07312 .6806 L
.06695 .6548 L
.06306 .629 L
.0614 .60511 L
.06135 .6032 L
.0614 .58614 L
.06179 .5774 L
.0644 .5516 L
.06922 .5258 L
.07637 .5 L
.08603 .4742 L
.0872 .47145 L
.09844 .4484 L
.113 .42413 L
.11403 .4226 L
.1334 .3968 L
.1388 .39051 L
.15759 .371 L
.1646 .36453 L
.18851 .3452 L
.1904 .34383 L
.2162 .32717 L
.23046 .3194 L
.242 .31384 L
.2678 .30337 L
.2936 .29549 L
.30069 .2936 L
.3194 .28997 L
Mfstroke
.3968 .31694 m
.4226 .31532 L
.4484 .31586 L
.4742 .31855 L
.48022 .3194 L
.5 .32347 L
.5258 .33072 L
.5516 .34049 L
.56208 .3452 L
.5774 .35303 L
.6032 .36876 L
.60646 .371 L
.629 .38831 L
.63866 .3968 L
.6548 .41273 L
.6637 .4226 L
.6806 .444 L
.68371 .4484 L
.69982 .4742 L
.7064 .4866 L
.71268 .5 L
.72273 .5258 L
.73023 .5516 L
.7322 .55937 L
.7354 .5774 L
.73833 .6032 L
.7391 .629 L
.73771 .6548 L
.73414 .6806 L
.7322 .69093 L
.72832 .7064 L
.7201 .7322 L
.70927 .758 L
.7064 .76394 L
.69553 .7838 L
.6806 .80656 L
.67838 .8096 L
.65706 .8354 L
.6548 .83782 L
.63024 .8612 L
.629 .86225 L
.6032 .88181 L
.59532 .887 L
.5774 .89754 L
.5516 .91008 L
.54517 .9128 L
.5258 .91984 L
.5 .9271 L
.4742 .93201 L
.4484 .93471 L
Mistroke
.4226 .93524 L
.3968 .93363 L
.371 .92982 L
.3452 .92375 L
.3194 .91526 L
.31304 .9128 L
.2936 .90415 L
.2678 .89006 L
.26287 .887 L
.242 .87251 L
.22792 .8612 L
.2162 .85068 L
.20111 .8354 L
.1904 .82316 L
.17979 .8096 L
.1646 .78705 L
.16265 .7838 L
.14889 .758 L
.1388 .73417 L
.13808 .7322 L
.12985 .7064 L
.12403 .6806 L
.12046 .6548 L
.11908 .629 L
.11984 .6032 L
.12277 .5774 L
.12794 .5516 L
.13545 .5258 L
.1388 .51631 L
.14549 .5 L
.15836 .4742 L
.1646 .46349 L
.17446 .4484 L
.1904 .42741 L
.19448 .4226 L
.2162 .39989 L
.21952 .3968 L
.242 .37806 L
.25169 .371 L
.2678 .3605 L
.2936 .34642 L
.29612 .3452 L
.3194 .3353 L
.3452 .32681 L
.371 .32074 L
.37627 .3194 L
.3968 .31694 L
Mfstroke
.242 .08627 m
.2678 .07786 L
.2936 .07186 L
.3194 .06813 L
.3452 .06659 L
.371 .06719 L
.3968 .06996 L
.4226 .07496 L
.4484 .08229 L
.46224 .0872 L
.4742 .09214 L
.5 .10478 L
.51411 .113 L
.5258 .12063 L
.54979 .1388 L
.5516 .14033 L
.57707 .1646 L
.5774 .16495 L
.59874 .1904 L
.6032 .19648 L
.61616 .2162 L
.629 .23967 L
.63013 .242 L
.64115 .2678 L
.64955 .2936 L
.6548 .31536 L
.65554 .3194 L
.65927 .3452 L
.66081 .371 L
.6602 .3968 L
.65742 .4226 L
.6548 .4385 L
.65242 .4484 L
.64509 .4742 L
.63523 .5 L
.629 .51351 L
.62258 .5258 L
.60672 .5516 L
.6032 .55665 L
.58702 .5774 L
.5774 .5882 L
.5624 .6032 L
.5516 .61281 L
.53083 .629 L
.5258 .6325 L
.5 .64835 L
.48765 .6548 L
.4742 .66099 L
.4484 .67085 L
.4226 .67817 L
Mistroke
.41247 .6806 L
.3968 .68317 L
.371 .68594 L
.3452 .68655 L
.3194 .685 L
.2936 .68127 L
.28993 .6806 L
.2678 .67528 L
.242 .66687 L
.2162 .65584 L
.21405 .6548 L
.1904 .64187 L
.17082 .629 L
.1646 .62444 L
.13927 .6032 L
.1388 .60276 L
.11464 .5774 L
.113 .57546 L
.09493 .5516 L
.0872 .53976 L
.07907 .5258 L
.06643 .5 L
.0614 .48783 L
.05657 .4742 L
.04923 .4484 L
.04423 .4226 L
.04146 .3968 L
.04085 .371 L
.04239 .3452 L
.04611 .3194 L
.0521 .2936 L
.0605 .2678 L
.0614 .2654 L
.07152 .242 L
.08549 .2162 L
.0872 .2134 L
.10291 .1904 L
.113 .17766 L
.12457 .1646 L
.1388 .15036 L
.15185 .1388 L
.1646 .12869 L
.18757 .113 L
.1904 .11127 L
.2162 .09729 L
.23951 .0872 L
.242 .08627 L
Mfstroke
0 g
.03 w
.76753 .42432 Mdot
.69731 .37627 Mdot
.37129 .59562 Mdot
.42909 .62528 Mdot
.35083 .37657 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.46078 .37867 m
.48039 .37109 L
.5 .36629 L
.51961 .36402 L
.53922 .36423 L
.55882 .36703 L
.57843 .37279 L
.59804 .3823 L
.59813 .38235 L
.61765 .39708 L
.62242 .40196 L
.63658 .42157 L
.63725 .42254 L
.64475 .44118 L
.64838 .46078 L
.64813 .48039 L
.64425 .5 L
.63725 .51866 L
.63667 .51961 L
.62503 .53922 L
.61765 .54883 L
.60836 .55882 L
.59804 .56821 L
.58431 .57843 L
.57843 .58216 L
.55882 .59237 L
.54416 .59804 L
.53922 .59949 L
.51961 .60392 L
.5 .60573 L
.48039 .60489 L
.46078 .60114 L
.45034 .59804 L
.44118 .59403 L
.42157 .58244 L
.41644 .57843 L
.40196 .56387 L
.39814 .55882 L
.38702 .53922 L
.38235 .52791 L
.3808 .51961 L
.37848 .5 L
.37972 .48039 L
.38235 .4678 L
.38444 .46078 L
.3929 .44118 L
.40196 .42652 L
.40579 .42157 L
.42157 .40461 L
.42457 .40196 L
Mistroke
.44118 .38947 L
.45325 .38235 L
.46078 .37867 L
Mfstroke
.48039 .30157 m
.5 .29789 L
.51961 .29579 L
.53922 .29525 L
.55882 .29629 L
.57843 .29898 L
.59804 .30346 L
.59971 .30392 L
.61765 .30992 L
.63725 .31872 L
.64602 .32353 L
.65686 .33039 L
.67334 .34314 L
.67647 .34593 L
.69235 .36275 L
.69608 .36744 L
.70603 .38235 L
.71569 .40184 L
.71574 .40196 L
.72221 .42157 L
.72588 .44118 L
.727 .46078 L
.72573 .48039 L
.72213 .5 L
.7162 .51961 L
.71569 .52103 L
.70785 .53922 L
.69689 .55882 L
.69608 .56011 L
.68304 .57843 L
.67647 .58642 L
.66576 .59804 L
.65686 .60668 L
.64415 .61765 L
.63725 .62302 L
.61765 .63644 L
.61633 .63725 L
.59804 .64747 L
.57843 .65642 L
.57735 .65686 L
.55882 .6635 L
.53922 .66882 L
.51961 .67245 L
.5 .67439 L
.48039 .67464 L
.46078 .67311 L
.44118 .66968 L
.42157 .66416 L
.40326 .65686 L
.40196 .65624 L
Mistroke
.38235 .64547 L
.3705 .63725 L
.36275 .63102 L
.34877 .61765 L
.34314 .61131 L
.33307 .59804 L
.32353 .58231 L
.32155 .57843 L
.31328 .55882 L
.30776 .53922 L
.30468 .51961 L
.30392 .50761 L
.30387 .5 L
.30392 .49754 L
.30524 .48039 L
.30881 .46078 L
.31463 .44118 L
.32288 .42157 L
.32353 .42024 L
.33382 .40196 L
.34314 .38843 L
.34789 .38235 L
.36275 .3658 L
.36585 .36275 L
.38235 .34827 L
.38905 .34314 L
.40196 .33427 L
.42055 .32353 L
.42157 .323 L
.44118 .31397 L
.46078 .30689 L
.47075 .30392 L
.48039 .30157 L
Mfstroke
.5 .24388 m
.51961 .24188 L
.53922 .24108 L
.55882 .24149 L
.57843 .24313 L
.59298 .2451 L
.59804 .24607 L
.61765 .25039 L
.63725 .2562 L
.65686 .26368 L
.65924 .26471 L
.67647 .27307 L
.69541 .28431 L
.69608 .28475 L
.71569 .2993 L
.72107 .30392 L
.73529 .31774 L
.74051 .32353 L
.7549 .34217 L
.75555 .34314 L
.76719 .36275 L
.77451 .37856 L
.77599 .38235 L
.78234 .40196 L
.78648 .42157 L
.7886 .44118 L
.78879 .46078 L
.78714 .48039 L
.78367 .5 L
.77837 .51961 L
.77451 .53094 L
.77121 .53922 L
.76212 .55882 L
.7549 .57196 L
.75097 .57843 L
.73758 .59804 L
.73529 .60108 L
.72168 .61765 L
.71569 .62425 L
.70283 .63725 L
.69608 .64354 L
.68038 .65686 L
.67647 .65993 L
.65686 .67401 L
.65312 .67647 L
.63725 .68614 L
.61857 .69608 L
.61765 .69653 L
.59804 .70536 L
.57843 .71273 L
Mistroke
.56939 .71569 L
.55882 .71872 L
.53922 .72336 L
.51961 .72669 L
.5 .72869 L
.48039 .72935 L
.46078 .72864 L
.44118 .72648 L
.42157 .72279 L
.40196 .71745 L
.39657 .71569 L
.38235 .71027 L
.36275 .70102 L
.35389 .69608 L
.34314 .68933 L
.32576 .67647 L
.32353 .67462 L
.30475 .65686 L
.30392 .65597 L
.28839 .63725 L
.28431 .63156 L
.27548 .61765 L
.26534 .59804 L
.26471 .59665 L
.25755 .57843 L
.25184 .55882 L
.24803 .53922 L
.24599 .51961 L
.24566 .5 L
.24701 .48039 L
.25003 .46078 L
.25478 .44118 L
.26133 .42157 L
.26471 .41312 L
.26979 .40196 L
.28036 .38235 L
.28431 .37592 L
.29329 .36275 L
.30392 .34904 L
.30897 .34314 L
.32353 .3278 L
.328 .32353 L
.34314 .31036 L
.35137 .30392 L
.36275 .29577 L
.38093 .28431 L
.38235 .28349 L
.40196 .27314 L
.42099 .26471 L
.42157 .26447 L
Mistroke
.44118 .25732 L
.46078 .25155 L
.48039 .2471 L
.49125 .2451 L
.5 .24388 L
Mfstroke
.46078 .20208 m
.48039 .19813 L
.5 .1952 L
.51961 .19328 L
.53922 .19235 L
.55882 .19242 L
.57843 .1935 L
.59804 .19562 L
.61765 .19882 L
.63725 .20318 L
.64736 .20588 L
.65686 .20876 L
.67647 .21569 L
.69608 .22412 L
.69894 .22549 L
.71569 .23426 L
.73335 .2451 L
.73529 .2464 L
.7549 .26099 L
.75936 .26471 L
.77451 .27871 L
.77994 .28431 L
.79412 .3008 L
.79653 .30392 L
.80997 .32353 L
.81373 .32984 L
.82077 .34314 L
.82929 .36275 L
.83333 .37412 L
.83579 .38235 L
.84042 .40196 L
.84332 .42157 L
.84459 .44118 L
.84428 .46078 L
.84242 .48039 L
.83905 .5 L
.83415 .51961 L
.83333 .5224 L
.8277 .53922 L
.81966 .55882 L
.81373 .57126 L
.80997 .57843 L
.79853 .59804 L
.79412 .60487 L
.78521 .61765 L
.77451 .63158 L
.76983 .63725 L
.7549 .65397 L
.75213 .65686 L
.73529 .67324 L
Mistroke
.73173 .67647 L
.71569 .69008 L
.70806 .69608 L
.69608 .70492 L
.68016 .71569 L
.67647 .71803 L
.65686 .72961 L
.64625 .73529 L
.63725 .7398 L
.61765 .7487 L
.60205 .7549 L
.59804 .75637 L
.57843 .76288 L
.55882 .76825 L
.53922 .7725 L
.52787 .77451 L
.51961 .77565 L
.5 .77768 L
.48039 .77858 L
.46078 .77833 L
.44118 .77688 L
.42324 .77451 L
.42157 .77418 L
.40196 .77017 L
.38235 .76474 L
.36275 .75777 L
.35578 .7549 L
.34314 .7491 L
.32353 .7385 L
.31827 .73529 L
.30392 .72566 L
.2909 .71569 L
.28431 .71012 L
.26942 .69608 L
.26471 .69115 L
.25201 .67647 L
.2451 .66747 L
.23772 .65686 L
.22596 .63725 L
.22549 .6364 L
.21634 .61765 L
.20863 .59804 L
.20588 .58983 L
.20262 .57843 L
.1982 .55882 L
.19527 .53922 L
.19378 .51961 L
.19368 .5 L
.19496 .48039 L
.19763 .46078 L
Mistroke
.2017 .44118 L
.20588 .42584 L
.20724 .42157 L
.21431 .40196 L
.223 .38235 L
.22549 .37735 L
.23346 .36275 L
.2451 .34428 L
.24588 .34314 L
.2605 .32353 L
.26471 .31844 L
.27771 .30392 L
.28431 .29718 L
.29803 .28431 L
.30392 .27921 L
.32232 .26471 L
.32353 .26382 L
.34314 .25052 L
.35202 .2451 L
.36275 .23901 L
.38235 .22905 L
.39013 .22549 L
.40196 .22049 L
.42157 .2132 L
.44118 .20708 L
.44548 .20588 L
.46078 .20208 L
Mfstroke
.51961 .1466 m
.53922 .1456 L
.55882 .14545 L
.57843 .14616 L
.59239 .14706 L
.59804 .14775 L
.61765 .15025 L
.63725 .15369 L
.65686 .15813 L
.67647 .16363 L
.68591 .16667 L
.69608 .17026 L
.71569 .17815 L
.73303 .18627 L
.73529 .18742 L
.7549 .19826 L
.76706 .20588 L
.77451 .21093 L
.79376 .22549 L
.79412 .22578 L
.81373 .24334 L
.81551 .2451 L
.83333 .26449 L
.83352 .26471 L
.84854 .28431 L
.85294 .29079 L
.86106 .30392 L
.87141 .32353 L
.87255 .32592 L
.87984 .34314 L
.88652 .36275 L
.89158 .38235 L
.89216 .38481 L
.89513 .40196 L
.89723 .42157 L
.89795 .44118 L
.89732 .46078 L
.89536 .48039 L
.89216 .49966 L
.89208 .5 L
.88748 .51961 L
.88155 .53922 L
.87426 .55882 L
.87255 .56295 L
.86556 .57843 L
.8554 .59804 L
.85294 .6024 L
.84371 .61765 L
.83333 .63312 L
.83038 .63725 L
Mistroke
.81528 .65686 L
.81373 .65875 L
.79823 .67647 L
.79412 .68086 L
.77898 .69608 L
.77451 .70031 L
.75721 .71569 L
.7549 .71762 L
.73529 .73313 L
.73238 .73529 L
.71569 .74707 L
.7037 .7549 L
.69608 .75962 L
.67647 .7709 L
.66972 .77451 L
.65686 .781 L
.63725 .78999 L
.6274 .79412 L
.61765 .79793 L
.59804 .80485 L
.57843 .81077 L
.56726 .81373 L
.55882 .81572 L
.53922 .81971 L
.51961 .82272 L
.5 .82477 L
.48039 .82583 L
.46078 .82589 L
.44118 .82491 L
.42157 .82287 L
.40196 .81972 L
.38235 .81539 L
.37598 .81373 L
.36275 .80981 L
.34314 .80289 L
.32353 .7945 L
.32271 .79412 L
.30392 .7845 L
.28717 .77451 L
.28431 .77266 L
.26471 .75871 L
.25986 .7549 L
.2451 .74225 L
.23773 .73529 L
.22549 .72265 L
.21931 .71569 L
.20588 .69892 L
.20379 .69608 L
.19065 .67647 L
.18627 .66916 L
Mistroke
.17953 .65686 L
.17019 .63725 L
.16667 .62883 L
.16245 .61765 L
.15617 .59804 L
.15127 .57843 L
.14765 .55882 L
.14706 .55557 L
.14528 .53922 L
.14412 .51961 L
.14415 .5 L
.14535 .48039 L
.14706 .46459 L
.14773 .46078 L
.15132 .44118 L
.15614 .42157 L
.16224 .40196 L
.16667 .38983 L
.16968 .38235 L
.17854 .36275 L
.18627 .34789 L
.18895 .34314 L
.20103 .32353 L
.20588 .31638 L
.21498 .30392 L
.22549 .29078 L
.23105 .28431 L
.2451 .2692 L
.24959 .26471 L
.26471 .25062 L
.27111 .2451 L
.28431 .23444 L
.29636 .22549 L
.30392 .22022 L
.32353 .2077 L
.3266 .20588 L
.34314 .19666 L
.36275 .18695 L
.3642 .18627 L
.38235 .17843 L
.40196 .17102 L
.41497 .16667 L
.42157 .16463 L
.44118 .15923 L
.46078 .15475 L
.48039 .15117 L
.5 .14846 L
.51316 .14706 L
.51961 .1466 L
Mfstroke
.46078 .10736 m
.48039 .10406 L
.5 .10153 L
.51961 .09974 L
.53922 .0987 L
.55882 .0984 L
.57843 .09885 L
.59804 .10006 L
.61765 .10206 L
.63725 .10486 L
.65372 .10784 L
.65686 .10849 L
.67647 .11301 L
.69608 .11845 L
.71569 .12489 L
.72272 .12745 L
.73529 .1324 L
.7549 .14108 L
.76698 .14706 L
.77451 .15106 L
.79412 .1625 L
.80064 .16667 L
.81373 .17562 L
.82785 .18627 L
.83333 .19071 L
.8505 .20588 L
.85294 .20821 L
.86965 .22549 L
.87255 .22875 L
.88597 .2451 L
.89216 .25342 L
.8999 .26471 L
.91176 .28431 L
.91176 .28431 L
.92179 .30392 L
.93015 .32353 L
.93137 .32671 L
.93699 .34314 L
.9424 .36275 L
.94646 .38235 L
.94924 .40196 L
.95077 .42157 L
.95098 .42682 L
.95111 .44118 L
.95098 .447 L
.95026 .46078 L
.94825 .48039 L
.94508 .5 L
.94075 .51961 L
.93524 .53922 L
Mistroke
.93137 .55099 L
.92854 .55882 L
.92061 .57843 L
.91176 .59737 L
.91143 .59804 L
.90093 .61765 L
.89216 .63237 L
.88907 .63725 L
.87574 .65686 L
.87255 .66126 L
.86087 .67647 L
.85294 .68612 L
.84431 .69608 L
.83333 .70802 L
.8259 .71569 L
.81373 .72759 L
.80541 .73529 L
.79412 .74525 L
.78253 .7549 L
.77451 .76127 L
.7568 .77451 L
.7549 .77586 L
.73529 .78918 L
.72753 .79412 L
.71569 .80132 L
.69608 .81238 L
.69356 .81373 L
.67647 .82242 L
.65686 .83149 L
.65261 .83333 L
.63725 .83963 L
.61765 .84686 L
.59896 .85294 L
.59804 .85322 L
.57843 .85871 L
.55882 .86333 L
.53922 .86711 L
.51961 .87002 L
.5 .87207 L
.49369 .87255 L
.48039 .87325 L
.46078 .87354 L
.44118 .87291 L
.43358 .87255 L
.42157 .87135 L
.40196 .86882 L
.38235 .86528 L
.36275 .86068 L
.34314 .85496 L
.33703 .85294 L
Mistroke
.32353 .84804 L
.30392 .83984 L
.29032 .83333 L
.28431 .83023 L
.26471 .81907 L
.25623 .81373 L
.2451 .80617 L
.22903 .79412 L
.22549 .79127 L
.20642 .77451 L
.20588 .774 L
.18723 .7549 L
.18627 .75385 L
.17073 .73529 L
.16667 .72999 L
.15647 .71569 L
.14706 .701 L
.14413 .69608 L
.13347 .67647 L
.12745 .66392 L
.12433 .65686 L
.11656 .63725 L
.11007 .61765 L
.10784 .60994 L
.10479 .59804 L
.10065 .57843 L
.09761 .55882 L
.09563 .53922 L
.09469 .51961 L
.09478 .5 L
.0959 .48039 L
.09805 .46078 L
.10124 .44118 L
.10549 .42157 L
.10784 .4124 L
.11084 .40196 L
.11734 .38235 L
.12502 .36275 L
.12745 .35713 L
.13398 .34314 L
.14429 .32353 L
.14706 .31868 L
.15607 .30392 L
.16667 .2882 L
.16946 .28431 L
.18466 .26471 L
.18627 .26276 L
.2019 .2451 L
.20588 .2409 L
.22151 .22549 L
Mistroke
.22549 .22181 L
.24397 .20588 L
.2451 .20497 L
.26471 .19 L
.26995 .18627 L
.28431 .17664 L
.30054 .16667 L
.30392 .16471 L
.32353 .15404 L
.33767 .14706 L
.34314 .14451 L
.36275 .13605 L
.38235 .12856 L
.38549 .12745 L
.40196 .122 L
.42157 .1163 L
.44118 .11143 L
.45822 .10784 L
.46078 .10736 L
Mfstroke
.9902 .54155 m
.98469 .55882 L
.97742 .57843 L
.97059 .59462 L
.96904 .59804 L
.95953 .61765 L
.95098 .63349 L
.94883 .63725 L
.93689 .65686 L
.93137 .66528 L
.92366 .67647 L
.91176 .69257 L
.90904 .69608 L
.89295 .71569 L
.89216 .71661 L
.87527 .73529 L
.87255 .73815 L
.85583 .7549 L
.85294 .75766 L
.83444 .77451 L
.83333 .77547 L
.81373 .79181 L
.81082 .79412 L
.79412 .80684 L
.78458 .81373 L
.77451 .8207 L
.75515 .83333 L
.7549 .83349 L
.73529 .84528 L
.72162 .85294 L
.71569 .85613 L
.69608 .86608 L
.68234 .87255 L
.67647 .87518 L
.65686 .88346 L
.63725 .89093 L
.63382 .89216 L
.61765 .89761 L
.59804 .90351 L
.57843 .90864 L
.56479 .91176 L
.55882 .91301 L
.53922 .9166 L
.51961 .91943 L
.5 .92148 L
.48039 .92274 L
.46078 .9232 L
.44118 .92286 L
.42157 .92167 L
.40196 .91963 L
Mistroke
.38235 .9167 L
.36275 .91285 L
.35791 .91176 L
.34314 .90804 L
.32353 .90222 L
.30392 .89533 L
.29583 .89216 L
.28431 .88729 L
.26471 .87802 L
.25427 .87255 L
.2451 .86741 L
.22549 .85533 L
.2219 .85294 L
.20588 .84159 L
.1952 .83333 L
.18627 .82598 L
.17251 .81373 L
.16667 .80817 L
.15289 .79412 L
.14706 .78773 L
.13576 .77451 L
.12745 .764 L
.12071 .7549 L
.10784 .73592 L
.10745 .73529 L
.09578 .71569 L
.08824 .70152 L
.08553 .69608 L
.07658 .67647 L
.06884 .65686 L
.06863 .65629 L
.06222 .63725 L
.05666 .61765 L
.05212 .59804 L
.04902 .58134 L
.04856 .57843 L
.04595 .55882 L
.04426 .53922 L
.04348 .51961 L
.04361 .5 L
.04464 .48039 L
.04657 .46078 L
.04902 .44348 L
.04942 .44118 L
.0532 .42157 L
.05793 .40196 L
.06365 .38235 L
.06863 .36759 L
.07039 .36275 L
.07821 .34314 L
Mistroke
.08715 .32353 L
.08824 .32131 L
.09729 .30392 L
.10784 .28576 L
.10873 .28431 L
.12158 .26471 L
.12745 .25643 L
.13597 .2451 L
.14706 .23137 L
.15208 .22549 L
.16667 .20949 L
.17015 .20588 L
.18627 .19013 L
.19047 .18627 L
.20588 .17286 L
.21347 .16667 L
.22549 .15735 L
.23973 .14706 L
.2451 .14337 L
.26471 .13075 L
.27016 .12745 L
.28431 .11933 L
.30392 .10902 L
.30628 .10784 L
.32353 .09971 L
.34314 .09134 L
.35099 .08824 L
.36275 .08385 L
.38235 .07717 L
.40196 .07128 L
.41171 .06863 L
.42157 .06614 L
.44118 .06171 L
.46078 .05799 L
.48039 .05494 L
.5 .05256 L
.51961 .05084 L
.53922 .04978 L
.55882 .04937 L
.57843 .04963 L
.59804 .05055 L
.61765 .05216 L
.63725 .05446 L
.65686 .05749 L
.67647 .06127 L
.69608 .06583 L
.70667 .06863 L
.71569 .07121 L
.73529 .07747 L
.7549 .08467 L
Mistroke
.76374 .08824 L
.77451 .09288 L
.79412 .10218 L
.80497 .10784 L
.81373 .1127 L
.83333 .12458 L
.83774 .12745 L
.85294 .13799 L
.86494 .14706 L
.87255 .15319 L
.88803 .16667 L
.89216 .1705 L
.90791 .18627 L
.91176 .19042 L
.92514 .20588 L
.93137 .2137 L
.94013 .22549 L
.95098 .24161 L
.95316 .2451 L
.96445 .26471 L
.97059 .27672 L
.97417 .28431 L
.98244 .30392 L
.98936 .32353 L
.9902 .32616 L
Mfstroke
.0098 .65592 m
.0101 .65686 L
.01676 .67647 L
.0244 .69608 L
.02941 .70768 L
.0331 .71569 L
.04291 .73529 L
.04902 .74644 L
.05394 .7549 L
.06628 .77451 L
.06863 .77799 L
.0801 .79412 L
.08824 .80472 L
.09555 .81373 L
.10784 .82785 L
.1129 .83333 L
.12745 .84815 L
.13245 .85294 L
.14706 .86612 L
.15468 .87255 L
.16667 .8821 L
.18027 .89216 L
.18627 .89635 L
.20588 .90907 L
.21034 .91176 L
.22549 .92041 L
.2451 .93049 L
.24694 .93137 L
.26471 .9394 L
.28431 .94723 L
.29472 .95098 L
.30392 .95405 L
.32353 .95991 L
.34314 .96485 L
.36275 .96892 L
.37213 .97059 L
.38235 .97216 L
.40196 .97458 L
.42157 .97621 L
.44118 .97708 L
.46078 .9772 L
.48039 .97659 L
.5 .97526 L
.51961 .97323 L
.53857 .97059 L
.53922 .97048 L
.55882 .96705 L
.57843 .96292 L
.59804 .9581 L
.61765 .95259 L
Mistroke
.62296 .95098 L
.63725 .94639 L
.65686 .93948 L
.67647 .93187 L
.67769 .93137 L
.69608 .92354 L
.71569 .91447 L
.72124 .91176 L
.73529 .90464 L
.7549 .89403 L
.75823 .89216 L
.77451 .88261 L
.79068 .87255 L
.79412 .87033 L
.81373 .85714 L
.81968 .85294 L
.83333 .84297 L
.84591 .83333 L
.85294 .82775 L
.8698 .81373 L
.87255 .81135 L
.89167 .79412 L
.89216 .79366 L
.91173 .77451 L
.91176 .77447 L
.93016 .7549 L
.93137 .75356 L
.9471 .73529 L
.95098 .73056 L
.96266 .71569 L
.97059 .705 L
.97692 .69608 L
.98995 .67647 L
.9902 .67609 L
Mfstroke
.9902 .19312 m
.98518 .18627 L
.97059 .16786 L
.96958 .16667 L
.95192 .14706 L
.95098 .14608 L
.93187 .12745 L
.93137 .127 L
.91176 .1101 L
.90896 .10784 L
.89216 .09505 L
.88251 .08824 L
.87255 .08157 L
.85294 .06949 L
.85146 .06863 L
.83333 .05864 L
.81394 .04902 L
.81373 .04892 L
.79412 .04021 L
.77451 .03245 L
.76615 .02941 L
.7549 .02557 L
.73529 .0195 L
.71569 .01421 L
.69678 .0098 L
s
.0098 .3697 m
.01201 .36275 L
.01886 .34314 L
.02667 .32353 L
.02941 .31716 L
.03548 .30392 L
.04535 .28431 L
.04902 .27754 L
.05636 .26471 L
.06859 .2451 L
.06863 .24505 L
.08215 .22549 L
.08824 .2173 L
.09717 .20588 L
.10784 .19306 L
.1138 .18627 L
.12745 .17157 L
.13225 .16667 L
.14706 .15231 L
.15278 .14706 L
.16667 .13494 L
.17575 .12745 L
.18627 .11919 L
.20165 .10784 L
.20588 .10486 L
.22549 .0918 L
.23117 .08824 L
.2451 .07988 L
.26471 .06901 L
.26543 .06863 L
.28431 .05909 L
.30392 .05006 L
.3063 .04902 L
.32353 .04185 L
.34314 .03443 L
.35765 .02941 L
.36275 .02774 L
.38235 .02176 L
.40196 .01645 L
.42157 .01179 L
.43082 .0098 L
s
.9902 .78032 m
.97785 .79412 L
.97059 .8019 L
.95914 .81373 L
.95098 .82183 L
.93895 .83333 L
.93137 .84033 L
.91717 .85294 L
.91176 .85758 L
.8936 .87255 L
.89216 .8737 L
.87255 .88882 L
.86804 .89216 L
.85294 .903 L
.84017 .91176 L
.83333 .91631 L
.81373 .92882 L
.80956 .93137 L
.79412 .94055 L
.77556 .95098 L
.77451 .95155 L
.7549 .96185 L
.73713 .97059 L
.73529 .97146 L
.71569 .98041 L
.69608 .9887 L
.69237 .9902 L
s
.0098 .80453 m
.01587 .81373 L
.02941 .83282 L
.0298 .83333 L
.04517 .85294 L
.04902 .85756 L
.06218 .87255 L
.06863 .87948 L
.08107 .89216 L
.08824 .89907 L
.10217 .91176 L
.10784 .91667 L
.12592 .93137 L
.12745 .93255 L
.14706 .9469 L
.15301 .95098 L
.16667 .95987 L
.18452 .97059 L
.18627 .97159 L
.20588 .98215 L
.22237 .9902 L
s
.9902 .09079 m
.98753 .08824 L
.97059 .07289 L
.96559 .06863 L
.95098 .05678 L
.94079 .04902 L
.93137 .04221 L
.91241 .02941 L
.91176 .02899 L
.89216 .017 L
.87941 .0098 L
s
.0098 .21993 m
.01896 .20588 L
.02941 .1909 L
.03279 .18627 L
.04795 .16667 L
.04902 .16535 L
.06457 .14706 L
.06863 .14254 L
.08282 .12745 L
.08824 .12198 L
.10292 .10784 L
.10784 .10332 L
.12513 .08824 L
.12745 .0863 L
.14706 .07072 L
.14982 .06863 L
.16667 .05641 L
.17748 .04902 L
.18627 .04326 L
.20588 .03115 L
.20884 .02941 L
.22549 .02 L
.24498 .0098 L
s
.9902 .88965 m
.98743 .89216 L
.97059 .90699 L
.96498 .91176 L
.95098 .92334 L
.94091 .93137 L
.93137 .93877 L
.91505 .95098 L
.91176 .95337 L
.89216 .96718 L
.88715 .97059 L
.87255 .98026 L
.8569 .9902 L
s
.0098 .93263 m
.02779 .95098 L
.02941 .95256 L
.0489 .97059 L
.04902 .97069 L
.06863 .98725 L
.07231 .9902 L
s
.0098 .09032 m
.01171 .08824 L
.02941 .06971 L
.03049 .06863 L
.04902 .05082 L
.05098 .04902 L
.06863 .03344 L
.07341 .02941 L
.08824 .01739 L
.09807 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo013ooooo00?o
0000ooooooooool05_ooool2o`0001gooooo0P000002o`0002kooooo1ol0000Jooooo`;o00005Ooo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool=000000;o00005P0I
6AT3o`0001`0<c<c0`00000i04a<C0?o00006@0c<c<2o`0000l06ATI1?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool<00000003o`00000I6AT06ATI01D06ATI00?o
000003<c<`0c<c<06@0c<c<4000003l0C4a<0ol0000H03<c<`03o`00000I6AT06ATI00`06ATI1?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool;00000003o`00000I
6AT06ATI01@06ATI0_l0000H03<c<`0400000?l000000000000004H0C4a<00?o000003<c<`0c<c<0
5P0c<c<3o`0000/06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
ooooool:00000003o`00000I6AT06ATI01@06ATI00?o000003<c<`0c<c<05@0c<c<3000004/0C4a<
0ol0000H03<c<`03o`00000I6AT06ATI00P06ATI1?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003oooooooooooooool900000003o`00000I6AT06ATI01@06ATI00?o000003<c<`0c<c<0
4`0c<c<300000540C4a<0ol0000F03<c<`03o`00000I6AT06ATI00L06ATI1?ooool00`00003ooooo
ooooo`3?ooooo`002Oooool01000003oooooooooooooool800000003o`00000I6AT06ATI01<06ATI
0_l0000E03<c<`030000001<C4`0C4a<05D0C4a<00?o000003<c<`0c<c<0500c<c<00ol000006ATI
01TI6@0601TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
1P000002o`0001@06ATI0_l0000D03<c<`<00000801<C4`I00000200C4a<0ol0000D03<c<`03o`00
000I6AT06ATI00D06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
ooooool500000003o`00000I6AT06ATI01806ATI0_l0000C03<c<`<00000701<C4`7000001T0IVIV
1`00000L04a<C0?o00004P0c<c<2o`0000D06ATI1?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003oooooooooooooool400000003o`00000I6AT06ATI01806ATI00?o000003<c<`0c<c<0
4P0c<c<00`000000C4a<04a<C00J04a<C0<000009`1VIVH4000001/0C4a<00?o000003<c<`0c<c<0
4@0c<c<00ol000006ATI01TI6@0201TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000oooooooooooooooo0`0000000ol000006ATI01TI6@0A01TI6@;o00004`0c<c<2000001P0C4a<
1@00000^06IVIP@00000601<C4`2o`000180<c<c00Co000001TI6@0I6AT06ATI1?ooool00`00003o
ooooooooo`3?ooooo`002Oooool01000003oooooooooooooool300000003o`00000I6AT06ATI0100
6ATI00?o000003<c<`0c<c<04@0c<c<2000001P0C4a<0P00000g06IVIP<000005`1<C4`00ol00000
<c<c03<c<`0@03<c<`03o`00000I6AT06ATI00Cooooo00<00000ooooooooool0coooool000Wooooo
00@00000oooooooooooooooo0P0000000ol000006ATI01TI6@0@01TI6@03o`00000c<c<0<c<c0140
<c<c00<0000004a<C01<C4`0501<C4`4000003`0IVIV0`00000E04a<C003o`00000c<c<0<c<c0100
<c<c00?o000001TI6Oooool00oooool00`00003oooooooooo`3?ooooo`002Oooool01P00003ooooo
ooooooooool00000o`0001806ATI00?o000003<c<`0c<c<04@0c<c<00`000000C4a<04a<C00B04a<
C0<00000@`1VIVH00`00003o000004a<C00C04a<C003o`00000c<c<0<c<c0100<c<c00?o0000oooo
ooooool00_ooool00`00003oooooooooo`2;ooooo`;o0000@_ooool000Wooooo00D00000oooooooo
ooooooooo`00000B01TI6@;o0000400c<c<00`00003o00000000000B04a<C00300000?l000000000
04P0IVIV1000000A04a<C0;o00004@0c<c<01Ol0003oooooooooooooool0000008[ooooo0ol00000
0ooooooo0000ooooo`11ooooo`002Oooool01000003ooooooooooooooolB01TI6@03o`00000c<c<0
<c<c00h0<c<c0P00000C04a<C08000008P1VIVH;00000280IVIV0P00000A04a<C0;o00003`0c<c<4
ooooo`0300000?oooooooooo08Kooooo0_l00004ooooo`;o0000@Oooool000Wooooo00@00000oooo
oooooooooooo4@0I6AT00ol00000<c<c03<c<`0>03<c<`030000001<C4`0C4a<0140C4a<0P00000J
06IVIPX000002`1oOgl;000001T0IVIV0P00000A04a<C003o`00000c<c<0<c<c00`0<c<c1?ooool0
0`00003oooooooooo`23ooooo`?o00001_ooool00ol0003oooooo`000010ooooo`002Oooool01000
003oooooooooooooool@01TI6@03o`00000c<c<0<c<c00h0<c<c00<00000o`00001<C4`03`1<C4`3
000001P0IVIV00@00000o`000?l000000000801oOgl3000001P0IVIV00?o000004a<C01<C4`03`1<
C4`2o`0000`0<c<c1?ooool00`00003oooooooooo`20ooooo`?o00002Oooool00ol0003oooooo`00
0010ooooo`002Oooool01000003oooooooooooooool@01TI6@03o`00000c<c<0<c<c00d0<c<c00<0
000004a<C01<C4`03P1<C4`2000001P0IVIV0`00000W07moO`@000005@1VIVH200000140C4a<00?o
000003<c<`0c<c<02@0c<c<4ooooo`0300000?oooooooooo07kooooo0_l0000<ooooo`04o`000?oo
ooooooooo`0003oooooo0009ooooo`0400000?ooooooooooooooo`l06ATI00?o000003<c<`0c<c<0
300c<c<2000000l0C4a<0P00000F06IVIP@00000;P1oOgl3000001@0IVIV0P00000@04a<C003o`00
000c<c<0<c<c00P0<c<c1?ooool00`00003oooooooooo`1kooooo`?o00003Oooool00one[];o0000
ooooo`02ooooo`03o`000?oooooooooo03cooooo0009ooooo`0400000?ooooooooooooooo`d06ATI
0_l0000>03<c<`030000001<C4`0C4a<00h0C4a<00<0000006IVIP1VIVH04@1VIVH5000003D0Ogmo
00@00000o`000000000000004P1VIVH2000000l0C4a<00?o000003<c<`0c<c<01`0c<c<4ooooo`03
00000?oooooooooo07Wooooo0_l0000>ooooo`?o]JkB00Go0000ooooooooooooooooo`00000noooo
o`002Oooool01000003oooooooooooooool<01TI6@03o`00000c<c<0<c<c00d0<c<c00<0000004a<
C01<C4`03@1<C4`00`00003o000006IVIP0A06IVIP80000000?o000007moO`1oOgl0>`1oOgl20000
0180IVIV00<0000004a<C01<C4`0301<C4`00ol00000<c<c03<c<`0703<c<`Cooooo00<00000oooo
ooooool0M_ooool3o`0000oooooo0_nd[M42okF^dP03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0>oooool000Wooooo00@00000oooooooooooooooo2`0I6AT00ol00000<c<c03<c<`0=03<c
<`030000001<C4`0C4a<00`0C4a<0P00000A06IVIP<00000@P1oOgl200000140IVIV00<0000004a<
C01<C4`0301<C4`00ol00000<c<c03<c<`0603<c<`Cooooo00<00000ooooooooool0M?ooool2o`00
013ooooo00?o]:c@okB]dOnd[M400_nd[M400one[];o0000okJ^d@03ooooo`03o`000?oooooooooo
03_ooooo0009ooooo`0400000?ooooooooooooooo`X06ATI00?o000003<c<`0c<c<03@0c<c<00`00
0000C4a<04a<C00<04a<C0030000001VIVH0IVIV0100IVIV00<0000007moO`1oOgl0A@1oOgl20000
0100IVIV00<0000004a<C01<C4`0301<C4`00ol00000<c<c03<c<`0503<c<`Cooooo00<00000oooo
ooooool0LOooool3o`0000oooooo00?o/j_@okB/d?nd[=000_nd[=02okB]d@04okF]d?nf[]7o0000
okJ^d@Cooooo00?o0000ooooooooool0>_ooool000Wooooo00@00000oooooooooooooooo2@0I6AT0
0ol00000<c<c03<c<`0=03<c<`030000001<C4`0C4a<00`0C4a<00?o000006IVIP1VIVH03P1VIVH0
0`00003o00000000000I07moO`@000000_l0000<00000004o`00000000000000000001/0Ogmo00?o
000006IVIP1VIVH03P1VIVH00ol00000C4a<04a<C00<04a<C0;o00001@0c<c<4ooooo`0300000?oo
oooooooo06kooooo0ol0000Aooooo`?o/j_@0_nd[=000one[=3o]Jg@okF]d002okF]d003o`000?nf
[]7o]jkA00Cooooo00?o0000ooooooooool0>Oooool000Wooooo00@00000oooooooooooooooo2@0I
6AT00ol00000<c<c03<c<`0;03<c<`0300000?l00000C4a<00d0C4a<00<0000006IVIP1VIVH0301V
IVH3000001D0Ogmo1`00000F09VIV@L000005@1oOgl2000000l0IVIV0P00000>04a<C003o`00000c
<c<0<c<c0080<c<c1?ooool00`00003oooooooooo`1/ooooo`;o00004_ooool00oncZLoo/j_@ok>[
d002ok>[d004okB/d?ne[=3o]Jc@okF/d0?o]Jg@00Co]ZkAo`000?ng[]7o]jkA0oooool00ol0003o
ooooooooo`0iooooo`002Oooool01000003oooooooooooooool801TI6@03o`00000c<c<0<c<c00/0
<c<c00<0000004a<C01<C4`0301<C4`2000000h0IVIV00<0000007moO`1oOgl04`1oOgl3000002@0
VIVI0`00000D07moO`8000003`1VIVH00`000000C4a<04a<C00<04a<C004o`00000c<c<0<c<c03<c
<`Cooooo00<00000ooooooooool0JOooool3o`0001;ooooo00Co/ZS>ok>YconcZLoo/jW?0oncZm04
okF/d0;o]Jg@00Go]Zg@okN^dOl0003o]jkAokR^d004ooooo`03o`000?oooooooooo03Sooooo0009
ooooo`0400000?ooooooooooooooo`H06ATI0_l0000=03<c<`030000001<C4`0C4a<00`0C4a<00<0
000006IVIP1VIVH02`1VIVH00`00003o00000000000A07moO`D00000:P2IVIT01000003o00000000
0000000B07moO`03o`0000000000IVIV00d0IVIV00?o000004a<C01<C4`0301<C4`00ol00000<c<c
03<c<`04ooooo`0300000?oooooooooo06Oooooo0_l0000Dooooo`?o/ZS>0oncZLl00oncZm3o]:[?
okBZc`03okF/d0Co]Zg@00Co0000okR^d?nh[]3o^:k@1?ooool00ol0003oooooooooo`0gooooo`00
2Oooool01000003oooooooooooooool601TI6@03o`00000c<c<0<c<c00/0<c<c00?o000004a<C01<
C4`0301<C4`00`000000IVIV06IVIP0;06IVIP030000001oOgl0Ogmo0100Ogmo0P00000c09VIV@<0
00004@1oOgl00`000000IVIV06IVIP0<06IVIP030000001<C4`0C4a<00/0C4a<00?o000003<c<`0c
<c<01?ooool00`00003oooooooooo`1Tooooo`?o00005?ooool00onaYlko/ZS>ok:XcP02ok:XcP;o
/jW?00?o]:W>okBZcondZ/l00_ndZ/l00one[=3o]Zc?okJ/c`03okJ]d004o`000?nh[]3o^:k@okR^
d0Cooooo00?o0000ooooooooool0=oooool000Wooooo00@00000oooooooooooooooo1@0I6AT00ol0
0000<c<c03<c<`0<03<c<`030000001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH02`1VIVH00`00
0000Ogmo07moO`0@07moO`030000002IVIT0VIVI03H0VIVI0`00000?07moO`8000003@1VIVH00`00
0000C4a<04a<C00:04a<C003o`00000c<c<0<c<c00Cooooo00<00000ooooooooool0H_ooool2o`00
01Gooooo1?naYlh2ok:XcP03ok>XcOndZLko]:W>00;o]:W>0_ndZ/l00oneZ/ko]Zc?okJ/c`02okJ/
c`03okJ]d?ng[Loo000000;o^:k@00?o^Jo?ooooooooool00oooool00ol0003oooooooooo`0foooo
o`002Oooool01000003oooooooooooooool501TI6@03o`00000c<c<0<c<c00/0<c<c00<0000004a<
C01<C4`02`1<C4`00`000000IVIV06IVIP0;06IVIP030000001oOgl0Ogmo00h0Ogmo0`00000l09VI
V@030000001oOgl0Ogmo00h0Ogmo00<0000006IVIP1VIVH02`1VIVH00`000000C4a<04a<C00:04a<
C003o`00000c<c?ooooo00?ooooo00<00000ooooooooool0Goooool3o`0001Kooooo0_naY/d3ok6W
cP04ok:Xc_ncZ<go/jS=ok>Xc@;o]:W>00?o]:W=okFZc_neZ/h00_neZ/h2okJ/c`05okN/c_ng[Loo
]jg?o`000?nh[]000oni[ll5ooooo`03o`000?oooooooooo03Gooooo0009ooooo`0400000?oooooo
ooooooooo`@06ATI00?o000003<c<`0c<c<02`0c<c<00`000000C4a<04a<C00;04a<C0030000001V
IVH0IVIV00/0IVIV00<0000007moO`1oOgl0301oOgl300000400VIVI0P00000?07moO`03o`00001V
IVH0IVIV00/0IVIV00?o000004a<C01<C4`02P1<C4`00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo05gooooo0_l0000Gooooo`03ok2Tc?naY/go/JK=00;o/JK=00?o/JO>ok:WcOncZ<d00onc
Z<d01?ndZLko]:W=okBYcOndZLd2okFZcP03okJ[cOng[<ko]jc>00;o]jc>00?o]jg?o`000?nh[Lh0
0oni[ll5ooooo`03o`000?oooooooooo03Gooooo0009ooooo`0400000?ooooooooooooooo`<06ATI
00?o000003<c<`0c<c<02`0c<c<00ol00000C4a<04a<C00:04a<C00300000?l00000IVIV00/0IVIV
00<00000o`00001oOgl03@1oOgl00`000000VIVI09VIV@0F09VIVA8000006`2IVIT2000000h0Ogmo
0P00000;06IVIP800000301<C4`01Ol0003oooooooooooooool0000005cooooo0ol0000Gooooo`Co
/:C<0_naY/d01?naYLco/ZO=ok:WcOnbYld3ok>Xc@Co]:W=00Co]J[>okJ[cOnfZlgo]Z_=0_ng[<h0
0onh[<go^:g>o`000002okR]cP03okV_conj[loo^Zo?00Gooooo00?o0000ooooooooool0=?ooool0
00Wooooo00@00000oooooooooooooooo0P0I6AT00ol00000<c<c03<c<`0;03<c<`030000001<C4`0
C4a<00X0C4a<00<0000006IVIP1VIVH02P1VIVH2000000h0Ogmo0P00000F09VIV@<000004P2c/k<7
000001H0VIVI0P00000>07moO`030000001VIVH0IVIV00X0IVIV00<0000004a<C01<C4`02@1<C4`4
ooooo`0300000?oooooooooo05Oooooo0ol0000Iooooo`;o[j?<0on`Y<`01?naY/go/JG<ok6Uc?na
YL`3ok:Wc@03ok>XcOndZ<go]:S=00?o]:W=1?nfZld01ong[<ko^:c=okR/cOnh[<go0000okR]c_ni
[/h01?nj[ll5ooooo`03o`000?oooooooooo03?ooooo0009ooooo`0600000?ooooooooooooooo`0I
6AWo00003@0c<c<00`000000C4a<04a<C00:04a<C0030000001VIVH0IVIV00X0IVIV00<0000007mo
O`1oOgl0301oOgl2000001<0VIVI1@00000L0;>c/`<0000000?o000009VIV@2IVIT04P2IVIT00ol0
0000Ogmo07moO`0<07moO`03o`00001VIVH0IVIV00X0IVIV00<0000004a<C01<C4`0201<C4`4oooo
o`0300000?oooooooooo05Gooooo0_l0000Jooooo`03ojjRc?n_Xlco[j?<00;o[j?<0_n`Y<`4ok6U
c0;o/ZO=00?o/jK<okBXcOndZ<d00_ndZ<d00ondZLgo]ZW<okJYc003okJ[c@Co^:c=00Co0000okV^
c_ni[/ko^Jk>0_nj[ll00onk/<koooooooooo`03ooooo`03o`000?oooooooooo03?ooooo0009oooo
o`0600000?ooooooooooooooo`0I6AWo00003@0c<c<00`000000C4a<04a<C00904a<C003o`00001V
IVH0IVIV00X0IVIV00<0000007moO`1oOgl02`1oOgl00`00003o000009VIV@0B09VIV@0300000?l0
0000/k>c02@0/k>c0`00000B09VIV@800000301oOgl00`000000IVIV06IVIP0:06IVIP030000001<
C4`0C4a<00P0C4a<1?ooool00`00003oooooooooo`1Booooo`?o00006_ooool4ojjRc0;o[j?<00Co
/:?;ok2Tc?n`Y<co/:C<0onaYL`4ok>Vc0;o]:S=00?o]JS<okJYc?nfZL`00_nfZL`00onfZlgo]j_=
okN[c@03okR/c@05o`000?ni[/ko^Jk>okV^c_nj[ll00onk/<h5ooooo`03o`000?oooooooooo03;o
oooo0009ooooo`0500000?ooooooooooooooool000003@0c<c<00`000000C4a<04a<C00:04a<C003
0000001VIVH0IVIV00T0IVIV00<0000007moO`1oOgl02`1oOgl00`000000VIVI09VIV@0?09VIV@@0
0000:P2c/k<300000140VIVI00<0000007moO`1oOgl02P1oOgl00`000000IVIV06IVIP0:06IVIP03
0000001<C4`0C4a<00L0C4a<1?ooool00`00003oooooooooo`1@ooooo`;o00007?ooool2ojfQb`?o
[Z;<00Co[j?<ok2Sbon`Xl_o/:?;0on`Y<`00onaYLco/ZG;ok:Ub`03ok>Vc0Co]JS<0_nfZL`00ong
ZLco]j_=okN[c@02okN[c@03okR/cOni[Lgo000000;o^Jk>00?o^jk=ok^`c_nk/<h00_nk/<h5oooo
o`03o`000?oooooooooo03;ooooo0009ooooo`0500000?ooooooooooooooool00000300c<c<00`00
0000C4a<04a<C00:04a<C0030000001VIVH0IVIV00T0IVIV00<0000007moO`1oOgl02P1oOgl20000
00l0VIVI0`00000a0;>c/`030000002IVIT0VIVI00l0VIVI00<0000007moO`1oOgl02P1oOgl00`00
0000IVIV06IVIP0906IVIP030000001<C4`0C4a<00L0C4a<1?ooool00`00003oooooooooo`1=oooo
o`?o00007?ooool00on/X<_o[J7;ojfQb`02ojfQb`03ojjRc?n_X/_o/:?;00?o/:?;0_n`Y<`00ona
Y<_o/ZG;ok:Ub`02ok:Ub`03ok>Vc?ndY/_o]:K;00?o]JS<00Co]ZW<okNYc?ngZLco]jW<0_ngZld0
1OnhZlco^Jg=okV]cOl0003o^Jk>00?o^jk=0_nk/<h00onl/<koooooooooo`04ooooo`03o`000?oo
oooooooo037ooooo0009ooooo`0400000?ooooooooooooooo``0<c<c00<0000004a<C01<C4`02P1<
C4`00`000000IVIV06IVIP0906IVIP03o`00001oOgl0Ogmo00T0Ogmo0P00000>09VIV@0300000?l0
0000000003D0/k>c00Co000000000000000000003P2IVIT00`000000Ogmo07moO`0:07moO`030000
001VIVH0IVIV00T0IVIV00<0000004a<C01<C4`01P1<C4`4ooooo`0300000?oooooooooo04_ooooo
0_l0000Looooo`03oj^Obon/X<_o[:3;00;o[:3;0_n]XL/01?n^XL[o[j;;ojnRbon_X//2ok2Sb`03
ok2Sb_naY<_o/JC;00;o/JC;0_nbYL/01?ncYL[o]:K;okBVbondY//2okFXc003okJXbongZLco]jW<
00;o]jW<00Oo]j_=okR[c?nhZlco^:_<okV]cOl0003o^Zg<00?o^jk=00Co^k3>okb`c_nl/<ko_;3>
1_ooool00ol0003oooooooooo`0`ooooo`002Oooool01000003oooooooooooooool<03<c<`030000
001<C4`0C4a<00T0C4a<00?o000006IVIP1VIVH02@1VIVH00`000000Ogmo07moO`0907moO`030000
002IVIT0VIVI00`0VIVI0P00000l0;>c/`8000003@2IVIT00`000000Ogmo07moO`0:07moO`030000
001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`01P1<C4`4ooooo`0300000?oooooooooo04Sooooo
0ol0000Kooooo`03ojZNb_n[Wl_oZio;00;oZio;0on/X</01?n]XL_o[Z7:ojjQb_n^XLX2ojnRb`04
ok2Sbon`Xl[o/:?:ok2SbP?o/JC;00Co/ZG;ok>Ub_ncYL[o/jG:0_ndY//4okJXb`;o]jW<00?o^:[;
okR[c?nhZl`00_nhZl`01Oni[Lgo0000okZ]c?nj[Lco^jk=00;o_:o=0onl/<h6ooooo`03o`000?oo
oooooooo033ooooo0009ooooo`0400000?ooooooooooooooo`/0<c<c00<0000004a<C01<C4`02@1<
C4`00`000000IVIV06IVIP0906IVIP030000001oOgl0Ogmo00T0Ogmo00<0000009VIV@2IVIT02`2I
VIT200000400/k>c00<0000009VIV@2IVIT02`2IVIT00`000000Ogmo07moO`0:07moO`030000001V
IVH0IVIV00P0IVIV00<0000004a<C01<C4`01@1<C4`4ooooo`0300000?oooooooooo04Gooooo0ol0
000Looooo`04ojVMb_nZW/[oZYk:ojZNbP?oZio;0_n/X</00on/Wl[o[Z7:ojjQbP02ojjQbP03ojnR
bon_XL[o/:?:00?o/:?:0_naY</00onbY<[o/jG:ok>UbP02ok>UbP03okBVboneYl[o]JO:00?o]ZS;
1?nhZ//2okR[c005okZ/c?nj[Lco0000okZ]c?nk[/`01?nl[ld00onl/<ko_[7>okjacP06ooooo`03
o`000?oooooooooo02oooooo0009ooooo`0400000?ooooooooooooooo`X0<c<c00<0000004a<C01<
C4`02@1<C4`00`000000IVIV06IVIP0906IVIP030000001oOgl0Ogmo00T0Ogmo00<0000009VIV@2I
VIT02`2IVIT00`000000/k>c0;>c/`0E0;>c/`0300000?l0003o00000100000000?o00000;>c/`2c
/k<05P2c/k<00ol00000VIVI09VIV@0;09VIV@030000001oOgl0Ogmo00X0Ogmo00<0000006IVIP1V
IVH0201VIVH00ol00000000004a<C00404a<C0Cooooo00<00000ooooooooool0@oooool2o`0001ko
oooo0_nYWLX4ojZNbP03oj^Obon[W/Wo[9o:00?o[9o:0_n^XLX01?n^X<Wo[j7:ojnQb_n_XLX3ok2S
bPCo/ZC:0_ncYLX00ondYL[o]JO:okFWbP02okFWbP03okJXbongZ<_o]jS;00?o^:[;1?nj[<`01?l0
003o^jk<ok^^c?nk[/`2okb_c@04okf`cOnn/Lko_[7>okjacPOooooo00?o0000ooooooooool0;_oo
ool000Wooooo00@00000oooooooooooooooo2P0c<c<00`000000C4a<04a<C00804a<C0030000001V
IVH0IVIV00T0IVIV00<0000007moO`1oOgl02@1oOgl00ol00000VIVI09VIV@0:09VIV@0300000?l0
0000/k>c0140/k>c1P00000D0<c<c0H000004P2c/k<2000000d0VIVI00<0000007moO`1oOgl02@1o
Ogl00`000000IVIV06IVIP0906IVIP030000001<C4`0C4a<00<0C4a<1?ooool00`00003ooooooooo
o`10ooooo`?o00007_ooool00onWW<[oZIg:ojVMbP02ojVMbP;oZYk:00CoZYg9oj^NbOn[W/WoZik9
0on/WlX01?n^XL[o[Z39ojjPbOn^X<T3ojnQbP03ok2Sb_naXlWo/J?900?o/ZC:00Co/jG:okBUb_nd
YL[o]:G:0_neYlX00onfYl[o]jS;okNXb`02okNXb`03okRZboniZl_o^J_;00?o^Zc<00Go0000ok^^
c?nk[/co^jk<okb_c@03okf`c@;o_[7>00?o_k;>ooooooooool01?ooool00ol0003oooooooooo`0^
ooooo`002Oooool01000003oooooooooooooool903<c<`030000001<C4`0C4a<00P0C4a<00<00000
06IVIP1VIVH02@1VIVH00`000000Ogmo07moO`0907moO`030000002IVIT0VIVI00X0VIVI00<00000
0;>c/`2c/k<03`2c/k<300000200c<c<0`00000A0;>c/`800000302IVIT00`000000Ogmo07moO`09
07moO`030000001VIVH0IVIV00T0IVIV00<0000004a<C01<C4`00P1<C4`4ooooo`0300000?oooooo
oooo03kooooo0_l0000Oooooo`04ojJKb_nWW<[oYic:ojNLbP?oZIg:00CoZYk:ojZMbOnZWLWoZYg9
0on[W/T00on/Wl[o[Io9ojjPb@03ojjPb@;o[j7:00?o/:79ok6SbOnaXlT00_naXlT00onbY<[o/jC9
ok>Tb@03okBUbP04okFWb_nfYl[o]ZO:okJWbP;o]jS;00?o^:W:okV[boniZl/00_niZl/00onj[<co
^jg;o`000002ok^^c003okf_c?nm/<go_K3=00;o_K3=00Co_[7>oknbc_no//ko_k;>1_ooool00ol0
003oooooooooo`0]ooooo`002Oooool01000003oooooooooooooool903<c<`030000001<C4`0C4a<
00P0C4a<00<0000006IVIP1VIVH0201VIVH00`000000Ogmo07moO`0907moO`030000002IVIT0VIVI
00X0VIVI00<000000;>c/`2c/k<03`2c/k<00`000000c<c<0<c<c00T0<c<c0030000002c/k<0/k>c
0100/k>c00?o000009VIV@2IVIT02P2IVIT00`000000Ogmo07moO`0807moO`030000001VIVH0IVIV
00T0IVIV00<0000004a<C01<C4`00P1<C4`4ooooo`0300000?oooooooooo03_ooooo0ol0000Noooo
o`03ojFJb_nVVl[oYY_:00;oYY_:0onWW<X00onYWL[oZIc9ojZMb@03ojZMb@;oZik900Co[9k9ojfO
bOn]WlWo[Io90on^X<T4ok2Qb@;o/J?900?o/Z?9ok>TbOncY<T00_ncY<T00ondYL[o]JK9okJWbP03
okJWbP04okNXbonhZL[o^:W:okRYbP;o^J_;00Go^Z_;ok^]bonk[L_o0000ok^^c003okf_c0;o_K3=
00Go_k7=oknbc_no//ko_k;>ol6dcP07ooooo`03o`000?oooooooooo02cooooo0009ooooo`040000
0?ooooooooooooooo`P0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0906IVIP03
o`00001oOgl0Ogmo00P0Ogmo00<0000009VIV@2IVIT02@2IVIT2000000l0/k>c00<00000o`000000
0000:03<c<`01?l00000000000000000000>0;>c/`800000302IVIT00`000000Ogmo07moO`0807mo
O`030000001VIVH0IVIV00T0IVIV00@0000004a<C01<C4`0C4a<1?ooool00`00003oooooooooo`0i
ooooo`;o00007oooool01?nTVL[oYI[:ojFJb_nUV/X3ojJKbP;oYic:00CoZ9_9ojVLbOnYW<WoZIc9
0onZWLT4ojbNb@?o[Io900?o[Z39ojnPb?n_X<P00on`XLT01?naXlWo/Z?9ok:SbOnbXlT2ok>Tb@04
okBTbOneY/Wo]JK9okFVb@?o]ZO:1?nhZLX01_niZl_o^Z_;okZ[bonjZl_o^jg;o`0000Co_Jo<00Go
_K3=oknacOno/Lgo_k7=oknbcP03ol6dcPKooooo00?o0000ooooooooool0;?ooool000Wooooo00@0
0000oooooooooooooooo200c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00P0IVIV
00<0000007moO`1oOgl0201oOgl00ol00000VIVI09VIV@0909VIV@030000002c/k<0/k>c00`0/k>c
0`00000_0<c<c08000003P2c/k<00`000000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00P0Ogmo
00<0000006IVIP1VIVH02@1VIVH010000000C4a<04a<C01<C4`4ooooo`0300000?oooooooooo03Ko
oooo0ol0000Nooooo`03oj>Hb_nTVL[oY9W:00;oY9W:0onUV/X00onVVl[oYY[9ojRKb@03ojRKb@?o
ZIc900?oZYg9oj^Mb?n[WLP00on/W/T2ojfOb@03ojjOb?n_X<So[j3800;o[j3800?o/:79ok6Qb?nb
XlT00onbXlT01?ncY<Wo]:C9okBTbOndY<T3okFVb@03okJWb_ngZ<Wo]jS900;o^:W:00?o^J[:okZ[
bonjZl/00_njZl/00onk[L_o0000okb^b`03okf_c0?o_k7=00?o`;;=ol6dc_o1]<h00_o1]<h7oooo
o`03o`000?oooooooooo02_ooooo0009ooooo`0400000?ooooooooooooooo`L0<c<c00<0000004a<
C01<C4`0201<C4`00`000000IVIV06IVIP0806IVIP030000001oOgl0Ogmo00P0Ogmo00<0000009VI
V@2IVIT02@2IVIT00`000000/k>c0;>c/`0<0;>c/`030000003<c<`0c<c<0380c<c<00<000000;>c
/`2c/k<0302c/k<00ol00000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IV
IP1VIVH02@1VIVH00ol00000C4a<04a<C004ooooo`0300000?oooooooooo03?ooooo0ol0000Ooooo
o`04oj6HbonSV<[oXiS:oj>HbP?oY9W:0_nUV/X01?nUVLWoYY[9ojJJbOnVV/T3ojRKb@;oZIc900?o
ZI_8oj^Mb?n[WLP00_n[WLP00on/W/Wo[9g8ojjOb003ojjOb0;o[j3800Co/:38ok6Qb?naXLSo/J78
0onbXlT4okBTb@;o]JK900Go]ZK9okNXbOngZ<Wo]jS9okRYbP03okVZbP;o^Z_;00?o^jc:okb^bol0
00000_nl[//01?nm[lco_[3<okj`c?no/Ld3ol2bc@;o`KC>00?o`[G>ooooooooool01Oooool00ol0
003oooooooooo`0[ooooo`002Oooool01000003oooooooooooooool603<c<`03o`00001<C4`0C4a<
00P0C4a<00<0000006IVIP1VIVH0201VIVH00`000000Ogmo07moO`0807moO`030000002IVIT0VIVI
00T0VIVI00?o00000;>c/`2c/k<02P2c/k<00`00003o00000000000f0<c<c08000003@2c/k<00`00
0000VIVI09VIV@0909VIV@03o`00001oOgl0Ogmo00P0Ogmo00<00000o`00001VIVH0201VIVH00`00
0000C4a<04a<C004ooooo`0300000?oooooooooo037ooooo0_l0000Pooooo`04oj2GbonQV<_oXIS;
oj6Hb`?oXiS:00?oY9W:ojBHbOnUVLT00onUVLT3ojJJb@03ojRKbOnXV/SoZI_800?oZI_80_n[WLP0
1?n[W<So[9g8ojbMb?n/WLP3ojjOb004ojnPb?n`X<So/:38ok2Pb0?o/J7800?o/Z?9ok>Sb?ncXlP0
0_ndY<T00oneYLSo]ZK9okJVb@02okJVb@03okNXbOnhZ<Wo^:S900?o^J[:00Oo^Z_;ok^/b_nk[<[o
^jc:okb^bol0003o_Jo;00?o_[3<1?o0//d01?o1]<ko`[G>ol:ec_o2]Lh7ooooo`03o`000?oooooo
oooo02[ooooo0009ooooo`0400000?ooooooooooooooo`H0<c<c00<0000004a<C01<C4`0201<C4`0
0ol00000IVIV06IVIP0706IVIP03o`00001oOgl0Ogmo00P0Ogmo00?o000009VIV@2IVIT02@2IVIT0
0`000000/k>c0;>c/`0:0;>c/`030000003<c<`0c<c<03T0c<c<00<000000;>c/`2c/k<02`2c/k<0
0`000000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH0201VIVH0
0`000000C4a<04a<C004ooooo`0300000?oooooooooo02kooooo0ol0000Oooooo`03oinGbonPUl_o
X9O;00;oX9O;0_nQV</2oj>HbP04oj>GbOnTV<WoY9S9ojBHb@?oYIW90_nVV/T01?nWVLSoZ9[8ojRJ
b?nXV/P3ojVKb003oj^Mb?n[W<SoZic800Co[9g800?o[Yo8ojjOaon`X<P00on`X<P2ok6Qb005ok:R
b?ncXlSo/j?8ok>Sb?ndY<T00oneYLP2okJVb@03okNWb?nhZ<Wo^:S900;o^:S900?o^J[:ok^[bOnk
ZlT00onk[<X01Onm[l_o0000okf_bonm[l_o_[3<00;o_k7<0oo0//d3ol:ecP03ol>gc_oooooooooo
00Kooooo00?o0000ooooooooool0:Oooool000Wooooo00@00000oooooooooooooooo1@0c<c<00`00
0000C4a<04a<C00904a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl0201oOgl00`00
0000VIVI09VIV@0809VIV@030000002c/k<0/k>c00X0/k>c00<000000<c<c03<c<`05`3<c<`<0000
01P0c<c<00<000000;>c/`2c/k<02`2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo
00P0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<ooooo`03ooooo`0300000?oooooooooo
02cooooo0_l0000Pooooo`04oijFc?nOUl_oWiO;oinGb`?oX9O;00?oXIS;oj6GbOnSUlT00onSUlT3
ojBHb@03ojFIbOnUV<SoYiW800?oYiW80onXV/P00onYVlSoZY_8oj^Lb003oj^Lb0;o[9g800Co[Ig7
ojjOaon^WlOo[Yo70_n`X<P00on`X<Oo/Z;8ok:Rb002ok:Rb0;o/j?81?neYLP01?nfY/Wo]jO8okNW
b?ngYlP2okRXb@03okZYbOnkZlWo^j_900;o^j_900Ko^jc:okf]b_nm[L[o0000okf_bono/</4okna
c004ol2bcOo2]<go`[C=ol:ecP?o`kO>1oooool00ol0003oooooooooo`0Yooooo`002Oooool01000
003oooooooooooooool503<c<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01`1VIVH0
0`000000Ogmo07moO`0807moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<02P2c/k<0
0`000000c<c<0<c<c00B0<c<c0H00000303Vi^H3000001H0c<c<00?o00000;>c/`2c/k<02`2c/k<0
0ol00000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH0201VIVH0
0`000000C4a<ooooo`03ooooo`0300000?oooooooooo02Wooooo0ol0000Mooooo`03oi^EcOnLU/co
W9K<00CoWYK<0onOUl/00onPUl_oX9K:oj6Gb@02oj6Gb@?oXiO90_nTV<T01?nTV<SoYIS8ojFHb?nU
V<P3ojNIb0;oZ9[800CoZ9[7ojZKb?nZVlSoZY_80on[W<P01?n/WLSo[Ig7ojfMaon]WLL2ojjOa`04
ok2Pb?n`X<Oo/:37ok2Pa`?o/Z;800?o/j?8okBTb?ndY<P00oneYLP4okNWb004okRXbOnjZLWo^ZW9
okZYb@;o^j_900Go_:c9okf]b_nm[L[o_Jg:o`000003okn`b`;o_k7<00Go`K?<ol:dcOo2]<go`[C=
ol>fc@03ol>gcPSooooo00?o0000ooooooooool0:?ooool000Wooooo00@00000oooooooooooooooo
100c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl0
1`1oOgl00`000000VIVI09VIV@0809VIV@03o`00002c/k<0/k>c00X0/k>c00<000000<c<c03<c<`0
403<c<`00`00003o00000000000E0>KViP@000004`3<c<`00`000000/k>c0;>c/`0:0;>c/`030000
002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0806IVIP030000
0?oooooooooo00;ooooo00<00000ooooooooool09oooool2o`0001kooooo00CoVYG=oi^EcOnKULgo
ViG=0_nLU/`3oijFc0;oWiO;00CoWYG:oj2Fb_nPU/[oX9K:0onQUlT00onSUlWoXiO8ojBHb003ojBH
b0?oYIS800?oYiW8ojNIaonXV/L00onXV/L3ojZKb003oj^Lb?n/W<Oo[Ig700?o[Ig700?o[Yo7ojnO
aon`X<L00on`X<L2ok:Rb003ok>RaondY<So]:C800;o]:C800?o]JG8okJVb?nfY/P00ongYlP4okZY
b@04ok^[bOnl[<Wo_:c9okb/b@;o_Jg:00Go0000okn`bono/<_o_k3;oknac003ol6cc005ol:dcOo3
]/go`kK=ol>fcOo3]lh00_o5^Lh8ooooo`03o`000?oooooooooo02Oooooo0009ooooo`0400000?oo
ooooooooooooo`@0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0706IVIP030000
001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`090;>c/`030000
0?l00000c<c<0100c<c<0P00000L0>KViP<000004@3<c<`00`000000/k>c0;>c/`090;>c/`030000
002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0806IVIP030000
0?oooooooooo00;ooooo00<00000ooooooooool09?ooool3o`0001_ooooo00?oV9G?oiVEc_nIULh0
1?nJULd2oi^Ec@?oW9K<00?oWYK<oifEbonNULX00onNULX2oj2FbP;oXIO900CoXIK9oj>Gb?nSUlSo
XiO80onTV<P2ojFHb004ojFHaonWVLOoYiW7ojNIa`?oZ9[70_nZVlP01?nZVlOo[9c7ojbLaon/W<L2
ojfMa`04ojjNaon_WlOo[io7ojnOa`?o/:371?ncX/L2okBTb003okFTaonfY/So]ZK800;o]ZK800?o
]jO8okVXb?niZ<P00_njZLT00onkZlWo_:c9okb/b@02okb/b@03okf]b_nn[l[o000000?o_k3;0oo1
/l`01Oo3]<co`kK=ol>fcOo3]/goaKS>00?oaKW>2?ooool00ol0003oooooooooo`0Wooooo`002Ooo
ool01000003oooooooooooooool303<c<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH0
1`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<0
2@2c/k<00`000000c<c<0<c<c00?0<c<c08000008@3Vi^H00`00003o00000<c<c00?0<c<c003o`00
002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0807moO`030000
001VIVH0IVIV00P0IVIV00D00000oooooooooooooooo0000000Tooooo`;o00006Oooool01?nFUM3o
UiG?oiNEconGULl3oiREc`;oVIG>0onJULd00onKULgoViC<oibDb`02oibDb`?oWIG;0onNULX00onP
U/[oX9G9oj6Fb@03oj6Fb@;oXiO80onTV<P3ojFHa`?oYiW70_nXV/L00onYV/OoZY_7ojZKa`02ojZK
a`;o[9c700Co[Ig7ojjNaon^W/Oo[Yk70on_WlL00on`X<Oo/J77ok6Qa`03ok>Ra`04okBTb?neY<Oo
]JC7okFTa`;o]ZK800Go^:O8okVXb?niZ<So^JS8okZYb@03ok^[b@;o_:c900Ko_Jg:okj_b_nn[l[o
0000okj_b_no/</2ol6ab`05ol6cc?o3]<co`kC<ol>dc?o3]/d00oo5^<h2olFicP03olJkcooooooo
oooo00Kooooo00?o0000ooooooooool09_ooool000Wooooo00@00000oooooooooooooooo0`0c<c<0
0ol00000C4a<04a<C00704a<C003o`0000000000IVIV00L0IVIV00?o000007moO`1oOgl01`1oOgl0
0ol00000VIVI09VIV@0809VIV@03o`00002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`0303<c<`0
1000003o000000000000000U0>KViP8000003`3<c<`00`000000/k>c0;>c/`090;>c/`03o`00002I
VIT0VIVI00P0VIVI00?o000007moO`1oOgl0201oOgl00ol00000IVIV06IVIP0706IVIP05o`000?oo
ooooooooooooo`0000008Oooool3o`0001Oooooo00?oU9GBoiFEdOnEUM400onFUM03oiNEc`;oV9G?
0onIULh00onJULgoVI?<oi^Dc002oi^Dc0?oW9C;0onMUL/00onNUL[oWYC9oj2Eb@02oj2Eb@?oXIK9
0onSUlP00onTV<SoY9O8ojBGb003ojFHa`;oYiW71?nYV/L3ojZKa`;o[9c71?n^W/L2ojnOa`03ok2O
aonaXLOo/J7700;o/J7700?o/j;7okBSaoneY<L00oneY<L01?nfY/So^:O8okRWb?nhYlP2okVXb0Co
^j_900Oo_:c9okf]b_nm[L[o_Jg:okj_b_l0003o`;3;00?o`K7;00Co`[?<ol>dc?o3]<co`kC<1?o5
^<h01?o5^Lkoa[_?olJkcoo6^ll8ooooo`03o`000?oooooooooo02Gooooo0009ooooo`0400000?oo
ooooooooooooo`<0<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0706IVIP030000
001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`080;>c/`03o`00
003<c<`0c<c<00`0c<c<00<000000>KViP3Vi^H0:@3Vi^H00`000000c<c<0<c<c00<0<c<c0030000
002c/k<0/k>c00X0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0807moO`030000
001VIVH0IVIV00L0IVIV00Go0000oooooooooooooooo0000000Nooooo`?o00005Oooool00onCU]Co
TiKCoi>Fd`04oiBEdP;oUIGA0onFUM02oiNEc`03oiREconGTlkoV9?=00;oV9?=0onITl`3oi^Dc0;o
W9C;0_nMUL/01?nMU<[oWYC9oijDbOnNU<T3oj2Eb@03oj6FbOnQULSoXiK800;oXiK80onTUlP3ojFH
a`?oYiW70onYV/L2ojZKa`04oj^Ka_n/W<Oo[9c7ojbLa`?o[Yk71?n`WlL2ok6Qa`04ok:QaondXlOo
]:?7okBSa`?o]JC71?nhYlP00oniZ<So^ZW8okZYb003ok^[b@Co_Jg:00Go_Zo:o`000?o0/<_o`;3;
ol6ab`03ol:cc003ol>dc?o4]/goa;K=00;oaKS>00Goa[[>olJkcoo6^looa[_?olRmc`08ooooo`03
o`000?oooooooooo02Gooooo0009ooooo`0400000?ooooooooooooooo`80<c<c00<0000004a<C01<
C4`0201<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2I
VIT0202IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3V
i^H0:`3Vi^H00`000000c<c<0<c<c00<0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2I
VIT01`2IVIT00`000000Ogmo07moO`0807moO`030000001VIVH0IVIV00L0IVIV1?ooool00`00003o
ooooooooo`0Jooooo`;o00005?ooool00onAV=KoTYOEoi:Ge@03oi>Fe0;oTiKC0onDUM82oiFEd@;o
UYG@00?oUI??oiJCc_nFTlh00onGTlh3oiRCc@;oVI?<0_nKU<`00onJTl_oVi?:oi^CbP04oifDbP;o
WYC90_nPULT01?nOU<SoXIG8oj6Eb?nQULP3oj>Fb0?oY9O800?oYIS7ojJHaonWVLL00_nWVLL3ojVJ
a`CoZi_60on/W<L00on^W/Oo[ik6ojnNaP03ok2Oa`04ok6QaonbXLOo/Z77ok:Qa`?o]:?700?o]JC7
okJUaonfYLL00_nhYlP00oniZ<So^ZW8okZYb002okZYb003ok^[bOnl[<Wo_:c900?o_Jg:00Co`;3;
o`000?o0/<_o`K;;1?o2/l`3olBfc@05olFhc_o6^/koa[[>olJjc_o6^ll00oo8_Ll8ooooo`03o`00
0?oooooooooo02Cooooo0009ooooo`0400000?ooooooooooooooo`80<c<c00<0000004a<C01<C4`0
1`1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0
1`2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3Vi^H0
;@3Vi^H00`000000c<c<0<c<c00<0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT0
1`2IVIT00`000000Ogmo07moO`0807moO`030000001VIVH0IVIV00H0IVIV1?ooool00`00003ooooo
ooooo`0Gooooo`?o00003oooool01?n@V]WoTIWHoi6If?nAVMP2oi6He`?oTISF0_nBUmD3oi>Fe0;o
TiKC00CoU9GBoi>CdOnDTm3oU9?@1?nETll2oiJCcP?oUi?>0_nHTld00onITlcoVI;<oiZCb`02oiZC
b`?oVi?:0onMU<X00onNU<WoWY?9oinDb002oinDb0?oXIG80onSU/P2ojBGb004ojBGaonVV<OoYYS7
ojJHa`?oYiW700?oZI[7ojVJa_nYV/H00on[VlH2ojbLa`03ojfMa_n_W/Ko[ik600;o[ik600?o/9o7
ok6Pa_nbXLL00onbXLL2okBSa`05okFTaonfYLOo]ZG7okJUaonhYlP00oniZ<P2okZYb003ok^[b?nl
[<Wo_:c900;o_:c900Co_Jg:okn_b_l0003o00000oo1///2ol:cc0;oa;G<0_o4]/d01?o6^Lgoa[[>
olJjc_o6^/h3olRmc`03olZod?oooooooooo00Oooooo00?o0000ooooooooool08oooool000Wooooo
00H00000oooooooooooooooo03<c<`00000:04a<C0030000001VIVH0IVIV00L0IVIV00<0000007mo
O`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0/k>c00<000000<c<
c03<c<`02`3<c<`00`000000i^KV0>KViP0_0>KViP03o`0000000000c<c<00`0c<c<00<000000;>c
/`2c/k<0202c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IV
IP1VIVH01P1VIVH4ooooo`0300000?oooooooooo01Kooooo0_l0000;ooooo`04oi2NgOn@WMcoT9gL
oi2Mg0;oT9_K0_n@V]T3oi6If0;oTISG0_nAV=H00onBUmGoT9GDoi6Dd`02oi6Dd`;oTYCB0onCTm42
oiBCd0?oUI??0_nFTlh2oiNCcP03oiJBcOnGT/coUi;<00?oVI;<0onJTl/3oi^CbP03oifDb_nLTlWo
WY?900;oWY?90onOU<P3oj6Eb003oj>Fb?nSU/OoY9O700?oY9O70_nVV<L2ojNIa`04ojRIa_nYV/Ko
ZI[6ojVJaP?oZi_61?n]WLH2ojnNaP04ok2Oa_naX<Ko/J36ok6PaP;o/Z7700?o]:;7okFTaoneY<L0
0_neY<L00onfYLOo^:K7okVXb003okVXb004okZYb?nkZlSo^j_8ok^[b0;o_:c90ol000000ono[l[o
0000ol6bb`02ol6bb`05ol:cc?o4]Lcoa;G<olBec?o4]/d00oo6^Ld01?o6^/kob;c?olRlcoo8_Ll3
olZod0Sooooo00?o0000ooooooooool08oooool000Wooooo00H00000oooooooooooooooo03<c<`00
000:04a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00ol00000VIVI09VI
V@0709VIV@030000002c/k<0/k>c00P0/k>c00?o00000<c<c03<c<`02P3<c<`00`00003o00000>KV
iP0c0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VI
V@0809VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01P1VIVH4ooooo`0300000?oo
oooooooo01Kooooo00?o0000ooooool000001?ooool00onAX^3oTJ7Ooi6Qg`02oi6OgP?oT9kM0on@
WM`2oi2Kf`;oT9[I00CoTIWHohnGf?n?UmOoSiOG0on@U]H2oi2Ee0?oTICC0_nBU=83oi>Cd@;oU9?@
00CoUI??oi>BconET/koUI;>1?nFT/d2oiNBc0?oVI;<0_nJTl/2oi^CbP04oi^Bb_nLTlWoW9?9oibC
b@?oWY?90_nOU<P2oj6Eb004oj6DaonSU/OoXiK7oj>Fa`?oY9O700?oYYS7ojJHa_nXVLH00onXVLH3
ojVJaP03oj^Ka_n/VlKo[9_600?o[Ig600Co[ik6ok2Oa_n`WlKo/9o60_naX<H01?nbXLOo]:;7okBR
aondX/L2okFTa`04okJUaonhY/Oo^:K7okRVa`?o^JS800?o^ZW8ok^[b?nkZlP00ol00002okj^b@04
okn_b_o1/L[o`K7:o`0000;o`K;;0oo4]L`01Oo5]lgoa[W=olJicOo6^Lgob;_>00?ob;c?0oo:_m00
0oo;`]7oooooooooo`07ooooo`03o`000?oooooooooo02;ooooo0009ooooo`0500000?oooooooooo
ooooo`0000002P1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00P0Ogmo00<00000
09VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00X0c<c<00<00000
0>KViP3Vi^H0=@3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<00000
09VIV@2IVIT0202IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00D0IVIV1?ooool0
0`00003oooooooooo`0Fooooo`04o`000?nCYn?oTjGRoi>UhP;oTZCQ0onAX^02oi6Qg`;oTIoN0_n@
W]d2oi2Mg003ohjKfon>V][oSY[J00;oSYSI0on?UmP2ohnGe`?oT9KF0_n@UM@2oi6Dd`03oi:Dd_n@
T]7oTI;@00;oTI;@0_nBT/l3oi>Bc`;oUI;>0onFT/d2oiNBc0;oVI;<00?oV97;oiVBb_nIT/X01?nK
T/X2oibCb@;oWY?900?oWY?8oinDb?nOU<P01?nQU<L2oj>Fa`;oY9O700CoYIK7ojJHa_nVV<KoYYS6
0onXVLH2ojVJaP03ojZJa_n/VlKo[9_600;o[9_600?o[Ig6ojjMa_n`WlH00on`WlH00onaX<Ko/Z76
okBRa`03okBRa`04okFTaonfYLOo]ZG7okJUa`?o^:K700?o^JS8okZYb?l000000_l000001Onm[<Wo
_Zk9okj^bOnn[/Wo`:o:00Co`K7:00Co0000ol>dboo3]<_oa;G<0oo5]ld01Oo6^Lgob;_>olRkc_o8
^lkob;c?00;obKk?00Cob[o@ol_2dOo;`]7obl;A2?ooool00ol0003oooooooooo`0Rooooo`002Ooo
ool01@00003oooooooooooooool0000000T0C4a<00<0000006IVIP1VIVH01`1VIVH00ol00000Ogmo
07moO`0707moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<
0<c<c00:0<c<c0030000003Vi^H0i^KV01H0i^KV2000000I0>KViP03o`00003<c<`0c<c<00X0c<c<
00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00L0Ogmo
00<0000006IVIP1VIVH01@1VIVH4ooooo`0300000?oooooooooo01Kooooo00?o0000oi>WhonCYn<0
0_nCYN82oi:Th@;oTJ;P00?oTJ7OohnOgon?Wml00_n>WMd2ohjLg0?oSY_K0_n>V]X2ohjHf@;oSiOH
0on?UmL01?n@U]KoSYCEohjCe?n>Tm@2ohnCdP?oT9;A0onAT]02oi:Bc`?oTi;?0_nET/h01?nFT/go
UI3<oiNAc?nGTL`4oiRAb`;oVI;:0onKT/X00onLTlWoW9;9oijCb002oijCb0?oWiC80onQU<L00onS
U/OoXiG7ojFFa`03ojFFa`?oYYS60_nXVLH4ojZJaP;o[9_600Co[9c6ojjMa_n^WLKo[Yg60_n`WlH0
1?naWlKo/Z76ok:Qa_nbXLH3okBRa`Co]ZG70_nhY/L3o`000003okZYb?nlZlSo_Jc900;o_Jc900Co
_Zk9ol2_b_o0[l[o`:o:0_o1/LX01Oo2/l_o`kC;o`000?o3]<_oaKK<00?oaKO=0oo8^lh01?o9_Loo
bKk?olVncoo9_/l3ol_2d@;ocLCB2?ooool00ol0003oooooooooo`0Qooooo`002Oooool01@00003o
oooooooooooooooo000000T0C4a<00?o000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0707mo
O`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c0090<c<
c003o`00003Vi^H0i^KV01@0i^KV0`000008ooooo`@000005@3Vi^H00`000000c<c<0<c<c00:0<c<
c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0707mo
O`030000001VIVH0IVIV00D0IVIV1?ooool00`00003oooooooooo`0Eooooo`03o`000?ooooooTjOS
00;oTJGS0_nAY>82oi2Rh@;oSj7P0on?Wml2ohjMg@;oSYcL0_n>Vm/01?n>V][oS9SJohbGf?n<UmP2
ohfFe`?oSICF0on>U=D2ohjCe0;oSi?B0on@T]42oi6Bd0;oTY;?0_nCT/l00onBT<koU93=oiB@c@03
oiF@c0;oUi7<0onHTL/3oiVBbP03oi^Bb_nKTLWoW9;900;oW9;90onNTlP3oinDb0;oXIC70onSULL3
ojFFa`;oYYS600CoYiS6ojRIa_nXVLKoZ9W60onZV/H01?n/VlKo[9c6ojbLa_n/W<H2ojjMaP03ok2O
a_naWlKo/Io600Co/Z7600?o]:;7okFSaoneXlL00_nfYLL3o`0000;o^JS800Co^ZW8okb[b?nlZlSo
_:_80_nm[<T4ol2_bP05ol6ab_o2/l_o`[?;ol:cbol000000oo5]/`01?o5]lgoak[=olNjcOo8^lh3
olVmc`04olVncoo;`M3obl7@ol_2d@?ocLCB2Oooool00ol0003oooooooooo`0Pooooo`002Oooool0
1000003oooooooooooooool:04a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01P1o
Ogl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02P3<
c<`00`000000i^KV0>KViP0A0>KViP<000003oooool2000001<0i^KV00<000000<c<c03<c<`02`3<
c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01`1o
Ogl00`000000IVIV06IVIP0506IVIPCooooo00<00000ooooooooool05Oooool00ol0003ooooooooo
o`03oi6Uh`;oTJCR0_n@X^42ohnQh004ohnOgon<WMkoS9cMohbLg@;oS9[L0_n<VM/3ohbHfP;oS9OH
0_n=U]L3ohfDeP;oSYCE0_n>Tm@3ohnCdP04oi2BdOn?T=7oT93@oi2@d0;oTI3?1?nBT<h2oiB@c@?o
UI3<0_nGTL`00onHTL_oUi3:oiVAbP02oiVAbP?oVi790onLT/T2oijCb0;oWiC800CoWi?7oj6DaonQ
U<OoXIC70onSULL00onUU/OoYIO6ojNHaP03ojNHaP?oZ9W600?oZY[6oj^Ka_n/W<H00on/W<H00on^
WLKo[ik6ok6OaP03ok6OaP;o/Z7600?o/j;7okFSaoneXlL00ol00002okRVa`?o^JS81?nlZlP00onm
[<Wo_jk9okn^b@03ol2_bP?o`[?;00Goa;G<olFfc?l0003oaKK<olNic@03olNjc@?obKg?00Gobl3@
ol_1d?o;`M3obl7@olg3d@03olg4dP03olk7dooooooooooo00Kooooo00?o0000ooooooooool08?oo
ool000Wooooo00@00000oooooooooooooooo2@1<C4`00`000000IVIV06IVIP0706IVIP030000001o
Ogl0Ogmo00L0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`070;>c/`030000003<
c<`0c<c<00X0c<c<00<000000>KViP3Vi^H03`3Vi^H3000001Cooooo0P0000000ol00000i^KV0>KV
iP0?0>KViP030000003<c<`0c<c<00X0c<c<00?o00000;>c/`2c/k<0202c/k<00`000000VIVI09VI
V@0709VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH0101VIVH4ooooo`0300000?oo
oooooooo01Gooooo00Ko0000oooooooooooooooooi6Uhon?Y><2ohjRhP;oSZ3Q0_n=Wml3ohbMgP;o
S9cM0_n<V]`2ohbIf`?oS9SJ0_n<UmP2ohfFe`04ohfDe_n;TmKoS9;DohbBe0;oSI7C0on=TM83ohn@
d@;oT93@0_nAT<l3oi:@cP;oU93=0_nET<`00onDSlcoUY3;oiJ@b`03oiN@bP?oVI7:0_nKTLT2oibB
b@03oibAb?nNT/SoWY;800CoWi?70_nQU<L3oj>Ea`?oYIO60onWV<H2ojRIaP04ojVIa_n[VlKoZi_6
oj^KaP;o[9c600Co[Ig6ojnNa_n_W/Ko[ik60onaWlH00onbXLKo/j;7o`000002o`000003okFSaonf
YLOo^:K700?o^:K700?o^JS8ok^Yb?nkZLP00_nlZlP00onm[LWo_jk9okn^b@02okn^b@04ol2_b_o1
/L[o`K7:ol:cb`?oa;G<00GoaKK<o`000?o7^LgoakW=olNjc@02olVlcP05olVmcoo;`=3obl3@ol_0
d?o;`M000oo=`m400oo=a=;oc/OColk7d`09ooooo`03o`000?oooooooooo01oooooo0009ooooo`04
00000?ooooooooooooooo`T0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0607mo
O`030000002IVIT0VIVI00H0VIVI00?o00000;>c/`2c/k<0202c/k<00ol00000c<c<0<c<c0090<c<
c0030000003Vi^H0i^KV00h0i^KV0P00000Iooooo`8000004@3Vi^H00`000000c<c<0<c<c0090<c<
c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0707mo
O`030000001VIVH0IVIV00@0IVIV1?ooool00`00003oooooooooo`0Eooooo`04o`000?oooooooooo
ooooo`?oSjCS0_n>X^82ohjPh@;oSIoO0_n<WMh01?n<W=goRI[MohVHg?n9V=`3ohVGf`;oRIKI0_n:
U=P2ohZCe`?oRi?F0_n<T]@2ohfAd`?oSI7B0_n?T=42oi2@d0?oTI3?00CoTY3>oi6?cOnBSlgoTXo=
1?nDSl`2oiJ@b`?oUi3:0_nITLX00onKTLWoVY79oibAb002oibAb0?oWY;80onOTlL2oj6Da`CoXiG7
0onUUlH2ojNHaPCoZIW60_n[VlH00on/W<Ko[Ig6ojfMaP04ojnNaP04ok6Oa_l0003o0000o`0000;o
/j;700Co]J?7okJUaonfYLOo]ZG70_nhY/L01OniZ<So^jW8ok^Yb?nkZLSo_:_800?o_Jg90_no[/T0
1Oo0/<[o`K7:ol6ab_o1/L[o`kC;00?oa;G<0_o7^Ld00ol0003ob;_>olVlcP02olVlcP04ol^ocoo;
`=3obl3@ol_0d0?ocL?A0_o?a]800oo>am?od<[Dom3:e009ooooo`03o`000?oooooooooo01kooooo
0009ooooo`0400000?ooooooooooooooo`T0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo
07moO`0507moO`03o`00002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<
0<c<c0080<c<c003o`00003Vi^H0i^KV00d0i^KV0P00000Mooooo`030000003Vi^H0i^KV00h0i^KV
00<000000<c<c03<c<`02@3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI
00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0406IVIPCooooo00<00000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`;oSjCS00?oSZ;RohbQh_n<XN800_n;Wn42oh^Mg`;oRY_N
0_n9V]d2ohVHg0?oRIOK0_n9U]T2ohZDf0;oRY?G0_n;TmH3ohbBe0;oSI7C00CoSI7Bohb?d_n=Sm3o
SHo@0_n>Sll3oi2?cP?oTHo=0_nBSld3oiB?c0;oUY3;0_nGT<X00onGSl[oV939oiR@b@03oiZAb@?o
W9780_nNT/P3oinCa`?oXIC70onSULL3ojFGaP?oYiS60onYVLH00on[VlKo[9_6ojfMaP03ojfMaP;o
[ik60_l00003ok:QaP03ok>RaoneXlOo]ZG700?o]ZG700Co^:K7okVXb?niZ<So^JS80_nkZLP4okf]
b@05okn^bOo0/<[o`;3:ol2`b_o1/LX00oo3]</01Oo4]Lcoa[S<olJhc?o7^Lgo000000;ob;_>00Go
bKc>ol^ocoo;_loobko?ol_0d003olg3d@?oclKB0oo@b]@00ooAcMGoooooooooo`06ooooo`03o`00
0?oooooooooo01kooooo0009ooooo`0400000?ooooooooooooooo`P0C4a<00<0000006IVIP1VIVH0
1`1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0
202c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00d0i^KV00<00000ooooooooool0
7_ooool00ol00000i^KV0>KViP0>0>KViP030000003<c<`0c<c<00T0c<c<00<000000;>c/`2c/k<0
202c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH0
101VIVH4ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool00oooool2ohfRh`?oS:7R
0_n;Wn42oh^Mg`;oRY_N0_n9V]d2ohVHg004ohVGfon7UM[oQiCIohNDf@;oQi?H0_n8T]L2ohVAe@?o
RI3D0_n;T=<3ohb?dP;oSHo@0_n>Sll3oi2?cP;oTHo=0onBSld01?nDSlcoThk;oiF?bonESl/3oiN?
bP?oV9390onJTLT2oibAb003oijBb?nNT/OoWi?700?oWi?70onQU<L00onSULOoY9K6ojFGaP02ojFG
aP?oYiS60_nYVLH01?nZV/Ko[9_6ojbKa_n/VlH2ojfMaP?o00000_n`WlH2ok:QaP04ok>RaoneXlOo
]J?7okFSa`;o]ZG700?o^:K7okVXb?niZ<P00_niZ<P00onkZLSo_:_8okb[b003okf]b@?o`;3:00?o
`[;;ol>dboo3]</00_o3]</3olJhc0;ob;_>00?o0000olRkc_o;_ll00_o;_ll01?o=`]3ocL?Aolg3
dOo=`m43olo6dP;od<WC00?od<[Dom7=eOoAcMD02Oooool00ol0003oooooooooo`0Mooooo`002Ooo
ool01000003oooooooooooooool804a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl0
1P1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`0
203<c<`00`000000i^KV0>KViP0=0>KViP0300000?oooooooooo023ooooo00<000000>KViP3Vi^H0
3P3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT0
1P2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00@0IVIV1?ooool00`00003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Gooooo0_n=X^<01?n<XN;oRIoRohRMhOn8WN42ohRKg`;o
Qi[N0_n7V=d2ohNGg0?oQiGJ0_n7U=T2ohNCf0;oR9;G0_n9TMD3ohV@e0;oRi3C0_n<Sm83ohf?d0;o
SXo?0_n@Slh00onASlgoT8k=oi6>c002oi6>c0;oThk;0onESl/3oiN?bP;oV9390_nJTLT00onJT<So
W978oibAb003oijBa`?oWi?70_nQU<L01?nRU<OoY9K6ojBFa_nTU/H3ojFGaP;oYiS61?nZV/H01On/
VlKo0000o`000?l0003o[Yk600Co/9o600Co/Z76ok>RaoncX/Oo/j;70_neXlL01?nfYLOo^:K7okRV
aonhY/L2okVXb003ok^Zb?nlZlSo_:_800;o_:_800Co_Jg9okn_bOno[lWo`;3:0oo2///2ol>db`;o
aKK<0_o6^<`01_o8^/gob;_>olRkc_l0003ob[k?ol^oc`?ocL;@00CocL?Aolo6d_o?a];oclKB0_o@
bM<01OoBcMGodLgEom7=eOoAcMGod]3F00Wooooo00?o0000ooooooooool07?ooool000Wooooo00@0
0000oooooooooooooooo201<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00H0Ogmo
00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00P0c<c<
00<000000>KViP3Vi^H03@3Vi^H00ol0003oooooooooo`0Pooooo`030000003Vi^H0i^KV00h0i^KV
00<000000<c<c03<c<`02@3<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI
00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0406IVIPCooooo00<00000ooooooooool0
5?ooool00ol0003oooooooooo`05ooooo`;oRZ7S0on9Wn82ohRMh@;oR9_O0_n7V]h2ohNHg@;oQiOL
0_n7UMX2ohNDf@?oQi?H0_n8T]L2ohVAe@;oRI3D00CoRi3CohR>d_n:S]7oRXkA0on;S]02ohf>c`;o
SXk>0on@S/d3oi6>c0;oThk;0onESl/2oiN?bP;oV9390onJT<P3oibAb0?oWY;700?oWi?7oj2CaonR
U<L00_nRU<L3ojBFaP?oYIO600CoYiS6ojRIa_nXVLKoZY[60ol000000on/VlKo[Ic6ojjNaP02ojjN
aP?o/9o61?ncX/L00oneXlOo]ZG7okRVa`03okRVa`04okVXb?nkZ/So^j[8ok^Zb0;o_:_800Co_Zg9
okn_bOno[lWo_jo91?o2///01Oo3]<_oaKK<olFfc?o5]/coa[S<00;ob;[=00Cob;_>olZncoo:_/oo
00000oo=`]001?o>aM7oclKBolo6d_o?a]82om39d`?od/gE00CodLgEom;@e_oBd=Koe=?H2?ooool0
0ol0003oooooooooo`0Looooo`002Oooool01000003oooooooooooooool804a<C0030000001VIVH0
IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0
/k>c00H0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP0=0>KViP0300000?oooooo
oooo02;ooooo00<000000>KViP3Vi^H03@3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0
/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0
IVIV00@0IVIV1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo0_n:XN<0
0on9Wn;oQigRohNMhP02ohJKh@;oQI[O0_n4V=h2ohBFg@;oQ9GL0_n4TmX2ohBBf@;oQI7H0_n6T=H2
ohJ?e@;oQhoD0on8S]82ohZ>d@?oRhk@0_n=S/l2ohj>cP?oT8k=0_nAS/`2oi>>b`;oUHo;00?oU8k;
oiJ?b_nFSlX00onHT<T3oiZ@b0;oW9780onNT/L3oj2Ca`?oXYC70onTU/H00onUUlKoYYO6ojRIaP03
o`0000;oZY[61?n]W<H3ojjNaP03ok2Oa_naX<Oo/J3700;o/j;700Co]:?7okJUaonfYLOo]ZG70onh
Y/L01OniZ<So^j[8ok^Zb?nkZ/So_:_800?o_Zg900?o_jo9ol6ab_o1/LX00oo2///3olFfc005olNi
cOo8^/gob;[=olRjcOo:_Lh00_o:_/l00ol0003oc<7@olg2d003olk5d@03olo6d_o@bM?od<WC00?o
d/gE0_oCd=H00ooBd=Koe=?HomCCf009ooooo`03o`000?oooooooooo01_ooooo0009ooooo`040000
0?ooooooooooooooo`L0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0607moO`03
0000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0070<c<c003
0000003Vi^H0i^KV00d0i^KV00<00000ooooooooool09?ooool00`000000i^KV0>KViP0=0>KViP03
0000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0709VIV@03
0000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH0101VIVH4ooooo`0300000?oooooooooo01Co
oooo00?o0000ooooooooool01oooool2ohROh`?oQigR0_n6Vn42ohFJg`;oQ9SN0_n4U]d2ohBEg0;o
Q9?J0_n4T]T2ohFAf0;oQY3F0_n6SmD2ohN?e0?oR8kB0_n:S]42oh^>d0;oSHk?0_n>S/h2oi2>c@03
ohn=cOn@SLcoT8g<00;oTXk;1?nDS//2oiJ?bP?oV9390_nJT<P2oibAb0CoWY;70_nPTlL3oj:Da`;o
Y9K600CoY9K7o`000?l0003o00000onXVLH00onZV/KoZi_6oj^KaP03ojfLaP;o[Yk600Go[io7ok6P
aonaX<Oo/J37ok>Ra`03okBSa`?o]ZG700Ko^:K7okVXb?niZ<So^JS8ok^Zb?nl[<T3okj]b@03ol2`
b_o1/L[o`K7:00;o`K7:00Co`[;;olBec?o4]LcoaKK<0oo7^Ld01oo8^/gob[g>olZmc_o:_Lkob[k?
olc1d?l000000oo>aM42om38dP04om39dooBc=Cod/cDom;=e@?odm3F00Coe=?GomCCf?oEe]WoeMKI
2Oooool00ol0003oooooooooo`0Jooooo`002Oooool01000003oooooooooooooool704a<C0030000
001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0509VIV@03o`00
00000000/k>c00L0/k>c00<000000<c<c03<c<`0203<c<`00ol00000i^KV0>KViP0;0>KViP03o`00
0000003ooooo02Oooooo00<000000>KViP3Vi^H0303Vi^H00`000000c<c<0<c<c0080<c<c0030000
002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0607moO`03o`00
001VIVH0IVIV00@0IVIV1?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo
0_n8Wn<01?n7WN;oQ9cRoh>JhOn3V^42oh:Hg`;oPYKN0_n1U=d2oh6Cg0;oPI7J0_n2T=T2oh:?f0;o
PhkF0_n4S]D2ohF=d`?oQXgB0_n8S=42ohV<d0;oRhc?0_n=S<h4ohn=c@;oT8g<0_nBS//3oiB>b`;o
UXo:0_nHT<T00onHSlWoVY38oiZ@b003oibAb0?oWY;70onPTlL00onRU<OoXYG7o`000002o`000003
ojBFaonVUlKoYYO600;oZ9W600?oZIW6oj^Ka_n[VlH00_n[VlH00on]W<Ko[Yg7ojnOa`03ojnOa`;o
/J371?ndXlL2okJUa`05okRWb?niZ<So^JS8okVXb?nkZ/T00onl[<T01?nn[LWo`;3:ol2`b_o0/<X2
ol6abP05ol>dboo4]Lcoa;G<olBec?o6^<d00oo7^Ld3olZmcP06olc0coo<`M3oc<7@olc1d?l0003o
c/GA0oo@b=83om;<e0?odm3F0_oDdmL3omGFf@03omKIf_oooooooooo00Kooooo00?o0000oooooooo
ool06_ooool000Wooooo00@00000oooooooooooooooo1`1<C4`00`000000IVIV06IVIP0706IVIP03
0000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`070;>c/`03
0000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H02`3Vi^H00`00003oooooooooo`0Wooooo`03
0000003Vi^H0i^KV00`0i^KV00<000000<c<c03<c<`0203<c<`00`000000/k>c0;>c/`070;>c/`03
0000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0406IVIPCo
oooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`;oQIkS0on4W>82oh>Jh@;o
PYSO0_n2U]h2oh6Dg@;oPI?L0_n1TMX2oh:@f@;oPXoH0_n3S]H2ohB>e@;oQHgC0on6SM82ohR<d@;o
RHc@0_n;S<l2ohf<cP?oShg=0_n@SL`3oi:>b`04oiB>bonCS/_oUXk:oiJ>bPCoV8o90_nJT<P3oibA
b004oijBaonNT/SoX9?7oj2Ca`?o000000KoXYG7ojBFaonTU/OoY9K7ojJGa_nWV<L4ojVIaP;oZi_6
00Co[9c7ojjMaon^WLOo[Yg70on_WlL00onaX<Oo/j;7ok>Ra`03okBSa`Co^:O800Co^JS8ok^ZbOnk
Z/Wo^j[90_nl[<T4ol2`bP05ol6ab_o3]<_o`kC;ol>dboo4]L`00oo6^<d01?o7^LgobKc>olVlc_o:
_Lh3olc0c`03olc1d?o>a=7o000000Cod<SB0_oBc=@2om?@eP04omGCeooDdmOoe=?GomCCe`;oeMKI
0_oFfMX00ooFg=coooooooooo`06ooooo`03o`000?oooooooooo01Wooooo0009ooooo`0400000?oo
ooooooooooooo`L0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000
002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0080<c<c0030000
003Vi^H0i^KV00/0i^KV00<00000ooooooooool0:Oooool00`000000i^KV0>KViP0;0>KViP030000
003<c<`0c<c<00T0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0609VIV@030000
001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH0101VIVH4ooooo`0300000?oooooooooo01?ooooo
00?o0000ooooooooool02_ooool2ohFNh`;oQ9cR0_n3V^42oh:Hg`;oPYKN0_n1U=d2oh6Cg0;oPI7J
0_n2T=T2oh:?f0;oPhkF0on4S]D2ohF=d`;oQXgB0_n8S=42ohV<d0?oRhc?0_n=S<h01?n?SLgoSHc=
ohn<c?n?S<`3oi6=b`?oThk;0_nFS/X3oiR?b@;oVY380onLTLP01?nNT/So0000o`000?l00002oj2C
a`;oXYG70_nTU/L01?nUUlOoYiS7ojNHaonWV<L3ojVIaP04oj^Ka_n/W<Oo[9c7ojbLa`;o[Yg70_n_
WlL00onaX<Oo/j;7ok>Ra`02ok>Ra`03okBSaonfYLSo]ZG800?o^:O81?nkZ/T00onl[<Wo_Zk:okj^
bP03ol2`bP?o`kC;00GoaKO<olJhcOo6^<goa[S=olRkcP03olVlcP?oc<3?0oo>a=401?o@b=;o0000
om38d_o@b=82om;<e003om??eOoCd=KoeM?G00;oeM?G00?oe=?GomGFfOoEe]T00_oFfMX2omKLg003
omOOgOoooooooooo00Gooooo00?o0000ooooooooool06Oooool000Wooooo00@00000oooooooooooo
oooo1`1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2I
VIT01P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3V
i^H02P3Vi^H00`00003oooooooooo`0Zooooo`030000003Vi^H0i^KV00/0i^KV00<000000<c<c03<
c<`02@3<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1o
Ogl01P1oOgl00ol00000IVIV06IVIP0406IVIPCooooo00<00000ooooooooool04oooool00ol0003o
ooooooooo`0:ooooo`;oPYcS0_n1V^82ognHh@;oOiKP0_mnU=h2ogjCg@?oOY7L0_mnT=X2ogn?f@;o
OhkH00CoPHgFoh:<eOn2S=GoPXcE0_n3S=<2ohB;dP;oQX_A0_n8Rm03ohV;c`;oRhc>0on=S<d2ohn<
c0?oTHg;0_nCS//3oiJ>bP04oiR?bOnGSlWoVI39oiV@b@;oW9780_l00002oijBb0?oX9?70_nRULL4
ojFGa`?oYiS700?oZIW6ojVJaon/W<L00on/W<L00on^WLOo[io7ok6Pa`03ok6Pa`;o/j;700?o]:C8
okJUb?nfYLP00_nfYLP00onhYlSo^JW9okVYb@02ok^Zb@03okf]b_nn[/[o_Zk:00;o_Zk:00Co`;3:
ol:bboo2//_o`kC;0oo5]l`01Oo6^<gob;_>olRkc_o8^lkobKc>00;obko?00Coc<3?olk4dOo>a=7o
c/CA0oo@b=800ol0003od/cDom;<e002om??e@?oeM?G0_oFemP01OoEe]Woe]WJomKIf_oGgMcoe]cL
00;oemoM00?oen;Oooooooooool01Oooool00ol0003oooooooooo`0Hooooo`002Oooool01000003o
ooooooooooooool704a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`00
0000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0203<c<`00`00
0000i^KV0>KViP0:0>KViP0300000?oooooooooo02[ooooo00<000000>KViP3Vi^H02`3Vi^H00`00
0000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`00
0000Ogmo07moO`0607moO`030000001VIVH0IVIV00@0IVIV1?ooool00`00003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo0_n2W><2oh6JhP;oOiSQ0_moU^02ogjDgP;oOY?M0omnTM`2ogj@
fP;oOhoI0_moS]P01?n1SMKoPXcEoh:<eOn2S=D2oh><d`;oQ8_B0_n6Rm42ohR;d0?oRH_?0_n;S<h2
ohf<c@?oShc<0_nASL/00onCS/_oThg;oiF>bP02oiF>bP;oUho900CoVI39o`000?l0003o00000_nL
TLP3oijBb003oj2CaonPU<OoXYG700;oXYG70onUUlL2ojNHa`04ojNIaonYV/OoZI[7ojVJa`?o[9c7
0on_WlL3ok6Pa`04ok>RaondY<So]:C8okBTb0;o]ZG800Go^:O9okVYbOniZLWo^JW9ok^Zb@03okf]
bP;o_Zk:00Go`;7;ol:bboo2//_o`[;;olBec003olFgc0?ob;_>00Gob[k?ol^ocoo;_loobko?olg3
d003olk4d@05om37d_o@b=;od/cDom;<e?l000000ooCcmD2omGCe`;oe]OH0_oGf]X01OoFfM[oemgL
omOMg?oGh=goemoM00;oen;O00?oenCPooooooooool01Oooool00ol0003oooooooooo`0Gooooo`00
2Oooool01000003oooooooooooooool704a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1o
Ogl01P1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<
c<`0203<c<`00`000000i^KV0>KViP0:0>KViP0300000?oooooooooo02[ooooo00<000000>KViP3V
i^H02`3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2I
VIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00@0IVIV1?ooool00`00003o
ooooooooo`0Cooooo`03o`000?oooooooooo00cooooo0_moVn@2ogfHh`;oO9KQ0_mkU>02og^BgP;o
Ni7M0_mkSm`2og^>fP;oO8gI0_mmS=P2ogj;eP;oPXcE0_n3S=<2ohB;dP;oQX_A0on8Rm02ohV;c`;o
Rhc>00?oSHc=ohb;cOn>S<`00_n>S<`2oi6=b`?oThg;0_nES/X3o`0000?oVI3900?oW978oibBb?nN
TlP00_nNTlP3oj2Da`?oXYG700?oYIO7ojFHaonWVLL00onWVLL3ojVJa`03ojbLaon]WLOo[Ig700?o
[io700?o/J37ok:Rb?nbX/P00ondY<P01?nfYLSo^:O9okRWbOnhYlT2okVYb@05ok^[b_nm[L[o_Jg:
okf]b_nn[/X00oo0/L/01Oo2//_oa;G<olBec?o4]LcoaKO<00;oak[>00Gob;_>olZncoo:_/oob[k?
ol^oc`03olg3d003olk4dOo@am;od<OB00?od/cD00?o0000om??eOoCcmD00_oEdmL2omKGf0;oem[J
0_oHgM/01OoGgMcoen3MomOPgOoHhmkoen;O00;oenCP00?oe^KQooooooooool01?ooool00ol0003o
ooooooooo`0Gooooo`002Oooool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00H0
IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0
/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP0:0>KViP0300000?oooooooooo02co
oooo00<000000>KViP3Vi^H02`3Vi^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00H0
/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00@0
IVIV1?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo0_moVn@2ogfHh`;o
O9KQ0_mkU>02og^BgP;oNi7M0_mkSm`2og^>fP;oO8gI0_mmS=P00omnRmKoOh_Eogn;e@03oh6:e003
oh::d_n4R]7oQ8[A00?oQX[@0_n8R/l3ohZ;cP;oS8_=0on>S<`2oi6=b`05oi>=bol0003o0000o`00
0?nES/X00_nGSlT3oiV@b@?oW9;80onNTlP2oj2Da`;oXYG700CoXiK8ojFHaonUV<OoYIS70onWVLL2
ojVJa`04oj^Laon]WLOo[Ig7ojfMa`;o[io700?o/:78ok:Rb?nbX/P00_nbX/P00ondY<So]ZK9okRW
b@03okRWb@06okVYbOnkZl[o^j_:ok^[b_nm[L[o_jo;0oo0/L/01Oo2]<coa;G<olBec?o4]Lcoa[W>
00?oak[>00CobKg?olZncoo:_/oob[k?0oo=`m02olo6dP04om37d_oAbm?odL_Com;<e0;odloE00?o
0000omGCeooEdmL00_oFemP2omOJfP;of=gK0_oHhMd01OoGh=gof>?NomSSg_oHiN3oenCP00;oe^KQ
00?oe^SSooooooooool01?ooool00ol0003oooooooooo`0Fooooo`002Oooool01000003ooooooooo
ooooool604a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI
09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV
0>KViP0:0>KViP0300000?oooooooooo02cooooo00<000000>KViP3Vi^H02`3Vi^H00`000000c<c<
0<c<c0080<c<c0030000002c/k<0/k>c00H0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo
07moO`0607moO`030000001VIVH0IVIV00@0IVIV1?ooool00`00003oooooooooo`0Cooooo`03o`00
0?oooooooooo00kooooo00?oNiWTogZGhomjUn<00_miUN82ogRCh0;oN97O0_mgSmd2ogN>g0;oN8gK
0_mlSMT2ogf<f0;oOX_F0_moRmD3oh6:e003oh::d_n4R]7oQ8[A00?oQX[@0_n8R/l3ohZ;cP;oS8_=
0_n>S<`3o`0000;oThg;00CoUHk:oiB>b_nGSlWoUho91?nIT<T2oibBb0?oWY?800?oX9C7oj6Eb?nS
U/P00onSU/P3ojFHa`03ojNIaonXV/SoZic700?oZic70_n]WLL4ok2Qb0;o/Z;800Co]:C9okJVbOnf
Y/Wo]ZK90_nhYlT01OniZ/[o^j_:ok^[b_nkZl[o_Jk;00?o_jo;00Go`;7;ol:dc?o2]<co`[C<olBe
c003olJicP05olNjc_o9_LoobKg?olVmcoo:_/l00_o<`]001?o=`m3oclKBolo6d_oAb]<3om7;d`;o
dloE0_oEdmL00ol0003oe]OHomKGf002omOJfP04omSNfooHgM_of>7MomSQg@;of>CN00Gof>?NomSU
h?oGj>7oenSQomKVh@02omKXh`03omCZi?oCk>Gooooo00Cooooo00?o0000ooooooooool05Oooool0
00Wooooo00@00000oooooooooooooooo1P1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0
Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0
c<c<00P0c<c<00<000000>KViP3Vi^H02P3Vi^H00ol0003oooooooooo`0/ooooo`030000003Vi^H0
i^KV00/0i^KV00<000000<c<c03<c<`0203<c<`00`000000/k>c0;>c/`060;>c/`030000002IVIT0
VIVI00L0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0406IVIPCooooo00<00000
ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03ogRHiOmjUn?oNYOS00;oNIGR0_mhTn02
ogRAg`;oMhoM0_mgS]`00omhSM_oNH_IogV;f@02ogZ;f0;oNh[G0_mlRMD3ogj9e0;oP8WC0_n4R]42
ohJ:d0;oR8[?0_n:Rlh00on8R/koRh_>o`000002o`0000;oT8c<0onBSL/3oiB>bP;oUho90onIT<T3
oibBb0;oWY?80onQULP3oj>Fb0;oYIS700CoYYW8ojRJb?nXV/SoZ9[80on[W<L00on]WLOo[Yo8ojjO
b003ok2Qb004ok:Rb?ndY<Wo]:C9okBTb@;o]ZK91?niZ/X01?nkZl[o_Jk;okf^bonm[//2okn_b`04
ol6bc?o2]<co`[C<ol:dc0?oa[W>00Gob;c?olVmcoo9_LoobKg?ol_1d003olc2d003olk6d_o?a];o
dL[C00;odL[C00?odL_Com??eOoCcmD00_oEdmL2omKGf003o`000?oHfm[oem[J00;of=kK00KofN7M
omSQgOoHi=kof>CNomSWgooHiN02omOXh@;oen[R00?oe^SSomCZi?oCk>D00_oBkNL4ooooo`03o`00
0?oooooooooo01Gooooo0009ooooo`0400000?ooooooooooooooo`H0C4a<00<0000006IVIP1VIVH0
1P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<0
1`2c/k<00`000000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV00/0i^KV00<00000ooooooooool0
;?ooool00`000000i^KV0>KViP0:0>KViP030000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<0
1`2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH0
101VIVH4ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00omhV>GoMYGS
ogJEh`02ogFChP;oM97Q00?oM8oOog>>g_mcS]h00_mgS]`2ogR=f`;oNH_I0_mjRmP2og^:e`;oO8WE
0omnRM@00on0RM?oPXWBoh:9dP02ohB9d0?oQX[?0ol00002oh^;cP;oSHc=0_n@S<`3oi:=b`;oU8k:
0onGSlT00onIT<WoVI79oibBb@02oibBb@?oWY?80onQULP00onSU/SoY9O8ojJIb003ojJIb0;oZ9[8
0_n[W<L00on/WLSo[Yo8ojjOb002ojjOb003ok2Qb?naXlWo]:C900?o]:C900?o]ZK9okNXb_ngZ<X0
0oniZ/X4okf^b`05okn_boo1//co`K;<ol6bc?o2]<`00_o4]lh01Oo6^Lkob;c?olRlcoo8_<oobKg?
00?obl7@00?oc<;@olk6d_o>a]800ooAb]<2om?>e@03om??eOoEdmOoeM?G00?oe]OH00?o0000omSK
f_oHg]/00_oHg]/00ooIhMgofNGNomSTgP02omSWg`07omSYhOoGj>7oen[RomOZh_oFk>Coe>gUom?/
i@02om;]i`03om7]j?oooooooooo00?ooooo00?o0000ooooooooool05?ooool000Wooooo00@00000
oooooooooooooooo1P1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0
000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00L0c<c<00<0
00000>KViP3Vi^H02P3Vi^H00`00003oooooooooo`0]ooooo`030000003Vi^H0i^KV00X0i^KV00<0
00000<c<c03<c<`0203<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00L0VIVI00<0
000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0406IVIPCooooo00<00000ooooooooool04_oo
ool00ol0003oooooooooo`0Aooooo`;oM9KU0_mfUN<2ogFChP;oM97Q00?oM8oOog>>g_mcS]h00_md
S=d2ogB;f`04ogF:f_mfRMSoMXWHogJ9f0;oNh[G0_mlRMD2ogj9e0;oP8WC0_n2RM801On4RM3o0000
o`000?l0003oQX[?00;oR8[>0_n;Rlh2ohf<c@?oT8c<0_nBSL/00onDS/[oU8o;oiN@bP02oiN@bP?o
VI790onLT/T2oijCb0;oXIG800CoXIK9ojBGb?nTUlSoY9O80onVVLP00onXV/SoZIc9ojbMb003ojbM
b0;o[Yo800Co[j79ok6SbOnaXlWo/J?90_ndY<T00oneYl[o]jS:okNXbP02okNXbP03okVZb_nk[L_o
^jg;00;o_Jk;00Go_k7<ol6bc?o1//co`K;<ol>fcP03olBgcP04olJkcoo8_<oob;c?olRlc`?obl7@
00KocLGBolk6d_o>a];oc/KBom3:dooAb]<3om?>e@?oeM?G0_oFemP2omSKfP04o`000?oIg]_of=kK
omWQg@;ofNGN00OofNSOomSWgooHjN7of>WQomO/h_oGj^;oe^cT00;oe>gU00?odnoVom;]iooAkNP0
0_o?k^T00oo=k^[oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo0009ooooo`0400000?oo
ooooooooooooo`H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0607moO`030000
002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c0070<c<c0030000
003Vi^H0i^KV00X0i^KV00<00000ooooooooool0;Oooool00`000000i^KV0>KViP0:0>KViP030000
003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0709VIV@030000
001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH0101VIVH4ooooo`0300000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00omdU^GoLYCTog:Di002og6Bh`;oL93Q0_m`S^02og>>gP;oM8cM
0_mdRm/00omeR][oMXWHogJ9f002ogR8e`;oNHSF0_mkR=@2ogf8d`04oh28d_l0003o0000oh:9d@?o
QHW@0_n7R/l2ohZ;cP;oS8c=0on?S<`2oi:=c0?oU8o;0onGT<X3oiVAb@;oW9;900?oWY?8oinDbOnQ
U/T00onQU/T3ojBGb003ojJIb?nWV/WoZIc900;oZIc90on/WLP01?n^WlSo[j79ojnQbOn_XLT2ok6S
b@04okBTbOneYl[o]JO:okFWbP;o]jS:00Go^J_;ok^]bonk[L_o^jg;okf^b`03oknac005ol6bc?o3
]/ko`kK>ol>fc_o4]lh00oo6^ll01?o8_<oob/3Aol[0dOo;`M03olg5dP03olk6d_o@b]?od<[C00;o
d/kE00CodlkEomCCeooDdmOoeM?G0_oFemP3omSKfP05omWNfol0003ofN;MomWVg_oIiMh00_oIj=l0
1ooIjn7of>WQomO/h_oGk>;oe^kSomG_iOoDkND00_oCknH00ooAknOod?3Yolo^j@02olg^jP05olc^
k?ooooooooooooooool000005Oooool000Wooooo00@00000oooooooooooooooo1P1<C4`00`000000
IVIV06IVIP0606IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000
/k>c0;>c/`060;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H02P3Vi^H00`00003o
ooooooooo`0/ooooo`030000003Vi^H0i^KV00/0i^KV00<000000<c<c03<c<`0203<c<`00`000000
/k>c0;>c/`070;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01P1oOgl00`000000
IVIV06IVIP0506IVIPCooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03
og2Ei_mbU>CoLYCT00;oLI;S0_m`T>400om`S^3oL8cNog2<gP02og2;g@;oLHWL0_maR=X2ogJ9f0;o
N8SG0_miR=H01?mkR=Co0000o`000?l00002oh28dP;oPXWA0on5RM02ohN:c`;oRX_>0_n<S<d3ohn<
c0;oTXg<0onDSl/2oiN@bP;oVI7900?oVI;;oibCb_nLTlX00onOU<T3oj6Fb@;oY9O800CoY9W9ojNJ
bOnWV/WoYi[90onYW<T00on/WLSo[Io9ojnQb@03ojnQb@03ok6SbOncYL[o/jG:00?o]JO:00Co]jS:
okV[boniZl_o^J_;0_nk[L/01?nm/<co_k7<oknac?no/L`3ol>fcP05olFjcoo6^looa[_?olJkcoo9
_m400oo:`=43olg5dP;oclWD00Cod<[Com;>eOoBc]God/kE0ooDdmL2omKGf0;of=_J0_oIgm/01_oI
g]_ofN;Mo`000?oIi]kofNWOomWXg`;ofN_Q00?of>gRomO/h_oFk^<00_oEknD00ooClNKodnoVom7_
i`02om3`j@04olk`j_o=k^[oc>k/ol[]k@;ob>g^0_ooool00ol0003oooooooooo`0Booooo`002Ooo
ool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0
1@1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0
203<c<`00`000000i^KV0>KViP0:0>KViP0300000?oooooooooo02cooooo00<000000>KViP3Vi^H0
2`3Vi^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT0
1P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV1?ooool00`00003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Cooooo0_m`UNH01?m^T^CoKI3Sofb>h_m/S^82ofb<h@;o
L8cN0_m`Rmd2og69g003og68f_mcR=WoLhSI00;oM8OH0ol000000omkR=CoOHSCogf8d`03oh28dP;o
PXWA0_n5RM02ohN:c`?oRX_>0_n<S<d2ohn<c0;oTXg<0_nDSl/00onDSlcoUi3;oiN@b`04oiVBb`;o
W9?:0onOU<T00onQU/WoXYO:ojBIb@03ojBIb@;oYi[90_nYW<T01?n[W/[o[Io9ojfObOn]WlT3ojnQ
b@Co/jG:00?o]JO:okNYbongZL/00oniZl/01Onk[L_o_K3<okf`c?nm/<co_k7<00;o`KC>00Go`kK>
olFjcoo5^/ooaK[?olJkc`03olVod@04ol[0dOo<a=;oc<CBolg5dP?oclWD0ooBc]D2omCBe`03omCC
eooFemSoe]OH00;of=_J0_oIgm/2omWSg@07omWRgOl0003ofNWOomWYgooIk>7ofN_QomS]hP02omO_
h`03omKai?oEknGodo7V00;od_;W00Kod?;Xom3`jOo>l>[oc?3[ol[`k?o:kNd2olS]kP04olK/kooo
ooooooooo`0001Cooooo0009ooooo`0400000?ooooooooooooooo`H0C4a<00<0000006IVIP1VIVH0
1P1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0
1P2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00X0i^KV00<00000ooooooooool0
;?ooool00`000000i^KV0>KViP0;0>KViP030000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<0
1`2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH0
1@1VIVH4ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool2ofbCiP;oJY7U
00CoKI3Sofb>h_m/S^;oK8cQ0_m/Rml2ofb9gP;oKHSL0_maR=X3o`000003ogB7f?mfQmOoNHOE00;o
NHOE00CoNhODogf8dommR=?oOHSC0_n0R=82oh>9d@;oQX[@0on8Rll2oh^<cP;oSXg=0_nAS/`4oiB?
c0;oUi3;0onIT//2oibCbP;oWiC900CoWiK:oj:Gb_nRUl[oXYO:0onTVLT00onWV/WoZ9c:oj^NbP03
oj^NbP?o[Io900?o[j79ok6SbonaXl/00_ncYLX00oneZ<co]jW;okNYb`02okNYb`03okV[bonk[/go
_K3<00;o_K3<00Go_k?>ol6dc_o1]<ko`KC>ol>hc`03olFjc`?obKoA00Cobl?Bolc4d_o<a=;oc<CB
0_o>b=@01?o?bMCodLgFom7=e_oBc]D2omCBe`;oe]OI00Goe]OHomSKf_oHfm[ofMoLomWOf`02omWS
g@;of^ON00Cof^[Oo`000?oIk>7of>oR0_oGlN<00ooGkn?oe_7TomKai002om;ciP06om;bioo@l^So
c_;Yolcbjoo<l>_ob_3/0_o8knd01oo6k^ooa^c_olCZl?o4j_3o`^W`ooooool000004oooool000Wo
oooo00@00000oooooooooooooooo1P1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo
00D0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<
00P0c<c<00<000000>KViP3Vi^H02P3Vi^H00`00003oooooooooo`0/ooooo`030000003Vi^H0i^KV
00/0i^KV00<000000<c<c03<c<`0203<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI
00H0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP0506IVIPCooooo00<00000oooo
ooooool04Oooool00ol0003oooooooooo`0Fooooo`;oK9?V00?oJY7UofV?i?mYSn@00_mXSN<00omW
Rn7oK8_Oofb;g`02ofb9gP?o000000CoKXOKofn7f_maQ]WoLHKI0_mfQmL3ogV7e@04og^7e?mmR=?o
OHSCogf8d`;oP8SB0_n3RM42ohJ:d0?oR8_?0_n;S<h2ohj=c@;oTHk<0onDSl`2oiN@b`;oVI;;00?o
VI?<oibDbonLU</01?nOU/X2oj:GbP;oY9W900CoYI_;ojRLb_nXW<[oZ9c:0on[W/X2ojfOb@05ojjR
bonaXl_o/J?;ok6SboncYLX00oneZ<`2okNYb`05okV]cOnk[/go^jk=ok^^cOnm/<`00ono/lh01Oo1
]<ko`kS?ol>hcoo3^<ooaK[?00;oakgA00GobKoAol_3d_o;`m;obl?Bolc4dP03olk8e0?odLgF00Co
dm;GomCBeooFemWoe]OI0_oGfmX01OoHfm[ofMoLomWOg?oIi=gofN?M00;of^ON00Cof^[OomW]hOoI
k>7o00000_oGlN<2omKci007omKai?oBlnKod_?Vom3dj?o>m>Woc_;Yolcbj`02ol_bk007olSakOo8
kngoa^k_olK^koo5kO3oa>[`ol;Yl002ol7Wl@03ooooool0003ooooo017ooooo0009ooooo`040000
0?ooooooooooooooo`H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`03
0000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c0080<c<c003
0000003Vi^H0i^KV00X0i^KV00<00000ooooooooool0:oooool00`000000i^KV0>KViP0;0>KViP03
0000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0609VIV@03
0000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01@1VIVH4ooooo`0300000?oooooooooo017o
oooo00?o0000ooooooooool05_ooool2ofRBi`;oIXoV0_mYSn@2ofR=h`04ofN;hOl0003o0000o`00
00?oKHSL0_m^Qm/01?m_Qm[oLHKIog66fOmcQ]L3ogJ6eP;oN8OE0_mmR=<2oh28dP;oPhWA0on6R]02
ohR;c`;oRhc>0_n>SLd3oi6>c004oiB?c?nCT<goUi7<oiNAc0CoVI?<0_nLU</3oinFbP03oj:Gb_nS
VL_oYI_;00?oYI_;0onXW<X00on[W/[o[:3;ojjRb`03ojjRb`03ok6SbonbY/co/ZK<00?o]JS<00Co
]jW;okV]cOni[Lgo^Jg=0_nk[/d01?nm/Lko_k?>okncc_no/lh3ol>hc`05olFldOo7_M7oakgAolNm
dOo9`]<00oo;`m83olk8e0?odLgF0_oCd]L01?oEemWoe]OIomOKf_oGfmX2omSPg003omWOg?oIi=go
fNCM00;of^ON00Kof^[OomW]hOoIkN7of?3RomObhol00002omKci004omCdiOoBm^Kod_?Vom3dj0;o
c_CY00Coc?CZol_djoo;l^cob?7]0_o7l>h01?o6k^ooaNg`ol?[l?o1jO42ol7Wl@03okoUlOoooooo
000001;ooooo0009ooooo`0400000?ooooooooooooooo`H0C4a<00<0000006IVIP1VIVH01P1VIVH0
0`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<0
0`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV00X0i^KV00<00000ooooooooool0:oooool0
0`000000i^KV0>KViP0;0>KViP030000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<01`2c/k<0
0`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH01@1VIVH4
ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool05oooool2ofRBi`03ofJ?i_mTSNGo
I8gU00?o000000CoHXWRofN9h?mWRN3oIhSO0_mXQmd2ofV6g0;oJhKK0_maQ]T01OmcQ]OoMXKFogJ6
e_mfQ]KoN8OE00;oNhOD0_mnR=<2oh69dP?oQ8[A0_n7Rm02ohZ<c`;oSHg>0on@Slh3oi>@c@;oUi7<
0onITl`3oibDb`03oinFb_nPUlcoXiW;00;oXiW;0onUVl/2ojRLbP04ojVNc?n/X<_o[:3;ojbPb`;o
[Z;;00?o/:C<ok:Vc?nbY/`00_nbY/`00oneZ<co]j_=okV]c@03okV]c@05ok^^cOnm/Lko_K7>okfa
c_no/lh00_o1]m001Oo3^<ooaKcAolFldOo5_=7oakgA00?obL;C00Cobl?Bolg7e?o=amCoc/SD0_oA
cMH2om?Bf005om?BeooEemWoeMOIomOKfooGfmX00_oHh=`2omWTgP06omWTgOoJimkof^ONom[[h?oI
kn7ofNgQ0_oHl>801OoGl^?o0000omKci?oDm>God_KV00;od?KW00Coc_OXolkdjOo<m>[oboC[0_o8
m>d01_o7lnkoao3^olG_koo3k_3o`n_`ol7Yl@;o_nOb00Go_nGaokgSl_nlhO;o_>7bo`00000Aoooo
o`002Oooool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00H0IVIV00<0000007mo
O`1oOgl01@1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<
c03<c<`0203<c<`00`000000i^KV0>KViP0;0>KViP03o`000?oooooooooo02[ooooo00<000000>KV
iP3Vi^H02`3Vi^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00D0IVIV1?ooool00`00
003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00GoHi7Xo`000?l0003o0000ofB=i@02
of>;h`03of:9h_mRR>7oHXSQ00;oHhKO0_mXQmd2ofV6g003of^6fom]QM[oKHGJ00;oL8GI0_mfQ]H2
ogR7e@;oNhOD0_mnR=<2oh69dP?oQ8[A0_n7Rm02ohZ<c`;oSHg>0on@Slh2oi>@c@?oUi7<00?oVI?<
oiZDcOnMU/`00_nMU/`3oj2Gc0?oXiW;00?oYI_;ojJMc?nYW/`00onYW/`2ojbPb`04ojjRbon`Y<co
/:C<ok2Tc0;o/ZK<00Co]:W>okN[cOngZlgo]j_=0_ni[Ld01Onk/<oo_K7>okfac_nm/Lko_kG@00?o
`KO@00Coa;_BolFldOo5_=7oaKcA0oo9`]<01_o<a]GocLODolg7e?o=amCoclcGom7=eP;odm;H0_oD
emX01OoEemWoem_KomOKfooHh=gof>3L00?ofNCN00?of^SOom[Wg_oJjn000_oIkn402_oHlN;of?3R
omObhooFm>Coe?KTo`000?oBmnGod?SVom3fioo>mnP2olcgj@;ob?K/00Gob?C]olOck_o5lNoo`o3`
ol?^l002ol7/l@06ol3Zl_noio;o_^GbokkUl_nlho;o_>7b0_njg_800ol0003oooooooooo`0>oooo
o`002Oooool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00H0IVIV00<0000007mo
O`1oOgl01P1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<
c03<c<`01`3<c<`00`000000i^KV0>KViP0;0>KViP0300000?oooooooooo02Wooooo00<000000>KV
iP3Vi^H02`3Vi^H00`000000c<c<0<c<c0080<c<c003o`00002c/k<0/k>c00L0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00H0IVIV1?ooool00`00
003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo0ol00002of>Aj0;oHHkV00CoGhcUoej9
i?mNRNCoGHSS0_mRR>400omSQ]ooI8GNofB5gP02ofF5g@;oJhKK0_m]QMX00om`QMWoLXKGog:6e`02
ogF6eP;oN8OE0omnR=<2oh69dP;oQ8[A0_n7Rm03ohZ<c`;oSHg>0_n@Slh00onCT<goTi7>oiNCcP02
oiNCcP?oVYC=0onMU/`2oj2Gc0;oXiW;00CoXi_=ojJMc?nVWLcoYYg<0onYW/`00on/X<_o[J?=ojfS
c@03ok2Tc004ok:Vc?ndZLko]:W>okBYcP;o]j_=1?nk/<l01Onm/Lko_kG@okned?no]M3o`KO@00?o
a;_B00CoaKcAolS1doo8`M?obL;C0oo<a]D01Oo=amCoclcGolo<eooAdMWodm;H00?oe=OJ00Coe]_L
omOKfooHh=gof>3M0_oIiMh01_oIi=kof^SOom[XgooJk>3ofO3QomW_h@;of?7R00[oeoCSomGfhooC
n>Coe?KTom;giOl0003od?SVolkhioo;n>Soc?OY0_o8m^`01?o6mNgoa?C_olGakoo3l?02ol7^l@06
ol7/lOo0j_;o_^SbokkXl_nniO;o_>?b0_nkhO<00onjg_;o^Mcbo`00000@ooooo`002Oooool01000
003oooooooooooooool604a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl0
0`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`01`3<c<`0
0`000000i^KV0>KViP0;0>KViP0300000?oooooooooo02Sooooo00<000000>KViP3Vi^H02`3Vi^H0
0`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT0
0`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00H0IVIV1?ooool00`00003oooooooooo`0A
ooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`03oej?j?mLSNOoG8gW00;oFX[V0_mNRN@0
1?mMR>?oGHKRoej5hOmNQN42ofB5gP03ofF5gOmWQMcoIhGL00;oJHGK0_m`QMT2og:6e`;oMHKF0_mh
QmD2ogb8e0;oOhWC0_n2R]82ohJ;d@?oRHgA0_n=S]02oi2@c`?oTi7>0onGTlh3oiZDc@;oWIK<00?o
X9O<oj2IcOnSVld00onSVld3ojJMc003ojVNc?nZXLgo[J?=00?o[J?=00?o/:C<ok6Wc_ndZLh00ond
ZLh00ongZlgo^Jk?okV^c`03ok^`c`?o_kG@00Go`[[BolBkd_o4^m;oa;_BolJoe003olS1d`?oc<KE
0_o>bmL01?o?c=OodM7Iom7AfOoCe]/3omCGfP03omKKg?oGh=gof>3M00;ofNGN0_oIjMl02?oJj=oo
f^cPomW`hOoIl>7of??RomSah_oGm>?oeOKS0_oCn>@02_oAnNGocoWUom3hi_l0003oboSXolWhj_o7
n>_oaOO/olKekOo4m>l2ol?bl003ol7alOo1k_7o`>cb00;o_^[c00?o_^SbokcVlonkho<00_nkhO<0
1?nig_;o^McbokWLl_l0000@ooooo`002Oooool01000003oooooooooooooool604a<C0030000001V
IVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0509VIV@030000002c
/k<0/k>c00L0/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0;0>KViP0300000?oo
oooooooo02Oooooo00<000000>KViP3Vi^H0303Vi^H00`000000c<c<0<c<c0090<c<c0030000002c
/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0707moO`030000001V
IVH0IVIV00H0IVIV00D00000oooooooooooooooo0000000Booooo`03o`000?oooooooooo01;ooooo
0ol00007ooooo`04oeV>jOmLSNOoG8gWoeZ:iP;oF8SU0_mHQ^@01?mMQ^;oGXGQoej5hOmOQ=l2ofF5
g@;oIhGL00?oJHGKofb5f_m/QMX00_m_QMT2ogF6eP?oN8OE0_mlR=@2ogn9d`;oPX[B0_n6Rm43ohV=
d@;oSHk@0_n@T<l3oi>AcP;oUi?>0_nJU<d00onJU/koWIS>oifHcP03oj2Ic@?oXi_=0_nVWL`01?nW
WlkoZZ7=ojZQcOnZXLd2ojfSc@04ojnVconaYlko/JO>ok6WcP;o]:W>00?o]Zg@okV^coni[/l00_ni
[/l01?nk/<oo_KCAokfddOno]M03ol:jdP05olBkd_o6_mCoa[oDolJoe?o8`M<00_o:aMH01_o<a]Go
c/_Golk;eoo>bmOod=3Iom7Af@?odmKK00Koe=OJomKKg?oFfmcoen3MomSUgooIiMh2omWYg`;ofNgQ
00GofO7RomW`hOoHln;of??RomGgh`02om;ii009om?hi?oAnNGocoWUolgji_o:n^Oo0000olWhj_o7
n>_oaOO/00;oa?K^00Go`_C_ol?bl?o1lO7o_nobokk]l`02okkZl`03okgXlonkiO?o^n?c00;o^^7c
00Go^Mkbooooooooooooooooo`00000@ooooo`002Oooool01000003oooooooooooooool604a<C003
0000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0509VIV@03
0000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`01`3<c<`00`000000i^KV0>KViP0<0>KViP03
00000?oooooooooo02Gooooo00<000000>KViP3Vi^H0303Vi^H00`000000c<c<0<c<c0090<c<c003
0000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0607moO`03
0000001VIVH0IVIV00L0IVIV00D00000oooooooooooooooo0000000Booooo`03o`000?oooooooooo
00oooooo0ol0000;ooooo`;oFHkY0_mDRNL2oeR8i@03oeR6i?mHQN?oF8GS00;oGXGQ00CoGhCOof24
g_mPQ=koHhCM0_mYQM/2ofb5fP;oKhGI0_mbQ]P2ogJ7e`;oNHSF0_moRM<2oh::dP?oQX_A0_n9SM42
ohf>d003oi2@con?TM7oTi;@00;oTi;@0_nGU<l4oiZFcP;oWIS>0onPVLd00onSVlgoY9g>ojNOcP03
ojNOcP03ojZQcOn/Y<oo[jK?00?o[jK?0_naYlh4okJ]d0;o^Jk?00Go^k;AokfddOnm]=7o_KCAoknh
d`03ol:jdP?oa[oD00Cob<CFol[5e_o:aMKob/GF0_o=bmP00oo>bmOod=3Iom3@f@03om?Ff`;oeM_L
00Koe]_LomOPgOoGh=gof>GOomWZh?oIjMl2omW]h@05omWah_oGm>;oeoCRomSch_oEmn<00_oBnN@0
4?o@n^Coc__Uol_kiOo=n^Kob_[WolSjj?o6nN[o0000olCijoo2n>goa?K^ol;dkoo0lo7o_o7boko_
l_nnkO<2okcZl`05okgXlonkiO?o^^?dok[Sm?njhO<01_ooool00ol0003oooooooooo`0=ooooo`00
2Oooool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1o
Ogl01P1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<
c<`0203<c<`00`000000i^KV0>KViP0;0>KViP0300000?oooooooooo02Gooooo00<000000>KViP3V
i^H0303Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2I
VIT01P2IVIT00`000000Ogmo07moO`0707moO`03o`00001VIVH0IVIV00H0IVIV00<00000oooooooo
ool00_ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo0ol0000>ooooo`;o
DhgZ00CoD8[YoeB9iomBQnKoDXOV0_mBQND00omHQN?oF8CRoeR4hP02oeV3h@;oH8CN00?oHhCMofF4
g?mUQ=`00_mXQ=/2ofn5f@;oLXKH0_mfQmL00omiR=KoOHWEogf9e@03oh6;e0;oQ8cC0_n8S]83ohb?
d@;oSi7A0onCT]02oiNDc`?oVYK>00?oWIS>oijJd?nQW<l00_nQW<l3ojBMcP;oYio>00CoZJ;@ojbT
con/Y<oo[:C?0on_Y/l00onaYlko/j_@ok>[d003okJ]d005okRad_nk/]7o^k;Aok^bdOnm]=400ono
^=<01?o2^];oa;kDolBne?o6_m@3olS4eP04ol[5e_o=bmSocL_Holo@fP?od=3I00Cod]KKom?FfooE
fmcoeM_L0_oGhMh01ooGh=gof>GOomWZh?oIj^3ofNkRomW]hOoIlN800_oGm>801ooFmn?oe?WSom7j
hooBnNCod?[TolkkiOo;nnD00_o8nnH02_o6nnOoa?_Yol;jj_o4nN_o0000ol7fk_nomO3o__?aokoa
l_nmko<2okc]m005okcZlonkj?Co^^Gdok[Um?njho@02?ooool00ol0003oooooooooo`0=ooooo`00
2Oooool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1o
Ogl01P1oOgl00ol00000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<
c<`0203<c<`00`000000i^KV0>KViP0<0>KViP0300000?oooooooooo02?ooooo00<000000>KViP3V
i^H0303Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2I
VIT01`2IVIT00ol00000Ogmo07moO`0607moO`030000001VIVH0IVIV00L0IVIV00<00000oooooooo
ool00_ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo0ol0000Booooo`;o
DhgZ00GoD8[Yodj8j?mBQnKoDXOVoe:5i@02oe:4i0;oF8CR00?oFH?Qoe^3gomKPml00_mMPml2ofF4
g003ofR4fom[QM[oJhGJ00;oKhKI0_mcQmT2ogV8eP;oOHWE0on1Rm@2ohB<d`;oR8kB0on<Sm42ohnA
d@;oTi;@0onGU<l00onJU/koVYS@oijJd002oijJd0?oXIc?00?oY9g>ojFPd?nYX]000onYX]03ojbT
c`03ojnVcon`ZM7o/j_@00?o/j_@00Ko]Zg@okRad_nh/M;o^;7Bok^bdOnm]m@3oknhd`05ol:meOo4
_]Coa;kDolBne?o6`mL00oo8a=H00oo;bMWocL_Holo@fP02olo@fP05om3@fOoBe]_od]KKomCKgOoE
fm`00_oGhMh2omOVh00:omSZhOoIj^3ofNkRomW^h_oHl^;oeoGSomOdh_oFmn?oe?WSom7jh`;oco_S
00coc?cTolWli?o6o>Gob?_VolKkioo4nnWo`_[Zol7ik?non>go0000okoel?nnlo42okgal`03ok__
m?nlkOCo^n[d00;o^^Od00?o^^Gdooooooooool02?ooool00ol0003oooooooooo`0=ooooo`002Ooo
ool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0
1P1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0
203<c<`00`000000i^KV0>KViP0=0>KViP03o`000000003ooooo027ooooo00<000000>KViP3Vi^H0
3@3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT0
1P2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<00000ooooooooool0
0_ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo0ol0000Fooooo`03odj<
jom;RNWoBhWY00;oCXSX00GoC8GVodb4iOmBQ>CoDXCToe:3h`02oe>2hP;oFh?O00?oGH?Oof63g_mQ
Pmh00_mTQ=d2of^5fP;oKhKI00?oLhOIogN8f?mgR=P00_mkR]L3ogn<eP;oPhgE0_n8S]82ohb?d@03
oh^Adon?T]?oSi;C00;oTiCB0onGU]43oiZHd0?oWY[@00?oXIc?oj:NdOnUX=000_nUX=03ojVRd0;o
[:C?00Co[JOAok2YdOn`ZM7o/:WA0_ncZm001One[m;o^;7BokRad_nh/M;o^[GD00?o_KOD00Go_kSC
ol:meOo2_MGo`[gEolBne003olK3e`03olS4e_o;bMWoblWI00?ocm3J0_oAeM`01OoBe]_oe=_MomCK
gOoEhMooen7N00;oenKP0_oHj^401?oHkn;ofNkRomSbh_oGmN<2omGhh`0Eom;jhoo@nn?ocOcSolok
hoo<o>CobOcTolKliOo4o>Ko`_cWol3kjOnnn^[o_OW/okohkOnnm^oo_?Gao`000?nklo;o_O7cok__
m?njk?Co^NWe00;o^^Od3?ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooo
ooooool604a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI
09VIV@0609VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV
0>KViP0>0>KViP0300000?oooooooooo01gooooo0P00000?0>KViP030000003<c<`0c<c<00T0c<c<
00?o00000;>c/`2c/k<01`2c/k<00ol00000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00H0Ogmo
00<0000006IVIP1VIVH01`1VIVH00`000000C4a<ooooo`03ooooo`0300000?oooooooooo013ooooo
00?o0000ooooooooool00oooool3o`0001[ooooo00CoB8_[od^9jOm;RNWoB8KX0_m6Q>L01Om<Q>Go
Bh;Uod^2iOm<P^CoDh;R00;oEX;Q0_mHP^02of63gP03ofB4gOmWQMcoIhGL00;oJhKK0_mcQmT2ogN8
f0;oNh[G0omoS=H01?n3SMGoQhoDohN?e?n7Sm@3oh^Ad`;oSi;C0_nCU=83oiNFd@;oVYS@0_nNV]00
1?nNW=;oXYkAoj:NdOnRW]43ojFPd003ojVRd?nZYM;o[JOA00?o[JOA00?o/:WAok:]donb[M<00one
[m801_nh/M;o^[GDokZee?nj]MCo_KODoknkeP?o`[gE00Coa<;HolK3eoo6`mOoa/?G0_o9b=X01?o;
bMWocLoKolg?foo?d=X2om7Eg0;od]_O00Coe=_MomGQgooEhMooe^KQ0_oGjn<02_oHj^7of>oRomS_
h_oGln?oeOKSom?ihooEn>?od_[Som3khoo=o><2olWmh`08olOmhoo1oNCo_ocUol;lioo0nnWo__[Z
okgik?nln>h2ok_fl006ok[dl_nklo;o0000ok[^m?nik?Go^NWe3oooool00ol0003oooooooooo`0=
ooooo`002Oooool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00L0IVIV00<00000
07moO`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00L0/k>c00<00000
0<c<c03<c<`0203<c<`00`000000i^KV0>KViP0>0>KViP0300000?oooooooooo01[ooooo00?o0000
0000003Vi^H03`3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00L0/k>c00<00000
09VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00L0IVIV00<00000
04a<C?ooool00oooool00`00003oooooooooo`0?ooooo`04o`000?ooooooooooooooo`?o00007_oo
ool2odR;j`03odB8j_m1QNWoAXCW00;oAH;V0_m;P^D01Om<P^CoCH7SoeJ2hOmFP^7oF8;P00;oFh?O
0_mTQ=d2ofN5g0;oJhKK00CoKhSKogB9f_mdRM[oM8WJ0_mkR]L2ogn<eP;oPhgE0on7Sm@2oh^Ad`;o
Si;C0_nCU=82oiNFd@04oiNIdonKV]?oVi[Coi^Jd`?oWYcB0_nRW]42ojFPd004ojNTdonZYM;oZZGB
ojZUdP;o[JOA00?o[j_Dok:]donb[M<00_nb[M<00one[m;o]k?EokZee002okZee005okbjeono^mKo
_k_Foknke_o2_MD00oo4`]P00oo6`mOobLSJolW8fP02ol_>g004olg?foo?eMgocmGMom7Eg0?od]_O
00?oe>7QomGQgooFi^400_oGjn<2omK_h`03omS_h_oGln?oeOKS00;odoWS00_odO_Solklhoo:oN;o
aogRolWmhoo7oN?o`OgTokoliOnmo>Oo^o_Yok[jj`02okWik@03okSgkonkm_3o^_Cb00;o^?3d00?o
^^kdo`000?ooool04?ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooo
ool704a<C003o`00001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VI
V@0609VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`0203<c<`00ol00000i^KV0>KV
iP0?0>KViP03o`000000003ooooo01Oooooo0P00000B0>KViP030000003<c<`0c<c<00T0c<c<00<0
00000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00L0Ogmo00<0
000006IVIP1VIVH01`1VIVH00`000000C4a<ooooo`03ooooo`0300000?oooooooooo00oooooo1?l0
000Rooooo`05od::k?lnQ^[o?XKZod65jOloPnP00_m5P^H01?m4PNGoAH3UodF0iOm=PN<2odn1hP03
oe:2h_mKPmooFh?O00;oGhCO00GoHhGNof^6fom[Q]_oJhKKofn8f`02ogB9fP;oN8_I0_mmSMP2oh6?
e`?oQY7G0_n:T]H2ohnDe@?oTiOD0onGVM<3oi^Jd`;oWYcB00?oXYkAoj>Re?nSX]@00onWY=<00onZ
YM;o[:WEojn[e003ojn[e0;o/ZgC00Go];7FokNceOng/mGo]k?EokZee003okbje`05oknke_o2`MWo
`/7Iol;1fOo4`]P00_o6am/01?o9b=[oblkLol_>g?o;c]`3oloEg@;odM_P00Kod]_OomCQhOoDhN7o
eNKRomG[i?oGjn<2omK_h`0:omGci?oDmnCodO[Tom7ji?oCnN?odO_Solklhoo:oN;oaogRolCmhP;o
__gR00So^ocSokWliOnhnnOo]o[YokKijoninNgo^?O_okOdlP;o]o;d00Co^?3dokS]mOoooooo0000
4Oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003oooooooooooooool704a<C0030000
001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@030000
002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP0A0>KViP030000
0?oooooooooo01Cooooo00<000000>KViP3Vi^H04@3Vi^H00`000000c<c<0<c<c0090<c<c0030000
002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0707moO`030000
001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01?ooool00`00003oooooooooo`0?ooooo`;o0000
9?ooool2ocb9k0;o?XKZ00?o>XCYocn3j?lmPNL00_lmOnH00om5P>GoAX3TodJ0i002odn1hP03oe:2
h_mFP^7oEX;Q00;oGhCO00?oHhGNofN6gOmWQ]d00_m/R=d2ogB9fP;oN8_I0_mmSMP2oh6?e`?oQY7G
0_n:T]H2ohnDe@?oTiOD0_nGVM<2oi^Jd`03oi^MeOnOWmCoWioD00CoXj;D00?oYjCCojRWe_n/ZMD0
0_n/ZMD3ojn[e0Co];7F00?o]k?EokVhf?ni^=P00onl^]L3ol;1f@04olC6g?o6am_oa/OKolK7f`;o
bLgM00CoblkLolgDgoo=e=oocmGM0_oAfn02om;QhP08omCQhOoEi^;oeN_TomG[i?oEl>Goe^oSomGc
i?oDmn@2om7ji00>olklhoo;oN;oaogQolCnhOo0oN3o_?gPok[lh?nnoN;o^ocSokWliOnhnnOo]o[Y
okKijonemo02okGelP03okGclongl_Co]^oe00Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0<ooooo`002Oooool01000003oooooooooooooool704a<C0030000001VIVH0IVIV00H0
IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00P0
/k>c00<000000<c<c03<c<`0203<c<`00`000000i^KV0>KViP0A0>KViP8000004_ooool2000001<0
i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00L0
VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00Co
oooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`;o?8W/00Ko=hGZoc>2jOlc
P^Wo>87XocIoiolmOnH2oceoi@03odJ0i?m9P>CoBH3T00;oC87S00?oEX;QoeZ4hOmJQ>400_mNQN02
ofN6g@03ofb8gOmaR]coLH[L00;oMXcL0_mkS]/3oh6?e`;oQY7G0_n:T]H00on?U=GoSYOHoi:Ie`02
oi:Ie`?oUi_F0onKWMD2oinOe0;oXj;D00CoY:GGojRWe_nXYmKoZ:OF0on/ZMD00on_ZmCo/K3Gok6`
e`02okBaeP03okJffOni^=So^KSH00;o^KSH00Co_;[Goknof_no_m[o`/7I0oo4a]`01?o6am_obLgM
olW=gOo;dn03olgDg`05oloJhOoAfn3od^7Rom;Qh_oCi^@00_oCk>D04ooEjnCoeO3UomG`iOoDm>Go
d_SUoloji?oAn^Coc_cSol_mh_o7oN7oa?kQol3mh?nloN3o^_cPokOlhOnenn;o]?_Tok?ji_nbnN`0
0_nbmnh01?nbm_7o]OGbokGclondlOD7ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03?ooool000Wooooo00@00000oooooooooooooooo1`1<C4`00`000000IVIV06IVIP0606IVIP03
0000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`070;>c/`03
0000003<c<`0c<c<00T0c<c<00<000000>KViP3Vi^H04P3Vi^H5000000Wooooo0P0000000ol00000
00000>KViP0B0>KViP8000002`3<c<`00`00003o00000;>c/`080;>c/`03o`00002IVIT0VIVI00L0
VIVI00?o000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0806IVIP030000001<C4`0C4a<00Co
oooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03ocJ8k?laQ>[o<h;Y00;o
<83X00Go=WoWocEni_lmOnGo?GoUocmoi@02odV0i003odb1hom?P^?oCh;S00;oFXCQ00?oGXGPof>7
h?mSQn000_mXRMl2og6:g0;oMXcL0_mkS]/2ogn@fP;oQ9;I0on9UMT2ohjGf0?oTYWG0onGVmH2oi^M
e@03oinOe?nPXmOoX:?G00?oY:GG0_nXYmH2ojbYe@05ojf^f?na/=Oo/K3Gok6`eond/MH00onf]]T2
okVhf0;o^kgK00Go_koJol75gOo1aMgo`LGMolC6g002olK<g`05olW=gOo;dn3obm?Pol_Ch?o=e=l0
0_o?f^400oo@h>Cod^7Rom?Vi003om?/i@05om?ai_oEl>Goe?CUom;hiOo?n^@00_o<o><02?o8oN;o
a?kQokomgonloMko^?cNokGlg_nbnmko[o[R0_n^nNL01_n^n>Wo[_S]ok;gk_nbm_7o/_Ccok;bm@[o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003ooooo
ooooooooool704a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000
VIVI09VIV@0609VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`02P3<c<`00`000000
i^KV0>KViP0F0>KViPT000005P3Vi^H00`000000c<c<0<c<c00;0<c<c0030000002c/k<0/k>c00P0
/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00P0
IVIV00<0000004a<C01<C4`01?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo02?o
oooo00?o<8O/oc64j_laQ>X00_l`P>P01_l^O^Oo=GkVocEni_lfONKo=ggVod5oi@;oAH3U00?oCh;S
oeB4homDQ><00_mIQN<2of>7h005ofR9gom]RmooKH_Ooff;gomcS]h00omkS]/2ogn@fP;oQ9;I0on9
UMT2ohjGf0;oTYWG0_nGVmH00onGW]WoW:7HoibQf004oj2Se`;oY:GG00?oZ:OFojV/fOnY[=T00on]
[]P01_na/=Oo/[CJok:df_nb]=[o][KIokRlg0?o^kgK00Go_/?Nol75gOo1aMgo`LGMol?;h003olK<
g`03olSBh_o;dn3obm?P00;ocM[S00Cocm[Qom3Pi?oAi^KodNKV0_oAk>L05ooCk>Godo7Vom7ei_oA
mNKocoSVolckiOo8o>Coc?cSolSmh_o4o^7o_ogOokcmg_nho=ko]OcNok;kg_nXn>7oZ?STojkiion^
n>Wo[_S]ojofkon_mO;o/??d00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`002Oooool01000003oooooooooooooool804a<C0030000001VIVH0IVIV00H0IVIV00<00000
07moO`1oOgl01`1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00L0/k>c00<00000
0<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0c0>KViP030000003<c<`0c<c<00/0c<c<00<00000
0;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00L0Ogmo00<00000
06IVIP1VIVH0201VIVH010000000C4a<04a<C01<C4`4ooooo`0300000?oooooooooo01Cooooo0_l0
000Uooooo`06obZ3j_lUOnSo9GoXobQniolVO>Ko;GgV0_l]O>H00olgONKo>GkVodF0i@02odR2i@;o
E8CS00?oFHGSoej8homNR><00_mXRMl3off;g`03og>>g_mhT=koN93N00;oOY;M0on3UM`2ohRGg0;o
SI[K0_nBW=X4oiNNf@;oW:7H0_nPXmL00onQYm_oYJWJojFYfP04ojV/f@03ojf^f?n_/]_o/[CJ00;o
/[CJ00Go];[MokRlg?nh_=co^;cLok^mf`03okk3gP05ol75gOo3bn3o`l_Pol?;h?o6c=l00_o8d^80
0oo:fNGocM[SolgJh`02olkPi@05oloViooAi^KodNcWom7/iooAlNP00_o?m^P04_oAmNKocoSVolck
iOo8o>Coa?gRokomh?nkoMko]ocLok;kfon_n]_o[?[LojWig_nXn>7oZ?STojWhionZmn_oZoK^ojce
lA3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`002Oooool01000003o
ooooooooooooool804a<C0030000001VIVH0IVIV00H0IVIV00?o000007moO`1oOgl01`1oOgl00`00
0000VIVI09VIV@0609VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02P3<c<`00ol0
0000i^KV0>KViP0a0>KViP03o`00003<c<`0c<c<00/0c<c<00<000000;>c/`2c/k<0202c/k<00`00
0000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH01`1VIVH00`00
0000C4a<04a<C00204a<C0Cooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`0Roooo
o`08obF5j_lTP^Wo9GoXobEoj?lQONOo9WcVobAki_l]O>H2obiliP03ocUni_lmOnKoB8;U00;oB8;U
00CoCHCUoe:6iOmNR>?oGXSS0_mTR^82ofV=hP;oKhoR0_mhT=h2ogjBg@?oPiGL0_n8Um`2ohfJf`;o
TYcJ0_nGW]T01?nGX]coW:GLoibUg?nLYM`3oj6Wf`;oYJWJ0_nY[=T01On[/=co[k;Kojnbfon_/]_o
/[CJ00?o];[M00Go^;cLok[2h?nj`^3o^/;Pokk3gP02ol39hP;o`l_P0_o5dN<00oo8d^;ob]WUol[I
i@02ol_Oi`06olkPiOo?i^OocnKWolo/jOoAk>OodO7X0_o?m^P04Oo<nNOobO_VolGmi?o5oNCo`?gR
okKlgOnanm_o[?[IojWif?nTmmWoXoOKoj;gg_nRmn7oXoKTojGfj?nVm^coZOCb01?ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool8
04a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@06
09VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0_
0>KViP8000003P3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI00<00000
07moO`1oOgl0201oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<0080C4a<1?ooool0
0`00003oooooooooo`0Gooooo`03o`000?oooooooooo02;ooooo0_lUQNX2oaini`04oaUkiOlMNnGo
77WUobAjiP;o;WcV00Co<GgVoceoi_lmOnKo@H7V0_m6Q>L00omBQ^GoF8SUoeR8i@02ofB:hP;oJHgR
00?oKhoRogFBhOmeT^400omkUN42oh6Hh0;oQi[O0_n=WMh3oi:Pg@?oUj;L0onLYM`00onQYm_oXZcN
ojJ^g@02ojJ^g@?oZk3L00Ko[k;Kok2hg_n`^=ko/;SNokBjgOnf`>43ok[2h005okc8hoo0bN;o`<WR
ol39h_o2d>D00oo5dN<01?o7f>Kob]WUol_Oioo;gnL2olcVj@08oloVioo?k>Woc_7Zolkaj_o<m^[o
coKXolciioo9nnH2olGmi00<ol3mh_nfo=go/O_KojcjfOnYnMSoW?CFoi_df_nLm=goWOCQoioeiOnS
m>goYOCa5_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo0009ooooo`04
00000?ooooooooooooooo`P0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0607mo
O`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00:0<c<
c0030000003Vi^H0i^KV02d0i^KV00<000000<c<c03<c<`0303<c<`2000000X0/k>c00<0000009VI
V@2IVIT01`2IVIT00`000000Ogmo07moO`0807moO`030000001VIVH0IVIV00L0IVIV00<0000004a<
C01<C4`00`1<C4`4ooooo`0300000?oooooooooo01Sooooo00?o0000ooooooooool08_ooool2oan5
j@07oaN0iolGONKo4G[SoaEii?lLNNGo6gWTobEkiP02obMliP04ocAnioliPNOo>H7WodJ4i`;oC8KW
0_mHR>D00omNRnGoIHkUofF>i@02ofn?hP;oMI;Q0omkUN42oh6Hh0;oQi[O0_n=WMh3oi:Pg@;oUj;L
0_nLYM`01?nLZMooXZcNoj:/g_nR[=h3ojJ^g@03oj^`g?n/]^3o[;KP00;o/;SN00Go/[kRokK0hOnf
`>7o]/3Qok[2h003okc8h`05ol39h_o2d>Go`]3Uol;@iOo5dN<00_o7f>H01?o8gnWobmoWolcVjOo<
i^T2olc/j`04ol_ak?o>lN[oc?KZolWij@;oaO_W00go`?cUok_mh_neo=koZ_WHojGge_nRm]GoW_GE
oicde_nClMKoU_;Noi_cionNln_oXO?_01Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`002Oooool01000003oooooooooooooool904a<C0030000001VIVH0IVIV00H0IVIV
00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c
00<000000<c<c03<c<`02`3<c<`2000002`0i^KV00<000000<c<c03<c<`0303<c<`00`000000/k>c
0;>c/`090;>c/`03o`00002IVIT0VIVI00P0VIVI00?o000007moO`1oOgl01`1oOgl00ol00000IVIV
06IVIP0706IVIP03o`00001<C4`0C4a<00@0C4a<1?ooool00`00003oooooooooo`0Iooooo`;o0000
9?ooool00olKQNSo4WoUoa1li002oa5jh`04oa9gholKNNCo6gWTobMliP;o:ggW00Co>H7Wocj3j?ln
PnSoC8KW0_mBRNP2oeV=j0;oIHkU00CoK97Uog:DiOmbU>GoLYCU0_miV>@2ognKi0?oQYkS0_n<XN82
oi:Th@;oUjOP1?nLZMl00onR[=koX[7RojNch@03ojNch@03ojbfh?n^_>Co[[cT00?o/[kR00Go]/3Q
okS6iOnha^Go^<KUokc8h`02okk?i`;o`]3U0_o3enP01Oo7f>Kob=oYolSUk?o8iNcoc>KY00;oc>c[
0_o;lN`04?o8m^coaOWZol7kj?o5nnOo`?cUok_mh_neo=koXoOFoikddonFlM7oU?7Boi?`donClMKo
U?7ToiSbjOnKl^hKooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool000Wo
oooo00@00000oooooooooooooooo2@1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo
00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`03o`00003<c<`0c<c<
00`0c<c<0P00000X0>KViP8000003P3<c<`00ol00000/k>c0;>c/`090;>c/`030000002IVIT0VIVI
00P0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0806IVIP030000001<C4`0C4a<
00@0C4a<1?ooool00`00003oooooooooo`0Kooooo`03o`000?oooooooooo02;ooooo0_lGQNL01Ol:
Nn;o2WSQo`YhhOl9MN7o4GOS00;o4WOS0ol[ONL00olnPnSoA8OYodB7j@02oe:9j005oeV=j?mPT>So
H93Xof2@j?mWU>P00ombU>D2ogVHi0;oOi_T0on6W^<2ohbQhP;oTZCQ0_nGYn02oibYg`04oif^i?nR
/N;oX[7Roj:ahP;oYk?Q00?oZ;WUojjli?n^_>@00_n^_>@00onb_^;o]<CVokC4iP02okS6i@;o^/gY
00?o_/oWokoFjonoe^/00_o3enP2olCNk004olGUk_o8iNcob>c]olS/k@;oao7^013obo7/olSfk?o5
nN[o`O_Xok_liOneo>7o[o[MojSifOnSmmKoW_CCohc]c_n;k<ooRngBohk^hOnBl>KoU_3/7_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooo
ooooo`T0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0
VIVI00L0VIVI00<000000;>c/`2c/k<02@2c/k<00`000000c<c<0<c<c00=0<c<c08000009@3Vi^H0
0`000000c<c<0<c<c00<0<c<c0800000302c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0
Ogmo00P0Ogmo00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00404a<C0Cooooo00<00000
ooooooooool07?ooool00ol0003oooooooooo`0Rooooo`;o4hGV00Go2GoRo`=ggol3Mmoo07CLo`Qd
h002oa9gh`04oa=hholQO>Ko9GoXobEoj0;oA8OY0_m;R^X01OmBS^_oH93Xof2@j?mPT>SoIiCX00;o
KYOX0_mfVnP3ogfNj0;oQ:;W0_n;YNH2oi6XiPCoUjcU0_nM[^@00onR/N;oXkOWoj>gi`03ojRii@;o
[[cT0_n_`^P00onda>Ko]L_[ok[=j@02ok[=j@;o^mC]00Go_mK[ol3Mk_o0gNko`=g^olCNk002olGU
kP05olC[l?o8k>goao7^olOak_o4m^h00_o0nN`03?nknnWo]O_UojkjhOnWn=coVo?CoiGad?nAklko
PNO;ohCYdOn6jmgoRngToi3^jB7ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;
ooooo`002Oooool01000003oooooooooooooool:04a<C0030000001VIVH0IVIV00L0IVIV00<00000
07moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0/k>c00<00000
0<c<c03<c<`03P3<c<`00`000000i^KV0>KViP0O0>KViP<000003P3<c<`00`000000/k>c0;>c/`0;
0;>c/`030000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP08
06IVIP030000001<C4`0C4a<00D0C4a<1?ooool00`00003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Cooooo00Ko1X3Qo`1jgOl0M]co07;Ho`1af_l7MN02o`Ufh@05oaIjiOlUOnSo:h;Yob^2jOlk
Qn/00_m3Rn`2oe:>j`03oeZBk?mRU^coHYK/00;oKYOX0_mfVnP3ogfNj0;oQ:;W0_n;YNH2oi6XiP;o
UjcU00CoUk7Yoifdj?nM]>SoWKCX0onS]nL00onX^NGoZL3ZojW0jP02ojo2j005ok39kOnebn_o]L_[
okG;jonjcNT00onke>d00onkfo3o`=g^ol3MkP02ol3Tl005olGUk_o4jo3o`_7`ol;al?nomO000_nk
n>h03?o0nNco^o_YokGkiOn^n^7oYoSLohc]cOn7j/[oN>?8og[UcOmmim;oQ>[QohW/ib?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01@00003ooooooooooooo
ool0000000T0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0707moO`030000002I
VIT0VIVI00L0VIVI00<000000;>c/`2c/k<02@2c/k<00`000000c<c<0<c<c00>0<c<c0800000703V
i^H300000100c<c<00?o00000;>c/`2c/k<02P2c/k<00`00003o000009VIV@0809VIV@03o`00001o
Ogl0Ogmo00P0Ogmo00?o000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00604a<C0Cooooo00<0
0000ooooooooool07_ooool2o`0002Gooooo00Ko3hWTo`1jfol0N]_o07GFo`1`e_l0L=P2o`Ufh@05
o`]hh_lKONKo:h;Yob^2jOlbQn/00_m3Rn`00om;SnkoDiC_oe>Dk`02of:Fk004ofZJkOmbWngoLYo]
og:Ok@;oNZ?/0_n2Y^`2ohVZj`CoT:kZ0_nG/NT00onM]>SoWK[]oifjk@03ojBmj`03ojW0j_nZanko
Z/O^00?o/<W]00Ko]L_[okKBkonfd^oo]];_ok_DkOnkfo02ok_Sl`;o`>C`0_noj_800onml??o`_7`
okoel002ok_hkP0;okGjj_n^nNKoYoSQoioffonHl]GoN^?4ofkMa?maglSoM^?FogcVgOn3jN@09_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0500000?oooooo
ooooooooo`0000002@1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00L0Ogmo00<0
000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`0:0;>c/`030000003<c<`0c<c<00l0c<c<0P00
000F0>KViP@000004P3<c<`2000000/0/k>c00<0000009VIV@2IVIT02@2IVIT00`000000Ogmo07mo
O`0707moO`030000001VIVH0IVIV00T0IVIV00<0000004a<C01<C4`01P1<C4`4ooooo`0300000?oo
oooooooo023ooooo00?o0000ooooooooool08oooool01ol@RnGo18;No`B2g_l0MM?o073Ao`1^dol0
L=L00_l0Lm`01Ol?NnCo887XobN6jolWQ^_o>H_]00;o@Y3_0_mCU>l00omLVO3oIIk`ofFNl003og:O
k@;oNZ?/0_n2Y^`2ohVZj`;oT:kZ00CoSk?_oiJgk_nF]nkoU[O^0onM^^d00onT_N_oY<C`ojC4l003
oj[7kP03ok39kOn`d?7o/=3a00;o]];_00Co]][bokKQmOnfhOGo^n?c0onjjO@02?noj_;o_O3cok[d
l_ndmnoo[_S[ojKgi_nNmN3oU_;I0_n>k]<01Om_gKooKMboofOI`om]g]?oM>?J02[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0:ooooo`002Oooool01@00003oooooooooooooool0
000000T0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0807moO`030000002IVIT0
VIVI00L0VIVI00<000000;>c/`2c/k<02P2c/k<00`000000c<c<0<c<c00@0<c<c0<00000403Vi^H3
000001@0c<c<0P00000<0;>c/`030000002IVIT0VIVI00T0VIVI00<0000007moO`1oOgl0201oOgl0
0`000000IVIV06IVIP0806IVIP030000001<C4`0C4a<00L0C4a<1?ooool00`00003oooooooooo`0Q
ooooo`03o`000?oooooooooo02Gooooo00Co1XONo`1neol0L<ko06g=0_l0KM800ol0K]7o07?Ho`Ai
g`02obN6j`03obn;kOm2T>oo@Y3_00;oBiKa00CoEI_cofFNl?mUW_3oIIk`0_m^Xo42ogNWl@;oOj_`
0on7/?02ohnck`03oiJgk_nE_O?oUKgc00?oWL7a00?oY<C`oj?;m?nSbo@00onZc_<01?n`d?7o/=Sd
ok3Hm?nff_82okKQm@;o]>Og0_njjO@03_ngkoGo/o?dojgelOn]mO7oY_K/oikdi_nElMooQ>W@oggU
b_mgh/GoH]FjoecC__mUf/ooM>;O;Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo0009ooooo`0600000?ooooooooooooooo`0c<c<000002@1<C4`00`000000IVIV06IVIP07
06IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`0:
0;>c/`030000003<c<`0c<c<0180c<c<4000000F0<c<c003o`00002c/k<0/k>c00/0/k>c00?o0000
09VIV@2IVIT02@2IVIT00`000000Ogmo07moO`0807moO`030000001VIVH0IVIV00T0IVIV00<00000
04a<C01<C4`01`1<C4`4ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool09Oooool2
oaVEi`08o`f?hOl0N/oo07;9o`1Ya?l0JLKo073Ao`1ff_l9ON82oab5j@04obB;k?lhTO3o>97`od:G
lP;oEI_c0_mNXO@00omXY_GoLZceog:/m@03og^am@?oQKGe0_n=^O@3oiFml`03oig1lOnLb?KoW<Sf
00?oXl_d00CoZ/kcojWEmonYeOOo/=Sd0_n_goP2ojgUn@04okCWmon`kOOo[?7fojcamP;oYO?b00So
[OGaojKfk?nNm>KoUO7Oog7Oa_m[fl7oC/VdofKKfc7ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0:ooooo`002Oooool01P00003oooooooooooooool0<c<c000000T0C4a<00<00000
06IVIP1VIVH0201VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0VIVI00<00000
0;>c/`2c/k<02P2c/k<00ol0000000000<c<c00f0<c<c0800000302c/k<2000000X0VIVI00?o0000
07moO`1oOgl0201oOgl00ol00000IVIV06IVIP0906IVIP030000001<C4`0C4a<00P0C4a<00Go0000
oooooooooooooooo0000000Uooooo`03o`000?oooooooooo02Oooooo0_lBTn<01_l5SM_o07O7o`1W
`?l0J<Co07?Co`1jg0;o48?U00Co68WXobjAkol^TNoo>9Sb0_m<WOD00omGY?OoHZ[hof:Zn002og:/
m@?oNk7e00?oQKGeoh6knOn;`?T00on;`?T2oi?4n003oic8m_nJco[oV/oj00;oX];i0_nOfO`01_nX
g?[oYN?kojGSnonUho_o[NGiojW[nP;oXnkh00[o[?7fojGcl_nUlo;oWO?]oiCai_n;kMgoIMS2oeoD
_?mEdLooGmOI=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0009oooo
o`0600000?ooooooooooooooo`0c<c<000002@1<C4`00`000000IVIV06IVIP0806IVIP030000001o
Ogl0Ogmo00L0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0;0;>c/`030000003<
c<`0c<c<0340c<c<0`00000=0;>c/`030000002IVIT0VIVI00T0VIVI0P00000907moO`030000001V
IVH0IVIV00T0IVIV00<0000004a<C01<C4`02@1<C4`01@00003oooooooooooooool0000002Kooooo
0_l0000Yooooo`0:oc>XlOlOWNSo7igXo`2;e_l0Ol[o06Jfo`1W^ol0K<;o07?<o`b7h`;o8Y3/00Co
;IS`od>OmOm3WoGoCZKh0omRZ_P2off`n@;oMkKi0_n1^oT2oh_0n@;oQlKl0_nAbo/01OnJco[oU]Gm
oiKEoOnFeOgoWmWl00;oW=om0_nUho/01_nPj?_oVN_ioiW[nOnSk_SoVo3coi?_k@;oRNcU00?oOnSL
oeS@__lo_Z/0>Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0009oooo
o`0400000?ooooooooooooooo`80<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP08
06IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0;
0;>c/`800000;`3<c<`2000000h0/k>c0P00000;09VIV@030000001oOgl0Ogmo00P0Ogmo00<00000
06IVIP1VIVH02@1VIVH00`000000C4a<04a<C00904a<C00300000?oooooooooo00;ooooo00<00000
ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`;o>jgd0_l`ZNl01_lUY>Wo49SMoa2HgOl0
JK[o06o3o`1ic`?o5XkW0olhX?@00om4Z?OoFZkjoeZ^nP02ofJdn`;oLK_l0oml`Od00on7a_coP/co
oh;<o`02ohgAoP;oU]Gm0_nBfoh00onLgogoU^CmohoVnP02ohoVnP06oiW[nOnAk?CoQn[]oggVhomb
hMWoBlRi?Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0009ooooo`04
00000?ooooooooooooooo`80<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0706IV
IP030000001oOgl0Ogmo00P0Ogmo00<0000009VIV@2IVIT02@2IVIT00ol00000/k>c0;>c/`0<0;>c
/`030000003<c<`0c<c<02X0c<c<0P00000?0;>c/`030000002IVIT0VIVI00X0VIVI00?o000007mo
O`1oOgl0201oOgl00`000000IVIV06IVIP0906IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c
<oooool00oooool00`00003oooooooooo`0Wooooo`03o`000?oooooooooo02Wooooo00?oC;Kiod:c
m_m2/oH00_lh/?401ol^[>co6Z3PoaZPh?l0L;_o07_8o`27e_lDTn@00_l/Wo02ocVXm003odJan?mM
^?coGKSl00?oJ[on00?oM/Goofk9oom^bOl00_mkd?l2ohOFo`;oOmWn00CoRmonoh?Qn_mih??oNN3c
0_m^gNX00omki>coCL_8odC5_@11ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool000Wooooo00@00000oooooooooooooooo0P0c<c<00`000000C4a<04a<C00904a<C003o`00
001VIVH0IVIV00L0IVIV00?o000007moO`1oOgl01`1oOgl00ol00000VIVI09VIV@0909VIV@030000
002c/k<0/k>c00d0/k>c00?o00000000003<c<`0:03<c<`00`000000/k>c0;>c/`0>0;>c/`030000
002IVIT0VIVI00X0VIVI00<0000007moO`1oOgl02@1oOgl00`000000IVIV06IVIP0906IVIP030000
001<C4`0C4a<00T0C4a<00<0000003<c<oooool00oooool00`00003oooooooooo`0Xooooo`03o`00
0?oooooooooo02[ooooo0_mM__d2oeFln`03odfjn?m5^?GoAKSe00;o?;G`0_ld/^/01?l0Rm3o4iWP
obfVk_l]Y^h3ocZ`lP;oB;Wf0_mG`oT01OmUbocoF/_foe[;m_mJboKoJ=?h00;oGM7_00GoJmWboeoE
j?mDd=coE=3LodS9c`16ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
00Wooooo00@00000oooooooooooooooo0`0c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0
IVIV00L0IVIV00<0000007moO`1oOgl0201oOgl00`000000VIVI09VIV@0909VIV@030000002c/k<0
/k>c00h0/k>c0P00000T0<c<c0<000003`2c/k<2000000`0VIVI00<0000007moO`1oOgl02@1oOgl0
0`000000IVIV06IVIP0906IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<01?ooool0
0`00003oooooooooo`0Yooooo`;o0000;?ooool2ofg4oP;oIl?n0_mP`od00omJ`__oI<GmofC5o@02
oek4o004oeS4nOmB`oOoD/?go`28_0;o2IS=00?o5Z?Boc2ci?lT[ML00_lT[ML01?lb^=co9k7?oafZ
`_lDY;E=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo00@0
0000oooooooooooooooo0`0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00L0IVIV
00<0000007moO`1oOgl0201oOgl00`000000VIVI09VIV@0909VIV@030000002c/k<0/k>c00l0/k>c
0P00000P0<c<c003o`0000000000/k>c0100/k>c00<0000009VIV@2IVIT02`2IVIT00`000000Ogmo
07moO`0907moO`030000001VIVH0IVIV00T0IVIV00<0000004a<C01<C4`02@1<C4`010000000<c<c
03<c<`0c<c<4ooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wooooo
00@00000oooooooooooooooo100c<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00P0
IVIV00<0000007moO`1oOgl0201oOgl00`000000VIVI09VIV@0909VIV@03o`000000000000000100
/k>c00@00000o`000000000000005`3<c<`500000140/k>c0P00000<09VIV@8000002`1oOgl00`00
0000IVIV06IVIP0906IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<00P0c<c<4oooo
o`0300000?oooooooooo02cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Toooo
o`05o`000?ooooooooooooooool000002oooool000Wooooo00@00000oooooooooooooooo100c<c<0
0`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl02@1oOgl0
0ol00000VIVI09VIV@0;09VIV@030000002c/k<0/k>c0140/k>c1000000@0<c<c0<00000502c/k<2
000000d0VIVI00<0000007moO`1oOgl02P1oOgl00`000000IVIV06IVIP0906IVIP030000001<C4`0
C4a<00T0C4a<00<0000003<c<`0c<c<00`0c<c<4ooooo`0300000?oooooooooo02gooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo0009
ooooo`0400000?ooooooooooooooo`D0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IV
IP0806IVIP030000001oOgl0Ogmo00T0Ogmo00<0000009VIV@2IVIT02`2IVIT00`000000/k>c0;>c
/`0D0;>c/a0000005@2c/k<2000000h0VIVI00<0000007moO`1oOgl02P1oOgl00ol00000IVIV06IV
IP0906IVIP030000001<C4`0C4a<00T0C4a<00<0000003<c<`0c<c<0100c<c<4ooooo`0300000?oo
oooooooo02kooooo0_l0000Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002ooo
ool000Wooooo00@00000oooooooooooooooo1@0c<c<00`000000C4a<04a<C00904a<C0030000001V
IVH0IVIV00P0IVIV00?o000007moO`1oOgl02@1oOgl00`000000VIVI09VIV@0;09VIV@030000002c
/k<0/k>c03L0/k>c00?o000009VIV@2IVIT0302IVIT2000000`0Ogmo00<0000006IVIP1VIVH02@1V
IVH00ol00000C4a<04a<C00:04a<C003o`00000c<c<0<c<c00@0<c<c1?ooool00`00003ooooooooo
o`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00
000;ooooo`002Oooool01000003oooooooooooooool603<c<`030000001<C4`0C4a<00P0C4a<00<0
000006IVIP1VIVH02@1VIVH00`000000Ogmo07moO`0907moO`03o`00002IVIT0VIVI00/0VIVI00?o
00000000002c/k<0=02c/k<2000000h0VIVI00<0000007moO`1oOgl02`1oOgl00`000000IVIV06IV
IP0906IVIP030000001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<01@0c<c<4ooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooo000000[ooooo0009ooooo`0400000?ooooooooooooooo`L0<c<c00<0000004a<C01<C4`0201<
C4`00`000000IVIV06IVIP0906IVIP030000001oOgl0Ogmo00T0Ogmo00<0000009VIV@2IVIT0302I
VIT200000340/k>c0P00000?09VIV@030000001oOgl0Ogmo00/0Ogmo00<0000006IVIP1VIVH02P1V
IVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00H0<c<c1?ooool00`00003ooooooooo
o`0booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo0009
ooooo`0400000?ooooooooooooooo`L0<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IV
IP0:06IVIP030000001oOgl0Ogmo00T0Ogmo00<0000009VIV@2IVIT03@2IVIT2000002d0/k>c0P00
000@09VIV@030000001oOgl0Ogmo00/0Ogmo00<0000006IVIP1VIVH02P1VIVH00`000000C4a<04a<
C00904a<C0030000000c<c<0<c<c00L0<c<c1?ooool00`00003oooooooooo`0cooooo`;o00008ooo
ool00ol0003oooooooooo`1Wooooo`?o00002_ooool000Wooooo00@00000oooooooooooooooo1`0c
<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00T0IVIV00?o000007moO`1oOgl02P1o
Ogl00`00003o000009VIV@0>09VIV@0400000?l000000000000002D0/k>c0`0000000ol00000VIVI
09VIV@0>09VIV@800000301oOgl2000000/0IVIV00<00000o`00001<C4`02P1<C4`00`00003o0000
03<c<`0803<c<`Cooooo00<00000ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo06?ooooo1?l0000=ooooo`002Oooool01000003oooooooooooooool803<c<`030000
001<C4`0C4a<00T0C4a<00?o000006IVIP1VIVH02@1VIVH00`000000Ogmo07moO`0;07moO`030000
002IVIT0VIVI0100VIVI1000000N0;>c/`<000004P2IVIT2000000`0Ogmo0P00000<06IVIP030000
001<C4`0C4a<00X0C4a<00<0000003<c<`0c<c<02@0c<c<4ooooo`0300000?oooooooooo03Kooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool000Wooooo00@0
0000oooooooooooooooo2@0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00T0IVIV
00<0000007moO`1oOgl02`1oOgl00`000000VIVI09VIV@0C09VIV@<000005`2c/k<4000001@0VIVI
00<0000007moO`1oOgl02`1oOgl00`000000IVIV06IVIP0;06IVIP030000001<C4`0C4a<00X0C4a<
00<0000003<c<`0c<c<02P0c<c<4ooooo`0300000?oooooooooo03Oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Looooo`Co00005?ooool000Wooooo00@00000oooooooooooooooo
2P0c<c<00ol00000C4a<04a<C00904a<C0030000001VIVH0IVIV00T0IVIV0P00000<07moO`030000
0?l00000000001D0VIVI1000000<0;>c/`<0000000Co000000000000000000005@2IVIT200000003
o`00001oOgl0Ogmo00X0Ogmo0P00000<06IVIP800000301<C4`00`000000<c<c03<c<`0;03<c<`Co
oooo00<00000ooooooooool0>?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001So
oooo0009ooooo`0400000?ooooooooooooooo`X0<c<c00<0000004a<C01<C4`02P1<C4`00`000000
IVIV06IVIP0:06IVIP030000001oOgl0Ogmo00`0Ogmo00<0000009VIV@2IVIT05P2IVIT<000001T0
VIVI0`00000>07moO`030000001VIVH0IVIV00/0IVIV00<0000004a<C01<C4`0301<C4`00`000000
<c<c03<c<`0;03<c<`05o`000?ooooooooooooooo`000000??ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05Cooooo1?l0000Looooo`002Oooool01000003oooooooooooooool:03<c
<`030000001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH02P1VIVH00`000000Ogmo07moO`0<07mo
O`800000>P2IVIT00`000000Ogmo07moO`0>07moO`030000001VIVH0IVIV00/0IVIV00<0000004a<
C01<C4`0301<C4`00`000000<c<c03<c<`0<03<c<`05o`000?ooooooooooooooo`000000?Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo0ol0000Pooooo`002Oooool01000
003oooooooooooooool;03<c<`030000001<C4`0C4a<00X0C4a<00<0000006IVIP1VIVH02`1VIVH0
0`000000Ogmo07moO`0=07moO`030000002IVIT0VIVI03D0VIVI0P00000@07moO`03o`00001VIVH0
IVIV00/0IVIV00?o000004a<C01<C4`0301<C4`00`000000<c<c03<c<`0<03<c<`03o`000?oooooo
oooo00;ooooo00<00000ooooooooool0??ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04gooooo1?l0000Sooooo`002Oooool01000003oooooooooooooool<03<c<`8000002`1<C4`0
0`000000IVIV06IVIP0:06IVIP03o`0000000000Ogmo00h0Ogmo0`00000`09VIV@@00000401oOgl2
000000d0IVIV0P00000<04a<C08000003P0c<c<00ol000006ATIooooo`03ooooo`0300000?oooooo
oooo03gooooo0_l0000Iooooo`03o`000?oooooooooo04Wooooo1?l0000Wooooo`002Oooool01@00
003ooooooooooooooooo000000d0<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0;
06IVIP030000001oOgl0Ogmo00l0Ogmo1000000[09VIV@030000001oOgl0Ogmo0100Ogmo0P00000>
06IVIP030000001<C4`0C4a<00/0C4a<00<0000003<c<`0c<c<03@0c<c<00ol000006ATI01TI6@04
ooooo`0300000?oooooooooo03oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15
ooooo`Co0000:oooool000Wooooo00D00000ooooooooooooooooo`00000=03<c<`030000001<C4`0
C4a<00X0C4a<00<0000006IVIP1VIVH02`1VIVH2000001<0Ogmo0P00000V09VIV@<000004@1oOgl2
000000h0IVIV0P00000=04a<C0030000000c<c<0<c<c00d0<c<c00Co000001TI6@0I6AT06ATI1?oo
ool00`00003oooooooooo`10ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@ooo
ool3o`0002oooooo0009ooooo`0600000?ooooooooooooooo`0I6AWo00003@0c<c<00`000000C4a<
04a<C00:04a<C003o`0000000000IVIV00`0IVIV0P00000C07moO`D000006P2IVIT300000004o`00
00000000000000000180Ogmo0P00000>06IVIP8000003P1<C4`00`000000<c<c03<c<`0=03<c<`03
o`00000I6AT06ATI00806ATI1?ooool00`00003oooooooooo`11ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0?oooool4o`0003;ooooo0009ooooo`0600000?ooooooooooooooo`0I
6AWo00003@0c<c<00`000000C4a<04a<C00<04a<C0030000001VIVH0IVIV00`0IVIV0P00000F07mo
O`<00000502IVIT3000001P0Ogmo00<0000006IVIP1VIVH03@1VIVH00`000000C4a<04a<C00=04a<
C0030000000c<c<0<c<c00d0<c<c00?o000001TI6@0I6AT00`0I6AT4ooooo`0300000?oooooooooo
04;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`002Oooool01000003o
ooooooooooooool201TI6@03o`00000c<c<0<c<c00/0<c<c00<0000004a<C01<C4`0301<C4`00`00
0000IVIV06IVIP0=06IVIP030000001oOgl0Ogmo01H0Ogmo5000000H07moO`<000003`1VIVH00`00
0000C4a<04a<C00=04a<C0030000000c<c<0<c<c00d0<c<c00?o000001TI6@0I6AT0100I6AT4oooo
o`0300000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0goooo
o`Co0000>_ooool000Wooooo00@00000oooooooooooooooo0`0I6AT00ol00000<c<c03<c<`0;03<c
<`03o`00001<C4`0C4a<00/0C4a<00<0000006IVIP1VIVH03P1VIVH00`000000Ogmo07moO`0o07mo
O`03o`0000000000IVIV00l0IVIV00?o00000000001<C4`03P1<C4`00`000000<c<c03<c<`0=03<c
<`03o`00000I6AT06ATI00D06ATI1?ooool00`00003oooooooooo`15ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<oooool4o`0003kooooo0009ooooo`0400000?oooooooooooooo
o`<06ATI00?o000003<c<`0c<c<0300c<c<00`000000C4a<04a<C00;04a<C08000003`1VIVH00ol0
000000000000000m07moO`800000401VIVH2000000h0C4a<00<00000o`00000c<c<03P0c<c<00ol0
00006ATI01TI6@0601TI6@Cooooo00<00000ooooooooool0A_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo033ooooo0ol00012ooooo`002Oooool01000003oooooooooooooool401TI
6@03o`00000c<c<0<c<c00`0<c<c00<0000004a<C01<C4`0301<C4`200000100IVIV0`00000f07mo
O`@00000401VIVH2000000h0C4a<0P00000?03<c<`;o00002@0I6AT4ooooo`0300000?oooooooooo
04Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool000Wo
oooo00@00000oooooooooooooooo1@0I6AT00ol00000<c<c03<c<`0<03<c<`03o`00001<C4`0C4a<
00d0C4a<00<0000006IVIP1VIVH0401VIVH300000300Ogmo0`00000B06IVIP8000003`1<C4`00`00
0000<c<c03<c<`0>03<c<`03o`00000I6AT06ATI00T06ATI1?ooool00`00003oooooooooo`18oooo
o`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000BOooool000Wooooo00@00000oooooooo
oooooooo1P0I6AT00ol00000<c<c03<c<`0<03<c<`8000003P1<C4`00`00003o000006IVIP0B06IV
IP0400000?l000000000000002P0Ogmo1000000D06IVIP03o`00001<C4`0C4a<00h0C4a<00<00000
03<c<`0c<c<03P0c<c<00ol000006ATI01TI6@0:01TI6@Cooooo00<00000ooooooooool0B_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0001=ooooo`002Oooool01000
003oooooooooooooool701TI6@03o`00000c<c<0<c<c00d0<c<c00<0000004a<C01<C4`03@1<C4`0
0`000000IVIV06IVIP0D06IVIP<000008P1oOgl3000001D0IVIV0`00000?04a<C00300000?l00000
<c<c00l0<c<c00?o000001TI6@0I6AT02`0I6AT4ooooo`0300000?oooooooooo04_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`?o0000DOooool000Wooooo00@00000oooo
oooooooooooo1`0I6AT00ol00000<c<c03<c<`0>03<c<`030000001<C4`0C4a<00d0C4a<00<00000
06IVIP1VIVH05P1VIVH4000001X0Ogmo1000000F06IVIP8000004@1<C4`00`000000<c<c03<c<`0?
03<c<`03o`00000I6AT06ATI00`06ATI1?ooool00`00003oooooooooo`1<ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0009ooooo`0400000?oooooooooo
ooooo`P06ATI00?o000003<c<`0c<c<03@0c<c<00`000000C4a<04a<C00>04a<C08000006P1VIVH6
000000/0Ogmo00?o00000000000000001P00000I06IVIP030000001<C4`0C4a<0100C4a<00<00000
03<c<`0c<c<03`0c<c<00ol000006ATI01TI6@0=01TI6@Cooooo00<00000ooooooooool0COooool2
o`0000Sooooo00?o0000ooooooooool06Oooool4o`0005Sooooo0009ooooo`0400000?oooooooooo
ooooo`T06ATI00?o000003<c<`0c<c<03@0c<c<200000100C4a<1000000L06IVIP0300000?l00000
000000P000007P1VIVH300000003o`00001<C4`0C4a<00l0C4a<00<00000o`00000c<c<03`0c<c<2
o`0001006ATI1?ooool00`00003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05Oooool4o`0005cooooo0009ooooo`0400000?ooooooooooooooo`X06ATI00?o0000
03<c<`0c<c<03P0c<c<200000180C4a<00<0000006IVIP1VIVH0?`1VIVH300000180C4a<0`00000@
03<c<`;o00004P0I6AT4ooooo`0300000?oooooooooo053ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`?o0000H?ooool000Wooooo00@00000oooooooooooooooo2`0I6AT0
0ol00000<c<c03<c<`0?03<c<`030000001<C4`0C4a<0100C4a<0P00000n06IVIP030000001<C4`0
C4a<0180C4a<00<0000003<c<`0c<c<0400c<c<00ol000006ATI01TI6@0B01TI6@Cooooo00<00000
ooooooooool0DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001S
ooooo`002Oooool01000003oooooooooooooool<01TI6@;o0000400c<c<00ol00000C4a<04a<C00A
04a<C0800000>@1VIVH200000003o`00001<C4`0C4a<0140C4a<0P00000B03<c<`;o0000500I6AT0
1Ol0003oooooooooooooool0000005Cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0
001Wooooo`002Oooool01000003oooooooooooooool>01TI6@03o`00000c<c<0<c<c00h0<c<c0P00
000C04a<C0<00000<`1VIVH3000001@0C4a<0P00000C03<c<`03o`00000I6AT06ATI01<06ATI00?o
0000ooooooooool00_ooool00`00003oooooooooo`1Dooooo`04o`000?ooooooooooo`0000Sooooo
1?l0001[ooooo`002Oooool01000003oooooooooooooool?01TI6@03o`00000c<c<0<c<c00l0<c<c
00<0000004a<C01<C4`04`1<C4`3000002`0IVIV1000000E04a<C08000004`0c<c<2o`0001D06ATI
00?o000000000?ooool00oooool00`00003oooooooooo`1Eooooo`03o`000?oooooo000000Gooooo
0ol0001_ooooo`002Oooool01000003oooooooooooooool@01TI6@03o`00000c<c<0<c<c00l0<c<c
00?o00000000000000005@1<C4`4000002@0IVIV00Co00000000000000000000601<C4`00`000000
<c<c03<c<`0B03<c<`03o`00000I6AT06ATI01<06ATI0_l00002000000Cooooo00<00000oooooooo
ool0E_ooool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooo
oooo4@0I6AT00ol00000<c<c03<c<`0A03<c<`030000001<C4`0C4a<01H0C4a<00?o000000000000
00001000000G06IVIPH000006P1<C4`00`00003o000003<c<`0B03<c<`;o00005@0I6AT00ol00000
000000000002000000Cooooo00<00000ooooooooool0Eoooool2o`0007Kooooo0009ooooo`040000
0?oooooooooooooooa806ATI00?o000003<c<`0c<c<04@0c<c<2000001d0C4a<5`00000N04a<C080
00004`0c<c<2o`0001H06ATI00?o00000000000000000`000004ooooo`0300000?oooooooooo0<oo
oooo0009ooooo`0400000?oooooooooooooooa<06ATI00?o000003<c<`0c<c<04P0c<c<00`000000
C4a<04a<C01=04a<C0800000500c<c<00ol000006ATI01TI6@0E01TI6@03o`0000000000000000@0
00001?ooool00`00003oooooooooo`3?ooooo`002Oooool01@00003oooooooooooooool0000001<0
6ATI0_l0000C03<c<`04o`00000000000000000004L0C4a<1000000E03<c<`03o`00000I6AT06ATI
01@06ATI0_l00007000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooo
oooooooo0P00000D01TI6@03o`00000c<c<0<c<c01@0<c<c0P00001204a<C0<00000600c<c<00ol0
00006ATI01TI6@0C01TI6@;o00002@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`04
00000?ooooooooooooooo`<00000500I6AT00ol00000<c<c03<c<`0E03<c<`030000001<C4`0C4a<
03h0C4a<00<0000003<c<`0c<c<05P0c<c<3o`0001D06ATI00?o00000000000000002@000004oooo
o`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`<0000000?o000001TI
6@0I6AT04P0I6AT2o`0001H0<c<c1000000h04a<C0@000005`0c<c<2o`0001L06ATI00?o00000000
000000002P000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooo
o`D000005@0I6AT00ol00000<c<c03<c<`0G03<c<`<00000<`1<C4`00`00003o000003<c<`0I03<c
<`;o00005P0I6AT2o`0000d000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
ooooooooooooool6000001D06ATI0_l0000J03<c<`<00000;01<C4`4000001T0<c<c0ol0000G01TI
6@03o`0000000000000000d000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
ooooooooooooool7000001H06ATI0_l0000K03<c<`@000008@1<C4`7000001/0<c<c0_l0000I01TI
6@03o`0000000000000000h000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
ooooooooooooool8000001L06ATI0_l0000M03<c<`L000004`1<C4`700000200<c<c0_l0000I01TI
6@;o00004@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooooooo
o`T00000600I6AT00ol00000<c<c03<c<`0Q03<c<a<000009P0c<c<00ol000006ATI01TI6@0H01TI
6@03o`00000000000000014000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
ooooooooooooool:000001P06ATI0ol0001F03<c<`?o00006@0I6AT2o`0001@000001?ooool00`00
003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool:000000;o00006@0I6AT00ol0
0000<c<c03<c<`1A03<c<`;o00006`0I6AT00ol0000000000000000D000000Cooooo00<00000oooo
ooooool0coooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`00
2Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool0coooool000Wooooo]P00003Aooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`002Ooooonfo`00017ooooo]_l0000:ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool2000001Sooooo0P00000Nooooo`@00000;oooool3o`0001kooooo0P00000D
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0=ooooo`0300000?oooooooooo01Oooooo00<00000oooo
ooooool06_ooool4000003Kooooo0ol0000Mooooo`8000004_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03?ooool00`00003oooooooooo`0Fooooo`8000006_ooool3000003gooooo1?l0000Kooooo`80
00004?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0Fooooo`030000
0?oooooooooo01Sooooo0P000014ooooo`?o00006_ooool00`00003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`8000005_ooool00`00003o00000000000Fooooo`@0000000?o
0000ooooooooool0Aoooool4o`0001Kooooo00?o000000000?ooool03Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo01Kooooo00<00000
ooooooooool0D?ooool3o`0001Gooooo00<00000ooooooooool02oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01oooool00`00003oooooooooo`0Dooooo`8000005_ooool3000005Kooooo00?o0000oooo
ooooool04oooool2000000_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00<00000oooooooo
ool04oooool2000001Gooooo0`00000Soooooa<000009?ooool2o`0001Gooooo0P000009ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool0
4oooool2000001oooooo1`00000Cooooo`L000007oooool2o`0001Gooooo00<00000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`0Booooo`0300000?oo
oooooooo01;ooooo0P00000Jooooo`L000008Oooool7000001[ooooo0_l0000Dooooo`0300000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=Oooool?
o`00oc;ooooo2P000?lbooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0`00003oooooooooo`0Booooo`0300000?oooooooooo01;ooooo00<00000ooooooooool06?ooool2
000002oooooo0`00000Iooooo`03o`000?oooooooooo01;ooooo00<00000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0`ooooo`Go003o3oooool4o`00
obWooooo1@000?l:ooooo`X0003o:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00;ooooo00?o000000000?ooool04_ooool2000001?ooooo0P00000Fooooo`@0000000?o0000oooo
ooooool0<_ooool01?l00000000000000000000Fooooo`;o00004oooool2000000Cooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;Oooool3o`00oaSooooo1Ol00?lPoooo
o`@0003o6Oooool30000obGooooo00?o0000ooooooooool03oooool01Ol0003oooooooooooooool0
000001Cooooo00<00000ooooooooool04Oooool2000001Gooooo0`00000mooooo`@000005?ooool2
o`0001?ooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0Z
ooooo`?o003o8?ooool4o`00oaSooooo10000?lPooooo`80003o8oooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooo000001Cooooo00<00000ooooooooool04?ooool2000001Cooooo0`00
0014ooooo`0300000?l0003ooooo01?ooooo0_l0000Booooo`0400000?ooooooooooo`0000[ooooo
0009ooooo`03o`000?oooooooooo02Oooooo00<0003oo`00ool00?l09oooool2o`00oa?ooooo0`00
0?lVooooo`80003o8Oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000001Cooooo00<0
0000ooooooooool04?ooool00`00003oooooooooo`0Booooo`800000BOooool2000001Cooooo00?o
0000ooooooooool04?ooool00`00003oooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0U
ooooo`80003o;?ooool2o`00o`oooooo0P000?l[ooooo`<0003o7_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooo000001?ooooo00<00000ooooooooool03oooool00`00003o0000ooooo`0B
ooooo`800000COooool2000001?ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000:
ooooo`002Oooool00ol0003oooooooooo`0Sooooo`80003o<?ooool2o`00o`_ooooo0P000?l`oooo
o`80003o7?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00<00000oooo
ooooool03_ooool2000001;ooooo0`00000Ooooooa<000007oooool2000001;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Qooooo`80
003o=?ooool2o`00o`Oooooo0P000?ldooooo`80003o6_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo017ooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0@ooooo`80
00006oooool7000001?ooooo1`00000Jooooo`8000004Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo023ooooo00<0003oooooooooool0
=_ooool00ol00?ooooooooooo`03ooooo`030000oooooooooooo03Kooooo00<0003oooooooooool0
5oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00<00000o`000?ooool0
3oooool00`00003o0000ooooo`0?ooooo`8000005_ooool500000003o`000000003ooooo023ooooo
00Co000000000000000000006?ooool00ol0003oooooooooo`0?ooooo`;o00003oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Nooooo`030000ool00?oooooo03Wooooo
0_l00?l00oooool0003o0000o`0Poooooa@0003o1_ooool20000oaOooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0>ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
3_ooool2000001Gooooo0`00000/ooooo`<000005_ooool20000017ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`80003o?Ooo
ool00`000?oo003oo`00o`0Mooooo`@0003o5?ooool50000o`?ooooo00<0003oooooooooool05?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00<00000ooooooooool03_oo
ool2000000oooooo0P00000Dooooo`<00000<_ooool4000001Cooooo0P00000@ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool0
0`000?ooooooooooo`0kooooo`80003o0oooool00ol00?ooooooooooo`0Fooooo`@0003o7Oooool3
0000o`03ooooo`000?oooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00kooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0@
ooooo`0400000?l000000000000003Wooooo1000000Booooo`8000003oooool2o`0000_ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool00`000?ooooooooooo`0k
ooooo`030000oooooooooooo00Cooooo00?o003oooooooooool04_ooool30000obCooooo10000?lC
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03?ooool00`00003oooooooooo`0=
ooooo`0300000?oooooooooo00gooooo00<00000o`000?ooool04Oooool00`00003oooooooooo`0o
ooooo`8000004_ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool06?ooool20000ocgooooo00<0003ooooo
ooooool01_ooool00ol00?ooooooooooo`0>ooooo`030000ool00?l0003o02Wooooo00?o003o0000
o`000?l04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00<00000oooo
ooooool03Oooool00`00003oooooooooo`0<ooooo`8000004Oooool3000004Cooooo0P00000Aoooo
o`0300000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Gooooo`030000oooooooooooo03cooooo00<0003ooooooooo
ool02?ooool00ol00?ooooooooooo`0<ooooo`030000oooooooooooo02gooooo0P000?l@ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00`00003oooooooooo`0=ooooo`03
00000?oooooooooo00cooooo00<00000ooooooooool03oooool20000023ooooo2000000Qooooo`80
00004?ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool05_ooool00`000?ooooooooooo`0looooo`030000
oooooooooooo00[ooooo00?o003oooooooooool02Oooool20000oc7ooooo0`000?l>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`030000
0?oooooooooo00cooooo00?o0000ooooooooool03_ooool00`00003o0000ooooo`0Jooooo`@00000
0_l000000`00003oooooooooo`06ooooo`<0000000?o00000000000000001@00000Hooooo`03o`00
00000000000000kooooo0P00000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool05_ooool00`000?ooooooooooo`0kooooo`030000oooo
oooooooo00cooooo00?o003oooooooooool01Oooool30000ocCooooo00<0003oooooo`000?l03Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00<00000ooooooooool03?oo
ool00`00003o0000ooooo`0=ooooo`0300000?oooooooooo00gooooo0P00000Fooooo`L000006_oo
ool3000001Sooooo00<00000ooooooooool03Oooool2000000gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Eooooo`030000oooooooo
oooo03_ooooo00<0003oooooooooool03_ooool00ol00?ooooooooooo`03ooooo`030000oooooooo
oooo03Kooooo00<0003oooooo`000?l03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0<ooooo`8000003_ooool2
000001Cooooo1000000Tooooo`@000005Oooool00`00003oooooooooo`0>ooooo`0300000?oooooo
oooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Dooooo`030000oooooooooooo03Gooooo1P3o]/400ol00?l0okK10?nf`@0@0?nf
`@05o`00oooooooooooo0000ool00?l0>_ooool010000?ooooooo`00o`000?l:ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`0<ooooo`0300000?oo
oooooooo00_ooooo0P00000=ooooo`0300000?l00000000001;ooooo00D00000o`00000000000000
ooooo`0I0?nf`A;ooooo1000000Booooo`03o`000000003ooooo00kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo01?ooooo00<0003oooooooooool0<oooool90?nf`@030000o`3o]/40okK10100okK100?o
003o0?nf`@000?l0?Oooool010000?ooooooooooo`000?l9ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01_ooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`0@ooooo`<000000_oooolO0?nf`A?ooooo
0`00000Aooooo`0300000?oooooooooo00cooooo00<00000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01;ooooo00<0
003oooooooooool0<Oooool;0?nf`@030000o`3o]/40okK10180okK100?o003o0?nf`@3o]/400P3o
]/4kooooo`040000oooooooooooo0000o`Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`05ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`0;ooooo`0300000?oooooooooo00kooooo0`000002ooooobD0okK14oooool20000013ooooo
0P00000=ooooo`0300000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Booooo`030000oooooooooooo02kooooo3@3o
]/400`000?l0okK10?nf`@0B0?nf`@030000o`3o]/7o003o00H0okK1>Oooool010000?oooooooooo
o`000?l7ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`0>ooooo`0300000?oooooooooo02/0okK14_ooool20000013ooooo00<00000ooooooooool0
2oooool00`00003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002_ooool000Wooooo
00?o0000ooooooooool04Oooool00`000?ooooooooooo`0/ooooo`l0okK100<0003o0?nf`@3o]/40
4P3o]/401@000?l0okK10?nf`@3o]/7o003o00P0okK1=_ooool010000?ooooooooooooooool20000
o`Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo
00cooooo00<00000ooooooooool02oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo
00gooooo0P00000a0?nf`A7ooooo0P00000?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool01?l0003oooooooooool0000:ooooo`002Oooool00ol0003oooooooooo`0@oooo
o`030000oooooooooooo02[ooooo4@3o]/400`000?l0okK10?nf`@0B0?nf`@030000o`3o]/40okK1
00<0okK100?o003o0?nf`@3o]/40203o]/4dooooo`030000oooooooooooo00;ooooo00<0003ooooo
ooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0:ooooo`0300000?l0003ooooo00_ooooo00<00000o`00
0?ooool03Oooool2000001P0okK14`00000;0?nf`A3ooooo0P00000>ooooo`8000003?ooool00`00
003oooooooooo`0;ooooo`03o`000?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo013o
oooo00<0003oooooooooool09ooooolD0?nf`@030000o`3o]/40okK10140okK100<0003o0?nf`@3o
]/401@3o]/400ol00?l0okK10?nf`@080?nf`C?ooooo00<0003oooooooooool00oooool01@000?oo
oooooooooooooooo0000017ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0;oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool02_ooool2000000kooooo0P00000F0?nf
`@@000004`3o]/47000000D0okK14Oooool2000000kooooo00<00000ooooooooool02_ooool00`00
003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00oo
oooo00<0003oooooooooool09ooooolD0?nf`@030000o`3o]/40okK10100okK10P000?l80?nf`@03
o`00o`3o]/40okK100T0okK1<oooool00`000?ooooooooooo`03ooooo`040000ooooooooooooo`00
017ooooo00Go0000oooooooooooooooo0000000=ooooo`0300000?oooooooooo00[ooooo00<00000
ooooooooool02_ooool00`00003oooooooooo`0<ooooo`800000503o]/44000001h0okK110000002
0?nf`A;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`0300000?oooooo
oooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03_ooool00`00
0?ooooooooooo`0VoooooaD0okK100<0003o0?nf`@3o]/40403o]/400`000?l0okK10?nf`@090?nf
`@03o`00o`3o]/40okK100/0okK1<Oooool00`000?ooooooooooo`03ooooo`030000oooooooo0000
017ooooo00Go0000oooooooooooooooo0000000<ooooo`0300000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00`00003oooooooooo`0<ooooo`0300000?l00000okK10140okK10P000000
0ol00000okK10?nf`@0T0?nf`@<000000P3o]/4@ooooo`8000003?ooool00`00003oooooooooo`0:
ooooo`0300000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool03Oooool00`000?ooooooooooo`0UoooooaH0okK100<0003o0?nf`@3o]/40403o]/400`00
0?l0okK10?nf`@0;0?nf`@03o`00o`3o]/40okK100`0okK1<?ooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo00oooooo00Co0000ooooooooool000003?ooool00`00003oooooooooo`0;
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02oooool200000140okK10`00000/
0?nf`@8000000P3o]/4@ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02_ooool0
0`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
00gooooo00<0003oooooooooool09?oooolG0?nf`@030000o`3o]/40okK10100okK100<0003o0?nf
`@3o]/402`3o]/400ol00?l0okK10?nf`@0=0?nf`Boooooo00<0003oooooooooool01?ooool00ol0
003oooooooooo`0?ooooo`03o`000?ooool0000000gooooo00<00000ooooooooool02_ooool00`00
003oooooooooo`09ooooo`0300000?oooooooooo00_ooooo00<000000?nf`@3o]/403P3o]/430000
0340okK10P0000000`3o]/7oooooooooo`0>ooooo`0300000?oooooooooo00[ooooo00<00000oooo
ooooool02_ooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo00cooooo00<0003oooooooooool09?oooolG0?nf`@030000o`3o]/40okK10100
okK100<0003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@0=0?nf`Bkooooo00<0003ooooooooo
ool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00<00000oooooooo
ool02_ooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00<00000o`00003o
]/403P3o]/42000003H0okK10P00000@ooooo`0300000?oooooooooo00[ooooo00?o0000oooooooo
ool02_ooool00`00003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo00_ooooo00<0003oooooooooool09?oooolG0?nf`@030000o`3o]/40okK10100okK1
00<0003o0?nf`@3o]/403`3o]/400ol00?l0okK10?nf`@0=0?nf`Bkooooo00<0003oooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00<00000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00<000000?nf`@3o]/40
3@3o]/42000003X0okK100<00000ooooooooool03_ooool00`00003oooooooooo`0:ooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0;ooooo`030000oooooooooooo02;ooooo6@3o]/400`000?l0okK10?nf
`@0@0?nf`@030000o`3o]/40okK10100okK100?o003o0?nf`@3o]/403P3o]/4]ooooo`030000oooo
oooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`0300000?oo
oooooooo00Wooooo00<00000ooooooooool02Oooool00`00003oooooooooo`09ooooo`8000003@3o
]/43000003d0okK10`00000>ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02Ooo
ool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo00[ooooo00<0003oooooooooool08_oooolJ0?nf`@030000o`3o]/40okK100l0okK100<0003o
0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@0?0?nf`Bgooooo00D0003oooooooooooooooooo`00
000Aooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool02Oooool00`00003ooooooooo
o`09ooooo`0300000?oooooooooo00Wooooo00<000000?nf`@3o]/402`3o]/42000001L0okK100<0
0000o`000?l00000400000000ol00000okK10?nf`@0F0?nf`@0300000?l0003ooooo00cooooo00<0
0000ooooooooool02_ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02_ooool00`000?ooooooooooo`0Q
oooooa/0okK100<0003o0?nf`@3o]/403`3o]/400`000?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40
okK10100okK1;?ooool01@000?oooooooooooooooooo0000017ooooo00?o0000ooooooooool02_oo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02?oo
ool00ol00000okK10?nf`@0;0?nf`@030000003o]/40okK101@0okK10`00000D0?nf`@L000004P3o
]/42000000gooooo00<00000ooooooooool02Oooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02Oooool0
0`000?ooooooooooo`0Qoooooa/0okK100<0003o0?nf`@3o]/403`3o]/400`000?l0okK10?nf`@0C
0?nf`@03o`00o`3o]/40okK10100okK1;?ooool010000?ooooooooooool0000Aooooo`03o`000?oo
oooooooo00Wooooo00<00000ooooooooool02Oooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo00Sooooo00<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@0B0?nf`@<000007P3o
]/4200000140okK100?ooooo0000000000003?ooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo00Wooooo00<00000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`09ooooo`030000oooooooooooo023ooooo703o]/400`000?l0okK10?nf`@0>
0?nf`@030000o`3o]/40okK101@0okK100?o003o0?nf`@3o]/404@3o]/4[ooooo`040000oooooooo
ooooo`00017ooooo00?o0000ooooooooool02?ooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo00Wooooo00<00000ooooooooool02?ooool00`000000okK10?nf`@0;0?nf`@030000003o
]/40okK100l0okK11000000S0?nf`@800000403o]/42ooooo`03o`000?oooooooooo00[ooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02?ooool00`000?ooooooooooo`0P
oooooad0okK100<0003o0?nf`@3o]/403@3o]/400`000?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40
okK10180okK1:_ooool010000?ooooooooooool0000Aooooo`03o`000?oooooooooo00Oooooo00<0
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000000003ooooo00Wooooo00<0
00000?nf`@3o]/402P3o]/400ol0000000000?nf`@0>0?nf`@<00000:@3o]/42000000l0okK100?o
oooo00000?ooool03?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`08
ooooo`03o`00oooooooooooo01oooooo7@3o]/400`000?l0okK10?nf`@0=0?nf`@030000o`3o]/40
okK101L0okK100?o003o0?nf`@3o]/404@3o]/4[ooooo`03o`00oooooooo0000017ooooo00?o0000
ooooooooool01oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool02?ooool00ol00000okK10?nf`@0:0?nf`@030000003o]/40okK100h0okK100<00000
0?nf`@3o]/40;03o]/400`000000okK10?nf`@0<0?nf`@;ooooo00<00000ooooooooool02_ooool0
0`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`030000oooooooooooo
01oooooo7@3o]/400ol00?l0okK10?nf`@0=0?nf`@030000o`3o]/40okK101L0okK100?o003o0?nf
`@3o]/404P3o]/4Zooooo`03o`00oooooooo0000017ooooo00?o0000ooooooooool01_ooool00`00
003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02Oooool00`00
0000okK10?nf`@090?nf`@030000003o]/40okK100`0okK10`00000`0?nf`@8000003@3o]/42oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`08oooo
o`0300000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool02?ooool00`000?ooooooooooo`0Noooooad0okK100?o003o0?nf`@3o]/403@3o]/400`000?l0
okK10?nf`@0H0?nf`@03o`00o`3o]/40okK101<0okK1:oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Kooooo00<00000ooooooooool02Oooool00`00003oooooooooo`08ooooo`03
00000?oooooooooo00Sooooo00<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@0;0?nf`@80
0000=@3o]/42000000`0okK10_ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Wo
oooo00<00000o`000?ooool02?ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00Oooooo00<0003oooooooooool07_oooolB0?nf`@ko003o
3P3o]/400`000?l0okK10?nf`@0I0?nf`@03o`00o`3o]/40okK101<0okK1:_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool02Oooool00`00003ooooo
ooooo`07ooooo`03o`000000003ooooo00Wooooo00<000000?nf`@3o]/40203o]/400`00003o0000
0?nf`@0<0?nf`@0300000?l00000okK103L0okK10P00000;0?nf`@;ooooo00<00000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`030000oooo
oooooooo01gooooo303o]/450000o`;o003o2`3o]/400ol00?l0okK10?nf`@06o`00o`L0okK100<0
003o0?nf`@3o]/406P3o]/400ol00?l0okK10?nf`@0D0?nf`BWooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01ooo
ool00`00003oooooooooo`08ooooo`03o`00003o]/40okK100P0okK100<000000?nf`@3o]/40303o
]/400`000000okK10?nf`@0j0?nf`@030000003o]/40okK100T0okK10_ooool00`00003ooooooooo
o`09ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Oooooo00<0003o
ooooooooool07?ooool:0?nf`@80003o00?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@06
0?nf`@Co003o0`3o]/400`000?l0okK10?nf`@0J0?nf`@03o`00o`3o]/40okK101@0okK1:Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool02Oooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo00Sooooo00<000000?nf`@3o]/40203o]/40
0`000000okK10?nf`@0;0?nf`@8000005P3o]/4C000001D0okK100?o00000?nf`@3o]/40203o]/43
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08
ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o0000ooooooooool01_ooool0
0`000?ooooooooooo`0Mooooo`L0okK10`000?lE0?nf`@03o`00o`3o]/40okK100X0okK10ol00?lM
0?nf`@03o`00o`3o]/40okK101D0okK1:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Cooooo00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`0300000?oooooo
oooo00Sooooo00<00000ooooo`3o]/40203o]/400ol00000okK10?nf`@0:0?nf`@8000004`3o]/45
000001<0okK10`00000C0?nf`@030000003o]/40okK100P0okK10oooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02?ooool01000003oooooooooool0
000:ooooo`002Oooool00ol0003oooooooooo`06ooooo`030000oooooooooooo01cooooo1@3o]/43
0000oaP0okK100?o003o0?nf`@3o]/40303o]/400`000?oo003oo`00o`0L0?nf`@03o`00o`3o]/40
okK101D0okK19oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00<00000
ooooooooool02Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000
ooooo`3o]/402@3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK10140okK10P00000K
0?nf`@<000004@3o]/400`000000okK10?nf`@080?nf`@;ooooo00<00000ooooooooool02Oooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00@00000oooooooooooo00002_oo
ool000Wooooo00?o0000ooooooooool01_ooool00`000?ooooooooooo`0Kooooo`@0okK10P000?lI
0?nf`@<0003o3?l00?l20?nf`@030000o`3o]/40okK100?o003o6@3o]/400ol00?l0okK10?nf`@0E
0?nf`BOooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool01oooool00`00003oooooooooo`07ooooo`0300000?ooool0
okK100T0okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@0?0?nf`@<00000803o]/40
0`000000okK10?nf`@0?0?nf`@030000003o]/40okK100L0okK10oooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?ooool01000003oooooooooool0
000:ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000oooooooooooo01cooooo0P3o]/42
0000oaH0okK10P000?l01Ol00?l0003o0000o`3o]/7o003o00d0okK11Ol00?l30?nf`@;o003o603o
]/400ol00?l0okK10?nf`@0E0?nf`BKooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`07ooooo`0300000?ooool0okK100P0okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf
`@0>0?nf`@800000903o]/4200000100okK100?o00000?nf`@3o]/401`3o]/42ooooo`0300000?oo
oooooooo00Wooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08ooooo`0300000?oo
oooo000000[ooooo0009ooooo`03o`000?oooooooooo00Gooooo00<0003oooooooooool06oooool3
0000oaD0okK10`000?l60?nf`@03o`00o`3o]/40okK100`0okK100Co003o0?nf`@3o]/40okK11?l0
0?l00`3o]/7o003oo`00o`0F0?nf`@03o`00o`3o]/40okK101D0okK19_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00<00000ooooo`3o]/40203o]/400ol00000okK10?nf
`@090?nf`@030000003o]/40okK100d0okK10P00000X0?nf`@8000003`3o]/400`000000okK10?nf
`@060?nf`@?ooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo00Sooooo00?o0000ooooool000002_ooool000Wooooo00?o0000ooooooooool01Oooool0
0`000?ooooooooooo`0Jooooo`030000o`3o]/40okK101<0okK10`000?l90?nf`@03o`00o`3o]/40
okK100`0okK100<0003o0?nf`@3o]/401@3o]/45o`00oa@0okK100?o003o0?nf`@3o]/405P3o]/4U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`08
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01oooool00`00003ooooo0?nf`@08
0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/403@3o]/400`000000okK10?nf`@0Z
0?nf`@8000003P3o]/400`000000okK10?nf`@060?nf`@?ooooo00<00000ooooooooool02?ooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0Iooooo`030000o`3o]/40okK1
0180okK10P000?l;0?nf`@03o`00o`3o]/40okK100d0okK100<0003o0?nf`@3o]/40203o]/43o`00
oa<0okK100?o003o0?nf`@3o]/405`3o]/4Tooooo`03o`000?oooooooooo00oooooo00Go0000oooo
oooooooooooo0000000:ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01oooool0
0`00003ooooo0?nf`@080?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40303o]/42
000002l0okK100<000000?nf`@3o]/40303o]/400`000000okK10?nf`@060?nf`@;ooooo00<00000
ooooooooool02Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0Hoooo
o`030000o`3o]/40okK10140okK10P000?l=0?nf`@03o`00o`3o]/40okK100`0okK100<0003o0?nf
`@3o]/40303o]/42o`00oa40okK100?o003o0?nf`@3o]/405`3o]/4Tooooo`03o`000?oooooooooo
00oooooo00Go0000oooooooooooooooo00000009ooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool01oooool00`00003ooooo0?nf`@070?nf`@03o`0000000000okK100T0okK100<00000
0?nf`@3o]/402`3o]/4200000380okK100?o00000?nf`@3o]/40303o]/400`000000okK10?nf`@05
0?nf`@?ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`0300000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`00
0?ooooooooooo`0Fooooo`030000ool00?oooooo0100okK100<0003oo`00o`000?l03`3o]/400ol0
0?l0okK10?nf`@0<0?nf`@030000o`3o]/40okK100`0okK11?l00?l?0?nf`@03o`00o`3o]/40okK1
01P0okK18oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooo`0000002Oooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00?o0000ooooo`3o]/401`3o]/40
0`000000okK10?nf`@080?nf`@03o`00003o]/40okK100/0okK100?o00000?nf`@3o]/40<P3o]/40
0`000000okK10?nf`@0<0?nf`@030000003o]/40okK100H0okK10_ooool00`00003oooooooooo`08
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000oooooooooooo01Gooooo00<0003ooooo
ooooool03`3o]/420000oa80okK100?o003o0?nf`@3o]/40303o]/400`000?l0okK10?nf`@0>0?nf
`@04o`00o`3o]/7o003oo`00o`d0okK100?o003o0?nf`@3o]/40603o]/4Sooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooool000002_ooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo00Sooooo00<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@090?nf`@030000003o
]/40okK100X0okK100<000000?nf`@3o]/40=03o]/400`000000okK10?nf`@0<0?nf`@030000003o
]/40okK100D0okK10oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05
ooooo`030000oooooooooooo01Cooooo00@0003ooooooooooooooooo3@3o]/420000oa@0okK100?o
003o0?nf`@3o]/40303o]/400`000?l0okK10?nf`@0?0?nf`@03o`00o`3o]/40okK100;o003o2`3o
]/400ol00?l0okK10?nf`@0I0?nf`B;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
o`000009ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01oooool00`00003ooooo
0?nf`@070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/402P3o]/400`000000okK1
0?nf`@0f0?nf`@030000003o]/40okK100/0okK100<000000?nf`@3o]/401P3o]/42ooooo`030000
0?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Gooooo00<0003oooooooooool04ooo
ool010000?ooooooooooooooool=0?nf`@030000o`3o]/40okK100`0okK10ol000050?nf`@03o`00
o`3o]/40okK100/0okK100<0003o0?nf`@3o]/404@3o]/42o`00o`80okK100?o003o0?nf`@3o]/40
2@3o]/400ol00?l0okK10?nf`@020?nf`@?o0000503o]/4Qooooo`03o`000?oooooooooo00oooooo
00?o0000ooooo`0000002_ooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00<00000ooooo`3o]/401`3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100X0okK1
00<000000?nf`@3o]/40503o]/4<000001P0okK100?o00000?nf`@3o]/402`3o]/400`000000okK1
0?nf`@060?nf`@;ooooo00<00000ooooooooool01oooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Ooo
ool00`000?ooooooooooo`0Booooo`04o`00ooooooooooooooooo``0okK10P000?l>0?nf`@Go0000
103o]/400ol00?l0okK10?nf`@0;0?nf`@030000o`3o]/40okK101<0okK100?o003o0?nf`@3o]/40
0ol00?l80?nf`@04o`00o`3o]/40okK10?nf`@Go00004`3o]/4Qooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Ko
oooo00<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100X0
okK100<000000?nf`@3o]/404P3o]/43000000`0okK10`00000F0?nf`@030000003o]/40okK100X0
okK100<000000?nf`@3o]/401P3o]/42ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo00Gooooo00<0003oooooooooool04Oooool00`000?ooooooooooo`02ooooo`/0okK1
00<0003o0?nf`@3o]/403P3o]/45o`0000@0okK100?o003o0?nf`@3o]/402`3o]/400`000?l0okK1
0?nf`@0C0?nf`@03o`00o`3o]/40okK100<0okK100?o003o0?nf`@3o]/401@3o]/401?l00?l0okK1
0?nf`@3o]/45o`0001@0okK18?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[o
oooo00<00000ooooooooool01_ooool00`00003oooooooooo`06ooooo`0300000?ooool0okK100L0
okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK10140
okK10P00000B0?nf`@@000004`3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100H0
okK10_ooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000
oooooooooooo013ooooo00<0003oooooooooool00_ooool;0?nf`@030000o`3o]/40okK100l0okK1
1Ol000040?nf`@03o`00o`3o]/40okK100/0okK100<0003o0?nf`@3o]/40503o]/400ol00?l0okK1
0?nf`@030?nf`@03o`00o`3o]/40okK100@0okK100Co003o0?nf`@3o]/40okK11Ol0000D0?nf`B3o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool01oooool00`000000okK10?nf`@060?nf`@03o`00003o]/40okK100P0
okK100?o00000?nf`@3o]/402@3o]/400`000000okK10?nf`@0@0?nf`@;o0000603o]/4200000180
okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@060?nf`@;ooooo00<00000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0?ooooo`030000
oooooooooooo00?ooooo2P3o]/400`000?l0okK10?nf`@0A0?nf`@?o00001@3o]/400ol00?l0okK1
0?nf`@0:0?nf`@040000o`3o]/40okK10?nf`@L0oooo3P3o]/400ol00?l0okK10?nf`@030?nf`@03
o`00o`3o]/40okK10080okK100?o003o0?nf`@3o]/400`3o]/43o`0001D0okK18?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`07ooooo`030000003o]/40okK100H0okK100<000000?nf`@3o]/40203o]/400`000000
okK10?nf`@080?nf`@03o`00003o]/40okK10100okK100<000000?nf`@3o]/400`3o]/470?oooa00
okK100<000000?nf`@3o]/403`3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100H0
okK10_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`030000
oooooooooooo00kooooo00<0003oooooooooool01?ooool90?nf`@030000o`3o]/40okK101X0okK1
00?o003o0?nf`@3o]/402P3o]/400`000?l0oooo0?ooo`0<0?ooo`/0okK100?o003o0?nf`@3o]/40
0`3o]/401Ol00?l0okK10?nf`@3o]/7o003o01h0okK17oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Wooooo00<00000ooooooooool01_ooool00`00003oooooooooo`06ooooo`03
00000?ooool0okK100L0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@090?nf`@03
0000003o]/40okK100h0okK10P0000020?nf`@l0oooo3@3o]/400`000000okK10?nf`@0>0?nf`@03
0000003o]/40okK100T0okK100<000000?nf`@3o]/401`3o]/400oooool00000ooooo`08ooooo`03
00000?oooooooooo00Oooooo00<00000ooooooooool01oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`05ooooo`030000oooooooooooo00gooooo00?o003oooooooooool0
1?ooool80?nf`@03o`00o`000?l0okK101`0okK100?o003o0?nf`@3o]/40203o]/420?ooo`030000
o`3oool0oooo00h0oooo2P3o]/400ol00?l0okK10?nf`@030?nf`@04o`00o`3o]/40okK1o`00oah0
okK17oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00<00000oooooooo
ool01_ooool00`00003oooooooooo`07ooooo`030000003o]/40okK100H0okK100<000000?nf`@3o
]/40203o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o
]/404`3oool<0?nf`@03o`00003o]/40okK100h0okK100<000000?nf`@3o]/402@3o]/400`000000
okK10?nf`@060?nf`@;ooooo00<00000ooooooooool01oooool00`00003oooooooooo`07ooooo`03
00000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
1Oooool00`000?ooooooooooo`0=ooooo`030000oooooooooooo00Cooooo203o]/400`000?l0okK1
0?nf`@0L0?nf`@03o`00o`3o]/40okK100H0okK1103oool00`000?l0oooo0?ooo`0@0?ooo`P0okK1
00?o003o0?nf`@3o]/400`3o]/401?l00?l0okK10?nf`Ol00?lN0?nf`Aoooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool01_ooool00`00003ooooo0?nf`@070?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o
]/40203o]/400`000000okK10?nf`@0=0?nf`@03o`0000000000okK101L0oooo2`3o]/400`000000
okK10?nf`@0=0?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/401P3o]/42ooooo`03
00000?oooooooooo00Oooooo00<00000ooooooooool01oooool00`00003oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Gooooo00<0003oooooooooool0
3?ooool00`000?ooooooooooo`05ooooo`L0okK100<0003o0?nf`@3o]/407@3o]/400ol00?l0okK1
0?nf`@050?nf`@D0oooo00<0003o0?ooo`3oool04P3oool70?nf`@03o`00o`3o]/40okK100<0okK1
00?o003o0?nf`Ol00?l07`3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
2?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooo`3o]/40
1`3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40
303o]/400`000000okK10?nf`@0J0?ooo`T0okK100<000000?nf`@3o]/403@3o]/400`000000okK1
0?nf`@090?nf`@030000003o]/40okK100L0okK100?ooooo00000?ooool02?ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool01Oooool00`000?ooooooooooo`0;ooooo`030000oooooooooooo00Gooooo1`3o
]/400`000?l0okK10?nf`@0O0?nf`@03o`00o`3o]/40okK100<0okK11P3oool00`000?l0oooo0?oo
o`0C0?ooo`L0okK100?o003o0?nf`@3o]/400`3o]/42o`00oa80okK10ol0000:0?nf`Akooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool01Oooool00`00003ooooo0?nf`@070?nf`@030000003o]/40okK100L0okK100<0
00000?nf`@3o]/40203o]/400`000000okK10?nf`@0<0?nf`@030000003o]/40okK101`0oooo2@3o
]/400`000000okK10?nf`@0=0?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/401P3o
]/42ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Gooooo00<0003o
ooooooooool02oooool00`000?ooooooooooo`05ooooo`H0okK100<0003o0?nf`@3o]/40803o]/40
0ol00?l0okK10?nf`@020?nf`@L0oooo00<0003o0?ooo`3oool0503oool70?nf`@03o`00o`3o]/40
okK100<0okK100?o003o0?nf`@3o]/403`3o]/45o`0000T0okK17_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`0300000?ooool0okK100L0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@08
0?nf`@03o`0000000000okK100`0okK100<000000?nf`@3o]/407P3oool90?nf`@03o`00003o]/40
okK100d0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@060?nf`@;ooooo00<00000
ooooooooool01_ooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00`000?ooooooooooo`0:oooo
o`030000oooooooooooo00Kooooo1@3o]/400`000?l0okK10?nf`@0Q0?nf`@04o`00o`3o]/40okK1
0?nf`@P0oooo00<0003o0?ooo`3oool05@3oool70?nf`@03o`00o`3o]/40okK10080okK10_l00?l@
0?nf`@Go00002@3o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooo`3o]/401P3o]/40
0ol00000okK10?nf`@070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40303o]/40
0ol00000okK10?ooo`0O0?ooo`P0okK100<000000?nf`@3o]/403@3o]/400`000000okK10?nf`@08
0?nf`@030000003o]/40okK100H0okK10_ooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo00Oooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`05ooooo`030000oooooooooooo00[ooooo00<0003oooooooooool01_ooool50?nf
`@030000o`3o]/40okK10240okK100Co003o0?nf`@3o]/40okK1203oool00`000?l0oooo0?ooo`0E
0?ooo`L0okK100?o003o0?nf`@3o]/400P3o]/400ol00?l0okK1o`00o`0?0?nf`@Go00002@3o]/4N
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo00Kooooo00<00000ooooo`3o]/401P3o]/400`000000okK10?nf`@07
0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40303o]/400`000000okK10?ooo`0O
0?ooo`P0okK100<000000?nf`@3o]/403@3o]/400`000000okK10?nf`@080?nf`@030000003o]/40
okK100H0okK10_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05oooo
o`030000oooooooooooo00Wooooo00<0003oooooooooool01oooool40?nf`@030000o`3o]/40okK1
0280okK100?o003o0?nf`@3oool02@3oool00`000?l0oooo0?ooo`0F0?ooo`L0okK100Co003o0?nf
`@3o]/7o003o0`3o]/400ol00?l0okK10?nf`@0=0?nf`@?o00002P3o]/4Nooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo00Kooooo00<00000ooooooooool01`3o]/400`000000okK10?nf`@060?nf`@030000003o]/40
okK100P0okK100<000000?nf`@3o]/40303o]/400`000000oooo0?ooo`0Q0?ooo`P0okK100<00000
0?nf`@3o]/40303o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100D0okK10_ooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`06ooooo`030000oooooooooooo
00Oooooo00<0003oooooooooool02?ooool30?nf`@030000o`3o]/40okK102@0okK100?o003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`0G0?ooo`L0okK100?o003o0?nf`Ol00?l0103o]/400ol0
0?l0okK10?nf`@0J0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06oooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00003oooooooooo`070?nf
`@030000003o]/40okK100H0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@0;0?nf
`@030000003oool0oooo02<0oooo203o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK1
00T0okK100<000000?nf`@3o]/401P3o]/400oooool00000ooooo`07ooooo`0300000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`06ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool02?ooool30?nf`@03
0000o`3o]/40okK102D0okK100?o003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0G0?ooo`P0
okK10_l00?l50?nf`@03o`00o`3o]/40okK101T0okK17Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00003oooooooooo`06ooooo`03
00000?ooool0okK100L0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@080?nf`@03
0000003o]/40okK100/0okK100<000000?ooo`3oool08`3oool80?nf`@030000003o]/40okK100/0
okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@060?nf`@03ooooo`00003ooooo00Oo
oooo00<00000ooooooooool01oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00Kooooo00<0003oooooooooool01_ooool00`000?oooooo
ooooo`08ooooo`<0okK100<0003o0?nf`@3o]/40903o]/400`3ooooo003o0?ooo`090?ooo`030000
o`3oool0oooo01P0oooo1`3o]/42o`00o`D0okK100?o003o0?nf`@3o]/406@3o]/4Mooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo00Kooooo00<00000ooooo`3o]/401P3o]/400`000000okK10?nf`@060?nf`@030000
003o]/40okK100P0okK100<000000?nf`@3o]/402`3o]/400`000000oooo0?ooo`0U0?ooo`L0okK1
00<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100H0okK1
00?ooooo00000?ooool01oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01_ooool00`000?oooooooooo
o`05ooooo`030000oooooooooooo00Wooooo0P3o]/400`000?l0okK10?nf`@0U0?nf`@030?ooool0
0?l0oooo00T0oooo00<0003o0?ooo`3oool0603oool70?nf`@;o003o1P3o]/400ol00?l0okK10?nf
`@0H0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`0300000?oo
oooooooo00Kooooo00<00000ooooooooool01_ooool00`00003ooooo0?nf`@060?nf`@030000003o
]/40okK100H0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@0;0?nf`@030000003o
ool0oooo02D0oooo1`3o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK100T0okK100<0
00000?nf`@3o]/401P3o]/400oooool00000ooooo`07ooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`07
ooooo`030000oooooooooooo00Cooooo00<0003oooooooooool02Oooool00`3o]/40003o0?nf`@0V
0?nf`@80oooo00?o003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0H0?ooo`H0okK10_l00?l7
0?nf`@03o`00o`3o]/40okK101L0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Kooooo00<00000ooooooooool01_ooool00`00003oooooooooo`06ooooo`03o`000?ooool0
okK100H0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@080?nf`@030000003o]/40
okK100/0okK100<000000?ooo`3oool09P3oool60?nf`@030000003o]/40okK100/0okK100<00000
0?nf`@3o]/402@3o]/400`000000okK10?nf`@060?nf`@03ooooo`00003ooooo00Oooooo00<00000
ooooooooool01oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Oooooo00<0003oooooooooool00oooool00`000?ooooooooooo`0:oooo
o`030?nf`@000?l0okK102H0okK10`3oool00ol00?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
01P0oooo1P3o]/42o`00o`L0okK100?o003o0?nf`@3o]/405`3o]/4Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo
00Kooooo00<00000ooooo`3o]/401P3o]/400`000000okK10?nf`@060?nf`@030000003o]/40okK1
00P0okK100<000000?nf`@3o]/402P3o]/400`000000oooo0?ooo`0W0?ooo`H0okK100<000000?nf
`@3o]/402`3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100H0okK100?ooooo0000
0?ooool01oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool01oooool00`000?ooooooooooo`03ooooo`03
o`00oooooooooooo00[ooooo00<0003o0?nf`@3o]/409P3o]/430?ooo`03o`00o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool0603oool60?nf`@03o`00o`3o]/7o003o00L0okK100?o003o0?nf`@3o
]/405P3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00`00003o
ooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01P3o]/400`000000
okK10?nf`@070?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/402`3o]/400`000000
oooo0?ooo`0W0?ooo`H0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@080?nf`@03
0000003o]/40okK100L0okK100<00000ooooooooool01oooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
1oooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00[ooooo00<0003o0?nf`@3o]/40
9P3o]/430?ooo`03o`00o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0603oool60?nf`@03o`00
o`3o]/7o003o00L0okK100?o003o0?nf`@3o]/405P3o]/4Kooooo`03o`00oooooooo0000017ooooo
00?o0000ooooooooool01Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool01P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100L0okK1
00<000000?nf`@3o]/402`3o]/400`000000oooo0?ooo`0W0?ooo`H0okK100<000000?nf`@3o]/40
2`3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100L0okK100<00000ooooooooool0
1oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool02?ooool01@000?ooooooooooooooool0003o00cooooo
00<0003o0?nf`@3o]/409P3o]/450?ooo`03o`00o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
6@3oool40?nf`@05o`00o`3o]/40okK10?nf`Ol00?l01`3o]/400ol00?l0okK10?nf`@0E0?nf`A_o
oooo00?o003oooooool000004Oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool01_ooool00`00003oooooooooo`060?nf`@030000003o]/40okK100L0
okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@0;0?nf`@030000003oool0oooo02P0
oooo1@3o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o
]/401`3o]/400`00003oooooooooo`07ooooo`0300000?oooooooooo00Kooooo00<00000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`050000
ooooooooooooooooo`000?l02oooool00`000?oooooo0?nf`@0W0?nf`@D0oooo00?o003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0I0?ooo`@0okK100Go003o0?nf`@3o]/40okK1o`00o`070?nf
`@03o`00o`3o]/40okK101D0okK16_ooool01?l00?ooooooooooool0000Aooooo`03o`000?oooooo
oooo00Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo00H0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@070?nf`@030000003o]/40
okK100/0okK100<000000?ooo`3oool0:03oool50?nf`@030000003o]/40okK100/0okK100<00000
0?nf`@3o]/40203o]/400`000000okK10?nf`@070?nf`@0300000?oooooooooo00Kooooo00<00000
ooooooooool01oooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Wooooo00@0003oooooooooool0003o2oooool00`000?l0okK10?nf`@0W
0?nf`@D0oooo00?o003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0I0?ooo`@0okK100Go003o
0?nf`@3o]/40okK1o`00o`080?nf`@03o`00o`3o]/40okK101@0okK16_ooool01?l00?oooooooooo
ool0000Aooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool01_ooool00`00003ooooo
ooooo`06ooooo`0300000?ooool0okK100H0okK100<000000?nf`@3o]/401`3o]/400`000000okK1
0?nf`@070?nf`@030000003o]/40okK100/0okK100<000000?ooo`3oool0:03oool50?nf`@030000
003o]/40okK100/0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@070?nf`@030000
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00`00003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Wooooo00<0003oooooo`000?l02ooo
ool00`000?oooooo0?nf`@0X0?nf`@H0oooo00?o003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0I0?ooo`<0okK100?o003o0?nf`@3o]/400`3o]/400ol00?l0okK10?nf`@050?nf`@03o`00o`3o
]/40okK101@0okK16Oooool01Ol00?oooooooooooooooooo0000017ooooo00?o0000ooooooooool0
1Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooo`3o]/40
1P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100L0okK100?o00000?nf`@3o]/40
2`3o]/400`000000oooo0?ooo`0X0?ooo`D0okK100<000000?nf`@3o]/402`3o]/400`000000okK1
0?nf`@080?nf`@030000003o]/40okK100L0okK100<00000ooooooooool01_ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool02Oooool00`000?oooooo0000o`0;ooooo`030000ooooool0okK102P0okK11P3o
ool00ol00?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01T0oooo0`3o]/400ol00?l0okK10?nf
`@030?nf`@03o`00o`3o]/40okK100D0okK100?o003o0?nf`@3o]/40503o]/4Iooooo`05o`00oooo
ooooooooooooool000004Oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool01_ooool00`00003ooooo0?nf`@060?nf`@030000003o]/40okK100L0okK1
00<000000?nf`@3o]/401`3o]/400ol00000okK10?nf`@0;0?nf`@030000003oool0oooo02P0oooo
1@3o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40
1`3o]/400`00003oooooooooo`06ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0:ooooo`80003o2_oo
ool00`000?ooooooooooo`0Y0?nf`@L0oooo00?o003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0H0?ooo`80okK100?o003o0?nf`@3o]/40103o]/400ol00?l0okK10?nf`@060?nf`@03o`00o`3o
]/40okK101<0okK16?ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<0
0000ooooo`3o]/401P3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100L0okK100<0
00000?nf`@3o]/402`3o]/400`000000oooo0?ooo`0X0?ooo`@0okK100<000000?nf`@3o]/402`3o
]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100L0okK100<00000ooooooooool01_oo
ool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool02_ooool00`000?ooooooooooo`09ooooo`040000oooooooo
ooooooooobP0okK11`3oool00ol00?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01P0oooo0P3o
]/400ol00?l0okK10?nf`@050?nf`@03o`00o`3o]/40okK100D0okK100?o003o0?nf`@3o]/404`3o
]/4Hooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`05ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`060?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf
`@0;0?nf`@030000003oool0oooo02P0oooo0`3o]/400`000000okK10?nf`@0;0?nf`@0300000?l0
0000okK100T0okK100<000000?nf`@3o]/401`3o]/400ol0003oooooooooo`06ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0:ooooo`80003o2_ooool010000?oooooooooooooooolX0?nf`@P0oooo00?o
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0G0?ooo`030?nf`Ol00?l0okK100L0okK100?o
003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@0B0?nf`AOooooo00?o003oooooooooool00ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`06ooooo`0300000?oooooooooo00H0okK100<000000?nf`@3o]/401`3o
]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100/0okK100<000000?ooo`3oool0:03o
ool30?nf`@030000003o]/40okK100/0okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf
`@070?nf`@0300000?oooooooooo00Kooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00[ooooo0P000?l:
ooooo`040000ooooooooooooooooobT0okK11`3oool00ol00?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo01H0oooo0P3o]/400ol00?l0okK10?nf`@060?nf`@03o`00o`3o]/40okK100H0okK100?o
003o0?nf`@3o]/404P3o]/4Gooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`060?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/401`3o
]/400`000000okK10?nf`@0;0?nf`@030000003oool0oooo02L0oooo0`3o]/400`000000okK10?nf
`@0<0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40203o]/400`00003ooooooooo
o`06ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0:ooooo`030000ooooool0003o00Sooooo00<0003o
ooooooooool00_oooolY0?nf`@P0oooo00?o003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0E
0?ooo`030?nf`Ol00?l0okK100P0okK100?o003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@0B
0?nf`AKooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo00H0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@080?nf`@030000003o]/40
okK100X0okK100<000000?ooo`3oool09`3oool30?nf`@030000003o]/40okK100/0okK100<00000
0?nf`@3o]/402@3o]/400`000000okK10?nf`@070?nf`@030000003o]/7ooooo00Kooooo00<00000
ooooooooool01oooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00Wooooo00D0003ooooooooooooooooo0000o`07ooooo`030000oooooooo
oooo00;ooooo:@3o]/490?ooo`03o`00o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05@3oool0
0ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/404@3o]/4F
ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05
ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00003oooooooooo`06
0?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@0;
0?nf`@030000003oool0oooo02H0oooo0P3o]/400ol00000okK10?nf`@0<0?nf`@030000003o]/40
okK100P0okK100<000000?nf`@3o]/40203o]/400`000000okK1ooooo`06ooooo`0300000?oooooo
oooo00Oooooo00<00000ooooooooool01oooool00`00003oooooo`00000:ooooo`002Oooool00ol0
003oooooooooo`09ooooo`050000ooooooooooooooooo`000?l01oooool00`000?ooooooooooo`02
ooooobT0okK12@3oool00ol00?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01D0oooo00?o003o
0?nf`@3o]/402@3o]/400ol00?l0okK10?nf`@060?nf`@03o`00o`3o]/40okK10140okK15Oooool0
0ol00?ooooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool0
0`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01P3o]/40
0`000000okK10?nf`@070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/402`3o]/40
0`000000oooo0?ooo`0V0?ooo`030?nf`@000000okK100h0okK100<000000?nf`@3o]/40203o]/40
0`000000okK10?nf`@080?nf`@030000003o]/7ooooo00Kooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`07ooooo`0300000?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo
00Wooooo00<0003oooooooooool00_ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo
00?ooooo:P3o]/490?ooo`03o`00o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04`3oool00ol0
0?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/404@3o]/4Doooo
o`03o`00oooooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05oooo
o`0300000?oooooooooo00Oooooo00<00000ooooooooool01_ooool00`00003ooooo0?nf`@060?nf
`@030000003o]/40okK100L0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@0;0?nf
`@030000003oool0oooo02@0oooo00<0okK10000003o]/403P3o]/400`000000okK10?nf`@080?nf
`@030000003o]/40okK100P0okK100<000000?nf`@3o]/401_ooool00`00003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00@00000oooooooooooo00002_ooool000Wooooo00?o0000oooo
ooooool02Oooool00`000?ooooooooooo`03ooooo`030000oooooooooooo00;ooooo00<0003ooooo
ooooool00ooooolZ0?nf`@T0oooo00?o003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B0?oo
o`03o`00o`3o]/40okK100/0okK100?o003o0?nf`@3o]/401P3o]/400ol00?l0okK10?nf`@0A0?nf
`ACooooo00?o003oooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`06ooooo`0300000?ooool0okK1
00H0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK1
00/0okK100<0oooo0000003oool0903oool00`000000okK10?nf`@0=0?nf`@030000003o]/40okK1
00T0okK100<000000?nf`@3o]/401`3o]/4010000000okK10?nf`@3o]/46ooooo`03o`000?oooooo
oooo00Oooooo00<00000ooooooooool01oooool01000003oooooooooool0000:ooooo`002Oooool0
0ol0003oooooooooo`09ooooo`030000oooooooooooo00Cooooo00D0003ooooooooooooooooo0000
o`05ooooob/0okK12@3oool00ol00?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00?o
003o0?nf`@3o]/402`3o]/400ol00?l0okK10?nf`@060?nf`@03o`00o`3o]/40okK10140okK14ooo
ool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Ooo
ool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Kooooo00<00000ooooo`3o]/401P3o
]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40303o
]/400`3ooooo00000?ooo`0R0?ooo`030000003o]/40okK100h0okK100<000000?nf`@3o]/402@3o
]/400`000000okK10?nf`@070?nf`@040000003o]/40okK10?nf`@Kooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`07ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`00
0?oooooooooo00Sooooo00<0003oooooooooool01_ooool00`000?oooooo0000o`07ooooob`0okK1
1`3oool00ol00?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0100oooo00?o003o0?nf`@3o]/40
303o]/400ol00?l0okK10?nf`@060?nf`@03o`00o`3o]/40okK10140okK14_ooool00ol00?oooooo
ooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01P3o]/400`000000okK1
0?nf`@070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/403@3o]/400`000000oooo
0?ooo`0P0?ooo`030000003o]/40okK100h0okK100<000000?nf`@3o]/402@3o]/400`000000okK1
0?nf`@070?nf`@030000003o]/40okK10080okK11_ooool00`00003oooooooooo`06ooooo`030000
0?oooooooooo00Sooooo00@00000oooooooooooo00002_ooool000Wooooo00?o0000ooooooooool0
2?ooool00`000?ooooooooooo`07ooooo`80003o1oooool/0?nf`@P0oooo00?o003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0?0?ooo`03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/40
1`3o]/400ol00?l0okK10?nf`@0?0?nf`A?ooooo00?o003oooooooooool02?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00`00003ooooo
ooooo`06ooooo`0300000?oooooooooo00L0okK100<000000?nf`@3o]/401`3o]/400`000000okK1
0?nf`@080?nf`@030000003o]/40okK100d0okK100<000000?ooo`3oool07P3oool00`000000okK1
0?nf`@0?0?nf`@030000003o]/40okK100T0okK100?o00000?nf`@3o]/401`3o]/4010000000okK1
0?nf`@3o]/46ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01oooool01@00003o
oooooooooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo00Sooooo00<0003ooooooooo
ool01oooool00ol00?l0003oooooo`06ooooobd0okK1203oool2o`00o`D0oooo00<0003o0?ooo`3o
ool0303oool2o`00oa00okK100?o003o0?nf`@3o]/401`3o]/400ol00?l0okK10?nf`@0?0?nf`A7o
oooo0_l00?l;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003o
ooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01`3o]/400`000000
okK10?nf`@070?nf`@030000003o]/40okK100P0okK100<00000o`00003o]/403P3o]/400`00003o
00000000000J0?ooo`80000000?o00000?nf`@3o]/403P3o]/42000000/0okK100<000000?nf`@3o
]/401`3o]/400`000000okK10?nf`@020?nf`@Kooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`08ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o0000oooooooo
ool02?ooool00ol00?ooooooooooo`08ooooo`030000oooooooooooo00Gooooo903o]/43o`0000L0
okK12@3oool00ol00?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00?o003o0?ooo`3o
]/40403o]/400ol00?l0okK10?nf`@070?nf`@03o`00o`3o]/40okK100l0okK14?ooool00ol00?oo
ooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003o
ooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01`3o]/400`000000
okK10?nf`@070?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/403P3o]/420?ooo`03
0000003oool0oooo01D0oooo0P0000020?oooa00okK100<000000?nf`@3o]/402P3o]/400`000000
okK10?nf`@080?nf`@030000003o]/40okK10080okK11_ooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo00Sooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003o
ooooooooo`08ooooo`030000oooooooooooo00Sooooo0P000?l6ooooob<0okK11Ol000070?nf`@T0
oooo00?o003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`03o`00o`3o]/40okK10100
okK100?o003o0?nf`@3o]/401`3o]/400ol00?l0okK10?nf`@0?0?nf`@oooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00<00000oooooooo
ool01_ooool00`00003oooooooooo`06ooooo`0300000?ooool0okK100H0okK100<000000?nf`@3o
]/40203o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100h0okK10P3oool00`000000
oooo0?ooo`0B0?ooo`8000000`3oool@0?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o
]/40203o]/400`000000okK10?nf`@030?nf`@Gooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`08ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool02?ooool00`000?ooooooooooo`08ooooo`030000ooooool0003o00Kooooo
8P3o]/45o`0000P0okK12@3oool00ol00?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo
00?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK100h0okK1
3_ooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
1`3o]/400ol00000okK10?nf`@070?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/40
3`3o]/420?ooo`0300000?l00000000000l0oooo00?o00000000003oool00P3ooolA0?nf`@030000
003o]/40okK100X0okK100?o00000?nf`@3o]/40203o]/400ol00000okK10?nf`@040?nf`@Cooooo
00?o0000ooooooooool01oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02?ooool00`000?oooooooooo
o`08ooooo`030000oooooooooooo0080003o1?oooolR0?nf`@Go00002P3o]/480?ooo`03o`00o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`3o]/7o003o0?nf`@0C0?nf`@03o`00o`3o
]/40okK100P0okK100?o003o0?nf`@3o]/403@3o]/4=ooooo`;o003o4?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`06ooooo`0300000?oooooooooo00L0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf
`@090?nf`@030000003o]/40okK10140okK10`3oool700000080oooo1`0000020?oooa<0okK100<0
00000?nf`@3o]/402P3o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100<0okK11?oo
ool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`08ooooo`03o`00oooooooo
oooo00Sooooo00<0003oooooooooool00_ooool010000?oooooooooooooooolS0?nf`@?o00003@3o
]/470?ooo`05o`00o`3oool0oooo0?ooo`000?l01@3oool20?nf`@03o`00o`3o]/40okK101<0okK1
00?o003o0?nf`@3o]/40203o]/400ol00?l0okK10?nf`@0=0?nf`@cooooo00?o003oooooooooool0
4?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo00L0okK100<000000?nf`@3o]/40
203o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK10180okK1203oool2000000L0oooo
503o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40
0`3o]/44ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Sooooo00<0
003oooooooooool02?ooool00`000?ooooooooooo`03ooooo`040000ooooooooooooooooob`0okK1
0ol000050?nf`@H0oooo0_l00?l20?ooo`030000o`3oool0oooo0080okK10_l00?lF0?nf`@03o`00
o`3o]/40okK100P0okK100?o003o0?nf`@3o]/403@3o]/4;ooooo`03o`00oooooooooooo017ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool01_ooool00`00003oooooooooo`070?nf`@030000003o]/40okK100L0okK1
00<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0C0?nf`@d0oooo5@3o]/400`000000okK1
0?nf`@0;0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40103o]/43ooooo`030000
0?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Sooooo00<0003oooooooooool02?oo
ool00`000?ooooooooooo`04ooooo`030000oooooooooooo02/0okK11Ol000080?nf`@@0oooo00Co
003o0?nf`@3o]/40003o0P3o]/400ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK100P0okK1
00?o003o0?nf`@3o]/40303o]/4;ooooo`03o`00oooooooooooo01;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
1_ooool00`00003oooooooooo`070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40
2P3o]/400ol0000000000?nf`@0F0?nf`@D0oooo5`3o]/42000000`0okK10P00000:0?nf`@030000
003o]/40okK100@0okK11?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`09ooooo`030000oooooooooooo00Oooooo00<0003oooooooooool01Oooool00`000?oooooo0?nf
`@0Z0?nf`@Go00003@3o]/401Ol00?l0okK10?nf`@000?oo003o01T0okK100?o003o0?nf`@3o]/40
203o]/400ol00?l0okK10?nf`@0<0?nf`@_ooooo00?o003oooooooooool04_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`06ooooo`0300000?oooooooooo00L0okK100<000000?nf`@3o]/40203o]/400`000000okK1
0?nf`@0<0?nf`@030000003o]/40okK102h0okK10P00000=0?nf`@030000003o]/40okK100T0okK1
00<000000?nf`@3o]/401@3o]/44ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
2Oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00Wooooo00<0003oooooooooool01oooool00`000?ooooooooooo`06ooooo`03o`00o`00
0?l0okK102T0okK11Ol0000>0?nf`@?o003o00<0003o0?nf`@3o]/405`3o]/400ol00?l0okK10?nf
`@080?nf`@03o`00o`3o]/40okK100`0okK12Oooool2o`00oaGooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01_oo
ool00`00003oooooooooo`070?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40303o
]/400`000000okK10?nf`@0/0?nf`@030000003o]/40okK100`0okK100<000000?nf`@3o]/402@3o
]/400ol00000okK10?nf`@060?nf`@?ooooo00<00000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool02Oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo00Sooooo0P000?lY
0?nf`@?o00003@3o]/42o`00o`050?nf`Ol00?oo003o0?nf`@000?l0603o]/400ol00?l0okK10?nf
`@080?nf`@03o`00o`3o]/40okK100/0okK12Oooool00ol00?ooooooooooo`0Eooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02?ooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo00Oooooo00?o0000ooooo`3o]/401`3o]/400`000000okK10?nf`@080?nf`@03o`00003o
]/40okK100`0okK100?o00000?nf`@3o]/40:03o]/4200000003o`00003o]/40okK100`0okK100?o
00000?nf`@3o]/402@3o]/400`000000okK10?nf`@060?nf`@;ooooo00<00000o`000?ooool02?oo
ool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`07ooooo`030000oooooooo
oooo00Wooooo00<0okK10000o`000?l0=P3o]/400ol00?l0okK10?nf`@030?nf`@;o003o00<0003o
0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK100/0okK11oooool2
o`00oaGooooo0P000?l00ooooooo0000ooooo`0@ooooo`03o`000?oooooooooo00Sooooo00<00000
ooooooooool01oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00L0okK100<00000
0?nf`@3o]/40203o]/400`000000okK10?nf`@0=0?nf`@030000003o]/40okK102H0okK100<00000
0?nf`@3o]/403P3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100H0okK10_ooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`09ooooo`030000oooooooooooo
00Oooooo00<0003oooooooooool02_ooool20?nf`@80003o<P3o]/42o`00o`P0okK100?o003o0000
o`3o]/40503o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK100/0okK11Oooool3o`00
oaKooooo00D0003oooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00Wooooo00<00000
ooooooooool01oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00L0okK100<00000
0?nf`@3o]/40203o]/400`000000okK10?nf`@0=0?nf`@800000903o]/4200000100okK100<00000
0?nf`@3o]/402P3o]/400`000000okK10?nf`@060?nf`@;ooooo00<00000ooooooooool02?ooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
00[ooooo103o]/400`000?l0okK10?nf`@0^0?nf`@03o`00o`3o]/40okK100T0okK10ol00?lC0?nf
`@03o`00o`3o]/40okK100P0okK100?o003o0?nf`@3o]/402P3o]/44ooooo`;o003o6?ooool00`00
0?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00`00
003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01`3o]/400`00
0000okK10?nf`@090?nf`@030000003o]/40okK100h0okK10P00000Q0?nf`@030000003o]/40okK1
00l0okK100<000000?nf`@3o]/402P3o]/400ol00000okK10?nf`@060?nf`@;ooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool02Oooool00`000?ooooooooooo`07ooooo`03
0000oooooooooooo00_ooooo0`3o]/400ol00?l0003o0?nf`@0]0?nf`@03o`00o`3o]/40okK100`0
okK100<0003oo`00o`3o]/404@3o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK100X0
okK100Coooooo`00ool00?oo003o6Oooool00`000?ooooooooooo`03ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooo`0000002_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo
00Oooooo00<00000ooooooooool01`3o]/400`000000okK10?nf`@090?nf`@800000403o]/430000
01/0okK10P0000000ol00000okK10?nf`@0>0?nf`@0300000?l00000okK100/0okK100<000000?nf
`@3o]/401`3o]/400oooool00000ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`09ooooo`03
0000oooooooooooo00Oooooo00<0003oooooooooool02oooool50?nf`@<0003o:03o]/43o`00oa00
okK100<0003oo`00ool00?l0403o]/400ol00?l0okK10?nf`@080?nf`@03o`00o`3o]/40okK100T0
okK10_l00?lJooooo`80003o1_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000000[o
oooo00<00000ooooooooool01oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00L0
okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@0@0?nf`@<000005@3o]/4300000180
okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@070?nf`@03ooooo`00003ooooo00[o
oooo00<00000ooooooooool01oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo00[ooooo00<0003oooooooooool01oooool00`000?oooooo
ooooo`0:ooooo`P0okK110000?lP0?nf`@Co003o503o]/420000o`?o003o303o]/400ol00?l0okK1
0?nf`@090?nf`@03o`00o`3o]/40okK100L0okK10_l00?lKooooo`030000oooooooooooo00Kooooo
00?o0000ooooooooool03oooool01?l0003oooooooooo`00000:ooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool02?ooool00`00003ooooo0?nf`@070?nf`@800000303o]/400`000000
okK10?nf`@0B0?nf`@@000003@3o]/44000001@0okK100<000000?nf`@3o]/402`3o]/400`000000
okK10?nf`@080?nf`@0300000?oooooooooo00Wooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00[ooooo
00<0003oooooooooool01oooool00`000?ooooooooooo`0;ooooo`/0okK110000?lI0?nf`@?o003o
6P3o]/400`000?l0okK10?nf`@04o`00o`P0okK100?o003o0?nf`@3o]/402@3o]/400ol00?l0okK1
0?nf`@040?nf`@?o003o0P3o]/4Jooooo`030000oooooooooooo00Oooooo00?o0000ooooooooool0
3oooool01?l0003oooooooooo`00000:ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool02?ooool00ol0003ooooo0?nf`@080?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o
]/405@3o]/4=000001D0okK10P0000000ol00000okK10?nf`@0:0?nf`@0300000?l00000okK100T0
okK100?o0000ooooooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Wo
oooo00?o0000ooooool000002_ooool000Wooooo00?o0000ooooooooool02_ooool00`000?oooooo
ooooo`07ooooo`030000oooooooooooo00cooooo3P3o]/450000oa40okK10P000?l00ol00?l0okK1
0?nf`@0L0?nf`@80003o103o]/45o`00o`<0okK100?o003o0?nf`@3o]/402@3o]/400ol00?l0okK1
o`00o`04o`00o`@0okK16_ooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo00oooooo
00Co0000ooooooooool000002_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00So
oooo00<00000ooooooooool0203o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK103D0
okK100<000000?nf`@3o]/40303o]/400`000000okK10?nf`@0:0?nf`@0300000?oooooooooo00So
oooo00<00000ooooooooool02Oooool00`00003oooooooooo`09ooooo`0300000?oooooo000000[o
oooo0009ooooo`03o`000?oooooooooo00[ooooo00<0003oooooooooool01oooool00`000?oooooo
ooooo`0<oooooa<0okK14@000?lS0?nf`@80003o1`3o]/4Ao`00o`P0okK16_ooool20000o`[ooooo
00?o0000ooooooooool03oooool01Ol0003oooooooooooooool0000000[ooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`08ooooo`0300000?ooool0okK100P0okK100<000000?nf`@3o
]/402`3o]/400`000000okK10?nf`@0b0?nf`@8000003P3o]/400`000000okK10?nf`@0:0?nf`@03
00000?oooooooooo00Sooooo00<00000ooooooooool02Oooool00`00003oooooooooo`09ooooo`04
00000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooooooo00_ooooo00<0003ooooooooo
ool01_ooool00`000?ooooooooooo`0=ooooodP0okK10P000?l80?nf`@03o`00o`3o]/40okK100P0
okK100?o003o0?nf`@3o]/40203o]/4Gooooo`<0003o3?ooool00ol0003oooooooooo`0?ooooo`05
o`000?ooooooooooooooo`0000002_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo
00Sooooo00<00000ooooooooool02@3o]/400`000000okK10?nf`@0;0?nf`@800000<@3o]/400`00
0000okK10?nf`@0=0?nf`@03o`00003o]/40okK100X0okK100<00000ooooooooool02Oooool00`00
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00@00000oooooooooooo00002_ooool0
00Wooooo00?o0000ooooooooool02oooool00`000?ooooooooooo`07ooooo`030000oooooooooooo
00coooooBP3o]/400`000?l0okK10?nf`@040?nf`@03o`00o`3o]/40okK100T0okK100?o003o0?nf
`@3o]/401`3o]/4Fooooo`80003o3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00;ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo
00Sooooo00<00000ooooo`3o]/402@3o]/400ol00000okK10?nf`@0<0?nf`@800000;@3o]/420000
00l0okK100<000000?nf`@3o]/402P3o]/400ol0003oooooooooo`09ooooo`0300000?oooooooooo
00Sooooo00<00000ooooooooool02_ooool01@00003ooooooooooooooooo000000[ooooo0009oooo
o`03o`000?oooooooooo00_ooooo00<0003oooooooooool01oooool00`000?ooooooooooo`0=oooo
odX0okK10P000?l40?nf`@03o`00o`3o]/40okK100T0okK100?o003o0?nf`@3o]/401`3o]/4Eoooo
o`030000oooooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`0300000?oooooooooo00X0okK100<000000?nf`@3o]/403@3o]/42000002T0okK10P00000@0?nf
`@030000003o]/40okK100X0okK100<000000?nf`Oooool02Oooool00`00003oooooooooo`09oooo
o`0300000?oooooooooo00Wooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0<ooooo`030000oooooooooooo00Kooooo00<0003ooooooooo
ool03_oooom;0?nf`@80003o0P3o]/400ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK100H0
okK15?ooool20000oa;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03
00000?oooooooooo00Sooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08ooooo`03
00000?oooooooooo00X0okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@0T0?nf`@80
0000403o]/42000000`0okK100<000000?nf`Oooool02Oooool00`00003oooooooooo`09ooooo`03
00000?oooooooooo00Wooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0<ooooo`030000oooooooooooo00Kooooo00<0003oooooooooool0
3ooooom<0?nf`@030000ool00?l0okK100/0okK100?o003o0?nf`@3o]/401@3o]/4Booooo`<0003o
5?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0
2Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
2P3o]/400`000000okK10?nf`@0>0?nf`@<00000803o]/4300000140okK100<000000?nf`@3o]/40
2`3o]/400`000000okK1ooooo`09ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0
2_ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00gooooo00<0003oooooooooool01Oooool00`000?ooooooooooo`0@oooood/0okK100?o
003o0?nf`@000?l00P000?l80?nf`@03o`00o`3o]/40okK100D0okK14?ooool30000oaOooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00X0okK10P00
000A0?nf`@0400000?l000000000000001P0okK11000000A0?nf`@80000000?o00000?nf`@3o]/40
2P3o]/42000000030?nf`Ooooooooooo00Sooooo00<00000ooooooooool02Oooool00`00003ooooo
ooooo`0:ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool03Oooool00`000?ooooooooooo`06ooooo`030000oooooooooooo00ooooooB`3o
]/400ol00?l0okK10?nf`@020?nf`@@0003o103o]/400ol00?l0okK10?nf`@040?nf`@kooooo0`00
0?lJooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00`00003ooooooooo
o`09ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02Oooool00ol0003ooooo0?nf
`@0;0?nf`@8000004`3o]/47000000T0okK12000000D0?nf`@030000003o]/40okK100`0okK100<0
00000?nf`@3o]/402_ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00<0
0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0>
ooooo`030000oooooooooooo00Gooooo00<0003oooooooooool04?oooom:0?nf`@03o`00o`3o]/40
okK100H0okK10`000?l00ol00?l0003o0000o`050?nf`@Kooooo0P000?l00ol00?l0003o0000o`03
0000oagooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool02?ooool00`00003oooooooooo`09ooooo`0300000?ooool0
okK100`0okK100<000000?nf`@3o]/405`3o]/49000001X0okK10P00000>0?nf`@040000003o]/40
okK10?nf`@Wooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`0300000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03_ooool0
0`000?ooooooooooo`05ooooo`03o`00oooooooooooo017oooooB@3o]/400ol00?l0okK10?nf`@09
0?nf`@03o`00o`3o]/7o003o00/0003o9Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Gooooo00<00000ooooooooool02Oooool00`00003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00<00000ooooo`3o]/40303o]/400`000000okK10?nf`@0g0?nf`@8000003@3o]/42
00000004o`00003o]/40okK10?nf`@Wooooo00<00000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool03oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo01;oooooA`3o]/40
0ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK100@0okK1;Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool02Oooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo00Wooooo00?o0000ooooo`3o]/40303o]/400ol0000000000?nf`@0d
0?nf`@8000003P3o]/400`000000okK10?nf`@030?nf`@Wooooo00<00000ooooooooool02_ooool0
0`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool03oooool00`000?ooooooooooo`05ooooo`030000oooooooooooo
01;oooooA@3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/40okK100<0okK1;_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool02Oooool00`00
003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00<00000ooooo`3o]/403@3o]/400`00
0000okK10?nf`@0_0?nf`@<000003`3o]/400`000000okK10?nf`@030?nf`@Wooooo00<00000oooo
ooooool02_ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool03oooool00`000?ooooooooooo`05ooooo`03
0000oooooooooooo01?oooooA03o]/400ol00?l0okK10?nf`@0:0?nf`@04o`00o`3o]/40okK10?nf
`C3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`0300000?oooooooooo
00Wooooo00<00000ooooooooool02_ooool00`00003oooooooooo`09ooooo`0300000?ooool0okK1
00d0okK10P00000^0?nf`@030000003o]/40okK100l0okK100<000000?nf`@3o]/400P3o]/4:oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo013ooooo00<0003ooooooooo
ool01Oooool00`000?ooooooooooo`0Coooood80okK100?o003o0?nf`@3o]/402P3o]/401?l00?l0
okK10?nf`@3o]/4aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00`00
003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00`00
003o00000?nf`@0>0?nf`@D000009P3o]/4200000003o`00003o]/40okK100d0okK10P0000000ol0
0000okK10?nf`@020?nf`@Wooooo0P00000;ooooo`0300000?l0003ooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Aooooo`03
0000oooooooooooo00Cooooo00<0003oooooooooool05Ooooom00?nf`@03o`00o`3o]/40okK100X0
okK100?o003o0?nf`@3o]/40<_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oo
oooo00<00000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00_o
oooo00<00000ooooo`3o]/404@3o]/43000001l0okK11000000@0?nf`@8000001P3o]/48ooooo`80
00003?ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00_ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool04_ooool00`000?ooooooooooo`04ooooo`030000
oooooooooooo01Gooooo?P3o]/400ol00?l0okK10?nf`@0;0?nf`@03o`00o`3o]/7ooooo03;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool02Oooool00`00003oooooooooo`0;ooooo`0300000?ooool0okK101<0okK1
1000000H0?nf`@<000004`3o]/400ol00000okK10?nf`@050?nf`@Sooooo00<00000ooooooooool0
2oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool04_ooool00`000?ooooooooooo`05ooooo`030000oooo
oooooooo01Gooooo?@3o]/400ol00?l0okK10?nf`@0:0?nf`@03o`00o`3o]/7ooooo03?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00<0
0000ooooooooool02Oooool2000000cooooo00<00000o`00000000005P3o]/401000003o00000000
0000000<0?nf`@P00000503o]/42000000L0okK11oooool2000000cooooo0P00000=ooooo`030000
0?oooooooooo00gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool04ooo
ool00`000?ooooooooooo`04ooooo`030000oooooooooooo01Kooooo>`3o]/400ol00?l0okK10?nf
`@0;0?nf`@03o`00oooooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0:ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`0<ooooo`030000003o]/40okK101L0okK13000000J0?nf`@800000203o]/47ooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0<ooooo`0300000?oo
oooo000000[ooooo0009ooooo`03o`000?oooooooooo01Cooooo00<0003oooooooooool01?ooool0
0`000?ooooooooooo`0GooooocP0okK100?o003o0?nf`@3o]/402`3o]/400ol00?ooooooooooo`0d
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00`00003oooooooooo`0:
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool2000003/0okK10P000008
0?nf`@Sooooo00<00000ooooooooool02oooool00`00003oooooooooo`0<ooooo`0300000?oooooo
oooo00gooooo00<00000ooooool000002_ooool000Wooooo00?o0000ooooooooool05?ooool00`00
0?ooooooooooo`04ooooo`030000oooooooooooo01Sooooo=P3o]/400ol00?l0okK10?nf`@0;0?nf
`@03ooooool00?oooooo03Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0=oooo
o`030000003o]/40okK103H0okK10P0000090?nf`@Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`0300000?oooooooooo00gooooo00@00000oooooooooooo00002_ooool0
00Wooooo00?o0000ooooooooool05Oooool00`000?ooooooooooo`04ooooo`030000oooooooooooo
01Wooooo<`3o]/400ol00?l0okK10?nf`@0:0?nf`@;ooooo00?o003oooooooooool0=Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00<00000ooooooooool02_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00@00000o`00000000000000<@3o]/42
00000003o`00003o]/40okK100L0okK12?ooool2000000gooooo0P00000=ooooo`0300000?oooooo
oooo00cooooo0P000003ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01Kooooo0P000?l5ooooo`030000oooooooooooo01[ooooo<03o]/400ol00?l0okK10?nf`@090?nf
`@?ooooo00?o003oooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00cooooo00<00000ooooooooool02oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo
00oooooo00<0okK1000000000000;@3o]/42000000X0okK11oooool3000000kooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool06?ooool00`000?ooooooooooo`03ooooo`03
0000oooooooooooo01[ooooo;P3o]/400ol00?l0okK10?nf`@090?nf`@?ooooo00?o003ooooooooo
ool0=oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000gooooo00?o0000oooooooo
ool02oooool00`00003oooooooooo`0;ooooo`8000004?ooool20?nf`@800000:@3o]/42000000/0
okK11oooool00`00003oooooooooo`0=ooooo`8000003_ooool00`00003oooooooooo`0<ooooo`03
00000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6?ooool00`000?ooooooooooo`03ooooo`030000oooooooooooo01gooooo:P3o]/400ol00?l0okK1
0?nf`@080?nf`@Gooooo00?o003oooooooooool0=oooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooo000000gooooo00<00000ooooooooool02oooool00ol000000000ooooo`0<ooooo`80
00004Oooool0103o]/40000000000000000Q0?nf`@D000002`3o]/46ooooo`80000000?o0000oooo
ooooool03?ooool2000000kooooo00?o000000000?ooool03Oooool00`00003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo00<0003ooooooooo
ool00oooool00`000?ooooooooooo`0OooooobH0okK100?o003o0?nf`@3o]/401P3o]/47ooooo`03
o`00oooooooooooo03Sooooo00?o0000ooooooooool03oooool01?l0003oooooooooo`00000>oooo
o`0300000?oooooooooo00cooooo00<00000ooooooooool03?ooool2000001;ooooo00<0okK1o`00
000000001@00000D0?nf`@H000003@3o]/48ooooo`0300000?oooooooooo00kooooo00<00000oooo
ooooool03Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo00Gooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool00`000?ooooooooooo`03ooooo`03
0000oooooooooooo027ooooo8P3o]/400ol00?l0okK10?nf`@040?nf`@Wooooo00?o003ooooooooo
ool0>Oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooo`0000003_ooool00`00
003oooooooooo`0<ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool04_ooool50?nf
`A@00000403o]/49ooooo`8000004?ooool00`00003oooooooooo`0=ooooo`0300000?oooooooooo
00kooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Kooooo`80003o0oooool00`000?ooooooooooo`0Toooooah0okK100?o003o0?nf`@3o
]/400P3o]/4;ooooo`03o`00oooooooooooo03[ooooo00?o0000ooooooooool03oooool01Ol0003o
ooooooooooooool0000000oooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0>oooo
o`8000005OoooolS0?nf`@[ooooo00?o000000000?ooool04?ooool00`00003oooooooooo`0=oooo
o`0300000?oooooooooo00kooooo00<00000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Mooooo`80003o0_ooool00`000?ooooooooooo`0VoooooaT0
okK10_l00?l20?nf`@gooooo00?o003oooooooooool0>oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo00?o000000000?ooool03Oooool00`00003oooooooooo`0;ooooo`80
00004?ooool2000001Kooooo7@3o]/4;ooooo`8000004Oooool2000000kooooo00<00000o`000?oo
ool03_ooool2000000[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
7oooool010000?ooooooooooo`000?lZoooooaD0okK100?o003o0?nf`Oooool03_ooool00ol00?oo
ooooooooo`0looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`0=ooooo`0300000?oooooooooo00cooooo0P00000@ooooo`<000005_oooolG0?nf`@_o
oooo0`00000Aooooo`8000003_ooool20000013ooooo00<00000ooooooooool02_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Pooooo`040000oooooooooooo0000oc;o
oooo103o]/46ooooo`;o003o4?ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00<00000ooooooooool04?ooool3000001cooooo103o]/4Aooooo`@000004_ooool2000000oo
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo027ooooo00@0003oooooooooool0003o>_ooool00ol00?oo
ooooooooo`0?ooooo`03o`00oooooooooooo03kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00gooooo00<00000ooooooooool03Oooool00`00003o
ooooooooo`0Booooo`0300000?oooooooooo02_ooooo0`00000Dooooo`8000004?ooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool08_ooool010000?ooooooooooo`000?lhooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool0?oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Ko
oooo00<00000ooooooooool03Oooool00`00003oooooooooo`0=ooooo`03o`000000003ooooo01;o
oooo00?o00000000000000009_ooool4000001Gooooo0P00000@ooooo`0300000?l0003ooooo013o
oooo00<00000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Sooooo`030000ool00?l0003o0080003o<oooool3o`00oa3ooooo0_l00?m2ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003oooooooooo`0>ooooo`030000
0?oooooooooo00kooooo00<00000ooooooooool04oooool4000001oooooo0`00000Hooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Kooooo0`000?l`ooooo`;o003o4_oo
ool00ol00?ooooooooooo`12ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01ooo
ool00`00003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo0P00000Gooooo`L000004?oo
ool8000001Wooooo0P00000Aooooo`0300000?oooooooooo013ooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Xooooo`<0003o;Oooool0
0ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo04?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`08ooooo`8000003oooool00`00003oooooooooo`0?ooooo`8000007?ooool>
00000003o`000000003ooooo01cooooo0P0000000ol000000000ooooo`0@ooooo`0300000?l0003o
oooo013ooooo00<00000o`000?ooool04Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Yooooo`@0003o:?ooool3o`00oa?ooooo00?o003oooooooooool0A?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool03Oooool00`00
003oooooooooo`0@ooooo`800000A_ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo
013ooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0/ooooo`80003o9Oooool2o`00oa?ooooo0ol00?m7ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02oooool00`00003oooooooooo`0=ooooo`<000004Oooool00`00003o
ooooooooo`10ooooo`<000004oooool2000001;ooooo00<00000ooooooooool04oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0^ooooo`03o`00o`000?l0003o023ooooo
0ol00?lBooooo`;o003oB_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo
00<00000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`@00000>oooool3000001Cooooo
0P00000Aooooo`80000000?o0000ooooooooool04Oooool200000003ooooool0003ooooo00Wooooo
0009ooooo`03o`000?oooooooooo033ooooo1P000?lFooooo`Go003o4oooool2o`00odcooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`0300000?oooooooooo013ooooo0P00
000Cooooo`03o`0000000000000003Cooooo1000000Fooooo`0300000?l0003ooooo013ooooo00<0
0000ooooooooool04oooool01@00003ooooooooooooooooo000000[ooooo0009ooooo`03o`000?oo
oooooooo037ooooo00<0003oooooooooool00_ooool50000o`cooooo0`000?l2o`00oaOooooo00?o
003oooooooooool0C?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0P00
000Booooo`0300000?oooooooooo01?ooooo1000000]ooooo`<000006?ooool2000001;ooooo00<0
0000ooooooooool04oooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo03;ooooo0`000?l6ooooo``0003o6oooool00ol00?ooooooooooo`1=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00`00003oooooooooo`0@
ooooo`03o`000?oooooooooo01Kooooo0`00000Wooooo`<000006Oooool2000001?ooooo00<00000
ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo03Gooooo0P000?lWooooo`Co003oD?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool3000001Sooooo00@00000o`00
0000000000007oooool200000003o`000000003ooooo01Oooooo00@00000o`000000000000005?oo
ool00ol0003oooooooooo`0Cooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0=oooool01?l00?l0003o0000o`000?lPooooo`?o003oE?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo0P00000Cooooo`8000006_oo
ool70000013ooooo2000000Kooooo`0300000?oooooooooo01Cooooo0P00000Eooooo`0300000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>oooool4
0000oaWooooo0ol00?mGooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool0
0`00003oooooooooo`0Booooo`0300000?oooooooooo01kooooo4000000Qooooo`8000005Oooool2
000001Gooooo0P000008ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
03oooooo1@000?lAooooo`?o003oF_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04_ooool00ol0000000000000001<ooooo`8000005Oooool00`00
003o0000ooooo`0Eooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0A?ooool;0000o`Ko003oGOooool00ol0003oooooooooo`0?ooooo`03
o`000?ooool0000001Cooooo0P00000Fooooo`0300000?oooooooooo04Oooooo00<00000o`000?oo
ool05Oooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`04o`00
0?oooooooooo000001Gooooo0P00000Eooooo`<00000@_ooool4000001Kooooo0P00000Fooooo`80
00003?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00Go0000oooooooooooooooo0000000Fooooo`03o`000?oooooooooo01Go
oooo0P00000mooooo`<000006?ooool2000001Oooooo00<00000ooooooooool03?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool00`00003oooooooooo`0Dooooo`0300000?oooooooooo01Kooooo
0P00000gooooo`80000000?o000000000?ooool06?ooool2000001Oooooo0P00000?ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`03ooooo`0300000?oooooooooo01Cooooo00<00000ooooooooool05ooo
ool30000037ooooo0`00000Looooo`0300000?oooooooooo01Kooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`0Dooooo`8000006_ooool4
000002Wooooo1000000Mooooo`8000006?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`05ooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool06oooool40000
0003o`000?oooooooooo01oooooo0`00000Oooooo`8000006Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`06ooooo`8000005_ooool00ol0000000000000000Oooooo`T0
00003Oooool800000003o`0000000000000001oooooo0`00000Iooooo`8000005?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02?ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo02Gooooo
3@00000Wooooo`<000006_ooool2000001Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00<0
0000ooooooooool05_ooool3000005Oooooo00<00000ooooooooool06_ooool00`00003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00<00000
ooooooooool0D_ooool2o`0001cooooo00<00000ooooooooool05oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooooonfo`00017ooooo]_l0000:ooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.42308 .13396 m
.44231 .13047 L
.46154 .12877 L
.48077 .12893 L
.5 .13079 L
.51923 .13403 L
.52225 .13462 L
.53846 .13852 L
.55769 .14375 L
.57692 .14932 L
.59239 .15385 L
.59615 .15511 L
.61538 .162 L
.63462 .16942 L
.64387 .17308 L
.65385 .17779 L
.67308 .18755 L
.6822 .19231 L
.69231 .19838 L
.71154 .21044 L
.71326 .21154 L
.73077 .22393 L
.74029 .23077 L
.75 .23821 L
.76505 .25 L
.76923 .25345 L
.78751 .26923 L
.78846 .27011 L
.80695 .28846 L
.80769 .28927 L
.82296 .30769 L
.82692 .31308 L
.83575 .32692 L
.84612 .34615 L
.84615 .34622 L
.85372 .36538 L
.85978 .38462 L
.86429 .40385 L
.86538 .40957 L
.86706 .42308 L
.86862 .44231 L
.86927 .46154 L
.86911 .48077 L
.86825 .5 L
.86684 .51923 L
.86538 .53493 L
.86486 .53846 L
.86161 .55769 L
.85759 .57692 L
.85291 .59615 L
.8479 .61538 L
.84615 .62215 L
.84166 .63462 L
.8341 .65385 L
.82692 .6718 L
.82631 .67308 L
.81644 .69231 L
.80769 .70878 L
.80601 .71154 L
.79361 .73077 L
.78846 .73844 L
.77974 .75 L
.76923 .76299 L
.7637 .76923 L
.75 .78339 L
.74464 .78846 L
.73077 .80026 L
.72114 .80769 L
.71154 .81421 L
.69231 .82593 L
.69052 .82692 L
.67308 .83531 L
.65385 .84349 L
.6469 .84615 L
.63462 .85001 L
.61538 .85546 L
.59615 .86004 L
.57692 .86356 L
.56389 .86538 L
.55769 .86579 L
.53846 .86667 L
.51923 .86649 L
.50172 .86538 L
.5 .86519 L
.48077 .86228 L
.46154 .85804 L
.44231 .85262 L
.42308 .84637 L
.42245 .84615 L
.40385 .83823 L
.38462 .82933 L
.37948 .82692 L
.36538 .81925 L
.34615 .80854 L
.34462 .80769 L
.32692 .79657 L
.31397 .78846 L
.30769 .78411 L
.28846 .77052 L
.28662 .76923 L
.26923 .75543 L
.26249 .75 L
.25 .73896 L
.24108 .73077 L
.23077 .72065 L
.22199 .71154 L
.21154 .70026 L
.20471 .69231 L
.19231 .67777 L
.18867 .67308 L
.17341 .65385 L
.17308 .65342 L
.15946 .63462 L
.15385 .62682 L
.14652 .61538 L
.13483 .59615 L
.13462 .59577 L
.12577 .57692 L
.11852 .55769 L
.11538 .54727 L
.11372 .53846 L
.11123 .51923 L
.1107 .5 L
.11214 .48077 L
.11538 .46169 L
.11544 .46154 L
.12123 .44231 L
.1288 .42308 L
.13462 .4098 L
.1377 .40385 L
.14821 .38462 L
.15385 .3741 L
.15915 .36538 L
.17076 .34615 L
.17308 .34209 L
.18315 .32692 L
.19231 .31273 L
.19594 .30769 L
.21005 .28846 L
.21154 .28641 L
.22569 .26923 L
.23077 .26318 L
.2428 .25 L
.25 .24246 L
.26182 .23077 L
.26923 .22393 L
.28313 .21154 L
.28846 .20722 L
.3072 .19231 L
.30769 .19196 L
.32692 .1786 L
.33518 .17308 L
.34615 .16663 L
.36538 .15583 L
.36919 .15385 L
.38462 .14701 L
.40385 .13958 L
.42013 .13462 L
F
0 g
.42308 .13396 m
.44231 .13047 L
.46154 .12877 L
.48077 .12893 L
.5 .13079 L
.51923 .13403 L
.52225 .13462 L
.53846 .13852 L
.55769 .14375 L
.57692 .14932 L
.59239 .15385 L
.59615 .15511 L
.61538 .162 L
.63462 .16942 L
.64387 .17308 L
.65385 .17779 L
.67308 .18755 L
.6822 .19231 L
.69231 .19838 L
.71154 .21044 L
.71326 .21154 L
.73077 .22393 L
.74029 .23077 L
.75 .23821 L
.76505 .25 L
.76923 .25345 L
.78751 .26923 L
.78846 .27011 L
.80695 .28846 L
.80769 .28927 L
.82296 .30769 L
.82692 .31308 L
.83575 .32692 L
.84612 .34615 L
.84615 .34622 L
.85372 .36538 L
.85978 .38462 L
.86429 .40385 L
.86538 .40957 L
.86706 .42308 L
.86862 .44231 L
.86927 .46154 L
.86911 .48077 L
.86825 .5 L
.86684 .51923 L
.86538 .53493 L
.86486 .53846 L
.86161 .55769 L
.85759 .57692 L
.85291 .59615 L
Mistroke
.8479 .61538 L
.84615 .62215 L
.84166 .63462 L
.8341 .65385 L
.82692 .6718 L
.82631 .67308 L
.81644 .69231 L
.80769 .70878 L
.80601 .71154 L
.79361 .73077 L
.78846 .73844 L
.77974 .75 L
.76923 .76299 L
.7637 .76923 L
.75 .78339 L
.74464 .78846 L
.73077 .80026 L
.72114 .80769 L
.71154 .81421 L
.69231 .82593 L
.69052 .82692 L
.67308 .83531 L
.65385 .84349 L
.6469 .84615 L
.63462 .85001 L
.61538 .85546 L
.59615 .86004 L
.57692 .86356 L
.56389 .86538 L
.55769 .86579 L
.53846 .86667 L
.51923 .86649 L
.50172 .86538 L
.5 .86519 L
.48077 .86228 L
.46154 .85804 L
.44231 .85262 L
.42308 .84637 L
.42245 .84615 L
.40385 .83823 L
.38462 .82933 L
.37948 .82692 L
.36538 .81925 L
.34615 .80854 L
.34462 .80769 L
.32692 .79657 L
.31397 .78846 L
.30769 .78411 L
.28846 .77052 L
.28662 .76923 L
Mistroke
.26923 .75543 L
.26249 .75 L
.25 .73896 L
.24108 .73077 L
.23077 .72065 L
.22199 .71154 L
.21154 .70026 L
.20471 .69231 L
.19231 .67777 L
.18867 .67308 L
.17341 .65385 L
.17308 .65342 L
.15946 .63462 L
.15385 .62682 L
.14652 .61538 L
.13483 .59615 L
.13462 .59577 L
.12577 .57692 L
.11852 .55769 L
.11538 .54727 L
.11372 .53846 L
.11123 .51923 L
.1107 .5 L
.11214 .48077 L
.11538 .46169 L
.11544 .46154 L
.12123 .44231 L
.1288 .42308 L
.13462 .4098 L
.1377 .40385 L
.14821 .38462 L
.15385 .3741 L
.15915 .36538 L
.17076 .34615 L
.17308 .34209 L
.18315 .32692 L
.19231 .31273 L
.19594 .30769 L
.21005 .28846 L
.21154 .28641 L
.22569 .26923 L
.23077 .26318 L
.2428 .25 L
.25 .24246 L
.26182 .23077 L
.26923 .22393 L
.28313 .21154 L
.28846 .20722 L
.3072 .19231 L
.30769 .19196 L
Mistroke
.32692 .1786 L
.33518 .17308 L
.34615 .16663 L
.36538 .15583 L
.36919 .15385 L
.38462 .14701 L
.40385 .13958 L
.42013 .13462 L
.42308 .13396 L
Mfstroke
.2 g
.42308 .17174 m
.44231 .16903 L
.46154 .16812 L
.48077 .16882 L
.5 .17071 L
.51767 .17308 L
.51923 .17332 L
.53846 .17643 L
.55769 .17994 L
.57692 .18401 L
.59615 .18885 L
.60817 .19231 L
.61538 .19475 L
.63462 .20215 L
.65385 .21084 L
.65529 .21154 L
.67308 .2214 L
.68825 .23077 L
.69231 .23352 L
.71154 .24744 L
.71489 .25 L
.73077 .26291 L
.7382 .26923 L
.75 .27973 L
.75941 .28846 L
.76923 .29806 L
.77849 .30769 L
.78846 .31896 L
.79485 .32692 L
.80769 .34524 L
.80825 .34615 L
.8187 .36538 L
.82686 .38462 L
.82692 .3848 L
.83274 .40385 L
.83707 .42308 L
.84004 .44231 L
.84183 .46154 L
.84258 .48077 L
.84237 .5 L
.84124 .51923 L
.83921 .53846 L
.83627 .55769 L
.83246 .57692 L
.82791 .59615 L
.82692 .60003 L
.82194 .61538 L
.81476 .63462 L
.80769 .65172 L
.80668 .65385 L
.79673 .67308 L
.78846 .68762 L
.78549 .69231 L
.77222 .71154 L
.76923 .71554 L
.75672 .73077 L
.75 .73824 L
.73845 .75 L
.73077 .75714 L
.71654 .76923 L
.71154 .77311 L
.69231 .78677 L
.68974 .78846 L
.67308 .79847 L
.65594 .80769 L
.65385 .8087 L
.63462 .81729 L
.61538 .82464 L
.60858 .82692 L
.59615 .83033 L
.57692 .83454 L
.55769 .83732 L
.53846 .83858 L
.51923 .83828 L
.5 .83641 L
.48077 .83304 L
.46154 .82827 L
.45684 .82692 L
.44231 .82185 L
.42308 .81407 L
.40875 .80769 L
.40385 .8053 L
.38462 .79549 L
.3712 .78846 L
.36538 .78524 L
.34615 .77433 L
.33729 .76923 L
.32692 .76285 L
.30769 .75048 L
.30697 .75 L
.28846 .73655 L
.28092 .73077 L
.26923 .72098 L
.25864 .71154 L
.25 .70322 L
.23944 .69231 L
.23077 .68277 L
.22261 .67308 L
.21154 .6593 L
.20751 .65385 L
.19369 .63462 L
.19231 .63261 L
.18126 .61538 L
.17308 .60195 L
.16992 .59615 L
.16023 .57692 L
.15385 .56176 L
.15247 .55769 L
.14712 .53846 L
.14404 .51923 L
.14334 .5 L
.14497 .48077 L
.14879 .46154 L
.15385 .44405 L
.15449 .44231 L
.16208 .42308 L
.17071 .40385 L
.17308 .39872 L
.1803 .38462 L
.1905 .36538 L
.19231 .36199 L
.20171 .34615 L
.21154 .33014 L
.2137 .32692 L
.22727 .30769 L
.23077 .30292 L
.24242 .28846 L
.25 .27956 L
.25951 .26923 L
.26923 .25934 L
.27904 .25 L
.28846 .24172 L
.3017 .23077 L
.30769 .22628 L
.32692 .2127 L
.32867 .21154 L
.34615 .20113 L
.36272 .19231 L
.36538 .19108 L
.38462 .18291 L
.40385 .17637 L
.41591 .17308 L
F
0 g
.42308 .17174 m
.44231 .16903 L
.46154 .16812 L
.48077 .16882 L
.5 .17071 L
.51767 .17308 L
.51923 .17332 L
.53846 .17643 L
.55769 .17994 L
.57692 .18401 L
.59615 .18885 L
.60817 .19231 L
.61538 .19475 L
.63462 .20215 L
.65385 .21084 L
.65529 .21154 L
.67308 .2214 L
.68825 .23077 L
.69231 .23352 L
.71154 .24744 L
.71489 .25 L
.73077 .26291 L
.7382 .26923 L
.75 .27973 L
.75941 .28846 L
.76923 .29806 L
.77849 .30769 L
.78846 .31896 L
.79485 .32692 L
.80769 .34524 L
.80825 .34615 L
.8187 .36538 L
.82686 .38462 L
.82692 .3848 L
.83274 .40385 L
.83707 .42308 L
.84004 .44231 L
.84183 .46154 L
.84258 .48077 L
.84237 .5 L
.84124 .51923 L
.83921 .53846 L
.83627 .55769 L
.83246 .57692 L
.82791 .59615 L
.82692 .60003 L
.82194 .61538 L
.81476 .63462 L
.80769 .65172 L
.80668 .65385 L
Mistroke
.79673 .67308 L
.78846 .68762 L
.78549 .69231 L
.77222 .71154 L
.76923 .71554 L
.75672 .73077 L
.75 .73824 L
.73845 .75 L
.73077 .75714 L
.71654 .76923 L
.71154 .77311 L
.69231 .78677 L
.68974 .78846 L
.67308 .79847 L
.65594 .80769 L
.65385 .8087 L
.63462 .81729 L
.61538 .82464 L
.60858 .82692 L
.59615 .83033 L
.57692 .83454 L
.55769 .83732 L
.53846 .83858 L
.51923 .83828 L
.5 .83641 L
.48077 .83304 L
.46154 .82827 L
.45684 .82692 L
.44231 .82185 L
.42308 .81407 L
.40875 .80769 L
.40385 .8053 L
.38462 .79549 L
.3712 .78846 L
.36538 .78524 L
.34615 .77433 L
.33729 .76923 L
.32692 .76285 L
.30769 .75048 L
.30697 .75 L
.28846 .73655 L
.28092 .73077 L
.26923 .72098 L
.25864 .71154 L
.25 .70322 L
.23944 .69231 L
.23077 .68277 L
.22261 .67308 L
.21154 .6593 L
.20751 .65385 L
Mistroke
.19369 .63462 L
.19231 .63261 L
.18126 .61538 L
.17308 .60195 L
.16992 .59615 L
.16023 .57692 L
.15385 .56176 L
.15247 .55769 L
.14712 .53846 L
.14404 .51923 L
.14334 .5 L
.14497 .48077 L
.14879 .46154 L
.15385 .44405 L
.15449 .44231 L
.16208 .42308 L
.17071 .40385 L
.17308 .39872 L
.1803 .38462 L
.1905 .36538 L
.19231 .36199 L
.20171 .34615 L
.21154 .33014 L
.2137 .32692 L
.22727 .30769 L
.23077 .30292 L
.24242 .28846 L
.25 .27956 L
.25951 .26923 L
.26923 .25934 L
.27904 .25 L
.28846 .24172 L
.3017 .23077 L
.30769 .22628 L
.32692 .2127 L
.32867 .21154 L
.34615 .20113 L
.36272 .19231 L
.36538 .19108 L
.38462 .18291 L
.40385 .17637 L
.41591 .17308 L
.42308 .17174 L
Mfstroke
.3 g
.38462 .20621 m
.40385 .20088 L
.42308 .19758 L
.44231 .19624 L
.46154 .19658 L
.48077 .19795 L
.5 .19957 L
.51923 .20099 L
.53846 .20234 L
.55769 .20414 L
.57692 .20685 L
.59615 .21082 L
.59917 .21154 L
.61538 .2164 L
.63462 .22376 L
.6497 .23077 L
.65385 .23297 L
.67308 .24437 L
.6815 .25 L
.69231 .25792 L
.7064 .26923 L
.71154 .27363 L
.72782 .28846 L
.73077 .29127 L
.74728 .30769 L
.75 .31051 L
.76508 .32692 L
.76923 .33175 L
.78068 .34615 L
.78846 .35723 L
.79356 .36538 L
.80372 .38462 L
.80769 .39374 L
.81144 .40385 L
.81715 .42308 L
.82125 .44231 L
.82398 .46154 L
.82549 .48077 L
.82588 .5 L
.82519 .51923 L
.82344 .53846 L
.82059 .55769 L
.81663 .57692 L
.81159 .59615 L
.80769 .60891 L
.80534 .61538 L
.79745 .63462 L
.78846 .65339 L
.78822 .65385 L
.77693 .67308 L
.76923 .68463 L
.7636 .69231 L
.75 .70885 L
.74759 .71154 L
.73077 .72852 L
.72833 .73077 L
.71154 .74512 L
.70536 .75 L
.69231 .75972 L
.67868 .76923 L
.67308 .77292 L
.65385 .78486 L
.64759 .78846 L
.63462 .7953 L
.61538 .80413 L
.60635 .80769 L
.59615 .81107 L
.57692 .81615 L
.55769 .81944 L
.53846 .82089 L
.51923 .8205 L
.5 .8183 L
.48077 .81432 L
.46154 .80868 L
.45862 .80769 L
.44231 .80128 L
.42308 .79252 L
.41476 .78846 L
.40385 .78283 L
.38462 .7727 L
.37801 .76923 L
.36538 .76246 L
.34615 .75202 L
.3425 .75 L
.32692 .74088 L
.31083 .73077 L
.30769 .72864 L
.28846 .71458 L
.2846 .71154 L
.26923 .69823 L
.26294 .69231 L
.25 .67901 L
.2447 .67308 L
.23077 .65621 L
.22898 .65385 L
.21521 .63462 L
.21154 .62915 L
.20298 .61538 L
.19231 .59682 L
.19196 .59615 L
.18252 .57692 L
.17473 .55769 L
.17308 .55323 L
.16916 .53846 L
.16594 .51923 L
.16516 .5 L
.16678 .48077 L
.17056 .46154 L
.17308 .45184 L
.17619 .44231 L
.18327 .42308 L
.19126 .40385 L
.19231 .4014 L
.20022 .38462 L
.20997 .36538 L
.21154 .3624 L
.22098 .34615 L
.23077 .33053 L
.23323 .32692 L
.24734 .30769 L
.25 .3043 L
.26357 .28846 L
.26923 .28235 L
.28241 .26923 L
.28846 .2637 L
.30476 .25 L
.30769 .24777 L
.32692 .23423 L
.33231 .23077 L
.34615 .22291 L
.36538 .21351 L
.36976 .21154 L
F
0 g
.38462 .20621 m
.40385 .20088 L
.42308 .19758 L
.44231 .19624 L
.46154 .19658 L
.48077 .19795 L
.5 .19957 L
.51923 .20099 L
.53846 .20234 L
.55769 .20414 L
.57692 .20685 L
.59615 .21082 L
.59917 .21154 L
.61538 .2164 L
.63462 .22376 L
.6497 .23077 L
.65385 .23297 L
.67308 .24437 L
.6815 .25 L
.69231 .25792 L
.7064 .26923 L
.71154 .27363 L
.72782 .28846 L
.73077 .29127 L
.74728 .30769 L
.75 .31051 L
.76508 .32692 L
.76923 .33175 L
.78068 .34615 L
.78846 .35723 L
.79356 .36538 L
.80372 .38462 L
.80769 .39374 L
.81144 .40385 L
.81715 .42308 L
.82125 .44231 L
.82398 .46154 L
.82549 .48077 L
.82588 .5 L
.82519 .51923 L
.82344 .53846 L
.82059 .55769 L
.81663 .57692 L
.81159 .59615 L
.80769 .60891 L
.80534 .61538 L
.79745 .63462 L
.78846 .65339 L
.78822 .65385 L
.77693 .67308 L
Mistroke
.76923 .68463 L
.7636 .69231 L
.75 .70885 L
.74759 .71154 L
.73077 .72852 L
.72833 .73077 L
.71154 .74512 L
.70536 .75 L
.69231 .75972 L
.67868 .76923 L
.67308 .77292 L
.65385 .78486 L
.64759 .78846 L
.63462 .7953 L
.61538 .80413 L
.60635 .80769 L
.59615 .81107 L
.57692 .81615 L
.55769 .81944 L
.53846 .82089 L
.51923 .8205 L
.5 .8183 L
.48077 .81432 L
.46154 .80868 L
.45862 .80769 L
.44231 .80128 L
.42308 .79252 L
.41476 .78846 L
.40385 .78283 L
.38462 .7727 L
.37801 .76923 L
.36538 .76246 L
.34615 .75202 L
.3425 .75 L
.32692 .74088 L
.31083 .73077 L
.30769 .72864 L
.28846 .71458 L
.2846 .71154 L
.26923 .69823 L
.26294 .69231 L
.25 .67901 L
.2447 .67308 L
.23077 .65621 L
.22898 .65385 L
.21521 .63462 L
.21154 .62915 L
.20298 .61538 L
.19231 .59682 L
.19196 .59615 L
Mistroke
.18252 .57692 L
.17473 .55769 L
.17308 .55323 L
.16916 .53846 L
.16594 .51923 L
.16516 .5 L
.16678 .48077 L
.17056 .46154 L
.17308 .45184 L
.17619 .44231 L
.18327 .42308 L
.19126 .40385 L
.19231 .4014 L
.20022 .38462 L
.20997 .36538 L
.21154 .3624 L
.22098 .34615 L
.23077 .33053 L
.23323 .32692 L
.24734 .30769 L
.25 .3043 L
.26357 .28846 L
.26923 .28235 L
.28241 .26923 L
.28846 .2637 L
.30476 .25 L
.30769 .24777 L
.32692 .23423 L
.33231 .23077 L
.34615 .22291 L
.36538 .21351 L
.36976 .21154 L
.38462 .20621 L
Mfstroke
.4 g
.38462 .22516 m
.40385 .22137 L
.42308 .22013 L
.44231 .22136 L
.46154 .22443 L
.48077 .2276 L
.5 .22852 L
.51923 .22721 L
.53846 .2256 L
.55769 .22505 L
.57692 .22617 L
.59615 .22923 L
.60359 .23077 L
.61538 .2344 L
.63462 .24185 L
.65091 .25 L
.65385 .2517 L
.67308 .26424 L
.67975 .26923 L
.69231 .27956 L
.70206 .28846 L
.71154 .29769 L
.72118 .30769 L
.73077 .31802 L
.73878 .32692 L
.75 .33976 L
.75541 .34615 L
.76923 .36372 L
.77044 .36538 L
.78302 .38462 L
.78846 .39468 L
.79283 .40385 L
.80028 .42308 L
.8057 .44231 L
.80769 .45137 L
.80941 .46154 L
.81166 .48077 L
.81261 .5 L
.81233 .51923 L
.81087 .53846 L
.80823 .55769 L
.80769 .5609 L
.80419 .57692 L
.79876 .59615 L
.79191 .61538 L
.78846 .62378 L
.78337 .63462 L
.77281 .65385 L
.76923 .6596 L
.75989 .67308 L
.75 .68542 L
.74393 .69231 L
.73077 .70546 L
.72407 .71154 L
.71154 .72194 L
.70008 .73077 L
.69231 .73655 L
.67381 .75 L
.67308 .75052 L
.65385 .76409 L
.64617 .76923 L
.63462 .77651 L
.61538 .78707 L
.61251 .78846 L
.59615 .79533 L
.57692 .80137 L
.55769 .80519 L
.53846 .80684 L
.51923 .80637 L
.5 .8038 L
.48077 .79915 L
.46154 .79251 L
.45182 .78846 L
.44231 .78403 L
.42308 .77408 L
.41417 .76923 L
.40385 .76356 L
.38462 .75323 L
.37837 .75 L
.36538 .74342 L
.34615 .73361 L
.34075 .73077 L
.32692 .72302 L
.30859 .71154 L
.30769 .71092 L
.28846 .69653 L
.28338 .69231 L
.26923 .67924 L
.26319 .67308 L
.25 .65816 L
.24653 .65385 L
.23243 .63462 L
.23077 .63217 L
.22032 .61538 L
.21154 .59967 L
.20974 .59615 L
.20066 .57692 L
.19318 .55769 L
.19231 .55538 L
.18769 .53846 L
.18444 .51923 L
.18361 .5 L
.18513 .48077 L
.18869 .46154 L
.19231 .44721 L
.19383 .44231 L
.20021 .42308 L
.20753 .40385 L
.21154 .39408 L
.2158 .38462 L
.22529 .36538 L
.23077 .35521 L
.23615 .34615 L
.24878 .32692 L
.25 .3252 L
.26362 .30769 L
.26923 .30113 L
.2811 .28846 L
.28846 .28132 L
.30216 .26923 L
.30769 .26484 L
.32692 .25116 L
.32868 .25 L
.34615 .24011 L
.36538 .2314 L
.36649 .23077 L
F
0 g
.38462 .22516 m
.40385 .22137 L
.42308 .22013 L
.44231 .22136 L
.46154 .22443 L
.48077 .2276 L
.5 .22852 L
.51923 .22721 L
.53846 .2256 L
.55769 .22505 L
.57692 .22617 L
.59615 .22923 L
.60359 .23077 L
.61538 .2344 L
.63462 .24185 L
.65091 .25 L
.65385 .2517 L
.67308 .26424 L
.67975 .26923 L
.69231 .27956 L
.70206 .28846 L
.71154 .29769 L
.72118 .30769 L
.73077 .31802 L
.73878 .32692 L
.75 .33976 L
.75541 .34615 L
.76923 .36372 L
.77044 .36538 L
.78302 .38462 L
.78846 .39468 L
.79283 .40385 L
.80028 .42308 L
.8057 .44231 L
.80769 .45137 L
.80941 .46154 L
.81166 .48077 L
.81261 .5 L
.81233 .51923 L
.81087 .53846 L
.80823 .55769 L
.80769 .5609 L
.80419 .57692 L
.79876 .59615 L
.79191 .61538 L
.78846 .62378 L
.78337 .63462 L
.77281 .65385 L
.76923 .6596 L
.75989 .67308 L
Mistroke
.75 .68542 L
.74393 .69231 L
.73077 .70546 L
.72407 .71154 L
.71154 .72194 L
.70008 .73077 L
.69231 .73655 L
.67381 .75 L
.67308 .75052 L
.65385 .76409 L
.64617 .76923 L
.63462 .77651 L
.61538 .78707 L
.61251 .78846 L
.59615 .79533 L
.57692 .80137 L
.55769 .80519 L
.53846 .80684 L
.51923 .80637 L
.5 .8038 L
.48077 .79915 L
.46154 .79251 L
.45182 .78846 L
.44231 .78403 L
.42308 .77408 L
.41417 .76923 L
.40385 .76356 L
.38462 .75323 L
.37837 .75 L
.36538 .74342 L
.34615 .73361 L
.34075 .73077 L
.32692 .72302 L
.30859 .71154 L
.30769 .71092 L
.28846 .69653 L
.28338 .69231 L
.26923 .67924 L
.26319 .67308 L
.25 .65816 L
.24653 .65385 L
.23243 .63462 L
.23077 .63217 L
.22032 .61538 L
.21154 .59967 L
.20974 .59615 L
.20066 .57692 L
.19318 .55769 L
.19231 .55538 L
.18769 .53846 L
Mistroke
.18444 .51923 L
.18361 .5 L
.18513 .48077 L
.18869 .46154 L
.19231 .44721 L
.19383 .44231 L
.20021 .42308 L
.20753 .40385 L
.21154 .39408 L
.2158 .38462 L
.22529 .36538 L
.23077 .35521 L
.23615 .34615 L
.24878 .32692 L
.25 .3252 L
.26362 .30769 L
.26923 .30113 L
.2811 .28846 L
.28846 .28132 L
.30216 .26923 L
.30769 .26484 L
.32692 .25116 L
.32868 .25 L
.34615 .24011 L
.36538 .2314 L
.36649 .23077 L
.38462 .22516 L
Mfstroke
.5 g
.36538 .24722 m
.38462 .24231 L
.40385 .24072 L
.42308 .24316 L
.43986 .25 L
.44231 .2516 L
.45678 .26923 L
.45611 .28846 L
.4476 .30769 L
.44231 .32324 L
.43924 .32692 L
.42887 .34615 L
.42308 .35717 L
.41815 .36538 L
.40615 .38462 L
.40385 .38813 L
.39253 .40385 L
.38462 .41393 L
.37691 .42308 L
.36538 .43584 L
.35941 .44231 L
.34615 .45628 L
.34165 .46154 L
.32721 .48077 L
.32692 .48126 L
.32005 .5 L
.32132 .51923 L
.32692 .53275 L
.33032 .53846 L
.34472 .55769 L
.34615 .55947 L
.36112 .57692 L
.36538 .5819 L
.37746 .59615 L
.38462 .60448 L
.394 .61538 L
.40385 .62527 L
.41427 .63462 L
.42308 .63936 L
.44231 .64524 L
.46154 .64524 L
.48077 .64243 L
.5 .63905 L
.51923 .63642 L
.53846 .63506 L
.55769 .63472 L
.57034 .63462 L
.57692 .63439 L
.59615 .63175 L
.61538 .6207 L
.61994 .61538 L
.62924 .59615 L
.63456 .57692 L
.63462 .57669 L
.63906 .55769 L
.64351 .53846 L
.64831 .51923 L
.6534 .5 L
.65385 .49855 L
.65846 .48077 L
.66254 .46154 L
.6642 .44231 L
.66099 .42308 L
.65385 .40926 L
.64807 .40385 L
.63462 .39355 L
.61915 .38462 L
.61538 .38256 L
.59615 .3717 L
.58607 .36538 L
.57692 .35913 L
.56108 .34615 L
.55769 .34335 L
.54224 .32692 L
.53846 .32451 L
.52786 .30769 L
.51923 .29336 L
.5172 .28846 L
.51763 .26923 L
.51923 .26663 L
.53846 .25055 L
.54291 .25 L
.55769 .24643 L
.57692 .24495 L
.59615 .24672 L
.61061 .25 L
.61538 .25139 L
.63462 .25898 L
.65295 .26923 L
.65385 .26982 L
.67308 .28408 L
.67805 .28846 L
.69231 .30231 L
.69719 .30769 L
.71154 .32444 L
.71355 .32692 L
.72924 .34615 L
.73077 .34803 L
.74546 .36538 L
.75 .37091 L
.76114 .38462 L
.76923 .39637 L
.77401 .40385 L
.78399 .42308 L
.78846 .43451 L
.79112 .44231 L
.7962 .46154 L
.79945 .48077 L
.80109 .5 L
.80126 .51923 L
.80001 .53846 L
.79734 .55769 L
.79322 .57692 L
.78846 .59353 L
.78756 .59615 L
.78006 .61538 L
.77053 .63462 L
.76923 .63692 L
.7585 .65385 L
.75 .66496 L
.74315 .67308 L
.73077 .68539 L
.72305 .69231 L
.71154 .70124 L
.69704 .71154 L
.69231 .7148 L
.67308 .72834 L
.66982 .73077 L
.65385 .74326 L
.64526 .75 L
.63462 .75818 L
.61828 .76923 L
.61538 .771 L
.59615 .78103 L
.57692 .78813 L
.57613 .78846 L
.55769 .79251 L
.53846 .79438 L
.51923 .79381 L
.5 .79085 L
.48986 .78846 L
.48077 .78547 L
.46154 .77765 L
.44527 .76923 L
.44231 .76761 L
.42308 .75608 L
.41325 .75 L
.40385 .7446 L
.38462 .73432 L
.37723 .73077 L
.36538 .7255 L
.34615 .7167 L
.33561 .71154 L
.32692 .70681 L
.30769 .69482 L
.30407 .69231 L
.28846 .67999 L
.28076 .67308 L
.26923 .66136 L
.26263 .65385 L
.25 .63752 L
.24799 .63462 L
.23586 .61538 L
.23077 .60625 L
.22575 .59615 L
.21725 .57692 L
.21154 .56128 L
.21043 .55769 L
.20531 .53846 L
.20222 .51923 L
.20136 .5 L
.20262 .48077 L
.20563 .46154 L
.20993 .44231 L
.21154 .43595 L
.21529 .42308 L
.22174 .40385 L
.22938 .38462 L
.23077 .3814 L
.23854 .36538 L
.24944 .34615 L
.25 .34523 L
.26253 .32692 L
.26923 .31824 L
.27823 .30769 L
.28846 .29695 L
.2974 .28846 L
.30769 .27977 L
.32183 .26923 L
.32692 .26595 L
.34615 .25513 L
.35673 .25 L
F
0 g
.36538 .24722 m
.38462 .24231 L
.40385 .24072 L
.42308 .24316 L
.43986 .25 L
.44231 .2516 L
.45678 .26923 L
.45611 .28846 L
.4476 .30769 L
.44231 .32324 L
.43924 .32692 L
.42887 .34615 L
.42308 .35717 L
.41815 .36538 L
.40615 .38462 L
.40385 .38813 L
.39253 .40385 L
.38462 .41393 L
.37691 .42308 L
.36538 .43584 L
.35941 .44231 L
.34615 .45628 L
.34165 .46154 L
.32721 .48077 L
.32692 .48126 L
.32005 .5 L
.32132 .51923 L
.32692 .53275 L
.33032 .53846 L
.34472 .55769 L
.34615 .55947 L
.36112 .57692 L
.36538 .5819 L
.37746 .59615 L
.38462 .60448 L
.394 .61538 L
.40385 .62527 L
.41427 .63462 L
.42308 .63936 L
.44231 .64524 L
.46154 .64524 L
.48077 .64243 L
.5 .63905 L
.51923 .63642 L
.53846 .63506 L
.55769 .63472 L
.57034 .63462 L
.57692 .63439 L
.59615 .63175 L
.61538 .6207 L
Mistroke
.61994 .61538 L
.62924 .59615 L
.63456 .57692 L
.63462 .57669 L
.63906 .55769 L
.64351 .53846 L
.64831 .51923 L
.6534 .5 L
.65385 .49855 L
.65846 .48077 L
.66254 .46154 L
.6642 .44231 L
.66099 .42308 L
.65385 .40926 L
.64807 .40385 L
.63462 .39355 L
.61915 .38462 L
.61538 .38256 L
.59615 .3717 L
.58607 .36538 L
.57692 .35913 L
.56108 .34615 L
.55769 .34335 L
.54224 .32692 L
.53846 .32451 L
.52786 .30769 L
.51923 .29336 L
.5172 .28846 L
.51763 .26923 L
.51923 .26663 L
.53846 .25055 L
.54291 .25 L
.55769 .24643 L
.57692 .24495 L
.59615 .24672 L
.61061 .25 L
.61538 .25139 L
.63462 .25898 L
.65295 .26923 L
.65385 .26982 L
.67308 .28408 L
.67805 .28846 L
.69231 .30231 L
.69719 .30769 L
.71154 .32444 L
.71355 .32692 L
.72924 .34615 L
.73077 .34803 L
.74546 .36538 L
.75 .37091 L
Mistroke
.76114 .38462 L
.76923 .39637 L
.77401 .40385 L
.78399 .42308 L
.78846 .43451 L
.79112 .44231 L
.7962 .46154 L
.79945 .48077 L
.80109 .5 L
.80126 .51923 L
.80001 .53846 L
.79734 .55769 L
.79322 .57692 L
.78846 .59353 L
.78756 .59615 L
.78006 .61538 L
.77053 .63462 L
.76923 .63692 L
.7585 .65385 L
.75 .66496 L
.74315 .67308 L
.73077 .68539 L
.72305 .69231 L
.71154 .70124 L
.69704 .71154 L
.69231 .7148 L
.67308 .72834 L
.66982 .73077 L
.65385 .74326 L
.64526 .75 L
.63462 .75818 L
.61828 .76923 L
.61538 .771 L
.59615 .78103 L
.57692 .78813 L
.57613 .78846 L
.55769 .79251 L
.53846 .79438 L
.51923 .79381 L
.5 .79085 L
.48986 .78846 L
.48077 .78547 L
.46154 .77765 L
.44527 .76923 L
.44231 .76761 L
.42308 .75608 L
.41325 .75 L
.40385 .7446 L
.38462 .73432 L
.37723 .73077 L
Mistroke
.36538 .7255 L
.34615 .7167 L
.33561 .71154 L
.32692 .70681 L
.30769 .69482 L
.30407 .69231 L
.28846 .67999 L
.28076 .67308 L
.26923 .66136 L
.26263 .65385 L
.25 .63752 L
.24799 .63462 L
.23586 .61538 L
.23077 .60625 L
.22575 .59615 L
.21725 .57692 L
.21154 .56128 L
.21043 .55769 L
.20531 .53846 L
.20222 .51923 L
.20136 .5 L
.20262 .48077 L
.20563 .46154 L
.20993 .44231 L
.21154 .43595 L
.21529 .42308 L
.22174 .40385 L
.22938 .38462 L
.23077 .3814 L
.23854 .36538 L
.24944 .34615 L
.25 .34523 L
.26253 .32692 L
.26923 .31824 L
.27823 .30769 L
.28846 .29695 L
.2974 .28846 L
.30769 .27977 L
.32183 .26923 L
.32692 .26595 L
.34615 .25513 L
.35673 .25 L
.36538 .24722 L
Mfstroke
.6 g
.34615 .26918 m
.36538 .2622 L
.38462 .25912 L
.40385 .2612 L
.41917 .26923 L
.42308 .27462 L
.42839 .28846 L
.42767 .30769 L
.42308 .32539 L
.42255 .32692 L
.41472 .34615 L
.40505 .36538 L
.40385 .36761 L
.39338 .38462 L
.38462 .39716 L
.37945 .40385 L
.36538 .4203 L
.36285 .42308 L
.34615 .43991 L
.34379 .44231 L
.32692 .45846 L
.32423 .46154 L
.30801 .48077 L
.30769 .48125 L
.30085 .5 L
.30224 .51923 L
.30769 .53311 L
.31131 .53846 L
.32682 .55769 L
.32692 .55782 L
.34443 .57692 L
.34615 .57891 L
.36104 .59615 L
.36538 .60138 L
.37614 .61538 L
.38462 .62609 L
.39084 .63462 L
.40385 .64852 L
.40777 .65385 L
.42308 .66012 L
.44231 .66319 L
.46154 .66044 L
.48077 .65587 L
.48924 .65385 L
.5 .65142 L
.51923 .64826 L
.53846 .64689 L
.55769 .64715 L
.57692 .6483 L
.59615 .64881 L
.61538 .64501 L
.62894 .63462 L
.63462 .62327 L
.63751 .61538 L
.64231 .59615 L
.64597 .57692 L
.6496 .55769 L
.65376 .53846 L
.65385 .53809 L
.65872 .51923 L
.66447 .5 L
.67063 .48077 L
.67308 .47421 L
.67645 .46154 L
.68114 .44231 L
.68339 .42308 L
.67987 .40385 L
.67308 .39181 L
.66172 .38462 L
.65385 .38018 L
.63462 .37182 L
.61944 .36538 L
.61538 .36332 L
.59615 .35248 L
.58732 .34615 L
.57692 .3385 L
.56726 .32692 L
.55769 .31236 L
.55548 .30769 L
.55247 .28846 L
.55769 .27745 L
.56938 .26923 L
.57692 .26664 L
.59615 .2656 L
.61426 .26923 L
.61538 .2695 L
.63462 .27712 L
.65197 .28846 L
.65385 .28965 L
.67247 .30769 L
.67308 .30844 L
.68725 .32692 L
.69231 .33222 L
.69889 .34615 L
.71101 .36538 L
.71154 .3664 L
.72925 .38462 L
.73077 .38592 L
.75 .40375 L
.7501 .40385 L
.76656 .42308 L
.76923 .42917 L
.77622 .44231 L
.7833 .46154 L
.78771 .48077 L
.78846 .48294 L
.79021 .5 L
.79093 .51923 L
.78999 .53846 L
.78846 .55124 L
.78742 .55769 L
.78314 .57692 L
.777 .59615 L
.76923 .61441 L
.76876 .61538 L
.75801 .63462 L
.75 .64588 L
.74386 .65385 L
.73077 .66695 L
.72435 .67308 L
.71154 .68194 L
.69424 .69231 L
.69231 .69333 L
.67308 .70412 L
.6623 .71154 L
.65385 .71879 L
.64125 .73077 L
.63462 .73759 L
.62056 .75 L
.61538 .75424 L
.59615 .76682 L
.59148 .76923 L
.57692 .77538 L
.55769 .7806 L
.53846 .78277 L
.51923 .78208 L
.5 .77855 L
.48077 .77204 L
.4744 .76923 L
.46154 .7627 L
.44263 .75 L
.44231 .74984 L
.42308 .73553 L
.4172 .73077 L
.40385 .72324 L
.38462 .71308 L
.38069 .71154 L
.36538 .70677 L
.34615 .69969 L
.32922 .69231 L
.32692 .69076 L
.30769 .67898 L
.29958 .67308 L
.28846 .66341 L
.27887 .65385 L
.26923 .64259 L
.26328 .63462 L
.2511 .61538 L
.25 .6136 L
.24146 .59615 L
.23395 .57692 L
.23077 .56709 L
.22843 .55769 L
.22427 .53846 L
.22163 .51923 L
.22069 .5 L
.22138 .48077 L
.22317 .46154 L
.22592 .44231 L
.22982 .42308 L
.23077 .4188 L
.23507 .40385 L
.24202 .38462 L
.25 .36693 L
.25083 .36538 L
.26186 .34615 L
.26923 .33519 L
.27547 .32692 L
.28846 .31185 L
.29242 .30769 L
.30769 .29374 L
.31409 .28846 L
.32692 .27968 L
.34603 .26923 L
F
0 g
.34615 .26918 m
.36538 .2622 L
.38462 .25912 L
.40385 .2612 L
.41917 .26923 L
.42308 .27462 L
.42839 .28846 L
.42767 .30769 L
.42308 .32539 L
.42255 .32692 L
.41472 .34615 L
.40505 .36538 L
.40385 .36761 L
.39338 .38462 L
.38462 .39716 L
.37945 .40385 L
.36538 .4203 L
.36285 .42308 L
.34615 .43991 L
.34379 .44231 L
.32692 .45846 L
.32423 .46154 L
.30801 .48077 L
.30769 .48125 L
.30085 .5 L
.30224 .51923 L
.30769 .53311 L
.31131 .53846 L
.32682 .55769 L
.32692 .55782 L
.34443 .57692 L
.34615 .57891 L
.36104 .59615 L
.36538 .60138 L
.37614 .61538 L
.38462 .62609 L
.39084 .63462 L
.40385 .64852 L
.40777 .65385 L
.42308 .66012 L
.44231 .66319 L
.46154 .66044 L
.48077 .65587 L
.48924 .65385 L
.5 .65142 L
.51923 .64826 L
.53846 .64689 L
.55769 .64715 L
.57692 .6483 L
.59615 .64881 L
Mistroke
.61538 .64501 L
.62894 .63462 L
.63462 .62327 L
.63751 .61538 L
.64231 .59615 L
.64597 .57692 L
.6496 .55769 L
.65376 .53846 L
.65385 .53809 L
.65872 .51923 L
.66447 .5 L
.67063 .48077 L
.67308 .47421 L
.67645 .46154 L
.68114 .44231 L
.68339 .42308 L
.67987 .40385 L
.67308 .39181 L
.66172 .38462 L
.65385 .38018 L
.63462 .37182 L
.61944 .36538 L
.61538 .36332 L
.59615 .35248 L
.58732 .34615 L
.57692 .3385 L
.56726 .32692 L
.55769 .31236 L
.55548 .30769 L
.55247 .28846 L
.55769 .27745 L
.56938 .26923 L
.57692 .26664 L
.59615 .2656 L
.61426 .26923 L
.61538 .2695 L
.63462 .27712 L
.65197 .28846 L
.65385 .28965 L
.67247 .30769 L
.67308 .30844 L
.68725 .32692 L
.69231 .33222 L
.69889 .34615 L
.71101 .36538 L
.71154 .3664 L
.72925 .38462 L
.73077 .38592 L
.75 .40375 L
.7501 .40385 L
Mistroke
.76656 .42308 L
.76923 .42917 L
.77622 .44231 L
.7833 .46154 L
.78771 .48077 L
.78846 .48294 L
.79021 .5 L
.79093 .51923 L
.78999 .53846 L
.78846 .55124 L
.78742 .55769 L
.78314 .57692 L
.777 .59615 L
.76923 .61441 L
.76876 .61538 L
.75801 .63462 L
.75 .64588 L
.74386 .65385 L
.73077 .66695 L
.72435 .67308 L
.71154 .68194 L
.69424 .69231 L
.69231 .69333 L
.67308 .70412 L
.6623 .71154 L
.65385 .71879 L
.64125 .73077 L
.63462 .73759 L
.62056 .75 L
.61538 .75424 L
.59615 .76682 L
.59148 .76923 L
.57692 .77538 L
.55769 .7806 L
.53846 .78277 L
.51923 .78208 L
.5 .77855 L
.48077 .77204 L
.4744 .76923 L
.46154 .7627 L
.44263 .75 L
.44231 .74984 L
.42308 .73553 L
.4172 .73077 L
.40385 .72324 L
.38462 .71308 L
.38069 .71154 L
.36538 .70677 L
.34615 .69969 L
.32922 .69231 L
Mistroke
.32692 .69076 L
.30769 .67898 L
.29958 .67308 L
.28846 .66341 L
.27887 .65385 L
.26923 .64259 L
.26328 .63462 L
.2511 .61538 L
.25 .6136 L
.24146 .59615 L
.23395 .57692 L
.23077 .56709 L
.22843 .55769 L
.22427 .53846 L
.22163 .51923 L
.22069 .5 L
.22138 .48077 L
.22317 .46154 L
.22592 .44231 L
.22982 .42308 L
.23077 .4188 L
.23507 .40385 L
.24202 .38462 L
.25 .36693 L
.25083 .36538 L
.26186 .34615 L
.26923 .33519 L
.27547 .32692 L
.28846 .31185 L
.29242 .30769 L
.30769 .29374 L
.31409 .28846 L
.32692 .27968 L
.34603 .26923 L
.34615 .26918 L
Mfstroke
.7 g
.34615 .28304 m
.36538 .27731 L
.38462 .27713 L
.40309 .28846 L
.40385 .28952 L
.40944 .30769 L
.40743 .32692 L
.40385 .3395 L
.40147 .34615 L
.39256 .36538 L
.38462 .37929 L
.38098 .38462 L
.36626 .40385 L
.36538 .40487 L
.34808 .42308 L
.34615 .42486 L
.32692 .4416 L
.32639 .44231 L
.30769 .45669 L
.30157 .46154 L
.28846 .47077 L
.27741 .48077 L
.26923 .48699 L
.25234 .48077 L
.25 .47553 L
.24481 .46154 L
.24352 .44231 L
.24482 .42308 L
.24848 .40385 L
.25 .39679 L
.25439 .38462 L
.26289 .36538 L
.26923 .35364 L
.27405 .34615 L
.28846 .32711 L
.28862 .32692 L
.30761 .30769 L
.30769 .30762 L
.32692 .29313 L
.33263 .28846 L
F
0 g
.34615 .28304 m
.36538 .27731 L
.38462 .27713 L
.40309 .28846 L
.40385 .28952 L
.40944 .30769 L
.40743 .32692 L
.40385 .3395 L
.40147 .34615 L
.39256 .36538 L
.38462 .37929 L
.38098 .38462 L
.36626 .40385 L
.36538 .40487 L
.34808 .42308 L
.34615 .42486 L
.32692 .4416 L
.32639 .44231 L
.30769 .45669 L
.30157 .46154 L
.28846 .47077 L
.27741 .48077 L
.26923 .48699 L
.25234 .48077 L
.25 .47553 L
.24481 .46154 L
.24352 .44231 L
.24482 .42308 L
.24848 .40385 L
.25 .39679 L
.25439 .38462 L
.26289 .36538 L
.26923 .35364 L
.27405 .34615 L
.28846 .32711 L
.28862 .32692 L
.30761 .30769 L
.30769 .30762 L
.32692 .29313 L
.33263 .28846 L
.34615 .28304 L
s
.7 g
.26923 .5297 m
.28097 .53846 L
.28846 .54497 L
.30362 .55769 L
.30769 .56112 L
.3264 .57692 L
.32692 .57869 L
.34379 .59615 L
.34615 .59885 L
.3585 .61538 L
.36538 .62365 L
.37014 .63462 L
.37946 .65385 L
.38137 .67308 L
.36538 .68541 L
.34615 .6805 L
.32692 .67309 L
.3269 .67308 L
.30769 .66184 L
.29716 .65385 L
.28846 .64491 L
.27978 .63462 L
.26923 .61853 L
.26761 .61538 L
.25835 .59615 L
.25189 .57692 L
.25185 .55769 L
.25482 .53846 L
F
0 g
.26923 .5297 m
.28097 .53846 L
.28846 .54497 L
.30362 .55769 L
.30769 .56112 L
.3264 .57692 L
.32692 .57869 L
.34379 .59615 L
.34615 .59885 L
.3585 .61538 L
.36538 .62365 L
.37014 .63462 L
.37946 .65385 L
.38137 .67308 L
.36538 .68541 L
.34615 .6805 L
.32692 .67309 L
.3269 .67308 L
.30769 .66184 L
.29716 .65385 L
.28846 .64491 L
.27978 .63462 L
.26923 .61853 L
.26761 .61538 L
.25835 .59615 L
.25189 .57692 L
.25185 .55769 L
.25482 .53846 L
.26923 .5297 L
s
.8 g
.32692 .30724 m
.34615 .29752 L
.36538 .29377 L
.38462 .29954 L
.38936 .30769 L
.39211 .32692 L
.38792 .34615 L
.38462 .35481 L
.37992 .36538 L
.36791 .38462 L
.36538 .3881 L
.35217 .40385 L
.34615 .4097 L
.33088 .42308 L
.32692 .42573 L
.30769 .43785 L
.29759 .44231 L
.28846 .44492 L
.27256 .44231 L
.26923 .43931 L
.26196 .42308 L
.26278 .40385 L
.26751 .38462 L
.26923 .37831 L
.27526 .36538 L
.28702 .34615 L
.28846 .34411 L
.30277 .32692 L
.30769 .32221 L
.32614 .30769 L
F
0 g
.32692 .30724 m
.34615 .29752 L
.36538 .29377 L
.38462 .29954 L
.38936 .30769 L
.39211 .32692 L
.38792 .34615 L
.38462 .35481 L
.37992 .36538 L
.36791 .38462 L
.36538 .3881 L
.35217 .40385 L
.34615 .4097 L
.33088 .42308 L
.32692 .42573 L
.30769 .43785 L
.29759 .44231 L
.28846 .44492 L
.27256 .44231 L
.26923 .43931 L
.26196 .42308 L
.26278 .40385 L
.26751 .38462 L
.26923 .37831 L
.27526 .36538 L
.28702 .34615 L
.28846 .34411 L
.30277 .32692 L
.30769 .32221 L
.32614 .30769 L
.32692 .30724 L
s
.9 g
.32692 .32311 m
.34615 .31372 L
.36538 .3173 L
.37547 .32692 L
.37312 .34615 L
.36538 .36497 L
.36533 .36538 L
.35344 .38462 L
.34615 .39275 L
.33617 .40385 L
.32692 .40881 L
.30769 .41889 L
.28846 .41607 L
.27889 .40385 L
.28213 .38462 L
.28846 .36836 L
.28905 .36538 L
.30151 .34615 L
.30769 .33907 L
.31957 .32692 L
F
0 g
.32692 .32311 m
.34615 .31372 L
.36538 .3173 L
.37547 .32692 L
.37312 .34615 L
.36538 .36497 L
.36533 .36538 L
.35344 .38462 L
.34615 .39275 L
.33617 .40385 L
.32692 .40881 L
.30769 .41889 L
.28846 .41607 L
.27889 .40385 L
.28213 .38462 L
.28846 .36836 L
.28905 .36538 L
.30151 .34615 L
.30769 .33907 L
.31957 .32692 L
.32692 .32311 L
s
.8 g
.28846 .58747 m
.30769 .58649 L
.31694 .59615 L
.32692 .60561 L
.33465 .61538 L
.34336 .63462 L
.32692 .64815 L
.30769 .63871 L
.30456 .63462 L
.29016 .61538 L
.28846 .61169 L
.28501 .59615 L
F
0 g
.28846 .58747 m
.30769 .58649 L
.31694 .59615 L
.32692 .60561 L
.33465 .61538 L
.34336 .63462 L
.32692 .64815 L
.30769 .63871 L
.30456 .63462 L
.29016 .61538 L
.28846 .61169 L
.28501 .59615 L
.28846 .58747 L
s
1 g
.32692 .3471 m
.34385 .36538 L
.32692 .38414 L
.31112 .36538 L
F
0 g
.32692 .3471 m
.34385 .36538 L
.32692 .38414 L
.31112 .36538 L
.32692 .3471 L
s
.3 g
.48077 .31772 m
.5 .32016 L
.51224 .32692 L
.51923 .33236 L
.53594 .34615 L
.53846 .34856 L
.55769 .36425 L
.55921 .36538 L
.57692 .37793 L
.58736 .38462 L
.59615 .38997 L
.61538 .402 L
.61805 .40385 L
.63462 .41785 L
.63852 .42308 L
.6468 .44231 L
.64806 .46154 L
.6457 .48077 L
.64162 .5 L
.63691 .51923 L
.63462 .52847 L
.63223 .53846 L
.62748 .55769 L
.62177 .57692 L
.61538 .59187 L
.61322 .59615 L
.59615 .61303 L
.59242 .61538 L
.57692 .61943 L
.55769 .62144 L
.53846 .62246 L
.51923 .62391 L
.5 .62614 L
.48077 .62866 L
.46154 .63008 L
.44231 .62814 L
.42308 .62018 L
.41553 .61538 L
.40385 .60494 L
.39506 .59615 L
.38462 .58453 L
.37794 .57692 L
.36538 .56212 L
.36185 .55769 L
.34791 .53846 L
.34615 .53548 L
.33909 .51923 L
.33782 .5 L
.34484 .48077 L
.34615 .47801 L
.35845 .46154 L
.36538 .45311 L
.37505 .44231 L
.38462 .43127 L
.39149 .42308 L
.40385 .4075 L
.40653 .40385 L
.42021 .38462 L
.42308 .3805 L
.4329 .36538 L
.44231 .35217 L
.44552 .34615 L
.46154 .32886 L
.46364 .32692 L
F
0 g
.48077 .31772 m
.5 .32016 L
.51224 .32692 L
.51923 .33236 L
.53594 .34615 L
.53846 .34856 L
.55769 .36425 L
.55921 .36538 L
.57692 .37793 L
.58736 .38462 L
.59615 .38997 L
.61538 .402 L
.61805 .40385 L
.63462 .41785 L
.63852 .42308 L
.6468 .44231 L
.64806 .46154 L
.6457 .48077 L
.64162 .5 L
.63691 .51923 L
.63462 .52847 L
.63223 .53846 L
.62748 .55769 L
.62177 .57692 L
.61538 .59187 L
.61322 .59615 L
.59615 .61303 L
.59242 .61538 L
.57692 .61943 L
.55769 .62144 L
.53846 .62246 L
.51923 .62391 L
.5 .62614 L
.48077 .62866 L
.46154 .63008 L
.44231 .62814 L
.42308 .62018 L
.41553 .61538 L
.40385 .60494 L
.39506 .59615 L
.38462 .58453 L
.37794 .57692 L
.36538 .56212 L
.36185 .55769 L
.34791 .53846 L
.34615 .53548 L
.33909 .51923 L
.33782 .5 L
.34484 .48077 L
.34615 .47801 L
Mistroke
.35845 .46154 L
.36538 .45311 L
.37505 .44231 L
.38462 .43127 L
.39149 .42308 L
.40385 .4075 L
.40653 .40385 L
.42021 .38462 L
.42308 .3805 L
.4329 .36538 L
.44231 .35217 L
.44552 .34615 L
.46154 .32886 L
.46364 .32692 L
.48077 .31772 L
Mfstroke
.2 g
.46154 .3575 m
.48077 .34703 L
.5 .34817 L
.51923 .35784 L
.53098 .36538 L
.53846 .3712 L
.55732 .38462 L
.55769 .38487 L
.57692 .39758 L
.58658 .40385 L
.59615 .41006 L
.61256 .42308 L
.61538 .42544 L
.62677 .44231 L
.63149 .46154 L
.63107 .48077 L
.62811 .5 L
.6239 .51923 L
.61898 .53846 L
.61538 .5508 L
.61334 .55769 L
.60548 .57692 L
.59615 .58955 L
.58902 .59615 L
.57692 .60176 L
.55769 .6061 L
.53846 .60802 L
.51923 .60964 L
.5 .61154 L
.48077 .61329 L
.46154 .6135 L
.44231 .60992 L
.42308 .60014 L
.4174 .59615 L
.40385 .58379 L
.39711 .57692 L
.38462 .56283 L
.38042 .55769 L
.3665 .53846 L
.36538 .53657 L
.35762 .51923 L
.35634 .5 L
.36331 .48077 L
.36538 .47644 L
.37641 .46154 L
.38462 .4512 L
.39218 .44231 L
.40385 .42819 L
.4079 .42308 L
.42287 .40385 L
.42308 .40358 L
.43712 .38462 L
.44231 .37826 L
.45192 .36538 L
F
0 g
.46154 .3575 m
.48077 .34703 L
.5 .34817 L
.51923 .35784 L
.53098 .36538 L
.53846 .3712 L
.55732 .38462 L
.55769 .38487 L
.57692 .39758 L
.58658 .40385 L
.59615 .41006 L
.61256 .42308 L
.61538 .42544 L
.62677 .44231 L
.63149 .46154 L
.63107 .48077 L
.62811 .5 L
.6239 .51923 L
.61898 .53846 L
.61538 .5508 L
.61334 .55769 L
.60548 .57692 L
.59615 .58955 L
.58902 .59615 L
.57692 .60176 L
.55769 .6061 L
.53846 .60802 L
.51923 .60964 L
.5 .61154 L
.48077 .61329 L
.46154 .6135 L
.44231 .60992 L
.42308 .60014 L
.4174 .59615 L
.40385 .58379 L
.39711 .57692 L
.38462 .56283 L
.38042 .55769 L
.3665 .53846 L
.36538 .53657 L
.35762 .51923 L
.35634 .5 L
.36331 .48077 L
.36538 .47644 L
.37641 .46154 L
.38462 .4512 L
.39218 .44231 L
.40385 .42819 L
.4079 .42308 L
.42287 .40385 L
Mistroke
.42308 .40358 L
.43712 .38462 L
.44231 .37826 L
.45192 .36538 L
.46154 .3575 L
Mfstroke
.1 g
.48077 .37621 m
.5 .37629 L
.51923 .38444 L
.5196 .38462 L
.53846 .39613 L
.55028 .40385 L
.55769 .40869 L
.57692 .42181 L
.57865 .42308 L
.59615 .43766 L
.59995 .44231 L
.61 .46154 L
.61235 .48077 L
.61079 .5 L
.60707 .51923 L
.60156 .53846 L
.59615 .55208 L
.59372 .55769 L
.57732 .57692 L
.57692 .57719 L
.55769 .58603 L
.53846 .58958 L
.51923 .59163 L
.5 .59329 L
.48077 .5943 L
.46154 .59327 L
.44231 .58788 L
.42408 .57692 L
.42308 .57597 L
.40396 .55769 L
.40385 .55758 L
.38888 .53846 L
.38462 .53088 L
.37973 .51923 L
.37834 .5 L
.38462 .48219 L
.38534 .48077 L
.39811 .46154 L
.40385 .45398 L
.41324 .44231 L
.42308 .43025 L
.42861 .42308 L
.44231 .4068 L
.44422 .40385 L
.46154 .38697 L
.46456 .38462 L
F
0 g
.48077 .37621 m
.5 .37629 L
.51923 .38444 L
.5196 .38462 L
.53846 .39613 L
.55028 .40385 L
.55769 .40869 L
.57692 .42181 L
.57865 .42308 L
.59615 .43766 L
.59995 .44231 L
.61 .46154 L
.61235 .48077 L
.61079 .5 L
.60707 .51923 L
.60156 .53846 L
.59615 .55208 L
.59372 .55769 L
.57732 .57692 L
.57692 .57719 L
.55769 .58603 L
.53846 .58958 L
.51923 .59163 L
.5 .59329 L
.48077 .5943 L
.46154 .59327 L
.44231 .58788 L
.42408 .57692 L
.42308 .57597 L
.40396 .55769 L
.40385 .55758 L
.38888 .53846 L
.38462 .53088 L
.37973 .51923 L
.37834 .5 L
.38462 .48219 L
.38534 .48077 L
.39811 .46154 L
.40385 .45398 L
.41324 .44231 L
.42308 .43025 L
.42861 .42308 L
.44231 .4068 L
.44422 .40385 L
.46154 .38697 L
.46456 .38462 L
.48077 .37621 L
s
.48077 .41622 m
.5 .41475 L
.51923 .42169 L
.52239 .42308 L
.53846 .43237 L
.55258 .44231 L
.55769 .44579 L
.57246 .46154 L
.57692 .46941 L
.58099 .48077 L
.58208 .5 L
.57798 .51923 L
.57692 .52296 L
.56982 .53846 L
.55769 .55072 L
.54225 .55769 L
.53846 .55879 L
.51923 .56276 L
.5 .56468 L
.48077 .56483 L
.46154 .56167 L
.45125 .55769 L
.44231 .55352 L
.42536 .53846 L
.42308 .53513 L
.41358 .51923 L
.41153 .5 L
.41868 .48077 L
.42308 .47206 L
.43126 .46154 L
.44231 .44805 L
.44661 .44231 L
.46154 .42819 L
.46824 .42308 L
F
.48077 .41622 m
.5 .41475 L
.51923 .42169 L
.52239 .42308 L
.53846 .43237 L
.55258 .44231 L
.55769 .44579 L
.57246 .46154 L
.57692 .46941 L
.58099 .48077 L
.58208 .5 L
.57798 .51923 L
.57692 .52296 L
.56982 .53846 L
.55769 .55072 L
.54225 .55769 L
.53846 .55879 L
.51923 .56276 L
.5 .56468 L
.48077 .56483 L
.46154 .56167 L
.45125 .55769 L
.44231 .55352 L
.42536 .53846 L
.42308 .53513 L
.41358 .51923 L
.41153 .5 L
.41868 .48077 L
.42308 .47206 L
.43126 .46154 L
.44231 .44805 L
.44661 .44231 L
.46154 .42819 L
.46824 .42308 L
.48077 .41622 L
s
.7 g
.48077 .67024 m
.5 .66386 L
.51923 .65995 L
.53846 .65852 L
.55769 .65939 L
.57692 .66217 L
.59615 .66631 L
.61538 .67128 L
.6218 .67308 L
.63462 .67833 L
.63649 .69231 L
.63462 .69813 L
.62907 .71154 L
.61693 .73077 L
.61538 .73304 L
.59742 .75 L
.59615 .75098 L
.57692 .76241 L
.55769 .76855 L
.55421 .76923 L
.53846 .77111 L
.51923 .77023 L
.51319 .76923 L
.5 .76609 L
.48077 .75803 L
.46841 .75 L
.46154 .74742 L
.44765 .73077 L
.44231 .72357 L
.43614 .71154 L
.43996 .69231 L
.44231 .69024 L
.46154 .67606 L
.47443 .67308 L
F
0 g
.48077 .67024 m
.5 .66386 L
.51923 .65995 L
.53846 .65852 L
.55769 .65939 L
.57692 .66217 L
.59615 .66631 L
.61538 .67128 L
.6218 .67308 L
.63462 .67833 L
.63649 .69231 L
.63462 .69813 L
.62907 .71154 L
.61693 .73077 L
.61538 .73304 L
.59742 .75 L
.59615 .75098 L
.57692 .76241 L
.55769 .76855 L
.55421 .76923 L
.53846 .77111 L
.51923 .77023 L
.51319 .76923 L
.5 .76609 L
.48077 .75803 L
.46841 .75 L
.46154 .74742 L
.44765 .73077 L
.44231 .72357 L
.43614 .71154 L
.43996 .69231 L
.44231 .69024 L
.46154 .67606 L
.47443 .67308 L
.48077 .67024 L
s
.8 g
.51923 .67287 m
.53846 .67112 L
.55769 .67295 L
.5586 .67308 L
.57692 .67639 L
.59615 .68951 L
.59757 .69231 L
.6029 .71154 L
.59615 .72831 L
.59451 .73077 L
.57692 .74915 L
.5726 .75 L
.55769 .75567 L
.53846 .75906 L
.51923 .75788 L
.5 .75179 L
.49618 .75 L
.48077 .73943 L
.47271 .73077 L
.46597 .71154 L
.47625 .69231 L
.48077 .68737 L
.5 .67682 L
.51755 .67308 L
F
0 g
.51923 .67287 m
.53846 .67112 L
.55769 .67295 L
.5586 .67308 L
.57692 .67639 L
.59615 .68951 L
.59757 .69231 L
.6029 .71154 L
.59615 .72831 L
.59451 .73077 L
.57692 .74915 L
.5726 .75 L
.55769 .75567 L
.53846 .75906 L
.51923 .75788 L
.5 .75179 L
.49618 .75 L
.48077 .73943 L
.47271 .73077 L
.46597 .71154 L
.47625 .69231 L
.48077 .68737 L
.5 .67682 L
.51755 .67308 L
.51923 .67287 L
s
.9 g
.51923 .68775 m
.53846 .68487 L
.55769 .68933 L
.56416 .69231 L
.57692 .70906 L
.57731 .71154 L
.57692 .71639 L
.57056 .73077 L
.55769 .73841 L
.53846 .7435 L
.51923 .74159 L
.5 .73093 L
.49983 .73077 L
.49232 .71154 L
.5 .69913 L
.50997 .69231 L
F
0 g
.51923 .68775 m
.53846 .68487 L
.55769 .68933 L
.56416 .69231 L
.57692 .70906 L
.57731 .71154 L
.57692 .71639 L
.57056 .73077 L
.55769 .73841 L
.53846 .7435 L
.51923 .74159 L
.5 .73093 L
.49983 .73077 L
.49232 .71154 L
.5 .69913 L
.50997 .69231 L
.51923 .68775 L
s
.7 g
.59615 .29564 m
.61538 .29469 L
.63462 .30421 L
.64055 .30769 L
.65174 .32692 L
.63462 .34305 L
.61538 .33709 L
.60062 .32692 L
.59615 .32207 L
.58597 .30769 L
F
0 g
.59615 .29564 m
.61538 .29469 L
.63462 .30421 L
.64055 .30769 L
.65174 .32692 L
.63462 .34305 L
.61538 .33709 L
.60062 .32692 L
.59615 .32207 L
.58597 .30769 L
.59615 .29564 L
s
.7 g
.71154 .42966 m
.73077 .42384 L
.75 .43449 L
.75975 .44231 L
.76904 .46154 L
.76923 .46263 L
.77574 .48077 L
.77951 .5 L
.78092 .51923 L
.78031 .53846 L
.77778 .55769 L
.77325 .57692 L
.76923 .58943 L
.76666 .59615 L
.7574 .61538 L
.75 .62698 L
.745 .63462 L
.73077 .64924 L
.72843 .65385 L
.71154 .66329 L
.69231 .67147 L
.6858 .67308 L
.67308 .67492 L
.65385 .67319 L
.65361 .67308 L
.64922 .65385 L
.65088 .63462 L
.6526 .61538 L
.65385 .60029 L
.65437 .59615 L
.65656 .57692 L
.65955 .55769 L
.66364 .53846 L
.66897 .51923 L
.67308 .50677 L
.67537 .5 L
.68281 .48077 L
.69162 .46154 L
.69231 .46038 L
.6981 .44231 L
F
0 g
.71154 .42966 m
.73077 .42384 L
.75 .43449 L
.75975 .44231 L
.76904 .46154 L
.76923 .46263 L
.77574 .48077 L
.77951 .5 L
.78092 .51923 L
.78031 .53846 L
.77778 .55769 L
.77325 .57692 L
.76923 .58943 L
.76666 .59615 L
.7574 .61538 L
.75 .62698 L
.745 .63462 L
.73077 .64924 L
.72843 .65385 L
.71154 .66329 L
.69231 .67147 L
.6858 .67308 L
.67308 .67492 L
.65385 .67319 L
.65361 .67308 L
.64922 .65385 L
.65088 .63462 L
.6526 .61538 L
.65385 .60029 L
.65437 .59615 L
.65656 .57692 L
.65955 .55769 L
.66364 .53846 L
.66897 .51923 L
.67308 .50677 L
.67537 .5 L
.68281 .48077 L
.69162 .46154 L
.69231 .46038 L
.6981 .44231 L
.71154 .42966 L
s
.8 g
.73077 .45325 m
.74869 .46154 L
.75 .46281 L
.76403 .48077 L
.76818 .5 L
.76923 .50894 L
.7703 .51923 L
.77027 .53846 L
.76923 .54889 L
.76799 .55769 L
.76341 .57692 L
.75578 .59615 L
.75 .60681 L
.74581 .61538 L
.73077 .63135 L
.72699 .63462 L
.71154 .64454 L
.69231 .64838 L
.67308 .63494 L
.6729 .63462 L
.66744 .61538 L
.66635 .59615 L
.66723 .57692 L
.66971 .55769 L
.67308 .54079 L
.67372 .53846 L
.67918 .51923 L
.68701 .5 L
.69231 .48973 L
.69425 .48077 L
.71154 .46219 L
.71224 .46154 L
F
0 g
.73077 .45325 m
.74869 .46154 L
.75 .46281 L
.76403 .48077 L
.76818 .5 L
.76923 .50894 L
.7703 .51923 L
.77027 .53846 L
.76923 .54889 L
.76799 .55769 L
.76341 .57692 L
.75578 .59615 L
.75 .60681 L
.74581 .61538 L
.73077 .63135 L
.72699 .63462 L
.71154 .64454 L
.69231 .64838 L
.67308 .63494 L
.6729 .63462 L
.66744 .61538 L
.66635 .59615 L
.66723 .57692 L
.66971 .55769 L
.67308 .54079 L
.67372 .53846 L
.67918 .51923 L
.68701 .5 L
.69231 .48973 L
.69425 .48077 L
.71154 .46219 L
.71224 .46154 L
.73077 .45325 L
s
.9 g
.73077 .47897 m
.73731 .48077 L
.75 .49289 L
.75433 .5 L
.75964 .51923 L
.7602 .53846 L
.75768 .55769 L
.75196 .57692 L
.75 .58196 L
.746 .59615 L
.73077 .61201 L
.72698 .61538 L
.71154 .62452 L
.69231 .62179 L
.68679 .61538 L
.67755 .59615 L
.67771 .57692 L
.67977 .55769 L
.68418 .53846 L
.69146 .51923 L
.69231 .51739 L
.70173 .5 L
.71154 .48773 L
.7218 .48077 L
F
0 g
.73077 .47897 m
.73731 .48077 L
.75 .49289 L
.75433 .5 L
.75964 .51923 L
.7602 .53846 L
.75768 .55769 L
.75196 .57692 L
.75 .58196 L
.746 .59615 L
.73077 .61201 L
.72698 .61538 L
.71154 .62452 L
.69231 .62179 L
.68679 .61538 L
.67755 .59615 L
.67771 .57692 L
.67977 .55769 L
.68418 .53846 L
.69146 .51923 L
.69231 .51739 L
.70173 .5 L
.71154 .48773 L
.7218 .48077 L
.73077 .47897 L
s
1 g
.71154 .51476 m
.73077 .50638 L
.7417 .51923 L
.7456 .53846 L
.74384 .55769 L
.73724 .57692 L
.73077 .58851 L
.72149 .59615 L
.71154 .60009 L
.70209 .59615 L
.69389 .57692 L
.6941 .55769 L
.69864 .53846 L
.70821 .51923 L
F
0 g
.71154 .51476 m
.73077 .50638 L
.7417 .51923 L
.7456 .53846 L
.74384 .55769 L
.73724 .57692 L
.73077 .58851 L
.72149 .59615 L
.71154 .60009 L
.70209 .59615 L
.69389 .57692 L
.6941 .55769 L
.69864 .53846 L
.70821 .51923 L
.71154 .51476 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.663 .741 .908 r
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55034 Mtetra
.55728 .55034 .56299 .55635 .57385 .5531 .56816 .54706 Mtetra
.56816 .54706 .57385 .5531 .58474 .54983 .57909 .54378 Mtetra
.663 .742 .908 r
.57909 .54378 .58474 .54983 .59568 .54656 .59006 .54049 Mtetra
.663 .742 .909 r
.59006 .54049 .59568 .54656 .60667 .54327 .60107 .53719 Mtetra
.60107 .53719 .60667 .54327 .61769 .53997 .61213 .53388 Mtetra
.662 .743 .91 r
.61213 .53388 .61769 .53997 .62877 .53666 .62323 .53056 Mtetra
.62323 .53056 .62877 .53666 .63988 .53333 .63438 .52724 Mtetra
.662 .744 .911 r
.63438 .52724 .63988 .53333 .65104 .53 .64557 .5239 Mtetra
.662 .745 .911 r
.64557 .5239 .65104 .53 .66224 .52665 .6568 .52054 Mtetra
.663 .745 .912 r
.6568 .52054 .66224 .52665 .67349 .52328 .66808 .51716 Mtetra
.663 .746 .912 r
.66808 .51716 .67349 .52328 .68478 .5199 .67941 .51376 Mtetra
.67941 .51376 .68478 .5199 .69612 .5165 .69078 .51033 Mtetra
.69078 .51033 .69612 .5165 .70751 .51309 .70219 .50689 Mtetra
.664 .746 .912 r
.70219 .50689 .70751 .51309 .71894 .50966 .71365 .50343 Mtetra
.664 .746 .911 r
.71365 .50343 .71894 .50966 .73041 .50621 .72516 .49995 Mtetra
.72516 .49995 .73041 .50621 .74193 .50276 .73671 .49646 Mtetra
.73671 .49646 .74193 .50276 .7535 .49928 .74831 .49295 Mtetra
.664 .745 .911 r
.74831 .49295 .7535 .49928 .76512 .49579 .75996 .48942 Mtetra
.664 .745 .91 r
.75996 .48942 .76512 .49579 .77678 .49228 .77166 .48587 Mtetra
.664 .744 .91 r
.77166 .48587 .77678 .49228 .78849 .48876 .7834 .48231 Mtetra
.664 .744 .909 r
.7834 .48231 .78849 .48876 .80024 .48522 .79519 .47872 Mtetra
.664 .743 .909 r
.79519 .47872 .80024 .48522 .81205 .48166 .80703 .47513 Mtetra
.80703 .47513 .81205 .48166 .8239 .4781 .81891 .47152 Mtetra
.664 .742 .908 r
.81891 .47152 .8239 .4781 .8358 .47452 .83085 .4679 Mtetra
.83085 .4679 .8358 .47452 .84775 .47093 .84284 .46428 Mtetra
.84284 .46428 .84775 .47093 .85976 .46733 .85487 .46064 Mtetra
.664 .741 .908 r
.85487 .46064 .85976 .46733 .87181 .46371 .86696 .457 Mtetra
.86696 .457 .87181 .46371 .88391 .46008 .87909 .45334 Mtetra
.87909 .45334 .88391 .46008 .89606 .45643 .89128 .44966 Mtetra
.89128 .44966 .89606 .45643 .90826 .45277 .90352 .44598 Mtetra
.90352 .44598 .90826 .45277 .92051 .4491 .91581 .44227 Mtetra
.91581 .44227 .92051 .4491 .93281 .44541 .92815 .43855 Mtetra
.92815 .43855 .93281 .44541 .94517 .4417 .94054 .43482 Mtetra
.94054 .43482 .94517 .4417 .95757 .43798 .95299 .43107 Mtetra
.95299 .43107 .95757 .43798 .97003 .43424 .96548 .4273 Mtetra
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.663 .741 .908 r
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55084 Mtetra
.52983 .55084 .53564 .55685 .54644 .5536 .54066 .54757 Mtetra
.54066 .54757 .54644 .5536 .55728 .55034 .55153 .54428 Mtetra
.663 .742 .908 r
.55153 .54428 .55728 .55034 .56816 .54706 .56244 .541 Mtetra
.663 .742 .909 r
.56244 .541 .56816 .54706 .57909 .54378 .57339 .53771 Mtetra
.662 .742 .909 r
.57339 .53771 .57909 .54378 .59006 .54049 .58439 .53441 Mtetra
.662 .743 .91 r
.58439 .53441 .59006 .54049 .60107 .53719 .59544 .53112 Mtetra
.661 .744 .911 r
.59544 .53112 .60107 .53719 .61213 .53388 .60652 .52783 Mtetra
.661 .745 .913 r
.60652 .52783 .61213 .53388 .62323 .53056 .61766 .52454 Mtetra
.66 .747 .914 r
.61766 .52454 .62323 .53056 .63438 .52724 .62883 .52124 Mtetra
.66 .748 .915 r
.62883 .52124 .63438 .52724 .64557 .5239 .64006 .51792 Mtetra
.661 .75 .916 r
.64006 .51792 .64557 .5239 .6568 .52054 .65132 .51458 Mtetra
.661 .752 .917 r
.65132 .51458 .6568 .52054 .66808 .51716 .66264 .51121 Mtetra
.662 .753 .918 r
.66264 .51121 .66808 .51716 .67941 .51376 .674 .5078 Mtetra
.663 .754 .918 r
.674 .5078 .67941 .51376 .69078 .51033 .6854 .50436 Mtetra
.6854 .50436 .69078 .51033 .70219 .50689 .69685 .50088 Mtetra
.664 .754 .917 r
.69685 .50088 .70219 .50689 .71365 .50343 .70834 .49737 Mtetra
.664 .753 .917 r
.70834 .49737 .71365 .50343 .72516 .49995 .71988 .49384 Mtetra
.664 .752 .916 r
.71988 .49384 .72516 .49995 .73671 .49646 .73147 .49029 Mtetra
.665 .752 .915 r
.73147 .49029 .73671 .49646 .74831 .49295 .7431 .48672 Mtetra
.665 .751 .914 r
.7431 .48672 .74831 .49295 .75996 .48942 .75478 .48313 Mtetra
.665 .749 .913 r
.75478 .48313 .75996 .48942 .77166 .48587 .7665 .47952 Mtetra
.665 .748 .912 r
.7665 .47952 .77166 .48587 .7834 .48231 .77828 .47589 Mtetra
.666 .747 .911 r
.77828 .47589 .7834 .48231 .79519 .47872 .7901 .47224 Mtetra
.665 .746 .91 r
.7901 .47224 .79519 .47872 .80703 .47513 .80197 .46858 Mtetra
.665 .745 .909 r
.80197 .46858 .80703 .47513 .81891 .47152 .81389 .46492 Mtetra
.665 .743 .909 r
.81389 .46492 .81891 .47152 .83085 .4679 .82586 .46125 Mtetra
.664 .743 .908 r
.82586 .46125 .83085 .4679 .84284 .46428 .83788 .45759 Mtetra
.664 .742 .908 r
.83788 .45759 .84284 .46428 .85487 .46064 .84995 .45392 Mtetra
.84995 .45392 .85487 .46064 .86696 .457 .86207 .45024 Mtetra
.664 .741 .908 r
.86207 .45024 .86696 .457 .87909 .45334 .87424 .44655 Mtetra
.87424 .44655 .87909 .45334 .89128 .44966 .88647 .44284 Mtetra
.88647 .44284 .89128 .44966 .90352 .44598 .89874 .43913 Mtetra
.89874 .43913 .90352 .44598 .91581 .44227 .91107 .43539 Mtetra
.91107 .43539 .91581 .44227 .92815 .43855 .92345 .43164 Mtetra
.92345 .43164 .92815 .43855 .94054 .43482 .93588 .42788 Mtetra
.93588 .42788 .94054 .43482 .95299 .43107 .94836 .4241 Mtetra
.94836 .4241 .95299 .43107 .96548 .4273 .9609 .4203 Mtetra
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.663 .741 .908 r
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54807 Mtetra
.51317 .54807 .51905 .5541 .52983 .55084 .52398 .54479 Mtetra
.52398 .54479 .52983 .55084 .54066 .54757 .53484 .5415 Mtetra
.663 .742 .909 r
.53484 .5415 .54066 .54757 .55153 .54428 .54573 .53821 Mtetra
.662 .742 .909 r
.54573 .53821 .55153 .54428 .56244 .541 .55667 .53493 Mtetra
.661 .743 .91 r
.55667 .53493 .56244 .541 .57339 .53771 .56766 .53165 Mtetra
.66 .744 .912 r
.56766 .53165 .57339 .53771 .58439 .53441 .57869 .5284 Mtetra
.659 .745 .914 r
.57869 .5284 .58439 .53441 .59544 .53112 .58976 .52516 Mtetra
.657 .748 .916 r
.58976 .52516 .59544 .53112 .60652 .52783 .60088 .52194 Mtetra
.656 .751 .919 r
.60088 .52194 .60652 .52783 .61766 .52454 .61205 .51873 Mtetra
.656 .754 .922 r
.61205 .51873 .61766 .52454 .62883 .52124 .62326 .51553 Mtetra
.655 .758 .925 r
.62326 .51553 .62883 .52124 .64006 .51792 .63452 .5123 Mtetra
.656 .762 .928 r
.63452 .5123 .64006 .51792 .65132 .51458 .64582 .50903 Mtetra
.657 .766 .93 r
.64582 .50903 .65132 .51458 .66264 .51121 .65717 .50571 Mtetra
.659 .77 .931 r
.65717 .50571 .66264 .51121 .674 .5078 .66857 .50231 Mtetra
.661 .772 .932 r
.66857 .50231 .674 .5078 .6854 .50436 .68001 .49885 Mtetra
.663 .772 .931 r
.68001 .49885 .6854 .50436 .69685 .50088 .69149 .49532 Mtetra
.664 .772 .93 r
.69149 .49532 .69685 .50088 .70834 .49737 .70301 .49173 Mtetra
.665 .77 .928 r
.70301 .49173 .70834 .49737 .71988 .49384 .71458 .4881 Mtetra
.666 .768 .926 r
.71458 .4881 .71988 .49384 .73147 .49029 .7262 .48444 Mtetra
.667 .765 .924 r
.7262 .48444 .73147 .49029 .7431 .48672 .73786 .48076 Mtetra
.667 .762 .921 r
.73786 .48076 .7431 .48672 .75478 .48313 .74957 .47706 Mtetra
.668 .759 .919 r
.74957 .47706 .75478 .48313 .7665 .47952 .76133 .47333 Mtetra
.668 .756 .917 r
.76133 .47333 .7665 .47952 .77828 .47589 .77313 .46958 Mtetra
.668 .754 .914 r
.77313 .46958 .77828 .47589 .7901 .47224 .78498 .46583 Mtetra
.668 .751 .913 r
.78498 .46583 .7901 .47224 .80197 .46858 .79688 .46207 Mtetra
.667 .748 .911 r
.79688 .46207 .80197 .46858 .81389 .46492 .80883 .45832 Mtetra
.666 .746 .91 r
.80883 .45832 .81389 .46492 .82586 .46125 .82083 .45459 Mtetra
.665 .744 .909 r
.82083 .45459 .82586 .46125 .83788 .45759 .83289 .45086 Mtetra
.665 .743 .908 r
.83289 .45086 .83788 .45759 .84995 .45392 .84499 .44715 Mtetra
.664 .742 .908 r
.84499 .44715 .84995 .45392 .86207 .45024 .85715 .44343 Mtetra
.85715 .44343 .86207 .45024 .87424 .44655 .86936 .4397 Mtetra
.664 .741 .908 r
.86936 .4397 .87424 .44655 .88647 .44284 .88162 .43597 Mtetra
.88162 .43597 .88647 .44284 .89874 .43913 .89393 .43222 Mtetra
.89393 .43222 .89874 .43913 .91107 .43539 .9063 .42846 Mtetra
.9063 .42846 .91107 .43539 .92345 .43164 .91871 .42468 Mtetra
.91871 .42468 .92345 .43164 .93588 .42788 .93118 .42089 Mtetra
.93118 .42089 .93588 .42788 .94836 .4241 .94371 .41708 Mtetra
.94371 .41708 .94836 .4241 .9609 .4203 .95628 .41325 Mtetra
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.663 .741 .908 r
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54529 Mtetra
.49646 .54529 .5024 .55134 .51317 .54807 .50725 .542 Mtetra
.663 .741 .909 r
.50725 .542 .51317 .54807 .52398 .54479 .51809 .53871 Mtetra
.662 .742 .909 r
.51809 .53871 .52398 .54479 .53484 .5415 .52897 .53542 Mtetra
.661 .742 .91 r
.52897 .53542 .53484 .5415 .54573 .53821 .5399 .53215 Mtetra
.66 .743 .912 r
.5399 .53215 .54573 .53821 .55667 .53493 .55087 .5289 Mtetra
.658 .745 .914 r
.55087 .5289 .55667 .53493 .56766 .53165 .56188 .5257 Mtetra
.655 .747 .918 r
.56188 .5257 .56766 .53165 .57869 .5284 .57294 .52255 Mtetra
.652 .751 .922 r
.57294 .52255 .57869 .5284 .58976 .52516 .58405 .51946 Mtetra
.649 .756 .928 r
.58405 .51946 .58976 .52516 .60088 .52194 .59521 .51643 Mtetra
.646 .762 .934 r
.59521 .51643 .60088 .52194 .61205 .51873 .60641 .51343 Mtetra
.643 .77 .94 r
.60641 .51343 .61205 .51873 .62326 .51553 .61766 .51044 Mtetra
.642 .779 .947 r
.61766 .51044 .62326 .51553 .63452 .5123 .62896 .50743 Mtetra
.642 .788 .952 r
.62896 .50743 .63452 .5123 .64582 .50903 .64031 .50435 Mtetra
.643 .797 .956 r
.64031 .50435 .64582 .50903 .65717 .50571 .6517 .50117 Mtetra
.647 .805 .959 r
.6517 .50117 .65717 .50571 .66857 .50231 .66314 .49784 Mtetra
.652 .81 .959 r
.66314 .49784 .66857 .50231 .68001 .49885 .67462 .49436 Mtetra
.658 .812 .957 r
.67462 .49436 .68001 .49885 .69149 .49532 .68613 .49074 Mtetra
.663 .811 .954 r
.68613 .49074 .69149 .49532 .70301 .49173 .69769 .487 Mtetra
.667 .807 .95 r
.69769 .487 .70301 .49173 .71458 .4881 .70929 .48317 Mtetra
.67 .801 .945 r
.70929 .48317 .71458 .4881 .7262 .48444 .72094 .47929 Mtetra
.671 .794 .94 r
.72094 .47929 .7262 .48444 .73786 .48076 .73263 .47538 Mtetra
.672 .786 .935 r
.73263 .47538 .73786 .48076 .74957 .47706 .74436 .47145 Mtetra
.673 .779 .93 r
.74436 .47145 .74957 .47706 .76133 .47333 .75614 .46751 Mtetra
.673 .773 .925 r
.75614 .46751 .76133 .47333 .77313 .46958 .76797 .46355 Mtetra
.673 .766 .921 r
.76797 .46355 .77313 .46958 .78498 .46583 .77984 .45961 Mtetra
.672 .76 .917 r
.77984 .45961 .78498 .46583 .79688 .46207 .79177 .45568 Mtetra
.67 .755 .914 r
.79177 .45568 .79688 .46207 .80883 .45832 .80374 .45179 Mtetra
.669 .75 .912 r
.80374 .45179 .80883 .45832 .82083 .45459 .81577 .44794 Mtetra
.667 .747 .91 r
.81577 .44794 .82083 .45459 .83289 .45086 .82786 .44412 Mtetra
.666 .745 .909 r
.82786 .44412 .83289 .45086 .84499 .44715 .84 .44034 Mtetra
.665 .743 .908 r
.84 .44034 .84499 .44715 .85715 .44343 .85219 .43658 Mtetra
.664 .742 .908 r
.85219 .43658 .85715 .44343 .86936 .4397 .86443 .43281 Mtetra
.86443 .43281 .86936 .4397 .88162 .43597 .87673 .42905 Mtetra
.664 .741 .908 r
.87673 .42905 .88162 .43597 .89393 .43222 .88908 .42527 Mtetra
.88908 .42527 .89393 .43222 .9063 .42846 .90149 .42147 Mtetra
.90149 .42147 .9063 .42846 .91871 .42468 .91394 .41767 Mtetra
.91394 .41767 .91871 .42468 .93118 .42089 .92645 .41384 Mtetra
.92645 .41384 .93118 .42089 .94371 .41708 .93901 .41 Mtetra
.93901 .41 .94371 .41708 .95628 .41325 .95162 .40615 Mtetra
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.663 .741 .908 r
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .5425 Mtetra
.47968 .5425 .4857 .54857 .49646 .54529 .49046 .5392 Mtetra
.663 .742 .909 r
.49046 .5392 .49646 .54529 .50725 .542 .50129 .5359 Mtetra
.662 .742 .909 r
.50129 .5359 .50725 .542 .51809 .53871 .51215 .53262 Mtetra
.66 .742 .911 r
.51215 .53262 .51809 .53871 .52897 .53542 .52306 .52936 Mtetra
.658 .744 .913 r
.52306 .52936 .52897 .53542 .5399 .53215 .53402 .52616 Mtetra
.654 .746 .917 r
.53402 .52616 .5399 .53215 .55087 .5289 .54502 .52303 Mtetra
.65 .749 .922 r
.54502 .52303 .55087 .5289 .56188 .5257 .55606 .52001 Mtetra
.644 .754 .929 r
.55606 .52001 .56188 .5257 .57294 .52255 .56716 .51711 Mtetra
.636 .762 .939 r
.56716 .51711 .57294 .52255 .58405 .51946 .5783 .51433 Mtetra
.627 .772 .949 r
.5783 .51433 .58405 .51946 .59521 .51643 .5895 .51168 Mtetra
.618 .784 .961 r
.5895 .51168 .59521 .51643 .60641 .51343 .60075 .50911 Mtetra
.607 .8 .973 r
.60075 .50911 .60641 .51343 .61766 .51044 .61205 .50658 Mtetra
.598 .816 .984 r
.61205 .50658 .61766 .51044 .62896 .50743 .62341 .50402 Mtetra
.59 .834 .991 r
.62341 .50402 .62896 .50743 .64031 .50435 .63481 .50134 Mtetra
.588 .851 .994 r
.63481 .50134 .64031 .50435 .6517 .50117 .64626 .49845 Mtetra
.592 .865 .994 r
.64626 .49845 .6517 .50117 .66314 .49784 .65774 .49529 Mtetra
.604 .877 .992 r
.65774 .49529 .66314 .49784 .67462 .49436 .66927 .49182 Mtetra
.621 .884 .989 r
.66927 .49182 .67462 .49436 .68613 .49074 .68083 .48803 Mtetra
.64 .884 .985 r
.68083 .48803 .68613 .49074 .69769 .487 .69242 .48399 Mtetra
.657 .877 .98 r
.69242 .48399 .69769 .487 .70929 .48317 .70404 .47977 Mtetra
.669 .865 .974 r
.70404 .47977 .70929 .48317 .72094 .47929 .71571 .47545 Mtetra
.676 .85 .966 r
.71571 .47545 .72094 .47929 .73263 .47538 .72741 .47109 Mtetra
.68 .834 .957 r
.72741 .47109 .73263 .47538 .74436 .47145 .73917 .46673 Mtetra
.682 .818 .948 r
.73917 .46673 .74436 .47145 .75614 .46751 .75096 .46238 Mtetra
.683 .803 .939 r
.75096 .46238 .75614 .46751 .76797 .46355 .7628 .45805 Mtetra
.682 .79 .931 r
.7628 .45805 .76797 .46355 .77984 .45961 .77469 .45376 Mtetra
.68 .778 .924 r
.77469 .45376 .77984 .45961 .79177 .45568 .78664 .44954 Mtetra
.677 .767 .919 r
.78664 .44954 .79177 .45568 .80374 .45179 .79863 .4454 Mtetra
.674 .759 .915 r
.79863 .4454 .80374 .45179 .81577 .44794 .81069 .44135 Mtetra
.67 .752 .912 r
.81069 .44135 .81577 .44794 .82786 .44412 .8228 .4374 Mtetra
.668 .748 .91 r
.8228 .4374 .82786 .44412 .84 .44034 .83497 .43352 Mtetra
.666 .745 .909 r
.83497 .43352 .84 .44034 .85219 .43658 .84719 .42969 Mtetra
.665 .743 .908 r
.84719 .42969 .85219 .43658 .86443 .43281 .85947 .42588 Mtetra
.664 .742 .908 r
.85947 .42588 .86443 .43281 .87673 .42905 .87181 .42207 Mtetra
.87181 .42207 .87673 .42905 .88908 .42527 .8842 .41826 Mtetra
.664 .741 .908 r
.8842 .41826 .88908 .42527 .90149 .42147 .89664 .41443 Mtetra
.89664 .41443 .90149 .42147 .91394 .41767 .90913 .4106 Mtetra
.90913 .4106 .91394 .41767 .92645 .41384 .92168 .40674 Mtetra
.92168 .40674 .92645 .41384 .93901 .41 .93428 .40287 Mtetra
.93428 .40287 .93901 .41 .95162 .40615 .94693 .39899 Mtetra
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55285 Mtetra
.42022 .55285 .42641 .55885 .43698 .5556 .43081 .54958 Mtetra
.43081 .54958 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.663 .741 .908 r
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .5397 Mtetra
.46286 .5397 .46895 .54579 .47968 .5425 .47362 .53639 Mtetra
.662 .742 .909 r
.47362 .53639 .47968 .5425 .49046 .5392 .48443 .53309 Mtetra
.661 .742 .91 r
.48443 .53309 .49046 .5392 .50129 .5359 .49528 .52981 Mtetra
.659 .743 .912 r
.49528 .52981 .50129 .5359 .51215 .53262 .50617 .52657 Mtetra
.656 .744 .915 r
.50617 .52657 .51215 .53262 .52306 .52936 .51711 .52342 Mtetra
.65 .747 .92 r
.51711 .52342 .52306 .52936 .53402 .52616 .5281 .52038 Mtetra
.643 .751 .927 r
.5281 .52038 .53402 .52616 .54502 .52303 .53913 .51751 Mtetra
.632 .758 .938 r
.53913 .51751 .54502 .52303 .55606 .52001 .55021 .51485 Mtetra
.617 .767 .952 r
.55021 .51485 .55606 .52001 .56716 .51711 .56134 .51243 Mtetra
.597 .78 .968 r
.56134 .51243 .56716 .51711 .5783 .51433 .57253 .51025 Mtetra
.569 .796 .985 r
.57253 .51025 .5783 .51433 .5895 .51168 .58377 .5083 Mtetra
.531 .813 .998 r
.58377 .5083 .5895 .51168 .60075 .50911 .59508 .50651 Mtetra
.481 .825 .998 r
.59508 .50651 .60075 .50911 .61205 .50658 .60644 .50481 Mtetra
.42 .827 .977 r
.60644 .50481 .61205 .50658 .62341 .50402 .61787 .50307 Mtetra
.357 .816 .931 r
.61787 .50307 .62341 .50402 .63481 .50134 .62934 .50112 Mtetra
.31 .799 .872 r
.62934 .50112 .63481 .50134 .64626 .49845 .64086 .49881 Mtetra
.294 .792 .823 r
.64086 .49881 .64626 .49845 .65774 .49529 .65242 .49599 Mtetra
.317 .806 .804 r
.65242 .49599 .65774 .49529 .66927 .49182 .664 .49255 Mtetra
.376 .841 .819 r
.664 .49255 .66927 .49182 .68083 .48803 .67561 .48849 Mtetra
.457 .887 .861 r
.67561 .48849 .68083 .48803 .69242 .48399 .68723 .48392 Mtetra
.542 .924 .911 r
.68723 .48392 .69242 .48399 .70404 .47977 .69888 .47897 Mtetra
.611 .94 .95 r
.69888 .47897 .70404 .47977 .71571 .47545 .71056 .47383 Mtetra
.656 .933 .97 r
.71056 .47383 .71571 .47545 .72741 .47109 .72227 .46865 Mtetra
.682 .911 .974 r
.72227 .46865 .72741 .47109 .73917 .46673 .73402 .4635 Mtetra
.694 .884 .968 r
.73402 .4635 .73917 .46673 .75096 .46238 .74582 .45843 Mtetra
.699 .856 .958 r
.74582 .45843 .75096 .46238 .7628 .45805 .75766 .45345 Mtetra
.698 .831 .946 r
.75766 .45345 .7628 .45805 .77469 .45376 .76956 .44858 Mtetra
.695 .808 .935 r
.76956 .44858 .77469 .45376 .78664 .44954 .7815 .44385 Mtetra
.689 .789 .927 r
.7815 .44385 .78664 .44954 .79863 .4454 .79351 .43929 Mtetra
.683 .773 .92 r
.79351 .43929 .79863 .4454 .81069 .44135 .80558 .43493 Mtetra
.677 .761 .915 r
.80558 .43493 .81069 .44135 .8228 .4374 .81771 .43075 Mtetra
.672 .753 .912 r
.81771 .43075 .8228 .4374 .83497 .43352 .8299 .42671 Mtetra
.668 .748 .91 r
.8299 .42671 .83497 .43352 .84719 .42969 .84216 .42278 Mtetra
.666 .744 .909 r
.84216 .42278 .84719 .42969 .85947 .42588 .85447 .4189 Mtetra
.665 .743 .908 r
.85447 .4189 .85947 .42588 .87181 .42207 .86684 .41504 Mtetra
.664 .742 .908 r
.86684 .41504 .87181 .42207 .8842 .41826 .87927 .4112 Mtetra
.87927 .4112 .8842 .41826 .89664 .41443 .89175 .40734 Mtetra
.664 .741 .908 r
.89175 .40734 .89664 .41443 .90913 .4106 .90428 .40347 Mtetra
.90428 .40347 .90913 .4106 .92168 .40674 .91687 .39958 Mtetra
.91687 .39958 .92168 .40674 .93428 .40287 .92951 .39568 Mtetra
.92951 .39568 .93428 .40287 .94693 .39899 .9422 .39177 Mtetra
.36148 .56308 .36785 .56901 .37824 .5658 .37189 .55985 Mtetra
.37189 .55985 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55285 .41397 .5468 Mtetra
.41397 .5468 .42022 .55285 .43081 .54958 .4246 .54351 Mtetra
.663 .741 .908 r
.4246 .54351 .43081 .54958 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53689 Mtetra
.44597 .53689 .45213 .543 .46286 .5397 .45672 .53357 Mtetra
.662 .742 .909 r
.45672 .53357 .46286 .5397 .47362 .53639 .46751 .53027 Mtetra
.661 .742 .91 r
.46751 .53027 .47362 .53639 .48443 .53309 .47835 .52699 Mtetra
.658 .743 .912 r
.47835 .52699 .48443 .53309 .49528 .52981 .48922 .52377 Mtetra
.653 .744 .916 r
.48922 .52377 .49528 .52981 .50617 .52657 .50015 .52066 Mtetra
.646 .747 .923 r
.50015 .52066 .50617 .52657 .51711 .52342 .51111 .51773 Mtetra
.634 .752 .933 r
.51111 .51773 .51711 .52342 .5281 .52038 .52213 .51504 Mtetra
.617 .76 .948 r
.52213 .51504 .5281 .52038 .53913 .51751 .53319 .51267 Mtetra
.59 .772 .966 r
.53319 .51267 .53913 .51751 .55021 .51485 .54431 .51067 Mtetra
.549 .785 .986 r
.54431 .51067 .55021 .51485 .56134 .51243 .55548 .50907 Mtetra
.483 .794 .999 r
.55548 .50907 .56134 .51243 .57253 .51025 .56672 .50789 Mtetra
.378 .785 .983 r
.56672 .50789 .57253 .51025 .58377 .5083 .57803 .50707 Mtetra
.224 .728 .899 r
.57803 .50707 .58377 .5083 .59508 .50651 .5894 .50655 Mtetra
.04 .61 .728 r
.5894 .50655 .59508 .50651 .60644 .50481 .60085 .50619 Mtetra
.116 0 0 r
.60085 .50619 .60644 .50481 .61787 .50307 .61236 .50579 Mtetra
.212 0 0 r
.61236 .50579 .61787 .50307 .62934 .50112 .62394 .50508 Mtetra
.25 0 0 r
.62394 .50508 .62934 .50112 .64086 .49881 .63556 .50376 Mtetra
.243 0 0 r
.63556 .50376 .64086 .49881 .65242 .49599 .64721 .50152 Mtetra
.201 0 0 r
.64721 .50152 .65242 .49599 .664 .49255 .65887 .49818 Mtetra
.126 0 0 r
.65887 .49818 .664 .49255 .67561 .48849 .67054 .49369 Mtetra
.015 0 0 r
.67054 .49369 .67561 .48849 .68723 .48392 .6822 .48822 Mtetra
0 0 0 r
.6822 .48822 .68723 .48392 .69888 .47897 .69386 .48206 Mtetra
.69386 .48206 .69888 .47897 .71056 .47383 .70553 .47554 Mtetra
.481 .888 .757 r
.70553 .47554 .71056 .47383 .72227 .46865 .71723 .46897 Mtetra
.609 .955 .883 r
.71723 .46897 .72227 .46865 .73402 .4635 .72897 .46252 Mtetra
.68 .959 .945 r
.72897 .46252 .73402 .4635 .74582 .45843 .74075 .45627 Mtetra
.711 .931 .962 r
.74075 .45627 .74582 .45843 .75766 .45345 .75258 .45023 Mtetra
.72 .894 .959 r
.75258 .45023 .75766 .45345 .76956 .44858 .76445 .44443 Mtetra
.718 .857 .948 r
.76445 .44443 .76956 .44858 .7815 .44385 .77639 .43889 Mtetra
.709 .824 .936 r
.77639 .43889 .7815 .44385 .79351 .43929 .78839 .43367 Mtetra
.698 .797 .927 r
.78839 .43367 .79351 .43929 .80558 .43493 .80046 .4288 Mtetra
.687 .777 .919 r
.80046 .4288 .80558 .43493 .81771 .43075 .8126 .42425 Mtetra
.678 .762 .914 r
.8126 .42425 .81771 .43075 .8299 .42671 .82481 .41996 Mtetra
.672 .753 .911 r
.82481 .41996 .8299 .42671 .84216 .42278 .83709 .41587 Mtetra
.668 .747 .909 r
.83709 .41587 .84216 .42278 .85447 .4189 .84944 .41189 Mtetra
.666 .744 .909 r
.84944 .41189 .85447 .4189 .86684 .41504 .86184 .40797 Mtetra
.664 .742 .908 r
.86184 .40797 .86684 .41504 .87927 .4112 .87431 .40408 Mtetra
.87431 .40408 .87927 .4112 .89175 .40734 .88682 .40019 Mtetra
.664 .741 .908 r
.88682 .40019 .89175 .40734 .90428 .40347 .89939 .39629 Mtetra
.89939 .39629 .90428 .40347 .91687 .39958 .91202 .39237 Mtetra
.91202 .39237 .91687 .39958 .92951 .39568 .9247 .38844 Mtetra
.9247 .38844 .92951 .39568 .9422 .39177 .93743 .38449 Mtetra
.35506 .5571 .36148 .56308 .37189 .55985 .3655 .55385 Mtetra
.3655 .55385 .37189 .55985 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.663 .741 .908 r
.40769 .54071 .41397 .5468 .4246 .54351 .41834 .53739 Mtetra
.41834 .53739 .4246 .54351 .43526 .5402 .42903 .53407 Mtetra
.42903 .53407 .43526 .5402 .44597 .53689 .43976 .53074 Mtetra
.662 .742 .909 r
.43976 .53074 .44597 .53689 .45672 .53357 .45054 .52743 Mtetra
.66 .742 .91 r
.45054 .52743 .45672 .53357 .46751 .53027 .46136 .52415 Mtetra
.657 .743 .913 r
.46136 .52415 .46751 .53027 .47835 .52699 .47222 .52095 Mtetra
.651 .744 .918 r
.47222 .52095 .47835 .52699 .48922 .52377 .48312 .5179 Mtetra
.641 .748 .926 r
.48312 .5179 .48922 .52377 .50015 .52066 .49407 .51507 Mtetra
.625 .753 .939 r
.49407 .51507 .50015 .52066 .51111 .51773 .50506 .51258 Mtetra
.598 .762 .958 r
.50506 .51258 .51111 .51773 .52213 .51504 .51611 .51053 Mtetra
.554 .773 .98 r
.51611 .51053 .52213 .51504 .53319 .51267 .5272 .50901 Mtetra
.478 .779 .997 r
.5272 .50901 .53319 .51267 .54431 .51067 .53836 .50809 Mtetra
.344 .759 .979 r
.53836 .50809 .54431 .51067 .55548 .50907 .54959 .50777 Mtetra
.13 .663 .861 r
.54959 .50777 .55548 .50907 .56672 .50789 .56088 .50805 Mtetra
.122 0 0 r
.56088 .50805 .56672 .50789 .57803 .50707 .57226 .50888 Mtetra
.318 0 0 r
.57226 .50888 .57803 .50707 .5894 .50655 .58372 .51017 Mtetra
.429 0 0 r
.58372 .51017 .5894 .50655 .60085 .50619 .59527 .51174 Mtetra
.479 0 .036 r
.59527 .51174 .60085 .50619 .61236 .50579 .6069 .51331 Mtetra
.493 .051 .128 r
.6069 .51331 .61236 .50579 .62394 .50508 .61861 .51446 Mtetra
.482 .07 .182 r
.61861 .51446 .62394 .50508 .63556 .50376 .63036 .51465 Mtetra
.453 .062 .207 r
.63036 .51465 .63556 .50376 .64721 .50152 .64214 .51336 Mtetra
.407 .03 .208 r
.64214 .51336 .64721 .50152 .65887 .49818 .65391 .51019 Mtetra
.345 0 .185 r
.65391 .51019 .65887 .49818 .67054 .49369 .66565 .50507 Mtetra
.264 0 .134 r
.66565 .50507 .67054 .49369 .6822 .48822 .67735 .49824 Mtetra
.159 0 .047 r
.67735 .49824 .6822 .48822 .69386 .48206 .68902 .49022 Mtetra
.023 0 0 r
.68902 .49022 .69386 .48206 .70553 .47554 .70068 .4816 Mtetra
0 0 0 r
.70068 .4816 .70553 .47554 .71723 .46897 .71234 .47293 Mtetra
.71234 .47293 .71723 .46897 .72897 .46252 .72404 .46453 Mtetra
.551 .916 .741 r
.72404 .46453 .72897 .46252 .74075 .45627 .73578 .45653 Mtetra
.677 .977 .88 r
.73578 .45653 .74075 .45627 .75258 .45023 .74757 .44894 Mtetra
.733 .965 .938 r
.74757 .44894 .75258 .45023 .76445 .44443 .75941 .44176 Mtetra
.746 .922 .95 r
.75941 .44176 .76445 .44443 .77639 .43889 .77131 .43502 Mtetra
.738 .875 .944 r
.77131 .43502 .77639 .43889 .78839 .43367 .78328 .42879 Mtetra
.722 .833 .934 r
.78328 .42879 .78839 .43367 .80046 .4288 .79533 .42313 Mtetra
.705 .8 .924 r
.79533 .42313 .80046 .4288 .8126 .42425 .80747 .418 Mtetra
.69 .776 .917 r
.80747 .418 .8126 .42425 .82481 .41996 .81969 .41332 Mtetra
.679 .761 .913 r
.81969 .41332 .82481 .41996 .83709 .41587 .83199 .40899 Mtetra
.671 .751 .91 r
.83199 .40899 .83709 .41587 .84944 .41189 .84437 .40487 Mtetra
.667 .746 .909 r
.84437 .40487 .84944 .41189 .86184 .40797 .85681 .40087 Mtetra
.665 .743 .908 r
.85681 .40087 .86184 .40797 .87431 .40408 .8693 .39692 Mtetra
.664 .742 .908 r
.8693 .39692 .87431 .40408 .88682 .40019 .88186 .39298 Mtetra
.88186 .39298 .88682 .40019 .89939 .39629 .89447 .38905 Mtetra
.664 .741 .908 r
.89447 .38905 .89939 .39629 .91202 .39237 .90713 .3851 Mtetra
.90713 .3851 .91202 .39237 .9247 .38844 .91985 .38114 Mtetra
.91985 .38114 .9247 .38844 .93743 .38449 .93263 .37715 Mtetra
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.663 .741 .908 r
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53458 Mtetra
.40135 .53458 .40769 .54071 .41834 .53739 .41203 .53124 Mtetra
.41203 .53124 .41834 .53739 .42903 .53407 .42275 .52791 Mtetra
.662 .742 .909 r
.42275 .52791 .42903 .53407 .43976 .53074 .43351 .52458 Mtetra
.66 .742 .911 r
.43351 .52458 .43976 .53074 .45054 .52743 .44431 .5213 Mtetra
.656 .743 .914 r
.44431 .5213 .45054 .52743 .46136 .52415 .45515 .51811 Mtetra
.649 .744 .919 r
.45515 .51811 .46136 .52415 .47222 .52095 .46604 .5151 Mtetra
.636 .748 .929 r
.46604 .5151 .47222 .52095 .48312 .5179 .47697 .51238 Mtetra
.614 .754 .945 r
.47697 .51238 .48312 .5179 .49407 .51507 .48794 .5101 Mtetra
.575 .762 .967 r
.48794 .5101 .49407 .51507 .50506 .51258 .49896 .5084 Mtetra
.505 .769 .991 r
.49896 .5084 .50506 .51258 .51611 .51053 .51003 .50742 Mtetra
.372 .753 .989 r
.51003 .50742 .51611 .51053 .5272 .50901 .52116 .50725 Mtetra
.139 .659 .886 r
.52116 .50725 .5272 .50901 .53836 .50809 .53236 .50789 Mtetra
.155 0 0 r
.53236 .50789 .53836 .50809 .54959 .50777 .54364 .50932 Mtetra
.377 0 0 r
.54364 .50932 .54959 .50777 .56088 .50805 .55501 .51151 Mtetra
.496 0 0 r
.55501 .51151 .56088 .50805 .57226 .50888 .56647 .51441 Mtetra
.555 .083 .089 r
.56647 .51441 .57226 .50888 .58372 .51017 .57803 .51796 Mtetra
.581 .152 .19 r
.57803 .51796 .58372 .51017 .59527 .51174 .5897 .52199 Mtetra
.588 .191 .257 r
.5897 .52199 .59527 .51174 .6069 .51331 .60147 .52614 Mtetra
.58 .208 .301 r
.60147 .52614 .6069 .51331 .61861 .51446 .61333 .52978 Mtetra
.558 .205 .327 r
.61333 .52978 .61861 .51446 .63036 .51465 .62526 .53206 Mtetra
.523 .186 .338 r
.62526 .53206 .63036 .51465 .64214 .51336 .63719 .53209 Mtetra
.475 .15 .335 r
.63719 .53209 .64214 .51336 .65391 .51019 .6491 .52922 Mtetra
.415 .099 .318 r
.6491 .52922 .65391 .51019 .66565 .50507 .66093 .52324 Mtetra
.342 .03 .283 r
.66093 .52324 .66565 .50507 .67735 .49824 .67268 .51455 Mtetra
.256 0 .226 r
.67268 .51455 .67735 .49824 .68902 .49022 .68436 .50397 Mtetra
.152 0 .141 r
.68436 .50397 .68902 .49022 .70068 .4816 .69599 .4925 Mtetra
.026 0 .016 r
.69599 .4925 .70068 .4816 .71234 .47293 .70761 .48101 Mtetra
0 0 0 r
.70761 .48101 .71234 .47293 .72404 .46453 .71925 .47001 Mtetra
.71925 .47001 .72404 .46453 .73578 .45653 .73094 .4597 Mtetra
.538 .882 .636 r
.73094 .4597 .73578 .45653 .74757 .44894 .74267 .45005 Mtetra
.691 .98 .819 r
.74267 .45005 .74757 .44894 .75941 .44176 .75445 .44101 Mtetra
.761 .983 .908 r
.75445 .44101 .75941 .44176 .77131 .43502 .7663 .43262 Mtetra
.772 .938 .936 r
.7663 .43262 .77131 .43502 .78328 .42879 .77822 .42496 Mtetra
.755 .883 .937 r
.77822 .42496 .78328 .42879 .79533 .42313 .79023 .41814 Mtetra
.73 .834 .929 r
.79023 .41814 .79533 .42313 .80747 .418 .80234 .41215 Mtetra
.707 .798 .921 r
.80234 .41215 .80747 .418 .81969 .41332 .81456 .40689 Mtetra
.689 .773 .915 r
.81456 .40689 .81969 .41332 .83199 .40899 .82687 .40219 Mtetra
.677 .757 .912 r
.82687 .40219 .83199 .40899 .84437 .40487 .83926 .39785 Mtetra
.67 .749 .91 r
.83926 .39785 .84437 .40487 .85681 .40087 .85173 .39373 Mtetra
.666 .745 .909 r
.85173 .39373 .85681 .40087 .8693 .39692 .86426 .38971 Mtetra
.665 .743 .908 r
.86426 .38971 .8693 .39692 .88186 .39298 .87685 .38573 Mtetra
.664 .742 .908 r
.87685 .38573 .88186 .39298 .89447 .38905 .8895 .38175 Mtetra
.664 .741 .908 r
.8895 .38175 .89447 .38905 .90713 .3851 .90221 .37777 Mtetra
.90221 .37777 .90713 .3851 .91985 .38114 .91497 .37377 Mtetra
.91497 .37377 .91985 .38114 .93263 .37715 .92778 .36976 Mtetra
.663 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54173 Mtetra
.35259 .54173 .35907 .54781 .36958 .54452 .36312 .53842 Mtetra
.36312 .53842 .36958 .54452 .38013 .54122 .3737 .53509 Mtetra
.3737 .53509 .38013 .54122 .39072 .5379 .38431 .53176 Mtetra
.38431 .53176 .39072 .5379 .40135 .53458 .39497 .52841 Mtetra
.663 .742 .908 r
.39497 .52841 .40135 .53458 .41203 .53124 .40568 .52506 Mtetra
.662 .742 .909 r
.40568 .52506 .41203 .53124 .42275 .52791 .41642 .52173 Mtetra
.66 .742 .911 r
.41642 .52173 .42275 .52791 .43351 .52458 .42721 .51843 Mtetra
.656 .743 .914 r
.42721 .51843 .43351 .52458 .44431 .5213 .43803 .51525 Mtetra
.647 .744 .92 r
.43803 .51525 .44431 .5213 .45515 .51811 .4489 .51227 Mtetra
.632 .747 .931 r
.4489 .51227 .45515 .51811 .46604 .5151 .45981 .50964 Mtetra
.603 .753 .95 r
.45981 .50964 .46604 .5151 .47697 .51238 .47075 .50755 Mtetra
.549 .76 .975 r
.47075 .50755 .47697 .51238 .48794 .5101 .48174 .50622 Mtetra
.442 .756 .995 r
.48174 .50622 .48794 .5101 .49896 .5084 .49278 .50583 Mtetra
.225 .691 .944 r
.49278 .50583 .49896 .5084 .51003 .50742 .50388 .50649 Mtetra
.108 0 0 r
.50388 .50649 .51003 .50742 .52116 .50725 .51505 .5082 Mtetra
.383 0 0 r
.51505 .5082 .52116 .50725 .53236 .50789 .5263 .51089 Mtetra
.518 0 0 r
.5263 .51089 .53236 .50789 .54364 .50932 .53764 .51442 Mtetra
.577 .101 .088 r
.53764 .51442 .54364 .50932 .55501 .51151 .54908 .51872 Mtetra
.607 .172 .189 r
.54908 .51872 .55501 .51151 .56647 .51441 .56063 .5238 Mtetra
.624 .22 .257 r
.56063 .5238 .56647 .51441 .57803 .51796 .5723 .52973 Mtetra
.633 .253 .307 r
.5723 .52973 .57803 .51796 .5897 .52199 .5841 .53643 Mtetra
.631 .273 .344 r
.5841 .53643 .5897 .52199 .60147 .52614 .59603 .5435 Mtetra
.619 .277 .37 r
.59603 .5435 .60147 .52614 .61333 .52978 .60807 .55008 Mtetra
.593 .266 .385 r
.60807 .55008 .61333 .52978 .62526 .53206 .62018 .5549 Mtetra
.555 .241 .391 r
.62018 .5549 .62526 .53206 .63719 .53209 .6323 .55659 Mtetra
.502 .2 .385 r
.6323 .55659 .63719 .53209 .6491 .52922 .64437 .55411 Mtetra
.436 .144 .368 r
.64437 .55411 .6491 .52922 .66093 .52324 .65632 .54712 Mtetra
.358 .073 .337 r
.65632 .54712 .66093 .52324 .67268 .51455 .66813 .53617 Mtetra
.269 0 .29 r
.66813 .53617 .67268 .51455 .68436 .50397 .67981 .5225 Mtetra
.173 0 .222 r
.67981 .5225 .68436 .50397 .69599 .4925 .69141 .50762 Mtetra
.069 0 .131 r
.69141 .50762 .69599 .4925 .70761 .48101 .70299 .49282 Mtetra
0 0 .008 r
.70299 .49282 .70761 .48101 .71925 .47001 .71458 .47884 Mtetra
0 0 0 r
.71458 .47884 .71925 .47001 .73094 .4597 .72621 .46588 Mtetra
.72621 .46588 .73094 .4597 .74267 .45005 .73788 .45383 Mtetra
.576 .882 .594 r
.73788 .45383 .74267 .45005 .75445 .44101 .7496 .44255 Mtetra
.729 .984 .782 r
.7496 .44255 .75445 .44101 .7663 .43262 .76137 .43205 Mtetra
.795 .99 .886 r
.76137 .43205 .7663 .43262 .77822 .42496 .77321 .42251 Mtetra
.794 .94 .923 r
.77321 .42251 .77822 .42496 .79023 .41814 .78515 .4141 Mtetra
.765 .879 .929 r
.78515 .4141 .79023 .41814 .80234 .41215 .79722 .40689 Mtetra
.732 .828 .924 r
.79722 .40689 .80234 .41215 .81456 .40689 .80941 .40077 Mtetra
.705 .791 .918 r
.80941 .40077 .81456 .40689 .82687 .40219 .82172 .39553 Mtetra
.686 .767 .913 r
.82172 .39553 .82687 .40219 .83926 .39785 .83412 .39087 Mtetra
.675 .754 .91 r
.83412 .39087 .83926 .39785 .85173 .39373 .84662 .38657 Mtetra
.668 .747 .909 r
.84662 .38657 .85173 .39373 .86426 .38971 .85918 .38245 Mtetra
.665 .743 .908 r
.85918 .38245 .86426 .38971 .87685 .38573 .87181 .37842 Mtetra
.664 .742 .908 r
.87181 .37842 .87685 .38573 .8895 .38175 .8845 .3744 Mtetra
.8845 .3744 .8895 .38175 .90221 .37777 .89724 .37038 Mtetra
.664 .741 .908 r
.89724 .37038 .90221 .37777 .91497 .37377 .91004 .36635 Mtetra
.91004 .36635 .91497 .37377 .92778 .36976 .9229 .36231 Mtetra
.663 .741 .908 r
.33554 .53893 .34209 .54503 .35259 .54173 .34605 .53561 Mtetra
.34605 .53561 .35259 .54173 .36312 .53842 .35661 .53227 Mtetra
.35661 .53227 .36312 .53842 .3737 .53509 .36722 .52893 Mtetra
.663 .742 .908 r
.36722 .52893 .3737 .53509 .38431 .53176 .37786 .52557 Mtetra
.663 .742 .909 r
.37786 .52557 .38431 .53176 .39497 .52841 .38855 .52221 Mtetra
.662 .742 .909 r
.38855 .52221 .39497 .52841 .40568 .52506 .39927 .51886 Mtetra
.66 .742 .911 r
.39927 .51886 .40568 .52506 .41642 .52173 .41004 .51556 Mtetra
.656 .743 .914 r
.41004 .51556 .41642 .52173 .42721 .51843 .42085 .51236 Mtetra
.647 .744 .92 r
.42085 .51236 .42721 .51843 .43803 .51525 .4317 .50939 Mtetra
.629 .747 .932 r
.4317 .50939 .43803 .51525 .4489 .51227 .44259 .50682 Mtetra
.594 .751 .953 r
.44259 .50682 .4489 .51227 .45981 .50964 .45351 .50489 Mtetra
.524 .754 .98 r
.45351 .50489 .45981 .50964 .47075 .50755 .46446 .50389 Mtetra
.37 .731 .989 r
.46446 .50389 .47075 .50755 .48174 .50622 .47546 .50409 Mtetra
.051 .588 .854 r
.47546 .50409 .48174 .50622 .49278 .50583 .48652 .50567 Mtetra
.329 0 0 r
.48652 .50567 .49278 .50583 .50388 .50649 .49764 .50861 Mtetra
.529 0 0 r
.49764 .50861 .50388 .50649 .51505 .5082 .50884 .51275 Mtetra
.597 .116 .081 r
.50884 .51275 .51505 .5082 .5263 .51089 .52015 .51775 Mtetra
.62 .182 .188 r
.52015 .51775 .5263 .51089 .53764 .51442 .53156 .52335 Mtetra
.629 .22 .25 r
.53156 .52335 .53764 .51442 .54908 .51872 .54308 .52946 Mtetra
.637 .248 .292 r
.54308 .52946 .54908 .51872 .56063 .5238 .55472 .53627 Mtetra
.647 .274 .324 r
.55472 .53627 .56063 .5238 .5723 .52973 .56649 .54409 Mtetra
.656 .297 .351 r
.56649 .54409 .5723 .52973 .5841 .53643 .57842 .55308 Mtetra
.657 .311 .375 r
.57842 .55308 .5841 .53643 .59603 .5435 .59049 .56288 Mtetra
.646 .312 .392 r
.59049 .56288 .59603 .5435 .60807 .55008 .60271 .57239 Mtetra
.619 .297 .403 r
.60271 .57239 .60807 .55008 .62018 .5549 .61501 .57987 Mtetra
.575 .264 .405 r
.61501 .57987 .62018 .5549 .6323 .55659 .62733 .58336 Mtetra
.512 .214 .397 r
.62733 .58336 .6323 .55659 .64437 .55411 .63957 .58134 Mtetra
.431 .145 .376 r
.63957 .58134 .64437 .55411 .65632 .54712 .65164 .57332 Mtetra
.333 .06 .341 r
.65164 .57332 .65632 .54712 .66813 .53617 .66353 .56003 Mtetra
.227 0 .289 r
.66353 .56003 .66813 .53617 .67981 .5225 .67523 .54319 Mtetra
.121 0 .222 r
.67523 .54319 .67981 .5225 .69141 .50762 .68683 .5249 Mtetra
.023 0 .143 r
.68683 .5249 .69141 .50762 .70299 .49282 .69838 .50688 Mtetra
0 0 .051 r
.69838 .50688 .70299 .49282 .71458 .47884 .70994 .49007 Mtetra
0 0 0 r
.70994 .49007 .71458 .47884 .72621 .46588 .72155 .47461 Mtetra
.72155 .47461 .72621 .46588 .73788 .45383 .73318 .46021 Mtetra
.73318 .46021 .73788 .45383 .7496 .44255 .74484 .44656 Mtetra
.641 .903 .588 r
.74484 .44656 .7496 .44255 .76137 .43205 .75653 .43364 Mtetra
.778 .992 .767 r
.75653 .43364 .76137 .43205 .77321 .42251 .76828 .42176 Mtetra
.826 .988 .873 r
.76828 .42176 .77321 .42251 .78515 .4141 .78013 .41128 Mtetra
.808 .931 .914 r
.78013 .41128 .78515 .4141 .79722 .40689 .79212 .40242 Mtetra
.767 .866 .922 r
.79212 .40242 .79722 .40689 .80941 .40077 .80426 .39511 Mtetra
.728 .815 .919 r
.80426 .39511 .80941 .40077 .82172 .39553 .81655 .38909 Mtetra
.699 .781 .915 r
.81655 .38909 .82172 .39553 .83412 .39087 .82896 .38398 Mtetra
.681 .76 .911 r
.82896 .38398 .83412 .39087 .84662 .38657 .84147 .37942 Mtetra
.672 .75 .909 r
.84147 .37942 .84662 .38657 .85918 .38245 .85406 .37517 Mtetra
.667 .745 .908 r
.85406 .37517 .85918 .38245 .87181 .37842 .86673 .37106 Mtetra
.665 .743 .908 r
.86673 .37106 .87181 .37842 .8845 .3744 .87945 .36699 Mtetra
.664 .742 .908 r
.87945 .36699 .8845 .3744 .89724 .37038 .89224 .36294 Mtetra
.664 .741 .908 r
.89224 .36294 .89724 .37038 .91004 .36635 .90508 .35887 Mtetra
.90508 .35887 .91004 .36635 .9229 .36231 .91798 .35479 Mtetra
.663 .741 .908 r
.32893 .53279 .33554 .53893 .34605 .53561 .33948 .52944 Mtetra
.663 .742 .908 r
.33948 .52944 .34605 .53561 .35661 .53227 .35006 .52609 Mtetra
.35006 .52609 .35661 .53227 .36722 .52893 .36069 .52273 Mtetra
.663 .742 .909 r
.36069 .52273 .36722 .52893 .37786 .52557 .37136 .51936 Mtetra
.662 .742 .909 r
.37136 .51936 .37786 .52557 .38855 .52221 .38207 .516 Mtetra
.66 .742 .911 r
.38207 .516 .38855 .52221 .39927 .51886 .39282 .51268 Mtetra
.656 .743 .914 r
.39282 .51268 .39927 .51886 .41004 .51556 .40361 .50946 Mtetra
.647 .744 .92 r
.40361 .50946 .41004 .51556 .42085 .51236 .41444 .50647 Mtetra
.628 .746 .932 r
.41444 .50647 .42085 .51236 .4317 .50939 .42531 .5039 Mtetra
.59 .75 .954 r
.42531 .5039 .4317 .50939 .44259 .50682 .4362 .50206 Mtetra
.506 .748 .982 r
.4362 .50206 .44259 .50682 .45351 .50489 .44712 .5013 Mtetra
.306 .702 .977 r
.44712 .5013 .45351 .50489 .46446 .50389 .45808 .50202 Mtetra
0 .472 .747 r
.45808 .50202 .46446 .50389 .47546 .50409 .46908 .5045 Mtetra
.48 0 0 r
.46908 .5045 .47546 .50409 .48652 .50567 .48014 .50879 Mtetra
.617 .114 .032 r
.48014 .50879 .48652 .50567 .49764 .50861 .49128 .51464 Mtetra
.65 .206 .185 r
.49128 .51464 .49764 .50861 .50884 .51275 .50252 .52148 Mtetra
.65 .243 .26 r
.50252 .52148 .50884 .51275 .52015 .51775 .51389 .52867 Mtetra
.641 .255 .298 r
.51389 .52867 .52015 .51775 .53156 .52335 .52537 .53573 Mtetra
.634 .26 .317 r
.52537 .53573 .53156 .52335 .54308 .52946 .53697 .54266 Mtetra
.637 .268 .328 r
.53697 .54266 .54308 .52946 .55472 .53627 .5487 .54996 Mtetra
.65 .286 .339 r
.5487 .54996 .55472 .53627 .56649 .54409 .56056 .55841 Mtetra
.668 .308 .353 r
.56056 .55841 .56649 .54409 .57842 .55308 .57259 .56855 Mtetra
.679 .325 .368 r
.57259 .56855 .57842 .55308 .59049 .56288 .58478 .58015 Mtetra
.673 .328 .381 r
.58478 .58015 .59049 .56288 .60271 .57239 .59714 .59192 Mtetra
.646 .309 .388 r
.59714 .59192 .60271 .57239 .61501 .57987 .60961 .60164 Mtetra
.592 .266 .387 r
.60961 .60164 .61501 .57987 .62733 .58336 .6221 .60673 Mtetra
.508 .195 .371 r
.6221 .60673 .62733 .58336 .63957 .58134 .6345 .60519 Mtetra
.39 .094 .337 r
.6345 .60519 .63957 .58134 .65164 .57332 .6467 .59634 Mtetra
.243 0 .281 r
.6467 .59634 .65164 .57332 .66353 .56003 .65867 .58112 Mtetra
.089 0 .206 r
.65867 .58112 .66353 .56003 .67523 .54319 .67043 .56176 Mtetra
0 0 .125 r
.67043 .56176 .67523 .54319 .68683 .5249 .68206 .54089 Mtetra
0 0 .052 r
.68206 .54089 .68683 .5249 .69838 .50688 .69364 .52063 Mtetra
0 0 0 r
.69364 .52063 .69838 .50688 .70994 .49007 .70525 .502 Mtetra
.70525 .502 .70994 .49007 .72155 .47461 .71689 .48494 Mtetra
.71689 .48494 .72155 .47461 .73318 .46021 .72854 .4688 Mtetra
.72854 .4688 .73318 .46021 .74484 .44656 .74017 .45304 Mtetra
.74017 .45304 .74484 .44656 .75653 .43364 .75179 .43762 Mtetra
.716 .929 .598 r
.75179 .43762 .75653 .43364 .76828 .42176 .76344 .42305 Mtetra
.828 .997 .77 r
.76344 .42305 .76828 .42176 .78013 .41128 .77518 .41001 Mtetra
.847 .976 .871 r
.77518 .41001 .78013 .41128 .79212 .40242 .78706 .39899 Mtetra
.809 .911 .91 r
.78706 .39899 .79212 .40242 .80426 .39511 .79913 .39007 Mtetra
.758 .847 .917 r
.79913 .39007 .80426 .39511 .81655 .38909 .81137 .38297 Mtetra
.718 .799 .915 r
.81137 .38297 .81655 .38909 .82896 .38398 .82377 .37721 Mtetra
.691 .77 .912 r
.82377 .37721 .82896 .38398 .84147 .37942 .83629 .3723 Mtetra
.676 .754 .91 r
.83629 .3723 .84147 .37942 .85406 .37517 .84891 .36786 Mtetra
.669 .747 .909 r
.84891 .36786 .85406 .37517 .86673 .37106 .86161 .36365 Mtetra
.666 .743 .908 r
.86161 .36365 .86673 .37106 .87945 .36699 .87437 .35953 Mtetra
.664 .742 .908 r
.87437 .35953 .87945 .36699 .89224 .36294 .88719 .35543 Mtetra
.664 .741 .908 r
.88719 .35543 .89224 .36294 .90508 .35887 .90008 .35133 Mtetra
.90008 .35133 .90508 .35887 .91798 .35479 .91302 .34722 Mtetra
.663 .741 .908 r
.32228 .5266 .32893 .53279 .33948 .52944 .33285 .52324 Mtetra
.663 .742 .909 r
.33285 .52324 .33948 .52944 .35006 .52609 .34346 .51987 Mtetra
.662 .742 .909 r
.34346 .51987 .35006 .52609 .36069 .52273 .35411 .5165 Mtetra
.662 .742 .91 r
.35411 .5165 .36069 .52273 .37136 .51936 .36481 .51314 Mtetra
.66 .743 .911 r
.36481 .51314 .37136 .51936 .38207 .516 .37554 .5098 Mtetra
.656 .743 .914 r
.37554 .5098 .38207 .516 .39282 .51268 .38632 .50656 Mtetra
.648 .744 .92 r
.38632 .50656 .39282 .51268 .40361 .50946 .39713 .50353 Mtetra
.63 .746 .931 r
.39713 .50353 .40361 .50946 .41444 .50647 .40797 .50092 Mtetra
.59 .748 .952 r
.40797 .50092 .41444 .50647 .42531 .5039 .41884 .49905 Mtetra
.5 .743 .982 r
.41884 .49905 .42531 .5039 .4362 .50206 .42973 .49839 Mtetra
.272 .681 .969 r
.42973 .49839 .4362 .50206 .44712 .5013 .44064 .49944 Mtetra
.204 0 0 r
.44064 .49944 .44712 .5013 .45808 .50202 .45157 .50265 Mtetra
.568 .006 0 r
.45157 .50265 .45808 .50202 .46908 .5045 .46255 .50823 Mtetra
.673 .199 .119 r
.46255 .50823 .46908 .5045 .48014 .50879 .47361 .51594 Mtetra
.689 .272 .25 r
.47361 .51594 .48014 .50879 .49128 .51464 .48477 .52505 Mtetra
.678 .294 .311 r
.48477 .52505 .49128 .51464 .50252 .52148 .49606 .53446 Mtetra
.657 .289 .337 r
.49606 .53446 .50252 .52148 .51389 .52867 .50749 .54307 Mtetra
.633 .273 .342 r
.50749 .54307 .51389 .52867 .52537 .53573 .51906 .55026 Mtetra
.614 .253 .334 r
.51906 .55026 .52537 .53573 .53697 .54266 .53074 .55626 Mtetra
.613 .244 .319 r
.53074 .55626 .53697 .54266 .5487 .54996 .54255 .56211 Mtetra
.635 .254 .305 r
.54255 .56211 .5487 .54996 .56056 .55841 .55448 .56924 Mtetra
.672 .282 .3 r
.55448 .56924 .56056 .55841 .57259 .56855 .56656 .5787 Mtetra
.703 .311 .302 r
.56656 .5787 .57259 .56855 .58478 .58015 .57883 .59049 Mtetra
.712 .321 .307 r
.57883 .59049 .58478 .58015 .59714 .59192 .59127 .60318 Mtetra
.686 .298 .306 r
.59127 .60318 .59714 .59192 .60961 .60164 .60385 .61411 Mtetra
.613 .228 .289 r
.60385 .61411 .60961 .60164 .6221 .60673 .61646 .62021 Mtetra
.467 .09 .239 r
.61646 .62021 .6221 .60673 .6345 .60519 .62897 .61905 Mtetra
.216 0 .138 r
.62897 .61905 .6345 .60519 .6467 .59634 .64128 .60984 Mtetra
0 0 0 r
.64128 .60984 .6467 .59634 .65867 .58112 .65335 .59371 Mtetra
.65335 .59371 .65867 .58112 .67043 .56176 .6652 .57329 Mtetra
.6652 .57329 .67043 .56176 .68206 .54089 .67693 .55164 Mtetra
.67693 .55164 .68206 .54089 .69364 .52063 .68864 .53109 Mtetra
.68864 .53109 .69364 .52063 .70525 .502 .70038 .51256 Mtetra
.70038 .51256 .70525 .502 .71689 .48494 .71215 .49557 Mtetra
.71215 .49557 .71689 .48494 .72854 .4688 .7239 .47897 Mtetra
.7239 .47897 .72854 .4688 .74017 .45304 .73557 .46184 Mtetra
.73557 .46184 .74017 .45304 .75179 .43762 .74715 .44412 Mtetra
.631 .831 .427 r
.74715 .44412 .75179 .43762 .76344 .42305 .7587 .42663 Mtetra
.792 .954 .624 r
.7587 .42663 .76344 .42305 .77518 .41001 .7703 .41056 Mtetra
.869 .995 .788 r
.7703 .41056 .77518 .41001 .78706 .39899 .78205 .39684 Mtetra
.853 .954 .877 r
.78205 .39684 .78706 .39899 .79913 .39007 .79401 .38583 Mtetra
.797 .884 .909 r
.79401 .38583 .79913 .39007 .81137 .38297 .80619 .37729 Mtetra
.743 .823 .914 r
.80619 .37729 .81137 .38297 .82377 .37721 .81855 .37064 Mtetra
.705 .783 .912 r
.81855 .37064 .82377 .37721 .83629 .3723 .83108 .36524 Mtetra
.683 .761 .91 r
.83108 .36524 .83629 .3723 .84891 .36786 .84372 .36055 Mtetra
.672 .749 .909 r
.84372 .36055 .84891 .36786 .86161 .36365 .85644 .3562 Mtetra
.667 .744 .908 r
.85644 .3562 .86161 .36365 .87437 .35953 .86924 .35201 Mtetra
.665 .742 .908 r
.86924 .35201 .87437 .35953 .88719 .35543 .88211 .34787 Mtetra
.664 .742 .908 r
.88211 .34787 .88719 .35543 .90008 .35133 .89503 .34373 Mtetra
.664 .741 .908 r
.89503 .34373 .90008 .35133 .91302 .34722 .90801 .33958 Mtetra
.663 .742 .909 r
.31558 .52038 .32228 .5266 .33285 .52324 .32617 .517 Mtetra
.662 .742 .909 r
.32617 .517 .33285 .52324 .34346 .51987 .3368 .51363 Mtetra
.661 .742 .91 r
.3368 .51363 .34346 .51987 .35411 .5165 .34748 .51027 Mtetra
.66 .743 .911 r
.34748 .51027 .35411 .5165 .36481 .51314 .3582 .50693 Mtetra
.657 .744 .914 r
.3582 .50693 .36481 .51314 .37554 .5098 .36896 .50367 Mtetra
.649 .745 .92 r
.36896 .50367 .37554 .5098 .38632 .50656 .37975 .5006 Mtetra
.633 .747 .93 r
.37975 .5006 .38632 .50656 .39713 .50353 .39058 .4979 Mtetra
.596 .748 .95 r
.39058 .4979 .39713 .50353 .40797 .50092 .40143 .49593 Mtetra
.509 .742 .979 r
.40143 .49593 .40797 .50092 .41884 .49905 .41228 .49518 Mtetra
.279 .678 .971 r
.41228 .49518 .41884 .49905 .42973 .49839 .42315 .49629 Mtetra
.229 0 0 r
.42315 .49629 .42973 .49839 .44064 .49944 .43402 .49988 Mtetra
.611 .059 0 r
.43402 .49988 .44064 .49944 .45157 .50265 .44491 .5064 Mtetra
.71 .251 .16 r
.44491 .5064 .45157 .50265 .46255 .50823 .45586 .51579 Mtetra
.722 .319 .286 r
.45586 .51579 .46255 .50823 .47361 .51594 .46691 .52733 Mtetra
.708 .337 .343 r
.46691 .52733 .47361 .51594 .48477 .52505 .47809 .53959 Mtetra
.681 .326 .367 r
.47809 .53959 .48477 .52505 .49606 .53446 .48944 .55079 Mtetra
.645 .297 .367 r
.48944 .55079 .49606 .53446 .50749 .54307 .50096 .55938 Mtetra
.602 .251 .347 r
.50096 .55938 .50749 .54307 .51906 .55026 .51262 .56474 Mtetra
.56 .194 .304 r
.51262 .56474 .51906 .55026 .53074 .55626 .52439 .56756 Mtetra
.536 .139 .236 r
.52439 .56756 .53074 .55626 .54255 .56211 .53626 .56965 Mtetra
.557 .111 .147 r
.53626 .56965 .54255 .56211 .55448 .56924 .54823 .57324 Mtetra
.628 .133 .059 r
.54823 .57324 .55448 .56924 .56656 .5787 .56034 .57994 Mtetra
.698 .18 0 r
.56034 .57994 .56656 .5787 .57883 .59049 .57261 .58997 Mtetra
.721 .194 0 r
.57261 .58997 .57883 .59049 .59127 .60318 .58507 .60181 Mtetra
.669 .117 0 r
.58507 .60181 .59127 .60318 .60385 .61411 .59767 .61253 Mtetra
.432 0 0 r
.59767 .61253 .60385 .61411 .61646 .62021 .61032 .61875 Mtetra
.262 .752 .915 r
.61032 .61875 .61646 .62021 .62897 .61905 .62289 .61782 Mtetra
.788 .965 .919 r
.62289 .61782 .62897 .61905 .64128 .60984 .63528 .60891 Mtetra
.915 .941 .807 r
.63528 .60891 .64128 .60984 .65335 .59371 .64745 .5933 Mtetra
.947 .927 .752 r
.64745 .5933 .65335 .59371 .6652 .57329 .65944 .57389 Mtetra
.951 .943 .733 r
.65944 .57389 .6652 .57329 .67693 .55164 .67134 .55393 Mtetra
.916 .978 .716 r
.67134 .55393 .67693 .55164 .68864 .53109 .68325 .53575 Mtetra
.752 .94 .606 r
.68325 .53575 .68864 .53109 .70038 .51256 .69524 .5199 Mtetra
0 0 0 r
.69524 .5199 .70038 .51256 .71215 .49557 .70726 .5053 Mtetra
.70726 .5053 .71215 .49557 .7239 .47897 .71921 .49005 Mtetra
.71921 .49005 .7239 .47897 .73557 .46184 .731 .47271 Mtetra
.731 .47271 .73557 .46184 .74715 .44412 .7426 .45319 Mtetra
.7426 .45319 .74715 .44412 .7587 .42663 .75406 .43273 Mtetra
.733 .879 .471 r
.75406 .43273 .7587 .42663 .7703 .41056 .76552 .41319 Mtetra
.862 .976 .67 r
.76552 .41319 .7703 .41056 .78205 .39684 .77711 .39621 Mtetra
.889 .981 .817 r
.77711 .39621 .78205 .39684 .79401 .38583 .78893 .38256 Mtetra
.84 .921 .887 r
.78893 .38256 .79401 .38583 .80619 .37729 .80101 .37216 Mtetra
.775 .852 .909 r
.80101 .37216 .80619 .37729 .81855 .37064 .81333 .36434 Mtetra
.724 .8 .912 r
.81333 .36434 .81855 .37064 .83108 .36524 .82584 .35828 Mtetra
.692 .769 .91 r
.82584 .35828 .83108 .36524 .84372 .36055 .83849 .35324 Mtetra
.676 .753 .909 r
.83849 .35324 .84372 .36055 .85644 .3562 .85124 .34872 Mtetra
.668 .746 .908 r
.85124 .34872 .85644 .3562 .86924 .35201 .86408 .34444 Mtetra
.665 .743 .908 r
.86408 .34444 .86924 .35201 .88211 .34787 .87698 .34024 Mtetra
.664 .742 .908 r
.87698 .34024 .88211 .34787 .89503 .34373 .88994 .33607 Mtetra
.664 .741 .908 r
.88994 .33607 .89503 .34373 .90801 .33958 .90297 .33188 Mtetra
.662 .742 .909 r
.30882 .51411 .31558 .52038 .32617 .517 .31944 .51073 Mtetra
.661 .742 .91 r
.31944 .51073 .32617 .517 .3368 .51363 .3301 .50737 Mtetra
.659 .743 .912 r
.3301 .50737 .3368 .51363 .34748 .51027 .3408 .50404 Mtetra
.656 .744 .914 r
.3408 .50404 .34748 .51027 .3582 .50693 .35154 .50077 Mtetra
.65 .745 .919 r
.35154 .50077 .3582 .50693 .36896 .50367 .36232 .49767 Mtetra
.636 .747 .929 r
.36232 .49767 .36896 .50367 .37975 .5006 .37313 .49489 Mtetra
.604 .749 .947 r
.37313 .49489 .37975 .5006 .39058 .4979 .38395 .49276 Mtetra
.528 .744 .974 r
.38395 .49276 .39058 .4979 .40143 .49593 .39479 .49179 Mtetra
.322 .692 .98 r
.39479 .49179 .40143 .49593 .41228 .49518 .40562 .49265 Mtetra
0 .398 .717 r
.40562 .49265 .41228 .49518 .42315 .49629 .41644 .49617 Mtetra
.616 .059 0 r
.41644 .49617 .42315 .49629 .43402 .49988 .42725 .50303 Mtetra
.732 .274 .163 r
.42725 .50303 .43402 .49988 .44491 .5064 .43808 .51351 Mtetra
.748 .35 .298 r
.43808 .51351 .44491 .5064 .45586 .51579 .44898 .5271 Mtetra
.737 .371 .359 r
.44898 .5271 .45586 .51579 .46691 .52733 .46001 .54234 Mtetra
.711 .362 .385 r
.46001 .54234 .46691 .52733 .47809 .53959 .47123 .55695 Mtetra
.672 .33 .387 r
.47123 .55695 .47809 .53959 .48944 .55079 .48266 .56846 Mtetra
.615 .271 .364 r
.48266 .56846 .48944 .55079 .50096 .55938 .49429 .57501 Mtetra
.531 .172 .304 r
.49429 .57501 .50096 .55938 .51262 .56474 .50607 .57629 Mtetra
.397 0 .164 r
.50607 .57629 .51262 .56474 .52439 .56756 .51794 .57372 Mtetra
.167 0 0 r
.51794 .57372 .52439 .56756 .53626 .56965 .52986 .57005 Mtetra
.166 .705 .772 r
.52986 .57005 .53626 .56965 .54823 .57324 .54185 .56828 Mtetra
.248 .626 .959 r
.54185 .56828 .54823 .57324 .56034 .57994 .55394 .57051 Mtetra
.179 .43 .863 r
.55394 .57051 .56034 .57994 .57261 .58997 .56617 .57708 Mtetra
.176 .348 .797 r
.56617 .57708 .57261 .58997 .58507 .60181 .57858 .58643 Mtetra
.274 .37 .78 r
.57858 .58643 .58507 .60181 .59767 .61253 .59113 .59552 Mtetra
.433 .448 .776 r
.59113 .59552 .59767 .61253 .61032 .61875 .60374 .60092 Mtetra
.582 .529 .76 r
.60374 .60092 .61032 .61875 .62289 .61782 .6163 .60002 Mtetra
.687 .587 .738 r
.6163 .60002 .62289 .61782 .63528 .60891 .62873 .59208 Mtetra
.751 .627 .722 r
.62873 .59208 .63528 .60891 .64745 .5933 .64099 .5785 Mtetra
.788 .661 .722 r
.64099 .5785 .64745 .5933 .65944 .57389 .65313 .56224 Mtetra
.812 .704 .745 r
.65313 .56224 .65944 .57389 .67134 .55393 .66526 .54654 Mtetra
.834 .783 .804 r
.66526 .54654 .67134 .55393 .68325 .53575 .67747 .53346 Mtetra
.836 .94 .893 r
.67747 .53346 .68325 .53575 .69524 .5199 .6898 .52303 Mtetra
.551 .898 .672 r
.6898 .52303 .69524 .5199 .70726 .5053 .70217 .51331 Mtetra
0 0 0 r
.70217 .51331 .70726 .5053 .71921 .49005 .71444 .50147 Mtetra
.71444 .50147 .71921 .49005 .731 .47271 .72644 .48536 Mtetra
.72644 .48536 .731 .47271 .7426 .45319 .73811 .46476 Mtetra
.73811 .46476 .7426 .45319 .75406 .43273 .74952 .44141 Mtetra
.678 .802 .345 r
.74952 .44141 .75406 .43273 .76552 .41319 .76083 .41807 Mtetra
.835 .927 .544 r
.76083 .41807 .76552 .41319 .77711 .39621 .77224 .39727 Mtetra
.908 .982 .73 r
.77224 .39727 .77711 .39621 .78893 .38256 .78389 .38042 Mtetra
.883 .952 .848 r
.78389 .38042 .78893 .38256 .80101 .37216 .79584 .36769 Mtetra
.812 .882 .896 r
.79584 .36769 .80101 .37216 .81333 .36434 .80809 .35837 Mtetra
.747 .82 .908 r
.80809 .35837 .81333 .36434 .82584 .35828 .82057 .35144 Mtetra
.705 .779 .91 r
.82057 .35144 .82584 .35828 .83849 .35324 .83322 .34595 Mtetra
.682 .758 .909 r
.83322 .34595 .83849 .35324 .85124 .34872 .846 .34121 Mtetra
.671 .748 .908 r
.846 .34121 .85124 .34872 .86408 .34444 .85887 .33682 Mtetra
.666 .744 .908 r
.85887 .33682 .86408 .34444 .87698 .34024 .87181 .33256 Mtetra
.664 .742 .908 r
.87181 .33256 .87698 .34024 .88994 .33607 .88482 .32834 Mtetra
.88482 .32834 .88994 .33607 .90297 .33188 .89788 .32412 Mtetra
.661 .742 .91 r
.30202 .50781 .30882 .51411 .31944 .51073 .31266 .50444 Mtetra
.659 .742 .911 r
.31266 .50444 .31944 .51073 .3301 .50737 .32334 .5011 Mtetra
.656 .743 .914 r
.32334 .5011 .3301 .50737 .3408 .50404 .33407 .49784 Mtetra
.65 .744 .919 r
.33407 .49784 .3408 .50404 .35154 .50077 .34482 .49472 Mtetra
.638 .747 .927 r
.34482 .49472 .35154 .50077 .36232 .49767 .35561 .49188 Mtetra
.611 .749 .943 r
.35561 .49188 .36232 .49767 .37313 .49489 .36642 .4896 Mtetra
.548 .747 .969 r
.36642 .4896 .37313 .49489 .38395 .49276 .37724 .48833 Mtetra
.382 .711 .987 r
.37724 .48833 .38395 .49276 .39479 .49179 .38804 .48876 Mtetra
0 .482 .811 r
.38804 .48876 .39479 .49179 .40562 .49265 .39882 .49177 Mtetra
.578 .003 0 r
.39882 .49177 .40562 .49265 .41644 .49617 .40957 .49829 Mtetra
.74 .269 .13 r
.40957 .49829 .41644 .49617 .42725 .50303 .4203 .50893 Mtetra
.768 .365 .288 r
.4203 .50893 .42725 .50303 .43808 .51351 .43105 .52361 Mtetra
.763 .395 .359 r
.43105 .52361 .43808 .51351 .44898 .5271 .44191 .54116 Mtetra
.742 .393 .391 r
.44191 .54116 .44898 .5271 .46001 .54234 .45294 .55921 Mtetra
.708 .367 .397 r
.45294 .55921 .46001 .54234 .47123 .55695 .46422 .57464 Mtetra
.652 .309 .378 r
.46422 .57464 .47123 .55695 .48266 .56846 .47576 .5844 Mtetra
.55 .192 .313 r
.47576 .5844 .48266 .56846 .49429 .57501 .48752 .58675 Mtetra
.31 0 .117 r
.48752 .58675 .49429 .57501 .50607 .57629 .49943 .582 Mtetra
0 0 0 r
.49943 .582 .50607 .57629 .51794 .57372 .51141 .57255 Mtetra
.842 .949 .888 r
.51141 .57255 .51794 .57372 .52986 .57005 .52339 .56209 Mtetra
.754 .744 .843 r
.52339 .56209 .52986 .57005 .54185 .56828 .53538 .55419 Mtetra
.627 .589 .791 r
.53538 .55419 .54185 .56828 .55394 .57051 .54743 .55118 Mtetra
.522 .477 .747 r
.54743 .55118 .55394 .57051 .56617 .57708 .55959 .55339 Mtetra
.468 .414 .714 r
.55959 .55339 .56617 .57708 .57858 .58643 .5719 .55921 Mtetra
.473 .399 .693 r
.5719 .55921 .57858 .58643 .59113 .59552 .58434 .56567 Mtetra
.519 .419 .682 r
.58434 .56567 .59113 .59552 .60374 .60092 .59686 .56955 Mtetra
.578 .454 .674 r
.59686 .56955 .60374 .60092 .6163 .60002 .60936 .56852 Mtetra
.63 .487 .67 r
.60936 .56852 .6163 .60002 .62873 .59208 .62178 .56204 Mtetra
.665 .514 .67 r
.62178 .56204 .62873 .59208 .64099 .5785 .63412 .55161 Mtetra
.683 .536 .679 r
.63412 .55161 .64099 .5785 .65313 .56224 .64642 .54013 Mtetra
.684 .557 .705 r
.64642 .54013 .65313 .56224 .66526 .54654 .65879 .53062 Mtetra
.667 .594 .763 r
.65879 .53062 .66526 .54654 .67747 .53346 .67134 .52478 Mtetra
.624 .695 .895 r
.67134 .52478 .67747 .53346 .6898 .52303 .68408 .52199 Mtetra
.381 .833 .927 r
.68408 .52199 .6898 .52303 .70217 .51331 .69689 .51931 Mtetra
0 0 0 r
.69689 .51931 .70217 .51331 .71444 .50147 .70956 .51278 Mtetra
.70956 .51278 .71444 .50147 .72644 .48536 .72185 .49936 Mtetra
.72185 .49936 .72644 .48536 .73811 .46476 .73366 .47853 Mtetra
.73366 .47853 .73811 .46476 .74952 .44141 .74505 .45253 Mtetra
.74505 .45253 .74952 .44141 .76083 .41807 .75622 .42516 Mtetra
.812 .876 .44 r
.75622 .42516 .76083 .41807 .77224 .39727 .76743 .40007 Mtetra
.912 .96 .635 r
.76743 .40007 .77224 .39727 .78389 .38042 .77889 .37948 Mtetra
.917 .966 .791 r
.77889 .37948 .78389 .38042 .79584 .36769 .79069 .36395 Mtetra
.852 .909 .873 r
.79069 .36395 .79584 .36769 .80809 .35837 .80284 .35279 Mtetra
.776 .841 .902 r
.80284 .35279 .80809 .35837 .82057 .35144 .81528 .34478 Mtetra
.72 .792 .908 r
.81528 .34478 .82057 .35144 .83322 .34595 .82793 .33871 Mtetra
.689 .764 .909 r
.82793 .33871 .83322 .34595 .846 .34121 .84072 .33369 Mtetra
.674 .75 .908 r
.84072 .33369 .846 .34121 .85887 .33682 .85362 .32916 Mtetra
.667 .745 .908 r
.85362 .32916 .85887 .33682 .87181 .33256 .8666 .32483 Mtetra
.665 .742 .908 r
.8666 .32483 .87181 .33256 .88482 .32834 .87965 .32056 Mtetra
.664 .742 .908 r
.87965 .32056 .88482 .32834 .89788 .32412 .89275 .3163 Mtetra
.659 .741 .911 r
.29516 .50147 .30202 .50781 .31266 .50444 .30583 .49811 Mtetra
.656 .742 .913 r
.30583 .49811 .31266 .50444 .32334 .5011 .31653 .49483 Mtetra
.65 .743 .917 r
.31653 .49483 .32334 .5011 .33407 .49784 .32727 .49169 Mtetra
.639 .745 .925 r
.32727 .49169 .33407 .49784 .34482 .49472 .33804 .4888 Mtetra
.617 .747 .939 r
.33804 .4888 .34482 .49472 .35561 .49188 .34883 .48639 Mtetra
.567 .747 .962 r
.34883 .48639 .35561 .49188 .36642 .4896 .35963 .48485 Mtetra
.441 .727 .987 r
.35963 .48485 .36642 .4896 .37724 .48833 .37042 .48478 Mtetra
.089 .577 .902 r
.37042 .48478 .37724 .48833 .38804 .48876 .38118 .48705 Mtetra
.48 0 0 r
.38118 .48705 .38804 .48876 .39882 .49177 .39188 .49267 Mtetra
.726 .229 .055 r
.39188 .49267 .39882 .49177 .40957 .49829 .40253 .50255 Mtetra
.779 .36 .256 r
.40253 .50255 .40957 .49829 .4203 .50893 .41317 .51706 Mtetra
.783 .407 .345 r
.41317 .51706 .4203 .50893 .43105 .52361 .42385 .53554 Mtetra
.77 .416 .385 r
.42385 .53554 .43105 .52361 .44191 .54116 .43468 .556 Mtetra
.745 .399 .397 r
.43468 .556 .44191 .54116 .45294 .55921 .44574 .57517 Mtetra
.7 .352 .383 r
.44574 .57517 .45294 .55921 .46422 .57464 .45712 .58924 Mtetra
.608 .241 .322 r
.45712 .58924 .46422 .57464 .47576 .5844 .4688 .59508 Mtetra
.328 0 .094 r
.4688 .59508 .47576 .5844 .48752 .58675 .48073 .59144 Mtetra
.672 .944 .679 r
.48073 .59144 .48752 .58675 .49943 .582 .49278 .57963 Mtetra
.909 .876 .791 r
.49278 .57963 .49943 .582 .51141 .57255 .50485 .5631 Mtetra
.837 .73 .746 r
.50485 .5631 .51141 .57255 .52339 .56209 .51689 .54619 Mtetra
.756 .632 .724 r
.51689 .54619 .52339 .56209 .53538 .55419 .52888 .53272 Mtetra
.67 .55 .709 r
.52888 .53272 .53538 .55419 .54743 .55118 .54089 .52488 Mtetra
.592 .479 .693 r
.54089 .52488 .54743 .55118 .55959 .55339 .55297 .52283 Mtetra
.541 .43 .676 r
.55297 .52283 .55959 .55339 .5719 .55921 .56516 .52491 Mtetra
.528 .41 .663 r
.56516 .52491 .5719 .55921 .58434 .56567 .57747 .52839 Mtetra
.545 .415 .654 r
.57747 .52839 .58434 .56567 .59686 .56955 .58986 .53044 Mtetra
.576 .432 .649 r
.58986 .53044 .59686 .56955 .60936 .56852 .60228 .52918 Mtetra
.604 .451 .648 r
.60228 .52918 .60936 .56852 .62178 .56204 .61467 .52437 Mtetra
.621 .466 .651 r
.61467 .52437 .62178 .56204 .63412 .55161 .62704 .51757 Mtetra
.62 .474 .661 r
.62704 .51757 .63412 .55161 .64642 .54013 .63948 .51156 Mtetra
.594 .473 .685 r
.63948 .51156 .64642 .54013 .65879 .53062 .6521 .50912 Mtetra
.524 .465 .733 r
.6521 .50912 .65879 .53062 .67134 .52478 .66499 .51155 Mtetra
.355 .456 .826 r
.66499 .51155 .67134 .52478 .68408 .52199 .67814 .51758 Mtetra
0 .404 .81 r
.67814 .51758 .68408 .52199 .69689 .51931 .69142 .52331 Mtetra
.319 0 0 r
.69142 .52331 .69689 .51931 .70956 .51278 .70454 .52351 Mtetra
.097 0 .002 r
.70454 .52351 .70956 .51278 .72185 .49936 .71719 .51403 Mtetra
0 0 0 r
.71719 .51403 .72185 .49936 .73366 .47853 .72919 .49385 Mtetra
.72919 .49385 .73366 .47853 .74505 .45253 .7406 .4656 Mtetra
.7406 .4656 .74505 .45253 .75622 .42516 .75165 .43415 Mtetra
.808 .841 .376 r
.75165 .43415 .75622 .42516 .76743 .40007 .76266 .40443 Mtetra
.914 .93 .556 r
.76266 .40443 .76743 .40007 .77889 .37948 .77391 .37967 Mtetra
.941 .963 .726 r
.77391 .37967 .77889 .37948 .79069 .36395 .78554 .36092 Mtetra
.889 .927 .84 r
.78554 .36092 .79069 .36395 .80284 .35279 .79758 .3476 Mtetra
.806 .861 .889 r
.79758 .3476 .80284 .35279 .81528 .34478 .80996 .33829 Mtetra
.739 .805 .905 r
.80996 .33829 .81528 .34478 .82793 .33871 .82259 .33152 Mtetra
.698 .771 .908 r
.82259 .33152 .82793 .33871 .84072 .33369 .8354 .32614 Mtetra
.678 .753 .908 r
.8354 .32614 .84072 .33369 .85362 .32916 .84833 .32145 Mtetra
.669 .746 .908 r
.84833 .32145 .85362 .32916 .8666 .32483 .86135 .31703 Mtetra
.665 .743 .908 r
.86135 .31703 .8666 .32483 .87965 .32056 .87443 .31271 Mtetra
.664 .742 .908 r
.87443 .31271 .87965 .32056 .89275 .3163 .88758 .30841 Mtetra
.657 .741 .912 r
.28826 .49509 .29516 .50147 .30583 .49811 .29894 .49176 Mtetra
.652 .742 .915 r
.29894 .49176 .30583 .49811 .31653 .49483 .30967 .48857 Mtetra
.642 .743 .922 r
.30967 .48857 .31653 .49483 .32727 .49169 .32042 .48561 Mtetra
.623 .744 .934 r
.32042 .48561 .32727 .49169 .33804 .4888 .33119 .48308 Mtetra
.583 .745 .953 r
.33119 .48308 .33804 .4888 .34883 .48639 .34198 .48128 Mtetra
.49 .734 .98 r
.34198 .48128 .34883 .48639 .35963 .48485 .35275 .48075 Mtetra
.237 .65 .96 r
.35275 .48075 .35963 .48485 .37042 .48478 .36349 .48223 Mtetra
.307 0 0 r
.36349 .48223 .37042 .48478 .38118 .48705 .37417 .4867 Mtetra
.68 .145 0 r
.37417 .4867 .38118 .48705 .39188 .49267 .38478 .49519 Mtetra
.776 .333 .197 r
.38478 .49519 .39188 .49267 .40253 .50255 .39534 .5084 Mtetra
.795 .404 .314 r
.39534 .5084 .40253 .50255 .41317 .51706 .40588 .52626 Mtetra
.792 .427 .366 r
.40588 .52626 .41317 .51706 .42385 .53554 .41652 .54738 Mtetra
.777 .422 .385 r
.41652 .54738 .42385 .53554 .43468 .556 .42736 .56891 Mtetra
.747 .389 .376 r
.42736 .56891 .43468 .556 .44574 .57517 .43851 .58689 Mtetra
.68 .299 .319 r
.43851 .58689 .44574 .57517 .45712 .58924 .45002 .59728 Mtetra
.433 0 .071 r
.45002 .59728 .45712 .58924 .4688 .59508 .46188 .59738 Mtetra
.759 .995 .826 r
.46188 .59738 .4688 .59508 .48073 .59144 .47396 .58694 Mtetra
.898 .818 .761 r
.47396 .58694 .48073 .59144 .49278 .57963 .48615 .56838 Mtetra
.85 .708 .705 r
.48615 .56838 .49278 .57963 .50485 .5631 .49831 .54595 Mtetra
.802 .645 .687 r
.49831 .54595 .50485 .5631 .51689 .54619 .51039 .52424 Mtetra
.748 .592 .682 r
.51039 .52424 .51689 .54619 .52888 .53272 .52239 .50684 Mtetra
.686 .539 .68 r
.52239 .50684 .52888 .53272 .54089 .52488 .53436 .49552 Mtetra
.623 .487 .675 r
.53436 .49552 .54089 .52488 .55297 .52283 .54637 .49013 Mtetra
.576 .446 .666 r
.54637 .49013 .55297 .52283 .56516 .52491 .55846 .48901 Mtetra
.557 .425 .657 r
.55846 .48901 .56516 .52491 .57747 .52839 .57065 .48975 Mtetra
.561 .422 .649 r
.57065 .48975 .57747 .52839 .58986 .53044 .58292 .49005 Mtetra
.576 .429 .645 r
.58292 .49005 .58986 .53044 .60228 .52918 .59523 .48854 Mtetra
.59 .438 .644 r
.59523 .48854 .60228 .52918 .61467 .52437 .60758 .48529 Mtetra
.592 .443 .648 r
.60758 .48529 .61467 .52437 .62704 .51757 .61998 .48194 Mtetra
.571 .437 .659 r
.61998 .48194 .62704 .51757 .63948 .51156 .63252 .48115 Mtetra
.511 .413 .679 r
.63252 .48115 .63948 .51156 .6521 .50912 .64533 .48549 Mtetra
.371 .354 .711 r
.64533 .48549 .6521 .50912 .66499 .51155 .6585 .49597 Mtetra
.047 .221 .721 r
.6585 .49597 .66499 .51155 .67814 .51758 .67204 .51083 Mtetra
0 0 .509 r
.67204 .51083 .67814 .51758 .69142 .52331 .68577 .5253 Mtetra
.597 .046 0 r
.68577 .5253 .69142 .52331 .70454 .52351 .69934 .53294 Mtetra
.268 0 .026 r
.69934 .53294 .70454 .52351 .71719 .51403 .71238 .52829 Mtetra
0 0 0 r
.71238 .52829 .71719 .51403 .72919 .49385 .72463 .5096 Mtetra
.72463 .5096 .72919 .49385 .7406 .4656 .7361 .47966 Mtetra
.691 .734 .223 r
.7361 .47966 .7406 .4656 .75165 .43415 .74707 .44437 Mtetra
.832 .829 .354 r
.74707 .44437 .75165 .43415 .76266 .40443 .7579 .40996 Mtetra
.924 .905 .506 r
.7579 .40996 .76266 .40443 .77391 .37967 .76894 .38077 Mtetra
.958 .948 .668 r
.76894 .38077 .77391 .37967 .78554 .36092 .78039 .35852 Mtetra
.92 .934 .8 r
.78039 .35852 .78554 .36092 .79758 .3476 .7923 .34277 Mtetra
.837 .877 .872 r
.7923 .34277 .79758 .3476 .80996 .33829 .80461 .33197 Mtetra
.76 .818 .898 r
.80461 .33197 .80996 .33829 .82259 .33152 .81723 .32438 Mtetra
.709 .778 .906 r
.81723 .32438 .82259 .33152 .8354 .32614 .83005 .31859 Mtetra
.683 .757 .908 r
.83005 .31859 .8354 .32614 .84833 .32145 .843 .31369 Mtetra
.671 .747 .908 r
.843 .31369 .84833 .32145 .86135 .31703 .85605 .30918 Mtetra
.666 .743 .908 r
.85605 .30918 .86135 .31703 .87443 .31271 .86918 .3048 Mtetra
.664 .742 .908 r
.86918 .3048 .87443 .31271 .88758 .30841 .88237 .30045 Mtetra
.655 .741 .913 r
.2813 .48866 .28826 .49509 .29894 .49176 .29201 .48538 Mtetra
.646 .741 .918 r
.29201 .48538 .29894 .49176 .30967 .48857 .30274 .48231 Mtetra
.631 .741 .927 r
.30274 .48231 .30967 .48857 .32042 .48561 .3135 .4796 Mtetra
.599 .741 .944 r
.3135 .4796 .32042 .48561 .33119 .48308 .32428 .47754 Mtetra
.531 .735 .969 r
.32428 .47754 .33119 .48308 .34198 .48128 .33504 .47656 Mtetra
.359 .693 .982 r
.33504 .47656 .34198 .48128 .35275 .48075 .34577 .4773 Mtetra
0 .465 .812 r
.34577 .4773 .35275 .48075 .36349 .48223 .35644 .48062 Mtetra
.578 0 0 r
.35644 .48062 .36349 .48223 .37417 .4867 .36703 .4875 Mtetra
.756 .275 .097 r
.36703 .4875 .37417 .4867 .38478 .49519 .37754 .49882 Mtetra
.797 .382 .261 r
.37754 .49882 .38478 .49519 .39534 .5084 .38801 .51488 Mtetra
.805 .424 .334 r
.38801 .51488 .39534 .5084 .40588 .52626 .3985 .53496 Mtetra
.799 .433 .363 r
.3985 .53496 .40588 .52626 .41652 .54738 .40914 .55689 Mtetra
.783 .414 .358 r
.40914 .55689 .41652 .54738 .42736 .56891 .42005 .57714 Mtetra
.743 .348 .302 r
.42005 .57714 .42736 .56891 .43851 .58689 .43134 .59148 Mtetra
.571 .075 .038 r
.43134 .59148 .43851 .58689 .45002 .59728 .44303 .59625 Mtetra
.706 .95 .954 r
.44303 .59625 .45002 .59728 .46188 .59738 .45506 .58972 Mtetra
.853 .76 .759 r
.45506 .58972 .46188 .59738 .47396 .58694 .4673 .57289 Mtetra
.834 .679 .691 r
.4673 .57289 .47396 .58694 .48615 .56838 .47959 .54912 Mtetra
.81 .637 .668 r
.47959 .54912 .48615 .56838 .49831 .54595 .49182 .52302 Mtetra
.781 .606 .663 r
.49182 .52302 .49831 .54595 .51039 .52424 .50393 .49892 Mtetra
.743 .575 .667 r
.50393 .49892 .51039 .52424 .52239 .50684 .51593 .47976 Mtetra
.695 .54 .672 r
.51593 .47976 .52239 .50684 .53436 .49552 .52787 .46672 Mtetra
.643 .501 .674 r
.52787 .46672 .53436 .49552 .54637 .49013 .53983 .4593 Mtetra
.6 .467 .671 r
.53983 .4593 .54637 .49013 .55846 .48901 .55184 .45591 Mtetra
.577 .445 .664 r
.55184 .45591 .55846 .48901 .57065 .48975 .56394 .45453 Mtetra
.574 .438 .658 r
.56394 .45453 .57065 .48975 .58292 .49005 .57611 .4534 Mtetra
.579 .438 .654 r
.57611 .4534 .58292 .49005 .59523 .48854 .58834 .45164 Mtetra
.581 .439 .653 r
.58834 .45164 .59523 .48854 .60758 .48529 .60063 .44963 Mtetra
.568 .434 .658 r
.60063 .44963 .60758 .48529 .61998 .48194 .61304 .44907 Mtetra
.524 .412 .668 r
.61304 .44907 .61998 .48194 .63252 .48115 .62564 .45255 Mtetra
.417 .357 .683 r
.62564 .45255 .63252 .48115 .64533 .48549 .63859 .46249 Mtetra
.178 .231 .68 r
.63859 .46249 .64533 .48549 .6585 .49597 .65198 .47978 Mtetra
0 0 .569 r
.65198 .47978 .6585 .49597 .67204 .51083 .66582 .50239 Mtetra
.679 .233 0 r
.66582 .50239 .67204 .51083 .68577 .5253 .67992 .52496 Mtetra
.743 .222 0 r
.67992 .52496 .68577 .5253 .69934 .53294 .69392 .53995 Mtetra
.424 0 .005 r
.69392 .53995 .69934 .53294 .71238 .52829 .70734 .54061 Mtetra
0 0 0 r
.70734 .54061 .71238 .52829 .72463 .5096 .71987 .52417 Mtetra
.71987 .52417 .72463 .5096 .7361 .47966 .73147 .49333 Mtetra
.772 .775 .271 r
.73147 .49333 .7361 .47966 .74707 .44437 .74239 .45475 Mtetra
.879 .837 .37 r
.74239 .45475 .74707 .44437 .7579 .40996 .75308 .41592 Mtetra
.944 .889 .488 r
.75308 .41592 .7579 .40996 .76894 .38077 .76394 .38237 Mtetra
.971 .928 .627 r
.76394 .38237 .76894 .38077 .78039 .35852 .77522 .35652 Mtetra
.943 .929 .76 r
.77522 .35652 .78039 .35852 .7923 .34277 .787 .3382 Mtetra
.865 .887 .849 r
.787 .3382 .7923 .34277 .80461 .33197 .79924 .32579 Mtetra
.781 .829 .89 r
.79924 .32579 .80461 .33197 .81723 .32438 .81182 .31728 Mtetra
.721 .785 .903 r
.81182 .31728 .81723 .32438 .83005 .31859 .82465 .31103 Mtetra
.688 .761 .907 r
.82465 .31103 .83005 .31859 .843 .31369 .83763 .3059 Mtetra
.673 .749 .908 r
.83763 .3059 .843 .31369 .85605 .30918 .85071 .30127 Mtetra
.667 .744 .908 r
.85071 .30127 .85605 .30918 .86918 .3048 .86388 .29682 Mtetra
.665 .742 .908 r
.86388 .29682 .86918 .3048 .88237 .30045 .87711 .29243 Mtetra
.652 .74 .914 r
.27428 .48219 .2813 .48866 .29201 .48538 .28501 .47897 Mtetra
.64 .739 .921 r
.28501 .47897 .29201 .48538 .30274 .48231 .29577 .47604 Mtetra
.616 .738 .933 r
.29577 .47604 .30274 .48231 .3135 .4796 .30653 .47364 Mtetra
.567 .734 .954 r
.30653 .47364 .3135 .4796 .32428 .47754 .31729 .47217 Mtetra
.454 .712 .978 r
.31729 .47217 .32428 .47754 .33504 .47656 .32802 .47216 Mtetra
.165 .599 .937 r
.32802 .47216 .33504 .47656 .34577 .4773 .33869 .47436 Mtetra
.373 0 0 r
.33869 .47436 .34577 .4773 .35644 .48062 .34928 .47968 Mtetra
.701 .17 0 r
.34928 .47968 .35644 .48062 .36703 .4875 .35977 .48898 Mtetra
.789 .339 .177 r
.35977 .48898 .36703 .4875 .37754 .49882 .37019 .50277 Mtetra
.81 .406 .285 r
.37019 .50277 .37754 .49882 .38801 .51488 .38059 .52077 Mtetra
.812 .429 .329 r
.38059 .52077 .38801 .51488 .3985 .53496 .39108 .54151 Mtetra
.806 .424 .331 r
.39108 .54151 .3985 .53496 .40914 .55689 .40178 .56214 Mtetra
.786 .377 .277 r
.40178 .56214 .40914 .55689 .42005 .57714 .41284 .57879 Mtetra
.679 .167 .014 r
.41284 .57879 .42005 .57714 .43134 .59148 .42431 .58752 Mtetra
.522 .807 .998 r
.42431 .58752 .43134 .59148 .44303 .59625 .4362 .58563 Mtetra
.792 .705 .768 r
.4362 .58563 .44303 .59625 .45506 .58972 .4484 .57273 Mtetra
.803 .647 .688 r
.4484 .57273 .45506 .58972 .4673 .57289 .46076 .55096 Mtetra
.797 .619 .661 r
.46076 .55096 .4673 .57289 .47959 .54912 .47312 .52427 Mtetra
.785 .602 .653 r
.47312 .52427 .47959 .54912 .49182 .52302 .48538 .49707 Mtetra
.766 .587 .656 r
.48538 .49707 .49182 .52302 .50393 .49892 .49749 .47298 Mtetra
.738 .57 .665 r
.49749 .47298 .50393 .49892 .51593 .47976 .50948 .4541 Mtetra
.701 .548 .677 r
.50948 .4541 .51593 .47976 .52787 .46672 .52141 .44095 Mtetra
.658 .521 .685 r
.52141 .44095 .52787 .46672 .53983 .4593 .53334 .43277 Mtetra
.62 .494 .688 r
.53334 .43277 .53983 .4593 .55184 .45591 .54531 .42809 Mtetra
.596 .474 .684 r
.54531 .42809 .55184 .45591 .56394 .45453 .55734 .4253 Mtetra
.588 .464 .678 r
.55734 .4253 .56394 .45453 .57611 .4534 .56944 .42313 Mtetra
.585 .459 .675 r
.56944 .42313 .57611 .4534 .58834 .45164 .58162 .42115 Mtetra
.576 .452 .675 r
.58162 .42115 .58834 .45164 .60063 .44963 .59387 .41997 Mtetra
.546 .436 .68 r
.59387 .41997 .60063 .44963 .61304 .44907 .60627 .42132 Mtetra
.469 .394 .689 r
.60627 .42132 .61304 .44907 .62564 .45255 .61891 .42773 Mtetra
.295 .296 .69 r
.61891 .42773 .62564 .45255 .63859 .46249 .63193 .44159 Mtetra
0 .09 .622 r
.63193 .44159 .63859 .46249 .65198 .47978 .64545 .46382 Mtetra
0 0 .413 r
.64545 .46382 .65198 .47978 .66582 .50239 .65949 .49238 Mtetra
.754 .337 0 r
.65949 .49238 .66582 .50239 .67992 .52496 .67387 .5216 Mtetra
.8 .312 0 r
.67387 .5216 .67992 .52496 .69392 .53995 .68821 .54319 Mtetra
.552 .009 0 r
.68821 .54319 .69392 .53995 .70734 .54061 .702 .54917 Mtetra
0 0 0 r
.702 .54917 .70734 .54061 .71987 .52417 .71482 .53565 Mtetra
.738 .8 .319 r
.71482 .53565 .71987 .52417 .73147 .49333 .72658 .50486 Mtetra
.875 .83 .359 r
.72658 .50486 .73147 .49333 .74239 .45475 .73754 .46393 Mtetra
.935 .851 .414 r
.73754 .46393 .74239 .45475 .75308 .41592 .74814 .42139 Mtetra
.97 .879 .495 r
.74814 .42139 .75308 .41592 .76394 .38237 .75885 .38387 Mtetra
.983 .907 .605 r
.75885 .38387 .76394 .38237 .77522 .35652 .76998 .3546 Mtetra
.958 .916 .727 r
.76998 .3546 .77522 .35652 .787 .3382 .78165 .33375 Mtetra
.888 .888 .825 r
.78165 .33375 .787 .3382 .79924 .32579 .79382 .31968 Mtetra
.801 .837 .878 r
.79382 .31968 .79924 .32579 .81182 .31728 .80638 .31021 Mtetra
.734 .792 .899 r
.80638 .31021 .81182 .31728 .82465 .31103 .81921 .30344 Mtetra
.694 .764 .905 r
.81921 .30344 .82465 .31103 .83763 .3059 .83221 .29806 Mtetra
.676 .75 .907 r
.83221 .29806 .83763 .3059 .85071 .30127 .84533 .2933 Mtetra
.668 .745 .908 r
.84533 .2933 .85071 .30127 .86388 .29682 .85854 .28879 Mtetra
.665 .742 .908 r
.85854 .28879 .86388 .29682 .87711 .29243 .87181 .28435 Mtetra
.649 .739 .915 r
.26722 .47567 .27428 .48219 .28501 .47897 .27797 .4725 Mtetra
.632 .737 .924 r
.27797 .4725 .28501 .47897 .29577 .47604 .28873 .46973 Mtetra
.599 .733 .939 r
.28873 .46973 .29577 .47604 .30653 .47364 .29949 .46768 Mtetra
.527 .721 .962 r
.29949 .46768 .30653 .47364 .31729 .47217 .31023 .46684 Mtetra
.356 .671 .975 r
.31023 .46684 .31729 .47217 .32802 .47216 .32092 .46789 Mtetra
0 .456 .834 r
.32092 .46789 .32802 .47216 .33869 .47436 .33152 .47164 Mtetra
.558 0 0 r
.33152 .47164 .33869 .47436 .34928 .47968 .34202 .47894 Mtetra
.759 .259 .03 r
.34202 .47894 .34928 .47968 .35977 .48898 .35242 .49041 Mtetra
.809 .372 .206 r
.35242 .49041 .35977 .48898 .37019 .50277 .36277 .50606 Mtetra
.82 .415 .28 r
.36277 .50606 .37019 .50277 .38059 .52077 .37315 .52491 Mtetra
.819 .421 .296 r
.37315 .52491 .38059 .52077 .39108 .54151 .38368 .54475 Mtetra
.808 .39 .252 r
.38368 .54475 .39108 .54151 .40178 .56214 .39452 .56225 Mtetra
.74 .236 .026 r
.39452 .56225 .40178 .56214 .41284 .57879 .40577 .57363 Mtetra
.235 .621 .956 r
.40577 .57363 .41284 .57879 .42431 .58752 .41746 .57577 Mtetra
.731 .67 .79 r
.41746 .57577 .42431 .58752 .4362 .58563 .42955 .5673 Mtetra
.773 .625 .696 r
.42955 .5673 .4362 .58563 .4484 .57273 .44189 .54919 Mtetra
.78 .604 .662 r
.44189 .54919 .4484 .57273 .46076 .55096 .45432 .52446 Mtetra
.778 .593 .65 r
.45432 .52446 .46076 .55096 .47312 .52427 .46671 .49712 Mtetra
.77 .586 .65 r
.46671 .49712 .47312 .52427 .48538 .49707 .47895 .47097 Mtetra
.757 .581 .658 r
.47895 .47097 .48538 .49707 .49749 .47298 .49105 .44869 Mtetra
.736 .574 .673 r
.49105 .44869 .49749 .47298 .50948 .4541 .50304 .43151 Mtetra
.706 .564 .691 r
.50304 .43151 .50948 .4541 .52141 .44095 .51496 .41936 Mtetra
.671 .548 .707 r
.51496 .41936 .52141 .44095 .53334 .43277 .52687 .41134 Mtetra
.638 .53 .715 r
.52687 .41134 .53334 .43277 .54531 .42809 .53882 .40614 Mtetra
.615 .514 .716 r
.53882 .40614 .54531 .42809 .55734 .4253 .55083 .40253 Mtetra
.603 .502 .712 r
.55083 .40253 .55734 .4253 .56944 .42313 .5629 .3997 Mtetra
.593 .492 .709 r
.5629 .3997 .56944 .42313 .58162 .42115 .57504 .39751 Mtetra
.573 .479 .71 r
.57504 .39751 .58162 .42115 .59387 .41997 .58727 .39673 Mtetra
.522 .45 .716 r
.58727 .39673 .59387 .41997 .60627 .42132 .59966 .39911 Mtetra
.402 .382 .722 r
.59966 .39911 .60627 .42132 .61891 .42773 .6123 .4071 Mtetra
.145 .226 .691 r
.6123 .4071 .61891 .42773 .63193 .44159 .62534 .42311 Mtetra
0 0 .54 r
.62534 .42311 .63193 .44159 .64545 .46382 .63891 .44818 Mtetra
0 0 .309 r
.63891 .44818 .64545 .46382 .65949 .49238 .65304 .4805 Mtetra
.769 .376 0 r
.65304 .4805 .65949 .49238 .67387 .5216 .66759 .51443 Mtetra
.792 .341 0 r
.66759 .51443 .67387 .5216 .68821 .54319 .68218 .54129 Mtetra
.592 .023 0 r
.68218 .54129 .68821 .54319 .702 .54917 .69626 .55218 Mtetra
.558 .906 .689 r
.69626 .55218 .702 .54917 .71482 .53565 .70938 .54207 Mtetra
.917 .912 .518 r
.70938 .54207 .71482 .53565 .72658 .50486 .72136 .51243 Mtetra
.963 .867 .465 r
.72136 .51243 .72658 .50486 .73754 .46393 .73241 .47042 Mtetra
.98 .857 .473 r
.73241 .47042 .73754 .46393 .74814 .42139 .743 .42527 Mtetra
.991 .866 .518 r
.743 .42527 .74814 .42139 .75885 .38387 .75364 .38458 Mtetra
.991 .886 .599 r
.75364 .38458 .75885 .38387 .76998 .3546 .76467 .35235 Mtetra
.966 .898 .704 r
.76467 .35235 .76998 .3546 .78165 .33375 .77625 .32919 Mtetra
.904 .882 .803 r
.77625 .32919 .78165 .33375 .79382 .31968 .78835 .31354 Mtetra
.819 .841 .866 r
.78835 .31354 .79382 .31968 .80638 .31021 .80089 .30312 Mtetra
.746 .797 .894 r
.80089 .30312 .80638 .31021 .81921 .30344 .81372 .29583 Mtetra
.701 .768 .904 r
.81372 .29583 .81921 .30344 .83221 .29806 .82675 .29017 Mtetra
.679 .752 .907 r
.82675 .29017 .83221 .29806 .84533 .2933 .8399 .28528 Mtetra
.669 .745 .908 r
.8399 .28528 .84533 .2933 .85854 .28879 .85315 .28069 Mtetra
.665 .743 .908 r
.85315 .28069 .85854 .28879 .87181 .28435 .86647 .2762 Mtetra
.646 .738 .916 r
.2601 .46909 .26722 .47567 .27797 .4725 .27087 .46598 Mtetra
.625 .735 .926 r
.27087 .46598 .27797 .4725 .28873 .46973 .28164 .46336 Mtetra
.582 .727 .943 r
.28164 .46336 .28873 .46973 .29949 .46768 .29241 .46164 Mtetra
.486 .704 .966 r
.29241 .46164 .29949 .46768 .31023 .46684 .30312 .46142 Mtetra
.254 .615 .957 r
.30312 .46142 .31023 .46684 .32092 .46789 .31376 .46348 Mtetra
0 .315 .721 r
.31376 .46348 .32092 .46789 .33152 .47164 .3243 .46866 Mtetra
.65 .094 0 r
.3243 .46866 .33152 .47164 .34202 .47894 .33471 .47773 Mtetra
.79 .306 .065 r
.33471 .47773 .34202 .47894 .35242 .49041 .34503 .49095 Mtetra
.825 .388 .199 r
.34503 .49095 .35242 .49041 .36277 .50606 .35532 .50778 Mtetra
.83 .412 .247 r
.35532 .50778 .36277 .50606 .37315 .52491 .36571 .52652 Mtetra
.823 .395 .226 r
.36571 .52652 .37315 .52491 .38368 .54475 .37635 .54434 Mtetra
.779 .293 .068 r
.37635 .54434 .38368 .54475 .39452 .56225 .38736 .55771 Mtetra
0 .325 .732 r
.38736 .55771 .39452 .56225 .40577 .57363 .39883 .5633 Mtetra
.663 .669 .845 r
.39883 .5633 .40577 .57363 .41746 .57577 .41075 .55907 Mtetra
.755 .627 .719 r
.41075 .55907 .41746 .57577 .42955 .5673 .42301 .54506 Mtetra
.772 .605 .672 r
.42301 .54506 .42955 .5673 .44189 .54919 .43545 .52336 Mtetra
.775 .593 .654 r
.43545 .52336 .44189 .54919 .45432 .52446 .44792 .49747 Mtetra
.772 .588 .65 r
.44792 .49747 .45432 .52446 .46671 .49712 .4603 .47109 Mtetra
.765 .586 .656 r
.4603 .47109 .46671 .49712 .47895 .47097 .47252 .44723 Mtetra
.754 .587 .67 r
.47252 .44723 .47895 .47097 .49105 .44869 .4846 .4276 Mtetra
.736 .589 .691 r
.4846 .4276 .49105 .44869 .50304 .43151 .49657 .41269 Mtetra
.712 .589 .716 r
.49657 .41269 .50304 .43151 .51496 .41936 .50849 .40201 Mtetra
.682 .584 .739 r
.50849 .40201 .51496 .41936 .52687 .41134 .52041 .3946 Mtetra
.654 .575 .753 r
.52041 .3946 .52687 .41134 .53882 .40614 .53236 .38934 Mtetra
.634 .563 .758 r
.53236 .38934 .53882 .40614 .55083 .40253 .54436 .38535 Mtetra
.62 .552 .757 r
.54436 .38535 .55083 .40253 .5629 .3997 .55642 .38212 Mtetra
.604 .54 .756 r
.55642 .38212 .5629 .3997 .57504 .39751 .56855 .37972 Mtetra
.572 .52 .759 r
.56855 .37972 .57504 .39751 .58727 .39673 .58078 .37901 Mtetra
.497 .478 .766 r
.58078 .37901 .58727 .39673 .59966 .39911 .59316 .38167 Mtetra
.327 .377 .762 r
.59316 .38167 .59966 .39911 .6123 .4071 .60579 .39008 Mtetra
0 .163 .681 r
.60579 .39008 .6123 .4071 .62534 .42311 .6188 .40664 Mtetra
0 0 .471 r
.6188 .40664 .62534 .42311 .63891 .44818 .63235 .43258 Mtetra
.657 .313 0 r
.63235 .43258 .63891 .44818 .65304 .4805 .64648 .46642 Mtetra
.743 .373 0 r
.64648 .46642 .65304 .4805 .66759 .51443 .66109 .50291 Mtetra
.719 .318 0 r
.66109 .50291 .66759 .51443 .68218 .54129 .6758 .53336 Mtetra
0 .029 .561 r
.6758 .53336 .68218 .54129 .69626 .55218 .6901 .54838 Mtetra
.71 .897 .964 r
.6901 .54838 .69626 .55218 .70938 .54207 .70348 .54193 Mtetra
.978 .904 .667 r
.70348 .54193 .70938 .54207 .72136 .51243 .71571 .51451 Mtetra
.997 .858 .556 r
.71571 .51451 .72136 .51243 .73241 .47042 .72694 .47288 Mtetra
.999 .843 .529 r
.72694 .47288 .73241 .47042 .743 .42527 .73761 .42655 Mtetra
.998 .847 .547 r
.73761 .42655 .743 .42527 .75364 .38458 .74825 .3838 Mtetra
.992 .862 .603 r
.74825 .3838 .75364 .38458 .76467 .35235 .75923 .34936 Mtetra
.968 .876 .69 r
.75923 .34936 .76467 .35235 .77625 .32919 .77076 .3243 Mtetra
.913 .871 .784 r
.77076 .3243 .77625 .32919 .78835 .31354 .78283 .30728 Mtetra
.832 .84 .853 r
.78283 .30728 .78835 .31354 .80089 .30312 .79535 .29597 Mtetra
.757 .8 .888 r
.79535 .29597 .80089 .30312 .81372 .29583 .80819 .28816 Mtetra
.707 .771 .901 r
.80819 .28816 .81372 .29583 .82675 .29017 .82124 .28224 Mtetra
.682 .754 .906 r
.82124 .28224 .82675 .29017 .8399 .28528 .83443 .2772 Mtetra
.67 .746 .907 r
.83443 .2772 .8399 .28528 .85315 .28069 .84772 .27252 Mtetra
.666 .743 .908 r
.84772 .27252 .85315 .28069 .86647 .2762 .86108 .26798 Mtetra
.643 .737 .917 r
.25293 .46245 .2601 .46909 .27087 .46598 .26371 .45937 Mtetra
.619 .732 .927 r
.26371 .45937 .27087 .46598 .28164 .46336 .2745 .45687 Mtetra
.567 .72 .945 r
.2745 .45687 .28164 .46336 .29241 .46164 .28527 .45543 Mtetra
.451 .685 .965 r
.28527 .45543 .29241 .46164 .30312 .46142 .29597 .45572 Mtetra
.178 .562 .934 r
.29597 .45572 .30312 .46142 .31376 .46348 .30657 .4586 Mtetra
0 .224 .653 r
.30657 .4586 .31376 .46348 .3243 .46866 .31704 .46494 Mtetra
.688 .146 0 r
.31704 .46494 .3243 .46866 .33471 .47773 .32738 .47536 Mtetra
.808 .326 .049 r
.32738 .47536 .33471 .47773 .34503 .49095 .33764 .48981 Mtetra
.839 .392 .16 r
.33764 .48981 .34503 .49095 .35532 .50778 .3479 .50723 Mtetra
.839 .4 .182 r
.3479 .50723 .35532 .50778 .36571 .52652 .35833 .52534 Mtetra
.813 .343 .1 r
.35833 .52534 .36571 .52652 .37635 .54434 .36907 .54086 Mtetra
.612 .05 0 r
.36907 .54086 .37635 .54434 .38736 .55771 .38025 .55028 Mtetra
.46 .66 .948 r
.38025 .55028 .38736 .55771 .39883 .5633 .39193 .55083 Mtetra
.737 .662 .777 r
.39193 .55083 .39883 .5633 .41075 .55907 .40404 .54155 Mtetra
.778 .633 .7 r
.40404 .54155 .41075 .55907 .42301 .54506 .41645 .52359 Mtetra
.787 .616 .669 r
.41645 .52359 .42301 .54506 .43545 .52336 .42897 .49983 Mtetra
.786 .607 .659 r
.42897 .49983 .43545 .52336 .44792 .49747 .44146 .47391 Mtetra
.781 .604 .66 r
.44146 .47391 .44792 .49747 .4603 .47109 .45382 .44911 Mtetra
.773 .605 .671 r
.45382 .44911 .4603 .47109 .47252 .44723 .46602 .42766 Mtetra
.761 .61 .691 r
.46602 .42766 .47252 .44723 .4846 .4276 .47808 .41054 Mtetra
.744 .618 .719 r
.47808 .41054 .4846 .4276 .49657 .41269 .49005 .39768 Mtetra
.72 .625 .75 r
.49005 .39768 .49657 .41269 .50849 .40201 .50199 .38835 Mtetra
.694 .628 .778 r
.50199 .38835 .50849 .40201 .52041 .3946 .51392 .38158 Mtetra
.669 .626 .797 r
.51392 .38158 .52041 .3946 .53236 .38934 .52589 .37645 Mtetra
.65 .619 .805 r
.52589 .37645 .53236 .38934 .54436 .38535 .5379 .3723 Mtetra
.635 .61 .808 r
.5379 .3723 .54436 .38535 .55642 .38212 .54997 .36883 Mtetra
.614 .597 .81 r
.54997 .36883 .55642 .38212 .56855 .37972 .56211 .36625 Mtetra
.571 .573 .816 r
.56211 .36625 .56855 .37972 .58078 .37901 .57434 .36538 Mtetra
.474 .518 .823 r
.57434 .36538 .58078 .37901 .59316 .38167 .58671 .36782 Mtetra
.258 .386 .802 r
.58671 .36782 .59316 .38167 .60579 .39008 .59932 .37579 Mtetra
0 .128 .672 r
.59932 .37579 .60579 .39008 .6188 .40664 .61229 .39167 Mtetra
0 0 .443 r
.61229 .39167 .6188 .40664 .63235 .43258 .62577 .41683 Mtetra
0 0 .278 r
.62577 .41683 .63235 .43258 .64648 .46642 .63982 .45022 Mtetra
.685 .341 0 r
.63982 .45022 .64648 .46642 .66109 .50291 .65437 .48714 Mtetra
0 0 .333 r
.65437 .48714 .66109 .50291 .6758 .53336 .66911 .51936 Mtetra
0 .093 .65 r
.66911 .51936 .6758 .53336 .6901 .54838 .68354 .53739 Mtetra
.617 .658 .868 r
.68354 .53739 .6901 .54838 .70348 .54193 .69714 .5345 Mtetra
.918 .8 .715 r
.69714 .5345 .70348 .54193 .71571 .51451 .70963 .51018 Mtetra
.976 .809 .612 r
.70963 .51018 .71571 .51451 .72694 .47288 .72109 .47038 Mtetra
.989 .811 .573 r
.72109 .47038 .72694 .47288 .73761 .42655 .73193 .42442 Mtetra
.991 .82 .575 r
.73193 .42442 .73761 .42655 .74825 .3838 .74265 .38095 Mtetra
.985 .836 .613 r
.74265 .38095 .74825 .3838 .75923 .34936 .75366 .34524 Mtetra
.964 .853 .683 r
.75366 .34524 .75923 .34936 .77076 .3243 .76518 .31886 Mtetra
.915 .856 .769 r
.76518 .31886 .77076 .3243 .78283 .30728 .77724 .30076 Mtetra
.841 .835 .841 r
.77724 .30076 .78283 .30728 .79535 .29597 .78976 .2887 Mtetra
.766 .801 .882 r
.78976 .2887 .79535 .29597 .80819 .28816 .80261 .28043 Mtetra
.713 .773 .899 r
.80261 .28043 .80819 .28816 .82124 .28224 .81569 .27424 Mtetra
.685 .755 .905 r
.81569 .27424 .82124 .28224 .83443 .2772 .82891 .26906 Mtetra
.672 .747 .907 r
.82891 .26906 .83443 .2772 .84772 .27252 .84224 .2643 Mtetra
.666 .744 .908 r
.84224 .2643 .84772 .27252 .86108 .26798 .85564 .25969 Mtetra
.642 .736 .917 r
.2457 .45574 .25293 .46245 .26371 .45937 .25651 .45267 Mtetra
.616 .73 .928 r
.25651 .45267 .26371 .45937 .2745 .45687 .26732 .45024 Mtetra
.559 .714 .944 r
.26732 .45024 .2745 .45687 .28527 .45543 .27809 .44895 Mtetra
.433 .669 .961 r
.27809 .44895 .28527 .45543 .29597 .45572 .28879 .44956 Mtetra
.15 .529 .92 r
.28879 .44956 .29597 .45572 .30657 .4586 .29937 .45295 Mtetra
0 .196 .652 r
.29937 .45295 .30657 .4586 .31704 .46494 .3098 .46 Mtetra
.682 .15 0 r
.3098 .46 .31704 .46494 .32738 .47536 .32009 .47123 Mtetra
.81 .323 0 r
.32009 .47123 .32738 .47536 .33764 .48981 .3303 .48638 Mtetra
.845 .384 .085 r
.3303 .48638 .33764 .48981 .3479 .50723 .34054 .50404 Mtetra
.84 .376 .081 r
.34054 .50404 .3479 .50723 .35833 .52534 .35099 .52155 Mtetra
.772 .263 0 r
.35099 .52155 .35833 .52534 .36907 .54086 .3618 .53544 Mtetra
0 .253 .695 r
.3618 .53544 .36907 .54086 .38025 .55028 .37311 .54223 Mtetra
.616 .707 .91 r
.37311 .54223 .38025 .55028 .39193 .55083 .38494 .53962 Mtetra
.781 .695 .768 r
.38494 .53962 .39193 .55083 .40404 .54155 .3972 .52733 Mtetra
.815 .672 .706 r
.3972 .52733 .40404 .54155 .41645 .52359 .40971 .50721 Mtetra
.822 .659 .681 r
.40971 .50721 .41645 .52359 .42897 .49983 .42231 .48252 Mtetra
.821 .653 .674 r
.42231 .48252 .42897 .49983 .44146 .47391 .43484 .45689 Mtetra
.814 .651 .681 r
.43484 .45689 .44146 .47391 .45382 .44911 .44721 .43327 Mtetra
.803 .654 .698 r
.44721 .43327 .45382 .44911 .46602 .42766 .45942 .41342 Mtetra
.787 .661 .724 r
.45942 .41342 .46602 .42766 .47808 .41054 .47149 .39786 Mtetra
.764 .67 .758 r
.47149 .39786 .47808 .41054 .49005 .39768 .48347 .38623 Mtetra
.736 .677 .793 r
.48347 .38623 .49005 .39768 .50199 .38835 .49543 .37768 Mtetra
.706 .679 .822 r
.49543 .37768 .50199 .38835 .51392 .38158 .50738 .37127 Mtetra
.681 .677 .84 r
.50738 .37127 .51392 .38158 .52589 .37645 .51938 .36622 Mtetra
.661 .672 .85 r
.51938 .36622 .52589 .37645 .5379 .3723 .53141 .36199 Mtetra
.644 .664 .854 r
.53141 .36199 .5379 .3723 .54997 .36883 .54351 .35839 Mtetra
.62 .652 .86 r
.54351 .35839 .54997 .36883 .56211 .36625 .55567 .35566 Mtetra
.57 .626 .869 r
.55567 .35566 .56211 .36625 .57434 .36538 .56791 .35456 Mtetra
.456 .564 .876 r
.56791 .35456 .57434 .36538 .58671 .36782 .58029 .35652 Mtetra
.212 .411 .84 r
.58029 .35652 .58671 .36782 .59932 .37579 .59287 .36358 Mtetra
0 .132 .68 r
.59287 .36358 .59932 .37579 .61229 .39167 .60579 .37797 Mtetra
0 0 .452 r
.60579 .37797 .61229 .39167 .62577 .41683 .61917 .40118 Mtetra
0 0 .315 r
.61917 .40118 .62577 .41683 .63982 .45022 .63309 .43254 Mtetra
0 0 .302 r
.63309 .43254 .63982 .45022 .65437 .48714 .64752 .46806 Mtetra
0 0 .42 r
.64752 .46806 .65437 .48714 .66911 .51936 .66218 .50023 Mtetra
0 .137 .662 r
.66218 .50023 .66911 .51936 .68354 .53739 .67665 .51994 Mtetra
.548 .526 .783 r
.67665 .51994 .68354 .53739 .69714 .5345 .6904 .52016 Mtetra
.832 .696 .713 r
.6904 .52016 .69714 .5345 .70963 .51018 .70313 .49942 Mtetra
.927 .748 .64 r
.70313 .49942 .70963 .51018 .72109 .47038 .71487 .46263 Mtetra
.96 .771 .602 r
.71487 .46263 .72109 .47038 .73193 .42442 .72594 .41851 Mtetra
.972 .789 .598 r
.72594 .41851 .73193 .42442 .74265 .38095 .73682 .37566 Mtetra
.971 .809 .625 r
.73682 .37566 .74265 .38095 .75366 .34524 .74793 .33971 Mtetra
.954 .829 .682 r
.74793 .33971 .75366 .34524 .76518 .31886 .75949 .31269 Mtetra
.912 .839 .759 r
.75949 .31269 .76518 .31886 .77724 .30076 .77157 .29389 Mtetra
.845 .827 .831 r
.77157 .29389 .77724 .30076 .78976 .2887 .78411 .28127 Mtetra
.772 .8 .875 r
.78411 .28127 .78976 .2887 .80261 .28043 .79698 .27261 Mtetra
.718 .774 .896 r
.79698 .27261 .80261 .28043 .81569 .27424 .81009 .26618 Mtetra
.688 .757 .904 r
.81009 .26618 .81569 .27424 .82891 .26906 .82335 .26085 Mtetra
.673 .748 .907 r
.82335 .26085 .82891 .26906 .84224 .2643 .83671 .256 Mtetra
.667 .744 .908 r
.83671 .256 .84224 .2643 .85564 .25969 .85016 .25134 Mtetra
.642 .736 .917 r
.23842 .44896 .2457 .45574 .25651 .45267 .24925 .44587 Mtetra
.615 .728 .927 r
.24925 .44587 .25651 .45267 .26732 .45024 .26008 .44343 Mtetra
.558 .71 .942 r
.26008 .44343 .26732 .45024 .27809 .44895 .27087 .44216 Mtetra
.436 .661 .956 r
.27087 .44216 .27809 .44895 .28879 .44956 .28158 .44282 Mtetra
.174 .525 .92 r
.28158 .44282 .28879 .44956 .29937 .45295 .29216 .44632 Mtetra
0 .225 .705 r
.29216 .44632 .29937 .45295 .3098 .46 .30259 .45354 Mtetra
.623 .107 0 r
.30259 .45354 .3098 .46 .32009 .47123 .31286 .46499 Mtetra
.781 .292 0 r
.31286 .46499 .32009 .47123 .3303 .48638 .32304 .48034 Mtetra
.829 .36 0 r
.32304 .48034 .3303 .48638 .34054 .50404 .33326 .4981 Mtetra
.82 .345 0 r
.33326 .4981 .34054 .50404 .35099 .52155 .34369 .51556 Mtetra
.71 .198 0 r
.34369 .51556 .35099 .52155 .3618 .53544 .35452 .52916 Mtetra
0 .329 .782 r
.35452 .52916 .3618 .53544 .37311 .54223 .36586 .53546 Mtetra
.633 .752 .934 r
.36586 .53546 .37311 .54223 .38494 .53962 .37774 .53226 Mtetra
.824 .769 .801 r
.37774 .53226 .38494 .53962 .3972 .52733 .39007 .51941 Mtetra
.871 .755 .732 r
.39007 .51941 .3972 .52733 .40971 .50721 .40267 .49887 Mtetra
.885 .747 .704 r
.40267 .49887 .40971 .50721 .42231 .48252 .41534 .47398 Mtetra
.887 .744 .698 r
.41534 .47398 .42231 .48252 .43484 .45689 .42795 .44834 Mtetra
.881 .746 .709 r
.42795 .44834 .43484 .45689 .44721 .43327 .44039 .42483 Mtetra
.866 .75 .733 r
.44039 .42483 .44721 .43327 .45942 .41342 .45265 .40511 Mtetra
.842 .754 .766 r
.45265 .40511 .45942 .41342 .47149 .39786 .46477 .38964 Mtetra
.807 .754 .804 r
.46477 .38964 .47149 .39786 .48347 .38623 .4768 .37803 Mtetra
.765 .748 .837 r
.4768 .37803 .48347 .38623 .49543 .37768 .4888 .36941 Mtetra
.725 .738 .862 r
.4888 .36941 .49543 .37768 .50738 .37127 .50079 .3629 Mtetra
.692 .726 .876 r
.50079 .3629 .50738 .37127 .51938 .36622 .51282 .35773 Mtetra
.668 .716 .885 r
.51282 .35773 .51938 .36622 .53141 .36199 .52489 .35342 Mtetra
.648 .708 .891 r
.52489 .35342 .53141 .36199 .54351 .35839 .53701 .34978 Mtetra
.619 .697 .899 r
.53701 .34978 .54351 .35839 .55567 .35566 .5492 .34702 Mtetra
.563 .673 .912 r
.5492 .34702 .55567 .35566 .56791 .35456 .56147 .34577 Mtetra
.438 .608 .92 r
.56147 .34577 .56791 .35456 .58029 .35652 .57385 .34726 Mtetra
.18 .446 .874 r
.57385 .34726 .58029 .35652 .59287 .36358 .58643 .35328 Mtetra
0 .158 .697 r
.58643 .35328 .59287 .36358 .60579 .37797 .5993 .36585 Mtetra
0 0 .475 r
.5993 .36585 .60579 .37797 .61917 .40118 .61257 .38643 Mtetra
0 0 .355 r
.61257 .38643 .61917 .40118 .63309 .43254 .62634 .41471 Mtetra
0 0 .36 r
.62634 .41471 .63309 .43254 .64752 .46806 .64059 .44738 Mtetra
0 0 .481 r
.64059 .44738 .64752 .46806 .66218 .50023 .65512 .47787 Mtetra
.064 .168 .663 r
.65512 .47787 .66218 .50023 .67665 .51994 .66953 .49782 Mtetra
.512 .464 .74 r
.66953 .49782 .67665 .51994 .6904 .52016 .68337 .50029 Mtetra
.765 .623 .703 r
.68337 .50029 .6904 .52016 .70313 .49942 .69631 .4831 Mtetra
.876 .694 .652 r
.69631 .4831 .70313 .49942 .71487 .46263 .70833 .45005 Mtetra
.925 .731 .621 r
.70833 .45005 .71487 .46263 .72594 .41851 .71967 .40891 Mtetra
.947 .758 .615 r
.71967 .40891 .72594 .41851 .73682 .37566 .73078 .36785 Mtetra
.952 .783 .636 r
.73078 .36785 .73682 .37566 .74793 .33971 .74203 .33265 Mtetra
.94 .806 .685 r
.74203 .33265 .74793 .33971 .75949 .31269 .75369 .30567 Mtetra
.905 .821 .754 r
.75369 .30567 .75949 .31269 .77157 .29389 .76583 .28659 Mtetra
.845 .818 .823 r
.76583 .28659 .77157 .29389 .78411 .28127 .7784 .27362 Mtetra
.776 .797 .87 r
.7784 .27362 .78411 .28127 .79698 .27261 .7913 .26467 Mtetra
.722 .774 .893 r
.7913 .26467 .79698 .27261 .81009 .26618 .80444 .25804 Mtetra
.69 .757 .903 r
.80444 .25804 .81009 .26618 .82335 .26085 .81774 .25257 Mtetra
.675 .748 .906 r
.81774 .25257 .82335 .26085 .83671 .256 .83114 .24764 Mtetra
.668 .744 .907 r
.83114 .24764 .83671 .256 .85016 .25134 .84463 .24291 Mtetra
.643 .735 .916 r
.23108 .44211 .23842 .44896 .24925 .44587 .24195 .43897 Mtetra
.618 .727 .924 r
.24195 .43897 .24925 .44587 .26008 .44343 .2528 .43644 Mtetra
.566 .708 .937 r
.2528 .43644 .26008 .44343 .27087 .44216 .26363 .43503 Mtetra
.458 .661 .949 r
.26363 .43503 .27087 .44216 .28158 .44282 .27436 .43547 Mtetra
.238 .543 .926 r
.27436 .43547 .28158 .44282 .29216 .44632 .28498 .43867 Mtetra
0 .294 .78 r
.28498 .43867 .29216 .44632 .30259 .45354 .29542 .44551 Mtetra
0 0 .503 r
.29542 .44551 .30259 .45354 .31286 .46499 .30571 .45657 Mtetra
.699 .226 0 r
.30571 .45657 .31286 .46499 .32304 .48034 .31588 .47168 Mtetra
.776 .317 0 r
.31588 .47168 .32304 .48034 .33326 .4981 .32607 .48954 Mtetra
.777 .317 0 r
.32607 .48954 .33326 .4981 .34369 .51556 .33644 .50764 Mtetra
.684 .2 0 r
.33644 .50764 .34369 .51556 .35452 .52916 .34718 .52255 Mtetra
0 .185 .665 r
.34718 .52255 .35452 .52916 .36586 .53546 .35844 .53075 Mtetra
.476 .767 .995 r
.35844 .53075 .36586 .53546 .37774 .53226 .37026 .52971 Mtetra
.843 .901 .878 r
.37026 .52971 .37774 .53226 .39007 .51941 .38257 .51882 Mtetra
.933 .895 .768 r
.38257 .51882 .39007 .51941 .40267 .49887 .39521 .49959 Mtetra
.959 .885 .715 r
.39521 .49959 .40267 .49887 .41534 .47398 .40798 .47509 Mtetra
.966 .882 .699 r
.40798 .47509 .41534 .47398 .42795 .44834 .42071 .44893 Mtetra
.961 .884 .71 r
.42071 .44893 .42795 .44834 .44039 .42483 .43329 .42422 Mtetra
.946 .887 .741 r
.43329 .42422 .44039 .42483 .45265 .40511 .44568 .40295 Mtetra
.916 .883 .786 r
.44568 .40295 .45265 .40511 .46477 .38964 .45791 .38591 Mtetra
.869 .867 .833 r
.45791 .38591 .46477 .38964 .4768 .37803 .47003 .37292 Mtetra
.811 .837 .87 r
.47003 .37292 .4768 .37803 .4888 .36941 .48209 .36327 Mtetra
.754 .804 .892 r
.48209 .36327 .4888 .36941 .50079 .3629 .49414 .35605 Mtetra
.708 .775 .904 r
.49414 .35605 .50079 .3629 .51282 .35773 .5062 .3505 Mtetra
.673 .755 .912 r
.5062 .3505 .51282 .35773 .52489 .35342 .51831 .34607 Mtetra
.644 .742 .921 r
.51831 .34607 .52489 .35342 .53701 .34978 .53047 .34252 Mtetra
.606 .732 .934 r
.53047 .34252 .53701 .34978 .5492 .34702 .54269 .33992 Mtetra
.538 .711 .951 r
.54269 .33992 .5492 .34702 .56147 .34577 .55499 .33878 Mtetra
.396 .646 .958 r
.55499 .33878 .56147 .34577 .57385 .34726 .56741 .34007 Mtetra
.115 .472 .894 r
.56741 .34007 .57385 .34726 .58643 .35328 .57999 .34527 Mtetra
0 .174 .693 r
.57999 .34527 .58643 .35328 .5993 .36585 .59282 .35609 Mtetra
0 0 .474 r
.59282 .35609 .5993 .36585 .61257 .38643 .606 .37386 Mtetra
0 0 .372 r
.606 .37386 .61257 .38643 .62634 .41471 .61963 .39847 Mtetra
0 0 .396 r
.61963 .39847 .62634 .41471 .64059 .44738 .63368 .42728 Mtetra
0 0 .524 r
.63368 .42728 .64059 .44738 .65512 .47787 .64802 .45473 Mtetra
.115 .197 .672 r
.64802 .45473 .65512 .47787 .66953 .49782 .66232 .47346 Mtetra
.496 .439 .723 r
.66232 .47346 .66953 .49782 .68337 .50029 .67617 .47701 Mtetra
.721 .58 .696 r
.67617 .47701 .68337 .50029 .69631 .4831 .68927 .46282 Mtetra
.834 .653 .659 r
.68927 .46282 .69631 .4831 .70833 .45005 .70154 .43364 Mtetra
.891 .697 .634 r
.70154 .43364 .70833 .45005 .71967 .40891 .71317 .39611 Mtetra
.92 .73 .629 r
.71317 .39611 .71967 .40891 .73078 .36785 .72454 .35772 Mtetra
.93 .758 .647 r
.72454 .35772 .73078 .36785 .74203 .33265 .73599 .32406 Mtetra
.923 .785 .69 r
.73599 .32406 .74203 .33265 .75369 .30567 .74778 .29776 Mtetra
.894 .804 .752 r
.74778 .29776 .75369 .30567 .76583 .28659 .75999 .2788 Mtetra
.841 .806 .817 r
.75999 .2788 .76583 .28659 .7784 .27362 .77262 .26571 Mtetra
.777 .792 .865 r
.77262 .26571 .7784 .27362 .7913 .26467 .78556 .25658 Mtetra
.725 .772 .891 r
.78556 .25658 .7913 .26467 .80444 .25804 .79874 .24979 Mtetra
.692 .757 .902 r
.79874 .24979 .80444 .25804 .81774 .25257 .81207 .24421 Mtetra
.676 .749 .906 r
.81207 .24421 .81774 .25257 .83114 .24764 .82552 .2392 Mtetra
.668 .744 .907 r
.82552 .2392 .83114 .24764 .84463 .24291 .83905 .23441 Mtetra
.645 .736 .915 r
.22369 .4352 .23108 .44211 .24195 .43897 .23459 .43196 Mtetra
.623 .728 .922 r
.23459 .43196 .24195 .43897 .2528 .43644 .24548 .42928 Mtetra
.579 .709 .932 r
.24548 .42928 .2528 .43644 .26363 .43503 .25634 .4276 Mtetra
.491 .667 .941 r
.25634 .4276 .26363 .43503 .27436 .43547 .26713 .4276 Mtetra
.321 .572 .93 r
.26713 .4276 .27436 .43547 .28498 .43867 .2778 .43013 Mtetra
.033 .378 .843 r
.2778 .43013 .28498 .43867 .29542 .44551 .2883 .43611 Mtetra
0 .105 .644 r
.2883 .43611 .29542 .44551 .30571 .45657 .29863 .44624 Mtetra
0 0 .426 r
.29863 .44624 .30571 .45657 .31588 .47168 .30883 .46066 Mtetra
.683 .257 0 r
.30883 .46066 .31588 .47168 .32607 .48954 .31898 .47853 Mtetra
.725 .299 0 r
.31898 .47853 .32607 .48954 .33644 .50764 .32924 .49779 Mtetra
.703 .255 0 r
.32924 .49779 .33644 .50764 .34718 .52255 .33982 .5153 Mtetra
.573 .069 0 r
.33982 .5153 .34718 .52255 .35844 .53075 .35088 .52742 Mtetra
0 .439 .772 r
.35088 .52742 .35844 .53075 .37026 .52971 .36251 .53102 Mtetra
.588 .947 .879 r
.36251 .53102 .37026 .52971 .38257 .51882 .3747 .52447 Mtetra
.833 .984 .703 r
.3747 .52447 .38257 .51882 .39521 .49959 .38733 .50831 Mtetra
.89 .951 .602 r
.38733 .50831 .39521 .49959 .40798 .47509 .40019 .48499 Mtetra
.91 .936 .568 r
.40019 .48499 .40798 .47509 .42071 .44893 .41309 .45808 Mtetra
.925 .938 .582 r
.41309 .45808 .42071 .44893 .43329 .42422 .42587 .43112 Mtetra
.936 .953 .633 r
.42587 .43112 .43329 .42422 .44568 .40295 .43847 .40682 Mtetra
.938 .966 .712 r
.43847 .40682 .44568 .40295 .45791 .38591 .45088 .38666 Mtetra
.916 .96 .799 r
.45088 .38666 .45791 .38591 .47003 .37292 .46313 .37095 Mtetra
.863 .926 .867 r
.46313 .37095 .47003 .37292 .48209 .36327 .47529 .35924 Mtetra
.795 .875 .906 r
.47529 .35924 .48209 .36327 .49414 .35605 .48741 .3507 Mtetra
.731 .828 .925 r
.48741 .3507 .49414 .35605 .5062 .3505 .49952 .34446 Mtetra
.677 .794 .937 r
.49952 .34446 .5062 .3505 .51831 .34607 .51167 .33989 Mtetra
.627 .776 .952 r
.51167 .33989 .51831 .34607 .53047 .34252 .52387 .33658 Mtetra
.567 .763 .971 r
.52387 .33658 .53047 .34252 .54269 .33992 .53613 .33449 Mtetra
.464 .738 .987 r
.53613 .33449 .54269 .33992 .55499 .33878 .54848 .33389 Mtetra
.265 .652 .966 r
.54848 .33389 .55499 .33878 .56741 .34007 .56093 .33548 Mtetra
0 .435 .829 r
.56093 .33548 .56741 .34007 .57999 .34527 .57354 .34034 Mtetra
0 .129 .582 r
.57354 .34034 .57999 .34527 .59282 .35609 .58636 .34981 Mtetra
.602 .1 0 r
.58636 .34981 .59282 .35609 .606 .37386 .59949 .36495 Mtetra
.649 .203 0 r
.59949 .36495 .606 .37386 .61963 .39847 .61299 .38571 Mtetra
0 0 .397 r
.61299 .38571 .61963 .39847 .63368 .42728 .62686 .41 Mtetra
0 0 .558 r
.62686 .41 .63368 .42728 .64802 .45473 .64099 .43329 Mtetra
.149 .234 .697 r
.64099 .43329 .64802 .45473 .66232 .47346 .65513 .4494 Mtetra
.499 .442 .725 r
.65513 .4494 .66232 .47346 .67617 .47701 .66893 .45264 Mtetra
.698 .561 .696 r
.66893 .45264 .67617 .47701 .68927 .46282 .68212 .44043 Mtetra
.804 .629 .664 r
.68212 .44043 .68927 .46282 .70154 .43364 .6946 .41468 Mtetra
.862 .673 .644 r
.6946 .41468 .70154 .43364 .71317 .39611 .70651 .38089 Mtetra
.894 .707 .641 r
.70651 .38089 .71317 .39611 .72454 .35772 .71814 .34561 Mtetra
.909 .737 .657 r
.71814 .34561 .72454 .35772 .73599 .32406 .72981 .31408 Mtetra
.905 .766 .696 r
.72981 .31408 .73599 .32406 .74778 .29776 .74175 .28894 Mtetra
.881 .787 .753 r
.74175 .28894 .74778 .29776 .75999 .2788 .75407 .27048 Mtetra
.833 .794 .814 r
.75407 .27048 .75999 .2788 .77262 .26571 .76677 .2575 Mtetra
.775 .785 .861 r
.76677 .2575 .77262 .26571 .78556 .25658 .77976 .24832 Mtetra
.725 .77 .888 r
.77976 .24832 .78556 .25658 .79874 .24979 .79298 .24143 Mtetra
.693 .756 .9 r
.79298 .24143 .79874 .24979 .81207 .24421 .80636 .23576 Mtetra
.677 .748 .905 r
.80636 .23576 .81207 .24421 .82552 .2392 .81985 .23068 Mtetra
.669 .744 .907 r
.81985 .23068 .82552 .2392 .83905 .23441 .83342 .22584 Mtetra
.648 .736 .913 r
.21625 .42821 .22369 .4352 .23459 .43196 .22717 .42487 Mtetra
.63 .729 .918 r
.22717 .42487 .23459 .43196 .24548 .42928 .2381 .42199 Mtetra
.595 .712 .926 r
.2381 .42199 .24548 .42928 .25634 .4276 .24902 .41995 Mtetra
.527 .677 .933 r
.24902 .41995 .25634 .4276 .26713 .4276 .25987 .41934 Mtetra
.401 .603 .929 r
.25987 .41934 .26713 .4276 .2778 .43013 .27061 .42094 Mtetra
.187 .457 .881 r
.27061 .42094 .2778 .43013 .2883 .43611 .28121 .4257 Mtetra
0 .23 .75 r
.28121 .4257 .2883 .43611 .29863 .44624 .29162 .43447 Mtetra
0 0 .559 r
.29162 .43447 .29863 .44624 .30883 .46066 .30186 .44776 Mtetra
0 0 .389 r
.30186 .44776 .30883 .46066 .31898 .47853 .31198 .46533 Mtetra
.673 .284 0 r
.31198 .46533 .31898 .47853 .32924 .49779 .32213 .48576 Mtetra
.724 .311 0 r
.32213 .48576 .32924 .49779 .33982 .5153 .33249 .50641 Mtetra
.726 .261 0 r
.33249 .50641 .33982 .5153 .35088 .52742 .34325 .52362 Mtetra
.62 .061 0 r
.34325 .52362 .35088 .52742 .36251 .53102 .35459 .53355 Mtetra
.181 0 0 r
.35459 .53355 .36251 .53102 .3747 .52447 .36656 .53333 Mtetra
0 0 0 r
.36656 .53333 .3747 .52447 .38733 .50831 .37909 .52206 Mtetra
.37909 .52206 .38733 .50831 .40019 .48499 .39201 .50116 Mtetra
.683 .803 .346 r
.39201 .50116 .40019 .48499 .41309 .45808 .40509 .47394 Mtetra
.755 .837 .381 r
.40509 .47394 .41309 .45808 .42587 .43112 .41813 .44441 Mtetra
.818 .882 .451 r
.41813 .44441 .42587 .43112 .43847 .40682 .43099 .4162 Mtetra
.873 .934 .557 r
.43099 .4162 .43847 .40682 .45088 .38666 .44364 .39177 Mtetra
.907 .975 .685 r
.44364 .39177 .45088 .38666 .46313 .37095 .45608 .37221 Mtetra
.897 .98 .807 r
.45608 .37221 .46313 .37095 .47529 .35924 .46838 .35753 Mtetra
.839 .943 .891 r
.46838 .35753 .47529 .35924 .48741 .3507 .48059 .34704 Mtetra
.758 .889 .937 r
.48059 .34704 .48741 .3507 .49952 .34446 .49277 .33985 Mtetra
.673 .843 .965 r
.49277 .33985 .49952 .34446 .51167 .33989 .50496 .33514 Mtetra
.58 .811 .987 r
.50496 .33514 .51167 .33989 .52387 .33658 .5172 .33235 Mtetra
.454 .778 .998 r
.5172 .33235 .52387 .33658 .53613 .33449 .52951 .3312 Mtetra
.246 .698 .954 r
.52951 .3312 .53613 .33449 .54848 .33389 .54191 .33174 Mtetra
0 .503 .778 r
.54191 .33174 .54848 .33389 .56093 .33548 .55442 .33428 Mtetra
.375 0 0 r
.55442 .33428 .56093 .33548 .57354 .34034 .56708 .33947 Mtetra
.58 .003 0 r
.56708 .33947 .57354 .34034 .58636 .34981 .57993 .34814 Mtetra
.693 .15 0 r
.57993 .34814 .58636 .34981 .59949 .36495 .59303 .361 Mtetra
.731 .217 0 r
.59303 .361 .59949 .36495 .61299 .38571 .60644 .37792 Mtetra
.65 .181 0 r
.60644 .37792 .61299 .38571 .62686 .41 .62015 .39727 Mtetra
0 .018 .589 r
.62015 .39727 .62686 .41 .64099 .43329 .63408 .41549 Mtetra
.186 .298 .747 r
.63408 .41549 .64099 .43329 .65513 .4494 .64803 .42766 Mtetra
.524 .474 .742 r
.64803 .42766 .65513 .4494 .66893 .45264 .66174 .42912 Mtetra
.696 .564 .702 r
.66174 .42912 .66893 .45264 .68212 .44043 .67495 .4176 Mtetra
.788 .618 .67 r
.67495 .4176 .68212 .44043 .6946 .41468 .68758 .39442 Mtetra
.841 .657 .653 r
.68758 .39442 .6946 .41468 .70651 .38089 .69972 .36402 Mtetra
.872 .689 .651 r
.69972 .36402 .70651 .38089 .71814 .34561 .71161 .33196 Mtetra
.887 .719 .668 r
.71161 .33196 .71814 .34561 .72981 .31408 .7235 .30286 Mtetra
.886 .748 .704 r
.7235 .30286 .72981 .31408 .74175 .28894 .73562 .27926 Mtetra
.865 .771 .756 r
.73562 .27926 .74175 .28894 .75407 .27048 .74807 .2616 Mtetra
.823 .781 .813 r
.74807 .2616 .75407 .27048 .76677 .2575 .76084 .24894 Mtetra
.771 .777 .858 r
.76084 .24894 .76677 .2575 .77976 .24832 .7739 .23984 Mtetra
.724 .766 .885 r
.7739 .23984 .77976 .24832 .79298 .24143 .78717 .23293 Mtetra
.693 .755 .899 r
.78717 .23293 .79298 .24143 .80636 .23576 .80059 .22721 Mtetra
.677 .748 .904 r
.80059 .22721 .80636 .23576 .81985 .23068 .81413 .22207 Mtetra
.669 .744 .907 r
.81413 .22207 .81985 .23068 .83342 .22584 .82775 .21718 Mtetra
.651 .737 .912 r
.20874 .42116 .21625 .42821 .22717 .42487 .2197 .4177 Mtetra
.638 .73 .915 r
.2197 .4177 .22717 .42487 .2381 .42199 .23068 .4146 Mtetra
.611 .717 .92 r
.23068 .4146 .2381 .42199 .24902 .41995 .24164 .41216 Mtetra
.562 .688 .925 r
.24164 .41216 .24902 .41995 .25987 .41934 .25257 .41087 Mtetra
.471 .631 .923 r
.25257 .41087 .25987 .41934 .27061 .42094 .26341 .41143 Mtetra
.314 .522 .898 r
.26341 .41143 .27061 .42094 .28121 .4257 .27411 .41476 Mtetra
.076 .34 .815 r
.27411 .41476 .28121 .4257 .29162 .43447 .28463 .42185 Mtetra
0 .107 .661 r
.28463 .42185 .29162 .43447 .30186 .44776 .29494 .43357 Mtetra
0 0 .48 r
.29494 .43357 .30186 .44776 .31198 .46533 .30508 .45029 Mtetra
0 0 .326 r
.30508 .45029 .31198 .46533 .32213 .48576 .31513 .47134 Mtetra
.716 .339 0 r
.31513 .47134 .32213 .48576 .33249 .50641 .32527 .49472 Mtetra
.776 .359 0 r
.32527 .49472 .33249 .50641 .34325 .52362 .33571 .517 Mtetra
.779 .292 0 r
.33571 .517 .34325 .52362 .35459 .53355 .34668 .53387 Mtetra
.604 .046 0 r
.34668 .53387 .35459 .53355 .36656 .53333 .35833 .54121 Mtetra
.107 0 0 r
.35833 .54121 .36656 .53333 .37909 .52206 .37066 .53648 Mtetra
0 0 0 r
.37066 .53648 .37909 .52206 .39201 .50116 .38356 .51969 Mtetra
.38356 .51969 .39201 .50116 .40509 .47394 .39678 .49346 Mtetra
.657 .761 .281 r
.39678 .49346 .40509 .47394 .41813 .44441 .41007 .46202 Mtetra
.745 .816 .347 r
.41007 .46202 .41813 .44441 .43099 .4162 .42324 .42992 Mtetra
.817 .877 .441 r
.42324 .42992 .43099 .4162 .44364 .39177 .43618 .40077 Mtetra
.875 .937 .565 r
.43618 .40077 .44364 .39177 .45608 .37221 .44886 .37669 Mtetra
.899 .981 .706 r
.44886 .37669 .45608 .37221 .46838 .35753 .46133 .35836 Mtetra
.867 .987 .836 r
.46133 .35836 .46838 .35753 .48059 .34704 .47366 .34544 Mtetra
.778 .953 .93 r
.47366 .34544 .48059 .34704 .49277 .33985 .48592 .33707 Mtetra
.641 .899 .984 r
.48592 .33707 .49277 .33985 .50496 .33514 .49817 .3323 Mtetra
.444 .822 .991 r
.49817 .3323 .50496 .33514 .5172 .33235 .51046 .33036 Mtetra
.15 .67 .885 r
.51046 .33036 .5172 .33235 .52951 .3312 .52282 .33071 Mtetra
.192 0 0 r
.52282 .33071 .52951 .3312 .54191 .33174 .53528 .33303 Mtetra
.435 0 0 r
.53528 .33303 .54191 .33174 .55442 .33428 .54786 .33722 Mtetra
.564 .021 0 r
.54786 .33722 .55442 .33428 .56708 .33947 .56059 .34339 Mtetra
.637 .125 .012 r
.56059 .34339 .56708 .33947 .57993 .34814 .5735 .35181 Mtetra
.689 .187 .046 r
.5735 .35181 .57993 .34814 .59303 .361 .58661 .36269 Mtetra
.724 .211 0 r
.58661 .36269 .59303 .361 .60644 .37792 .59997 .37578 Mtetra
.698 .158 0 r
.59997 .37578 .60644 .37792 .62015 .39727 .61355 .38981 Mtetra
0 .101 .616 r
.61355 .38981 .62015 .39727 .63408 .41549 .6273 .40218 Mtetra
.269 .422 .831 r
.6273 .40218 .63408 .41549 .64803 .42766 .64105 .40924 Mtetra
.58 .536 .77 r
.64105 .40924 .64803 .42766 .66174 .42912 .65462 .40755 Mtetra
.712 .585 .711 r
.65462 .40755 .66174 .42912 .67495 .4176 .66781 .39538 Mtetra
.783 .618 .677 r
.66781 .39538 .67495 .4176 .68758 .39442 .68054 .37374 Mtetra
.826 .648 .661 r
.68054 .37374 .68758 .39442 .69972 .36402 .69287 .34615 Mtetra
.853 .676 .661 r
.69287 .34615 .69972 .36402 .71161 .33196 .70498 .31714 Mtetra
.867 .704 .678 r
.70498 .31714 .71161 .33196 .7235 .30286 .7171 .2906 Mtetra
.866 .732 .712 r
.7171 .2906 .7235 .30286 .73562 .27926 .7294 .26879 Mtetra
.848 .755 .761 r
.7294 .26879 .73562 .27926 .74807 .2616 .74198 .25217 Mtetra
.81 .768 .814 r
.74198 .25217 .74807 .2616 .76084 .24894 .75485 .24004 Mtetra
.763 .768 .857 r
.75485 .24004 .76084 .24894 .7739 .23984 .76798 .23114 Mtetra
.721 .76 .884 r
.76798 .23114 .7739 .23984 .78717 .23293 .7813 .22428 Mtetra
.692 .752 .897 r
.7813 .22428 .78717 .23293 .80059 .22721 .79478 .21855 Mtetra
.677 .747 .904 r
.79478 .21855 .80059 .22721 .81413 .22207 .80836 .21337 Mtetra
.669 .744 .906 r
.80836 .21337 .81413 .22207 .82775 .21718 .82202 .20844 Mtetra
.654 .737 .911 r
.20118 .41406 .20874 .42116 .2197 .4177 .21218 .41048 Mtetra
.645 .732 .913 r
.21218 .41048 .2197 .4177 .23068 .4146 .22319 .40716 Mtetra
.626 .721 .915 r
.22319 .40716 .23068 .4146 .24164 .41216 .23421 .40433 Mtetra
.591 .699 .918 r
.23421 .40433 .24164 .41216 .25257 .41087 .24521 .40238 Mtetra
.526 .656 .918 r
.24521 .40238 .25257 .41087 .26341 .41143 .25615 .40189 Mtetra
.412 .575 .904 r
.25615 .40189 .26341 .41143 .27411 .41476 .26697 .40373 Mtetra
.225 .432 .854 r
.26697 .40373 .27411 .41476 .28463 .42185 .27762 .40897 Mtetra
0 .221 .739 r
.27762 .40897 .28463 .42185 .29494 .43357 .28804 .41874 Mtetra
0 0 .566 r
.28804 .41874 .29494 .43357 .30508 .45029 .29824 .4339 Mtetra
0 0 .389 r
.29824 .4339 .30508 .45029 .31513 .47134 .30826 .45453 Mtetra
.669 .328 0 r
.30826 .45453 .31513 .47134 .32527 .49472 .31823 .4794 Mtetra
.756 .386 0 r
.31823 .4794 .32527 .49472 .33571 .517 .32838 .50559 Mtetra
.798 .377 0 r
.32838 .50559 .33571 .517 .34668 .53387 .33897 .52872 Mtetra
.759 .252 0 r
.33897 .52872 .34668 .53387 .35833 .54121 .35023 .5438 Mtetra
.423 0 0 r
.35023 .5438 .35833 .54121 .37066 .53648 .36227 .54674 Mtetra
0 0 0 r
.36227 .54674 .37066 .53648 .38356 .51969 .37502 .53587 Mtetra
.37502 .53587 .38356 .51969 .39678 .49346 .3883 .51261 Mtetra
.685 .782 .307 r
.3883 .51261 .39678 .49346 .41007 .46202 .4018 .48095 Mtetra
.765 .819 .345 r
.4018 .48095 .41007 .46202 .42324 .42992 .41526 .44604 Mtetra
.822 .859 .407 r
.41526 .44604 .42324 .42992 .43618 .40077 .4285 .41262 Mtetra
.866 .907 .497 r
.4285 .41262 .43618 .40077 .44886 .37669 .44145 .384 Mtetra
.889 .956 .614 r
.44145 .384 .44886 .37669 .46133 .35836 .45413 .3618 Mtetra
.868 .993 .75 r
.45413 .3618 .46133 .35836 .47366 .34544 .4666 .34621 Mtetra
.765 .993 .878 r
.4666 .34621 .47366 .34544 .48592 .33707 .47895 .33657 Mtetra
.527 .912 .934 r
.47895 .33657 .48592 .33707 .49817 .3323 .49127 .3319 Mtetra
.119 .668 .796 r
.49127 .3319 .49817 .3323 .51046 .33036 .50361 .33117 Mtetra
.288 0 0 r
.50361 .33117 .51046 .33036 .52282 .33071 .51603 .33353 Mtetra
.505 0 0 r
.51603 .33353 .52282 .33071 .53528 .33303 .52855 .33822 Mtetra
.59 .088 .028 r
.52855 .33822 .53528 .33303 .54786 .33722 .54122 .34461 Mtetra
.622 .156 .126 r
.54122 .34461 .54786 .33722 .56059 .34339 .55404 .35219 Mtetra
.635 .187 .171 r
.55404 .35219 .56059 .34339 .5735 .35181 .56703 .3606 Mtetra
.643 .195 .172 r
.56703 .3606 .5735 .35181 .58661 .36269 .58019 .36956 Mtetra
.647 .174 .117 r
.58019 .36956 .58661 .36269 .59997 .37578 .59352 .37865 Mtetra
.615 .077 0 r
.59352 .37865 .59997 .37578 .61355 .38981 .60701 .38696 Mtetra
0 .303 .652 r
.60701 .38696 .61355 .38981 .6273 .40218 .62059 .39282 Mtetra
.451 .622 .925 r
.62059 .39282 .6273 .40218 .64105 .40924 .63416 .39389 Mtetra
.665 .616 .79 r
.63416 .39389 .64105 .40924 .65462 .40755 .64758 .38799 Mtetra
.741 .614 .717 r
.64758 .38799 .65462 .40755 .66781 .39538 .66071 .37407 Mtetra
.785 .625 .682 r
.66071 .37407 .66781 .39538 .68054 .37374 .67349 .35306 Mtetra
.815 .643 .668 r
.67349 .35306 .68054 .37374 .69287 .34615 .68597 .32768 Mtetra
.836 .665 .671 r
.68597 .32768 .69287 .34615 .70498 .31714 .69828 .30145 Mtetra
.847 .691 .688 r
.69828 .30145 .70498 .31714 .7171 .2906 .71061 .27748 Mtetra
.846 .717 .721 r
.71061 .27748 .7171 .2906 .7294 .26879 .72309 .2576 Mtetra
.829 .74 .767 r
.72309 .2576 .7294 .26879 .74198 .25217 .73581 .24223 Mtetra
.795 .755 .816 r
.73581 .24223 .74198 .25217 .75485 .24004 .74879 .23079 Mtetra
.754 .759 .857 r
.74879 .23079 .75485 .24004 .76798 .23114 .76199 .22222 Mtetra
.716 .755 .883 r
.76199 .22222 .76798 .23114 .7813 .22428 .77538 .21548 Mtetra
.69 .749 .897 r
.77538 .21548 .7813 .22428 .79478 .21855 .7889 .20977 Mtetra
.676 .745 .903 r
.7889 .20977 .79478 .21855 .80836 .21337 .80253 .20458 Mtetra
.669 .743 .906 r
.80253 .20458 .80836 .21337 .82202 .20844 .81625 .19962 Mtetra
.657 .738 .909 r
.19356 .4069 .20118 .41406 .21218 .41048 .20459 .40322 Mtetra
.651 .734 .911 r
.20459 .40322 .21218 .41048 .22319 .40716 .21565 .39971 Mtetra
.638 .726 .912 r
.21565 .39971 .22319 .40716 .23421 .40433 .22672 .39653 Mtetra
.614 .71 .913 r
.22672 .39653 .23421 .40433 .24521 .40238 .23779 .39398 Mtetra
.569 .678 .913 r
.23779 .39398 .24521 .40238 .25615 .40189 .24882 .39255 Mtetra
.487 .618 .906 r
.24882 .39255 .25615 .40189 .26697 .40373 .25976 .39299 Mtetra
.343 .509 .877 r
.25976 .39299 .26697 .40373 .27762 .40897 .27055 .39634 Mtetra
.119 .33 .799 r
.27055 .39634 .27762 .40897 .28804 .41874 .28112 .40388 Mtetra
0 .097 .651 r
.28112 .40388 .28804 .41874 .29824 .4339 .29143 .4168 Mtetra
0 0 .472 r
.29143 .4168 .29824 .4339 .30826 .45453 .30149 .4358 Mtetra
0 0 .322 r
.30149 .4358 .30826 .45453 .31823 .4794 .3114 .46042 Mtetra
.677 .357 0 r
.3114 .46042 .31823 .4794 .32838 .50559 .32136 .48851 Mtetra
.723 .374 0 r
.32136 .48851 .32838 .50559 .33897 .52872 .33162 .51608 Mtetra
.716 .307 0 r
.33162 .51608 .33897 .52872 .35023 .5438 .34248 .53784 Mtetra
.549 .012 0 r
.34248 .53784 .35023 .5438 .36227 .54674 .35414 .5486 Mtetra
.238 .749 .73 r
.35414 .5486 .36227 .54674 .37502 .53587 .36664 .54502 Mtetra
.722 .914 .557 r
.36664 .54502 .37502 .53587 .3883 .51261 .37983 .52694 Mtetra
.822 .886 .458 r
.37983 .52694 .3883 .51261 .4018 .48095 .39342 .49746 Mtetra
.858 .873 .432 r
.39342 .49746 .4018 .48095 .41526 .44604 .40711 .4618 Mtetra
.879 .88 .445 r
.40711 .4618 .41526 .44604 .4285 .41262 .42063 .42557 Mtetra
.892 .902 .489 r
.42063 .42557 .4285 .41262 .44145 .384 .43385 .39324 Mtetra
.892 .936 .563 r
.43385 .39324 .44145 .384 .45413 .3618 .44676 .36752 Mtetra
.853 .974 .666 r
.44676 .36752 .45413 .3618 .4666 .34621 .4594 .34939 Mtetra
.7 .975 .769 r
.4594 .34939 .4666 .34621 .47895 .33657 .47186 .3386 Mtetra
.284 .776 .721 r
.47186 .3386 .47895 .33657 .49127 .3319 .48425 .3342 Mtetra
.246 0 0 r
.48425 .3342 .49127 .3319 .50361 .33117 .49664 .33498 Mtetra
.522 0 0 r
.49664 .33498 .50361 .33117 .51603 .33353 .50911 .33968 Mtetra
.618 .136 .086 r
.50911 .33968 .51603 .33353 .52855 .33822 .52171 .34705 Mtetra
.643 .198 .179 r
.52171 .34705 .52855 .33822 .54122 .34461 .53447 .35581 Mtetra
.639 .216 .225 r
.53447 .35581 .54122 .34461 .55404 .35219 .54739 .3648 Mtetra
.622 .208 .238 r
.54739 .3648 .55404 .35219 .56703 .3606 .56047 .37301 Mtetra
.595 .177 .219 r
.56047 .37301 .56703 .3606 .58019 .36956 .5737 .37971 Mtetra
.552 .106 .145 r
.5737 .37971 .58019 .36956 .59352 .37865 .58703 .38441 Mtetra
.433 0 0 r
.58703 .38441 .59352 .37865 .60701 .38696 .60045 .3866 Mtetra
.133 .679 .796 r
.60045 .3866 .60701 .38696 .62059 .39282 .6139 .38555 Mtetra
.684 .786 .928 r
.6139 .38555 .62059 .39282 .63416 .39389 .6273 .38021 Mtetra
.747 .676 .781 r
.6273 .38021 .63416 .39389 .64758 .38799 .64057 .36957 Mtetra
.769 .637 .714 r
.64057 .36957 .64758 .38799 .66071 .37407 .65362 .35333 Mtetra
.789 .63 .684 r
.65362 .35333 .66071 .37407 .67349 .35306 .66643 .33239 Mtetra
.806 .639 .675 r
.66643 .33239 .67349 .35306 .68597 .32768 .67903 .30878 Mtetra
.82 .656 .679 r
.67903 .30878 .68597 .32768 .69828 .30145 .69152 .28512 Mtetra
.827 .678 .698 r
.69152 .28512 .69828 .30145 .71061 .27748 .70404 .26369 Mtetra
.824 .703 .731 r
.70404 .26369 .71061 .27748 .72309 .2576 .7167 .24583 Mtetra
.808 .727 .774 r
.7167 .24583 .72309 .2576 .73581 .24223 .72957 .23185 Mtetra
.779 .743 .82 r
.72957 .23185 .73581 .24223 .74879 .23079 .74266 .22123 Mtetra
.743 .75 .858 r
.74266 .22123 .74879 .23079 .76199 .22222 .75595 .21308 Mtetra
.71 .749 .883 r
.75595 .21308 .76199 .22222 .77538 .21548 .7694 .20653 Mtetra
.687 .746 .896 r
.7694 .20653 .77538 .21548 .7889 .20977 .78298 .20089 Mtetra
.674 .744 .903 r
.78298 .20089 .7889 .20977 .80253 .20458 .79666 .1957 Mtetra
.668 .742 .906 r
.79666 .1957 .80253 .20458 .81625 .19962 .81042 .19071 Mtetra
.659 .739 .909 r
.18588 .3997 .19356 .4069 .20459 .40322 .19694 .39592 Mtetra
.655 .736 .909 r
.19694 .39592 .20459 .40322 .21565 .39971 .20803 .39225 Mtetra
.647 .73 .91 r
.20803 .39225 .21565 .39971 .22672 .39653 .21916 .38879 Mtetra
.631 .718 .91 r
.21916 .38879 .22672 .39653 .23779 .39398 .23029 .38576 Mtetra
.6 .696 .91 r
.23029 .38576 .23779 .39398 .24882 .39255 .24141 .38353 Mtetra
.542 .653 .907 r
.24141 .38353 .24882 .39255 .25976 .39299 .25246 .38273 Mtetra
.436 .572 .892 r
.25246 .38273 .25976 .39299 .27055 .39634 .2634 .38431 Mtetra
.257 .43 .843 r
.2634 .38431 .27055 .39634 .28112 .40388 .27413 .38951 Mtetra
.004 .221 .731 r
.27413 .38951 .28112 .40388 .29143 .4168 .28461 .39971 Mtetra
0 0 .569 r
.28461 .39971 .29143 .4168 .30149 .4358 .2948 .41599 Mtetra
0 0 .417 r
.2948 .41599 .30149 .4358 .3114 .46042 .30476 .4386 Mtetra
0 0 .322 r
.30476 .4386 .3114 .46042 .32136 .48851 .31464 .46623 Mtetra
0 0 .294 r
.31464 .46623 .32136 .48851 .33162 .51608 .32469 .49568 Mtetra
0 0 .348 r
.32469 .49568 .33162 .51608 .34248 .53784 .33522 .52199 Mtetra
0 0 .539 r
.33522 .52199 .34248 .53784 .35414 .5486 .34649 .5395 Mtetra
.233 .512 .909 r
.34649 .5395 .35414 .5486 .36664 .54502 .35864 .5436 Mtetra
.839 .944 .89 r
.35864 .5436 .36664 .54502 .37983 .52694 .3716 .53243 Mtetra
.954 .952 .681 r
.3716 .53243 .37983 .52694 .39342 .49746 .38514 .50769 Mtetra
.96 .921 .574 r
.38514 .50769 .39342 .49746 .40711 .4618 .39892 .47399 Mtetra
.952 .908 .533 r
.39892 .47399 .40711 .4618 .42063 .42557 .41265 .43724 Mtetra
.94 .912 .532 r
.41265 .43724 .42063 .42557 .43385 .39324 .42611 .40286 Mtetra
.916 .932 .562 r
.42611 .40286 .43385 .39324 .44676 .36752 .43923 .37467 Mtetra
.847 .958 .618 r
.43923 .37467 .44676 .36752 .4594 .34939 .45204 .35459 Mtetra
.61 .914 .648 r
.45204 .35459 .4594 .34939 .47186 .3386 .46462 .34295 Mtetra
0 0 0 r
.46462 .34295 .47186 .3386 .48425 .3342 .47708 .33899 Mtetra
.434 0 0 r
.47708 .33899 .48425 .3342 .49664 .33498 .48953 .34136 Mtetra
.61 .128 .087 r
.48953 .34136 .49664 .33498 .50911 .33968 .50206 .34839 Mtetra
.661 .218 .188 r
.50206 .34839 .50911 .33968 .52171 .34705 .51473 .35824 Mtetra
.665 .245 .238 r
.51473 .35824 .52171 .34705 .53447 .35581 .52758 .36899 Mtetra
.643 .236 .257 r
.52758 .36899 .53447 .35581 .54739 .3648 .5406 .37879 Mtetra
.603 .197 .246 r
.5406 .37879 .54739 .3648 .56047 .37301 .55378 .3861 Mtetra
.536 .119 .197 r
.55378 .3861 .56047 .37301 .5737 .37971 .56707 .38988 Mtetra
.409 0 .063 r
.56707 .38988 .5737 .37971 .58703 .38441 .58042 .3897 Mtetra
.045 0 0 r
.58042 .3897 .58703 .38441 .60045 .3866 .59379 .38558 Mtetra
.698 .969 .931 r
.59379 .38558 .60045 .3866 .6139 .38555 .60713 .3777 Mtetra
.813 .802 .842 r
.60713 .3777 .6139 .38555 .6273 .38021 .62039 .36616 Mtetra
.795 .69 .749 r
.62039 .36616 .6273 .38021 .64057 .36957 .63354 .351 Mtetra
.787 .644 .704 r
.63354 .351 .64057 .36957 .65362 .35333 .64653 .33251 Mtetra
.789 .63 .684 r
.64653 .33251 .65362 .35333 .66643 .33239 .65936 .31156 Mtetra
.795 .633 .68 r
.65936 .31156 .66643 .33239 .67903 .30878 .67207 .2896 Mtetra
.803 .646 .688 r
.67207 .2896 .67903 .30878 .69152 .28512 .68472 .2684 Mtetra
.807 .667 .709 r
.68472 .2684 .69152 .28512 .70404 .26369 .69743 .24947 Mtetra
.803 .691 .742 r
.69743 .24947 .70404 .26369 .7167 .24583 .71026 .23368 Mtetra
.788 .715 .784 r
.71026 .23368 .7167 .24583 .72957 .23185 .72327 .22116 Mtetra
.762 .733 .826 r
.72327 .22116 .72957 .23185 .74266 .22123 .73647 .21144 Mtetra
.731 .742 .861 r
.73647 .21144 .74266 .22123 .75595 .21308 .74984 .20379 Mtetra
.703 .744 .884 r
.74984 .20379 .75595 .21308 .7694 .20653 .76336 .19746 Mtetra
.684 .744 .897 r
.76336 .19746 .7694 .20653 .78298 .20089 .777 .19191 Mtetra
.673 .743 .903 r
.777 .19191 .78298 .20089 .79666 .1957 .79073 .18673 Mtetra
.667 .742 .906 r
.79073 .18673 .79666 .1957 .81042 .19071 .80454 .18172 Mtetra
.661 .74 .908 r
.17813 .39245 .18588 .3997 .19694 .39592 .18923 .38859 Mtetra
.658 .738 .908 r
.18923 .38859 .19694 .39592 .20803 .39225 .20036 .38479 Mtetra
.653 .734 .908 r
.20036 .38479 .20803 .39225 .21916 .38879 .21153 .38112 Mtetra
.643 .726 .908 r
.21153 .38112 .21916 .38879 .23029 .38576 .22272 .37772 Mtetra
.623 .71 .908 r
.22272 .37772 .23029 .38576 .24141 .38353 .23391 .37487 Mtetra
.583 .68 .907 r
.23391 .37487 .24141 .38353 .25246 .38273 .24507 .37305 Mtetra
.507 .623 .9 r
.24507 .37305 .25246 .38273 .2634 .38431 .25613 .37306 Mtetra
.373 .517 .873 r
.25613 .37306 .2634 .38431 .27413 .38951 .26704 .37602 Mtetra
.166 .345 .798 r
.26704 .37602 .27413 .38951 .28461 .39971 .27771 .38328 Mtetra
0 .13 .668 r
.27771 .38328 .28461 .39971 .2948 .41599 .2881 .39614 Mtetra
0 0 .525 r
.2881 .39614 .2948 .41599 .30476 .4386 .29822 .41532 Mtetra
0 0 .426 r
.29822 .41532 .30476 .4386 .31464 .46623 .30817 .44035 Mtetra
0 0 .392 r
.30817 .44035 .31464 .46623 .32469 .49568 .31816 .46898 Mtetra
0 0 .43 r
.31816 .46898 .32469 .49568 .33522 .52199 .32846 .49707 Mtetra
0 0 .547 r
.32846 .49707 .33522 .52199 .34649 .5395 .3394 .51919 Mtetra
.199 .279 .722 r
.3394 .51919 .34649 .5395 .35864 .5436 .35116 .5301 Mtetra
.627 .62 .823 r
.35116 .5301 .35864 .5436 .3716 .53243 .36378 .52653 Mtetra
.881 .811 .775 r
.36378 .52653 .3716 .53243 .38514 .50769 .37711 .50851 Mtetra
.968 .874 .69 r
.37711 .50851 .38514 .50769 .39892 .47399 .39085 .47947 Mtetra
.986 .895 .63 r
.39085 .47947 .39892 .47399 .41265 .43724 .40465 .44494 Mtetra
.98 .912 .602 r
.40465 .44494 .41265 .43724 .42611 .40286 .41827 .41081 Mtetra
.953 .936 .604 r
.41827 .41081 .42611 .40286 .43923 .37467 .43157 .38179 Mtetra
.868 .961 .625 r
.43157 .38179 .43923 .37467 .45204 .35459 .44453 .36077 Mtetra
.559 .873 .586 r
.44453 .36077 .45204 .35459 .46462 .34295 .45723 .34876 Mtetra
.102 0 0 r
.45723 .34876 .46462 .34295 .47708 .33899 .46977 .34533 Mtetra
.51 .011 .008 r
.46977 .34533 .47708 .33899 .48953 .34136 .48228 .34905 Mtetra
.646 .187 .15 r
.48228 .34905 .48953 .34136 .50206 .34839 .49487 .35788 Mtetra
.682 .25 .215 r
.49487 .35788 .50206 .34839 .51473 .35824 .50761 .36941 Mtetra
.676 .256 .24 r
.50761 .36941 .51473 .35824 .52758 .36899 .52054 .38111 Mtetra
.64 .221 .233 r
.52054 .38111 .52758 .36899 .5406 .37879 .53365 .39059 Mtetra
.565 .136 .184 r
.53365 .39059 .5406 .37879 .55378 .3861 .54691 .39592 Mtetra
.41 0 .049 r
.54691 .39592 .55378 .3861 .56707 .38988 .56026 .39601 Mtetra
.002 0 0 r
.56026 .39601 .56707 .38988 .58042 .3897 .57363 .39067 Mtetra
.72 .989 .85 r
.57363 .39067 .58042 .3897 .59379 .38558 .58696 .38052 Mtetra
.869 .874 .838 r
.58696 .38052 .59379 .38558 .60713 .3777 .60022 .36657 Mtetra
.836 .742 .76 r
.60022 .36657 .60713 .3777 .62039 .36616 .61339 .34983 Mtetra
.806 .671 .715 r
.61339 .34983 .62039 .36616 .63354 .351 .62645 .33111 Mtetra
.789 .636 .692 r
.62645 .33111 .63354 .351 .64653 .33251 .63941 .31109 Mtetra
.782 .623 .683 r
.63941 .31109 .64653 .33251 .65936 .31156 .65228 .29052 Mtetra
.783 .625 .685 r
.65228 .29052 .65936 .31156 .67207 .2896 .66509 .27034 Mtetra
.785 .638 .698 r
.66509 .27034 .67207 .2896 .68472 .2684 .6779 .25158 Mtetra
.786 .658 .721 r
.6779 .25158 .68472 .2684 .69743 .24947 .69077 .2351 Mtetra
.781 .682 .755 r
.69077 .2351 .69743 .24947 .71026 .23368 .70376 .22136 Mtetra
.767 .706 .795 r
.70376 .22136 .71026 .23368 .72327 .22116 .71691 .21031 Mtetra
.744 .725 .834 r
.71691 .21031 .72327 .22116 .73647 .21144 .73022 .20151 Mtetra
.718 .736 .865 r
.73022 .20151 .73647 .21144 .74984 .20379 .74368 .19437 Mtetra
.695 .74 .886 r
.74368 .19437 .74984 .20379 .76336 .19746 .75727 .1883 Mtetra
.68 .742 .897 r
.75727 .1883 .76336 .19746 .777 .19191 .77096 .18283 Mtetra
.671 .742 .903 r
.77096 .18283 .777 .19191 .79073 .18673 .78474 .17768 Mtetra
.667 .741 .906 r
.78474 .17768 .79073 .18673 .80454 .18172 .7986 .17265 Mtetra
.662 .74 .908 r
.17033 .38515 .17813 .39245 .18923 .38859 .18145 .38123 Mtetra
.661 .739 .908 r
.18145 .38123 .18923 .38859 .20036 .38479 .19262 .37733 Mtetra
.658 .736 .908 r
.19262 .37733 .20036 .38479 .21153 .38112 .20382 .37351 Mtetra
.651 .731 .908 r
.20382 .37351 .21153 .38112 .22272 .37772 .21506 .36984 Mtetra
.638 .721 .908 r
.21506 .36984 .22272 .37772 .23391 .37487 .22632 .36653 Mtetra
.612 .701 .907 r
.22632 .36653 .23391 .37487 .24507 .37305 .23757 .36392 Mtetra
.56 .661 .904 r
.23757 .36392 .24507 .37305 .25613 .37306 .24875 .36264 Mtetra
.466 .587 .89 r
.24875 .36264 .25613 .37306 .26704 .37602 .25982 .36361 Mtetra
.31 .457 .846 r
.25982 .36361 .26704 .37602 .27771 .38328 .2707 .36803 Mtetra
.105 .274 .753 r
.2707 .36803 .27771 .38328 .2881 .39614 .28133 .37721 Mtetra
0 .087 .63 r
.28133 .37721 .2881 .39614 .29822 .41532 .29169 .39217 Mtetra
0 0 .528 r
.29169 .39217 .29822 .41532 .30817 .44035 .30182 .41306 Mtetra
0 0 .48 r
.30182 .41306 .30817 .44035 .31816 .46898 .31189 .43858 Mtetra
0 0 .49 r
.31189 .43858 .31816 .46898 .32846 .49707 .32213 .46566 Mtetra
0 .03 .551 r
.32213 .46566 .32846 .49707 .3394 .51919 .33283 .48966 Mtetra
.2 .206 .641 r
.33283 .48966 .3394 .51919 .35116 .5301 .34424 .5054 Mtetra
.477 .422 .717 r
.34424 .5054 .35116 .5301 .36378 .52653 .35649 .50878 Mtetra
.715 .612 .741 r
.35649 .50878 .36378 .52653 .37711 .50851 .36949 .49836 Mtetra
.866 .74 .722 r
.36949 .49836 .37711 .50851 .39085 .47947 .38303 .47601 Mtetra
.943 .817 .691 r
.38303 .47601 .39085 .47947 .40465 .44494 .39677 .44628 Mtetra
.975 .871 .669 r
.39677 .44628 .40465 .44494 .41827 .41081 .41043 .41488 Mtetra
.974 .922 .668 r
.41043 .41488 .41827 .41081 .43157 .38179 .42383 .38701 Mtetra
.912 .974 .685 r
.42383 .38701 .43157 .38179 .44453 .36077 .43691 .36632 Mtetra
.596 .904 .635 r
.43691 .36632 .44453 .36077 .45723 .34876 .44971 .35451 Mtetra
.128 0 0 r
.44971 .35451 .45723 .34876 .46977 .34533 .46233 .35152 Mtetra
.53 .031 .014 r
.46233 .35152 .46977 .34533 .48228 .34905 .47491 .35598 Mtetra
.659 .193 .135 r
.47491 .35598 .48228 .34905 .49487 .35788 .48756 .36555 Mtetra
.693 .242 .178 r
.48756 .36555 .49487 .35788 .50761 .36941 .50036 .37741 Mtetra
.679 .226 .171 r
.50036 .37741 .50761 .36941 .52054 .38111 .51336 .38854 Mtetra
.614 .139 .104 r
.51336 .38854 .52054 .38111 .53365 .39059 .52654 .39625 Mtetra
.428 0 0 r
.52654 .39625 .53365 .39059 .54691 .39592 .53987 .39851 Mtetra
0 0 0 r
.53987 .39851 .54691 .39592 .56026 .39601 .55326 .39441 Mtetra
.801 .97 .909 r
.55326 .39441 .56026 .39601 .57363 .39067 .56663 .38415 Mtetra
.868 .835 .811 r
.56663 .38415 .57363 .39067 .58696 .38052 .57994 .36894 Mtetra
.846 .737 .744 r
.57994 .36894 .58696 .38052 .60022 .36657 .59315 .35039 Mtetra
.818 .677 .709 r
.59315 .35039 .60022 .36657 .61339 .34983 .60627 .33013 Mtetra
.795 .641 .69 r
.60627 .33013 .61339 .34983 .62645 .33111 .61929 .30938 Mtetra
.779 .62 .683 r
.61929 .30938 .62645 .33111 .63941 .31109 .63226 .28897 Mtetra
.771 .613 .684 r
.63226 .28897 .63941 .31109 .65228 .29052 .64519 .26945 Mtetra
.768 .618 .693 r
.64519 .26945 .65228 .29052 .66509 .27034 .65811 .25132 Mtetra
.768 .632 .71 r
.65811 .25132 .66509 .27034 .6779 .25158 .67106 .23503 Mtetra
.766 .652 .736 r
.67106 .23503 .6779 .25158 .69077 .2351 .68409 .22092 Mtetra
.76 .677 .77 r
.68409 .22092 .69077 .2351 .70376 .22136 .69724 .20912 Mtetra
.747 .701 .808 r
.69724 .20912 .70376 .22136 .71691 .21031 .71051 .19945 Mtetra
.728 .72 .843 r
.71051 .19945 .71691 .21031 .73022 .20151 .72393 .19153 Mtetra
.706 .732 .871 r
.72393 .19153 .73022 .20151 .74368 .19437 .73747 .18489 Mtetra
.688 .738 .889 r
.73747 .18489 .74368 .19437 .75727 .1883 .75112 .17905 Mtetra
.676 .74 .899 r
.75112 .17905 .75727 .1883 .77096 .18283 .76487 .17369 Mtetra
.669 .741 .904 r
.76487 .17369 .77096 .18283 .78474 .17768 .77871 .16855 Mtetra
.666 .741 .906 r
.77871 .16855 .78474 .17768 .7986 .17265 .79262 .16351 Mtetra
.663 .741 .908 r
.16246 .3778 .17033 .38515 .18145 .38123 .17361 .37383 Mtetra
.662 .74 .908 r
.17361 .37383 .18145 .38123 .19262 .37733 .18481 .36986 Mtetra
.66 .738 .908 r
.18481 .36986 .19262 .37733 .20382 .37351 .19605 .36592 Mtetra
.657 .735 .907 r
.19605 .36592 .20382 .37351 .21506 .36984 .20733 .36207 Mtetra
.649 .729 .907 r
.20733 .36207 .21506 .36984 .22632 .36653 .21864 .35844 Mtetra
.632 .716 .907 r
.21864 .35844 .22632 .36653 .23757 .36392 .22996 .35526 Mtetra
.598 .69 .906 r
.22996 .35526 .23757 .36392 .24875 .36264 .24125 .35298 Mtetra
.535 .639 .9 r
.24125 .35298 .24875 .36264 .25982 .36361 .25247 .3523 Mtetra
.426 .548 .876 r
.25247 .3523 .25982 .36361 .2707 .36803 .26355 .35422 Mtetra
.268 .406 .817 r
.26355 .35422 .2707 .36803 .28133 .37721 .27443 .35991 Mtetra
.096 .237 .721 r
.27443 .35991 .28133 .37721 .29169 .39217 .28506 .37046 Mtetra
0 .096 .622 r
.28506 .37046 .29169 .39217 .30182 .41306 .29546 .38644 Mtetra
0 .021 .559 r
.29546 .38644 .30182 .41306 .31189 .43858 .30572 .40735 Mtetra
0 .017 .542 r
.30572 .40735 .31189 .43858 .32213 .46566 .31603 .43118 Mtetra
.054 .076 .565 r
.31603 .43118 .32213 .46566 .33283 .48966 .32665 .45437 Mtetra
.213 .187 .611 r
.32665 .45437 .33283 .48966 .34424 .5054 .33782 .47238 Mtetra
.404 .33 .66 r
.33782 .47238 .34424 .5054 .35649 .50878 .34971 .48096 Mtetra
.589 .477 .693 r
.34971 .48096 .35649 .50878 .36949 .49836 .36234 .47766 Mtetra
.74 .604 .706 r
.36234 .47766 .36949 .49836 .38303 .47601 .37556 .46285 Mtetra
.846 .704 .706 r
.37556 .46285 .38303 .47601 .39677 .44628 .3891 .43971 Mtetra
.914 .787 .706 r
.3891 .43971 .39677 .44628 .41043 .41488 .40269 .41317 Mtetra
.949 .865 .721 r
.40269 .41317 .41043 .41488 .42383 .38701 .4161 .38834 Mtetra
.936 .953 .764 r
.4161 .38834 .42383 .38701 .43691 .36632 .42924 .36926 Mtetra
.722 .984 .793 r
.42924 .36926 .43691 .36632 .44971 .35451 .44212 .35815 Mtetra
.01 0 0 r
.44212 .35815 .44971 .35451 .46233 .35152 .45482 .35537 Mtetra
.494 0 0 r
.45482 .35537 .46233 .35152 .47491 .35598 .46746 .35964 Mtetra
.644 .13 .007 r
.46746 .35964 .47491 .35598 .48756 .36555 .48017 .36857 Mtetra
.677 .164 .011 r
.48017 .36857 .48756 .36555 .50036 .37741 .49304 .3791 Mtetra
.626 .08 0 r
.49304 .3791 .50036 .37741 .51336 .38854 .50609 .38804 Mtetra
.36 0 0 r
.50609 .38804 .51336 .38854 .52654 .39625 .51933 .39267 Mtetra
.409 .794 .99 r
.51933 .39267 .52654 .39625 .53987 .39851 .53269 .39116 Mtetra
.756 .806 .893 r
.53269 .39116 .53987 .39851 .55326 .39441 .5461 .38295 Mtetra
.809 .731 .779 r
.5461 .38295 .55326 .39441 .56663 .38415 .55948 .36872 Mtetra
.812 .683 .722 r
.55948 .36872 .56663 .38415 .57994 .36894 .57277 .35005 Mtetra
.803 .65 .693 r
.57277 .35005 .57994 .36894 .59315 .35039 .58596 .32893 Mtetra
.789 .627 .68 r
.58596 .32893 .59315 .35039 .60627 .33013 .59906 .30719 Mtetra
.776 .612 .676 r
.59906 .30719 .60627 .33013 .61929 .30938 .61209 .28616 Mtetra
.765 .604 .679 r
.61209 .28616 .61929 .30938 .63226 .28897 .6251 .2666 Mtetra
.757 .604 .688 r
.6251 .2666 .63226 .28897 .64519 .26945 .63811 .24884 Mtetra
.753 .613 .703 r
.63811 .24884 .64519 .26945 .65811 .25132 .65114 .233 Mtetra
.75 .629 .725 r
.65114 .233 .65811 .25132 .67106 .23503 .66423 .21913 Mtetra
.747 .651 .754 r
.66423 .21913 .67106 .23503 .68409 .22092 .67741 .20722 Mtetra
.741 .677 .788 r
.67741 .20722 .68409 .22092 .69724 .20912 .69069 .19716 Mtetra
.729 .7 .823 r
.69069 .19716 .69724 .20912 .71051 .19945 .70408 .18873 Mtetra
.712 .719 .854 r
.70408 .18873 .71051 .19945 .72393 .19153 .71759 .18159 Mtetra
.695 .73 .878 r
.71759 .18159 .72393 .19153 .73747 .18489 .73121 .17538 Mtetra
.682 .737 .892 r
.73121 .17538 .73747 .18489 .75112 .17905 .74493 .16976 Mtetra
.673 .74 .901 r
.74493 .16976 .75112 .17905 .76487 .17369 .75874 .16447 Mtetra
.668 .741 .905 r
.75874 .16447 .76487 .17369 .77871 .16855 .77262 .15934 Mtetra
.665 .741 .907 r
.77262 .15934 .77871 .16855 .79262 .16351 .78658 .15428 Mtetra
.663 .741 .908 r
.15452 .37039 .16246 .3778 .17361 .37383 .1657 .36638 Mtetra
.663 .74 .908 r
.1657 .36638 .17361 .37383 .18481 .36986 .17693 .36236 Mtetra
.662 .74 .908 r
.17693 .36236 .18481 .36986 .19605 .36592 .18821 .35834 Mtetra
.66 .738 .907 r
.18821 .35834 .19605 .36592 .20733 .36207 .19953 .35437 Mtetra
.655 .734 .907 r
.19953 .35437 .20733 .36207 .21864 .35844 .21088 .35051 Mtetra
.645 .726 .908 r
.21088 .35051 .21864 .35844 .22996 .35526 .22226 .34693 Mtetra
.624 .71 .907 r
.22226 .34693 .22996 .35526 .24125 .35298 .23364 .34392 Mtetra
.583 .677 .904 r
.23364 .34392 .24125 .35298 .25247 .3523 .24498 .34199 Mtetra
.512 .615 .892 r
.24498 .34199 .25247 .3523 .26355 .35422 .25624 .34188 Mtetra
.4 .513 .857 r
.25624 .34188 .26355 .35422 .27443 .35991 .26734 .34456 Mtetra
.261 .375 .791 r
.26734 .34456 .27443 .35991 .28506 .37046 .27825 .35104 Mtetra
.135 .237 .706 r
.27825 .35104 .28506 .37046 .29546 .38644 .28895 .36209 Mtetra
.065 .141 .633 r
.28895 .36209 .29546 .38644 .30572 .40735 .29949 .37775 Mtetra
.065 .106 .594 r
.29949 .37775 .30572 .40735 .31603 .43118 .30999 .39695 Mtetra
.127 .128 .589 r
.30999 .39695 .31603 .43118 .32665 .45437 .32065 .41721 Mtetra
.235 .194 .607 r
.32065 .41721 .32665 .45437 .33782 .47238 .3317 .43499 Mtetra
.369 .29 .635 r
.3317 .43499 .33782 .47238 .34971 .48096 .34332 .44643 Mtetra
.51 .397 .661 r
.34332 .44643 .34971 .48096 .36234 .47766 .3556 .44868 Mtetra
.637 .502 .681 r
.3556 .44868 .36234 .47766 .37556 .46285 .36846 .44095 Mtetra
.742 .598 .696 r
.36846 .44095 .37556 .46285 .3891 .43971 .38171 .42501 Mtetra
.821 .684 .712 r
.38171 .42501 .3891 .43971 .40269 .41317 .39512 .40458 Mtetra
.875 .768 .741 r
.39512 .40458 .40269 .41317 .4161 .38834 .40846 .38417 Mtetra
.894 .861 .801 r
.40846 .38417 .4161 .38834 .42924 .36926 .4216 .36769 Mtetra
.811 .957 .91 r
.4216 .36769 .42924 .36926 .44212 .35815 .43453 .35765 Mtetra
.352 .823 .895 r
.43453 .35765 .44212 .35815 .45482 .35537 .4473 .35469 Mtetra
.25 0 0 r
.4473 .35469 .45482 .35537 .46746 .35964 .46001 .35781 Mtetra
.459 0 0 r
.46001 .35781 .46746 .35964 .48017 .36857 .47279 .36469 Mtetra
.394 0 0 r
.47279 .36469 .48017 .36857 .49304 .3791 .48571 .37239 Mtetra
0 .436 .861 r
.48571 .37239 .49304 .3791 .50609 .38804 .49881 .37786 Mtetra
.46 .615 .916 r
.49881 .37786 .50609 .38804 .51933 .39267 .51207 .37866 Mtetra
.657 .635 .817 r
.51207 .37866 .51933 .39267 .53269 .39116 .52545 .37338 Mtetra
.728 .624 .743 r
.52545 .37338 .53269 .39116 .5461 .38295 .53885 .36187 Mtetra
.756 .613 .701 r
.53885 .36187 .5461 .38295 .55948 .36872 .55222 .34515 Mtetra
.766 .604 .678 r
.55222 .34515 .55948 .36872 .57277 .35005 .5655 .32501 Mtetra
.767 .598 .669 r
.5655 .32501 .57277 .35005 .58596 .32893 .57869 .30344 Mtetra
.763 .593 .667 r
.57869 .30344 .58596 .32893 .59906 .30719 .59181 .2822 Mtetra
.756 .591 .672 r
.59181 .2822 .59906 .30719 .61209 .28616 .60489 .26245 Mtetra
.748 .593 .683 r
.60489 .26245 .61209 .28616 .6251 .2666 .61796 .24477 Mtetra
.742 .6 .699 r
.61796 .24477 .6251 .2666 .63811 .24884 .63106 .22927 Mtetra
.738 .613 .719 r
.63106 .22927 .63811 .24884 .65114 .233 .64421 .21581 Mtetra
.734 .632 .745 r
.64421 .21581 .65114 .233 .66423 .21913 .65742 .20419 Mtetra
.73 .656 .776 r
.65742 .20419 .66423 .21913 .67741 .20722 .67072 .1942 Mtetra
.723 .681 .809 r
.67072 .1942 .67741 .20722 .69069 .19716 .68412 .18563 Mtetra
.712 .703 .84 r
.68412 .18563 .69069 .19716 .70408 .18873 .69761 .17823 Mtetra
.699 .72 .866 r
.69761 .17823 .70408 .18873 .71759 .18159 .71121 .17173 Mtetra
.686 .731 .884 r
.71121 .17173 .71759 .18159 .73121 .17538 .7249 .16587 Mtetra
.676 .737 .896 r
.7249 .16587 .73121 .17538 .74493 .16976 .73868 .16042 Mtetra
.67 .739 .902 r
.73868 .16042 .74493 .16976 .75874 .16447 .75254 .15518 Mtetra
.666 .741 .905 r
.75254 .15518 .75874 .16447 .77262 .15934 .76648 .15006 Mtetra
.665 .741 .907 r
.76648 .15006 .77262 .15934 .78658 .15428 .78049 .14497 Mtetra
.663 .741 .908 r
.14652 .36294 .15452 .37039 .1657 .36638 .15773 .35889 Mtetra
.15773 .35889 .1657 .36638 .17693 .36236 .16899 .35482 Mtetra
.663 .74 .908 r
.16899 .35482 .17693 .36236 .18821 .35834 .1803 .35075 Mtetra
.662 .739 .908 r
.1803 .35075 .18821 .35834 .19953 .35437 .19165 .34669 Mtetra
.659 .737 .908 r
.19165 .34669 .19953 .35437 .21088 .35051 .20304 .34268 Mtetra
.653 .733 .908 r
.20304 .34268 .21088 .35051 .22226 .34693 .21447 .33883 Mtetra
.641 .723 .907 r
.21447 .33883 .22226 .34693 .23364 .34392 .22592 .33532 Mtetra
.616 .702 .906 r
.22592 .33532 .23364 .34392 .24498 .34199 .23737 .33249 Mtetra
.571 .663 .9 r
.23737 .33249 .24498 .34199 .25624 .34188 .24876 .33086 Mtetra
.497 .594 .881 r
.24876 .33086 .25624 .34188 .26734 .34456 .26007 .33115 Mtetra
.395 .491 .839 r
.26007 .33115 .26734 .34456 .27825 .35104 .27123 .33422 Mtetra
.284 .369 .774 r
.27123 .33422 .27825 .35104 .28895 .36209 .28222 .34085 Mtetra
.201 .262 .703 r
.28222 .34085 .28895 .36209 .29949 .37775 .29306 .3514 Mtetra
.172 .2 .649 r
.29306 .3514 .29949 .37775 .30999 .39695 .30382 .36546 Mtetra
.197 .189 .622 r
.30382 .36546 .30999 .39695 .32065 .41721 .31464 .38155 Mtetra
.264 .219 .619 r
.31464 .38155 .32065 .41721 .3317 .43499 .3257 .39714 Mtetra
.358 .279 .629 r
.3257 .39714 .3317 .43499 .34332 .44643 .33717 .40914 Mtetra
.462 .355 .646 r
.33717 .40914 .34332 .44643 .3556 .44868 .34916 .41479 Mtetra
.564 .436 .664 r
.34916 .41479 .3556 .44868 .36846 .44095 .36168 .41266 Mtetra
.655 .516 .682 r
.36168 .41266 .36846 .44095 .38171 .42501 .37462 .40331 Mtetra
.729 .592 .702 r
.37462 .40331 .38171 .42501 .39512 .40458 .38778 .38917 Mtetra
.782 .664 .733 r
.38778 .38917 .39512 .40458 .40846 .38417 .40097 .3737 Mtetra
.805 .735 .786 r
.40097 .3737 .40846 .38417 .4216 .36769 .41406 .36035 Mtetra
.771 .797 .874 r
.41406 .36035 .4216 .36769 .43453 .35765 .42701 .3515 Mtetra
.612 .794 .969 r
.42701 .3515 .43453 .35765 .4473 .35469 .43983 .34802 Mtetra
.345 .658 .971 r
.43983 .34802 .4473 .35469 .46001 .35781 .45262 .34918 Mtetra
.23 .529 .919 r
.45262 .34918 .46001 .35781 .47279 .36469 .46546 .35302 Mtetra
.328 .505 .88 r
.46546 .35302 .47279 .36469 .48571 .37239 .47843 .35695 Mtetra
.484 .523 .822 r
.47843 .35695 .48571 .37239 .49881 .37786 .49156 .3584 Mtetra
.595 .538 .761 r
.49156 .3584 .49881 .37786 .51207 .37866 .50483 .35541 Mtetra
.662 .548 .715 r
.50483 .35541 .51207 .37866 .52545 .37338 .51819 .34706 Mtetra
.7 .554 .685 r
.51819 .34706 .52545 .37338 .53885 .36187 .53158 .33357 Mtetra
.723 .559 .668 r
.53158 .33357 .53885 .36187 .55222 .34515 .54492 .3161 Mtetra
.735 .563 .66 r
.54492 .3161 .55222 .34515 .5655 .32501 .5582 .29637 Mtetra
.74 .567 .66 r
.5582 .29637 .5655 .32501 .57869 .30344 .57141 .27616 Mtetra
.74 .572 .666 r
.57141 .27616 .57869 .30344 .59181 .2822 .58456 .25691 Mtetra
.737 .579 .677 r
.58456 .25691 .59181 .2822 .60489 .26245 .5977 .23951 Mtetra
.733 .588 .694 r
.5977 .23951 .60489 .26245 .61796 .24477 .61085 .22432 Mtetra
.728 .602 .716 r
.61085 .22432 .61796 .24477 .63106 .22927 .62405 .21125 Mtetra
.724 .62 .741 r
.62405 .21125 .63106 .22927 .64421 .21581 .6373 .20005 Mtetra
.719 .641 .77 r
.6373 .20005 .64421 .21581 .65742 .20419 .65063 .19039 Mtetra
.714 .666 .801 r
.65063 .19039 .65742 .20419 .67072 .1942 .66404 .18198 Mtetra
.707 .689 .83 r
.66404 .18198 .67072 .1942 .68412 .18563 .67753 .17458 Mtetra
.698 .709 .856 r
.67753 .17458 .68412 .18563 .69761 .17823 .69112 .16797 Mtetra
.688 .723 .877 r
.69112 .16797 .69761 .17823 .71121 .17173 .70479 .16197 Mtetra
.679 .732 .891 r
.70479 .16197 .71121 .17173 .7249 .16587 .71854 .15637 Mtetra
.672 .737 .899 r
.71854 .15637 .7249 .16587 .73868 .16042 .73238 .15103 Mtetra
.668 .74 .904 r
.73238 .15103 .73868 .16042 .75254 .15518 .74629 .14584 Mtetra
.665 .741 .906 r
.74629 .14584 .75254 .15518 .76648 .15006 .76028 .1407 Mtetra
.664 .741 .907 r
.76028 .1407 .76648 .15006 .78049 .14497 .77434 .13558 Mtetra
.663 .741 .908 r
.13846 .35543 .14652 .36294 .15773 .35889 .1497 .35134 Mtetra
.1497 .35134 .15773 .35889 .16899 .35482 .16098 .34723 Mtetra
.16098 .34723 .16899 .35482 .1803 .35075 .17232 .34311 Mtetra
.663 .74 .908 r
.17232 .34311 .1803 .35075 .19165 .34669 .1837 .33899 Mtetra
.661 .739 .908 r
.1837 .33899 .19165 .34669 .20304 .34268 .19513 .33489 Mtetra
.658 .737 .908 r
.19513 .33489 .20304 .34268 .21447 .33883 .20661 .33087 Mtetra
.651 .731 .908 r
.20661 .33087 .21447 .33883 .22592 .33532 .21811 .32703 Mtetra
.637 .719 .907 r
.21811 .32703 .22592 .33532 .23737 .33249 .22963 .32358 Mtetra
.61 .694 .904 r
.22963 .32358 .23737 .33249 .24876 .33086 .24114 .32088 Mtetra
.563 .65 .894 r
.24114 .32088 .24876 .33086 .26007 .33115 .2526 .31942 Mtetra
.494 .579 .87 r
.2526 .31942 .26007 .33115 .27123 .33422 .26398 .31987 Mtetra
.407 .483 .826 r
.26398 .31987 .27123 .33422 .28222 .34085 .27524 .32289 Mtetra
.326 .381 .766 r
.27524 .32289 .28222 .34085 .29306 .3514 .28637 .32898 Mtetra
.276 .302 .707 r
.28637 .32898 .29306 .3514 .30382 .36546 .29741 .33815 Mtetra
.269 .261 .666 r
.29741 .33815 .30382 .36546 .31464 .38155 .30844 .34965 Mtetra
.302 .261 .644 r
.30844 .34965 .31464 .38155 .3257 .39714 .31961 .36189 Mtetra
.363 .29 .64 r
.31961 .36189 .3257 .39714 .33717 .40914 .33104 .37262 Mtetra
.438 .339 .645 r
.33104 .37262 .33717 .40914 .34916 .41479 .34286 .37954 Mtetra
.517 .398 .657 r
.34286 .37954 .34916 .41479 .36168 .41266 .35512 .38101 Mtetra
.591 .461 .672 r
.35512 .38101 .36168 .41266 .37462 .40331 .36776 .37677 Mtetra
.654 .523 .691 r
.36776 .37677 .37462 .40331 .38778 .38917 .38066 .36807 Mtetra
.701 .58 .717 r
.38066 .36807 .38778 .38917 .40097 .3737 .39367 .35727 Mtetra
.722 .63 .754 r
.39367 .35727 .40097 .3737 .41406 .36035 .40668 .34699 Mtetra
.706 .661 .803 r
.40668 .34699 .41406 .36035 .42701 .3515 .41961 .33928 Mtetra
.642 .653 .846 r
.41961 .33928 .42701 .3515 .43983 .34802 .43247 .33505 Mtetra
.555 .6 .853 r
.43247 .33505 .43983 .34802 .45262 .34918 .44532 .33389 Mtetra
.512 .54 .821 r
.44532 .33389 .45262 .34918 .46546 .35302 .45823 .33433 Mtetra
.531 .508 .775 r
.45823 .33433 .46546 .35302 .47843 .35695 .47124 .33436 Mtetra
.578 .502 .733 r
.47124 .33436 .47843 .35695 .49156 .3584 .48439 .33204 Mtetra
.623 .506 .7 r
.48439 .33204 .49156 .3584 .50483 .35541 .49765 .32599 Mtetra
.658 .515 .677 r
.49765 .32599 .50483 .35541 .51819 .34706 .51098 .31574 Mtetra
.684 .524 .663 r
.51098 .31574 .51819 .34706 .53158 .33357 .52433 .3017 Mtetra
.702 .533 .657 r
.52433 .3017 .53158 .33357 .54492 .3161 .53765 .28502 Mtetra
.713 .543 .657 r
.53765 .28502 .54492 .3161 .5582 .29637 .55093 .26713 Mtetra
.72 .553 .663 r
.55093 .26713 .5582 .29637 .57141 .27616 .56415 .24945 Mtetra
.723 .564 .674 r
.56415 .24945 .57141 .27616 .58456 .25691 .57736 .23302 Mtetra
.722 .577 .692 r
.57736 .23302 .58456 .25691 .5977 .23951 .59056 .21844 Mtetra
.719 .593 .714 r
.59056 .21844 .5977 .23951 .61085 .22432 .60379 .20585 Mtetra
.715 .612 .74 r
.60379 .20585 .61085 .22432 .62405 .21125 .61708 .19508 Mtetra
.711 .633 .769 r
.61708 .19508 .62405 .21125 .6373 .20005 .63042 .18582 Mtetra
.706 .656 .798 r
.63042 .18582 .6373 .20005 .65063 .19039 .64385 .17772 Mtetra
.7 .679 .826 r
.64385 .17772 .65063 .19039 .66404 .18198 .65735 .17052 Mtetra
.694 .7 .851 r
.65735 .17052 .66404 .18198 .67753 .17458 .67092 .16398 Mtetra
.686 .716 .871 r
.67092 .16398 .67753 .17458 .69112 .16797 .68458 .15795 Mtetra
.679 .727 .886 r
.68458 .15795 .69112 .16797 .70479 .16197 .69832 .15229 Mtetra
.673 .734 .896 r
.69832 .15229 .70479 .16197 .71854 .15637 .71213 .14687 Mtetra
.669 .738 .902 r
.71213 .14687 .71854 .15637 .73238 .15103 .72603 .14161 Mtetra
.666 .74 .905 r
.72603 .14161 .73238 .15103 .74629 .14584 .73999 .13642 Mtetra
.665 .741 .907 r
.73999 .13642 .74629 .14584 .76028 .1407 .75403 .13126 Mtetra
.664 .741 .907 r
.75403 .13126 .76028 .1407 .77434 .13558 .76814 .1261 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35543 .1497 .35134 .1416 .34373 Mtetra
.663 .741 .908 r
.1416 .34373 .1497 .35134 .16098 .34723 .15291 .33959 Mtetra
.15291 .33959 .16098 .34723 .17232 .34311 .16428 .33543 Mtetra
.16428 .33543 .17232 .34311 .1837 .33899 .17569 .33126 Mtetra
.662 .74 .908 r
.17569 .33126 .1837 .33899 .19513 .33489 .18715 .32709 Mtetra
.661 .739 .908 r
.18715 .32709 .19513 .33489 .20661 .33087 .19866 .32295 Mtetra
.657 .736 .908 r
.19866 .32295 .20661 .33087 .21811 .32703 .21021 .31891 Mtetra
.649 .729 .907 r
.21021 .31891 .21811 .32703 .22963 .32358 .22179 .31507 Mtetra
.634 .715 .905 r
.22179 .31507 .22963 .32358 .24114 .32088 .23339 .31166 Mtetra
.606 .688 .9 r
.23339 .31166 .24114 .32088 .2526 .31942 .24497 .30901 Mtetra
.562 .642 .887 r
.24497 .30901 .2526 .31942 .26398 .31987 .25652 .30757 Mtetra
.501 .574 .86 r
.25652 .30757 .26398 .31987 .27524 .32289 .26799 .30788 Mtetra
.433 .489 .817 r
.26799 .30788 .27524 .32289 .28637 .32898 .27938 .31042 Mtetra
.376 .406 .765 r
.27938 .31042 .28637 .32898 .29741 .33815 .29069 .3154 Mtetra
.346 .346 .716 r
.29069 .3154 .29741 .33815 .30844 .34965 .30196 .32258 Mtetra
.35 .318 .682 r
.30196 .32258 .30844 .34965 .31961 .36189 .31329 .33108 Mtetra
.382 .321 .664 r
.31329 .33108 .31961 .36189 .33104 .37262 .32478 .33942 Mtetra
.432 .346 .658 r
.32478 .33942 .33104 .37262 .34286 .37954 .33654 .34588 Mtetra
.49 .385 .662 r
.33654 .34588 .34286 .37954 .35512 .38101 .34862 .34896 Mtetra
.548 .43 .671 r
.34862 .34896 .35512 .38101 .36776 .37677 .36104 .34797 Mtetra
.601 .478 .685 r
.36104 .34797 .36776 .37677 .38066 .36807 .37371 .34328 Mtetra
.641 .523 .704 r
.37371 .34328 .38066 .36807 .39367 .35727 .38655 .3362 Mtetra
.663 .56 .728 r
.38655 .3362 .39367 .35727 .40668 .34699 .39945 .3285 Mtetra
.662 .581 .753 r
.39945 .3285 .40668 .34699 .41961 .33928 .41235 .32175 Mtetra
.637 .577 .771 r
.41235 .32175 .41961 .33928 .43247 .33505 .42524 .31676 Mtetra
.604 .552 .77 r
.42524 .31676 .43247 .33505 .44532 .33389 .43814 .3134 Mtetra
.586 .522 .75 r
.43814 .3134 .44532 .33389 .45823 .33433 .45109 .31076 Mtetra
.591 .502 .722 r
.45109 .31076 .45823 .33433 .47124 .33436 .46414 .30746 Mtetra
.61 .495 .697 r
.46414 .30746 .47124 .33436 .48439 .33204 .47729 .30224 Mtetra
.634 .497 .678 r
.47729 .30224 .48439 .33204 .49765 .32599 .49053 .29424 Mtetra
.656 .504 .666 r
.49053 .29424 .49765 .32599 .51098 .31574 .50382 .28332 Mtetra
.675 .514 .66 r
.50382 .28332 .51098 .31574 .52433 .3017 .51713 .26995 Mtetra
.689 .525 .659 r
.51713 .26995 .52433 .3017 .53765 .28502 .53042 .25508 Mtetra
.699 .537 .665 r
.53042 .25508 .53765 .28502 .55093 .26713 .5437 .2398 Mtetra
.706 .551 .676 r
.5437 .2398 .55093 .26713 .56415 .24945 .55695 .2251 Mtetra
.709 .568 .693 r
.55695 .2251 .56415 .24945 .57736 .23302 .57019 .21167 Mtetra
.71 .586 .715 r
.57019 .21167 .57736 .23302 .59056 .21844 .58346 .19983 Mtetra
.708 .607 .742 r
.58346 .19983 .59056 .21844 .60379 .20585 .59676 .1896 Mtetra
.704 .629 .771 r
.59676 .1896 .60379 .20585 .61708 .19508 .61013 .18075 Mtetra
.699 .652 .8 r
.61013 .18075 .61708 .19508 .63042 .18582 .62356 .17301 Mtetra
.694 .675 .827 r
.62356 .17301 .63042 .18582 .64385 .17772 .63706 .16607 Mtetra
.689 .694 .85 r
.63706 .16607 .64385 .17772 .65735 .17052 .65063 .15971 Mtetra
.683 .711 .869 r
.65063 .15971 .65735 .17052 .67092 .16398 .66428 .15377 Mtetra
.678 .723 .883 r
.66428 .15377 .67092 .16398 .68458 .15795 .67801 .14811 Mtetra
.673 .731 .893 r
.67801 .14811 .68458 .15795 .69832 .15229 .6918 .14267 Mtetra
.669 .736 .9 r
.6918 .14267 .69832 .15229 .71213 .14687 .70567 .13736 Mtetra
.667 .739 .904 r
.70567 .13736 .71213 .14687 .72603 .14161 .71962 .13213 Mtetra
.665 .74 .906 r
.71962 .13213 .72603 .14161 .73999 .13642 .73363 .12693 Mtetra
.664 .741 .907 r
.73363 .12693 .73999 .13642 .75403 .13126 .74772 .12174 Mtetra
.664 .741 .908 r
.74772 .12174 .75403 .13126 .76814 .1261 .76188 .11655 Mtetra
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33959 .14477 .33188 Mtetra
.663 .741 .908 r
.14477 .33188 .15291 .33959 .16428 .33543 .15616 .32769 Mtetra
.15616 .32769 .16428 .33543 .17569 .33126 .16761 .32348 Mtetra
.16761 .32348 .17569 .33126 .18715 .32709 .1791 .31926 Mtetra
.662 .74 .908 r
.1791 .31926 .18715 .32709 .19866 .32295 .19065 .31504 Mtetra
.66 .739 .908 r
.19065 .31504 .19866 .32295 .21021 .31891 .20224 .31087 Mtetra
.656 .735 .907 r
.20224 .31087 .21021 .31891 .22179 .31507 .21387 .30679 Mtetra
.648 .727 .907 r
.21387 .30679 .22179 .31507 .23339 .31166 .22553 .30294 Mtetra
.632 .711 .904 r
.22553 .30294 .23339 .31166 .24497 .30901 .2372 .29952 Mtetra
.606 .684 .897 r
.2372 .29952 .24497 .30901 .25652 .30757 .24887 .29683 Mtetra
.567 .639 .882 r
.24887 .29683 .25652 .30757 .26799 .30788 .26051 .29524 Mtetra
.517 .576 .854 r
.26051 .29524 .26799 .30788 .27938 .31042 .2721 .29516 Mtetra
.465 .504 .815 r
.2721 .29516 .27938 .31042 .29069 .3154 .28364 .29687 Mtetra
.425 .438 .77 r
.28364 .29687 .29069 .3154 .30196 .32258 .29515 .3004 Mtetra
.408 .392 .729 r
.29515 .3004 .30196 .32258 .31329 .33108 .30667 .30534 Mtetra
.416 .371 .7 r
.30667 .30534 .31329 .33108 .32478 .33942 .31828 .31085 Mtetra
.443 .373 .684 r
.31828 .31085 .32478 .33942 .33654 .34588 .33006 .31576 Mtetra
.482 .393 .678 r
.33006 .31576 .33654 .34588 .34862 .34896 .34207 .31887 Mtetra
.526 .423 .68 r
.34207 .31887 .34862 .34896 .36104 .34797 .35434 .31935 Mtetra
.568 .457 .688 r
.35434 .31935 .36104 .34797 .37371 .34328 .36685 .31704 Mtetra
.604 .492 .7 r
.36685 .31704 .37371 .34328 .38655 .3362 .37954 .31248 Mtetra
.628 .521 .714 r
.37954 .31248 .38655 .3362 .39945 .3285 .39235 .30666 Mtetra
.637 .54 .728 r
.39235 .30666 .39945 .3285 .41235 .32175 .40521 .30062 Mtetra
.633 .543 .735 r
.40521 .30062 .41235 .32175 .42524 .31676 .4181 .29504 Mtetra
.622 .533 .732 r
.4181 .29504 .42524 .31676 .43814 .3134 .43104 .29 Mtetra
.616 .517 .72 r
.43104 .29 .43814 .3134 .45109 .31076 .44402 .28504 Mtetra
.618 .505 .703 r
.44402 .28504 .45109 .31076 .46414 .30746 .45708 .27942 Mtetra
.628 .5 .688 r
.45708 .27942 .46414 .30746 .47729 .30224 .47022 .27241 Mtetra
.642 .502 .676 r
.47022 .27241 .47729 .30224 .49053 .29424 .48343 .26359 Mtetra
.657 .508 .67 r
.48343 .26359 .49053 .29424 .50382 .28332 .49668 .25299 Mtetra
.67 .517 .669 r
.49668 .25299 .50382 .28332 .51713 .26995 .50995 .24104 Mtetra
.681 .53 .674 r
.50995 .24104 .51713 .26995 .53042 .25508 .52323 .22843 Mtetra
.69 .545 .684 r
.52323 .22843 .53042 .25508 .5437 .2398 .5365 .2159 Mtetra
.696 .562 .7 r
.5365 .2159 .5437 .2398 .55695 .2251 .54977 .20406 Mtetra
.7 .583 .721 r
.54977 .20406 .55695 .2251 .57019 .21167 .56306 .19331 Mtetra
.7 .605 .747 r
.56306 .19331 .57019 .21167 .58346 .19983 .57638 .18378 Mtetra
.698 .629 .776 r
.57638 .18378 .58346 .19983 .59676 .1896 .58976 .17542 Mtetra
.694 .653 .805 r
.58976 .17542 .59676 .1896 .61013 .18075 .60319 .16803 Mtetra
.689 .675 .831 r
.60319 .16803 .61013 .18075 .62356 .17301 .61669 .16137 Mtetra
.684 .693 .853 r
.61669 .16137 .62356 .17301 .63706 .16607 .63025 .15521 Mtetra
.679 .709 .87 r
.63025 .15521 .63706 .16607 .65063 .15971 .64389 .1494 Mtetra
.675 .721 .883 r
.64389 .1494 .65063 .15971 .66428 .15377 .6576 .14382 Mtetra
.672 .729 .893 r
.6576 .14382 .66428 .15377 .67801 .14811 .67138 .1384 Mtetra
.669 .734 .899 r
.67138 .1384 .67801 .14811 .6918 .14267 .68523 .13307 Mtetra
.667 .738 .903 r
.68523 .13307 .6918 .14267 .70567 .13736 .69916 .12781 Mtetra
.665 .74 .905 r
.69916 .12781 .70567 .13736 .71962 .13213 .71315 .12258 Mtetra
.665 .741 .907 r
.71315 .12258 .71962 .13213 .73363 .12693 .72722 .11737 Mtetra
.664 .741 .907 r
.72722 .11737 .73363 .12693 .74772 .12174 .74135 .11214 Mtetra
.664 .741 .908 r
.74135 .11214 .74772 .12174 .76188 .11655 .75556 .1069 Mtetra
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.663 .741 .908 r
.14799 .31989 .15616 .32769 .16761 .32348 .15946 .31564 Mtetra
.15946 .31564 .16761 .32348 .1791 .31926 .17098 .31138 Mtetra
.17098 .31138 .1791 .31926 .19065 .31504 .18256 .30711 Mtetra
.662 .74 .908 r
.18256 .30711 .19065 .31504 .20224 .31087 .19418 .30284 Mtetra
.66 .738 .908 r
.19418 .30284 .20224 .31087 .21387 .30679 .20586 .29862 Mtetra
.656 .734 .907 r
.20586 .29862 .21387 .30679 .22553 .30294 .21757 .29451 Mtetra
.647 .725 .906 r
.21757 .29451 .22553 .30294 .2372 .29952 .22931 .29062 Mtetra
.632 .709 .902 r
.22931 .29062 .2372 .29952 .24887 .29683 .24107 .28713 Mtetra
.609 .682 .894 r
.24107 .28713 .24887 .29683 .26051 .29524 .25284 .28431 Mtetra
.576 .641 .878 r
.25284 .28431 .26051 .29524 .2721 .29516 .26459 .28243 Mtetra
.536 .587 .852 r
.26459 .28243 .2721 .29516 .28364 .29687 .27631 .28177 Mtetra
.498 .527 .817 r
.27631 .28177 .28364 .29687 .29515 .3004 .28801 .28247 Mtetra
.47 .474 .779 r
.28801 .28247 .29515 .3004 .30667 .30534 .29972 .28441 Mtetra
.46 .437 .745 r
.29972 .28441 .30667 .30534 .31828 .31085 .31147 .28717 Mtetra
.468 .42 .721 r
.31147 .28717 .31828 .31085 .33006 .31576 .32333 .29004 Mtetra
.49 .421 .706 r
.32333 .29004 .33006 .31576 .34207 .31887 .33535 .29215 Mtetra
.521 .435 .7 r
.33535 .29215 .34207 .31887 .35434 .31935 .34757 .29274 Mtetra
.554 .458 .7 r
.34757 .29274 .35434 .31935 .36685 .31704 .35998 .29142 Mtetra
.584 .483 .705 r
.35998 .29142 .36685 .31704 .37954 .31248 .37257 .2882 Mtetra
.609 .507 .712 r
.37257 .2882 .37954 .31248 .39235 .30666 .3853 .28354 Mtetra
.625 .524 .719 r
.3853 .28354 .39235 .30666 .40521 .30062 .39812 .27801 Mtetra
.631 .531 .722 r
.39812 .27801 .40521 .30062 .4181 .29504 .41101 .27211 Mtetra
.632 .53 .72 r
.41101 .27211 .4181 .29504 .43104 .29 .42396 .26605 Mtetra
.632 .524 .713 r
.42396 .26605 .43104 .29 .44402 .28504 .43696 .25973 Mtetra
.635 .518 .703 r
.43696 .25973 .44402 .28504 .45708 .27942 .45002 .25284 Mtetra
.641 .515 .694 r
.45002 .25284 .45708 .27942 .47022 .27241 .46314 .24508 Mtetra
.649 .517 .688 r
.46314 .24508 .47022 .27241 .48343 .26359 .47632 .23632 Mtetra
.659 .523 .687 r
.47632 .23632 .48343 .26359 .49668 .25299 .48954 .22664 Mtetra
.669 .533 .69 r
.48954 .22664 .49668 .25299 .50995 .24104 .50278 .21638 Mtetra
.678 .547 .699 r
.50278 .21638 .50995 .24104 .52323 .22843 .51604 .20597 Mtetra
.685 .565 .714 r
.51604 .20597 .52323 .22843 .5365 .2159 .52931 .19586 Mtetra
.69 .585 .734 r
.52931 .19586 .5365 .2159 .54977 .20406 .54261 .1864 Mtetra
.692 .609 .758 r
.54261 .1864 .54977 .20406 .56306 .19331 .55594 .17776 Mtetra
.692 .633 .786 r
.55594 .17776 .56306 .19331 .57638 .18378 .56931 .16997 Mtetra
.689 .657 .813 r
.56931 .16997 .57638 .18378 .58976 .17542 .58274 .16296 Mtetra
.685 .678 .838 r
.58274 .16296 .58976 .17542 .60319 .16803 .59623 .15656 Mtetra
.68 .696 .858 r
.59623 .15656 .60319 .16803 .61669 .16137 .60979 .15059 Mtetra
.676 .71 .874 r
.60979 .15059 .61669 .16137 .63025 .15521 .62342 .14492 Mtetra
.672 .721 .885 r
.62342 .14492 .63025 .15521 .64389 .1494 .63711 .13942 Mtetra
.67 .728 .893 r
.63711 .13942 .64389 .1494 .6576 .14382 .65087 .13404 Mtetra
.668 .734 .899 r
.65087 .13404 .6576 .14382 .67138 .1384 .66471 .12873 Mtetra
.667 .737 .903 r
.66471 .12873 .67138 .1384 .68523 .13307 .67861 .12346 Mtetra
.665 .739 .905 r
.67861 .12346 .68523 .13307 .69916 .12781 .69258 .11821 Mtetra
.665 .74 .906 r
.69258 .11821 .69916 .12781 .71315 .12258 .70663 .11297 Mtetra
.664 .741 .907 r
.70663 .11297 .71315 .12258 .72722 .11737 .72074 .10772 Mtetra
.664 .741 .908 r
.72074 .10772 .72722 .11737 .74135 .11214 .73493 .10246 Mtetra
.73493 .10246 .74135 .11214 .75556 .1069 .74919 .09717 Mtetra
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30774 Mtetra
.663 .741 .908 r
.15124 .30774 .15946 .31564 .17098 .31138 .1628 .30344 Mtetra
.1628 .30344 .17098 .31138 .18256 .30711 .1744 .29912 Mtetra
.1744 .29912 .18256 .30711 .19418 .30284 .18606 .2948 Mtetra
.662 .74 .908 r
.18606 .2948 .19418 .30284 .20586 .29862 .19777 .29048 Mtetra
.66 .738 .907 r
.19777 .29048 .20586 .29862 .21757 .29451 .20952 .28621 Mtetra
.655 .733 .907 r
.20952 .28621 .21757 .29451 .22931 .29062 .22132 .28204 Mtetra
.648 .725 .905 r
.22132 .28204 .22931 .29062 .24107 .28713 .23315 .27809 Mtetra
.634 .709 .901 r
.23315 .27809 .24107 .28713 .25284 .28431 .245 .2745 Mtetra
.614 .684 .892 r
.245 .2745 .25284 .28431 .26459 .28243 .25687 .27146 Mtetra
.588 .648 .877 r
.25687 .27146 .26459 .28243 .27631 .28177 .26873 .2692 Mtetra
.557 .602 .854 r
.26873 .2692 .27631 .28177 .28801 .28247 .2806 .26787 Mtetra
.53 .554 .824 r
.2806 .26787 .28801 .28247 .29972 .28441 .29247 .26749 Mtetra
.511 .511 .793 r
.29247 .26749 .29972 .28441 .31147 .28717 .30437 .2679 Mtetra
.506 .482 .764 r
.30437 .2679 .31147 .28717 .32333 .29004 .31633 .26871 Mtetra
.513 .467 .743 r
.31633 .26871 .32333 .29004 .33535 .29215 .32841 .26935 Mtetra
.531 .467 .729 r
.32841 .26935 .33535 .29215 .34757 .29274 .34063 .26924 Mtetra
.555 .477 .723 r
.34063 .26924 .34757 .29274 .35998 .29142 .35301 .2679 Mtetra
.58 .493 .721 r
.35301 .2679 .35998 .29142 .37257 .2882 .36555 .26513 Mtetra
.603 .511 .722 r
.36555 .26513 .37257 .2882 .3853 .28354 .37823 .26102 Mtetra
.621 .525 .725 r
.37823 .26102 .3853 .28354 .39812 .27801 .39102 .25582 Mtetra
.633 .535 .726 r
.39102 .25582 .39812 .27801 .41101 .27211 .40389 .24988 Mtetra
.64 .539 .724 r
.40389 .24988 .41101 .27211 .42396 .26605 .41684 .24343 Mtetra
.644 .539 .721 r
.41684 .24343 .42396 .26605 .43696 .25973 .42984 .23658 Mtetra
.647 .538 .716 r
.42984 .23658 .43696 .25973 .45002 .25284 .4429 .2293 Mtetra
.652 .538 .712 r
.4429 .2293 .45002 .25284 .46314 .24508 .456 .22156 Mtetra
.657 .542 .712 r
.456 .22156 .46314 .24508 .47632 .23632 .46916 .21336 Mtetra
.664 .549 .715 r
.46916 .21336 .47632 .23632 .48954 .22664 .48235 .20481 Mtetra
.671 .561 .723 r
.48235 .20481 .48954 .22664 .50278 .21638 .49557 .19614 Mtetra
.677 .577 .735 r
.49557 .19614 .50278 .21638 .51604 .20597 .50883 .18757 Mtetra
.682 .596 .753 r
.50883 .18757 .51604 .20597 .52931 .19586 .52211 .17935 Mtetra
.685 .618 .775 r
.52211 .17935 .52931 .19586 .54261 .1864 .53544 .17164 Mtetra
.686 .641 .8 r
.53544 .17164 .54261 .1864 .55594 .17776 .54881 .16449 Mtetra
.684 .664 .824 r
.54881 .16449 .55594 .17776 .56931 .16997 .56223 .15788 Mtetra
.681 .684 .846 r
.56223 .15788 .56931 .16997 .58274 .16296 .5757 .15173 Mtetra
.677 .701 .865 r
.5757 .15173 .58274 .16296 .59623 .15656 .58925 .14593 Mtetra
.673 .713 .879 r
.58925 .14593 .59623 .15656 .60979 .15059 .60286 .14037 Mtetra
.67 .723 .888 r
.60286 .14037 .60979 .15059 .62342 .14492 .61653 .13496 Mtetra
.668 .729 .895 r
.61653 .13496 .62342 .14492 .63711 .13942 .63028 .12963 Mtetra
.667 .734 .9 r
.63028 .12963 .63711 .13942 .65087 .13404 .64409 .12434 Mtetra
.666 .737 .903 r
.64409 .12434 .65087 .13404 .66471 .12873 .65798 .11908 Mtetra
.665 .739 .905 r
.65798 .11908 .66471 .12873 .67861 .12346 .67193 .11382 Mtetra
.665 .74 .906 r
.67193 .11382 .67861 .12346 .69258 .11821 .68595 .10855 Mtetra
.664 .741 .907 r
.68595 .10855 .69258 .11821 .70663 .11297 .70005 .10328 Mtetra
.70005 .10328 .70663 .11297 .72074 .10772 .71421 .09799 Mtetra
.664 .741 .908 r
.71421 .09799 .72074 .10772 .73493 .10246 .72844 .09268 Mtetra
.72844 .09268 .73493 .10246 .74919 .09717 .74275 .08735 Mtetra
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30774 .14296 .29978 Mtetra
.14296 .29978 .15124 .30774 .1628 .30344 .15454 .29544 Mtetra
.663 .741 .908 r
.15454 .29544 .1628 .30344 .1744 .29912 .16618 .29108 Mtetra
.16618 .29108 .1744 .29912 .18606 .2948 .17787 .28671 Mtetra
.17787 .28671 .18606 .2948 .19777 .29048 .18961 .28233 Mtetra
.662 .74 .908 r
.18961 .28233 .19777 .29048 .20952 .28621 .2014 .27796 Mtetra
.66 .737 .907 r
.2014 .27796 .20952 .28621 .22132 .28204 .21324 .27363 Mtetra
.656 .733 .906 r
.21324 .27363 .22132 .28204 .23315 .27809 .22512 .2694 Mtetra
.649 .725 .904 r
.22512 .2694 .23315 .27809 .245 .2745 .23704 .26536 Mtetra
.637 .711 .9 r
.23704 .26536 .245 .2745 .25687 .27146 .24899 .26162 Mtetra
.621 .689 .892 r
.24899 .26162 .25687 .27146 .26873 .2692 .26096 .25834 Mtetra
.601 .658 .878 r
.26096 .25834 .26873 .2692 .2806 .26787 .27295 .25564 Mtetra
.578 .621 .858 r
.27295 .25564 .2806 .26787 .29247 .26749 .28495 .2536 Mtetra
.559 .583 .834 r
.28495 .2536 .29247 .26749 .30437 .2679 .29698 .25219 Mtetra
.547 .549 .808 r
.29698 .25219 .30437 .2679 .31633 .26871 .30906 .25122 Mtetra
.545 .526 .784 r
.30906 .25122 .31633 .26871 .32841 .26935 .32122 .25035 Mtetra
.553 .514 .766 r
.32122 .25035 .32841 .26935 .34063 .26924 .33349 .24916 Mtetra
.568 .513 .753 r
.33349 .24916 .34063 .26924 .35301 .2679 .34588 .24727 Mtetra
.586 .519 .746 r
.34588 .24727 .35301 .2679 .36555 .26513 .35841 .24438 Mtetra
.606 .53 .743 r
.35841 .24438 .36555 .26513 .37823 .26102 .37107 .2404 Mtetra
.623 .541 .741 r
.37107 .2404 .37823 .26102 .39102 .25582 .38383 .23542 Mtetra
.637 .551 .741 r
.38383 .23542 .39102 .25582 .40389 .24988 .39669 .22962 Mtetra
.646 .558 .741 r
.39669 .22962 .40389 .24988 .41684 .24343 .40963 .22323 Mtetra
.653 .562 .74 r
.40963 .22323 .41684 .24343 .42984 .23658 .42262 .21642 Mtetra
.657 .566 .74 r
.42262 .21642 .42984 .23658 .4429 .2293 .43567 .20933 Mtetra
.661 .569 .741 r
.43567 .20933 .4429 .2293 .456 .22156 .44877 .20202 Mtetra
.665 .576 .745 r
.44877 .20202 .456 .22156 .46916 .21336 .46191 .19458 Mtetra
.669 .585 .752 r
.46191 .19458 .46916 .21336 .48235 .20481 .47509 .1871 Mtetra
.673 .598 .764 r
.47509 .1871 .48235 .20481 .49557 .19614 .48831 .1797 Mtetra
.677 .615 .779 r
.48831 .1797 .49557 .19614 .50883 .18757 .50157 .17251 Mtetra
.68 .634 .797 r
.50157 .17251 .50883 .18757 .52211 .17935 .51488 .1656 Mtetra
.68 .654 .818 r
.51488 .1656 .52211 .17935 .53544 .17164 .52823 .15904 Mtetra
.68 .674 .838 r
.52823 .15904 .53544 .17164 .54881 .16449 .54164 .15283 Mtetra
.677 .692 .857 r
.54164 .15283 .54881 .16449 .56223 .15788 .5551 .14694 Mtetra
.674 .707 .872 r
.5551 .14694 .56223 .15788 .5757 .15173 .56863 .14129 Mtetra
.671 .718 .884 r
.56863 .14129 .5757 .15173 .58925 .14593 .58222 .13583 Mtetra
.668 .726 .892 r
.58222 .13583 .58925 .14593 .60286 .14037 .59588 .13047 Mtetra
.667 .731 .898 r
.59588 .13047 .60286 .14037 .61653 .13496 .6096 .12518 Mtetra
.666 .735 .901 r
.6096 .12518 .61653 .13496 .63028 .12963 .62339 .11992 Mtetra
.665 .737 .904 r
.62339 .11992 .63028 .12963 .64409 .12434 .63726 .11466 Mtetra
.665 .739 .905 r
.63726 .11466 .64409 .12434 .65798 .11908 .65119 .10939 Mtetra
.664 .74 .906 r
.65119 .10939 .65798 .11908 .67193 .11382 .66519 .10411 Mtetra
.664 .741 .907 r
.66519 .10411 .67193 .11382 .68595 .10855 .67926 .09882 Mtetra
.67926 .09882 .68595 .10855 .70005 .10328 .6934 .09351 Mtetra
.664 .741 .908 r
.6934 .09351 .70005 .10328 .71421 .09799 .70762 .08818 Mtetra
.70762 .08818 .71421 .09799 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30044 Mtetra
.11153 .30044 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.12304 .29611 .13143 .3041 .14296 .29978 .1346 .29175 Mtetra
.1346 .29175 .14296 .29978 .15454 .29544 .14622 .28737 Mtetra
.14622 .28737 .15454 .29544 .16618 .29108 .15788 .28297 Mtetra
.663 .741 .908 r
.15788 .28297 .16618 .29108 .17787 .28671 .1696 .27856 Mtetra
.1696 .27856 .17787 .28671 .18961 .28233 .18137 .27413 Mtetra
.18137 .27413 .18961 .28233 .2014 .27796 .1932 .2697 Mtetra
.662 .74 .908 r
.1932 .2697 .2014 .27796 .21324 .27363 .20508 .26527 Mtetra
.66 .737 .907 r
.20508 .26527 .21324 .27363 .22512 .2694 .217 .26088 Mtetra
.656 .733 .906 r
.217 .26088 .22512 .2694 .23704 .26536 .22897 .25658 Mtetra
.65 .726 .904 r
.22897 .25658 .23704 .26536 .24899 .26162 .24099 .25243 Mtetra
.641 .713 .9 r
.24099 .25243 .24899 .26162 .26096 .25834 .25304 .24852 Mtetra
.628 .695 .892 r
.25304 .24852 .26096 .25834 .27295 .25564 .26511 .24496 Mtetra
.614 .67 .881 r
.26511 .24496 .27295 .25564 .28495 .2536 .27722 .24181 Mtetra
.598 .641 .864 r
.27722 .24181 .28495 .2536 .29698 .25219 .28936 .2391 Mtetra
.586 .612 .844 r
.28936 .2391 .29698 .25219 .30906 .25122 .30155 .23674 Mtetra
.58 .586 .824 r
.30155 .23674 .30906 .25122 .32122 .25035 .3138 .23456 Mtetra
.58 .568 .804 r
.3138 .23456 .32122 .25035 .33349 .24916 .32613 .2323 Mtetra
.588 .559 .789 r
.32613 .2323 .33349 .24916 .34588 .24727 .33856 .22965 Mtetra
.6 .557 .778 r
.33856 .22965 .34588 .24727 .35841 .24438 .35111 .22637 Mtetra
.615 .561 .771 r
.35111 .22637 .35841 .24438 .37107 .2404 .36376 .2223 Mtetra
.629 .569 .767 r
.36376 .2223 .37107 .2404 .38383 .23542 .37652 .21744 Mtetra
.642 .577 .766 r
.37652 .21744 .38383 .23542 .39669 .22962 .38937 .21187 Mtetra
.653 .585 .767 r
.38937 .21187 .39669 .22962 .40963 .22323 .4023 .20577 Mtetra
.66 .593 .769 r
.4023 .20577 .40963 .22323 .42262 .21642 .41529 .19931 Mtetra
.665 .599 .772 r
.41529 .19931 .42262 .21642 .43567 .20933 .42833 .19266 Mtetra
.668 .607 .777 r
.42833 .19266 .43567 .20933 .44877 .20202 .44142 .18593 Mtetra
.671 .615 .785 r
.44142 .18593 .44877 .20202 .46191 .19458 .45456 .17922 Mtetra
.673 .626 .794 r
.45456 .17922 .46191 .19458 .47509 .1871 .46774 .17259 Mtetra
.675 .64 .807 r
.46774 .17259 .47509 .1871 .48831 .1797 .48098 .16611 Mtetra
.676 .655 .822 r
.48098 .16611 .48831 .1797 .50157 .17251 .49425 .15982 Mtetra
.676 .671 .838 r
.49425 .15982 .50157 .17251 .51488 .1656 .50759 .15374 Mtetra
.675 .687 .853 r
.50759 .15374 .51488 .1656 .52823 .15904 .52097 .14788 Mtetra
.674 .701 .868 r
.52097 .14788 .52823 .15904 .54164 .15283 .53442 .14221 Mtetra
.671 .713 .88 r
.53442 .14221 .54164 .15283 .5551 .14694 .54792 .1367 Mtetra
.669 .722 .889 r
.54792 .1367 .5551 .14694 .56863 .14129 .56149 .13131 Mtetra
.667 .729 .896 r
.56149 .13131 .56863 .14129 .58222 .13583 .57513 .12599 Mtetra
.666 .733 .9 r
.57513 .12599 .58222 .13583 .59588 .13047 .58884 .12072 Mtetra
.665 .736 .903 r
.58884 .12072 .59588 .13047 .6096 .12518 .60261 .11547 Mtetra
.664 .738 .905 r
.60261 .11547 .6096 .12518 .62339 .11992 .61645 .11021 Mtetra
.664 .739 .906 r
.61645 .11021 .62339 .11992 .63726 .11466 .63036 .10494 Mtetra
.664 .74 .907 r
.63036 .10494 .63726 .11466 .65119 .10939 .64434 .09965 Mtetra
.664 .741 .907 r
.64434 .09965 .65119 .10939 .66519 .10411 .65839 .09434 Mtetra
.65839 .09434 .66519 .10411 .67926 .09882 .67251 .089 Mtetra
.664 .741 .908 r
.67251 .089 .67926 .09882 .6934 .09351 .6867 .08365 Mtetra
.6867 .08365 .6934 .09351 .70762 .08818 .70096 .07827 Mtetra
.70096 .07827 .70762 .08818 .7219 .08282 .71529 .07287 Mtetra
.71529 .07287 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29677 Mtetra
.09156 .29677 .10008 .30476 .11153 .30044 .10305 .29242 Mtetra
.10305 .29242 .11153 .30044 .12304 .29611 .11459 .28804 Mtetra
.11459 .28804 .12304 .29611 .1346 .29175 .12618 .28365 Mtetra
.12618 .28365 .1346 .29175 .14622 .28737 .13782 .27924 Mtetra
.13782 .27924 .14622 .28737 .15788 .28297 .14952 .2748 Mtetra
.663 .741 .908 r
.14952 .2748 .15788 .28297 .1696 .27856 .16127 .27035 Mtetra
.16127 .27035 .1696 .27856 .18137 .27413 .17307 .26588 Mtetra
.17307 .26588 .18137 .27413 .1932 .2697 .18493 .26139 Mtetra
.18493 .26139 .1932 .2697 .20508 .26527 .19684 .2569 Mtetra
.662 .74 .908 r
.19684 .2569 .20508 .26527 .217 .26088 .2088 .25241 Mtetra
.66 .737 .907 r
.2088 .25241 .217 .26088 .22897 .25658 .22082 .24795 Mtetra
.657 .734 .906 r
.22082 .24795 .22897 .25658 .24099 .25243 .23288 .24357 Mtetra
.652 .727 .904 r
.23288 .24357 .24099 .25243 .25304 .24852 .24499 .2393 Mtetra
.645 .717 .9 r
.24499 .2393 .25304 .24852 .26511 .24496 .25714 .23521 Mtetra
.636 .702 .894 r
.25714 .23521 .26511 .24496 .27722 .24181 .26933 .23136 Mtetra
.626 .683 .884 r
.26933 .23136 .27722 .24181 .28936 .2391 .28155 .22778 Mtetra
.617 .661 .871 r
.28155 .22778 .28936 .2391 .30155 .23674 .29383 .22444 Mtetra
.61 .639 .855 r
.29383 .22444 .30155 .23674 .3138 .23456 .30616 .22126 Mtetra
.607 .621 .839 r
.30616 .22126 .3138 .23456 .32613 .2323 .31856 .21809 Mtetra
.61 .608 .824 r
.31856 .21809 .32613 .2323 .33856 .22965 .33105 .21472 Mtetra
.617 .601 .812 r
.33105 .21472 .33856 .22965 .35111 .22637 .34362 .21099 Mtetra
.627 .6 .804 r
.34362 .21099 .35111 .22637 .36376 .2223 .35629 .20673 Mtetra
.638 .604 .799 r
.35629 .20673 .36376 .2223 .37652 .21744 .36906 .20192 Mtetra
.649 .61 .797 r
.36906 .20192 .37652 .21744 .38937 .21187 .38191 .19658 Mtetra
.658 .618 .798 r
.38191 .19658 .38937 .21187 .4023 .20577 .39483 .19082 Mtetra
.664 .627 .802 r
.39483 .19082 .4023 .20577 .41529 .19931 .40782 .18479 Mtetra
.669 .636 .807 r
.40782 .18479 .41529 .19931 .42833 .19266 .42087 .17862 Mtetra
.672 .645 .815 r
.42087 .17862 .42833 .19266 .44142 .18593 .43396 .17244 Mtetra
.674 .655 .823 r
.43396 .17244 .44142 .18593 .45456 .17922 .44711 .16631 Mtetra
.674 .666 .834 r
.44711 .16631 .45456 .17922 .46774 .17259 .46031 .16029 Mtetra
.674 .677 .845 r
.46031 .16029 .46774 .17259 .48098 .16611 .47356 .1544 Mtetra
.673 .689 .857 r
.47356 .1544 .48098 .16611 .49425 .15982 .48687 .14865 Mtetra
.672 .701 .868 r
.48687 .14865 .49425 .15982 .50759 .15374 .50023 .14304 Mtetra
.671 .711 .878 r
.50023 .14304 .50759 .15374 .52097 .14788 .51365 .13754 Mtetra
.669 .72 .887 r
.51365 .13754 .52097 .14788 .53442 .14221 .52714 .13214 Mtetra
.667 .727 .894 r
.52714 .13214 .53442 .14221 .54792 .1367 .54069 .12681 Mtetra
.666 .732 .899 r
.54069 .12681 .54792 .1367 .56149 .13131 .5543 .12153 Mtetra
.665 .735 .902 r
.5543 .12153 .56149 .13131 .57513 .12599 .56799 .11627 Mtetra
.664 .737 .904 r
.56799 .11627 .57513 .12599 .58884 .12072 .58174 .11101 Mtetra
.664 .739 .906 r
.58174 .11101 .58884 .12072 .60261 .11547 .59555 .10574 Mtetra
.664 .74 .906 r
.59555 .10574 .60261 .11547 .61645 .11021 .60944 .10046 Mtetra
.664 .74 .907 r
.60944 .10046 .61645 .11021 .63036 .10494 .6234 .09516 Mtetra
.664 .741 .907 r
.6234 .09516 .63036 .10494 .64434 .09965 .63743 .08983 Mtetra
.63743 .08983 .64434 .09965 .65839 .09434 .65152 .08448 Mtetra
.664 .741 .908 r
.65152 .08448 .65839 .09434 .67251 .089 .66569 .0791 Mtetra
.66569 .0791 .67251 .089 .6867 .08365 .67993 .0737 Mtetra
.67993 .0737 .6867 .08365 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07287 .70863 .06282 Mtetra
.70863 .06282 .71529 .07287 .7297 .06743 .72309 .05734 Mtetra
.07152 .29309 .08013 .30111 .09156 .29677 .08298 .28872 Mtetra
.08298 .28872 .09156 .29677 .10305 .29242 .09449 .28433 Mtetra
.09449 .28433 .10305 .29242 .11459 .28804 .10606 .27992 Mtetra
.10606 .27992 .11459 .28804 .12618 .28365 .11768 .27548 Mtetra
.11768 .27548 .12618 .28365 .13782 .27924 .12935 .27103 Mtetra
.12935 .27103 .13782 .27924 .14952 .2748 .14108 .26656 Mtetra
.14108 .26656 .14952 .2748 .16127 .27035 .15286 .26207 Mtetra
.663 .741 .908 r
.15286 .26207 .16127 .27035 .17307 .26588 .1647 .25756 Mtetra
.1647 .25756 .17307 .26588 .18493 .26139 .17659 .25303 Mtetra
.17659 .25303 .18493 .26139 .19684 .2569 .18853 .24848 Mtetra
.18853 .24848 .19684 .2569 .2088 .25241 .20053 .24393 Mtetra
.662 .74 .908 r
.20053 .24393 .2088 .25241 .22082 .24795 .21258 .23938 Mtetra
.66 .738 .907 r
.21258 .23938 .22082 .24795 .23288 .24357 .22469 .23485 Mtetra
.658 .734 .906 r
.22469 .23485 .23288 .24357 .24499 .2393 .23684 .23037 Mtetra
.654 .729 .904 r
.23684 .23037 .24499 .2393 .25714 .23521 .24904 .22598 Mtetra
.649 .721 .901 r
.24904 .22598 .25714 .23521 .26933 .23136 .26129 .2217 Mtetra
.643 .709 .895 r
.26129 .2217 .26933 .23136 .28155 .22778 .27359 .21757 Mtetra
.637 .695 .887 r
.27359 .21757 .28155 .22778 .29383 .22444 .28594 .21359 Mtetra
.632 .68 .877 r
.28594 .21359 .29383 .22444 .30616 .22126 .29834 .20971 Mtetra
.629 .665 .866 r
.29834 .20971 .30616 .22126 .31856 .21809 .31081 .20586 Mtetra
.629 .652 .854 r
.31081 .20586 .31856 .21809 .33105 .21472 .32335 .20192 Mtetra
.633 .644 .844 r
.32335 .20192 .33105 .21472 .34362 .21099 .33596 .19778 Mtetra
.639 .64 .836 r
.33596 .19778 .34362 .21099 .35629 .20673 .34866 .19332 Mtetra
.646 .641 .831 r
.34866 .19332 .35629 .20673 .36906 .20192 .36144 .18851 Mtetra
.654 .645 .829 r
.36144 .18851 .36906 .20192 .38191 .19658 .3743 .18334 Mtetra
.661 .652 .83 r
.3743 .18334 .38191 .19658 .39483 .19082 .38724 .17788 Mtetra
.667 .66 .834 r
.38724 .17788 .39483 .19082 .40782 .18479 .40023 .17222 Mtetra
.67 .669 .84 r
.40023 .17222 .40782 .18479 .42087 .17862 .41329 .16646 Mtetra
.672 .678 .847 r
.41329 .16646 .42087 .17862 .43396 .17244 .4264 .16069 Mtetra
.673 .687 .855 r
.4264 .16069 .43396 .17244 .44711 .16631 .43957 .15498 Mtetra
.673 .696 .864 r
.43957 .15498 .44711 .16631 .46031 .16029 .45279 .14934 Mtetra
.672 .705 .872 r
.45279 .14934 .46031 .16029 .47356 .1544 .46607 .1438 Mtetra
.67 .713 .88 r
.46607 .1438 .47356 .1544 .48687 .14865 .47941 .13834 Mtetra
.669 .72 .888 r
.47941 .13834 .48687 .14865 .50023 .14304 .49281 .13295 Mtetra
.667 .726 .893 r
.49281 .13295 .50023 .14304 .51365 .13754 .50627 .12763 Mtetra
.666 .731 .898 r
.50627 .12763 .51365 .13754 .52714 .13214 .5198 .12234 Mtetra
.665 .735 .901 r
.5198 .12234 .52714 .13214 .54069 .12681 .53339 .11707 Mtetra
.665 .737 .904 r
.53339 .11707 .54069 .12681 .5543 .12153 .54705 .11181 Mtetra
.664 .739 .905 r
.54705 .11181 .5543 .12153 .56799 .11627 .56078 .10655 Mtetra
.664 .74 .906 r
.56078 .10655 .56799 .11627 .58174 .11101 .57457 .10127 Mtetra
.664 .74 .907 r
.57457 .10127 .58174 .11101 .59555 .10574 .58844 .09597 Mtetra
.664 .741 .907 r
.58844 .09597 .59555 .10574 .60944 .10046 .60237 .09065 Mtetra
.60237 .09065 .60944 .10046 .6234 .09516 .61637 .0853 Mtetra
.664 .741 .908 r
.61637 .0853 .6234 .09516 .63743 .08983 .63045 .07993 Mtetra
.63045 .07993 .63743 .08983 .65152 .08448 .64459 .07453 Mtetra
.64459 .07453 .65152 .08448 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05268 Mtetra
.7019 .05268 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.06283 .285 .07152 .29309 .08298 .28872 .07432 .2806 Mtetra
.07432 .2806 .08298 .28872 .09449 .28433 .08587 .27617 Mtetra
.08587 .27617 .09449 .28433 .10606 .27992 .09746 .27172 Mtetra
.09746 .27172 .10606 .27992 .11768 .27548 .10911 .26725 Mtetra
.10911 .26725 .11768 .27548 .12935 .27103 .12082 .26276 Mtetra
.12082 .26276 .12935 .27103 .14108 .26656 .13257 .25825 Mtetra
.13257 .25825 .14108 .26656 .15286 .26207 .14438 .25372 Mtetra
.14438 .25372 .15286 .26207 .1647 .25756 .15625 .24917 Mtetra
.663 .741 .908 r
.15625 .24917 .1647 .25756 .17659 .25303 .16817 .2446 Mtetra
.16817 .2446 .17659 .25303 .18853 .24848 .18015 .24001 Mtetra
.18015 .24001 .18853 .24848 .20053 .24393 .19218 .2354 Mtetra
.19218 .2354 .20053 .24393 .21258 .23938 .20427 .23078 Mtetra
.662 .74 .908 r
.20427 .23078 .21258 .23938 .22469 .23485 .21641 .22617 Mtetra
.661 .738 .907 r
.21641 .22617 .22469 .23485 .23684 .23037 .2286 .22156 Mtetra
.659 .735 .906 r
.2286 .22156 .23684 .23037 .24904 .22598 .24085 .21699 Mtetra
.657 .731 .904 r
.24085 .21699 .24904 .22598 .26129 .2217 .25315 .21246 Mtetra
.653 .725 .901 r
.25315 .21246 .26129 .2217 .27359 .21757 .26551 .208 Mtetra
.65 .716 .897 r
.26551 .208 .27359 .21757 .28594 .21359 .27792 .20362 Mtetra
.647 .707 .891 r
.27792 .20362 .28594 .21359 .29834 .20971 .29038 .19929 Mtetra
.644 .697 .884 r
.29038 .19929 .29834 .20971 .31081 .20586 .3029 .19498 Mtetra
.644 .687 .876 r
.3029 .19498 .31081 .20586 .32335 .20192 .31549 .19063 Mtetra
.645 .68 .869 r
.31549 .19063 .32335 .20192 .33596 .19778 .32815 .18617 Mtetra
.648 .676 .862 r
.32815 .18617 .33596 .19778 .34866 .19332 .34088 .18154 Mtetra
.653 .675 .858 r
.34088 .18154 .34866 .19332 .36144 .18851 .35369 .17669 Mtetra
.658 .677 .857 r
.35369 .17669 .36144 .18851 .3743 .18334 .36657 .17162 Mtetra
.663 .682 .858 r
.36657 .17162 .3743 .18334 .38724 .17788 .37952 .16636 Mtetra
.667 .688 .861 r
.37952 .16636 .38724 .17788 .40023 .17222 .39253 .16096 Mtetra
.669 .696 .866 r
.39253 .16096 .40023 .17222 .41329 .16646 .40561 .15549 Mtetra
.67 .703 .872 r
.40561 .15549 .41329 .16646 .4264 .16069 .41874 .15001 Mtetra
.671 .71 .878 r
.41874 .15001 .4264 .16069 .43957 .15498 .43194 .14454 Mtetra
.67 .717 .884 r
.43194 .14454 .43957 .15498 .45279 .14934 .44519 .13913 Mtetra
.669 .723 .889 r
.44519 .13913 .45279 .14934 .46607 .1438 .4585 .13376 Mtetra
.667 .727 .894 r
.4585 .13376 .46607 .1438 .47941 .13834 .47188 .12844 Mtetra
.666 .731 .898 r
.47188 .12844 .47941 .13834 .49281 .13295 .48532 .12315 Mtetra
.665 .734 .901 r
.48532 .12315 .49281 .13295 .50627 .12763 .49882 .11788 Mtetra
.665 .737 .904 r
.49882 .11788 .50627 .12763 .5198 .12234 .51239 .11262 Mtetra
.664 .738 .905 r
.51239 .11262 .5198 .12234 .53339 .11707 .52603 .10735 Mtetra
.664 .739 .906 r
.52603 .10735 .53339 .11707 .54705 .11181 .53973 .10208 Mtetra
.664 .74 .907 r
.53973 .10208 .54705 .11181 .56078 .10655 .5535 .09678 Mtetra
.664 .741 .907 r
.5535 .09678 .56078 .10655 .57457 .10127 .56734 .09147 Mtetra
.56734 .09147 .57457 .10127 .58844 .09597 .58125 .08612 Mtetra
.664 .741 .908 r
.58125 .08612 .58844 .09597 .60237 .09065 .59523 .08076 Mtetra
.59523 .08076 .60237 .09065 .61637 .0853 .60929 .07537 Mtetra
.60929 .07537 .61637 .0853 .63045 .07993 .62341 .06995 Mtetra
.62341 .06995 .63045 .07993 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05903 Mtetra
.65187 .05903 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05268 .6951 .04244 Mtetra
.6951 .04244 .7019 .05268 .71641 .04714 .70966 .03685 Mtetra
.05408 .27685 .06283 .285 .07432 .2806 .06559 .2724 Mtetra
.06559 .2724 .07432 .2806 .08587 .27617 .07717 .26794 Mtetra
.07717 .26794 .08587 .27617 .09746 .27172 .08879 .26345 Mtetra
.08879 .26345 .09746 .27172 .10911 .26725 .10047 .25894 Mtetra
.10047 .25894 .10911 .26725 .12082 .26276 .1122 .25442 Mtetra
.1122 .25442 .12082 .26276 .13257 .25825 .12399 .24987 Mtetra
.12399 .24987 .13257 .25825 .14438 .25372 .13583 .2453 Mtetra
.13583 .2453 .14438 .25372 .15625 .24917 .14773 .24071 Mtetra
.14773 .24071 .15625 .24917 .16817 .2446 .15968 .23609 Mtetra
.663 .741 .908 r
.15968 .23609 .16817 .2446 .18015 .24001 .17169 .23146 Mtetra
.17169 .23146 .18015 .24001 .19218 .2354 .18376 .22681 Mtetra
.18376 .22681 .19218 .2354 .20427 .23078 .19588 .22214 Mtetra
.19588 .22214 .20427 .23078 .21641 .22617 .20805 .21746 Mtetra
.662 .74 .907 r
.20805 .21746 .21641 .22617 .2286 .22156 .22029 .21277 Mtetra
.662 .738 .907 r
.22029 .21277 .2286 .22156 .24085 .21699 .23258 .20809 Mtetra
.66 .736 .906 r
.23258 .20809 .24085 .21699 .25315 .21246 .24492 .20341 Mtetra
.659 .733 .905 r
.24492 .20341 .25315 .21246 .26551 .208 .25732 .19876 Mtetra
.657 .729 .902 r
.25732 .19876 .26551 .208 .27792 .20362 .26978 .19413 Mtetra
.655 .723 .899 r
.26978 .19413 .27792 .20362 .29038 .19929 .28229 .18953 Mtetra
.654 .717 .895 r
.28229 .18953 .29038 .19929 .3029 .19498 .29486 .18493 Mtetra
.653 .711 .89 r
.29486 .18493 .3029 .19498 .31549 .19063 .3075 .18031 Mtetra
.653 .706 .886 r
.3075 .18031 .31549 .19063 .32815 .18617 .3202 .17563 Mtetra
.655 .703 .882 r
.3202 .17563 .32815 .18617 .34088 .18154 .33297 .17085 Mtetra
.657 .701 .879 r
.33297 .17085 .34088 .18154 .35369 .17669 .34581 .16595 Mtetra
.66 .702 .878 r
.34581 .16595 .35369 .17669 .36657 .17162 .35872 .16092 Mtetra
.663 .705 .878 r
.35872 .16092 .36657 .17162 .37952 .16636 .37169 .15577 Mtetra
.666 .709 .88 r
.37169 .15577 .37952 .16636 .39253 .16096 .38473 .15052 Mtetra
.667 .715 .884 r
.38473 .15052 .39253 .16096 .40561 .15549 .39783 .14522 Mtetra
.668 .72 .888 r
.39783 .14522 .40561 .15549 .41874 .15001 .411 .1399 Mtetra
.668 .724 .892 r
.411 .1399 .41874 .15001 .43194 .14454 .42422 .13457 Mtetra
.667 .729 .895 r
.42422 .13457 .43194 .14454 .44519 .13913 .43751 .12927 Mtetra
.667 .732 .899 r
.43751 .12927 .44519 .13913 .4585 .13376 .45086 .12398 Mtetra
.666 .735 .901 r
.45086 .12398 .4585 .13376 .47188 .12844 .46428 .1187 Mtetra
.665 .737 .903 r
.46428 .1187 .47188 .12844 .48532 .12315 .47776 .11344 Mtetra
.664 .738 .905 r
.47776 .11344 .48532 .12315 .49882 .11788 .4913 .10817 Mtetra
.664 .739 .906 r
.4913 .10817 .49882 .11788 .51239 .11262 .50491 .10289 Mtetra
.664 .74 .907 r
.50491 .10289 .51239 .11262 .52603 .10735 .51859 .0976 Mtetra
.664 .741 .907 r
.51859 .0976 .52603 .10735 .53973 .10208 .53234 .09228 Mtetra
.664 .741 .908 r
.53234 .09228 .53973 .10208 .5535 .09678 .54616 .08695 Mtetra
.54616 .08695 .5535 .09678 .56734 .09147 .56005 .08158 Mtetra
.56005 .08158 .56734 .09147 .58125 .08612 .574 .0762 Mtetra
.574 .0762 .58125 .08612 .59523 .08076 .58803 .07078 Mtetra
.58803 .07078 .59523 .08076 .60929 .07537 .60213 .06534 Mtetra
.60213 .06534 .60929 .07537 .62341 .06995 .6163 .05987 Mtetra
.6163 .05987 .62341 .06995 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05903 .64486 .04885 Mtetra
.64486 .04885 .65187 .05903 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.04524 .26863 .05408 .27685 .06559 .2724 .05679 .26414 Mtetra
.05679 .26414 .06559 .2724 .07717 .26794 .06839 .25964 Mtetra
.06839 .25964 .07717 .26794 .08879 .26345 .08005 .25511 Mtetra
.08005 .25511 .08879 .26345 .10047 .25894 .09176 .25057 Mtetra
.09176 .25057 .10047 .25894 .1122 .25442 .10352 .246 Mtetra
.10352 .246 .1122 .25442 .12399 .24987 .11534 .24141 Mtetra
.11534 .24141 .12399 .24987 .13583 .2453 .12721 .2368 Mtetra
.12721 .2368 .13583 .2453 .14773 .24071 .13914 .23217 Mtetra
.13914 .23217 .14773 .24071 .15968 .23609 .15112 .22752 Mtetra
.15112 .22752 .15968 .23609 .17169 .23146 .16316 .22285 Mtetra
.663 .741 .908 r
.16316 .22285 .17169 .23146 .18376 .22681 .17526 .21815 Mtetra
.17526 .21815 .18376 .22681 .19588 .22214 .18741 .21344 Mtetra
.18741 .21344 .19588 .22214 .20805 .21746 .19963 .2087 Mtetra
.19963 .2087 .20805 .21746 .22029 .21277 .21189 .20396 Mtetra
.663 .74 .907 r
.21189 .20396 .22029 .21277 .23258 .20809 .22422 .19919 Mtetra
.662 .739 .907 r
.22422 .19919 .23258 .20809 .24492 .20341 .2366 .19443 Mtetra
.661 .737 .906 r
.2366 .19443 .24492 .20341 .25732 .19876 .24904 .18965 Mtetra
.66 .735 .905 r
.24904 .18965 .25732 .19876 .26978 .19413 .26154 .18488 Mtetra
.66 .732 .904 r
.26154 .18488 .26978 .19413 .28229 .18953 .2741 .18011 Mtetra
.659 .729 .901 r
.2741 .18011 .28229 .18953 .29486 .18493 .28672 .17533 Mtetra
.658 .726 .899 r
.28672 .17533 .29486 .18493 .3075 .18031 .2994 .17054 Mtetra
.658 .723 .896 r
.2994 .17054 .3075 .18031 .3202 .17563 .31214 .16571 Mtetra
.659 .72 .894 r
.31214 .16571 .3202 .17563 .33297 .17085 .32495 .16082 Mtetra
.66 .719 .892 r
.32495 .16082 .33297 .17085 .34581 .16595 .33782 .15586 Mtetra
.662 .719 .892 r
.33782 .15586 .34581 .16595 .35872 .16092 .35076 .15082 Mtetra
.663 .721 .892 r
.35076 .15082 .35872 .16092 .37169 .15577 .36377 .14571 Mtetra
.665 .723 .893 r
.36377 .14571 .37169 .15577 .38473 .15052 .37684 .14054 Mtetra
.666 .726 .895 r
.37684 .14054 .38473 .15052 .39783 .14522 .38997 .13531 Mtetra
.666 .73 .897 r
.38997 .13531 .39783 .14522 .411 .1399 .40317 .13007 Mtetra
.666 .732 .899 r
.40317 .13007 .411 .1399 .42422 .13457 .41643 .1248 Mtetra
.666 .735 .902 r
.41643 .1248 .42422 .13457 .43751 .12927 .42976 .11954 Mtetra
.665 .737 .903 r
.42976 .11954 .43751 .12927 .45086 .12398 .44315 .11427 Mtetra
.665 .738 .905 r
.44315 .11427 .45086 .12398 .46428 .1187 .4566 .10899 Mtetra
.664 .739 .906 r
.4566 .10899 .46428 .1187 .47776 .11344 .47012 .10371 Mtetra
.664 .74 .907 r
.47012 .10371 .47776 .11344 .4913 .10817 .48371 .09842 Mtetra
.664 .741 .907 r
.48371 .09842 .4913 .10817 .50491 .10289 .49737 .0931 Mtetra
.49737 .0931 .50491 .10289 .51859 .0976 .51109 .08777 Mtetra
.664 .741 .908 r
.51109 .08777 .51859 .0976 .53234 .09228 .52489 .08241 Mtetra
.52489 .08241 .53234 .09228 .54616 .08695 .53875 .07703 Mtetra
.53875 .07703 .54616 .08695 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .0762 .56669 .06618 Mtetra
.56669 .06618 .574 .0762 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.03634 .26033 .04524 .26863 .05679 .26414 .04791 .25581 Mtetra
.04791 .25581 .05679 .26414 .06839 .25964 .05954 .25127 Mtetra
.05954 .25127 .06839 .25964 .08005 .25511 .07123 .24671 Mtetra
.07123 .24671 .08005 .25511 .09176 .25057 .08297 .24212 Mtetra
.08297 .24212 .09176 .25057 .10352 .246 .09476 .23751 Mtetra
.09476 .23751 .10352 .246 .11534 .24141 .10661 .23289 Mtetra
.10661 .23289 .11534 .24141 .12721 .2368 .11851 .22824 Mtetra
.11851 .22824 .12721 .2368 .13914 .23217 .13047 .22357 Mtetra
.13047 .22357 .13914 .23217 .15112 .22752 .14249 .21887 Mtetra
.14249 .21887 .15112 .22752 .16316 .22285 .15456 .21416 Mtetra
.15456 .21416 .16316 .22285 .17526 .21815 .16669 .20942 Mtetra
.663 .741 .908 r
.16669 .20942 .17526 .21815 .18741 .21344 .17888 .20466 Mtetra
.17888 .20466 .18741 .21344 .19963 .2087 .19112 .19988 Mtetra
.19112 .19988 .19963 .2087 .21189 .20396 .20343 .19508 Mtetra
.20343 .19508 .21189 .20396 .22422 .19919 .21579 .19026 Mtetra
.663 .74 .907 r
.21579 .19026 .22422 .19919 .2366 .19443 .22821 .18543 Mtetra
.22821 .18543 .2366 .19443 .24904 .18965 .24069 .18058 Mtetra
.662 .739 .907 r
.24069 .18058 .24904 .18965 .26154 .18488 .25322 .17572 Mtetra
.662 .737 .906 r
.25322 .17572 .26154 .18488 .2741 .18011 .26582 .17084 Mtetra
.661 .736 .905 r
.26582 .17084 .2741 .18011 .28672 .17533 .27848 .16595 Mtetra
.661 .734 .904 r
.27848 .16595 .28672 .17533 .2994 .17054 .2912 .16104 Mtetra
.661 .732 .902 r
.2912 .16104 .2994 .17054 .31214 .16571 .30398 .1561 Mtetra
.661 .731 .901 r
.30398 .1561 .31214 .16571 .32495 .16082 .31683 .15113 Mtetra
.662 .73 .9 r
.31683 .15113 .32495 .16082 .33782 .15586 .32974 .14611 Mtetra
.32974 .14611 .33782 .15586 .35076 .15082 .34271 .14105 Mtetra
.663 .73 .9 r
.34271 .14105 .35076 .15082 .36377 .14571 .35576 .13593 Mtetra
.664 .732 .9 r
.35576 .13593 .36377 .14571 .37684 .14054 .36886 .13077 Mtetra
.664 .733 .901 r
.36886 .13077 .37684 .14054 .38997 .13531 .38203 .12557 Mtetra
.665 .735 .902 r
.38203 .12557 .38997 .13531 .40317 .13007 .39527 .12034 Mtetra
.665 .737 .904 r
.39527 .12034 .40317 .13007 .41643 .1248 .40857 .11509 Mtetra
.665 .738 .905 r
.40857 .11509 .41643 .1248 .42976 .11954 .42193 .10982 Mtetra
.664 .739 .906 r
.42193 .10982 .42976 .11954 .44315 .11427 .43536 .10454 Mtetra
.664 .74 .906 r
.43536 .10454 .44315 .11427 .4566 .10899 .44886 .09924 Mtetra
.664 .74 .907 r
.44886 .09924 .4566 .10899 .47012 .10371 .46242 .09393 Mtetra
.664 .741 .907 r
.46242 .09393 .47012 .10371 .48371 .09842 .47605 .08859 Mtetra
.664 .741 .908 r
.47605 .08859 .48371 .09842 .49737 .0931 .48975 .08324 Mtetra
.48975 .08324 .49737 .0931 .51109 .08777 .50352 .07786 Mtetra
.50352 .07786 .51109 .08777 .52489 .08241 .51736 .07245 Mtetra
.51736 .07245 .52489 .08241 .53875 .07703 .53127 .06702 Mtetra
.53127 .06702 .53875 .07703 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.7064 .46323 m
.7322 .44958 L
.758 .45324 L
.77714 .4742 L
.7838 .48794 L
.78642 .5 L
.78938 .5258 L
.78784 .5516 L
.7838 .57231 L
.78285 .5774 L
.77471 .6032 L
.75911 .629 L
.758 .63042 L
.73302 .6548 L
.7322 .65532 L
.7064 .66276 L
.68567 .6548 L
.6806 .65056 L
.66492 .629 L
.65942 .6032 L
.6586 .5774 L
.66117 .5516 L
.66757 .5258 L
.67884 .5 L
.6806 .4968 L
.6928 .4742 L
.7064 .46323 L
s
.5516 .2381 m
.5774 .23223 L
.6032 .23434 L
.6285 .242 L
.629 .24217 L
.6548 .25468 L
.67269 .2678 L
.6806 .27382 L
.6969 .2936 L
.7064 .30982 L
.7105 .3194 L
.71456 .3452 L
.7064 .36839 L
.70508 .371 L
.6806 .38805 L
.6548 .39109 L
.629 .38778 L
.6032 .37886 L
.58709 .371 L
.5774 .36497 L
.55424 .3452 L
.5516 .34381 L
.53423 .3194 L
.5258 .29922 L
.5244 .2936 L
.52496 .2678 L
.5258 .26521 L
.54335 .242 L
.5516 .2381 L
s
.242 .54167 m
.2678 .53379 L
.2936 .53834 L
.3194 .55101 L
.32046 .5516 L
.3452 .5706 L
.35221 .5774 L
.371 .60086 L
.37249 .6032 L
.38668 .629 L
.39391 .6548 L
.39403 .6806 L
.37184 .7064 L
.371 .7068 L
.3452 .71007 L
.32904 .7064 L
.3194 .7031 L
.2936 .6883 L
.28307 .6806 L
.2678 .66578 L
.25838 .6548 L
.242 .62949 L
.24176 .629 L
.23071 .6032 L
.2266 .5774 L
.23315 .5516 L
.242 .54167 L
s
.5258 .65206 m
.5516 .65252 L
.56232 .6548 L
.5774 .65909 L
.6032 .67803 L
.60524 .6806 L
.61905 .7064 L
.61928 .7322 L
.60598 .758 L
.6032 .76153 L
.5774 .77999 L
.56371 .7838 L
.5516 .78634 L
.5258 .7865 L
.51242 .7838 L
.5 .78045 L
.4742 .76342 L
.46966 .758 L
.45602 .7322 L
.45583 .7064 L
.46908 .6806 L
.4742 .67445 L
.5 .65787 L
.51172 .6548 L
.5258 .65206 L
s
.371 .26411 m
.38928 .2678 L
.3968 .27236 L
.41132 .2936 L
.41183 .3194 L
.40535 .3452 L
.3968 .36827 L
.39377 .371 L
.37677 .3968 L
.371 .40399 L
.3537 .4226 L
.3452 .42973 L
.3194 .44733 L
.31723 .4484 L
.2936 .45783 L
.2678 .4592 L
.24895 .4484 L
.242 .43807 L
.23752 .4226 L
.23899 .3968 L
.242 .38498 L
.24651 .371 L
.25976 .3452 L
.2678 .33273 L
.27797 .3194 L
.2936 .30305 L
.30304 .2936 L
.3194 .28247 L
.3452 .2693 L
.34999 .2678 L
.371 .26411 L
s
0 g
.03 w
.72423 .55572 Mdot
.61881 .31151 Mdot
.31087 .62244 Mdot
.53754 .71934 Mdot
.32454 .3619 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.71569 .51504 m
.73529 .5065 L
.74644 .51961 L
.75041 .53922 L
.74862 .55882 L
.74189 .57843 L
.73529 .59025 L
.72583 .59804 L
.71569 .60205 L
.70606 .59804 L
.69769 .57843 L
.69791 .55882 L
.70254 .53922 L
.7123 .51961 L
.71569 .51504 L
s
.32353 .3441 m
.34079 .36275 L
.32353 .38186 L
.30741 .36275 L
.32353 .3441 L
s
.51961 .69143 m
.53922 .68849 L
.55882 .69304 L
.56542 .69608 L
.57843 .71316 L
.57883 .71569 L
.57843 .72063 L
.57195 .73529 L
.55882 .74308 L
.53922 .74828 L
.51961 .74632 L
.5 .73545 L
.49982 .73529 L
.49217 .71569 L
.5 .70304 L
.51016 .69608 L
.51961 .69143 L
s
.73529 .47856 m
.74196 .48039 L
.7549 .49276 L
.75932 .5 L
.76473 .51961 L
.7653 .53922 L
.76273 .55882 L
.7569 .57843 L
.7549 .58357 L
.75082 .59804 L
.73529 .6142 L
.73143 .61765 L
.71569 .62696 L
.69608 .62418 L
.69045 .61765 L
.68103 .59804 L
.68119 .57843 L
.68329 .55882 L
.6878 .53922 L
.69521 .51961 L
.69608 .51773 L
.70568 .5 L
.71569 .48749 L
.72615 .48039 L
.73529 .47856 L
s
.32353 .31964 m
.34314 .31007 L
.36275 .31372 L
.37303 .32353 L
.37064 .34314 L
.36275 .36232 L
.36269 .36275 L
.35057 .38235 L
.34314 .39064 L
.33296 .40196 L
.32353 .40702 L
.30392 .4173 L
.28431 .41442 L
.27455 .40196 L
.27786 .38235 L
.28431 .36578 L
.28492 .36275 L
.29761 .34314 L
.30392 .33591 L
.31603 .32353 L
.32353 .31964 L
s
.51961 .67626 m
.53922 .67447 L
.55882 .67634 L
.55975 .67647 L
.57843 .67985 L
.59804 .69323 L
.59948 .69608 L
.60491 .71569 L
.59804 .73279 L
.59637 .73529 L
.57843 .75403 L
.57402 .7549 L
.55882 .76068 L
.53922 .76414 L
.51961 .76294 L
.5 .75673 L
.49611 .7549 L
.48039 .74413 L
.47217 .73529 L
.4653 .71569 L
.47579 .69608 L
.48039 .69105 L
.5 .68028 L
.5179 .67647 L
.51961 .67626 L
s
.28431 .58918 m
.30392 .58819 L
.31335 .59804 L
.32353 .60768 L
.3314 .61765 L
.34028 .63725 L
.32353 .65106 L
.30392 .64143 L
.30073 .63725 L
.28605 .61765 L
.28431 .61388 L
.28079 .59804 L
.28431 .58918 L
s
.73529 .45233 m
.75356 .46078 L
.7549 .46208 L
.7692 .48039 L
.77344 .5 L
.77451 .50912 L
.7756 .51961 L
.77557 .53922 L
.77451 .54985 L
.77325 .55882 L
.76858 .57843 L
.7608 .59804 L
.7549 .60891 L
.75063 .61765 L
.73529 .63392 L
.73145 .63725 L
.71569 .64738 L
.69608 .65129 L
.67647 .63759 L
.67629 .63725 L
.67072 .61765 L
.66962 .59804 L
.67051 .57843 L
.67303 .55882 L
.67647 .54159 L
.67713 .53922 L
.68269 .51961 L
.69068 .5 L
.69608 .48953 L
.69806 .48039 L
.71569 .46144 L
.7164 .46078 L
.73529 .45233 L
s
.32353 .30346 m
.34314 .29355 L
.36275 .28972 L
.38235 .29561 L
.38719 .30392 L
.39 .32353 L
.38572 .34314 L
.38235 .35196 L
.37756 .36275 L
.36532 .38235 L
.36275 .3859 L
.34927 .40196 L
.34314 .40793 L
.32757 .42157 L
.32353 .42428 L
.30392 .43664 L
.29362 .44118 L
.28431 .44384 L
.2681 .44118 L
.26471 .43812 L
.2573 .42157 L
.25813 .40196 L
.26295 .38235 L
.26471 .37592 L
.27086 .36275 L
.28285 .34314 L
.28431 .34106 L
.2989 .32353 L
.30392 .31873 L
.32273 .30392 L
.32353 .30346 L
s
.48039 .67358 m
.5 .66707 L
.51961 .66309 L
.53922 .66162 L
.55882 .66251 L
.57843 .66535 L
.59804 .66957 L
.61765 .67463 L
.62419 .67647 L
.63725 .68182 L
.63916 .69608 L
.63725 .70202 L
.6316 .71569 L
.61922 .73529 L
.61765 .73761 L
.59933 .7549 L
.59804 .75591 L
.57843 .76756 L
.55882 .77382 L
.55527 .77451 L
.53922 .77643 L
.51961 .77553 L
.51345 .77451 L
.5 .77131 L
.48039 .76309 L
.46779 .7549 L
.46078 .75227 L
.44663 .73529 L
.44118 .72795 L
.43488 .71569 L
.43878 .69608 L
.44118 .69397 L
.46078 .67951 L
.47393 .67647 L
.48039 .67358 L
s
.26471 .53028 m
.27667 .53922 L
.28431 .54585 L
.29977 .55882 L
.30392 .56232 L
.323 .57843 L
.32353 .58023 L
.34073 .59804 L
.34314 .60078 L
.35572 .61765 L
.36275 .62607 L
.3676 .63725 L
.3771 .65686 L
.37904 .67647 L
.36275 .68904 L
.34314 .68404 L
.32353 .67648 L
.3235 .67647 L
.30392 .66502 L
.29318 .65686 L
.28431 .64775 L
.27547 .63725 L
.26471 .62086 L
.26305 .61765 L
.25362 .59804 L
.24703 .57843 L
.24699 .55882 L
.25001 .53922 L
.26471 .53028 L
s
.71569 .42828 m
.73529 .42235 L
.7549 .4332 L
.76485 .44118 L
.77431 .46078 L
.77451 .46189 L
.78114 .48039 L
.78499 .5 L
.78643 .51961 L
.78581 .53922 L
.78323 .55882 L
.77861 .57843 L
.77451 .59118 L
.77189 .59804 L
.76245 .61765 L
.7549 .62947 L
.74981 .63725 L
.73529 .65216 L
.73291 .65686 L
.71569 .66649 L
.69608 .67483 L
.68945 .67647 L
.67647 .67835 L
.65686 .67658 L
.65662 .67647 L
.65214 .65686 L
.65383 .63725 L
.65559 .61765 L
.65686 .60225 L
.6574 .59804 L
.65963 .57843 L
.66268 .55882 L
.66685 .53922 L
.67228 .51961 L
.67647 .50691 L
.67881 .5 L
.68639 .48039 L
.69537 .46078 L
.69608 .4596 L
.70199 .44118 L
.71569 .42828 L
s
.59804 .29163 m
.61765 .29066 L
.63725 .30037 L
.6433 .30392 L
.65472 .32353 L
.63725 .33997 L
.61765 .3339 L
.60259 .32353 L
.59804 .31858 L
.58765 .30392 L
.59804 .29163 L
s
.34314 .27878 m
.36275 .27294 L
.38235 .27277 L
.40119 .28431 L
.40196 .28539 L
.40766 .30392 L
.40561 .32353 L
.40196 .33636 L
.39954 .34314 L
.39046 .36275 L
.38235 .37693 L
.37864 .38235 L
.36364 .40196 L
.36275 .403 L
.34511 .42157 L
.34314 .42339 L
.32353 .44046 L
.32299 .44118 L
.30392 .45584 L
.29768 .46078 L
.28431 .4702 L
.27305 .48039 L
.26471 .48673 L
.24748 .48039 L
.2451 .47505 L
.2398 .46078 L
.23849 .44118 L
.23981 .42157 L
.24355 .40196 L
.2451 .39476 L
.24958 .38235 L
.25824 .36275 L
.26471 .35077 L
.26962 .34314 L
.28431 .32372 L
.28447 .32353 L
.30384 .30392 L
.30392 .30385 L
.32353 .28907 L
.32935 .28431 L
.34314 .27878 L
s
.34314 .26465 m
.36275 .25754 L
.38235 .2544 L
.40196 .25652 L
.41758 .26471 L
.42157 .2702 L
.42698 .28431 L
.42625 .30392 L
.42157 .32197 L
.42103 .32353 L
.41305 .34314 L
.40319 .36275 L
.40196 .36501 L
.39129 .38235 L
.38235 .39515 L
.37709 .40196 L
.36275 .41873 L
.36016 .42157 L
.34314 .43873 L
.34072 .44118 L
.32353 .45765 L
.32079 .46078 L
.30424 .48039 L
.30392 .48088 L
.29695 .5 L
.29837 .51961 L
.30392 .53376 L
.30761 .53922 L
.32343 .55882 L
.32353 .55896 L
.34138 .57843 L
.34314 .58046 L
.35831 .59804 L
.36275 .60337 L
.37372 .61765 L
.38235 .62856 L
.3887 .63725 L
.40196 .65143 L
.40596 .65686 L
.42157 .66326 L
.44118 .66639 L
.46078 .66359 L
.48039 .65892 L
.48903 .65686 L
.5 .65439 L
.51961 .65117 L
.53922 .64977 L
.55882 .65003 L
.57843 .65121 L
.59804 .65173 L
Mistroke
.61765 .64785 L
.63146 .63725 L
.63725 .62569 L
.64021 .61765 L
.6451 .59804 L
.64883 .57843 L
.65253 .55882 L
.65677 .53922 L
.65686 .53883 L
.66184 .51961 L
.66769 .5 L
.67398 .48039 L
.67647 .4737 L
.67991 .46078 L
.6847 .44118 L
.68699 .42157 L
.68339 .40196 L
.67647 .38969 L
.66489 .38235 L
.65686 .37783 L
.63725 .36931 L
.62178 .36275 L
.61765 .36064 L
.59804 .34959 L
.58903 .34314 L
.57843 .33533 L
.56857 .32353 L
.55882 .30868 L
.55657 .30392 L
.55349 .28431 L
.55882 .27309 L
.57074 .26471 L
.57843 .26206 L
.59804 .26101 L
.6165 .26471 L
.61765 .26498 L
.63725 .27275 L
.65495 .28431 L
.65686 .28552 L
.67585 .30392 L
.67647 .30468 L
.69092 .32353 L
.69608 .32893 L
.70279 .34314 L
.71514 .36275 L
.71569 .36378 L
.73375 .38235 L
.73529 .38369 L
.7549 .40187 L
.755 .40196 L
Mistroke
.77178 .42157 L
.77451 .42778 L
.78163 .44118 L
.78885 .46078 L
.79335 .48039 L
.79412 .48261 L
.7959 .5 L
.79663 .51961 L
.79567 .53922 L
.79412 .55224 L
.79306 .55882 L
.78869 .57843 L
.78243 .59804 L
.77451 .61665 L
.77403 .61765 L
.76307 .63725 L
.7549 .64874 L
.74864 .65686 L
.73529 .67022 L
.72875 .67647 L
.71569 .6855 L
.69805 .69608 L
.69608 .69712 L
.67647 .70812 L
.66548 .71569 L
.65686 .72308 L
.64402 .73529 L
.63725 .74225 L
.62292 .7549 L
.61765 .75922 L
.59804 .77206 L
.59328 .77451 L
.57843 .78078 L
.55882 .78611 L
.53922 .78832 L
.51961 .78761 L
.5 .78401 L
.48039 .77738 L
.4739 .77451 L
.46078 .76785 L
.4415 .7549 L
.44118 .75474 L
.42157 .74015 L
.41558 .73529 L
.40196 .72762 L
.38235 .71726 L
.37835 .71569 L
.36275 .71082 L
.34314 .70361 L
.32587 .69608 L
Mistroke
.32353 .69451 L
.30392 .68248 L
.29565 .67647 L
.28431 .66661 L
.27453 .65686 L
.26471 .64539 L
.25864 .63725 L
.24622 .61765 L
.2451 .61583 L
.23639 .59804 L
.22873 .57843 L
.22549 .5684 L
.22311 .55882 L
.21887 .53922 L
.21617 .51961 L
.21522 .5 L
.21591 .48039 L
.21774 .46078 L
.22054 .44118 L
.22452 .42157 L
.22549 .4172 L
.22987 .40196 L
.23696 .38235 L
.2451 .36432 L
.24595 .36275 L
.25719 .34314 L
.26471 .33196 L
.27107 .32353 L
.28431 .30816 L
.28835 .30392 L
.30392 .28969 L
.31045 .28431 L
.32353 .27536 L
.34301 .26471 L
.34314 .26465 L
Mfstroke
.36275 .24227 m
.38235 .23726 L
.40196 .23564 L
.42157 .23812 L
.43868 .2451 L
.44118 .24673 L
.45593 .26471 L
.45525 .28431 L
.44658 .30392 L
.44118 .31978 L
.43805 .32353 L
.42748 .34314 L
.42157 .35437 L
.41654 .36275 L
.40431 .38235 L
.40196 .38594 L
.39042 .40196 L
.38235 .41224 L
.3745 .42157 L
.36275 .43459 L
.35666 .44118 L
.34314 .45542 L
.33855 .46078 L
.32382 .48039 L
.32353 .48089 L
.31652 .5 L
.31782 .51961 L
.32353 .5334 L
.32699 .53922 L
.34168 .55882 L
.34314 .56064 L
.3584 .57843 L
.36275 .5835 L
.37506 .59804 L
.38235 .60653 L
.39192 .61765 L
.40196 .62772 L
.41259 .63725 L
.42157 .6421 L
.44118 .64809 L
.46078 .64809 L
.48039 .64522 L
.5 .64178 L
.51961 .6391 L
.53922 .63771 L
.55882 .63736 L
.57172 .63725 L
.57843 .63703 L
.59804 .63433 L
.61765 .62307 L
Mistroke
.62229 .61765 L
.63178 .59804 L
.6372 .57843 L
.63725 .5782 L
.64178 .55882 L
.64633 .53922 L
.65122 .51961 L
.65641 .5 L
.65686 .49852 L
.66156 .48039 L
.66573 .46078 L
.66742 .44118 L
.66415 .42157 L
.65686 .40748 L
.65098 .40196 L
.63725 .39146 L
.62148 .38235 L
.61765 .38025 L
.59804 .36919 L
.58776 .36275 L
.57843 .35637 L
.56228 .34314 L
.55882 .34027 L
.54307 .32353 L
.53922 .32107 L
.52841 .30392 L
.51961 .2893 L
.51753 .28431 L
.51798 .26471 L
.51961 .26205 L
.53922 .24566 L
.54376 .2451 L
.55882 .24146 L
.57843 .23995 L
.59804 .24175 L
.61277 .2451 L
.61765 .24651 L
.63725 .25425 L
.65595 .26471 L
.65686 .2653 L
.67647 .27985 L
.68154 .28431 L
.69608 .29844 L
.70105 .30392 L
.71569 .321 L
.71773 .32353 L
.73373 .34314 L
.73529 .34505 L
.75027 .36275 L
.7549 .36838 L
Mistroke
.76626 .38235 L
.77451 .39434 L
.77938 .40196 L
.78956 .42157 L
.79412 .43322 L
.79683 .44118 L
.80201 .46078 L
.80532 .48039 L
.80699 .5 L
.80717 .51961 L
.80589 .53922 L
.80317 .55882 L
.79897 .57843 L
.79412 .59536 L
.7932 .59804 L
.78555 .61765 L
.77583 .63725 L
.77451 .63961 L
.76357 .65686 L
.7549 .6682 L
.74792 .67647 L
.73529 .68902 L
.72742 .69608 L
.71569 .70519 L
.70091 .71569 L
.69608 .71901 L
.67647 .73282 L
.67315 .73529 L
.65686 .74803 L
.64811 .7549 L
.63725 .76325 L
.6206 .77451 L
.61765 .77631 L
.59804 .78654 L
.57843 .79378 L
.57762 .79412 L
.55882 .79825 L
.53922 .80015 L
.51961 .79957 L
.5 .79655 L
.48966 .79412 L
.48039 .79107 L
.46078 .78309 L
.44419 .77451 L
.44118 .77286 L
.42157 .7611 L
.41155 .7549 L
.40196 .74939 L
.38235 .73892 L
.37482 .73529 L
Mistroke
.36275 .72992 L
.34314 .72095 L
.33239 .71569 L
.32353 .71086 L
.30392 .69864 L
.30023 .69608 L
.28431 .68352 L
.27646 .67647 L
.26471 .66453 L
.25798 .65686 L
.2451 .64022 L
.24305 .63725 L
.23068 .61765 L
.22549 .60833 L
.22037 .59804 L
.21171 .57843 L
.20588 .56248 L
.20475 .55882 L
.19953 .53922 L
.19638 .51961 L
.1955 .5 L
.19679 .48039 L
.19985 .46078 L
.20425 .44118 L
.20588 .43469 L
.2097 .42157 L
.21628 .40196 L
.22408 .38235 L
.22549 .37907 L
.23341 .36275 L
.24452 .34314 L
.2451 .3422 L
.25787 .32353 L
.26471 .31468 L
.27388 .30392 L
.28431 .29297 L
.29342 .28431 L
.30392 .27546 L
.31834 .26471 L
.32353 .26136 L
.34314 .25033 L
.35392 .2451 L
.36275 .24227 L
Mfstroke
.48039 .31415 m
.5 .31663 L
.51248 .32353 L
.51961 .32907 L
.53665 .34314 L
.53922 .34559 L
.55882 .36159 L
.56037 .36275 L
.57843 .37554 L
.58907 .38235 L
.59804 .38781 L
.61765 .40008 L
.62036 .40196 L
.63725 .41624 L
.64124 .42157 L
.64968 .44118 L
.65096 .46078 L
.64856 .48039 L
.64439 .5 L
.63959 .51961 L
.63725 .52903 L
.63482 .53922 L
.62998 .55882 L
.62416 .57843 L
.61765 .59367 L
.61544 .59804 L
.59804 .61525 L
.59423 .61765 L
.57843 .62178 L
.55882 .62382 L
.53922 .62486 L
.51961 .62634 L
.5 .62861 L
.48039 .63118 L
.46078 .63263 L
.44118 .63066 L
.42157 .62254 L
.41387 .61765 L
.40196 .60699 L
.393 .59804 L
.38235 .58619 L
.37555 .57843 L
.36275 .56334 L
.35914 .55882 L
.34493 .53922 L
.34314 .53617 L
.33593 .51961 L
.33464 .5 L
.3418 .48039 L
.34314 .47758 L
Mistroke
.35568 .46078 L
.36275 .4522 L
.3726 .44118 L
.38235 .42992 L
.38937 .42157 L
.40196 .40568 L
.4047 .40196 L
.41865 .38235 L
.42157 .37816 L
.43159 .36275 L
.44118 .34927 L
.44445 .34314 L
.46078 .3255 L
.46292 .32353 L
.48039 .31415 L
Mfstroke
.38235 .21977 m
.40196 .21591 L
.42157 .21464 L
.44118 .2159 L
.46078 .21903 L
.48039 .22226 L
.5 .2232 L
.51961 .22186 L
.53922 .22021 L
.55882 .21966 L
.57843 .2208 L
.59804 .22392 L
.60562 .22549 L
.61765 .22919 L
.63725 .23679 L
.65387 .2451 L
.65686 .24683 L
.67647 .25961 L
.68327 .26471 L
.69608 .27524 L
.70602 .28431 L
.71569 .29372 L
.72552 .30392 L
.73529 .31445 L
.74346 .32353 L
.7549 .33661 L
.76042 .34314 L
.77451 .36105 L
.77575 .36275 L
.78857 .38235 L
.79412 .39262 L
.79857 .40196 L
.80617 .42157 L
.81169 .44118 L
.81373 .45042 L
.81548 .46078 L
.81777 .48039 L
.81874 .5 L
.81846 .51961 L
.81696 .53922 L
.81427 .55882 L
.81373 .5621 L
.81016 .57843 L
.80462 .59804 L
.79763 .61765 L
.79412 .62621 L
.78893 .63725 L
.77816 .65686 L
.77451 .66273 L
.76498 .67647 L
Mistroke
.7549 .68906 L
.74871 .69608 L
.73529 .70949 L
.72847 .71569 L
.71569 .7263 L
.704 .73529 L
.69608 .74119 L
.67721 .7549 L
.67647 .75544 L
.65686 .76927 L
.64904 .77451 L
.63725 .78193 L
.61765 .79269 L
.61472 .79412 L
.59804 .80112 L
.57843 .80727 L
.55882 .81117 L
.53922 .81286 L
.51961 .81238 L
.5 .80975 L
.48039 .80502 L
.46078 .79824 L
.45088 .79412 L
.44118 .7896 L
.42157 .77946 L
.41249 .77451 L
.40196 .76873 L
.38235 .7582 L
.37598 .7549 L
.36275 .7482 L
.34314 .73819 L
.33762 .73529 L
.32353 .7274 L
.30484 .71569 L
.30392 .71505 L
.28431 .70039 L
.27913 .69608 L
.26471 .68276 L
.25855 .67647 L
.2451 .66126 L
.24156 .65686 L
.22718 .63725 L
.22549 .63476 L
.21484 .61765 L
.20588 .60163 L
.20405 .59804 L
.19479 .57843 L
.18716 .55882 L
.18627 .55647 L
.18156 .53922 L
Mistroke
.17825 .51961 L
.17741 .5 L
.17896 .48039 L
.18259 .46078 L
.18627 .44617 L
.18783 .44118 L
.19433 .42157 L
.20179 .40196 L
.20588 .392 L
.21023 .38235 L
.2199 .36275 L
.22549 .35237 L
.23098 .34314 L
.24386 .32353 L
.2451 .32177 L
.25898 .30392 L
.26471 .29723 L
.2768 .28431 L
.28431 .27703 L
.29828 .26471 L
.30392 .26023 L
.32353 .24628 L
.32532 .2451 L
.34314 .23501 L
.36275 .22613 L
.36388 .22549 L
.38235 .21977 L
Mfstroke
.46078 .35471 m
.48039 .34403 L
.5 .34519 L
.51961 .35505 L
.53159 .36275 L
.53922 .36868 L
.55844 .38235 L
.55882 .38262 L
.57843 .39557 L
.58828 .40196 L
.59804 .40829 L
.61477 .42157 L
.61765 .42398 L
.62925 .44118 L
.63406 .46078 L
.63364 .48039 L
.63062 .5 L
.62633 .51961 L
.62131 .53922 L
.61765 .55179 L
.61557 .55882 L
.60755 .57843 L
.59804 .5913 L
.59076 .59804 L
.57843 .60376 L
.55882 .60818 L
.53922 .61014 L
.51961 .61179 L
.5 .61373 L
.48039 .61551 L
.46078 .61573 L
.44118 .61208 L
.42157 .6021 L
.41578 .59804 L
.40196 .58543 L
.39509 .57843 L
.38235 .56406 L
.37807 .55882 L
.36388 .53922 L
.36275 .53729 L
.35483 .51961 L
.35352 .5 L
.36063 .48039 L
.36275 .47598 L
.37399 .46078 L
.38235 .45025 L
.39007 .44118 L
.40196 .42678 L
.4061 .42157 L
.42136 .40196 L
Mistroke
.42157 .40169 L
.43588 .38235 L
.44118 .37587 L
.45098 .36275 L
.46078 .35471 L
Mfstroke
.38235 .20045 m
.40196 .19502 L
.42157 .19165 L
.44118 .19029 L
.46078 .19063 L
.48039 .19203 L
.5 .19368 L
.51961 .19512 L
.53922 .19651 L
.55882 .19834 L
.57843 .2011 L
.59804 .20515 L
.60111 .20588 L
.61765 .21084 L
.63725 .21834 L
.65264 .22549 L
.65686 .22774 L
.67647 .23936 L
.68506 .2451 L
.69608 .25317 L
.71044 .26471 L
.71569 .2692 L
.73229 .28431 L
.73529 .28718 L
.75213 .30392 L
.7549 .3068 L
.77028 .32353 L
.77451 .32845 L
.78619 .34314 L
.79412 .35443 L
.79932 .36275 L
.80968 .38235 L
.81373 .39166 L
.81755 .40196 L
.82337 .42157 L
.82755 .44118 L
.83033 .46078 L
.83187 .48039 L
.83227 .5 L
.83157 .51961 L
.82978 .53922 L
.82687 .55882 L
.82284 .57843 L
.8177 .59804 L
.81373 .61104 L
.81133 .61765 L
.80329 .63725 L
.79412 .6564 L
.79387 .65686 L
.78236 .67647 L
Mistroke
.77451 .68825 L
.76876 .69608 L
.7549 .71294 L
.75244 .71569 L
.73529 .733 L
.73281 .73529 L
.71569 .74993 L
.70939 .7549 L
.69608 .76481 L
.68218 .77451 L
.67647 .77827 L
.65686 .79045 L
.65049 .79412 L
.63725 .80109 L
.61765 .81009 L
.60844 .81373 L
.59804 .81717 L
.57843 .82235 L
.55882 .8257 L
.53922 .82718 L
.51961 .82679 L
.5 .82454 L
.48039 .82048 L
.46078 .81473 L
.45781 .81373 L
.44118 .80718 L
.42157 .79826 L
.41309 .79412 L
.40196 .78838 L
.38235 .77805 L
.37562 .77451 L
.36275 .76761 L
.34314 .75696 L
.33941 .7549 L
.32353 .7456 L
.30712 .73529 L
.30392 .73312 L
.28431 .71879 L
.28038 .71569 L
.26471 .70212 L
.25829 .69608 L
.2451 .68252 L
.2397 .67647 L
.22549 .65927 L
.22367 .65686 L
.20963 .63725 L
.20588 .63168 L
.19716 .61765 L
.18627 .59872 L
.18592 .59804 L
Mistroke
.1763 .57843 L
.16835 .55882 L
.16667 .55427 L
.16268 .53922 L
.15939 .51961 L
.1586 .5 L
.16025 .48039 L
.1641 .46078 L
.16667 .4509 L
.16984 .44118 L
.17706 .42157 L
.1852 .40196 L
.18627 .39947 L
.19435 .38235 L
.20429 .36275 L
.20588 .35971 L
.21551 .34314 L
.22549 .3272 L
.228 .32353 L
.24239 .30392 L
.2451 .30046 L
.25893 .28431 L
.26471 .27808 L
.27814 .26471 L
.28431 .25907 L
.30093 .2451 L
.30392 .24282 L
.32353 .22902 L
.32902 .22549 L
.34314 .21748 L
.36275 .20789 L
.36721 .20588 L
.38235 .20045 L
Mfstroke
.48039 .37378 m
.5 .37387 L
.51961 .38217 L
.51998 .38235 L
.53922 .39409 L
.55127 .40196 L
.55882 .4069 L
.57843 .42027 L
.58019 .42157 L
.59804 .43644 L
.60191 .44118 L
.61216 .46078 L
.61456 .48039 L
.61297 .5 L
.60917 .51961 L
.60356 .53922 L
.59804 .5531 L
.59556 .55882 L
.57884 .57843 L
.57843 .57871 L
.55882 .58772 L
.53922 .59134 L
.51961 .59342 L
.5 .59512 L
.48039 .59615 L
.46078 .5951 L
.44118 .58961 L
.42259 .57843 L
.42157 .57746 L
.40207 .55882 L
.40196 .55871 L
.3867 .53922 L
.38235 .53149 L
.37737 .51961 L
.37595 .5 L
.38235 .48184 L
.38309 .48039 L
.39611 .46078 L
.40196 .45307 L
.41154 .44118 L
.42157 .42888 L
.42722 .42157 L
.44118 .40497 L
.44313 .40196 L
.46078 .38475 L
.46386 .38235 L
.48039 .37378 L
s
.42157 .1653 m
.44118 .16254 L
.46078 .16161 L
.48039 .16232 L
.5 .16425 L
.51802 .16667 L
.51961 .16692 L
.53922 .17008 L
.55882 .17366 L
.57843 .17782 L
.59804 .18275 L
.61029 .18627 L
.61765 .18877 L
.63725 .19631 L
.65686 .20517 L
.65833 .20588 L
.67647 .21594 L
.69194 .22549 L
.69608 .22829 L
.71569 .24248 L
.7191 .2451 L
.73529 .25826 L
.74287 .26471 L
.7549 .27541 L
.7645 .28431 L
.77451 .2941 L
.78395 .30392 L
.79412 .31541 L
.80063 .32353 L
.81373 .34221 L
.81429 .34314 L
.82495 .36275 L
.83327 .38235 L
.83333 .38254 L
.83927 .40196 L
.84368 .42157 L
.8467 .44118 L
.84853 .46078 L
.8493 .48039 L
.84908 .5 L
.84794 .51961 L
.84586 .53922 L
.84286 .55882 L
.83898 .57843 L
.83434 .59804 L
.83333 .60199 L
.82825 .61765 L
.82093 .63725 L
.81373 .65469 L
.81269 .65686 L
Mistroke
.80255 .67647 L
.79412 .6913 L
.79109 .69608 L
.77755 .71569 L
.77451 .71977 L
.76176 .73529 L
.7549 .74291 L
.74313 .7549 L
.73529 .76218 L
.72079 .77451 L
.71569 .77846 L
.69608 .7924 L
.69346 .79412 L
.67647 .80432 L
.65899 .81373 L
.65686 .81475 L
.63725 .82351 L
.61765 .83101 L
.61071 .83333 L
.59804 .83681 L
.57843 .8411 L
.55882 .84394 L
.53922 .84522 L
.51961 .84491 L
.5 .84301 L
.48039 .83957 L
.46078 .83471 L
.45599 .83333 L
.44118 .82816 L
.42157 .82023 L
.40696 .81373 L
.40196 .81129 L
.38235 .80128 L
.36868 .79412 L
.36275 .79083 L
.34314 .77971 L
.3341 .77451 L
.32353 .768 L
.30392 .75539 L
.30319 .7549 L
.28431 .74119 L
.27662 .73529 L
.26471 .72532 L
.25391 .71569 L
.2451 .7072 L
.23433 .69608 L
.22549 .68635 L
.21717 .67647 L
.20588 .66242 L
.20178 .65686 L
Mistroke
.18769 .63725 L
.18627 .63521 L
.17501 .61765 L
.16667 .60395 L
.16345 .59804 L
.15357 .57843 L
.14706 .56297 L
.14566 .55882 L
.1402 .53922 L
.13706 .51961 L
.13634 .5 L
.13801 .48039 L
.1419 .46078 L
.14706 .44296 L
.14771 .44118 L
.15546 .42157 L
.16425 .40196 L
.16667 .39673 L
.17404 .38235 L
.18443 .36275 L
.18627 .35928 L
.19586 .34314 L
.20588 .32681 L
.20809 .32353 L
.22192 .30392 L
.22549 .29905 L
.23737 .28431 L
.2451 .27524 L
.25479 .26471 L
.26471 .25462 L
.27471 .2451 L
.28431 .23666 L
.29782 .22549 L
.30392 .22091 L
.32353 .20706 L
.32531 .20588 L
.34314 .19527 L
.36003 .18627 L
.36275 .18502 L
.38235 .1767 L
.40196 .17003 L
.41426 .16667 L
.42157 .1653 L
Mfstroke
.48039 .41458 m
.5 .41308 L
.51961 .42016 L
.52283 .42157 L
.53922 .43104 L
.55361 .44118 L
.55882 .44473 L
.57389 .46078 L
.57843 .46882 L
.58258 .48039 L
.58369 .5 L
.57951 .51961 L
.57843 .52341 L
.57119 .53922 L
.55882 .55171 L
.54308 .55882 L
.53922 .55994 L
.51961 .56399 L
.5 .56595 L
.48039 .56611 L
.46078 .56288 L
.45029 .55882 L
.44118 .55457 L
.4239 .53922 L
.42157 .53582 L
.41189 .51961 L
.40979 .5 L
.41709 .48039 L
.42157 .47151 L
.42992 .46078 L
.44118 .44703 L
.44556 .44118 L
.46078 .42678 L
.46762 .42157 L
.48039 .41458 L
s
.42157 .12679 m
.44118 .12322 L
.46078 .12149 L
.48039 .12165 L
.5 .12356 L
.51961 .12685 L
.52269 .12745 L
.53922 .13143 L
.55882 .13676 L
.57843 .14244 L
.5942 .14706 L
.59804 .14835 L
.61765 .15537 L
.63725 .16293 L
.64669 .16667 L
.65686 .17147 L
.67647 .18142 L
.68578 .18627 L
.69608 .19246 L
.71569 .20476 L
.71744 .20588 L
.73529 .21851 L
.74501 .22549 L
.7549 .23307 L
.77025 .2451 L
.77451 .24862 L
.79315 .26471 L
.79412 .2656 L
.81297 .28431 L
.81373 .28513 L
.8293 .30392 L
.83333 .30941 L
.84233 .32353 L
.85291 .34314 L
.85294 .34321 L
.86066 .36275 L
.86683 .38235 L
.87143 .40196 L
.87255 .4078 L
.87425 .42157 L
.87585 .44118 L
.87651 .46078 L
.87634 .48039 L
.87547 .5 L
.87403 .51961 L
.87255 .53561 L
.87201 .53922 L
.8687 .55882 L
.8646 .57843 L
.85983 .59804 L
Mistroke
.85472 .61765 L
.85294 .62454 L
.84836 .63725 L
.84066 .65686 L
.83333 .67517 L
.83271 .67647 L
.82264 .69608 L
.81373 .71287 L
.81201 .71569 L
.79937 .73529 L
.79412 .74311 L
.78522 .7549 L
.77451 .76814 L
.76887 .77451 L
.7549 .78894 L
.74943 .79412 L
.73529 .80615 L
.72548 .81373 L
.71569 .82037 L
.69608 .83232 L
.69425 .83333 L
.67647 .84188 L
.65686 .85023 L
.64978 .85294 L
.63725 .85687 L
.61765 .86243 L
.59804 .8671 L
.57843 .87069 L
.56515 .87255 L
.55882 .87297 L
.53922 .87386 L
.51961 .87367 L
.50176 .87255 L
.5 .87235 L
.48039 .86938 L
.46078 .86506 L
.44118 .85953 L
.42157 .85316 L
.42093 .85294 L
.40196 .84487 L
.38235 .83579 L
.37712 .83333 L
.36275 .82551 L
.34314 .81459 L
.34157 .81373 L
.32353 .80238 L
.31032 .79412 L
.30392 .78969 L
.28431 .77583 L
.28244 .77451 L
Mistroke
.26471 .76044 L
.25783 .7549 L
.2451 .74364 L
.236 .73529 L
.22549 .72498 L
.21654 .71569 L
.20588 .70418 L
.19892 .69608 L
.18627 .68125 L
.18257 .67647 L
.167 .65686 L
.16667 .65643 L
.15278 .63725 L
.14706 .6293 L
.13959 .61765 L
.12767 .59804 L
.12745 .59764 L
.11844 .57843 L
.11104 .55882 L
.10784 .54819 L
.10615 .53922 L
.1036 .51961 L
.10306 .5 L
.10454 .48039 L
.10784 .46094 L
.1079 .46078 L
.1138 .44118 L
.12152 .42157 L
.12745 .40803 L
.1306 .40196 L
.14131 .38235 L
.14706 .37163 L
.15247 .36275 L
.1643 .34314 L
.16667 .33899 L
.17693 .32353 L
.18627 .30906 L
.18998 .30392 L
.20436 .28431 L
.20588 .28222 L
.22032 .26471 L
.22549 .25854 L
.23776 .2451 L
.2451 .23741 L
.25715 .22549 L
.26471 .21851 L
.27887 .20588 L
.28431 .20148 L
.30342 .18627 L
.30392 .18592 L
Mistroke
.32353 .1723 L
.33194 .16667 L
.34314 .16009 L
.36275 .14908 L
.36662 .14706 L
.38235 .14009 L
.40196 .13252 L
.41857 .12745 L
.42157 .12679 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0_l00012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`00
0011ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Pooo
ool3o`0000;ooooo1?nY_NP00ol0003oooooo`000010ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0P?ooool3o`0000;ooooo1onY_NP00ol0003oooooo`00
0010ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0O_oo
ool2o`0000?ooooo2OnY_NP01?l0003oZKgXooooool0000oooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0Noooool3o`0000;ooooo3?nY_NP01Ol0003oZKgX
oooooooooooo000003kooooo0009ooooo`0400000?ooooooooooooooodP000000_l00004000000P0
6ATIE`000004ooooo`0300000?oooooooooo07Wooooo0_l00003ooooo`koZKgX00Go0000ojVmj?nY
_NSoooooo`00000nooooo`002Oooool01000003ooooooooooooooom7000001H06ATID0000004oooo
o`0300000?oooooooooo07Kooooo0ol00002oooooa7oZKgX00Ko0000ojVmj?nY_NSoZKgXooooool0
000mooooo`002Oooool01000003ooooooooooooooom4000001`06ATIC@000004ooooo`0300000?oo
oooooooo07Cooooo0_l00002oooooaCoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003ooooooooo
o`0kooooo`002Oooool01000003ooooooooooooooom3000002406ATIB@000004ooooo`0300000?oo
oooooooo077ooooo0ol00002oooooaKoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003ooooooooo
o`0jooooo`002Oooool01000003oooooooooooooooln00000003o`0000000000000002H06ATI00?o
0000000000000000@`000004ooooo`0300000?oooooooooo06kooooo0ol00002oooooaWoZKgX00?o
0000ojVmj?nY_NP00onY_NP00ooooooo0000ooooo`0jooooo`002Oooool01000003ooooooooooooo
oolm000002h06ATI@P000004ooooo`0300000?oooooooooo06cooooo0_l00003oooooacoZKgX00?o
0000ojVmj?nY_NP00onY_NP00ol0003oooooooooo`0iooooo`002Oooool01000003ooooooooooooo
ooll000003406ATI@0000004ooooo`0300000?oooooooooo06Wooooo0ol00002oooooaooZKgX00?o
0000ojVmj?nY_NP00onY_NP00ooooooo0000ooooo`0iooooo`002Oooool01000003ooooooooooooo
oolj000000`06ATI5`00000B01TI6@03o`0000000000000003/000001?ooool00`00003ooooooooo
o`1Wooooo`;o00000ooooolQojVmj003o`000?nY_NSoZKgX00CoZKgX00?oooooo`000?ooool0>?oo
ool000Wooooo00@00000oooooooooooooooo>000000<01TI6@8000005`0c<c<3000001806ATI>`00
0004ooooo`0300000?oooooooooo06Cooooo0ol00002ooooobCoZKgX00?o0000ojVmj?nY_NP01?nY
_NP00ooooooo0000ooooo`0hooooo`002Oooool01000003ooooooooooooooolg000000X06ATI0`00
000L03<c<`L000003@0I6ATi000000Cooooo00<00000ooooooooool0H_ooool2o`0000?ooooo9_nY
_NP00ol0003oZKgXojVmj005ojVmj003ooooool0003ooooo03Oooooo0009ooooo`0400000?oooooo
ooooooooocH000002@0I6AT2000002H0<c<c0`00000<01TI6@03o`0000000000000003@000001?oo
ool00`00003oooooooooo`1Oooooo`?o00000_oooolYojVmj003o`000?nY_NSoZKgX00KoZKgX00?o
ooooo`000?ooool0=_ooool000Wooooo00@00000oooooooooooooooo=@00000801TI6@800000:`0c
<c<00ol0000000000000000:01TI6CH000001?ooool00`00003oooooooooo`1Mooooo`;o00000ooo
ool[ojVmj003o`000?nY_NSoZKgX00OoZKgX00?o0000ooooooooool0=Oooool000Wooooo00@00000
oooooooooooooooo<`00000701TI6@<000001`0c<c<I00000100<c<c0P00000:01TI6C@000001?oo
ool00`00003oooooooooo`1Jooooo`?o00000_ooool2ojVmiaGoZKgX00?oZKgWojVmj?nY_NP00onY
_NP2ojVmi`ooZKgX00?o0000ojVmj?nY_NP02?nY_NP00ol0003oooooooooo`0dooooo`002Oooool0
1000003ooooooooooooooolb000000L06ATI00<0000003<c<`0c<c<01@0c<c<3000001T0C4a<1`00
000;03<c<`<000002@0I6ATb000000Cooooo00<00000ooooooooool0Eoooool3o`0000?ooooo1OnY
_NL00onY_NSoZKgWojVmj004ojVmj0?oZKgW1?nY_NP2ojVmi`03ojVmj?nY_NOoZKgW00?oZKgW0_nY
_NP5ojVmi`03ojVmj?nY_NOoZKgX00CoZKgX0_nY_NL5ojVmj003o`000?nY_NSoZKgX00SoZKgX00?o
ooooo`000?ooool0=?ooool000Wooooo00@00000oooooooooooooooo;`0000000ol00000000001TI
6@0601TI6@030000000c<c<0<c<c00@0<c<c0P00000S04a<C0L000001`0c<c<00ol0000000000000
000801TI6C0000001?ooool00`00003oooooooooo`1Eooooo`;o00000oooool2ojZli`GoZKgW00Co
Z[cWojVmionY_NOoZKgW0_nY_NP2ojVli`;oZKgW00?oZ[cWojVlionY_>L00_nY_>L00onY_NOoZ[cW
ojVmi`04ojVmi`;oZKcW1OnY_NL01?nY_>OoZKgWojVmionY_NL2ojVmj003ojZmionY_NOoZKgW00;o
ZKgW00GoZKgXojZmionY_NSoZKgXo`00000;ojVmj003o`000?oooooooooo03?ooooo0009ooooo`04
00000?oooooooooooooooc0000001P0I6AT00`00003o000003<c<`0403<c<`0300000?l00000C4a<
02/0C4a<0P00000803<c<`030000000I6AT06ATI00H06ATI;`000004ooooo`0300000?oooooooooo
05;ooooo0ol00003ooooo`GoZ[cW00?oZKgWojZlionZ_>L00onZ_>L01OnY_NOoZ[cWojZlionZ_>Oo
ZKcW00;oZ[_V0onZ_>L2ojVli`04ojZli_nZ_>OoZ[cWojZli`;oZKgW00?oZ[cVojVlionY_>L00_nY
_>L00onY_NOoZ[cWojVli`03ojVli`03ojVmionZ_>OoZ[cW00?oZ[gW0_nY_NL4ojZmi`04ojVmj?l0
003oZ[gWojZmi`;oZKgX00?oZ[gXojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`0cooooo`002Ooo
ool01000003oooooooooooooool_000000H06ATI00<0000003<c<`0c<c<00P0c<c<3000000L0C4a<
2`00000N04a<C08000001`0c<c<00`0000006ATI01TI6@0601TI6Bh000001?ooool00`00003ooooo
ooooo`1@ooooo`;o00001?ooool00onZ_>KoZ[cWojZli`03ojZli`03ojZli_nZ_>OoZ[cW00?oZ[cW
0_nZ_>H2ojZli`03ojZkiOnZ^nKoZ[_V00;oZ[_V00?oZ[cWojZkiOnZ_>H00onZ_>H00onZ_>OoZ[_V
ojZkiP03ojZliP;oZKcW00CoZ[_VojZlionZ_>OoZ[cW0_nY_>L00onZ_>KoZ[cWojZli`02ojZli`03
ojZmionZ_>OoZ[cW00;oZ[gW00GoZ[cWojZmionZ_NOoZ[gWo`000002ojZmi`CoZ[gX1_nY_NP00ol0
003oooooooooo`0booooo`002Oooool01000003oooooooooooooool^000000H06ATI00<0000003<c
<`0c<c<00P0c<c<00`000000C4a<04a<C00404a<C0@000002`1VIVHH000000P0C4a<0`00000503<c
<`030000000I6AT06ATI00H06ATI;@000004ooooo`0300000?oooooooooo04gooooo0ol00003oooo
o`;oZK_V0onZ_>H01?nZ_>OoZ[_VojZki_nZ^nH2ojZliP;oZ[cW0_nZ^nH00onZ_>KoZ[[TojZji003
ojZki@;oZ[_V00CoZ[WTojZkiOnZ^nGoZ[_U0_nZ_>H00onZ^^CoZ[_VojZkiP02ojZkiP03ojZli_nZ
^^GoZ[_V00?oZ[_V00?oZ[cWojZkiOnZ^nD00onZ_>H2ojZli`;oZ[_V00?oZ[cWoj^ki_nZ_>L00onZ
_>L2ojZmi`04o`000?nZ_NOoZ[gWojZmi`;oZ[gX00?oZ[gWojVmj?nY_NP01?nY_NP00ooooooo0000
ooooo`0booooo`002Oooool01000003oooooooooooooool/000000H06ATI00<00000o`00000c<c<0
0P0c<c<00ol00000000004a<C00304a<C0<000009`1VIVH01000003o000000000000000704a<C080
0000100c<c<00ol0000000000000000701TI6B/000001?ooool00`00003oooooooooo`1;ooooo`;o
00001?ooool5ojVkiP03ojZli_nZ^^GoZ[[U00;oZ[_V00?oZkWTojZjiOnZ^^D00_nZ^^D00onZ^nKo
ZkWSojZji003ojZji003ojZkiOn[^>?oZkSS00?oZ[WT00?oZ[_Uoj^hhon[^><00onZ^^@2ojZkiP04
oj^hhonZ^^GoZ[[UojZji@;oZ[_V00?oZkWTojZkiOnZ^nD00_nZ^nD00onZ_>KoZk[Uoj^ji@02ojZk
iP04oj^ji?n[^nKoZk_Voj^kiP;oZ[cW00GoZk_VojZlionZ_>Oo0000ojZli`06ojZmi`03ojVmj?nZ
_NSoZ[gX00?oZKgX00?oooooo`000?ooool0<Oooool000Wooooo00@00000oooooooooooooooo:`00
000601TI6@030000000c<c<0<c<c0080<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0/06IVIP<000001P1<C4`2000000D0<c<c00<0000001TI6@0I6AT01P0I6ATY000000Cooooo00<0
0000ooooooooool0B?ooool3o`0000?ooooo0onY^^H4ojVkiP;oZ[WU00?oZ[[Uoj^hhon[^><00on[
^N@2ojZji@04oj^gh_n[^N?oZkWSoj^ih`;oZ[[T00?oZkKQoj^hhon[^><00_n[^><00onZ^NCoZkKP
oj^hh`03oj^hh`03ojZji?n[]^7oZkSS00?oZkSS00?oZ[[Uoj^gh_n[]n800on[^N@2ojZki@;oZkWS
00?oZk[Uojbhh_n/^>800on[^^@00on[^nKo[;[Tojbji003oj^kiP03ojZliol0003oZkcV00KoZ[gW
1?nZ_NP3ojVmj003o`000?oooooooooo033ooooo0009ooooo`0400000?ooooooooooooooobX00000
1P0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<0P00000406IVIP`00000
5`1VIVH4000000L0IVIV1000000404a<C003o`00000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT0
1P0I6ATX000000Cooooo00<00000ooooooooool0AOooool3o`0000Cooooo1?nY^^H00onY^>CoZ[WT
ojZii002ojZii003ojZiiOnZ]n;oZkSS00?oZkSS00?oZkWToj^eh?n[]N000on[]n800on[^N?o[;CO
ojbdg`03oj^fh@;oZkSS00Co[;?Noj^fh?n[]^3oZkKP0_n[^><01?n//mkoZkKQoj^fhOn[]^42oj^h
h`03ojbdgon[]n;oZkOR00;oZkOR00?oZkWTojbfhOn/]^400_n[^N<00on]]Moo[;SRojbhhP02ojbh
hP03oj^ji?n/^>;o[;[T00?o[;[T00CoZk_Vojbki?n[_>Ko00000_n[_>H01?nZ_NOoZkcVoj^li_n[
_>H2ojZmi`;oZ[gX0_nZ_NL01?nY_NSoZ[gXooooool0000aooooo`002Oooool01000003ooooooooo
oooooolX00000003o`00000I6AT06ATI00@06ATI00Ko000003<c<`0c<c<0<c<co`000000000304a<
C08000000P1VIVH01000003o0000o`000000000<07moO`03o`00001VIVH0IVIV00h0IVIV00?o0000
0000000000000`00000407moO`<0000000?o000006IVIP1VIVH01@1VIVH00ol00000C4a<04a<C002
04a<C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AT00ol0000000000000000T
000000Cooooo00<00000ooooooooool0@oooool2o`0000;ooooo0_nY^nH4ojVjiPGoZKST0_nZ^N@0
1?nZ]N7oZ[ORojZgh_nZ]n82oj^hh`03oj^cgon[]N3oZkGP00;oZkGP00?oZkORojbbgOn/]=l00on/
]=l00on[]^7o[;3KojbcgP03ojbcgP03oj^fh?n/[m[o[:oJ00?o[;?N00?oZkKQojfafon]/M/00on/
]=l2oj^ghP;o[K?M00?o[;KQojjbfon^/]/00on]]Ml2ojbhhP04ojfeg_n/^>;o[;SRojbhhP;o[;[T
00Ko[KWRojbki?n/^nCo[;_To`000?n[_>H2ojbki@;oZkcV00Co[;cVoj^mion[_NOoZkgW0onZ_NL3
ojZmj003ooooool0003ooooo02oooooo0009ooooo`0400000?ooooooooooooooobT000001@0I6AT0
1@000000<c<c03<c<`0c<c<0000000<0C4a<00@00000o`00001VIVH0IVIV0P00000@07moO`030000
001VIVH0IVIV00d0IVIV00<0000007moO`1oOgl0301oOgl3000000@0IVIV0P00000404a<C0030000
000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6ATV000000Cooooo00<00000ooooooooool0
@?ooool3o`0000;ooooo1OnY^nH00onY^^KoZ;STojRhi004ojVhi0;oZKCP0onZ]N400onZ]n;oZk;M
oj^bg@03oj^cg`;oZkGP00Co[:oJojbbgOn//]go[;;M0_n/]=l01?n/[MSo[;3Kojb`fon//=/2ojbc
gP03ojf[e_n/[m[o[:oJ00;o[:oJ00?o[;?Nojj/e_n]/M/00on]/M/00on/]=oo[ZoHojfcg@02ojfc
g@03ojn]e_n^/]_o[[;K00;o[[;K00?o[KGOojnaf_n]]Mh00on]]Mh00on/^>;o[[KNojfihP03ojfi
hP06ojbki?n]^^;o0000ojfjh_n/^nGo[K_T1?n/_>H00on[_NOoZkgVojZmi`03ojZmi`;oZ[gX00?o
ooooo`000?ooool0;oooool000Wooooo00@00000oooooooooooooooo:000000501TI6@050000000c
<c<0<c<c03<c<`0000000`1<C4`00`000000IVIV06IVIP02000000H0Ogmo1`00000607moO`030000
001VIVH0IVIV00/0IVIV00<0000007moO`1oOgl0401oOgl3000000<0IVIV0P00000304a<C0800000
100c<c<00`0000006ATI01TI6@0601TI6BD000001?ooool00`00003oooooooooo`0nooooo`;o0000
0oooool00onY^nOoZK_VojVkiP03ojVkiPGoZ;ST00?oZKSTojRch?nY]>000onY]>000onZ]N7oZ[3L
oj^bg@03oj^bg@03oj^cgon/[MSo[:gH00?o[:oJ00?o[;;MojbZeOn/Z]D00on/[MP00on//=_o[JOB
ojfWdP03ojf[eP;o[:oJ00Co[ZOAojj/e_n^[=Ko[ZcF0_n]/M/01On_ZM;o[ZoHojj_f?n^[mSo[K?M
00?o[jgF0_n^/]/01?n`[=Co[k7Jojnaf_n_/MX2ojfegP04ok2afOn^]]ko[[KNojjfgP;o[KWR00Go
[kONojfjh_n]^^;o0000ok2ih003ojfki0;o[;cV00Co[KcUoj^mi_n[_NKoZkgV0_nZ_NL01_n[_NOo
Z[gXojZmj?nZ_NSoooooo`0002oooooo0009ooooo`0400000?ooooooooooooooobL000001@0I6AT0
1@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVH000001@1oOgl3000000L0VIVI
00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0906IVIP030000001oOgl0Ogmo00L0Ogmo
1`00000607moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00P1<C4`00`000000<c<c
03<c<`0203<c<`8000001`0I6ATT000000Cooooo00<00000ooooooooool0>oooool3o`0000;ooooo
0_nY_>L3ojVki`03ojVki_nX^NGoZ;WU00GoZ;ST00CoZ;?QojRch?nX/n3oZ;?P0_nY]>001?nY[]_o
Z[3LojZ`g?nZ/=`2oj^bg@03oj^[eon/[MSo[:gH00;o[:gH00?o[:oJojbWd_n/Z]D00on/Z]D00on/
[MSo[:?>ojfWdP03ojfWdP03ojf[e_n^X/co[ZOA00?o[ZOA00?o[ZcFojnTc?n_Y<`00on_ZM800on^
[mSo/:S@ok2Xd003ojn]eP06ojjbfon`[=Co/:cDok2/e?n_/M[o/JcC1?n`/MT00on^]]ko/K?Iok6c
f@03ojnggP06ojfjh_l0003o/;WPok2ih?n]^nCo[k_R1?n]_>D00on[_NKo[;gVoj^mi`03oj^mi`05
ojZmj?nZ_NOoZ[gWooooool00000;_ooool000Wooooo00@00000oooooooooooooooo9@0000000ol0
00006ATI01TI6@0301TI6@050000000c<c<0<c<c03<c<ol000000P1<C4`01@00003o000006IVIP1V
IVKo000000<0Ogmo00<00000o`00000000002`2IVIT00ol00000Ogmo07moO`0407moO`030000001V
IVH0IVIV00P0IVIV00?o000007moO`1oOgl01@1oOgl00`00003o000009VIV@0609VIV@<00000101o
Ogl2000000<0IVIV00<0000004a<C01<C4`00P1<C4`00ol00000<c<c03<c<`0303<c<`030000000I
6AT06ATI00D06ATI00?o000000000000000080000004ooooo`0300000?oooooooooo03Wooooo0_l0
0003ooooo`GoZKcW00?oZK_WojRii_nX^NH00onX^ND00onX^>CoYk?QojNch@03ojRch@03ojRch?nX
[M_oZ:gK00?oZJkK00?oZ[3LojZXeOn[ZmL00on[ZmL2ojb]f004ojbUd?n/Ym;o[:OBojbWdP;o[:[E
00Co[:3;ojbSc_n/Xlko[:?>0_n]Ym801?n]WLOo[Z;<ojjRc?n^X/`2ojjWd@03ojnNa_n_Y<co[jC<
00;o[jC<00?o[jWBok6RbOn`Z=000on`Z=000on_[MKo/JO>ok2/e002ok2/e004ok:Vc?na[=?o/JcC
ok6/d`;o/;7I00?o/jgCok6cfOna/mT00_na/mT01_n_]mko/[GKok:efol0003o/;WPok:hg@?o[k_R
0_n]_>D01?n^_>Co[;gVojbmi_n/_NH4oj^mi`?oZ[gW00?o0000ooooooooool0;?ooool000Wooooo
00@00000oooooooooooooooo9@00000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01@00
0000IVIV06IVIP1VIVH000000080Ogmo0P00000309VIV@Oo00001@2IVIT00`000000Ogmo07moO`03
07moO`030000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0:
09VIV@<000000`1oOgl200000080IVIV00<0000004a<C01<C4`00P1<C4`2000000@0<c<c00<00000
01TI6@0I6AT01P0I6ATQ000000Cooooo00<00000ooooooooool0=_ooool3o`0000?ooooo00?oZKgX
ojVlionY_>L00onY_>L00onX^^KoZ;WVojRiiP02ojRiiP03ojRiiOnW]>;oYk?Q00?oYk?Q00?oZ;?Q
ojN/fonX[M/00onX[M/00onY[]_oZJKDojZXe@02ojZXe@?oZj_G1?n/YM02ojbWdP04ojbZeOn/X<_o
[:3;ojbPb`;o[:?>00Co[JOBojfMaon]WLOo[Ig70_n^X/`01?n^Ym7o[ik6ojnNa_n_W/H2ojnTc004
ok6K`_naX/Wo/J;9ok6Rb@;o/:S@00Go/Z76ok6Wc_naYlko/JO>ok2/e003ok:Vc0;o/JcC1?nc[M<2
ok6cf@05okB`e?nb]M_o/[GKok:efol000000onb^=d00on_^n;o/K[Pojjli003ojjli003ojbmi_n]
_NKo[KgV00?oZkgW1?nZ_NL00ol0003oooooooooo`0[ooooo`002Oooool01000003ooooooooooooo
oolT000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH0IVIV00800000
00<0Ogmo0000000000000P2IVIT3o`0000L0/k>c00?o000009VIV@2IVIT00P2IVIT00`000000Ogmo
07moO`0307moO`030000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI
09VIV@0=09VIV@030000001oOgl0Ogmo0080Ogmo00?o000006IVIP1VIVH00P00000404a<C0030000
000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT01P0I6ATP000000Cooooo00<00000ooooooooool0
<oooool3o`0000Cooooo1?nY_NP2ojVli`;oZ;_W0_nX^^H2ojRiiP04ojNfhonW]>;oYkCRojNdhP;o
Yk?Q00CoYJgLojN/fonW[=_oYjcK0_nX[M/01?nWYMCoZJKDojVVe?nYY]@3ojZXe@03oj^[eon[X/ko
Zj;>00?o[:G@00?o[:OBoj^Mb?n[WLP00on/X</00on/Xlko[9W3ojfMa`03ojfMa`03ojjRc?n^V<3o
[ik600?o[ik600Co[jC<ok6K`_naVl;o/I_20_naX/T4ok:QaP03ok6Wc_ndXLGo]:7500?o/ZK<00?o
/JcCokBWc?ndYl`00onc[M<4okB`e003ok:efonf/mOo000000;o/[SM00Co][SJok6jh?na^^3o/K[P
0_n^_>@2ok2lh`03ojfmi_n^_NGo[[gU00?oZkgW0onZ_NL00ol0003oooooooooo`0[ooooo`002Ooo
ool01000003ooooooooooooooolS000000D06ATI00Go000003<c<`0c<c<0<c<co`00000204a<C004
o`00001VIVH0IVIV00000080Ogmo00<0000009VIV@2IVIT00_l0000;0;>c/`03o`00002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0806IVIP030000001oOgl0Ogmo
00<0Ogmo00<0000009VIV@2IVIT03`2IVIT00`000000Ogmo07moO`0207moO`050000001VIVH0IVIV
06IVIP000000101<C4`00ol00000<c<c03<c<`0203<c<`030000000I6AT06ATI00H06ATI7`000004
ooooo`0300000?oooooooooo037ooooo0_l00004ooooo`CoZKgX0_nY_>L3ojRli`03ojRkionW^NKo
YkWV00?oYkOU0_nW]^<00onW]>;oYJkNojF^gP03ojF]g003ojN/fonUY=CoYjGD00?oYjGD0_nYY]@2
ojZXe@03ojVPcOn[X/koZj;>00;oZj;>00?o[:G@oj^Ka_n[WLP00on[WLP00on/X<_oZiG0ojbI``02
ojbI``?o[Ig70on^V<03ojnNaPCo/I_200?o/J;9ok>J_oncV[l00onbXLH4okBQa@03ok:Vc?nfX/Co
]:O<00?o]:O<00?o/jgCokJZcOnfZ/d00_nd/=@01Oni[/oo][?GokJceonf/mOo000000?o][SJ00Ko
/K[PokBkg_nd^mko];_Nok2lhona_N84ojjmi@03oj^mion/_^OoZ[gW00?oZ[gW00?o0000oooooooo
ool0:_ooool000Wooooo00@00000oooooooooooooooo8`00000501TI6@040000000c<c<0<c<c0000
00<0C4a<00<0000006IVIP0000000P1oOgl01?l00000VIVI09VIVOl000050;>c/`Co0000102c/k<0
0ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0201VIVH0
0ol00000Ogmo07moO`0307moO`030000002IVIT0VIVI00L0VIVI0ol0000609VIV@050000001oOgl0
Ogmo07moO`000000101VIVH01@000000C4a<04a<C01<C4`0000000D0<c<c00<0000001TI6@0I6AT0
1@0I6ATO000000Cooooo00<00000ooooooooool0;_ooool3o`0000;ooooo1onY_NP4ojVli`03ojRl
ionX^^KoYkWV00?oYkWV00?oYkOUojBbh_nT[n000_nT[n03ojF^gP03ojF]g?nSXmKoYJCD00;oYJCD
0onWYM@00onYY]CoZ9k<ojRNc003ojVPc@;oZj;>00CoZYW5oj^Ka_n[VlKoZi_60_n[WLP01?nZTkko
ZiG0oj^E`?n[UL03ojbI``03ojfMaon]Tkco[I>l00?o[YS000?o[ik6ok2E^on`UK/00_naVl800onc
UKSo/iZook>J_`02ok>J_`03ok:Qa_neVkgo]I^m00;o]:7500Co]ibmokJRa?nfX/Co]Z;40_ndYl`0
1?nhY<Go]Z[=okJZcOnfZ/d4okV^c`06okJceonj/m;o0000okZcd_nf^=[o^[SG0ond^mh01?ng_=go
/KgRok6mh_na_N82ojjmi@;o[kkU0_n/_^L2ojZmi`;oZkgW00?o0000ooooooooool0:Oooool000Wo
oooo00@00000oooooooooooooooo8P00000501TI6@040000000c<c<0<c<c000000<0C4a<00<00000
06IVIP0000000P1oOgl010000000VIVI09VIVOl000030;>c/`?o0000103<c<`2o`000080/k>c00?o
000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000/0IVIV00<0000007moO`1oOgl0
0`1oOgl00`000000VIVI09VIV@0509VIV@;o00000`2c/k<2o`0000D0VIVI00D0000007moO`1oOgl0
Ogmo0000000406IVIP050000001<C4`0C4a<04a<C00000001@0c<c<00`0000006ATI01TI6@0501TI
6Ah000001?ooool00`00003oooooooooo`0/ooooo`;o00000oooool:ojVmj0;oZKcW00CoZ;_WojRj
i_nX^^KoZ;[V0_nW^NH01?nU]>CoY;;RojBbh_nT/^83ojB_h003ojF^g_nRY=SoXj?F00;oXj?F0onU
Y=@00onWYMCoYYc<ojRNc003ojRNc003ojVPcOnXUlCoZYW500?oZYW50_n[VlH00on[WLSoZY>nojZC
_P03oj^E`0;o[9W300CoZhniojfC_?n]Tkco[I>l0_n^V<001On_T;Ko/9Fkok2E^on`UK_o/I_200?o
/iFh0_ncV[l01OneU[Oo]I^mokFK_OneVkgo]:7500?o]ibm0_nfX/@4okRTa@03okJZcOnjYlKo^ZO6
00?o^Jk?0_nj/m800ol0003o_k?>okZhe`02okZhe`05okBkg_ng_=go]kcMokNlgOna_N800_nc_^83
ojnni@?o[;kW0_n[_NL00on[_^Oo0000ooooo`0Zooooo`002Oooool01000003ooooooooooooooolR
000000@06ATI00@0000003<c<`0c<c<000000`1<C4`00`000000IVIV0000000207moO`040000002I
VIT0VIVIo`000080/k>c0_l000080<c<c005o`00002c/k<0/k>c0;>c/ol000000P2IVIT00`000000
Ogmo07moO`0207moO`030000001VIVH0IVIV00X0IVIV00<0000007moO`1oOgl00P1oOgl00`000000
VIVI09VIV@0409VIV@03o`00002c/k<0/k>c00D0/k>c00?o000009VIV@2IVIT00`2IVIT01@000000
Ogmo07moO`1oOgoo000000<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c
<`030000000I6AT06ATI00D06ATI7@000004ooooo`0300000?oooooooooo02Wooooo0ol00002oooo
o`coZKgX0_nX_>L3ojRki`03ojRji_nV]nGoY[OU00?oYKCT00?oY;;Roj6ZgOnQY]X00_nQY]X3oj:T
f0;oXj?F0_nUY=@01?nSV/coYYc<ojJLc?nVW<`2ojRNc004ojNEa?nXUlCoZ9O4ojRGa0?oZYW500?o
Zi_6ojVA_OnZTkh00onZTkh2oj^E`0CoZhni0_n]Tk`4ojn@]P;o/9Fk1?ncUKP00oncV[oo]IJgokFF
]`03okFK_@Co]ibm00?o]Z;4okVN_OniW[d00onhY<D4okZWaP05okV^conm[LWo_Jg9okZcd_l00000
0_no/lh00onj^=Oo_[WEokjie@02okNlg@04ok^mg?nc_^;o/kkRok>nhPCo[kkU00?o[;kWojfnion[
_^L00on[_^L00ol0003oooooooooo`0Xooooo`002Oooool01000003ooooooooooooooolQ000000@0
6ATI00Go000003<c<`0c<c<0<c<co`00000204a<C003o`00001VIVH000000080Ogmo00D0000009VI
VOl0003o00000;>c/`02o`0000X0c<c<00Go00000;>c/`2c/k<0/k>co`00000209VIV@050000001o
Ogl0Ogmo07moO`0000003P1VIVH01@000000Ogmo07moO`1oOgl0000000D0VIVI00?o00000;>c/`2c
/k<01`2c/k<00ol00000VIVI09VIV@0309VIV@050000001oOgl0Ogmo07moO`0000000`1VIVH00`00
0000C4a<04a<C00204a<C003o`0000000000<c<c00<0<c<c00<0000001TI6@0I6AT01@0I6AT00ol0
000000000000000I000000Cooooo00<00000ooooooooool09oooool2o`0000?ooooo3?nY_NP3ojVl
j0;oZ;cW00CoZ;_WojNii_nW^NKoYkWV0_nV]nD00onU]>CoXJkPoj6Zg@02oj6Zg@?oXJKJ00?oXZCH
oifIconPVLd00_nPVLd3oj>Jc003ojJLc?nTTlCoYiG400;oYiG40onXUl@2ojZIa@04ojR@_OnYTKgo
ZI6mojVA_@?oZY>n00?oZiG0ojV<]onYS;L00on[SkT00on]Tkco[Hbbojf</P03ojn@]P03ok2E^onb
Sk?o/Xnc00?o/iFh1?neU[L2okFK_@04okRG]_ngW;go]ibmokNL_@Co^Ijm00?o^:C5ok^Q__nkXKh0
0_njYlH02?noY/7o_Jg9okf]bOnm[LWo_k?>o`000?no/lkoa;C;0onn^MD4ok^mg003ok>nh_ne_n;o
]KoR00;o[kkU00Co/;oUojfnion]_^Oo[KkW1?n[_^L00ol0003oooooooooo`0Wooooo`002Oooool0
1000003ooooooooooooooolO00000003o`00000I6AT06ATI00<06ATI00@0000003<c<`0c<c<00000
0P1<C4`020000000IVIV06IVIP000000Ogmoo`00002IVIWo00000P2c/k<00ol00000c<c<0<c<c002
0<c<c0Go00000`3<c<`01Ol00000/k>c0;>c/`2c/k?o00000080VIVI00D0000007moO`1oOgl0Ogmo
0000000>06IVIP030000001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT00`2IVIT00ol00000/k>c
0;>c/`060;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl01@000000IVIV
06IVIP1VIVH0000000@0C4a<00<0000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0501TI6A/0
00001?ooool00`00003oooooooooo`0Tooooo`?o00000oooool>ojVmj0;oZKcX00CoZ;cWojRkionX
^nOoZ;_W0_nW^NH00onT]NGoXk7Soj>ah`03oj6^h0?oXJ[M00?oXJKJoibKd_nMVLl00_nMVLl3oj2I
c@03oj>Jc?nQTLCoY9?400;oY9?40onWUL@2ojRGa0?oZ92m1?nYTKd00onZTkkoZ8ZfojV<]`02ojV<
]`?oZhni0on]S;83ojn@]P?o/Xnc0oncUKP4okFF]`03okFK_OnhUkKo^9Nf00?o]ibm1?niW[d3ok^Q
_P05okZWa_noY/7o_jK1oknV`Onm[LT00_o2[LD01Ol0003oa;C;olBdboo4]<_o_[WE00;o`k_C0_nk
_M`2okjof`03okFoh_ng`N;o/;oU00?o/;oU00?o[KkWojfoion]_nL00_n[_^L00on[_^So0000oooo
o`0Xooooo`002Oooool01000003ooooooooooooooolO000000D06ATI00@0000003<c<`0c<c<00000
0P1<C4`020000000IVIV06IVIP000000Ogmo0000002IVIWo00000P2c/k<01?l00000c<c<0<c<c03<
c<`2o`0000D0i^KV00Go00000<c<c03<c<`0c<c<o`0000020;>c/`04o`00002IVIT0VIVI00000080
Ogmo00<0000006IVIP1VIVH00`1VIVH7000000@0IVIV00<0000007moO`1oOgl00P1oOgl00`000000
VIVI09VIV@0309VIV@03o`00002c/k<0/k>c00H0/k>c00?o000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0207moO`040000001VIVH0IVIV06IVIP8000000`1<C4`00`000000<c<c03<c<`0303<c
<`03o`00000I6AT06ATI00@06ATI6`000004ooooo`0300000?oooooooooo02;ooooo0_l00004oooo
o`ooZKgX0_nY_>P3ojRli`03ojRkionV^>KoY[SV00?oY;GU0_nS/N<00onQ[^3oW:?Joi^NeP02oi^N
eP?oW9_B0onMVLl01?nPVLgoWHo5oj6Aa?nQTL@3ojBCa0?oYiG400?oZ9O4ojN?_OnWSkd00onXT;d2
ojVA_@03ojJ9]_nXR[KoZ8Zf00CoZHbg00?oZhnioj^8/?n]S;800on]S;800on_T;Ko/8^_ok:?/`03
ok:?/`03ok>E^?neTK7o]I6a00;o]IJg00?o^9>aokRG]_nhUkH00_nhUkH00ongW;go^YZgokZJ]`02
okVN_@;o_9bh0_nkXKh4oknV`@?o`Zg500Co0000olBdboo4]<_oa;C;0oo3^m<3okjof`04ol72fong
`N;o]l7RokO1hP;o/;oU0_na`>D2ojfoi`CoZkkX00?o0000ooooooooool09_ooool000Wooooo00@0
0000oooooooooooooooo7P00000501TI6@040000000c<c<0<c<c00000080C4a<00P0000006IVIP1V
IVKo000007moO`000000VIVIo`000080/k>c00?o00000<c<c03<c<`00_l000080>KViP04o`00003<
c<`0c<c<o`000080/k>c00Oo000009VIV@00003o000007moO`00003o000000<0IVIV0P00000704a<
C006o`00001VIVH0IVIV06IVIP00003o0000101oOgl00`000000VIVI09VIV@0309VIV@03o`00002c
/k<0/k>c00H0/k>c00?o000009VIV@2IVIT00`2IVIT00ol00000Ogmo07moO`0207moO`030000001V
IVH0IVIV0080IVIV00D0000004a<C01<C4`0C4a<o`00000503<c<`030000000I6AT06ATI00@06ATI
6P000004ooooo`0300000?oooooooooo01oooooo0ol000000oooooooZKgXojVmj00BojVmj0?oZKcX
00?oZ;cWojNjionW^^L00onV^>H00onT]NGoX:kRoifYgP02oifYgP;oW:?J0onKW]H2oibKdP;oWIW?
00?oVHk7oif?aOnMSlD00onQTL@3ojBCa003ojNEa?nUS[goYhnm00;oYhnm0onXT;d00onYTKgoYXVf
ojJ9]P03ojR:]P;oZHbg00CoZ8F_oj^8/?n[R;3oZhR`0on]S;83ok2;[`?o/Xnc0oneTK401?neU[Oo
^9>aokRC/OnhTk42okRG]P05ok^F/OnjV[Oo^YZgokZJ]oniW[d00onlW;P00onkXKko_j6ioknQ^@02
oknV`@;oa:Jl0_o2[LD00ol0003oajk1olBdb`02olVgb004ol>kdoo7_]7oakkAokjof`?o`L;K00?o
]l7RokS2h_nh`^800_na`>D01?na`NKo[KoWojfoion]_nL3oj^nj003ooooool0003ooooo02Kooooo
0009ooooo`0400000?oooooooooooooooah00000100I6AT01Ol00000<c<c03<c<`0c<c?o00000080
C4a<00X0000006IVIP1VIVH0000007moO`000000VIVIo`00002c/k?o00000P3<c<`00ol00000i^KV
0>KViP080>KViP04o`00003<c<`0c<c<o`000080/k>c00?o000009VIV@0000000P1oOgl00`000000
IVIV06IVIP0206IVIP03o`00001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH00P1VIVH01@000000
Ogmo07moO`1oOgl0000000H0VIVI00?o00000;>c/`2c/k<0102c/k<00ol00000VIVI09VIV@0509VI
V@050000001oOgl0Ogmo07moO`000000101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0
<c<c0080<c<c00<0000001TI6@0I6AT0100I6ATJ000000Cooooo00<00000ooooooooool07?ooool3
o`0000;ooooo5onY_NP00onY_>SoZ;_WojRki`03ojNji`03ojJhi_nR/nCoX:kR00;oX:kR0onMZMh2
oibSfP04oi^Ne_nDTLgoUXo9oiJ?b@CoVHk70_nMSlD2oj6Aa0;oY9?400CoXhfmojF>_OnUS[goYHjm
0onWSkd00onXT;goYHVgojJ9]P03ojJ9]P;oZ8Zf00?oZHbgojR5[onXQJl00on[R;02ojf</P04ojj7
[?n`Rjoo/8^_ok2;[`;o/Xnc00Co]8f]okFA/OneTK7o]I6a1?nhTk401?nhUkKo^iJaok^F/OnkU[42
okZJ]`Co_9bh0onoXKT02?noY/7oa:JlolBV_?o4Y[co`Zg5olN^`Ol0003oajk10oo9]lP3olNnd@04
ol_1d?o1`]_o`L;Kol72f`?o^<;R1?na`NH3ojfoi`?oZkkX00?o0000ooooooooool09Oooool000Wo
oooo00@00000oooooooooooooooo7@00000501TI6@070000000c<c<0<c<c03<c<`000000C4a<0000
000206IVIP070000001oOgl0000009VIVOl00000/k>co`0000020<c<c003o`00003Vi^H0i^KV00T0
i^KV00Ko00000<c<c03<c<co00000;>c/ol0000209VIV@040000001oOgl0Ogmo000000<0IVIV00<0
000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000
1P2IVIT3o`000080/k>c00?o000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0207moO`030000
001VIVH0IVIV0080IVIV00D0000004a<C01<C4`0C4a<0000000503<c<`030000000I6AT06ATI00@0
6ATI6@000004ooooo`0300000?oooooooooo01[ooooo0_l00003oooooaOoZKgX0onX_>P00onX^nOo
Y[[WojJji`03ojFgiP;oX[?T00?oX:kRoiVTgOnFW=P00_nFW=P2oiBFdP?oU97=0_nFSlT3oiV>a`;o
WHo500?oXI74oin:_OnSSKd00onSSKd2ojF>_@;oYhnm00?oY8VhojF9]onURKL01?nVRKH00onXR[Ko
YXB`ojR5[`03ojR5[`;oZhR`00Co[Hbbojj7[?n^Qjco[XN/0_n`Rjl01?nbSk?o]8f]okB=[OndSJd2
okFA/@04okV@[?nhTk7o^9>aokRC/@Co^iJa00?o^YZgokfI/_nmVK800_nlW;P01?o0W;?o_j6ioknQ
^OnoXKT4olBV_0;oajk100?o0000olf`_Oo=/;d00_o9]lP00oo>^/KoakkAol_1d002ol_1d004ol72
foo3a=_o`lCKokS2hP;o^LCR1?na`NH2ojfoi`CoZkkX00?o0000ooooooooool09?ooool000Wooooo
00@00000oooooooooooooooo7000000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01@00
0000IVIV0000001oOgl000000080VIVI0_l000030<c<c003o`00003Vi^H0i^KV00T0i^KV00?o0000
0<c<c?l000000P2c/k<00ol00000VIVI0000000207moO`050000001VIVH0IVIV06IVIP0000003@1<
C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000202IVIT2o`0000X0VIVI
00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP05o`00001<C4`0C4a<04a<C000
0000100c<c<00`0000006ATI01TI6@0401TI6@0300000?l00000000001H000001?ooool00`00003o
ooooooooo`0Gooooo`?o00000ooooolJojVmj003ojRlj?nX^nOoZ;_W00?oY[[W00?oYKOVoj2ai?nM
Zn400_nMZn42oiVTg@?oUYcH0_nDU]82oiBAc@?oUXo900CoVHk7oiJ4__nKQkkoVhNn0onOR[d3oj>=
_@03ojF>_OnSRKWoY8Vh00;oY8Vh0onURKL2ojJ9]P03ojB3/OnVQ;3oYXB`00CoZ8F_0_n[R;04ojj7
[0;o/8^_1?ndSJd00oneTK7o^I2/okV@[003okRC/@Co^iJa0onmVK801?nlW;So`9bcol2L/oo0W;<2
oknQ^@05olBQ]Oo4Y[coa:JlolBV_?o9Z;P00_l00002olf`_@03olVgb?o>^/Koc[[600?obl7@0_o?
a=001?o3a=_oaLKKolG6fonia>83okW5h`;o/L7V0on]_nL3oj^nj003ooooool0003ooooo02Cooooo
0009ooooo`0400000?oooooooooooooooa/0000000?o000001TI6@0I6AT00`0I6AT010000000<c<c
03<c<`00000204a<C0050000001VIVH0000007moO`0000000P2IVIT00ol00000/k>co`0000020<c<
c005o`00003Vi^H0i^KV0>KVi_l00000203Vi^H00ol00000c<c<o`0000020;>c/`03o`00002IVIT0
00000080Ogmo00@0000006IVIP1VIVH00000101<C4`6000000D0C4a<0P00000306IVIP04o`00001o
Ogl0Ogmo07moO`8000004P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV0080IVIV
00D0000004a<C01<C4`0C4a<0000000403<c<`030000000I6AT06ATI00@06ATI60000004ooooo`03
00000?oooooooooo01Kooooo0_l00003oooooa_oZKgX00?oZ;cXojRkionX^nL00_nX^nL00onV^^Oo
Y;KVoj2ai002oj2ai0?oWJ_Q0_nIY=d2oiJLf004oiBFd_n;Q/SoSH?4ohf3a0?oTH?00_nFQ;h3oi^7
_P?oWhZm00?oXhfmoj:8^OnSRKT00_nSRKT3ojB9^0;oYHVg00?oYXVfojB3/OnTPk400onVQ;03ojR5
[`03oj^8/?n[Q:_oZhB[00?o[XN/00?o/8^_ok:9Z_nbRJX00ondSJd3okV@[0;o^9>a0_nlU:d3ok^F
/@?o_IVb1?o0W;<01?noXKWoa:6eolBQ]Oo4XKD3o`000004olf`_Ol0003ocK2molf`_@?oc[[600Go
e;g4ol_1d?o?a=3oclC@om;7d003olG6f`?o^LGS00Go^LGTok71i_na`NKo/L7Vojfoi`02ojboi`?o
ZkkX00?o0000ooooooooool08oooool000Wooooo00@00000oooooooooooooooo7000000501TI6@06
0000000c<c<0<c<c0000001<C4co00000P1VIVH01@000000Ogmo0000002IVIWo00000080/k>c00?o
00000<c<c?l000000`3Vi^H00ol00000ooooo`0000070>KViP03o`00003<c<co00000080/k>c00?o
000009VIV@0000000P1oOgl00`000000IVIVo`00000404a<C0030000000c<c<0<c<c00@0<c<c0P00
000504a<C0050000001VIVH0IVIV06IVIP000000101oOgl200000140VIVI00<0000007moO`1oOgl0
0`1oOgl01@000000IVIV06IVIP1VIVH0000000@0C4a<00D0000003<c<`0c<c<0<c<c0000000601TI
6AP000001?ooool00`00003oooooooooo`0Fooooo`03o`000?nY_NSoZKgX01goZKgX0_nX_>P2ojRk
i`;oY[WW0_nT]^H00onP/NCoVJSPoi>Nf`02oi>Nf`;oSiGE0_n<S<h2oh^6b0?oSH?40_nAPl03oiJ4
_P;oVhNn0_nOR[d00onNQ[WoXXRioj:8^@03oj>9^@?oY8Vh00?oYHVgoj:4/onTPk400onTPk42ojJ4
/0;oZ8F_00CoZ8:[oj^4Zon[Q:_oZhB[0on^Qj`3ok:9ZP?o]8f]1?niT:`00onhTk7o_9B]okbD[@02
ok^F/@;o_iN^0_nmVK801Oo1V[3o`9bcol2L/oo0W;?oa:6e00?o00000oo9Z;P00oo>Z[GocK2mo`00
0002om:c^`05oljja_oD_LCoe;g4omW1`_o?a=000ooBam001?o5a]_oa/SLolK8g?niaN<3okW5i005
ok71i_n``NOo/<7Wojboion/_nP01?nZ_^P00ol0003oooooooooo`0Rooooo`002Oooool01000003o
oooooooooooooolK000000D06ATI00@0000003<c<`0c<c<000000P1<C4`01@000000IVIV0000001o
Ogl000000080VIVI00Go00000;>c/ol00000c<c<o`0000030>KViP05o`00003oool0oooo0?ooool0
00001@3Vi^H02?l00000c<c<0<c<c?l00000/k>co`00002IVIT000000P1oOgl00ol00000IVIV0000
000304a<C08000002@0c<c<2000000@0C4a<00@0000006IVIP1VIVH0IVIV0P00000407moO`030000
002IVIT0VIVI00l0VIVI00<0000007moO`1oOgl00`1oOgl01@000000IVIV06IVIP1VIVH0000000@0
C4a<00Go000003<c<`0c<c<0<c<c0000000601TI6AL000001?ooool00`00003oooooooooo`0Foooo
o`03o`000?nY_NSoZKgX01coZKgX0_nX_>P3ojNki`03ojJiionS]^KoW[3T00;oW[3T0_nIZ>03oi>N
f`;oSiGE0_n<S<h2oh^6b0;oSH?40onAPl02oiJ4_P03oi^7__nJP[SoWXJi00;oWXJi0onRR;T3oj>9
^@03ojB9^?nQQ[KoXXBc00;oXXBc0onTPk42ojJ4/003ojR5[onXPZ_oZ8:[00?oZhB[0on^Qj`4ok:9
ZP03okB=[OnhSJWo^8fY00?o^I2/0onlU:d01OnkU[7o_iN^oknG[_noUjko_IVb00;o`IZ`00Co`9bc
o`000?l0003o00000_o4XKD2olRS/P07olVX^?o>Z[GocZZeolf`_OoB/k_o0000om:c^`03omBma004
omW1`_oBam3od/O@om;7d0;oeL_@00?oa/SLolK:gOo6b]d00_niaN@2okS6i0;o/<7W0on/_nP3ojZn
j003o`000?oooooooooo02;ooooo0009ooooo`0400000?oooooooooooooooaX000001@0I6AT01000
0000<c<c03<c<`00000204a<C0050000001VIVH0000007moO`0000000P2IVIT01Ol00000/k>co`00
003<c<co000000<0i^KV00?o00000?ooo`3oool00`3oool01Ol00000i^KV0>KViP3Vi^Ko00000080
c<c<00Go00000;>c/ol00000VIVIo`00000207moO`030000001VIVH0000000<0C4a<00<0000003<c
<`0c<c<02`0c<c<00ol00000C4a<04a<C00204a<C08000000`1VIVH2000000<0Ogmo00@00000o`00
0000000000003P2IVIT00`000000Ogmo07moO`0307moO`05o`00001VIVH0IVIV06IVIP000000101<
C4`01@000000<c<c03<c<`0c<c<0000000D06ATI5`000004ooooo`0300000?oooooooooo01Kooooo
00?o0000ojVmj?nY_NP07?nY_NP3ojRlj003ojNkionV^NOoXkKV00;oXkKV0onN/>@2oiVXh0;oTikK
0_n?UMD2ohb<cP;oRhK80on=Pl@2oi63`003oiJ4__nDO[SoVX:h00;oVX:h0onNQ[T2oj:8^@;oXhVi
00?oXHNhoj66]_nQQ[H00onRQ;<3ojB3/@03ojJ4/?nTP:goZ8:[00?oZ8:[0on[Q:/00on^Qjco/8JX
ok:9ZP03ok:9ZP?o^8fY0_niT:`01?nmTZ[o_9B]okbD[OnlU:d4oknG[P05ol6J/?l0003o0000o`00
0?o0W;<00_o4W[401Oo4XKGob:>bolRS/_o8Xk;obJRh00;ocZZe00Kodjfbom:c^ooB/k_o0000omRg
^?oD_L@2omW1`P03omg5`OoBam3oeL_@00;oeL_@0oo6b]d01?o6c=ko^<KTokS6i?nga^D3ok31i`?o
[;oX0onZ_^P00ol0003oooooooooo`0Qooooo`002Oooool01000003ooooooooooooooolJ000000D0
6ATI00@0000003<c<`0c<c<000000P1<C4`01@000000IVIV0000001oOgl000000080VIVI00Go0000
0;>c/ol00000c<c<o`0000030>KViP03o`00003oool0oooo00<0oooo00Go00000>KViP3Vi^H0i^KV
o`0000020<c<c005o`00002c/k?o000009VIV@0000000P1oOgl00`000000IVIV0000000304a<C003
0000000c<c<0<c<c00`0<c<c0P00000404a<C0030000001VIVH0IVIV0080IVIV0P00000507moO`80
0000302IVIT00`000000Ogmo07moO`0407moO`040000001VIVH0IVIV000000@0C4a<00D0000003<c
<`0c<c<0<c<c0000000501TI6AL000001?ooool00`00003oooooooooo`0Eooooo`04o`000?oooooo
oooooooooagoZKgX00?oZ;cXojNkionW^nL00_nV^NL00onS]^KoWJoToif_i002oiJUh0;oSY[J0_n7
SM82oh:2b`;oPG_30_n3Mkh3ohMg^P;oSWZi0_nDO[P3oiZ2^0?oWXJi00?oXXRioj67^?nQQkP00_nQ
QkP3oj66]P;oXXBc0onTPk43ojB0[@?oZ8:[0_n[Q:/01?n/PjSo/8JXok26Z?n`QZP3ok:9ZP?o^8fY
00Co^I2/okfBZ_nmTZ[o_I:Z0_nlU:d00oo1Ujco_iN^o`000002o`0000?o`IZ`0oo4W[44olRS/P?o
cZZe0_oC[K800ooB/k_o0000omRg^002omW1`P;ogLG100KohLW0omG;d?oEbm3oeL_@omO>dOo6b]d2
olK<gPCo]lKU00Go/<7Wojo1ion_`NOo[;oXoj^nj004ojZnj003o`000?oooooooooo023ooooo0009
ooooo`0400000?oooooooooooooooaT000001@0I6AT010000000<c<c03<c<`00000204a<C0030000
001VIVH000000080Ogmo00D0000009VIVOl00000/k>co`0000020<c<c003o`00003Vi^H0i^KV0080
i^KV00Go00000?ooo`3oool0ooooo`0000030>KViP06o`00003<c<`0c<c<o`00002c/k?o00000P2I
VIT01@000000Ogmo0000001VIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c<c<6000000L0<c<c
00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo
00<0000009VIV@2IVIT02P2IVIT00`000000Ogmo07moO`0307moO`050000001VIVH0IVIV06IVIP00
00000`1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00806ATI5`000004ooooo`03
00000?oooooooooo01Gooooo00Co0000oooooooooooooooo6onY_NP3ojRlj003ojNkionU^NOoYKWW
00;oX[GV0onM[n@2oiJUh0;oSY[J0_n7SM82oh:2b`;oPG_30_n3Mkh2ohMg^P;oSWZi0onDO[P3oiZ2
^003oij6^OnOQ[SoXHNh00GoXHNh0_nQQ[H3oj:4/`03ojB3/OnPOk3oY82]00;oY82]0onXPZ/00on[
Q:_o[8>Xojb3Z003ok26Z0;o/XVZ00Co]X^XokR=ZOnhSJWo^8fY1?nmTZX01OnlU:go0000o`000?l0
003o_iN^00;o`iZ]0_o1V[001Oo5W:ooa9jaolBN/Oo4W[7ob9n_00?ob:>b00?ocJF`oljZ]OoC[K80
0_oC[K82omRg^003o`000?oM^kKofL7200;ogLG10_oQbL001OoEbm3oelkAomO>dOoHdM;oa/cN00;o
aLcO0_nga^D2okK5iP03ojo1ion^`NOoZkkX00;oZkkX0onZ_^P00ol0003oooooooooo`0Pooooo`00
2Oooool01000003ooooooooooooooolI000000D06ATI00@0000003<c<`0c<c<000000P1<C4`01@00
0000IVIV0000001oOgl000000080VIVI00Go00000;>c/ol00000c<c<o`0000060>KViP03o`00003o
oooo000000@0i^KV00So00000<c<c03<c<co00000;>c/ol00000VIVI00000080Ogmo00<0000006IV
IP0000000P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00@06ATI0P00000603<c
<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407mo
O`8000002`2IVIT00`000000Ogmo07moO`0307moO`050000001VIVH0IVIV06IVIP0000000`1<C4`0
1P000000<c<c03<c<`0c<c<00000o`0000@06ATI5P000004ooooo`0300000?oooooooooo01Gooooo
00?o0000ooooooooool00_oooolKojVmj003ojRlj?nW^nSoYKWW00?oYKWW0_nR]NH01?nM[nCoTjCP
ohVFf_n9U]X2ogn6d@;oN7W70_n2P//2oh5k``;oPgNn0on7MkX2ohij^@;oU7jh0_nJP[P00onKPKKo
WhJhoin6^006oj67^0;oXHJf0_nRQ;<00onNPK?oX7n`oj1o/003ojB0[@?oZ8:[0on/PjP3ok26Z004
ok:9Z_nfRjSo]X^XokJ;Z0;o^8fY00?o_I6XokfBZ_l000000_l00003ol6G[004oknG[_o3VZgo`iZ]
ol6J/0?oaIb_00?oa9jaolRO[oo8Wjl00_o8Xk82olfU/00:oljZ]OoC[K;odjfbom>]/_oH/;3of;Nh
omfk]_l0003oh[ndomg5`@?ohLW000Koi<g0omO>dOoHdM;of=7BomSCe?o5c=l2olC=h@;o]/GV00Co
]<GVojk1ion^`NOo[/7W0on[_^P3ojZnj003o`000?oooooooooo01oooooo0009ooooo`0400000?oo
oooooooooooooaP000001@0I6AT010000000<c<c03<c<`00000204a<C00:0000001VIVH0IVIVo`00
001oOgl0000009VIVOl00000/k>co`000080c<c<00?o00000>KViP3Vi^H01@3Vi^H00ol00000i^KV
0>KViP020>KViP0=o`00003<c<co0000o`00002c/k?o000009VIV@000000Ogmo00000?l00000IVIV
o`00000204a<C004o`00000c<c<0<c<c03<c<`8000002@0I6AT2000000D0<c<c0P00000304a<C080
0000101VIVH00ol0000000000000000507moO`8000002P2IVIT2000000@0Ogmo00D0000006IVIP1V
IVH0IVIVo`00000204a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT00P0I6ATF0000
00Cooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`04oooooaSoZKgX0_nX_>P2ojNk
j0;oYKWW00?oXKGVoi^^i?nK[^@00onCY>02ohVFfP;oOhKA00?oN7W7ogE___meKkh00omgJkP2oh=g
_P;oQgNj0_n>N[T00onDO[SoUG^doi^1]P02oi^1]P?oWhJh1OnQQkP00onQQ[KoWHBhoij1/`02oij1
/`?oX7n`0onTP:d00onXPZ_oYh6Zojb3Z003ojb3Z0;o/8JX1?nfRjP01?nhSJWo0000o`000?l00002
okfBZPCo`IN/0oo3VZd4olFL[`05olBN/Oo8Wjoob9n_olRO[oo8Xk800_o=YK03om>]/P;of;2`00Co
f;Nhomfk]_oM^kKo00000ooQbL02onC=`004onOB`OoHdM;of=?DomSCe0?oa<gQ1?ndaNH00on^`NOo
[L3Xojg0j002oj^nj0CoZ[gX00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooooooo
oooo6000000401TI6@070000000c<c<0<c<c03<c<`000000C4a<o`00000306IVIP070000001oOgl0
000009VIVOl00000/k>co`0000020<c<c003o`00003Vi^H0i^KV00T0i^KV00Ko00000<c<c03<c<co
00000;>c/ol0000209VIV@030000001oOgl000000080IVIV00@0000004a<C01<C4`000000P0c<c<0
0`0000006ATI01TI6@0;01TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`2
000000D0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0909VIV@050000001oOgl0
Ogmo07moO`000000101VIVH010000000C4a<04a<C000000303<c<`030000000I6AT06ATI00806ATI
5P000004ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool01OoooolGojVmj003ojRl
j?nW^nSoYk_X00?oYKWW0_nQ]NH2oi^^i0;oTjCP0_n9U]X2ogn6d@;oN7W70_meKkh2ogM[^0;oOF^d
0_n5Kk<2ohee/`?oUG^d0onKPKH2oin6^0;oXHNh00?oXX^loin8^onOR;/00onMQ;P3oij1/`;oX7n`
0_nTP:d00onROjgoYh6ZojN1ZP04ojb3Z0;o/8JX00?o/hRXokJ;Z?nfRjP00_l00002okfAZ0;o_I:Z
0_o3UjX3ol6G[0?o`iZ]00Coaij^olFL[oo5W:ooaIb_1?o8Wjl3olfU/003om6W[OoC[K;of;2`00;o
f;2`0_oM^kH01?oR_kCo0000onO4/_oQbL02onC=`0;oim;10ooHdm@01?oGeMOoa<gQol7<hoo1c><2
okC5iP;o/lCW00?o[L3Xojfoj?n[_^P00_n[_^P3ojZmj003o`000?oooooooooo01kooooo0009oooo
o`0400000?oooooooooooooooaL00000100I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00P0
000006IVIP1VIVH0000007moO`000000VIVIo`000080/k>c00Co00000<c<c03<c<co00002P3Vi^H0
1_l00000c<c<0<c<c?l00000/k>co`000080VIVI00?o000007moO`0000000P1VIVH010000000C4a<
04a<C000000203<c<`030000000I6AT06ATI00d06ATI0`00000403<c<`800000101<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT02P2IVIT01@000000
Ogmo07moO`1oOgoo000000<0IVIV00@0000004a<C01<C4`00000100c<c<00`0000006ATI01TI6@02
01TI6AD000001?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo5OnY_NP2
ojRlj0?oYk_X00CoYKWWoj6fionK[nGoVjoU0_nAXn43ohBCfP03ogN1d?m/L<GoK73500;oJ6Bj0_me
Kkh2ogM[^0;oOF^d0_n5Kk<2ohee/`?oUG^d0onKPKH2oin6^003oj67^?nRRkcoXX^l00;oWhRk0onM
Q;P3oij1/`;oX7n`00?oY82]oj9o[OnROjd00onWPJX3ojb3Z003ok26Z?ncR:So000000;o000000?o
]X^XokfAZ?nmTJP00_nmTJP00onmTZ[o`iNZol>GZP02ol6G[0;oaYb]00?o`iZ]olNN[_o7WZh00oo5
W:l00oo8Wjkob9n_olRO[`02ol^R[P04olfU/?oAYjgodJN]om>]/P?of;2`00OogKB]omfk]_oR_kCo
ilBbo`000?o/b;3oi<g000?oim;100KojMK2omSCe?oGeMOoemGGomCGf_o1c><2okk<i0;o/lCW0_na
`nL2ojfoj003oj^nj?nZ_^SoZ[kX00;oZ[gX00?oZKgXo`000?ooool07_ooool000Wooooo00@00000
oooooooooooooooo5P00000501TI6@05o`00000c<c<0<c<c03<c<`0000000P1<C4`00`000000IVIV
0000000207moO`030000002IVIWo00000080/k>c00Co00000<c<c03<c<co0000203Vi^H2o`000080
c<c<00?o00000;>c/ol000000P2IVIT00`000000Ogmo0000000206IVIP040000001<C4`0C4a<0000
0080<c<c00<0000001TI6@0I6AT04@0I6AT00ol00000<c<c03<c<`0303<c<`8000000`1<C4`00ol0
0000000006IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT02P2IVIT01@00
0000Ogmo07moO`1oOgl000000080IVIV00D0000004a<C01<C4`0C4a<0000000303<c<`030000000I
6AT06ATI00806ATI00?o00000000000000004P000004ooooo`0300000?oooooooooo01Cooooo00?o
0000ooooooooool02?oooolEojVmj0;oZ;cX00?oYk_XojFjj?nQ]^L00_nQ]^L2oi^_i@;oTJ?Q0on4
TmX01?mgPM3oK735ofa`aOmXI;X3ofYN/`;oMf^h0_mmJk@2ohE_/`;oSGFc0_nENk@3oi^1]P03oin6
^?nSR[[oXX^l00?oXX^l0_nOR;/3oif4^0;oWX6c00?oX7n`oian/_nROjd00_nROjd3ojN1ZP;o[8>X
0ol000001?ncR:So]X^XokJ;Z?nfRjP4okfAZ0?o`iNZ00Go`IN/olJL[Oo6W:goaYb]ol>J[@03olNN
[P04olFL[oo8Wjkob9n^olRO[`?obj:^00CocJF`om6W[OoAYjgoeZZ[0_oH/;02omfd[@;oh[nd0_oW
a;801?l0003oim;1onOB`OoWd/42onWF`P06on[Ka?oGeMOoe=OJomCGf_oAemgo_/cT0_nkb^H2ok73
i`04ok32j?n/_nSo[;oXojboj0;oZ[kX1?nY_NP00ol0003oooooooooo`0Looooo`002Oooool01000
003ooooooooooooooolD00000003o`00000I6AT06ATI00@06ATI00D0000003<c<`0c<c<0<c<c0000
000204a<C0030000001VIVH000000080Ogmo00<0000009VIVOl000000P2c/k<01?l00000c<c<0<c<
c?l000060>KViP;o00000`3<c<`01_l00000/k>c0;>c/ol00000VIVI00000080Ogmo00<0000006IV
I_l000000`1<C4`010000000<c<c03<c<ol0000D01TI6@8000001@0c<c<00`000000C4a<04a<C002
04a<C0030000001VIVH0IVIV0080IVIV00?o000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0:
09VIV@050000001oOgl0Ogmo07moO`0000000P1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c
00<0000001TI6@0I6AT00P0I6ATE000000Cooooo00<00000ooooooooool05?ooool00ol0003ooooo
ooooo`0:oooooa;oZKgX00CoZ;gXojNlj?nW_>SoYkcX0_nU^^P00onQ]^OoVk3Voi^`iP02ohnTh`04
oh2Bg?m^OM7oKWgAofimd@;oH6O300?oK735ofQT^_mXI;X00_mZG[<2og5O[`;oOF^d0_n5Kk<2ohee
/`?oUG^d00?oVh6foj25]_nSR[X00_nSR[X3oj:;_0;oWhRk0_nMQ;P00onFQKooUh2hoiN0^003oian
/P?oXWn]00GoYh6Zo`000?l0003o0000ojn6Z@04ok>8Z003okJ;Z?nlT:So_92X00?o_I6X0oo3UjX4
olJL[@Coaij^0oo8Wjh4ol^R[P?odJN]0_oFZZ/01_oH/;3ogKB]omfd[OoS^:_oh[ndonO4/P;ok<R`
00Co0000onOB`OoYe/;ojMK20_oZfl@01?oYg/Soe=OJom7GgOoAemd3ok_:iPCo/<;X00?o[;oXoj^o
j?n[_nP00_nZ_^P3ojVmj003o`000?oooooooooo01cooooo0009ooooo`0400000?oooooooooooooo
oaD000001@0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00H0000006IVIP1VIVH0000007mo
O`00000209VIV@04o`00002c/k<0/k>co`0000<0c<c<0ol000020>KViP03o`00003<c<`0c<c<0080
c<c<00Ko00000;>c/`2c/k?o000009VIV@00000207moO`040000001VIVH0IVIV00000080C4a<00D0
000003<c<`0c<c<0<c<c0000000601TI6@Ko00002P0I6AT00`000000<c<c03<c<`0303<c<`030000
001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`030000002IVIT0VIVI00/0
VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP040000001<C4`0C4a<000000<0<c<c00<00000
01TI6@0I6AT00P0I6ATE000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`0:
oooooa7oZKgX0onX_NP00onW_>SoY[[XojJjj003oj:gi`;oVk3V0_n?Y><00on0T]coKWgAofimd@02
of1W``;oF5Rg00?oJ6BjofYN/omZG[<00_maGjl2og]T[@;oQFnc00?oSGFcoi5d/?nJOK<00_nJOK<2
oj25]PCoXhZj00CoXX^loj>CaOnJSLGoVXg50onFQKl2oiN0^0?oW7jb00GoXWn]o`000?l0003o0000
ojN1ZP04ojn6Z@?o/hRX0onlT:P2okfAZ0;oa9V[0_o3UjX01?o9X:koaYb]olJL[Oo6W:d4olNN[P?o
b9n^00KobJ6_ol^R[_o;XZkobj:^oljS[?oAYjd3omJZZ`;ogKB]0_oS^:/2onO4/P05onc8/?o`cZoo
0000ooCD[_oYe/800_oZfl@2onWNb005onOQcOoAemgocMKPolgFh?nkb^H00_nhb>L2ok32j004ojk1
j?n[_nSoZkoXoj^nj0?oZ[kX0onY_NP00ol0003oooooooooo`0Kooooo`002Oooool01000003ooooo
oooooooooolD000000H06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0030000001VIVH00000
0080Ogmo00<0000009VIVOl000000P2c/k<00ol00000c<c<0<c<c0050<c<c0;o0000103<c<`01_l0
0000/k>c0;>c/ol00000VIVIo`000080Ogmo00@0000006IVIP1VIVH000000P1<C4`01@000000<c<c
03<c<`0c<c<0000000H06ATI00?o000000000000000010000002o`0000T06ATI00?o000003<c<`0c
<c<00`0c<c<00`000000C4a<04a<C00204a<C005o`00001VIVH0IVIV06IVIP000000101oOgl00`00
0000VIVI09VIV@0;09VIV@040000001oOgl0Ogmo00000080IVIV00D0000004a<C01<C4`0C4a<0000
000203<c<`030000000I6AT06ATI00<06ATI50000004ooooo`0300000?oooooooooo01Cooooo00?o
0000ooooooooool02ooooolAojVmj003ojRmj?nX_>SoZ;cX00?oY[[X00CoX[OWoibaion@Y^CoT:KT
0_mnU=h2ofQkd`;oKWgA00CoH6O3oeQH]omHF;OoFE6^0_mZG[<2og5O[`;oNfB]0_n6K:h3oi5d/0;o
VWfc0onPQKH2oj>:^P03ojVD`?nSTlGoXi?500?oVXg50onFQKl2oiN0^0?o00000_nROjd00onWPJ[o
Z8>]ojR3[@03ojn6Z@;o/hRX00Go^Hn[okb@Z?nlT:So_92XokfAZ003olBIZ`03ol>GZ_o9X:kobJ2^
00;oaYb]0_o;Y;02olNN[P;obJ:a00?ob9n^olVQ[oo9XJl00_o;XZh2oljS[006om6W[OoFZZ_oeZZ[
omJZZooJ[JWogKB]0_oS^:/00ooX_:SoilBbonc8/002oo3>[`03o`000?offZkoj]_400;ojMk80_oW
hLd01OoShm?ocMKPolODhoo7e>?o^<SW00;o]LOW00?o[/7Xojg0j?n[_^P00on[_^P00onZ_^SoZ[gX
ojVmj002ojVmj003ooooool0003ooooo01_ooooo0009ooooo`0400000?oooooooooooooooa@00000
1@0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl00ol0
0000VIVIo`0000020;>c/`03o`00003<c<`0c<c<00P0c<c<0ol000000`2c/k?o0000o`00000209VI
V@030000001oOgl000000080IVIV00@0000004a<C01<C4`000000`0c<c<00`0000006ATI01TI6@04
01TI6@03o`0000000000000000L000000_l0000801TI6@800000100c<c<01@000000C4a<04a<C01<
C4`0000000@0IVIV00D0000007moO`1oOgl0Ogmo0000000609VIV@?o00001@2IVIT01?l00000Ogmo
07moO`00000206IVIP040000001<C4`0C4a<00000080<c<c00<0000001TI6@0I6AT00`0I6ATD0000
00Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`0=oooooa3oZKgX00?oZ;cXojJk
j?nV^nP00onS^>P2oibai`;oT:KT0_mnU=h00omXNm?oDf74oe=Qa002of1W``03oeQH]omIDJkoFE6^
00;oJUjc00?oLEn_og]T[OmkI:d00_n6K:h3oi5d/0?oVWfc0_nPQKH00onSR[[oZIC0ojVD`003oj>C
a@;oVXg50_nFQKl3o`0000?oW7jb00?oXWn]oin1/onXPjd00_nXPjd3ojn6Z@03ok>8Z?niSj_o^Hn[
00?o_92X1?o4VJ/01Oo3Uj[obJ2^olVP[_o9X:koaYb]00;objB`00Goaij^olVR/Oo9X[7obJ:aolRO
[P03olVQ[`03ol^R[_o>XjcocZ>/00?oeZZ[0_oJ[JT01ooM]:gohkR[onRlZ?oX_:Sok/:Uonc8/?o`
cZl00_ode:h00ol0003omn2`onWNb002onOQc@04on?SdooMhmWogN?IolODh`;o`]7U00?o]LOWok;5
j?nbaNP00_n]`>P2oj^nj0;oZ[kX0_nZ_NP3ojVmj003o`000?oooooooooo01[ooooo0009ooooo`04
00000?oooooooooooooooa@000001@0I6AT01@000000<c<c03<c<`0c<c<000000080C4a<00@00000
06IVIP1VIVH000000P1oOgl00`000000VIVIo`0000020;>c/`03o`00003<c<`0c<c<00L0c<c<00Go
00000;>c/`2c/k<0/k>co`00000309VIV@030000001oOgl000000080IVIV00Co000004a<C01<C4co
00000`0c<c<00ol000006ATI01TI6@0301TI6@;o000030000002o`0000P06ATI00D0000003<c<`0c
<c<0<c<c0000000304a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo00000003
09VIV@?o00000`2c/k<2o`0000<0VIVI00@0000007moO`1oOgl000000P1VIVH010000000C4a<04a<
C000000203<c<`030000000I6AT06ATI00<06ATI50000004ooooo`0300000?oooooooooo01Cooooo
00?o0000ooooooooool03Oooool?ojVmj0?oZ;cX0_nV^nP01?nS^>SoWK?Woi:Yi_nBZNH2ognHh@;o
IGgF0_mXNm<00omCHLCoATfdodI=]002oeQH]`03oeUA[_mQDZWoJUjc00;oLEn_0_mkI:d2ohI/[P;o
TGB`0onJOK<00onPQKKoZHnjojVD`003ojVD`0;oXi?500GoVXg5o`000?l0003o0000oiJ5_`02oiN0
^0;oW7jb00?oTh2koin1/onOPK<00onXPjd3ojn6Z@Co^Hn[0_nlT:P01?o4VZgoa9V[olBIZoo4VJ/4
olVP[P?objB`1?o9X[44olVQ[`?ocZ>/0ooFZZ/2omZ]Z@;ohkR[0_oX_:P02_o^`ZGol<j_oo3>[ood
e:kom]Z^o`000?ogh;3omnFdonOQcOoShm<2omgSf@;oe^3O00Go`]7Uokg>ionmc^Oo//GXok33j003
ojboj0?oZ[kX1OnY_NP00ooooooo0000ooooo`0Jooooo`002Oooool01000003ooooooooooooooolC
000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV00000080Ogmo
00@0000009VIV@2IVIWo00000`2c/k<00ol00000c<c<0<c<c0040<c<c0;o00000`2c/k<01ol00000
VIVI09VIV@2IVIT0000007moOol000000P1VIVH010000000C4a<04a<C000000303<c<`030000000I
6AT06ATI00<06ATI00?o00000000000000003P0000000ol000006ATI01TI6@0601TI6@05o`00000c
<c<0<c<c03<c<`0000000`1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00D0000009VIV@2I
VIT0VIVIo`0000080;>c/`04o`00002IVIT0VIVI000000<0Ogmo00Co000006IVIP1VIVH000000P1<
C4`010000000<c<c03<c<`00000401TI6A@000001?ooool00`00003oooooooooo`0Cooooo`03o`00
0?oooooooooo00oooooo3onY_NP00onX_>SoYk_XojBij002ojBij0;oWK?W0_nBZNH2ognHh@04ofEm
e_m8G/KoB5k6oe=Qa0;oATfd00?oA4:ZoeQH]omIDJh00_mQDZT2og5O[`;oNfB]0_n6K:h3oi5d/003
oiYm/onTQKCoZHnj00;oZHnj0onYU<03o`0000;oSYWJ0_n3R]82ohN2aP?oTh2k0onOPK<3ojR3[@;o
[hJY00Go/hf_okV?ZoniSj_o^Hn[okb@Z002olBJ[@?oa9V[1?o9X:h01?oA[KGobjB`ol^T/?o>ZkL3
olVR/@CobJ6_0_o>Xj`2om2TZ`07omJZZooJ[JWofZfYomZ]ZOoO/:KohkR[onRlZ002onk2Y@0:oo?8
X_o`cZoom=B^ooKJ[_ogh;3o0000ooOU]?oej[[olNg2omgSf@;oe^3O0_o>g><00onmc^Oo^<[Xok33
j002ok33j003ojboj?n[_nSoZkoX00?oZ[kX1OnY_NP00ol0003oooooooooo`0Iooooo`002Oooool0
1000003ooooooooooooooolC000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000
001VIVH0IVIVo`000080Ogmo00@0000009VIV@2IVIWo0000102c/k<3o`0000030<c<c?l0003o0000
00@0/k>c00Oo000009VIV@2IVIT00000o`00001oOgl000000080IVIV00@0000004a<C01<C4`00000
0`0c<c<00`0000006ATI01TI6@0301TI6@03o`000000000000000100000000?o000001TI6@0I6AT0
1P0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IVIP1VIVH000000P1oOgl01000
0000VIVI09VIVOl0000:0;>c/`04o`00002IVIT0VIVI00000080Ogmo00@0000006IVIP1VIVH00000
0P1<C4`010000000<c<c03<c<`00000401TI6A@000001?ooool00`00003oooooooooo`0Cooooo`03
o`000?oooooooooo017ooooo3?nY_NP01OnX_>SoYk_XojNkj?nW^nSoY;WX00;oWkGX0_nE[NL2oh>M
i007ofJ3fom2Gl[oIGgFodQNa_lc@k?oDf74odI=]002odA2ZP03oeUA[_mQDZWoHE:Y00;oKURX0_mk
I:d2ohI/[P;oTGB`00?oVGZ_ojB5]?nTQK@01?nYSkX2o`0000CoY:OH0_n>VMX2oh>:dP;oQh;60onC
P;/2oin1/`?oZ8>]00?o[hJYok>=[oncSJl00oniSj/01OnlT:Soa9Z]olBJ[Oo4VZgoa9V[00;ocJJa
0_o9X:h2om6]]@03ol^T/?o>ZkOocZ^g00;obJ:a0_o9Y;@4olVQ[`04oljS[?o@Y:_od:B[omJZZ`;o
fZfY0_oO/:H2onRlZ0;ok/:U00_ollRRooS?Woode:kom]Z^ooOP/?ogiKCo0000ooGZ^_oakL;ojno<
omKPg`02olkLh`05olKGi_nhb^So^<[XokS:j?n``nP00_n^`^P00on[_nSoZkkXojZnj003ojZnj0Go
ZKgX00?o0000ooooooooool06?ooool000Wooooo00@00000oooooooooooooooo4`00000501TI6@05
0000000c<c<0<c<c03<c<`0000000P1<C4`01?l00000IVIV06IVIP00000207moO`040000002IVIT0
VIVIo`0000L0/k>c00?o00000;>c/`2c/k<00`2c/k<01?l00000VIVI09VIV@00000307moO`030000
001VIVH0000000<0C4a<00@0000003<c<`0c<c<000001@0I6AT00ol0000000000000000B00000003
o`00000I6AT06ATI00D06ATI00D0000003<c<`0c<c<0<c<c0000000304a<C0040000001VIVH0IVIV
00000080Ogmo00@0000009VIV@2IVIWo00002P2c/k<01?l00000VIVI09VIV@00000207moO`040000
001VIVH0IVIV00000080C4a<00@0000003<c<`0c<c<00000100I6ATD000000Cooooo00<00000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`_oZKgX0_nX_>P01?nW^nSoYKWXojFij?nU^NP2
oinej0;oUJgW0_n3WN@00omVPm_o@Uo:odQNaP02oc=3/`;oATfd00CoA4:ZoeUA[_mIDJkoHE:Y0_m^
F:P2ogeRZ@;oS6j[0onINZl3ojB5]0?o00000ondZLd2ojBWf0;oW<_h00?oF:ShocZ7joljQn/00_n7
P/H3oi>0^`;oWh6c0_nXPjd01?nYS;Oo/hf_ok>=[oncSJl3okV?Z`Coa9Z]0oo=Y[401?o9X:kodJfe
om6]]OoA[KD4olj[]`03olVR/Oo9Y;CobJBd00CobJ6_00?ocZ>/om2TZoo@Y:/00ooJ[JT2omn`YP;o
j;bX00kok/:Uoo?8X_ocb:;on<nOoocFW?omg9[omn2`ooOU]?oej[[o0000oo7]`_o[klcohngGolkL
h`;oa]OV0_nhb^P2okC7j003ojk2j?n]`>SoZkkX00;oZkkX0_nZ_^P2ojZmj0GoZKgX00?o0000oooo
ooooool05oooool000Wooooo00@00000oooooooooooooooo4`00000501TI6@040000000c<c<0<c<c
000000<0C4a<00@0000006IVIP1VIVH000000P1oOgl010000000VIVI09VIVOl0000<0;>c/`04o`00
002IVIT0VIVI000000<0Ogmo00<0000006IVIP0000000`1<C4`010000000<c<c03<c<`00000601TI
6@03o`0000000000000001<0000000?o000001TI6@0I6AT0100I6AT01@000000<c<c03<c<`0c<c<0
000000<0C4a<00@0000006IVIP1VIVH000000P1oOgl00`000000VIVIo`0000050;>c/`?o0000102c
/k<01_l00000VIVI09VIV@000000Ogmo00000080IVIV00@0000004a<C01<C4`000000P0c<c<00`00
00006ATI01TI6@0201TI6A@000001?ooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo
01?ooooo2OnY_NP2ojRlj0?oYk_X00CoYKWXoj6gj?nI/>OoVK3W0_n8XnH2off<h0;oA6OA00Wo8Sbd
odQNa_lc@k?o;3>VodI=]?m4@Z[oCD:ToeUA[_mQDZT00_m^F:P2ogeRZ@?oS6j[0_nINZl3o`000005
ojV?^_nhXL7o^:71okRQ`OndZLd00oo5c=l01?nLboSoF];UomkfWooHmIh2ocZ7j`;oDh7Q0_nCP;/0
0onOPK?oV8W2ojV<]`02ojV<]`Co/hf_0_niSj/4olBJ[@?ocJJa00Gof;bnom6]]OoA[KGodJfeomJm
`P02olj[]`04ol^`_oo9Y;CobJBdolVT]0CobJ6_0oo@Y:/00ooCYJWofZfYomZ]Z@02omn`YP04onBd
Y?o^`ZGok/:Uoo?8XP;on<nO00Ooo=JLoogLV_omhYWonnRJooGZ^_l0003ojno<00;ohngG00Cof^SO
olKGi_nodNSo_m7X0_ndanP2ok74j0;o[L3X00?oZkkXojZnj?nZ_^P00_nZ_NP6ojVmj003o`000?oo
oooooooo01Oooooo0009ooooo`0400000?oooooooooooooooa8000001@0I6AT01@000000<c<c03<c
<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl01@000000VIVI09VIV@2IVIWo0000
00/0/k>c00Co000009VIV@2IVIWo00000`1oOgl01?l00000IVIV06IVIP00000204a<C0050000000c
<c<0<c<c03<c<`0000001@0I6AT00ol0000000000000000E00000003o`00000I6AT06ATI00@06ATI
00D0000003<c<`0c<c<0<c<c0000000204a<C0060000001VIVH0IVIV0000001oOgl000000P2IVIT0
0ol00000/k>c0;>c/`020;>c/`05o`00003<c<`0c<c<0<c<c?l000000`2c/k<01?l00000VIVI09VI
V@00000207moO`030000001VIVH000000080C4a<00@0000003<c<`0c<c<00000100I6ATD000000Co
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`SoZKgX0onX_>P00onW^nSo
Y[[XojJjj002oj6gj0;oVK3W0_n8XnH2off<h004odAWdOlH?;So8Sbdoc=3/`;o;3>V00?oA4:Zode2
Y?m=@Z@00_mQDZT00om^F:SoOF:YogeRZ@02oha^Z`?o000000?oVGZ_ojB5]?nTQK@01?nhXL43olG<
g`;ocoCX0_oNmYl01OoJnJ[oi_^donKk]?oUn/koDh7Q00;oNhGB0onHRL83ojV<]`?o/hf_00?o^Hn[
ol6L/oo1W;<00_o4VZd2oln^^0;ocJJa0_oH_;h01?oA[KGoe[g2omJm`_o>ZkL3ol^`_`;obJBd00Co
a:>folVQ[oo9XJoobJ6_0_o@Y:/3om>UZ@;ogk2V0_oT]:@2onk2Y@0;oo?8X_ohciooo=JLoocFW?om
g9[ooN:Ioo_XV_ohkJ3omO:[o`000?oSkML00_oJj=l01?o?hNGo_m7XokW<jOnic>T2ok74j004ojk2
j?n/_nSo[;oXojboj0;oZ[kX2OnY_NP00ol0003oooooooooo`0Fooooo`002Oooool01000003ooooo
oooooooooolB000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV
00000080Ogmo00D0000009VIV@2IVIT0VIVIo`0000090;>c/`;o00000`2IVIT010000000Ogmo07mo
O`00000206IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT00`0I6AT00ol00000
00000000000G00000003o`00000I6AT06ATI00<06ATI00D0000003<c<`0c<c<0<c<c0000000204a<
C0060000001VIVH0IVIV0000001oOgl000000P2IVIT01Ol00000/k>c0;>c/`2c/k?o000000D0c<c<
0_l000020;>c/`08o`00002IVIT0VIVI0000001oOgl0000006IVIP00000204a<C0040000000c<c<0
<c<c000000@06ATI50000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool05Ooo
ool6ojVmj0GoZ;cX00CoY[[Xoj>hj?nL/nSoW;?X0_n?ZNL2ogNFh`;oCgCH0_m4Im401?lH?;So42BR
oc=3/ol/<jH2odA2ZP03ode2Y?mLBZ?oHE:Y00;oKURX0ol000001On<KZ_oVGZ_oiUj[onINZooY8Fd
00;o/iBg0onhXL402_o>_<WoaLcOolodj?o?m>SojOV_omkfWooHmIkohoBMonKk]?oUn/h2omc]g@03
of@00?mkQM;oNhGB00;oV8W20onYS;L2ok>=[`05okZO__o1W;?o`Ibcol6L/oo4VZd00oo?[[P01?o=
Y[7of;bnomRl__oH_;h3omJm`PCobk2o00?obJBdolBS]_o4XkH00_o9XJl2olRO[P04om2TZooCYJWo
djFYom>UZ@;ogk2V0_oT]:@01oo[^Z7ollRRoo?8X_ohciooo=JLoogLV_omhYT00_okj9X01_ohkJ3o
mO:[oo3f^Ol0003of^SOoloQi@;oa][X00?o^LcYokC8jOndb>T00on^`^P00on/_nSoZkoXoj^oj002
ojZnj0WoZKgX00?o0000ooooooooool05Oooool000Wooooo00@00000oooooooooooooooo4P000005
01TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`050000
002IVIT0VIVI09VIVOl000001`2c/k<2o`0000@0VIVI00@0000007moO`1oOgl000000`1VIVH00`00
0000C4a<0000000403<c<`030000000I6AT06ATI00806ATI00?o0000000000000000600000000ol0
00006ATI01TI6@0301TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01P000000IVIV06IVIP00
0000Ogmo00000080VIVI00Co00000;>c/`2c/k?o00001`3<c<`01?l00000/k>c0;>c/ol0000209VI
V@050000001oOgl0000006IVIP0000000P1<C4`010000000<c<c03<c<`00000401TI6A@000001?oo
ool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo1_nY_NP3ojRlj0;oY[_X0_nS
^>P2oibcj0;oSjWW0_mgU^<01?m?M=So6TK0oaY6`?lH?;P2oa0TXP05ob`cY_lb<9ooA4:Zode2Y?mL
BZ<00ol00002ogeRZ@?oS6j[00?oVGZ_ojN5/?ncU;L00oncU;L00onhXL7oc[c9oljlb@02onCLc@08
onoc`ooNmYooj^j?onC_T?oOki3oj?V_on[ec?oLkMd2oloFgP;o06oL0_nHRL83ojV<]`04ok>=[onj
Wkko^YnnokZO_P;o`Ibc1?o?[[P3omRl_P;og]oF00?oe[g2om3=eoo@cML00oo;/;l4olBS]P04olVQ
[oo8Wjkob9n^om2TZ`?odjFY00KoejRWomn`Y_oT]:Coi;BTon^jXOob`Yd2ooS?W`06oocFW?omg9[o
oN:Ioo_XV_ohkJ3omO:[0_o`m[T01?oZml[o0000omO[hoo6f^P2okkBj@03okC8jOn`aNWo[L7X00?o
[L7X00?oZkoXojZnj?nZ_^P00_nZ_^P8ojVmj003o`000?oooooooooo01Gooooo0009ooooo`040000
0?oooooooooooooooa4000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@0000006IV
IP1VIVH000000P1oOgl00`000000VIVI09VIV@0209VIV@03o`00002c/k<0/k>c00<0/k>c00?o0000
09VIV@2IVIT00`2IVIT010000000Ogmo07moO`00000306IVIP030000001<C4`0000000@0<c<c00<0
000001TI6@0I6AT00`0I6AT00ol0000000000000000H00000003o`00000I6AT06ATI00@06ATI00@0
000003<c<`0c<c<000000P1<C4`00`000000IVIV0000000207moO`030000002IVIWo00000080/k>c
00?o00000<c<c03<c<`01`3<c<`01_l00000/k>c0;>c/ol00000VIVI00000080Ogmo00D0000006IV
IP000000C4a<0000000203<c<`030000000I6AT06ATI00806ATI50000004ooooo`0300000?oooooo
oooo01;ooooo00?o0000ooooooooool06?ooool5ojVmj0?oZ;cX00?oY[_XojBij?nT^NP00_nO]NP3
oiF^j00:oh6Oi_mOQ=oo:US<obYHc?lJA/3o63bho`0HWol@9:;o;3>Voc8`W`?o000000?oG4ZSog1F
YOm`EZD00_mmHZT2oha^Z`03oiMf[?nWQK3oYhF`00Co/iBg0oo>_<T00ooTg<goko?3onWi[`02on[^
S`;ognn@00Coj?V_on[ec?oNgMGocmKN0_o3_mH2o`1_g0;oMIgZ00?oZHbgojRRdOnjWkh00onjWkh0
0oo1W;?ock_7olnka`03oln^^005omkEcooH_;kog]oFomkOe_nbn>h01?o@cML00oo;/;oo_jg7okn]
a`02olBS]P04okfM]oo8Wjkob9n^olRO[P?odjFY0_oGZ:L2onBdY0;ojkZQ017ol/:MooS9VOoleYco
o=JLoogLV_omhYWonnRJooS]X?oelZ_ol?Jion[gb_oRlmWo0000omO[hoo<h^So_];YokO<jP03ok35
j@;o[L7X00?o[;oXojZnj?nZ_^P00_nZ_^P:ojVmj003o`000?oooooooooo01Cooooo0009ooooo`04
00000?oooooooooooooooa4000001@0I6AT01@000000<c<c03<c<`0c<c<0000000<0C4a<00@00000
06IVIP1VIVH000000P1oOgl00`000000VIVI09VIV@0309VIV@?o000000<0/k>co`00002IVIT0102I
VIT010000000Ogmo07moO`00000206IVIP05o`0000000000C4a<04a<C?l000000`0c<c<00`000000
6ATI01TI6@0301TI6@03o`0000000000000001X0000000?o000001TI6@0I6AT00`0I6AT010000000
<c<c03<c<`00000204a<C0050000001VIVH0000007moOol000000P2IVIT00ol00000/k>co`000003
0<c<c0Go00000`3<c<`03?l00000/k>co`00002IVIWo00000000001oOgl0000006IVIP000000C4a<
00000080<c<c00<0000001TI6@0I6AT00P0I6ATD000000Cooooo00<00000ooooooooool04_ooool0
0ol0003oooooooooo`0Iooooo`GoZKgX00CoZ;cXojNkj?nW^nSoYk_X0_nT^NP2oinej009oiF^j?n:
YnSoKi;TofnBi?mOQ=oo:US<oaY6`?l05Z7o63bh00?o000000Co<S2Oode2Y?m=@ZCoG4ZS0_m`EZD2
ohAUZ0?oUgJ/0onWQK02ok>D]`;ob:Vk00[oc[c9onCLcOo_ll?oko?3oo?_V_oZkXooi>n@omo_T?oX
nJooj_G<0_oNgMD00oo>`Lgo`koFokb]b`02okb]b`03okB]d_meWN[oZ:;A00;oZ:;A0_njWkh00oo1
c^Cock_7olnka`02olnka`05oln^^?oNeLoog]G?okSmfOoNgmH00onbn>h2om3=e`05ojo9kOno[LOo
_jg7okn]aoo4XkH00_nmWKL3olRO[P03olRN[OoCYJWoejRW00;oejRW0_oT]:@2on^jX@0?oo;2WOoh
bIWooM6CoogLV_omhYWonnRJoo7SO?o/ih7ojNj>onWeX_oXnk[oho_AomO[hol0003oc>;X00?o]lcZ
00Go/<GYojk2jOn^`^Wo[;oXoj^oj004ojZnj0_oZKgX00?o0000ooooooooool04oooool000Wooooo
00@00000oooooooooooooooo4@00000501TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`01000
0000IVIV06IVIP00000207moO`030000002IVIT0VIVI00H0VIVI00?o000009VIV@2IVIT0102IVIT0
10000000Ogmo07moO`00000206IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI
01TI6@0301TI6@03o`0000000000000001X0000000?o000001TI6@0I6AT00`0I6AT010000000<c<c
03<c<`00000204a<C0050000001VIVH0000007moO`0000000P2IVIT00ol00000/k>co`0000020<c<
c003o`00003Vi^H0i^KV00<0i^KV00Ko00000<c<c03<c<co00000;>c/ol0000209VIV@070000001o
Ogl0000006IVIP000000C4a<0000000203<c<`030000000I6AT06ATI00806ATI50000004ooooo`03
00000?oooooooooo01;ooooo00?o0000ooooooooool06_ooool3ojVmj0?oZ;cX00?oYk_XojFjj?nQ
]nP00_nQ]nP2oiVbj0;oRZOX00CoKi;Tod5^eom1K]Oo:US<0_l000001ol@9:;o41^Hob`cY_lb<9oo
@cRNode2Y?mLBZ<00_m`EZD2ohAUZ0CoUgJ/0_nWQK001OncU;Oob:VkolRY^oo8ZK_oglBm00;ol]fh
00SonNb[on[^SooZkXoognn@omo_S_o`mkKoj^;9omkMe@;oc/7=00Co`j_2okb]bonl[L_o_:g;0ona
X<L2ojRRd@04okZO__o1c^Co`LkTol7>i0;ock_70_o=n>P01?oNeLoo^?gIogmja?moN/@2oe=P``03
o`0P[?l0CJKo[lW]00;o[lW]00?o_jg7ojZMb_nmWKL00onmWKL01?o8Wjkob9j]olRN[OoCYJT3omNX
Y`03omb/Y?oT]:CojkZQ00;ol/:M013on<VIoogATooof8cooMf4ooSQO_oahgcok>N1onW^S_oYmJ;o
j?^jon?kdOoJm>3oc>;Xo`000?o2f>[o]lcZ0_nbanX00on^`^Wo[<7Xojc1j002oj^oj0CoZ[kX2_nY
_NP00ol0003oooooooooo`0Cooooo`002Oooool01000003ooooooooooooooolA000000D06ATI00D0
000003<c<`0c<c<0<c<c0000000204a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl00`000000
VIVI09VIV@0<09VIV@040000001oOgl0Ogmo00000080IVIV00D0000004a<C01<C4`0C4a<00000003
03<c<`030000000I6AT06ATI00<06ATI00?o00000000000000006`0000000ol000006ATI01TI6@02
01TI6@0;0000000c<c<0<c<c03<c<`000000C4a<0000001VIVH0000007moO`0000000P2IVIT00ol0
0000/k>co`0000020<c<c003o`00003Vi^H0i^KV00D0i^KV00ko00000<c<c03<c<co00000;>c/ol0
0000VIVI0000001oOgl0000006IVIP000000C4a<00000080<c<c00<0000001TI6@0I6AT00P0I6ATD
000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Looooo`;oZKgX00?oZ;cX
ojNlj?nW_>P00_nU^^P01?nQ]nSoWKGYoi6]jOnA[NT2ogbNi`0:oeN2h?l0003o0000o`000?l08J_o
01JQo`0HWol@9:;o41^Hoc8`W`;o@cRN0_mLBZ<00om`EZGoQ6FXohAUZ004oiMf[0;oYhF`0oo8ZK/2
omo4_@;ol]fh00?olnnJon[^SooTiWd00_oOkhh01?o`mkKoj^;9omO1a?o>`Ld3ol>[`P03okb]bonh
Wkoo^9no00;o/J3700GoZj3<ofS;oOmXbogoJ<_mol7>i002o`0000;ocOSX00?oVX[1oi:5`_nBQL80
0omoN/@01?mCH<?o022/o`00NOl06Id2og>Ok0;oZYg:1?nmWKL00oo8Wjkob9j]olRN[@03omNXY`;o
g:bT0_o[^Z403Oob`Ygon<VIooS9VOomdI?oomR<oogMQ?oahgcok>N1onW^S_oYmJ;oj?^jon?kdOoJ
m>000_o?jNP01?o2f>[o0000ok[@jonbanX2ojo4j@03ojc1j?n[_nSoZ[kX00CoZ[kX3?nY_NP00ol0
003oooooooooo`0Booooo`002Oooool01000003ooooooooooooooolA000000D06ATI00D0000003<c
<`0c<c<0<c<c0000000204a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl00`000000VIVI09VI
V@0;09VIV@050000001oOgl0Ogmo07moO`0000000P1VIVH01@000000C4a<04a<C01<C4`000000080
<c<c00<0000001TI6@0I6AT00`0I6AT00ol0000000000000000L00000003o`00000I6AT06ATI0080
6ATI00l0000003<c<`0c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0000002IVIWo00000;>c
/ol000000P3<c<`00ol00000i^KV0>KViP060>KViP0>o`00003<c<`0c<c<o`00002c/k?o000009VI
V@000000Ogmo0000001VIVH0000004a<C000000203<c<`030000000I6AT06ATI00806ATI50000004
ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool3ojRmj003ojNlj?nV^nWo
XkWY00;oXkWY0_nM]NT01OnA[NWo0000o`000?l0003oEh;P00;o7UC<00Go026[o`0FXOl008Oo42BR
oa0KV002oc8`W`03od<hW_mKAj7oG4ZS00;oL5JU0_n4IJP3oiMf[004ojN5/?njUk?o^YNcolRY^`;o
glBm0_obgKP01ooik:_olnnJoo3YR?oMj7oognn>oo3g]_oZh/T00_oG`L@01?o9ZKWo`j_2ol>[`_o3
Zl83okRO_`03ok6Paon^UKgoYi?000;oYi?00onRT<801?nNSL7oVX2foiMm]OnGOKD2oi9j]@?oQG>g
00GoIV6hoe=P`ol08:co00BFo`0IW@02og>Ok0;oZYg:0_nmWKL01OnfUKKob9j]olRN[Oo8WZgobIj[
00;oejRW0_oL[:@2on^jX@0<oo;2WOohbIWooM6CoogATooof8con>5noo7SO?o/ih7ojNj>omG]RooN
o/Wof?WN0_o?jNP00oo4gNco^]3[o`000002okC:j`03ojo4jOn]`NWo[L7Y00;oZkoX0onZ_^P=ojVm
j003o`000?oooooooooo01;ooooo0009ooooo`0400000?oooooooooooooooa4000001@0I6AT01@00
0000<c<c03<c<`0c<c<000000080C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`030000002I
VIT0VIVI00/0VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP050000001<C4`0C4a<04a<C000
00000P0c<c<00`0000006ATI01TI6@0301TI6@03o`0000000000000001`0000000?o000001TI6@0I
6AT00P0I6AT03`000000<c<c03<c<`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VIVOl0
0000/k>co`0000020<c<c003o`00003Vi^H0i^KV00H0i^KV00ko00000<c<c03<c<co00000;>c/ol0
0000VIVI0000001oOgl0000006IVIP000000C4a<00000080<c<c00<0000001TI6@0I6AT00P0I6ATD
000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03ojRmj?nX_>So
Z;cX00;oY[_Y00?oXkWYoj2hj_l000000_l000003_nG/^_oQZO[ofVCiomYTnOo>FkJoaiDc?l1>;_o
026[o`0FXOl01Hoo41^Hob0PU_lb<9oo@cRN0_mKAj42og1FY@;oQ6FX0_nGMZ`01OnWQ:ko^YNcokZG
/onjUk?odZnf00;oglBm00Sol]fhooW/Zooik:_ol>V8onCVOOoOkhkoko>Roo;S_@?oel740_o9ZKT0
0oo3Zl;o_YjhokjN^002okRO_`?o[YFm0_nWTl02oj:@`P03oif3]onJP;KoVX2f00;oUgfe0_nBN[D3
ohEc]`;oIV6h00?o02V^o`00Gol019H00_m4K=@2ojZMbP03okfM]onfUKKo]YFf00;ob9j]0_o9WZ/2
omNXY`;og:bT00coi;:Roo;2WOob`Ygon<VIoogATooof8cooMf4ooSQO_oahgcoc]MPoloPL?oEkH/2
omSigP06olk^jOo4gNco^m?/ok_Ck?ndb^_o00000_n`aNX00on]`NWoZl3XojZnj003ojZnj0ooZKgX
00?o0000ooooooooool04Oooool000Wooooo00@00000oooooooooooooooo4@00000501TI6@050000
000c<c<0<c<c03<c<`0000000P1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00<0000009VI
V@2IVIT02`2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00D0000004a<C01<C4`0C4a<0000
000203<c<`030000000I6AT06ATI00<06ATI00?o0000000000000000700000000ol000006ATI01TI
6@0201TI6@0A0000000c<c<0<c<c03<c<`000000C4a<0000001VIVH0000007moO`000000VIVIo`00
002c/k?o00000<c<c?l00000103Vi^H2o`0000<0i^KV00ko00000<c<c03<c<co00000;>c/ol00000
VIVI0000001oOgl0000006IVIP000000C4a<00000080<c<c00<0000001TI6@0I6AT00P0I6ATD0000
00Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Oooooo`03ojRlj?nW_>WoYkcY
00?o00000_nP^>X01?nG/^_oSk3/ogRQk?mhXN`2ofVCi`09ocU^f_lNE<co002Ao`00Q_l008Oo41^H
ob0PU_lb<9oo@cRN00;oFdNQ0_mfFZD2ohAUZ003oiMf[?nWQ:koYhB^00?o^YNc0_oB[kH01_oOa;go
l]fhooWNZoojjI[ol>V8onCVO@;oko>R00?ol^>momfo^ooG`L@00oo9ZKT3okjN^003okRO_onfU[Oo
]YJg00;o[YFm00?oYi?0oj>7]onMPkL00_nMPkL3oiZ0]P;oUgfe0_nBN[D3ohEc]`03ofIQ^?l0:Jko
001c00;o00BF00?oA6cDoiB9aOnDRLD01?nfUKH01?o8WZgobIj[olVNZoo9WZ/3omb/Y00>onBbX_ob
`Ygol/:MooS9VOomdI?oomR<oogMQ?oahgcoe=AJolkGH?oEkH_odoo5omSig_o>k^T2ol?Qk@06ok_C
k?ndc>_o]<c[ok35j_l0003o[L;Y0on[`>P3ojZnj13oZKgX00?o0000ooooooooool04?ooool000Wo
oooo00@00000oooooooooooooooo4@00000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`0
1@000000IVIV06IVIP1VIVH000000080Ogmo00<0000009VIV@2IVIT0302IVIT010000000Ogmo07mo
O`00000206IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI01TI6@0301TI6@03
o`0000000000000001/0000000?o000001TI6@0I6AT00P0I6AT02P000000<c<c03<c<`000000C4a<
0000001VIVH0000007moO`00000209VIV@;o00000P3<c<`00ol00000i^KV0>KViP02o`000080oooo
017o00000>KViP3Vi^H0i^KVo`00003<c<co00000;>c/ol00000VIVI0000001oOgl0000006IVIP00
0000C4a<0000000203<c<`030000000I6AT06ATI00806ATI50000004ooooo`0300000?oooooooooo
017ooooo00?o0000ooooooooool07oooool3o`000004ojNljOnU^nWoXk[Zoj>jjP;oW;O[0_n?/>`2
ogRQk009oe25iOlCEm3o4eO@o`0HY_l008Ko0027o`04R_l@6iSo822F00;o@cRN00?oFdNQogIJYOmf
FZD00_n@KjT4ojN4[P05okZG/ooB[kKodZnfom:_]_oYbK@00_oigZ/01Oo`jHSoi>Imom7QLoo_lj;o
l^>m00;ogKnk0oo9ZKT2ol:L/0;o_Yjh0onfU[L00on^UKgoZhbdoj>7]`02oj>7]`?oWH>g0_nJP;H2
oiMm]@;oTWZe0on5LkL01omVHKSo9CV`o`0Y[_l006Go00BFobm<_om4K=@00_nDRLD3okJE]P04olRN
[Oo9WZ_obIj[olVNZ`;og:bT0_oT/Z802_o/^ikon<VIooS9VOomdI?oomR<ooSQO_oQeUkoc]MPoloP
L?o:m9l2om?lg`05ol_`k?o3hNgo^]G]ok[EkOndc>/00_n`a^X00on]`^Wo0000oj^oj003oj^oj0?o
Z[kX3onY_NP00ol0003oooooooooo`0@ooooo`002Oooool01000003ooooooooooooooolA000000D0
6ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl0
0`000000VIVI09VIV@0<09VIV@040000001oOgl0Ogmo00000080IVIV00D0000004a<C01<C4`0C4a<
0000000303<c<`030000000I6AT06ATI00<06ATI00?o00000000000000006`0000000ol000006ATI
01TI6@0201TI6@0@0000000c<c<0<c<c0000001<C4`0000006IVIP000000Ogmo0000002IVIWo0000
0;>c/ol00000c<c<o`000080i^KV00?o00000?ooo`3oool00`3oool04?l00000i^KV0>KVi_l00000
c<c<o`00002c/k?o000009VIV@000000Ogmo0000001VIVH0000004a<C000000203<c<`030000000I
6AT06ATI00806ATI50000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool07?oo
ool3o`0000;ooooo0onV_>T00onS^^[oXK[[oiRfk@02oiRfk@;oQZg^00[oIY[]obmdhOl_M>7o4eO@
o`0HY_l0097o001]o`05Sol@6iSo822F0_m3>9h00omKAj7oMUZUogIJY@03oi1_Z@?oYhB^00[o^YNc
om:_]_oB[kKodZnfonW9]?oigZ_on^VJoo3YR?oQhG7oko>R0_obhkd2omfo^`03olfW/_o9ZKWo`Yb`
00;o`Yb`00?o_YjhokbF/?nlU[000_nfU[L3oj^<]0;oXhNg0onMPkL2oiZ0]P04oiMm]OnEMJcoTg>/
oi=c[0?oRfn^00GoN6B`ofIQ^?lU>K3o001@o`00I@02obm<_`;oU8W50onfUKH4olVNZ`;og:bT0_oT
/Z803?o/^ikomLFJoogATooof8cooMf4onoIJOoQeUkoc]MPol[dWoo7oLCodocOol_`k0;o`N;_00Co
^]G]okC<k?ndc>co/<KZ0_n]`nT01?l0003o[<3Yoj^oj?n[_nP3ojZnj17oZKgX00?o0000oooooooo
ool03oooool000Wooooo00@00000oooooooooooooooo4@00000501TI6@050000000c<c<0<c<c03<c
<`0000000P1<C4`01@000000IVIV06IVIP1VIVH000000080Ogmo00<0000009VIV@2IVIT0302IVIT0
10000000Ogmo07moO`00000206IVIP050000001<C4`0C4a<04a<C00000000`0c<c<00`0000006ATI
01TI6@0301TI6@03o`0000000000000001X0000000?o000001TI6@0I6AT00`0I6AT040000000<c<c
03<c<`000000C4a<0000001VIVH0000007moO`000000VIVIo`00002c/k?o00000<c<c?l000020>KV
iP03o`00003oool0oooo00<0oooo013o00000>KViP3Vi^Ko00000<c<c?l00000/k>co`00002IVIT0
000007moO`000000IVIV0000001<C4`000000P0c<c<00`0000006ATI01TI6@0201TI6A@000001?oo
ool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`03ojJljOnU
_>WoYKcY00;oXK[[00?oV;K]oiBek_nD]Nh00_mmZ_002omBT^ko;gCQo`0j_olCEm3o01RVo`00Q_l0
08Oo00B:ob0PU_ll<I_o@cRN00;oFdNQ00CoMUZUoi1_ZOn@KjWoT6nY0onWQ:h3om:_]P06onW9]?oi
gZ_onMj[oo[YV_oQhG7od]]X0_ofh[D2omfo^`;ocJNb1?o2W;03okbF/003okJF]ondT;3oZhbd00?o
Zhbd0_nSQkL01?nMPkOoV7V_oiIf[OnFMZd2oiEe[0?oTg>/0_n;Kjh2ogQT/005obDi/?l007So001U
o`04U_l_C;l00on6NKd00onfUKKo/Y2colVNZ`02olVNZ`;ocJ6Y00gog:bTonBbX_o/^ikok;^NooG5
V_omci;oomN7oo[KNOo_fFWoe=AJo`000?ngkIWobogR00;oaO3_00Co`N;_okSEkonheNoo]<c/0_n_
a^/01On]`nWo[<3Yoj^oj?l0003oZkoX00?oZ[kX4onY_NP00ol0003oooooooooo`0>ooooo`002Ooo
ool01000003ooooooooooooooolB000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C004
0000001VIVH0IVIV000000<0Ogmo00<0000009VIV@2IVIT0102IVIT3000000D0VIVI00Co000007mo
O`1oOgoo00000P1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c00<0000001TI6@0I6AT00`0I
6AT00ol0000000000000000I00000003o`00000I6AT06ATI00806ATI00@0000003<c<`0c<c<00000
0P1<C4`02_l00000000007moO`000000VIVIo`00002c/k?o00000<c<c?l000020>KViP03o`00003o
ool0oooo00D0oooo00oo00000>KVi_l00000c<c<o`00002c/k?o000009VIV@000000Ogmo0000001V
IVH0000004a<C00000000P0c<c<0100000006ATI01TI6@0I6ATE000000Cooooo00<00000oooooooo
ool04Oooool00ol0003oooooooooo`0Fooooo`?o00002_ooool00onU_>WoYKcZojFljP03oinjk0;o
U;G^0_mmZ_02oe:BkP06o`0j_ol0093o001ho`00Qol018[o822F0_ll<I/2oe]7X@;oMUZU0_n@KjT3
ojN4[P09okfI/_oB[kKojLVdonW9]?oigZ_on^VJoo3YR?oQhG7ok?2D00;om^:e00CohKjeomfo^oo=
Yk;ocJNb1?o2W;03okbF/0?o]92`0_n[S;@00onXQJooWWj`oiin/002oiQi[`;oUWJ]0_nEMJ`3oi=c
[0?oRfn^00GoN6B`od];/?lU>K3o001@o`00QP02obm<_`;oQWVm0onbT;<01?o9WZ_ocJ6YolfQZOo=
XJT2onBbXP;ok;^N00[omLFJoog?T_ooehOon]]ion7FG_o>ef3o]nfIok[kb?o2nnSoaO3_0_nlgo40
1?nheNoo//c]ok;<kOn_a^/2ojg2jP;o[<3Y00CoZkoXo`000?nZ_^SoZ[kX5?nY_NP00ol0003ooooo
ooooo`0>ooooo`002Oooool01000003ooooooooooooooolB000000D06ATI00D0000003<c<`0c<c<0
<c<c0000000204a<C0040000001VIVH0IVIV000000<0Ogmo00<0000009VIV@2IVIT00P2IVIT20000
00<0/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00@00000
04a<C01<C4`000000`0c<c<00ol000006ATI01TI6@0401TI6@03o`0000000000000001L0000000?o
000001TI6@0I6AT00`0I6AT04P000000<c<c03<c<`000000C4a<0000001VIVH0000007moO`000000
VIVIo`00002c/k?o00000<c<c?l00000i^KVo`0000P0oooo00oo00000>KVi_l00000c<c<o`00002c
/k?o000009VIV@000000Ogmo0000001VIVH0000004a<C00000000P0c<c<0100000006ATI01TI6@0I
6ATE000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`;o00003ooo
ool2ojFljP03oinjk?nN^^coW[[/00;oT;G_0_meZO802ollRngo01ZTo`00T?l007So001]o`04R_l=
4i3o822Foc`aVomNBZ;oFdNQ00;oMUZU0on@KjT01?nWQ:ko_IVbokfI/_oB[kH2onW9]004ooWNZooj
jI[olnR8om;KJ0;om^:e0_oQ_[D2olfW/P;oaIZ[0_o2W;02ol6FZ`;o_9J`0ondT;000on[S;CoZ8F_
ojR5[`02oiin/0?oV7V_0_nFMZd2oiEe[0;oTg>/0on;Kjh01OmhI;3oBd^`od];/?l008[o001U00;o
9S^b0_n6NKd3ok:@/`04olVNZoo=XJWocJ6YolfQZ@;oi;:R00_ok;^NooG5V_oeaI[ooLnBoooGQoo_
fFWohMINo`000?njnlSo`__Xokk/l`02okcOl@;o]M;_00Co//c]ojk5jon^aN_o[L;Z0_n[`>T2oj^o
j003ojZnj?l0003oZ[kX017oZKgX0oooool00ol0003oooooooooo`0>ooooo`002Oooool01000003o
oooooooooooooolB000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0
IVIV000000<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000002I
VIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP040000001<C4`0C4a<000000<0
<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000000F00000003o`00000I6AT06ATI00<0
6ATI0180000003<c<`0c<c<0000004a<C0000000IVIV0000001oOgl0000009VIVOl00000/k>co`00
003<c<co00000>KVi_l000080?ooo`0?o`00003Vi^Ko00000<c<c?l00000/k>co`00002IVIT00000
07moO`000000IVIV0000001<C4`000000080<c<c00@0000001TI6@0I6AT06ATI5@000004ooooo`03
00000?oooooooooo013ooooo00?o0000ooooooooool04_ooool3o`0001;ooooo0_nT_>X00onN^^co
WK[]ohjel@02ohjel@;oKjWd00So;8K[o`0JY?l0093o001Bo`00N_l=4i3o822Foc`aV`;oGTZR0_mf
FZD2oi1_Z@04oj>0[_nmVK;o_IVbokfI/P;of;Bd0_oigZ/01?oliJ7ohN5aonc`U?ofh[D3on6n]@05
om2V[_o=Yk;oaIZ[olFJZoo2W;000oo1UZ/00onlU[3o_9:/okbB[002okB@/0CoZ8F_0_nNO[02oiQi
[`;oUWJ]0_nEMJ`3oi=c[0;oRfn^0_mhI;001?m;Bk3o002:o`00D?l008h2obHk/P;oQWVm0_nbT;<4
olfQZ@04omFWZ?oT/Z;ok;^NooG5VP;ooLnB00?oomN7onoIJOoDe5X00_nkmo001?nnk??o]m_bok7>
konac^l3ok39k@05ojk5jon/`^[o[<;Zoj_0jOnZ_nP00onZ_^P00ol0003oZKgXojVmj00>ojVmj0Go
oooo00?o0000ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo4P00000501TI6@05
0000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000307moO`030000002IVIT0
VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<2000000<0VIVI00D0000007moO`1oOgl0Ogmo0000
000206IVIP040000001<C4`0C4a<000000<0<c<c00<0000001TI6@0I6AT01@0I6AT00ol000000000
0000000D00000003o`00000I6AT06ATI00<06ATI00@0000003<c<`0c<c<000000P1<C4`03@000000
IVIV0000001oOgl0000009VIVOl00000/k>co`00003<c<co00000>KVi_l00000203oool03ol00000
i^KVo`00003<c<co00000;>c/ol00000VIVI0000001oOgl0000006IVIP000000C4a<0000000203<c
<`040000000I6AT06ATI01TI6AD000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo0ol0000Eooooo`?oY;cZ0_nM^^d00on>]O7oSkKaohnfl@02ofj[mP07obJ7jol006go
001So`00I?l018[o3A>@oc`aV`02oei:XP;oPVFY0onSP:h3okfI/P;of;Bd00KolM6`oocUXOocj8So
`m5HooOQ/_oS_[82on6n]@;od:J^0oo5VZ/4ol6FZ`?o_9:/00?o]92`ok><[OncS:d00onXQJl2oiin
/0;oV7V_0_nFMZd2oiEe[0;oTg>/00?oU72Woi5_Z?nAKjP00_n6JJ/2od];/004o`00R_l008Ko9S^b
obHk/P;oOg6i00?o/Y2cok:?/_nbSk800_o=XJT2omFWZ0;ok;^N00SomLFJoog?T_omci;oomN7on7F
G_l0003o^oO`okSTm@;o/]Cb00?o/Lk_ojk7k?n]a>/00_n]a>/2ojc2jP;oZkoY0_nZ_nP3ojZnj003
o`000?nY_NSoZKgX00WoZKgX2_ooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooo
oooooooooolB000000H06ATI00@0000003<c<`0c<c<000000`1<C4`010000000IVIV06IVIP000002
07moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<01@2c/k<01@000000VIVI09VIV@2I
VIT000000080Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C0050000000c<c<0<c<c03<c<`00
00001`0I6AT2o`00018000000_l0000601TI6@04o`00000c<c<0<c<co`000080C4a<00X0000006IV
IP000000Ogmo00000?l00000/k>co`00003<c<co00000P3Vi^H00ol00000oooo0?ooo`060?ooo`0>
o`00003Vi^Ko00000<c<c?l00000/k>co`00002IVIWo00000000001VIVH0000004a<C000000203<c
<`030000000I6AT06ATI00806ATI5@000004ooooo`0300000?oooooooooo013ooooo00?o0000oooo
ooooool03?ooool3o`0001Wooooo1?nT_>X2oifjk@;oSkKa0_m^ZoH01OlVQn_o001So`00KOl018[o
3A>@00;o?36K00CoGTZRoh9UZOn2IJWoPVFY0onSP:h02OnmVK;of;BdomRd]?oH];ColM6`oocUXOoc
j8So_]1HooOQ/P02on>n/P03on6n]Oo@YZkod:J^00?oaIZ[00Co`iJWol6FZoo1UZ_o`IJ[0onlTZ`3
ok><[@?oZ8F_0_nNO[001?nHNJooTg6Yoi9`Z?nBL:P5oiA`Y`;oTFnX0_n6JJ/2ofYK[P04o`0GWol0
07_o9S^bobHk/P;oOg6i0onbSk82olfQZ@;oeJNX0_o/^ih01_oeaI[ooLnBoooGQoojfgWoaLI5okK^
mP;o/]_e00?o/]Cbojk:k_n^b^h00_n^an`00on]a>_oZl7Yoj_1j@02oj^oj@GoZ[kX0_nY_NP00ol0
003oZKgXojVmj005ojVmj0gooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooo
oooooooo4`00000501TI6@050000000c<c<0<c<c03<c<ol000000P1<C4`010000000IVIV06IVIP00
000207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<01P2c/k<01Ol00000VIVI09VI
V@2IVIT000000080Ogmo00Go00000000001VIVH0IVIV0000000204a<C0040000000c<c<0<c<c03<c
<`8000001`0I6AT2o`0000`000001?l0000701TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`0
2P000000IVIV0000001oOgl00000o`00002c/k?o00000<c<c?l000020>KViP03o`00003oool0oooo
00H0oooo00ko00000>KVi_l00000c<c<o`00002c/k?o00000000001oOgl0000006IVI_l00000C4a<
00000080<c<c00<0000001TI6@0I6AT00P0I6ATE000000Cooooo00<00000ooooooooool04?ooool0
0ol0003oooooooooo`09ooooo`?o00007_ooool3ojBljP;oW[_]0_nA^?42og>_m`07obf?kol005;o
001jo`dCT?lf;ico?36Koei:XP03oh9UZ@?oXh2^00So_IVbomRd]?oH];ColM6`oocUXOocj8So`m5H
ooOQ/P?ohkjb0_o@YZh2olNJZ003olFJZoo3UZOo`iJW00;o`IJ[0_o1U:P2okbB[0?o/hb]0onXQJl2
oiUgZ`;oTg6Y0_nBL:P5oiA`Y`;oTFnX0_n6JJ/3ofYK[P05o`00Aol008Ko9S^bobHk/_moLKT01?nb
Sk801?o=XJWoeJNXomFWZ?oP/JH2ooG5VP06oog?T_ooehOokmUYok2k>Onah_Oo/]_e0_n^cO000on^
b^ko[<C[ojc4j`02ojc2jP03oj_1jOnZ_nWoZ[oY00CoZ[kX0_nY_^P2ojVmj004o`000?nY_NSoZKgX
ojVmj17ooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo4`000005
01TI6@05o`00000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVI_l0000207moO`030000
002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<01`2c/k<200000080VIVI00@0000007moO`1oOgl0
00000P1VIVH01Ol00000C4a<04a<C01<C4co000000@0<c<c00<0000001TI6@0I6AT01P0I6AT<o`00
00X06ATI00<0000003<c<`0c<c<00P0c<c<03@000000C4a<04a<C0000000IVIV0000001oOgl00000
o`00002c/k?o00000<c<c?l000000P3Vi^H00ol00000oooo0?ooo`060?ooo`0>o`00003Vi^Ko0000
0<c<c?l00000/k>co`0000000000Ogmo0000001VIVH0000004a<C000000203<c<`030000000I6AT0
6ATI00806ATI5@000004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool01_ooool3
o`0002;ooooo00?oY;cZojFlj_nO_>d00_nO_>d2oiBjl@;oO;Cg00Go001Co`00I?l=4i3o=RnLoc`a
V`02oei:XP;oPVFY0onSP:h2omRd]0;olM6`00Coo>FQoo?XR?o1eV7omn6b0ooS_[801OoBYjcod:J^
olNJZ?o7VZSoaIZ[00?o`iJW00Co`IJ[ol6DZ?o1U:So_9:/0_nlTJX3ok><[@04ojR5[onTP:coVGN[
oiUgZ`;oTg6Y0_nBL:P6oiA`Y`;oTFnX0_n6JJ/2ofYK[P04o`0GWol007_o7C:/obHk/P;oOg6i0_nb
Sk800onhU;;oeJNXomFWZ002on2aYP06onfoXoomci;ooLnBoooGQooOe5_o/N;g0_n^dO801On^cO3o
[<G/ojc5k?n/a>_oZl7Y00?oZl3Y00?oZ[oYojZnj?nZ_^P00_nZ_^P2ojVnj0CoZKgX00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooooolD0000
00@06ATI00<0000003<c<`0c<c<00P0c<c<01P000000C4a<04a<C0000000IVIV000000<0Ogmo00D0
000009VIV@2IVIT0VIVI0000000;0;>c/`040000002IVIT0VIVI00000080Ogmo00@0000006IVIP1V
IVH000000`1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI01X06ATI00<0000003<c
<`0c<c<00P0c<c<03P000000C4a<04a<C0000000IVIV0000001oOgl0000009VIVOl00000/k>co`00
003<c<co00000P3Vi^H00ol00000oooo0?ooo`050?ooo`08o`00003Vi^Ko00000<c<c?l00000/k>c
o`00002IVIT200000080IVIV00<0000004a<C00000000P0c<c<0100000006ATI01TI6@0I6ATF0000
00Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`?o00009_ooool2ojFl
jP05oinlkOnQ_>coXKc/oj6lk?nI^o000_n6^?H01?l004_o00N=o`dCT?lf;i`2oei:XP?oPVFY0_nS
P:h02?nmV[Cof;Bdoo7A/?oadK3oo>FQooG[T_oXki7omn6b0_oS_[82om:W[003om2V[_o7VZSoaiZX
00Co`iJW0oo1U:P00onlTZco_96ZokbAZP02ok><[@03ok6:[?nTP:coY82/00;oVGN[0onCLJT2oi9`
Z0GoU72W0_nAKjP2ohIYZ`;oJU^^00Co;C^^o`00NolM<Zco7C:/0_moLKT00onbSk;o^9BbokRD/P02
omFWZ0;oh;6V00GokKnSooW?W?oicicoomN7olG6A@02ojc9k`;o[<O^00?o[<G/oj_1j_n[`NX00_n[
`NT01On[`>WoZ[kXojZnj?nZ_^SoZKkX00CoZKgX1Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00gooooo0009ooooo`0400000?oooooooooooooooa@000001@0I6AT01@000000<c<c
03<c<`0c<c<000000080C4a<00@0000006IVIP1VIVH000000P1oOgl01Ol00000VIVI09VIV@2IVIT0
000000`0/k>c00Co000009VIV@2IVIWo00000P1oOgl01?l00000IVIV06IVIP00000304a<C0030000
000c<c<0<c<c0080<c<c0P00000H01TI6@8000001@0c<c<00`000000C4a<0000000206IVIP090000
001oOgl0000009VIVOl00000/k>co`00003<c<co00000080i^KV00?o00000?ooo`3oool0103oool0
2Ol00000i^KV0>KVi_l00000c<c<o`00002c/k?o000009VIV@020000000506IVIP000000C4a<04a<
C00000000P0c<c<0100000006ATI01TI6@0I6ATF000000Cooooo00<00000ooooooooool03oooool0
1?l0003oooooooooooooool3o`0002_ooooo0_nV_NX00onQ_>coXkg[oj>mj`02oiflkP04o`00D_l0
1hgo3A>@ocH_W0;oIeBX0on2IJT00onSP:ko_IZdokfJ]002omfm^006oocUXOoeji;oj>nAooGR]ooR
_kCohkjb0ooBYj`3olNJZ0Co`iJW0oo1U:P3okbAZP03ok><[OnaRZco/HZ/00?oY82/0_nIMj/2oi=a
Z@;oTW2X1OnDL:L2oi5_Z0;oQVV[0omZFjh00ol]>jko001koadb[002ogi`^@Co^9Bb00CoeJNXon2a
Y_o]_j?okKnS0_oici`01?oofhko0000ojc9konZ`n/3oj_2j`03oj_1j_nZ_nWoZ[oY00;oZ[oY00?o
Z[kXojVnj?nY_^P00_nY_^P00onY_NSoooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo5000000501TI6@050000000c
<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VI
V@000000302c/k<01@000000VIVI09VIV@2IVIT000000080Ogmo00@0000006IVIP1VIVH000000P1<
C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI01@06ATI00<0000003<c<`0c<c<01@0c
<c<00`000000C4a<0000000206IVIP090000001oOgl0000009VIVOl00000/k>co`00003<c<co0000
0080i^KV00?o00000?ooo`3oool0103oool02Ol00000i^KV0>KVi_l00000c<c<o`00002c/k?o0000
09VIV@020000000506IVIP000000C4a<04a<C00000000P0c<c<0100000006ATI01TI6@0I6ATF0000
00Cooooo00<00000ooooooooool03oooool4o`0002kooooo0onV_NT00onS_N_oYKg[oj6mk@02oj6m
k@03o`00I?l=4i3o=RnL00;oIeBX0onFN[43okfJ]0;ogKfh00Gommn`ooG[T_oSli[omN:gon:o]004
om:W[0;oaiZX0_o5UZH2ol>FY`;oaIJV0_o1U:P3okbAZPCo/HZ/0_nTP:`2oiUgZ`;oTg6Y0_nBL:P5
oiA`Y`04oi5_Z?nGLJGoTVnXoi9_Z0?oPVV]00?o;C^^o`00NolM<Z`00omnL;T3okRD/P;oh;6V0_o]
_j<2ooW?W003oooKS_nZ`ncoZ/?[00;oZ/?[00CoZl;[ojZojOnZ_nWoZ[oY1OnY_^P<ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo
5000000601TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207mo
O`040000002IVIT0VIVI000000D0/k>c1Ol000030;>c/`040000002IVIT0VIVI00000080Ogmo00D0
000006IVIP1VIVH0IVIV0000000204a<C08000001@0c<c<3000001006ATI0`00000703<c<`030000
001<C4`0000000<0IVIV00T0000007moO`000000VIVIo`00002c/k?o00000<c<c?l000000P3Vi^H0
0ol00000oooo0?ooo`030?ooo`06o`00003Vi^H0i^KV0>KVi_l00000c<c<0_l0000209VIV@800000
00D0IVIV0000001<C4`0C4a<0000000203<c<`040000000I6AT06ATI01TI6AH000001?ooool00`00
003oooooooooo`0?ooooo`;o0000<Oooool00onV_NWoYkgYojNmj@02ojFmj`05oj6mkOnT_^co001;
o`07SOlf;i`00omWE:P3oiIj/@07okfJ]?oM_KSogKfhomfm^?oeji;ofmm^ooGR]`02on:o]003om:X
[_oBYjcodZN/00;obI^X00CoaiZXolFFY_o5UZKo`iJW0oo5UZH00oo1U:Soa9JWolBFY`02okbAZP04
okjCZ_naRZco/HZ/ok6:[0;oY82/0_nIMj/2oi=aZ@;oTW2X1?nDL:L00onGL:CoUg6UoiMaY@03oi9_
Z0;oPVV]00CoGUZfo`00Jol@:jWo7C:/0_mnL;T3okRD/P;oh;6V00GokKnSooW?W?oiciconLnLolG6
A@02oj[0jP?oZ/3Y00?oZ[oYojVnj?nY_^P00onY_^P?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo5@00000501TI6@050000000c
<c<0<c<c03<c<`0000000P1<C4`010000000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VI
V@000000102c/k<01Ol00000c<c<0<c<c03<c<co000000@0/k>c00@0000009VIV@2IVIT000000P1o
Ogl01@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<01@0c<c<4000000806ATI
2P00000903<c<`04o`00001<C4`0C4a<o`000080IVIV00D0000007moO`000000VIVIo`0000020;>c
/`03o`00003<c<co000000<0i^KV00Go00000?ooo`3oool0ooooo`0000030>KViP0:o`00003<c<co
00000;>c/ol00000VIVI0000001oOgoo000000000080C4a<00@0000003<c<`0c<c<000000`0I6ATG
000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0_ooooo`03ojNmjOnX_NWo
Z;gY00;oY[gZ00?oY;k/o`00Bol01hd00_lf;i`2ofMDZ0?oUWZa00So_IZdomfm^?oM_KSommn`ooG[
T_oSli[omN:gon:o]0;odZR^0_oBYj`2olVKZ004olNJZ?o5UZKoaIJVol>FY`?oaIJV00Co`IBXolBF
Yoo4UZOo_96Z0_nnTjX3ok6:[004ojB0[?nOO:coTg:Zoi=bZP;oSVbX0_n?K:H3oi=]Y@;oUg2T0_nG
LJD3oi9_Z0;oPVV]0_mNF[H01?l007_o42^Yogi`^OmnL;T3okRD/P03ol>O/oo]_j?okKnS00;onLnL
00?oom^>ojW0j_nZ`>X01?nY_^T2ojVnj1Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0<ooooo`002Oooool01000003ooooooooooooooolE000000H06ATI00D0000003<c<`0c<c<0
<c<c0000000204a<C0040000001VIVH0IVIV00000080Ogmo00@0000009VIV@2IVIT00000102c/k<0
0ol00000c<c<0<c<c0020<c<c003o`00002c/k<0/k>c0080/k>c00Co00000000002IVIWo00000P1o
Ogl200000080IVIV00D0000004a<C01<C4`0C4a<0000000:03<c<`8000004@0c<c<2000000<0C4a<
00P0000006IVIP1VIVH0000007moO`000000VIVIo`000080/k>c00?o00000<c<c?l000000`3Vi^H2
o`0000030?ooool00000i^KV00<0i^KV00Ko00000<c<c?l00000/k>co`00002IVIT20000000506IV
IP000000C4a<04a<C00000000P0c<c<01?l000006ATI01TI6@0I6ATG000000Cooooo00<00000oooo
ooooool04_ooool00ol0003oooooooooo`0_ooooo`CoZ;gY0_nW_NT00ol01hgo<cBTocH_W002ofMD
Z0?oUWZa0_oM_KP2ooOO/004om;RMOoSli[oh[ndon:o]0?odZR^00?odZN/olVKZ?o9VjP01oo5UZH3
olBFY`?o_Y>Z0onaRZ`2oiml[0;oTg:Z0_n>K:P2ohm/YP?oTffU0_nGL:@3oiMaY@;oTVnX0on2JJd0
0omNF[Ko001[oa0[Z@03oh=f_@03okRD/_o3Wk?o`inc00;okKnS0_oici`01?oofhkoZKkYojVnjOnY
_^TJooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000Wooooo00@00000
oooooooooooooooo5P00000501TI6@05o`00000c<c<0<c<c03<c<`0000000P1<C4`01?l00000IVIV
06IVIP00000207moO`040000002IVIT0VIVI000000@0/k>c00?o00000<c<c03<c<`00`3<c<`00ol0
0000/k>c0;>c/`020;>c/`040000002IVIT0VIVI000000<0Ogmo00@0000006IVIP1VIVKo00000`1<
C4`00ol0000000000000000G03<c<`<00000101<C4`02@000000IVIV06IVIP1VIVH0000007moO`00
0000VIVIo`0000020;>c/`03o`00003<c<co000000D0i^KV00?o00000>KViP3Vi^H00P3Vi^H01ol0
0000c<c<0<c<c?l00000/k>co`00002IVIT00P0000001@1VIVH0000004a<C01<C4`000000080<c<c
00@0000001TI6@0I6AT06ATI5`000004ooooo`0300000?oooooooooo01?ooooo00?o0000oooooooo
ool0<?ooool01onX_NWoZKgXojRmjOnX_NWo001;o`07SOlc=:@00omWE:P02_nFN[7o]ibmokNL_OoM
_KSommn`ooG[T_oEnk?ok^G4omk1^ooR_k@3om:X[P?obI^X0oo5UZH01?o7UjKoaIJVolFFY_o5UZH3
olBFY`Co_Y>Z00Co/HZ/ojn9[_nOO:coWgb/0_nCLZX2ohi/Z0?oSfbV0_nCKJD3oiM`Y0;oUg6U0onB
KjP2oh9Y[@;oGUZf00Co42^Yoh=f_On3M[goPgJm0oo3Wk<01_oD/[KonLnLooW?W?oicicoom^>ojVn
jAcooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`002Oooool01000003o
oooooooooooooolG000000D06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0
IVIV00000080Ogmo00@0000009VIV@2IVIT000000`2c/k<00ol00000c<c<0<c<c0040<c<c0;o0000
0`2c/k<010000000VIVI09VIV@00000207moO`050000001VIVH0IVIV06IVIP0000001@1<C4`30000
00T0<c<c2`00000604a<C0070000001VIVH0IVIV06IVIP000000Ogmo0000000209VIV@04o`00002c
/k<0/k>co`000080c<c<00?o00000>KViP3Vi^H01P3Vi^H01ol00000c<c<0<c<c?l00000/k>co`00
002IVIT00P0000001@1VIVH0000004a<C01<C4co000000<0<c<c00<0000001TI6@0I6AT060000004
ooooo`0300000?oooooooooo01Cooooo0_l0000aooooo`;oZKgX00CoZ;gYokUO0?l01hgo<cBT0omj
K;L3okNL_@;ohLo600Cod^9eonkUa?oN`K_og/6k1?oBZ:h2olVKZ0;oaYNW00?oaIJVolNGY_o7UjH0
0_o5UZH2olRJY`03olBFYoo7VjWoai^Y00?o_Y>Z0on_RJh2oiml[0;oTg:Z0_n>K:P2ohm/YP?oTffU
0_nGL:@2oiMaY@?oTVnX00KoPVV]oiQi[on6Mk_oQWNko`00Jol@:jT3oh=f_@03ol>O/ooD/[Koe;:f
00;ojlbg00?oom^>ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00cooooo0009ooooo`0400000?oooooooooooooooaP000001@0I6AT01@000000<c<c03<c<`0c<c<0
00000080C4a<00H0000006IVIP1VIVKo000007moO`00000209VIV@040000002c/k<0/k>c0;>c/`;o
00001`3<c<`01Ol00000/k>c0;>c/`2c/k<000000080VIVI00@0000007moO`1oOgl000000`1VIVH2
000000H0C4a<2@00000>04a<C080000000Go000006IVIP1VIVH0IVIV0000000207moO`040000002I
VIT0VIVIo`000080/k>c00Co00000<c<c03<c<co00001P3Vi^H2o`000080c<c<00Wo00000;>c/ol0
0000VIVI0000001oOgl0000006IVIP0000000P1<C4`010000000<c<c03<c<`00000301TI6AP00000
1?ooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo02oooooo0onY_NP00ol008co<cBT
oc<dY003ogY/]`;o]ibm0_oQclH2onkUa0;og/6k00?od:bdom:X[_oBZ:h00_o9WJ/01?o9VjSoaYNW
olJGYoo5UZH2olNGYP;oaIJV0_o8VZL00oo4UZOoai^YolNKZ@02okjCZP04oknG[_n_RJko[hV^ojn9
[P;oWgb/0_nCLZX2ohi/Z0;oSfbV0onCKJD2oiM`Y0;oUg6U0_nBKjP00onNNJWoV7V_oiQi[`02ohIg
^`03oeYddol08jWoPgJm00;oPgJm00?o`incomBb]_oD/[H00_o[c;L00oojij[oooooooooo`0Noooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooo
oooooooo6000000501TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01P000000IVIV06IVIP00
0000Ogmo000000<0VIVI00Go00000;>c/`2c/k<0/k>co`0000070<c<c005o`00002c/k<0/k>c0;>c
/`0000000`2IVIT010000000Ogmo07moO`00000406IVIP800000501<C4`7000000@0IVIV00<00000
o`00001oOgl00P1oOgl010000000VIVI09VIVOl000020;>c/`04o`00003<c<`0c<c<o`0000D0i^KV
00Go00000<c<c03<c<`0c<c<o`0000020;>c/`07o`00002IVIT0000007moO`000000IVIV00000002
04a<C0040000000c<c<0<c<c000000<06ATI60000004ooooo`0300000?oooooooooo01Oooooo00?o
0000ooooooooool0;oooool2ojVmj003okUO0?lbAkSo<TNh00?oNVbg00Go]ibmon7?a_oQclKom?>^
om;4c@02omk1^`;od:bd00GodZR^olVMZoo9WJ_obIf[olVKZ002olJGY`05olFFY_o7UjKoaiNVolNG
Y_o5UZH00_o8VZL01?o4UZOoai^YolNKZOnnTjX3oknG[P;o[hV^0_nOO:`2oi=bZP;oSVbX0on?K:H2
oi=]Y@;oUg2T00?oUg6UoiigY_nNNJT00_nNNJT3oiQi[`;oQWNk00Co01NVohb6b?n<Q/SoS8K80_oD
/[H3on_<]`03oo[WZ_oooooooooo01oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0<ooooo`002Oooool01000003ooooooooooooooolI000000D06ATI00D0000003<c<`0c<c<0<c<c
0000000204a<C0060000001VIVH0IVIV0000001oOgl000000P2IVIT00`000000/k>c0;>c/`020;>c
/`03o`00003<c<`0c<c<00@0c<c<00?o00000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0
00000080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00704a<C0X000002P1VIVH0
0`000000Ogmo07moO`0307moO`040000002IVIT0VIVIo`000080/k>c00Co00000<c<c03<c<`0c<c<
1Ol000030<c<c008o`00002c/k<0/k>co`00002IVIT0000007moO`00000206IVIP030000001<C4`0
00000080<c<c00<0000001TI6@0I6AT00P0I6ATH000000Cooooo00<00000ooooooooool06?ooool0
0ol0003oooooooooo`0_ooooo`;oZKgX00Co002<oc97^?lbAkSoNVbg0_nPW]800ooQclKoe_7Som;4
c@02om;4c@03omk1^oo@[;Cod:bd00CobIf[0oo6UjL4olNGYP?ob9ZW0oo7VjT4oknG[P;o[hV^0_nG
N[42ohY^[@;oQfRY0on?K:H2oi=]Y@03oiM`Y?nJLjGoWWNV00;oWWNV0onNNJT2oiQi[`04ohIg^onZ
V<?oZYS3o`0GYP?oS8K800Coe;:fon_<]oo[c;Oon^NZ8_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooaT000001P0I6AT010000000
<c<c03<c<`00000304a<C0030000001VIVH000000080Ogmo00@0000009VIV@2IVIT000000`2c/k<0
0ol00000c<c<0<c<c0050<c<c005o`00002c/k<0/k>c0;>c/`0000000`2IVIT01@000000Ogmo07mo
O`1oOgl0000000D0IVIV2@00000A06IVIP<000001P1oOgl010000000VIVI09VIVOl000030;>c/`03
o`00003<c<`0c<c<00L0c<c<00Wo00000;>c/`2c/k<0/k>co`00002IVIT0000007moO`0000000P1V
IVH00`000000C4a<0000000203<c<`030000000I6AT06ATI00806ATI60000004ooooo`0300000?oo
oooooooo01Wooooo0_l0000`ooooo`04ojVmj?ngCP3o<TNhoc97^0?oX9kB0_oFlN<3om;4c@?od:bd
00Coaj:colVMZoo9WJ_obIf[0oo6UjL4olNGYP?ob9ZW0oo7VjT01_o=YJoo_iN^oknG[_noUjko[hV^
oj^<]@;oUgZa0_n:KZd2ohMXZ@?oRfZW0_nCKZH2oiYcY@?oWWNV0onNNJT2oiQi[`?oZYS30_l05jH2
ohb6b004omBb]_o[c;Oon^NZokc<DB?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`002Oooool01000003ooooooooooooooolJ000000D06ATI00Go000003<c<`0c<c<0<c<c
o`00000204a<C004o`00001VIVH0IVIV00000080Ogmo00@0000009VIV@2IVIT000000`2c/k<00ol0
0000c<c<0<c<c0030<c<c0;o0000102c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo0P00000?
06IVIP/0000000?o00000000000000001`1oOgl2000000<0VIVI00Co00000;>c/`2c/k<0/k>c0_l0
00070<c<c003o`00002c/k<0/k>c00;o000000@0VIVI0000001oOgl000000P1VIVH00`000000C4a<
0000000203<c<`030000000I6AT06ATI00806ATI6@000004ooooo`0300000?oooooooooo01_ooooo
00?o0000ooooooooool0;_ooool01OnY_NSoS0<0oc97^?lbAkSoX9kB00;oe_7S0_nR`>l01?oBa<go
ak74olNaa?o@[;@2olNR/`;obIf[0_o5VZ`00oo6UjOoaiZYolNJZ@02olNGYP;oc9jY00Cob9ZWolnS
Zoo?Xj_oai^Y0_o=YJl3oknG[P?oZhbe0_nGN[401?n:KZgoQfRYohMXZOn7J:T2oh]ZY`;oTfjV0onJ
LjD2oiigYP?oWWVY00?oV7V_ojn>]?n_S[@00_nZV<<00ooEb<go00N?oifXgP02oifXgP03on_<]ooj
ij[ooooo02Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`002Oooool0
1000003ooooooooooooooolJ000000H06ATI00D0000003<c<`0c<c<0<c<c0000000204a<C0040000
001VIVH0IVIV00000080Ogmo00?o000009VIV@000000102c/k<3o`0000030<c<c?l00000/k>c00D0
/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`<000001P1VIVH6000001@0
Ogmo00<0000009VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00<0
c<c<00Co00000;>c/`2c/k?o00000`2IVIT00`000000Ogmo0000000206IVIP030000001<C4`00000
0080<c<c00<0000001TI6@0I6AT00P0I6ATI000000Cooooo00<00000ooooooooool07?ooool00ol0
003oooooooooo`0^ooooo`06ojVmj?n<0`3o>h?Xoc^3j?oFlN?oZKgX0_nM]>P3olNaa0Coaj:c00Co
bIf[olFJ[?o5VZcoaYNW0_o7VZT01Oo7UjKoc9jYolbNZOo<WZWob9ZW00;ocj>[00Goai^YolfU[oo=
YJoocJF_oknG[P02ol6Q^@;oZhbe0_nGN[42ohY^[@;oQfRY0_n;JZL2oi=^YP?oVW>U0onNMjH2oiii
Z@?o[hjd00KoZYS3omG8cOoEb<goj_ZgoooooonMZ=h2okGUmROooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooolK000000H06ATI00D0
000003<c<`0c<c<0<c<c0000000204a<C0040000001VIVH0IVIV00000080Ogmo00@0000009VIV@00
000000001@2c/k<00ol00000/k>c0;>c/`060;>c/`030000002IVIT0VIVI0080VIVI00?o000007mo
O`1oOgl0101oOgl6000000H0Ogmo5000000509VIV@03o`00002c/k<0/k>c00D0/k>c1Ol000020;>c
/`07o`00002IVIT0VIVI09VIVOl00000Ogmo0000000206IVIP030000001<C4`000000080<c<c00<0
000001TI6@0I6AT00P0I6ATJ000000Cooooo00<00000ooooooooool07Oooool00ol0003ooooooooo
o`0^ooooo`KoZKgX0_nM]>P00oo7/LCo_:W6okbYaP02olNR/`04ol6P^?o5VZcoaIZ/olFJ[0?oaiZY
00CoaiNVolbNZOo<WZWoc9jY0oo?Xj/4olfU[`?o`J6i0_n[S;D2oiMj/@;oRVj]0_n7J:T3oh]ZY`;o
TfjV0_nJLjD3oiigYP03oiiiZOn^RJgo[hjd00;o[hjd00?ockBnomG8cOoZn[L00oooool00oneiOKo
ooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool000Wooooo
00@00000oooooooooooooooo7000000601TI6@050000000c<c<0<c<c03<c<`0000000P1<C4`01000
0000IVIV06IVIP00000207moO`040000002IVIT0VIVI000000h0/k>c00<0000009VIV@2IVIT00P2I
VIT3000000/0Ogmo00@00000o`000000000000006@2IVIT00ol00000/k>c0;>c/`0;0;>c/`;o0000
0P2IVIT00`000000Ogmo0000000206IVIP04o`00001<C4`0C4a<00000080<c<c00<0000001TI6@0I
6AT00P0I6ATJ000000Cooooo00<00000ooooooooool07_ooool2o`0002oooooo1_nY_NP01OmeZ?;o
_:W6okbYa_nlZLKoaj:c00;o`J2h0oo5VZ`3olNJZ@Coc9jY0oo?Xj/00ooI]KCocJF_olfU[`02omJj
_P;o`J6i0_nPU/X2ohEj_`;oMfVf0on7J:T2oh]ZY`;oTfjV0onJLjD2oiigYP?o[XV]0_n_S[@00oo?
];kolo6kooooo`0]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool000Wo
oooo00@00000oooooooooooooooo7000000601TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`0
1?l00000IVIV06IVIP00000207moO`050000002IVIT0VIVI09VIV@0000003@2c/k<00`000000VIVI
09VIV@0509VIV@<000000P1oOgl6000000@0VIVI3?l0000=09VIV@03o`00002c/k<0/k>c00X0/k>c
00Go000009VIV@2IVIT0VIVI0000000207moO`030000001VIVH0000000<0C4a<00@0000003<c<`0c
<c<00000100I6ATJ000000Cooooo00<00000ooooooooool08?ooool00ol0003oooooooooo`0]oooo
o`KoZKgX00?o05>kokbYa_nYZmP01?o1X;P00oo5VZcoaInbolFO/P02olNJZ@03olfU/?o<WZWoc9jY
00;oeJf`00Cocj>[omVe]?oI]KCocJF_0ooF^[h00oo1XKWo`KkGol6ne`02oj2FbP03ohEj_omgJKKo
MfVf00?oNFJa0_n;JZL2oi=^YP?oVW>U00?oWWNVojZ3Zon^RJd00_n^RJd01?n_S[CockBnolnd__oc
lK/_ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool000Wooooo00@00000
oooooooooooooooo7@00000501TI6@050000000c<c<0<c<c03<c<`0000000`1<C4`010000000IVIV
06IVIP00000207moO`040000002IVIT0VIVI09VIV@8000002`2c/k<00`000000VIVI09VIV@0809VI
V@8000001`2IVIT3o`0000`0/k>c0ol0000:09VIV@03o`00002c/k<0/k>c00L0/k>c0ol0000309VI
V@040000001oOgl0Ogmo00000080IVIV00@0000004a<C01<C4`000000P0c<c<00`0000006ATI01TI
6@0301TI6AX000001?ooool00`00003oooooooooo`0Qooooo`03o`000?oooooooooo02kooooo1OnY
_NP3ojV[f0?o`J2h00CoaIZ/olFO/_o5Wk;oaiZY0_o=YK02olbNZ@;oeJf`00Cocj>[omVe]?oI]KCo
j>3:0ooF^[h00ooGl^?o`KkGol6ne`02oj2FbP;oQGZo0_mgJKH2ogUV/@;oQ6^^0_nCKZH2oiYcY@04
oj5lZonZPj_oZX>[ojZ3Z`;o[XV]0_o?];h00ooclK_oooooooooo`0_ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo7P00000501TI
6@050000000c<c<0<c<c03<c<`0000000`1<C4`010000000IVIV06IVIP00000207moO`030000002I
VIT0VIVI0080VIVI00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0?09VIV@;o00001`2c
/k<4o`0000L0/k>c1Ol0000609VIV@03o`00002c/k<0/k>c00@0/k>c0_l0000509VIV@04o`00001o
Ogl0Ogmo00000080IVIV00D0000004a<C01<C4`0C4a<0000000203<c<`030000000I6AT06ATI0080
6ATI6`000004ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool0;_ooool5ojVmj0?o
ZJ_H00?o`J2hok^[b_o5Wk800_o5Wk801Oo7VZWocJF`olfU/?o=YK3oc9jY00;oeJf`0ooI]K@2onSP
bP03omJj__oGl^?ooooo00?ooooo00?o?j3eobe^g?n5N[l00_mgJKH2ogUV/@;oQ6^^0_nCM:`3oj5l
Z`?oZX>[0_n^RJd00oo9ZKSockBnoo?a^`0aooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool000Wooooo00@00000oooooooooooooooo7`00000501TI6@050000000c<c<0<c<c
03<c<`0000000`1<C4`010000000IVIV06IVIP00000207moO`8000000`2IVIT3000000H0/k>c0P00
000=09VIV@Co00000P2c/k<7o`0000@0c<c<1_l000060;>c/`?o00000`2IVIT7o`0000D0VIVI0P00
000207moO`040000001VIVH0IVIV000000<0C4a<00@0000003<c<`0c<c<00000100I6AT00`00003o
00000000000I000000Cooooo00<00000ooooooooool08oooool00ol0003oooooooooo`0^ooooo`Ko
ZKgX00Co?9kdok^[b_nkZl[o^j_:0_o5Wk84olfU/0?oeJf`00CoiM72omVe]?oXh<[oj>3:2Oooool0
0ol]K]coMfVfogMY]P02ogUV/@;oQ6^^0onCM:`3oj5lZ`;oZX>[00Co[XV]olVY^?o9ZKSol^g0<ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooo
oooooooooal0000000?o000001TI6@0I6AT00`0I6AT01P000000<c<c03<c<`0c<c?o000000000080
C4a<00Go000006IVIP1VIVKo00000000000207moO`800000102IVIT4000000030;>c/`000000VIVI
00d0VIVI00?o00000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c00?0<c<c003o`00002c/k<0/k>c
00H0/k>c00?o000009VIV@2IVIT02P2IVIT2000000<0Ogmo00D0000006IVIP1VIVH0IVIV00000002
04a<C0050000000c<c<0<c<c03<c<`000000100I6ATL000000Cooooo00<00000ooooooooool09?oo
ool2o`0002oooooo1onY_NP2ok^[bP03olFO/_o:]<Cob[C400;ocJF`0_oJ`/800ooE[K3oiM72onGA
`P0>ooooo`;o;EW<0_miI[401?n4JjkoTgB/oi=d[?nCM:`3oj5lZ`;oZX>[0oo9ZKP00oobkL3ooooo
ooooo`0booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@0
0000oooooooooooooooo8@00000501TI6@030000000c<c<0<c<c0080<c<c00@0000004a<C01<C4`0
00000`1VIVH01@000000Ogmo07moO`1oOgl0000000L0VIVI00<0000009VIV@2IVIT0302IVIT00ol0
0000/k>c0;>c/`030;>c/`03o`00003<c<`0c<c<00<0c<c<1`0000070<c<c003o`00002c/k<0/k>c
00D0/k>c00?o000009VIV@2IVIT02@2IVIT00`000000Ogmo07moO`0207moO`05o`00001VIVH0IVIV
06IVI_l000000P1<C4`01Ol00000<c<c03<c<`0c<c?o000000@06ATI7@000004ooooo`0300000?oo
oooooooo02Kooooo00?o0000ooooooooool0;Oooool7ojVmj005ohG>ooo:]<Cob[C4olZda?o=YK00
0ooJ`/800oo2o]?oiM72ooooo`0?ooooo`03obeIc?m6G/OoNFJa00;oQ6^^0_nCM:`3oj5lZ`05ojZ3
Zoo0X;So`:2holVY^?obkL00=Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo0009ooooo`0400000?ooooooooooooooob8000001@0I6AT00ol00000<c<c03<c<`0203<c<`04
0000001<C4`0C4a<000000<0IVIV00L0000007moO`1oOgl0Ogmo00000?l0000000000180VIVI00?o
00000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c0020<c<c08000001`3Vi^H00`00003o00000000
00050<c<c003o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT01P2IVIT200000003o`00001o
Ogl0Ogmo0080Ogmo00D0000006IVIP1VIVH0IVIV0000000204a<C0050000000c<c<0<c<c03<c<`00
00001@0I6ATM000000Cooooo00<00000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`So
ZKgX00Kob[C4okCcm?ndloCo]??dom[2`_o2o]<Cooooo`04obeIc?m6G/OoQ6^^ohA[[P?oTgB/0_nQ
O:/3ol2P^003on[`c_obkL3ooooo03Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0:ooooo`002Oooool01000003ooooooooooooooolR000000H06ATI00<0000003<c<`0c<c<00P0c
<c<01Ol00000C4a<04a<C?l0000000000080IVIV00?o00000000001oOgl00`1oOgl00`000000VIVI
09VIV@0?09VIV@03o`00002c/k<0/k>c00<0/k>c00Go00000<c<c03<c<`0c<c<0000000;0>KViP03
0000003<c<`0c<c<00<0c<c<00?o00000;>c/`2c/k<0102c/k<00ol00000VIVI09VIV@0509VIV@03
0000001oOgl0Ogmo00@0Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0050000000c<c<0<c<c
03<c<`0000001@0I6ATM000000Cooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`0]
ooooo`?oZKgX7_ooool00om6G/OoKW;6ofibaP03oi=d[003oj5lZon_U[co[iJl00;o`:2h00?oj_3>
ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009oooo
o`0400000?ooooooooooooooob<000001P0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0
C4a<04a<C00000000`1VIVH00`000000Ogmo07moO`0207moO`<000003P2IVIT00ol00000/k>c0;>c
/`020;>c/`03o`00003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H02P3Vi^H00`000000c<c<0<c<
c0020<c<c003o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2IVIT0102IVIT00`000000Ogmo07mo
O`0307moO`8000000`1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c00<0000001TI6@0I6AT0
0`0I6ATN000000Cooooo00<00000ooooooooool0:Oooool2o`0002gooooo00?o0000ooooooooool0
7oooool00om6G/OoKW;6oiB7`P02oiB7`P?o[iJl00?o`:2hon[`c_ooool0>Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0400000?ooooooooooooooob@00000
1P0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH2000000D0
Ogmo0`00000:09VIV@03o`00002c/k<0/k>c00<0/k>c00Go00000<c<c03<c<`0c<c<0000000>0>KV
iP03o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c/k<00ol00000VIVI09VIV@0409VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH01Ol00000C4a<04a<C01<C4co
000000@0<c<c00<0000001TI6@0I6AT00P0I6AT00ol0000000000000000L000000Cooooo00<00000
ooooooooool0:oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo023ooooo0_m^L/H3
oiB7`P;o[iJl00?obOO[ooooooooool0>Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo0009ooooo`0400000?ooooooooooooooobH000001@0I6AT2000000<0<c<c0P000002
04a<C08000000`1VIVH2000000H0Ogmo00<00000o`00000000001`2IVIT00ol00000/k>c0;>c/`02
0;>c/`03o`00003<c<`0c<c<0080c<c<00<000000>KViP3Vi^H0303Vi^H00ol00000c<c<0<c<c002
0<c<c003o`00002c/k<0/k>c0080/k>c00?o000009VIV@2IVIT00P2IVIT2000000@0Ogmo00<00000
o`00001VIVH00`1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c00<00000o`00000I6AT0100I
6ATO000000Cooooo00<00000ooooooooool0;?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo02;ooooo0onDQl800on_U[cobOO[ooooo`0looooo`05o`000?ooooooooooooooool00000
2oooool000Wooooo00@00000oooooooooooooooo9`00000601TI6@030000000c<c<0<c<c0080<c<c
00D0000004a<C01<C4`0C4a<0000000406IVIP<000001P1oOgl00`000000VIVI09VIV@0409VIV@03
o`00002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`00P3<c<`00`000000i^KV0>KViP0<0>KViP03
0000003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c/k<01Ol00000VIVI09VIV@2IVIT00000
00D0Ogmo00<0000006IVIP1VIVH00`1VIVH01@000000C4a<04a<C01<C4`0000000@0<c<c00<00000
01TI6@0I6AT0100I6ATO000000Cooooo00<00000ooooooooool0;Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo06Gooooo00Co0000oooooooooooo00002oooool000Wooooo00@00000
oooooooooooooooo:000000601TI6@030000000c<c<0<c<c0080<c<c00@0000004a<C01<C4`0C4a<
0`00000406IVIP8000001@1oOgl3000000@0VIVI00?o00000;>c/`2c/k<00P2c/k<00ol00000c<c<
0<c<c0020<c<c0030000003Vi^H0i^KV00/0i^KV00D000000<c<c03<c<`0c<c<o`0000040;>c/`05
o`00002IVIT0VIVI09VIV@0000001@1oOgl00`000000IVIV06IVIP0206IVIP8000000`1<C4`00`00
0000<c<c03<c<`0203<c<`030000000I6AT06ATI00@06ATI80000004ooooo`0300000?oooooooooo
02kooooo0_l0000Xooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool000Wo
oooo00@00000oooooooooooooooo:@00000601TI6@030000000c<c<0<c<c0080<c<c0P00000404a<
C0030000001VIVH0IVIV00<0IVIV0P00000607moO`030000002IVIT0VIVI0080VIVI00?o00000;>c
/`2c/k<00P2c/k<01?l00000c<c<0<c<c03<c<`2000000/0i^KV00<000000<c<c03<c<`00P3<c<`0
1Ol00000/k>c0;>c/`2c/k?o000000<0VIVI00Co000007moO`1oOgl0Ogmo0P0000001?l00000IVIV
06IVIP1VIVH2000000@0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0401TI6B40
00001?ooool00`00003oooooooooo`0`ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0I_ooool00ol0003oooooo`00000;ooooo`002Oooool01000003ooooooooooooooolY000000L0
6ATI00?o00000000000c<c<00`0c<c<00`000000C4a<04a<C00204a<C003o`0000000000000000@0
IVIV0P00000507moO`03o`00002IVIT0VIVI0080VIVI00Go00000;>c/`2c/k<0/k>co`0000050<c<
c0800000203Vi^H00`000000c<c<0<c<c0020<c<c005o`00002c/k<0/k>c0;>c/ol000000`2IVIT0
1@000000Ogmo07moO`1oOgl0000000D0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0303<c<`030000000I6AT06ATI00@06ATI8@000004ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo000000[ooooo0009
ooooo`0400000?ooooooooooooooob/000001`0I6AT00`000000<c<c03<c<`0203<c<`8000001@1<
C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2I
VIT01?l00000/k>c0;>c/`2c/k<2o`0000D0c<c<200000040<c<c005o`00002c/k<0/k>c0;>c/ol0
00000`2IVIT01@000000Ogmo07moO`1oOgl0000000D0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0303<c<`030000000I6AT06ATI00@06ATI8P000004ooooo`0300000?oooooooooo
03;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Xooooo`;o00002_ooool000Wo
oooo00@00000oooooooooooooooo;000000701TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<
C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP800000101oOgl00`000000VIVI09VIV@0209VI
V@03o`00002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`03@3<c<`01Ol00000/k>c0;>c/`2c/k?o
000000<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0
C4a<00<0C4a<00?o000003<c<`0c<c<00`0c<c<00`0000006ATI01TI6@0401TI6B<000001?ooool0
0`00003oooooooooo`0cooooo`;o00008oooool00ol0003oooooooooo`1Wooooo`?o00002_ooool0
00Wooooo00@00000oooooooooooooooo;@00000701TI6@800000100c<c<00`00003o000000000003
04a<C0@000000`1VIVH2000000<0Ogmo0P00000309VIV@;o00000`2c/k<3o`0000X0c<c<0_l00002
0;>c/`;o00000P2IVIT00`00003o000007moO`0207moO`8000000`1VIVH2000000@0C4a<0P000004
03<c<`8000001P0I6ATT000000Cooooo00<00000ooooooooool0=Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06?ooooo1?l0000=ooooo`002Oooool01000003oooooooooooooool]
00000003o`00000000006ATI00H06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C004
04a<C0030000001VIVH0IVIV0080IVIV0P00000307moO`8000000`2IVIT2o`0000@0/k>c2_l00002
0;>c/`;o00000`2IVIT010000000Ogmo07moO`1oOgl2000000<0IVIV0P00000404a<C08000001@0c
<c<00`0000006ATI01TI6@0501TI6BD000001?ooool00`00003oooooooooo`0fooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00017ooooo0009ooooo`0400000?oooooo
oooooooooc0000001`0I6AT2000000D0<c<c0P00000504a<C0800000101VIVH00`000000Ogmo07mo
O`0207moO`8000000`2IVIT00ol00000/k>c0;>c/`0;0;>c/`;o0000102IVIT01@000000Ogmo07mo
O`1oOgl0000000@0IVIV00?o000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`030000
000I6AT06ATI00D06ATI00?o00000000000000008`000004ooooo`0300000?oooooooooo03Oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`Co00005?ooool000Wooooo00@0
0000oooooooooooooooo<P00000701TI6@8000001@0c<c<2000000D0C4a<0P00000306IVIP030000
0?l00000000000<0Ogmo00@0000009VIV@2IVIT0VIVI3Ol0000309VIV@80000000Go000007moO`00
00000000o`00000306IVIP8000001@1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI
00D06ATI9`000004ooooo`0300000?oooooooooo03Sooooo0_l0000Nooooo`03o`000?oooooooooo
05Sooooo1?l0000Hooooo`002Oooool01000003ooooooooooooooolc000000P06ATI0P00000503<c
<`8000001@1<C4`2000000@0IVIV00D0000007moO`1oOgl0Ogmoo`000002000000d0VIVI0`000003
07moO`030000001VIVH0IVIV0080IVIV0P00000504a<C08000001@0c<c<2000000P06ATI9`000004
ooooo`0300000?oooooooooo03[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1D
ooooo`Co00007?ooool000Wooooo00@00000oooooooooooooooo=000000901TI6@030000000c<c<0
<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP<000000`1oOgl7
00000080VIVI1000000407moO`8000000`1VIVH2000000D0C4a<0P00000503<c<`8000002@0I6ATX
000000Cooooo00<00000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo057ooooo0ol0000Pooooo`002Oooool01000003ooooooooooooooole000000T06ATI00<00000
03<c<`0c<c<0100c<c<2000000D0C4a<0P00000506IVIP800000201oOgl2000000H0Ogmo0P000004
06IVIP03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@08
01TI6@03o`0000000000000002H000001?ooool00`00003oooooooooo`0looooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0COooool4o`0002?ooooo0009ooooo`0400000?oooooooooo
ooooocD0000000?o00000000000I6AT01`0I6AT00ol0000000000000000503<c<`@000000`1<C4`4
000000<0IVIV00@00000o`000000000000001P1oOgl6000000D0IVIV0P00000404a<C08000001P0c
<c<2000000P06ATI:`000004ooooo`0300000?oooooooooo03gooooo0_l0000Iooooo`03o`000?oo
oooooooo04Wooooo1?l0000Wooooo`002Oooool01000003oooooooooooooooli000000T06ATI0P00
000703<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH6000000L0IVIV1000
000304a<C0<000001@0c<c<3000000T06ATI;0000004ooooo`0300000?oooooooooo03oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000:oooool000Wooooo00@00000
oooooooooooooooo>P00000:01TI6@030000000c<c<0<c<c00D0<c<c0`00000404a<C0H000002P1V
IVH3000000D0C4a<00?o00000000000c<c<01P0c<c<00`0000006ATI01TI6@0801TI6Bh000001?oo
ool00`00003oooooooooo`10ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@ooo
ool3o`0002oooooo0009ooooo`0400000?oooooooooooooooc/0000000?o00000000000I6AT01`0I
6AT01000003o000000000000000603<c<`0400000?l000000000000000H0C4a<2P00000604a<C080
00001P0c<c<200000003o`00000I6AT06ATI00P06ATI00?o0000000000000000;0000004ooooo`03
00000?oooooooooo047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0oooooo`Co
0000<_ooool000Wooooo00@00000oooooooooooooooo?P00000;01TI6@800000200c<c<300000100
C4a<0`00000703<c<`030000000I6AT06ATI00T06ATI<@000004ooooo`0300000?oooooooooo04;o
oooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`002Oooool01000003ooooo
oooooooooom0000000/06ATI00<0000003<c<`0c<c<0200c<c<@000000L0<c<c0`00000:01TI6C<0
00001?ooool00`00003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0=oooool4o`0003[ooooo0009ooooo`0400000?oooooooooooooood4000002`0I6AT3000001`0
<c<c00?o00000000000I6AT02`0I6AT00ol0000000000000000a000000Cooooo00<00000oooooooo
ool0AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0000nooooo`00
2Oooool01000003ooooooooooooooom200000003o`00000000006ATI00X06ATI00@00000o`000000
000000004`0c<c<5000000d06ATI=@000004ooooo`0300000?oooooooooo04Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0`ooooo`?o0000@_ooool000Wooooo00@00000oooooooo
ooooooooA@00000>01TI6@H000001P0c<c<7000000l06ATI>0000004ooooo`0300000?oooooooooo
04Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool000Wo
oooo00@00000ooooooooooooooooB000000A01TI6@H00000500I6ATj000000Cooooo00<00000oooo
ooooool0B?ooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0009ooooo`04
00000?ooooooooooooooodT0000000?o0000000000000000900I6AT200000003o`00000000000000
03P000001?ooool00`00003oooooooooo`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09?ooool4o`0004gooooo0009ooooo`0400000?ooooooooooooooodl000007P0I6AU00000
00Cooooo00<00000ooooooooool0Boooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
027ooooo0ol0001Aooooo`002Oooool01000003ooooooooooooooomC000001L06ATI@`000004oooo
o`0300000?oooooooooo04cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Moooo
o`Co0000E?ooool000Wooooo00@00000ooooooooooooooooE`00000<01TI6DX000001?ooool00`00
003oooooooooo`1=ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool000Wo
oooo00@00000ooooooooooooooooE`0000000ol0000000000000000800000003o`00000000000000
04P000001?ooool00`00003oooooooooo`1?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05Oooool4o`0005cooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00
063ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Aoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0006?ooooo0009ooooo`04
00000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0
003oooooooooo`0:ooooo`Co0000Ioooool000Wooooo00@00000oooooooooooooooo[@000004oooo
o`0300000?oooooooooo05Cooooo00Co0000oooooooooooo00002?ooool4o`0006_ooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo
000000Gooooo0ol0001_ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0E_ooool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo05Oooooo0_l0001fooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooo
oooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooo
ooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]
000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004
ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000
ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?
ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool0
00Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009oooo
o`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000
003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0
coooool000Wooooo]P00003Aooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonfo`00017o
oooo]_l0000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Boooool<000005_ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04Sooooo00<00000o`00000000003?ooool400000004o`0000000000
0000000005?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo1000000Gooooo`<00000D?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0@Oooool3000001kooooo0`00001=ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`10ooooo`0300000?oooooooooo02;ooooo0`00001:ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0nooooo`800000:?ooool01?l000000000000000000016ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0looooo`800000;_ooool3000004?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo0P00
000Cooooo`@000007?ooool00`00003oooooooooo`10ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo04cooooo6@3o]/5=ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0>Oooool00`00003oooooooooo`0;ooooo`0300000?l0003o000000D00000103o]/4;
000000L0okK12oooool4000003kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0BOoooolO0?nf`D[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0goooo
o`0300000?l0003ooooo00[ooooo0`000002oooooaD0okK1100000060?nf`@cooooo0P00000loooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Kooooo9@3o]/57ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0=_ooool00`00003oooooooooo`08ooooo`<0
00000_oooolL0?nf`@L000000P3o]/4;ooooo`0300000?oooooooooo03Wooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0@oooool[0?nf`DCooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0eooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
9P3o]/42000000<0okK12Oooool2000003Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0@?oooola0?nf`D7ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0cooooo`8000002?ooool00`00003o00000000000[0?nf`@@000000P3o]/48ooooo`800000=ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0mooooocL0okK1?_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03;ooooo00<00000ooooooooool01Oooool3
000000L0okK16P00000A0?nf`@030000003o]/40okK10080okK11oooool2000003Gooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>_oooolk0?nf`Cgooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0aooooo`0300000?oooooooooo00Gooooo00<000000?nf
`@3o]/401@3o]/43000001X0okK11`00000;0?nf`@<000000P3o]/48ooooo`0300000?oooooooooo
03;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>Ooooolm0?nf`Cco
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`0300000?oooooooooo00Go
oooo00<000000?nf`@3o]/40103o]/42000002@0okK1100000001?l0000000000000000000060?nf
`@<000002?ooool00ol000000000ooooo`0aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo03Oooooo@P3o]/4iooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0;oooool00`00003oooooooooo`05ooooo`0300000?l00000okK100<0okK10P0000000ol00000
okK10?nf`@0[0?nf`@8000001`3o]/400`000000okK10?nf`@07ooooo`0300000?oooooooooo02oo
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=Ooooom60?nf`COooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`0300000?oooooooooo00Cooooo
0P0000040?nf`@8000001`3o]/4<000001l0okK100<000000?nf`@3o]/401@3o]/4200000080okK1
1_ooool00`00003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo03CoooooB03o]/4fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Ooo
ool00`00003oooooooooo`04ooooo`030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o
]/43000000`0okK11`0000020?nf`A0000001`3o]/43000000H0okK100<000000?nf`@3o]/401_oo
ool2000002kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0<ooooom:
0?nf`CGooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0[ooooo`0300000?l0003o
oooo00Cooooo00<00000o`00003o]/40103o]/400`000000okK10?nf`@020?nf`@<000005P3o]/42
00000100okK1100000060?nf`@03o`0000000000000000@0okK100?o00000000003o]/401oooool2
000002cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0<_oooola0?nf
`@Ko003o5@3o]/4dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00`00
003oooooooooo`04ooooo`030000003o]/40okK100<0okK100<00000o`00003o]/400P3o]/420000
02l0okK10`0000060?nf`@030000003o]/40okK100<0okK100<000000?nf`Oooool01oooool00`00
003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo033o
oooo<03o]/43o`00o`H0okK11Ol00?lB0?nf`C;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Yooooo`0300000?oooooooooo00Cooooo00<000000?nf`@3o]/400P3o]/42000000<0
okK10P0000050?nf`@/00000903o]/43000000@0okK10P0000040?nf`@030000003o]/40okK100Oo
oooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0_oooooc00okK100?o003o0?nf`@3o]/40303o]/43o`00oa00okK1<Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01?ooool01?l00000okK1
0?nf`@3o]/42000000<0okK10P0000020?nf`@D000002`3o]/400ol00000okK10?nf`@0@0?nf`@d0
000000?o00000?nf`@3o]/40103o]/400ol00000okK10?nf`@030?nf`@030000003o]/40okK10080
okK100?o00000000003o]/401oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo02kooooo<@3o]/400ol00?l0okK10?nf`@0?0?nf`@;o003o
3`3o]/4`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00`00003ooooo
ooooo`03ooooo`050000003o]/40okK10?nf`@000000103o]/400`00003o00000?nf`@0200000140
okK100<000000?nf`@3o]/403P3o]/400`00003o00000?nf`@0<0?nf`@<00000103o]/42000000@0
okK100<000000?nf`@3o]/400`3o]/400`000000okK1ooooo`06ooooo`0300000?oooooooooo02Ko
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;Ooooola0?nf`@03o`00
o`3o]/40okK10180okK10_l00?l>0?nf`Boooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Wooooo`0300000?oooooooooo00?ooooo00D000000?nf`@3o]/40okK1000000030?nf`@80
00000P3o]/400`000000okK10?nf`@050?nf`@@000002@3o]/400`000000okK10?nf`@0<0?nf`@03
0000003o]/40okK10100okK10P0000040?nf`@030000003o]/40okK10080okK100<000000?nf`@3o
]/400`3o]/400`000000okK1ooooo`06ooooo`0300000?oooooooooo02Gooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0;?oooola0?nf`@03o`00o`3o]/40okK101D0okK1
00?o003o0?nf`@3o]/40303o]/4^ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
9_ooool00`00003oooooooooo`03ooooo`050000003o]/40okK10?nf`@0000000`3o]/401@000000
okK10?nf`@3o]/40000000@0okK1100000040?nf`@@000001P3o]/400`000000okK10?nf`@0:0?nf
`@030000003o]/40okK100T0okK1100000060?nf`@8000000`3o]/42000000<0okK100<000000?nf
`@3o]/400`3o]/400ol00000okK1ooooo`06ooooo`0300000?oooooooooo02Cooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0:ooooolC0?nf`@Go003o6@3o]/400ol00?l0
okK10?nf`@0G0?nf`@03o`00o`3o]/40okK100`0okK1;Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool01@000000okK10?nf`@3o]/7o0000
0080okK100H00000o`00003o]/40okK100000?l000020?nf`@0300000?l00000000000`0okK100?o
00000?nf`@3o]/40103o]/400`000000okK10?nf`@080?nf`@030000003o]/40okK100H0okK11000
00040?nf`@@00000103o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`Ol00000
1@3o]/42000000Oooooo00?o000000000?ooool08oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Zoooooa40okK10ol00?l50?nf`@?o003o5P3o]/400ol00?l0okK10?nf
`@0H0?nf`@03o`00o`3o]/40okK100/0okK1;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Cooooo00<00000ooooooooool00oooool01@000000okK10?nf`@3o]/4000000080okK1
00D000000?nf`@3o]/40okK1000000030?nf`@030000003o]/40okK100D0okK10`0000050?nf`@03
0000003o]/40okK100@0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@050?nf`@03
0000003o]/40okK100X0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@05
0000003o]/40okK10?nf`@0000001P3o]/400`00003oooooooooo`05ooooo`0300000?oooooooooo
02;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:_ooool>0?nf`@?o
003o2P3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK101T0okK100?o003o0?nf`@3o
]/402`3o]/4/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08oooool00`00003o
ooooooooo`03ooooo`050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10?nf`@3o]/40
00000080okK10P0000040?nf`@@000000`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100`0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40
okK10?nf`@0000001P3o]/400`00003oooooooooo`05ooooo`0300000?oooooooooo027ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:Oooool=0?nf`@;o003o3P3o]/40
0ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK101X0okK100?o003o0?nf`@3o]/402`3o]/4[
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool00`00003oooooooooo`04
ooooo`050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf`@040000
003o]/40okK10?nf`@<00000203o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080
okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100d0
okK100<000000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@050000003o]/40okK10?nf
`@0000001@3o]/400`00003oooooooooo`06ooooo`0300000?oooooooooo023ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0:?ooool=0?nf`@03o`00o`3o]/40okK100h0
okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@0K0?nf`@03o`00o`3o]/40okK100/0
okK1:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool00oooool00`000000okK10?nf`@0200000080okK100@000000?nf`@00000000000P3o]/401@00
0000okK100000?l00000000000`0okK100D000000?nf`@3o]/40okK1000000040?nf`@030000003o
]/40okK100T0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0?0?nf`@03o`000000
0000okK10080okK10P0000030?nf`@06o`00003o]/40okK10?nf`Ol000000000103o]/42000000Oo
oooo00<00000ooooooooool07oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0Wooooo`d0okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@0B0?nf`@03o`00
o`3o]/40okK101`0okK100?o003o0?nf`@3o]/402`3o]/4Yooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool08Oooool00`00003oooooooooo`03ooooo`040000003o]/40okK1000000<0
okK100<000000?nf`@0000000P3o]/401000003o00000?nf`@0000030?nf`@So0000103o]/401@00
0000okK10?nf`@3o]/40000000@0okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK100D0okK11`0000050?nf`@030000003o]/40okK10080okK100D00000
0?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK100<0okK100<00000ooooooooool01Ooo
ool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo02Kooooo3@3o]/400ol00?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK10180okK100?o003o
0?nf`@3o]/40703o]/400ol00?l0okK10?nf`@0;0?nf`BWooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Pooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000`3o
]/401P000000okK10?nf`@000000okK100000080okK100D000000?nf`@3o]/40okK1o`0000080?nf
`@03o`00003o]/40okK10080okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@0;
0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@05
0?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/401Ol00000okK10?nf`@3o
]/40000000@0okK100<000000?nf`@3o]/400P3o]/400oooool00000ooooo`06ooooo`0300000?oo
oooooooo01gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool09_ooool<
0?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf`@0=
0?nf`@?o00003@3o]/400ol00?l0okK10?nf`@0;0?nf`BSooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Oooooo`0300000?oooooooooo00?ooooo00Go00000?nf`@3o]/40okK1o`00
00020?nf`@06o`00003o]/40okK10000003o]/4000000P3o]/400`000000okK10?nf`@02o`0000X0
okK100Go00000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000003P3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/401`3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100D000000?nf`@3o]/40okK10000
00040?nf`@03o`00003o]/40okK10080okK100?ooooo00000?ooool01_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Gooooo303o]/40
0ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/402`3o]/45
o`0000d0okK100?o003o0?nf`@3o]/402`3o]/4Wooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`03ooooo`070000003o]/40okK10?nf`@000000okK1
000000020?nf`@030000003o]/7o000000<0okK100<000000?nf`Ol000000`3o]/44o`0000D0okK1
00Go00000?nf`@3o]/40okK1000000020?nf`@050000003o]/40okK10?nf`@0000003P3o]/400`00
0000okK10?nf`@020?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/401`3o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?ooooo00000?ooool01_ooool00`00
003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Co
oooo303o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o
]/402`3o]/45o`0000d0okK100?o003o0?nf`@3o]/402`3o]/4Wooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07oooool00`00003oooooooooo`02ooooo`070000003o]/40okK10?nf
`@000000okK1000000020?nf`@040000003o]/40okK100000080okK100<000000?nf`Ol000000`3o
]/400ol00000okK10?nf`@020?nf`@;o00000`3o]/401ol00000okK10?nf`@3o]/4000000?nf`@00
00000`3o]/400`000000okK10?nf`@030?nf`@H000001@3o]/401@000000okK10?nf`@3o]/400000
00D0okK100<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK1
0080okK100<000000?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000@0okK10_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool09?ooool;0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf
`@3o]/404`3o]/400ol00?l0okK10?nf`@0:0?nf`@Go00003P3o]/400ol00?l0okK10?nf`@0;0?nf
`BKooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`0300000?oooooooooo
00?ooooo00H000000?nf`@3o]/4000000?nf`@0000030?nf`@030000003o]/4000000080okK100<0
00000?nf`Ol000000P3o]/42o`0000L0okK100Oo00000?nf`@3o]/40okK1o`00003o]/4000000080
okK100Go00000?nf`@3o]/40okK1o`0000040?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/400`3o]/401@000000okK10?nf`@3o]/40000000D0okK100<000000?nf`@3o]/401P3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK100Go00000?nf`@3o]/40okK10000
00040?nf`@030000003o]/40okK10080okK100?ooooo00000?ooool01_ooool00`00003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02?ooooo303o]/40
0ol00?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/402`3o]/43
o`0000l0okK100?o003o0?nf`@3o]/402`3o]/4Vooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool07Oooool00`00003oooooooooo`02ooooo`05o`0000000000okK10?nf`@0000000P3o
]/402ol00000okK10?nf`@000000okK10000003o]/7o00000000003o]/7o00000080okK100?o0000
0?nf`@3o]/40203o]/401_l00000okK10?nf`Ol00000okK100000080okK100@000000?nf`@3o]/40
00000`3o]/400ol0000000000?nf`@070?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o
]/400P3o]/400`000000okK10?nf`@030?nf`@03o`0000000000okK100H0okK100<000000?nf`@3o
]/40103o]/400ol00000okK10?nf`@020?nf`@040000003o]/40okK10?nf`@8000000`3o]/401?l0
0000okK10?nf`@3o]/42ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool06_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Sooooo`/0okK100?o003o0?nf
`@3o]/405P3o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK101`0okK100?o003o0?nf
`@3o]/40303o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool00`00
003oooooooooo`03ooooo`050000003o]/40okK10?nf`@0000000P3o]/401@000000okK10000003o
]/7o00000080okK100<000000?nf`Ol000000P3o]/400ol00000okK10?nf`@090?nf`@06o`00003o
]/40okK1o`00003o]/4000000P3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/40okK1
00T0okK10P0000030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000`3o]/400oooool00000ooooo`05
ooooo`0300000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool08_ooool<0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/405P3o]/400ol0
0?l0okK10?nf`@0K0?nf`@03o`00o`3o]/40okK100d0okK19?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01_ooooo00<00000ooooooooool00oooool01@000000okK10?nf`@3o]/40
00000080okK100<000000?nf`@0000000P3o]/401@000000okK10000003o]/7o00000080okK100?o
00000?nf`@3o]/402@3o]/401?l00000okK10?nf`Ol000020?nf`@03o`00003o]/4000000080okK1
00@000000?nf`@3o]/4000003P3o]/401@000000okK10?nf`@3o]/40000000@0okK10P0000050?nf
`@<0000000<0okK10000003o]/40203o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK1
0080okK100Go00000?nf`@3o]/40okK1000000030?nf`@03ooooo`00003ooooo00Gooooo00<00000
ooooooooool06Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Qoooo
o``0okK100?o003o0?nf`@3o]/405`3o]/400ol00?l0okK10?nf`@0G0?nf`@03o`00o`3o]/40okK1
01X0okK100?o003o0?nf`@3o]/403@3o]/4Tooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`03ooooo`040000003o]/40okK100000080okK100<00000
0?nf`@0000000P3o]/401@000000okK10000003o]/7o00000080okK100?o00000?nf`@3o]/400P3o
]/400ol00000okK10?nf`@050?nf`@06o`00003o]/40okK1o`00003o]/4000000P3o]/400`000000
okK1000000020?nf`@030000003o]/40okK100<0okK1100000070?nf`@06o`00003o]/40okK10?nf
`@00003o0000103o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100T0okK100<00000
0?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000P3o
]/42ooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool06?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Qooooo`/0okK100?o003o0?nf`@3o]/405`3o]/40
0ol00?l0okK10?nf`@0H0?nf`@;o003o6`3o]/400ol00?l0okK10?nf`@0>0?nf`B?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Kooooo`0300000?oooooooooo00?ooooo00@00000
0?nf`@3o]/4000000P3o]/400`000000okK1000000020?nf`@050000003o]/4000000?nf`Ol00000
0P3o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK100D0okK100Ko00000?nf`@3o]/7o
00000?nf`@0000020?nf`@030000003o]/4000000080okK100Co00000?nf`@3o]/40okK10P000004
0?nf`@<000001@3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100?o0000
0000003o]/40403o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/400P3o]/401@000000okK10?nf`Oooool0000000Kooooo00<00000ooooooooool06?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Pooooo``0okK100?o003o
0?nf`@3o]/40203o]/43o`0000`0okK100?o003o0?nf`@3o]/406P3o]/400ol00?l0okK10?nf`@0H
0?nf`@03o`00o`3o]/40okK100h0okK18oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01[ooooo00<00000ooooooooool00oooool010000000okK10?nf`@0000020?nf`@030000003o
]/4000000080okK100D000000?nf`@000000okK1o`0000020?nf`@03o`00003o]/40okK10080okK1
00?o00000?nf`Ol000001P3o]/400ol00000okK1o`0000020?nf`@050000003o]/4000000?nf`@00
00000`3o]/4010000000okK10?nf`@0000090?nf`@800000103o]/400`000000okK10?nf`@020?nf
`@030000003o]/40okK100<0okK10P00000@0?nf`@030000003o]/40okK100<0okK100<000000?nf
`@3o]/400P3o]/400`000000okK10?nf`@020?nf`@050000003o]/7oooooooooo`0000001_ooool0
0`00003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
023ooooo2`3o]/400ol00?l0okK10?nf`@080?nf`@Go00002`3o]/400ol00?l0okK10?nf`@0K0?nf
`@03o`00o`3o]/40okK101L0okK100?o003o0?nf`@3o]/403`3o]/4Rooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06_ooool00`00003oooooooooo`02ooooo`040000003o]/40okK1
000000<0okK100<000000?nf`@0000000P3o]/401@000000okK10000003o]/7o00000080okK100Go
00000?nf`@3o]/40okK1o`0000030?nf`@03o`00003o]/40okK10080okK100Ko00000?nf`@3o]/7o
00000?nf`@0000020?nf`@030000003o]/4000000080okK100D000000?nf`@3o]/40okK10000000;
0?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100d0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@02
0?nf`@05o`00003o]/40okK10?nf`@0000000P3o]/400oooool00000ooooo`05ooooo`0300000?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07oooool<
0?nf`@03o`00o`3o]/40okK100P0okK11Ol0000:0?nf`@03o`00o`3o]/40okK101d0okK10_l00?lF
0?nf`@03o`00o`3o]/40okK10140okK18Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Wooooo00<00000ooooooooool00_ooool01Ol00000okK10?nf`@3o]/7o00000080okK100/0
00000?nf`@000000okK1o`0000000000okK10000003o]/7o00000?nf`@02o`0000<0okK100?o0000
0?nf`@3o]/400`3o]/401ol00000okK10?nf`@3o]/7o00000?nf`Ol000000P3o]/401@000000okK1
0000003o]/4000000080okK100D000000?nf`@3o]/40okK10000000=0?nf`@8000000`3o]/420000
00<0okK100?o00000000003o]/400`3o]/400ol0000000000000000>0?nf`@8000001@3o]/401Ol0
0000okK10?nf`@3o]/40000000@0okK100D000000?nf`@3o]/7ooooo00000006ooooo`0300000?oo
oooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool07_ooool<
0?nf`@03o`00o`3o]/40okK100T0okK11Ol000090?nf`@;o003o8@3o]/42o`00oa<0okK10_l00?lC
0?nf`B7ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00?ooooo00D000000?nf`@3o]/40okK1000000020?nf`@050000003o]/4000000?nf`@000000
0P3o]/401@000000okK1o`00003o]/7o000000D0okK100Go00000?nf`@3o]/40okK1o`0000030?nf
`@06o`00003o]/40okK1o`00003o]/4000000P3o]/400`000000okK1000000020?nf`@040000003o
]/40okK100000100okK10P0000030?nf`@8000000`3o]/42000000D0okK10`00000=0?nf`@030000
003o]/40okK100<0okK100D000000?nf`@3o]/40okK1000000030?nf`@050000003o]/40okK1oooo
o`0000001_ooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01kooooo303o]/400ol00?l0okK10?nf`@0:0?nf`@?o00002P3o]/400ol00?l0
okK10?nf`@0R0?nf`@03o`00o`3o]/40okK100h0okK10_l00?lF0?nf`B3ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Hooooo`0300000?oooooooooo00;ooooo00D000000?nf`@3o
]/40okK1000000020?nf`@050000003o]/4000000?nf`@0000000P3o]/401@000000okK1o`00003o
]/7o000000L0okK100?o00000?nf`Ol000000`3o]/401_l00000okK10?nf`Ol00000okK1o`000080
okK100<000000?nf`@0000000P3o]/4010000000okK10?nf`@0000050?nf`@L000001`3o]/400`00
0000okK10?nf`@020?nf`@8000000`3o]/42000000H0okK10P00000<0?nf`@030000003o]/40okK1
00<0okK100D000000?nf`@3o]/40okK1000000030?nf`@050000003o]/40okK1ooooo`0000001_oo
ool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01gooooo303o]/400ol00?l0okK10?nf`@0G0?nf`@03o`00o`3o]/40okK102@0okK11?l00?l;
0?nf`@03o`00o`3o]/40okK101H0okK18?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Oooooo00<00000ooooooooool00oooool010000000okK10?nf`@0000020?nf`@080000003o
]/40okK10000003o]/4000000?nf`@0000020?nf`@03o`00003o]/7o000000P0okK100Go00000?nf
`@3o]/40okK1o`0000020?nf`@08o`00003o]/40okK10000003o]/4000000?nf`Ol000020?nf`@04
0000003o]/40okK1o`0000@0okK10P0000070?nf`@<000001@3o]/42000000@0okK100?o00000?nf
`@3o]/400P3o]/42000000H0okK100?o00000?nf`@3o]/402P3o]/400ol00000okK10?nf`@030?nf
`@050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10?nf`@02ooooo`0300000?oooooo
oooo00?ooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Mooooo``0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0?0?nf
`@L0oooo4`3o]/44o`00o`@0okK10ol00?lI0?nf`B3ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`0300000?oooooooooo00?ooooo00@000000?nf`@3o]/4000000P3o]/40
20000000okK10?nf`@000000okK10000003o]/4000000P3o]/400ol00000okK1o`00000<0?nf`@04
o`00003o]/40okK1o`000080okK100D000000?nf`@000000okK1000000020?nf`@040000003o]/40
okK1000000<0okK100Co00000?nf`@3o]/40okK11`3oool20?nf`@8000001@3o]/400`000000okK1
0?nf`@020?nf`@800000103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100T0okK1
0P0000040?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10?nf`@02ooooo`03
00000?oooooooooo00?ooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Mooooo``0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK1
0?nf`@0;0?nf`@l0oooo4`3o]/44o`00oad0okK17oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Kooooo00<00000ooooooooool00oooool010000000okK10?nf`@0000020?nf`@04
0000003o]/40okK100000080okK10P0000030?nf`@03o`00003o]/7o000000/0okK100Co00000?nf
`@3o]/7o00000P3o]/400`000000okK1000000020?nf`@030000003o]/4000000080okK100D00000
0?nf`@3o]/40okK10000000?0?ooo`030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o
]/42000000<0okK10P0000050?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/400P3o
]/401@000000okK10?nf`@3o]/4000000080okK100D000000?nf`@3o]/7ooooo00000005ooooo`03
00000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
7?ooool<0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/402P3o]/4C0?oooc80okK1
7oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00<00000ooooooooool0
0_ooool01@000000okK10?nf`@3o]/4000000080okK100P000000?nf`@3o]/4000000?nf`@000000
okK100000080okK100Co00000?nf`@3o]/7o00002P3o]/401?l00000okK10?nf`Ol000020?nf`@03
0000003o]/7o00000080okK100<000000?nf`@0000000P3o]/401@000000okK10?nf`@3o]/400000
0140oooo00<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK1
0080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@0:0?nf`@050000003o]/40okK1
0?nf`@0000000`3o]/4010000000okK10?nf`@0000020?nf`@;ooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01cooooo303o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK100T0okK15`3oool`
0?nf`Aoooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`0300000?oooooo
oooo00?ooooo00Go00000?nf`@3o]/40okK1o`0000020?nf`@030000003o]/4000000080okK100<0
00000?nf`Ol000000P3o]/401?l00000okK10?nf`Ol000090?nf`@05o`00003o]/40okK1o`00003o
]/400P0000001`3o]/4000000?nf`@3o]/4000000?nf`@0000000P3o]/401@000000okK10?nf`@3o
ool0000001<0oooo00?o00000?ooo`3o]/400`3o]/42000000@0okK10P0000040?nf`@030000003o
]/40okK100<0okK100<000000?nf`@3o]/402P3o]/401@000000okK10?nf`@3o]/4000000080okK1
00H000000?nf`@3o]/40okK10000003o]/42ooooo`0300000?oooooooooo00?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo``0
okK100?o003o0?nf`@3o]/405@3o]/400ol00?l0okK10?nf`@080?nf`AX0oooo;`3o]/4Nooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`05
0000003o]/40okK10?nf`@0000000P3o]/400`000000okK1000000020?nf`@030000003o]/400000
0080okK100Co00000?nf`@3o]/7o00001`3o]/42o`0000050?nf`Ol0003o00000?nf`@0000000`3o
]/401@000000okK10000003o]/40000000<0okK100@000000?nf`@3oool000005@3oool200000003
0?ooo`3o]/40okK10080okK10P0000040?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o
]/400P3o]/400`000000okK10?nf`@0;0?nf`@040000003o]/40okK100000080okK100D000000?nf
`@3o]/40okK1000000020?nf`@03ooooo`00003ooooo00Cooooo00<00000ooooooooool05?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`d0okK100?o003o0?nf
`@3o]/40503o]/400ol00?l0okK10?nf`@080?nf`A`0oooo;P3o]/4Nooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05?ooool00`00003oooooooooo`03ooooo`050000003o]/40okK1
0?nf`@0000000P3o]/400`000000okK1000000020?nf`@030000003o]/40000000<0okK100Co0000
0?nf`@3o]/40okK10ol000020?nf`@;o00000P3o]/401?l00000okK10?nf`@0000030?nf`@050000
003o]/7o00000?nf`@0000000`3o]/4010000000okK10?ooo`0000070?ooo`L000002P3oool20000
00D0okK100<000000?nf`@3o]/400P3o]/401Ol00000okK10?nf`@3o]/40000000@0okK100<00000
0?nf`@3o]/40303o]/4010000000okK10?nf`@0000020?nf`@060000003o]/40okK10?nf`@000000
okK10_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo01Cooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool06oooool=0?nf`@03o`00o`3o]/40okK101<0okK1
00?o003o0?nf`@3o]/40203o]/4N0?ooobd0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01?ooooo00<00000ooooooooool00oooool01@00003ooooo0?nf`@3o]/4000000080
okK100@000000?nf`@3o]/4000000P3o]/400`000000okK1000000030?nf`@03o`00003o]/40okK1
00@0okK10_l000030?nf`@04o`00003o]/40okK1o`000080okK100H00000o`00003o]/4000000?nf
`@0000030?nf`@040000003o]/40oooo000000H0oooo0P0000070?ooo`0400000?l0000000000000
00P0oooo00<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@020?nf`@050000003o]/40okK1
0?nf`@0000000`3o]/400`000000okK10?nf`@050?nf`@<000001@3o]/401?l00000okK10?nf`@00
00020?nf`@050000003o]/40okK10000003o]/400_ooool00`00003oooooooooo`02ooooo`030000
0?oooooooooo01Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06ooo
ool=0?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/40203o]/4P0?ooob`0okK17_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00<00000ooooooooool00ooo
ool01@00003ooooo0?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000P3o]/400`000000
okK1000000030?nf`@03o`00003o]/40okK100P0okK10_l000020?nf`@030000003o]/40000000<0
okK100<000000?nf`@0000000P3o]/401Ol00000okK10?ooo`3oool0000000D0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`060?ooo`030000003o]/40okK100<0okK100D000000?nf
`@3o]/40okK1000000030?nf`@050000003o]/40okK10?nf`@0000001@3o]/42000000<0okK10P00
00030?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/4000000?nf`@02ooooo`03
00000?oooooooooo00;ooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Kooooo`d0okK100?o003o0?nf`@3o]/40403o]/42o`00o`/0okK1
803oool/0?nf`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`030000
0?oooooooooo00?ooooo00D00000ooooo`3o]/40okK1000000020?nf`@030000003o]/40000000<0
okK100<000000?nf`@000000103o]/400ol00000okK10?nf`@050?nf`@;o00000`3o]/400`000000
okK1000000030?nf`@030000003o]/40000000<0okK100@000000?nf`@3oool000001P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@020?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@050?nf`@040000003o]/40okK1000000<0okK100<000000?nf`@0000000P3o
]/401@000000okK1ooooooooool0000000Cooooo00<00000ooooooooool05?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`h0okK100?o003o0?nf`@3o]/403@3o
]/42o`00o`/0okK18`3oool[0?nf`Akooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Booooo`0300000?oooooooooo00?ooooo00D00000ooooooooool0okK1000000020?nf`@040000
003o]/40okK100000080okK100@000000?nf`@3o]/400000103o]/400ol00000okK10?nf`@030?nf
`@;o0000103o]/400`000000okK1o`0000030?nf`@03o`00003o]/40000000<0okK100@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00?o0000
0?nf`@3o]/400P3o]/401@000000okK10?nf`@3o]/40000000<0okK100@000000?nf`@3o]/400000
0`3o]/400`000000okK10?nf`@060?nf`@050000003o]/40okK10?nf`@0000000P3o]/4010000000
okK10?nf`@0000020?nf`@0400000?oooooooooo000000Cooooo00<00000ooooooooool05?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`h0okK100?o003o0?nf
`@3o]/40303o]/400ol00?l0okK10?nf`@0:0?nf`BD0oooo:`3o]/4Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04_ooool00`00003oooooooooo`03ooooo`0500000?oooooooooo
0?nf`@0000000P3o]/4010000000okK10?nf`Ol000020?nf`@040000003o]/40okK1000000D0okK1
1Ol000040?nf`@0600000?l00000okK10?nf`@000000okK10P0000000`3o]/4000000?nf`@020?nf
`@040000003oool0oooo000000H0oooo00<000000?ooo`3oool0403oool00ol00000oooo0?ooo`06
0?ooo`030000003o]/40okK10080okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o
]/40okK100000080okK100<000000?nf`@3o]/40203o]/4010000000okK10?nf`@0000020?nf`@04
0000003o]/40okK100000080okK100@000000?nf`Oooool000001?ooool00`00003oooooooooo`0D
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo403o]/42o`00
o`T0okK10ol00?l=0?nf`BD0oooo5P3o]/45o`00oa00okK17Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01;ooooo00<00000ooooooooool00oooool01@00003ooooo0?nf`@3o]/40
00000080okK100Co00000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@00000=0?nf`@070000
003o]/40okK10?nf`@000000okK1000000030?nf`@050000003o]/40okK10000003o]/400P3oool0
0`000000oooo0?ooo`030?ooo`03o`00003oool0oooo0180oooo0P0000060?ooo`030000003o]/40
okK10080okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080okK1
00<000000?nf`@3o]/40203o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK10000
0080okK100@000000?nf`Oooool000001?ooool00`00003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo4P3o]/42o`00o`D0okK10_l00?l?0?nf
`BL0oooo503o]/400ol00?l0okK10?nf`@030?nf`@;o003o3P3o]/4Mooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04Oooool00`00003oooooooooo`03ooooo`0500000?oooooooooo
0?nf`@0000000`3o]/400`000000okK1000000020?nf`@050000003o]/40okK10?nf`@000000303o
]/401`000000okK10?nf`@3o]/4000000?nf`Ol000000P3o]/4200000080okK100D000000?nf`@3o
ool0oooo000000050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool00`00
0000okK10?nf`@020?nf`@060000003o]/40okK10000003o]/4000000P3o]/4010000000okK10?nf
`@0000050?nf`@Co00000`3o]/4010000000okK10?nf`@0000020?nf`@030000003o]/7o00000080
okK100@000000?nf`Oooool000001Oooool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo503o]/45o`00oa40okK19`3ooolC0?nf`@03
o`00o`3o]/40okK100H0okK100?o003o0?nf`@3o]/402`3o]/4Mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04Oooool00`00003oooooooooo`03ooooo`0500000?oooooooooo0?nf
`Ol000000P3o]/4010000000okK10?nf`@0000020?nf`@050000003o]/40okK10?nf`@0000002@3o
]/4200000007o`00003o]/40okK100000?l00000okK1000000020?nf`@050000003o]/40okK10?nf
`Ol000000P3o]/400`3ooooo00000?ooo`040?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool00`3oool00`3o]/4000000?nf`@020?nf`@060000003o]/40okK10000003o]/4000000P3o
]/4010000000okK10?nf`@0000030?nf`@;o0000103o]/401Ol00000okK10?nf`@3o]/7o00000080
okK100D000000?nf`@000000okK1000000020?nf`@040000003o]/7ooooo000000Gooooo00<00000
ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Joooo
obT0okK1:@3oool@0?nf`@;o003o2P3o]/400ol00?l0okK10?nf`@0:0?nf`Agooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Aooooo`0300000?oooooooooo00?ooooo00D00000oooo
ooooool0okK1000000020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK1
000000080?nf`@030000003o]/40okK100<0okK100@000000?nf`@3o]/4000000P3o]/401P000000
okK10?nf`@3o]/4000000?nf`@80oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00@0oooo00D000000?nf`@3o]/40okK1000000020?nf`@030000003o
]/4000000080okK100@000000?nf`@3o]/4000000P3o]/400ol00000okK10?nf`@050?nf`@04o`00
003o]/40okK100000080okK100D000000?nf`@000000okK1000000020?nf`@040000003o]/7ooooo
000000Gooooo00<00000ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0JooooobT0okK1:@3oool?0?nf`@03o`00o`3o]/40okK100/0okK100?o003o0?nf
`@3o]/402@3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00`00
003oooooooooo`03ooooo`0500000?oooooooooo0?nf`@0000000P3o]/4010000000okK10?nf`@00
00020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@030?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK1000000020?nf`@03
0?ooo`000000oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`05
0000003o]/40okK10?nf`@0000000P3o]/401@000000okK10000003o]/4000000080okK100@00000
0?nf`@3o]/7o0000203o]/401?l00000okK10?nf`@0000020?nf`@050000003o]/4000000?nf`@00
00000P3o]/4010000000okK1ooooo`000005ooooo`0300000?oooooooooo01?ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool06_oooolY0?nf`BT0oooo3P3o]/400ol00?l0
okK10?nf`@0=0?nf`@03o`00o`3o]/40okK100P0okK17Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo013ooooo00<00000ooooooooool00oooool01@00003oooooooooooooool00000
0080okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@070000003o]/40okK10?nf`@000000okK1
000000030?nf`@050000003o]/40okK10?nf`@0000001@3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00<0oooo00L000000?nf`@3o]/40okK10000003o]/4000000080okK100<00000
0?nf`@0000000P3o]/400`000000okK1o`00000:0?nf`@06o`00003o]/40okK10000003o]/400000
0P3o]/401P000000okK10000003o]/4000000?nf`@;ooooo00D00000oooooooooooooooo0000000F
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo:@3o]/4Y0?oo
o`h0okK100?o003o0?nf`@3o]/403@3o]/400ol00?l0okK10?nf`@080?nf`Agooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`0300000?oooooooooo00?ooooo00D00000oooo
oooooooooooo000000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`000000okK10?nf
`@030?nf`@05o`000000000000000?nf`Ol000001@3o]/401@000000okK10?nf`@3o]/4000000080
okK100Co00000?nf`@3o]/7o00000`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool00`3oool01`000000okK10?nf`@3o]/4000000?nf`@0000000P3o
]/401`000000okK1o`00003o]/4000000?nf`Ol000000`3o]/46o`0000<0okK100go00000?nf`@00
0000okK1o`0000000000okK10000003o]/4000000?nf`@000000okK100;ooooo00D00000oooooooo
oooooooo0000000Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[o
oooo:03o]/4[0?ooo``0okK100?o003o0?nf`@3o]/403`3o]/400ol00?l0okK10?nf`@070?nf`Ago
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`0300000?oooooooooo00?o
oooo00D00000oooooooooooooooo000000020?nf`@050000003o]/40okK10?nf`@0000000P3o]/40
0`000000okK10?nf`@060?nf`@030000003o]/40okK100@0okK100D000000?nf`@3o]/40okK10000
00020?nf`@040000003o]/40okK1000000<0okK100<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00L000000?nf`@3o]/40okK10000003o]/400000
0080okK100L000000?nf`@000000okK10000003o]/7o00000080okK100?o00000?nf`@3o]/40103o
]/401_l00000okK10?nf`Ol00000okK100000080okK100P000000?nf`@000000okK10000003o]/40
00000?nf`@;ooooo00D00000oooooooooooooooo0000000Fooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo01[ooooo:03o]/4[0?ooo``0okK100?o003o0?nf`@3o]/403`3o
]/400ol00?l0okK10?nf`@070?nf`Agooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`0300000?oooooooooo00?ooooo00D00000oooooooooooooooo000000020?nf`@050000
003o]/40okK10?nf`@0000000P3o]/400`000000okK10?nf`@0=0?nf`@040000003o]/40okK10000
00<0okK100@000000?nf`@3o]/4000000`3o]/400`000000oooo0?ooo`030?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool00`3oool02@000000okK10?nf`@3o]/4000000?nf`@000000
okK1000000020?nf`@050000003o]/4000000?nf`Ol000000P3o]/400ol00000okK10?nf`@050?nf
`@05o`00003o]/7o00000?nf`@0000000P3o]/4020000000okK10000003o]/4000000?nf`@000000
okK10_ooool01@00003oooooooooooooool0000001Kooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool06OoooolY0?nf`B/0oooo2`3o]/400ol00?l0okK10?nf`@0@0?nf`@03
o`00o`3o]/40okK100L0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00<00000ooooooooool00oooool01@00003oooooooooo`3o]/4000000080okK100@000000?nf
`@3o]/4000000`3o]/400`000000okK10?nf`@0<0?nf`@050000003o]/40okK10?nf`@0000000P3o
]/4010000000okK10?nf`@0000030?nf`@030000003oool0oooo00<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`020?ooo`040000003o]/40okK100000080okK100L000000?nf`@00
0000okK10000003o]/4000000080okK100?o00000?nf`Ol00000203o]/403?l00000okK10?nf`Ol0
0000okK10000003o]/4000000?nf`@000000okK100000080okK100@00000ooooooooool000000ooo
ool00`00003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01Wooooo:@3o]/4[0?ooo`/0okK100?o003o0?nf`@3o]/40403o]/400ol00?l0okK10?nf`@07
0?nf`Agooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`0300000?oooooo
oooo00?ooooo00D00000ooooooooool0okK1000000020?nf`@040000003o]/40okK1000000<0okK1
00<000000?nf`@3o]/40303o]/4010000000okK10?nf`@0000030?nf`@040000003o]/40okK10000
00<0okK100<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0080oooo00@000000?nf`@3o]/4000000P3o]/402@000000okK1o`00003o]/4000000?nf`@000000
okK1o`0000020?nf`@03o`00003o]/40okK100H0okK100co00000?nf`@3o]/7o00000?nf`@000000
okK10000003o]/4000000?nf`@0000020?nf`@0400000?oooooooooo000000?ooooo00<00000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0IooooobT0
okK1:`3oool;0?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/401`3o]/4Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`03ooooo`05
00000?oooooooooo0?nf`@0000000P3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40
okK100`0okK100@000000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@0000030?nf`@030000
003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?ooo`040000
003o]/40okK100000080okK100H000000?nf`@000000okK100000?l000020?nf`@04o`00003o]/40
okK1o`000080okK10ol000030?nf`@0<o`00003o]/40okK1o`00003o]/4000000?nf`@000000okK1
0000003o]/4000000P3o]/401000003oooooooooo`000003ooooo`0300000?oooooooooo01Cooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06OoooolY0?nf`B/0oooo2P3o
]/400ol00?l0okK10?nf`@0A0?nf`@03o`00o`3o]/40okK100L0okK17Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00<00000ooooooooool00oooool01@00003ooooooooo
o`3o]/4000000080okK100D000000?nf`@3o]/40okK1000000020?nf`@030000003o]/40okK100`0
okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1000000<0okK100<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3o]/4000000P3o]/402@000000okK10000003o]/4000000?nf`@000000okK1o`0000020?nf
`@04o`00003o]/7o0000o`0000<0okK101Co00000?nf`@3o]/40okK1o`00003o]/7o00000?nf`@00
0000okK10000003o]/4000000?nf`@000000okK10000003o]/7ooooo000000Cooooo00<00000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0JooooobP0
okK1:`3oool:0?nf`@03o`00o`3o]/40okK10180okK100?o003o0?nf`@3o]/401P3o]/4Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`03ooooo`05
00000?ooooooooooooooo`0000000P3o]/401@000000okK10?nf`@3o]/4000000080okK100<00000
0?nf`@3o]/40303o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/400000
0`3o]/400`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00?o00000?ooo`3oool0
0P3oool010000000oooo0?nf`@0000020?nf`@080000003o]/4000000?nf`@000000okK100000?l0
00020?nf`@04o`00003o]/40okK1o`0000D0okK101?o00000?nf`@3o]/7o00000?nf`Ol00000okK1
0000003o]/4000000?nf`@000000okK10000003o]/4000000?nf`Oooool0000000Cooooo00<00000
ooooooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Joooo
obP0okK1:`3oool90?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/401P3o]/4Moooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`03oooo
o`0500000?ooooooooooooooo`0000000P3o]/401@000000okK10?nf`@3o]/4000000080okK100<0
00000?nf`@3o]/40303o]/401@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/40
00000`3o]/400`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?nf`@0000020?nf`@080000003o]/4000000?nf`@000000okK10000
0?l000020?nf`@04o`00003o]/40okK1o`0000D0okK101?o00000?nf`@3o]/7o00000?nf`Ol00000
okK10000003o]/4000000?nf`@000000okK10000003o]/4000000?nf`Oooool0000000Cooooo00<0
0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0J
ooooobT0okK1:@3oool:0?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/401P3o]/4M
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`03
ooooo`0500000?ooooooooooooooo`0000000P3o]/401@000000okK10?nf`@3o]/4000000080okK1
00<000000?nf`@3o]/401@3o]/42000000H0okK100D000000?nf`@3o]/40okK1000000020?nf`@04
0000003o]/40okK1000000<0okK100<000000?ooo`3oool0103oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0080oooo00H000000?nf`@3o]/4000000?nf`@0000020?nf`@080000003o
]/4000000?nf`@00003o00000?nf`Ol000020?nf`@03o`00003o]/40okK100@0okK101?o00000?nf
`@3o]/7o00000?nf`Ol00000okK10000003o]/4000000?nf`@000000okK10000003o]/4000000?nf
`Oooool0000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Joooooa80okK12?l00?l?0?nf`BT0oooo2P3o]/400ol00?l0okK10?nf
`@0C0?nf`@03o`00o`3o]/40okK100H0okK17Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00<00000ooooooooool00oooool01P00003oooooooooooooool0okK100000080
okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@030?nf`@040000003o]/40okK1
000000D0okK100Go00000?nf`@3o]/40okK1o`0000020?nf`@050000003o]/40okK10?nf`@000000
0P3o]/400`000000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?nf`@0000020?nf`@080000003o]/4000000?nf`@000000okK100000?l0
00020?nf`@04o`00003o]/40okK1o`0000L0okK101;o00000?nf`Ol00000okK1o`00003o]/400000
0?nf`@000000okK10000003o]/4000000?nf`@000000okK1ooooo`000004ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool?0?nf
`@?o003o203o]/42o`00o`d0okK1:@3oool90?nf`@03o`00o`3o]/40okK101<0okK100?o003o0?nf
`@3o]/401`3o]/4Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00
003oooooooooo`03ooooo`0600000?ooooooooooooooo`3o]/4000000P3o]/4010000000okK10?nf
`@0000030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400ol00000okK1
0?nf`@030?nf`@040000003o]/40okK100000080okK100Go00000?nf`@3o]/40okK1o`0000030?nf
`@030000003oool0oooo00@0oooo00?o00000000003oool05`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0okK100000080okK100X000000?nf`@000000okK10000003o]/400000o`00003o
]/7o00000P3o]/400ol00000okK10?nf`@060?nf`@0Bo`00003o]/7o00000?nf`Ol00000okK10000
003o]/4000000?nf`@000000okK10000003o]/4000000?nf`Oooool000001?ooool00`00003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo3P3o
]/400ol00?l0okK10?nf`@0;0?nf`@03o`00o`3o]/40okK100X0okK1:@3oool90?nf`@03o`00o`3o
]/40okK100L0okK10ol000090?nf`@03o`00o`3o]/40okK100L0okK17Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool01P00003ooooooooo
ooooool0okK100000080okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@020?nf
`@030000003o]/40okK100<0okK10P0000040?nf`@040000003o]/40okK100000080okK100@00000
0?nf`@3o]/4000000`3o]/400`3oool000000?ooo`060?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0103oool010000000oooo0?nf`@0000020?nf`@0:0000003o]/4000000?nf`@00
0000okK100000?l00000okK1o`000080okK100?o00000?nf`@3o]/401P3o]/404_l00000okK1o`00
003o]/7o00000?nf`@000000okK10000003o]/4000000?nf`@000000okK10000003o]/7ooooo0000
00Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Jooooo`d0okK100?o003o0?nf`@3o]/403@3o]/42o`00o`/0okK19`3oool:0?nf`@03
o`00o`3o]/40okK100H0okK11Ol000080?nf`@03o`00o`3o]/40okK100L0okK17Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00<00000ooooooooool00oooool01@00003o
ooooooooo`3o]/40000000<0okK100@000000?nf`@3o]/4000000P3o]/400`000000okK10?nf`@02
0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@00
00020?nf`@040000003o]/40okK1000000<0okK100<0oooo0000003oool01P3oool00`000000oooo
0?ooo`0A0?ooo`8000001P3oool04ol00000oooo0?nf`@3o]/7o00000?nf`@000000okK10000003o
]/4000000?nf`@000000okK1o`00003o]/7o00000?nf`Ol00000203o]/403Ol00000okK10?nf`Ol0
0000okK1o`00003o]/4000000?nf`Ol0000000000?nf`@0000000P3o]/400`000000okK100000004
ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool06_ooool=0?nf`@03o`00o`3o]/40okK100l0okK10_l00?l90?nf`BL0oooo2P3o]/400ol0
0?l0okK10?nf`@060?nf`@Go0000203o]/400ol00?l0okK10?nf`@070?nf`Agooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Aooooo`0300000?oooooooooo00?ooooo00<00000oooo
ooooool00P3o]/401?l00000okK10?nf`@0000020?nf`@040000003o]/40okK1000000@0okK100<0
00000?nf`@3o]/401P3o]/400ol00000okK10?nf`@020?nf`@040000003o]/40okK100000080okK1
00@000000?nf`@3o]/4000000P3o]/420?ooo`030000003oool0oooo00D0oooo00?o00000000003o
ool0303oool4000000P0oooo00@000000?ooo`3o]/4000000P3o]/403@000000okK10000003o]/40
00000?nf`@000000okK1o`00003o]/7o00000?nf`Ol00000203o]/401ol00000okK10?nf`Ol00000
okK1o`00003o]/400P000000103o]/4000000?nf`Ol000020?nf`@030000003o]/40000000Cooooo
00<00000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Jooooo`d0okK100?o003o0?nf`@3o]/404@3o]/400ol00?l0okK10?nf`@070?nf`BD0oooo2`3o
]/400ol00?l0okK10?nf`@060?nf`@Go0000203o]/400ol00?l0okK10?nf`@070?nf`Agooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`0300000?oooooooooo00Cooooo00Go
0000ooooo`3o]/40okK1000000020?nf`@040000003o]/40okK1o`000080okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@070?nf`@050000003o]/40okK10?nf`@0000000P3o]/401@00
0000okK10?nf`@3o]/7o00000080okK100Go00000?nf`@3o]/40oooo000000090?ooo`d00000303o
ool010000000okK10?nf`@0000020?nf`@0=0000003o]/4000000?nf`@000000okK10000003o]/7o
00000?nf`Ol00000okK1o`0000080?nf`@07o`00003o]/40okK1o`00003o]/7o00000?nf`@020000
00040?nf`@000000okK100000080okK100<000000?nf`@0000001?ooool00`00003oooooooooo`0E
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01_ooooo2`3o]/400ol0
0?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100P0okK18`3oool:0?nf`@03o`00o`3o]/40okK1
00P0okK10ol000090?nf`@03o`00o`3o]/40okK100L0okK17Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01;ooooo00<00000ooooooooool00oooool01@00003oooooooooo`3o]/40
00000080okK100@000000?nf`@3o]/4000000`3o]/401@000000okK10?nf`@3o]/40000000X0okK1
00D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1000000<0okK100D000000?nf
`@3o]/40okK10000000P0?ooo`050000003oool0okK10?nf`@0000000P3o]/403@000000okK10000
003o]/4000000?nf`@000000okK1o`00003o]/7o00000?nf`Ol00000203o]/401ol00000okK10?nf
`Ol00000okK1o`00003o]/400P000000103o]/4000000?nf`@0000020?nf`@030000003o]/400000
00Cooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Kooooo`/0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf`@080?nf`B80
oooo2`3o]/400ol00?l0okK10?nf`@0D0?nf`@03o`00o`3o]/40okK100H0okK17_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00<00000ooooooooool01?ooool01@00003o
oooo0?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@3o
]/40000000/0okK100D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK1000000<0
okK100D000000?nf`@3o]/40oooo0000000N0?ooo`050000003oool0okK10?nf`@0000000P3o]/40
2`000000okK10000003o]/4000000?nf`@000000okK1o`00003o]/7o00000080okK100?o00000?nf
`@3o]/401@3o]/402Ol00000okK10?nf`Ol00000okK1o`00003o]/4000000?nf`@0200000080okK1
00H000000?nf`@000000okK1ooooo`000003ooooo`0300000?oooooooooo01Kooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool06oooool;0?nf`@03o`00o`3o]/40okK101@0
okK100?o003o0?nf`@3o]/40203o]/4P0?ooo``0okK100?o003o0?nf`@3o]/40503o]/400ol00?l0
okK10?nf`@060?nf`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03
00000?oooooooooo00?ooooo00D00000ooooo`3o]/40okK1000000020?nf`@040000003o]/40okK1
00000080okK100D000000?nf`@3o]/40okK10000000<0?nf`@05o`0000000000okK10?nf`@000000
0P3o]/401?l00000okK10?nf`@0000030?nf`@040000003o]/40okK10?ooo`8000006@3oool30000
00050?ooo`3o]/40okK10?nf`@0000000P3o]/402`000000okK10000003o]/4000000?nf`@000000
okK1o`00003o]/7o00000080okK100?o00000?nf`@3o]/401@3o]/402Ol00000okK10?nf`Ol00000
okK1o`00003o]/4000000?nf`@0200000080okK100H000000?nf`@000000okK1ooooo`000003oooo
o`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool06oooool;0?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/402@3o]/4N0?ooo`d0
okK100?o003o0?nf`@3o]/40503o]/400ol00?l0okK10?nf`@060?nf`Akooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Cooooo`0300000?oooooooooo00?ooooo00D00000ooooo`3o
]/40okK1000000020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/40okK10000
00070?nf`@?o0000103o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK1o`0000<0
okK100?o00000?nf`@3o]/400P3oool2000001@0oooo0`0000030?ooo`<0okK100l000000?nf`@3o
]/40okK10000003o]/4000000?nf`@000000okK10000003o]/7o00000?nf`Ol000000P3o]/400ol0
0000okK10?nf`@050?nf`@09o`00003o]/40okK1o`00003o]/7o00000?nf`@000000okK100800000
0P3o]/401P000000okK10000003o]/7ooooo000000?ooooo00<00000ooooooooool05_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Kooooo`/0okK100?o003o0?nf`@3o
]/405@3o]/400ol00?l0okK10?nf`@090?nf`A`0oooo3P3o]/400ol00?l0okK10?nf`@0C0?nf`@03
o`00o`3o]/40okK100L0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Co
oooo00<00000ooooooooool00oooool01@000000okK10?nf`@3o]/4000000080okK100@000000?nf
`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/40000000@0okK10_l000030?nf`@03o`00003o
]/40okK10080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000030?nf`@03
0000003o]/40okK100<0oooo0`0000090?ooo`P000001@3oool30?nf`@07o`00003o]/40okK10?nf
`Ol00000okK1000000020?nf`@070000003o]/4000000?nf`Ol00000okK1o`0000030?nf`@03o`00
003o]/40okK10080okK10_l000030?nf`@;o000000X0okK1o`00003o]/4000000?nf`@000000okK1
0000003o]/4000000P3o]/401@00003oooooooooooooool0000001Wooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool07?ooool;0?nf`@03o`00o`3o]/40okK101D0okK100?o
003o0?nf`@3o]/402@3o]/4I0?oooa00okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK10?nf
`@070?nf`Akooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`0300000?oo
oooooooo00Cooooo00D000000?nf`@3o]/40okK1000000020?nf`@040000003o]/40okK100000080
okK100@000000?nf`@3o]/400000103o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK1
0080okK100Co00000?nf`@3o]/7o00000P3o]/4010000000okK10?nf`@0000030?nf`@030000003o
]/40okK100D0oooo2@00000;0?ooo`<0okK10P0000030?nf`@040000003o]/40okK100000080okK1
00L000000?nf`@000000okK1o`00003o]/7o000000@0okK100Co00000?nf`Ol0003o0000103o]/40
1_l00000okK1o`00003o]/4000000?nf`@80000000Go00000?nf`@000000okK1000000020?nf`@05
o`000?ooooooooooooooo`0000006Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Looooo`/0okK100?o003o0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0:0?nf`AD0
oooo4P3o]/400ol00?l0okK10?nf`@0B0?nf`@03o`00o`3o]/40okK100L0okK17oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01Cooooo00<00000ooooooooool01?ooool01Ol00000
okK10?nf`@3o]/4000000080okK100Co00000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@00
00040?nf`@03o`00003o]/40okK100@0okK100Go00000?nf`@3o]/40okK1000000030?nf`@030000
003o]/40000000<0okK100H000000?nf`@3o]/40okK1o`00000000020?nf`AD0oooo0P3o]/430000
00@0okK100D000000?nf`@3o]/40okK1000000020?nf`@070000003o]/7o00000?nf`Ol00000okK1
o`0000050?nf`@03o`00003o]/40okK100<0okK100Oo00000?nf`@3o]/7o00000?nf`@000000okK1
008000000P3o]/401P000000okK10000003o]/7ooooo000000?ooooo00<00000ooooooooool05ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Looooo`/0okK100?o003o
0?nf`@3o]/405P3o]/400ol00?l0okK10?nf`@0<0?nf`A40oooo503o]/400ol00?l0okK10?nf`@0B
0?nf`@03o`00o`3o]/40okK100L0okK17oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Gooooo00<00000ooooooooool00oooool00`000000okK10?nf`@020?nf`@030000003o]/40
000000<0okK100@000000?nf`@3o]/4000000P3o]/401@000000okK10?nf`@3o]/7o000000L0okK1
00Co00000?nf`@3o]/4000000`3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK1
0080okK10P0000020?nf`@h0oooo1`0000060?nf`@030000003o]/40okK10080okK100P000000?nf
`@3o]/4000000?nf`@000000okK1o`000080okK100?o00000?nf`@3o]/401`3o]/403_l00000okK1
0?nf`Ol00000okK10000003o]/4000000?nf`@000000okK10000003o]/4000000P3o]/400oooool0
0000ooooo`02ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool07Oooool;0?nf`@03o`00o`3o]/40okK100T0okK10ol0000:0?nf`@03o`00
o`3o]/40okK100d0okK13@3ooolF0?nf`@03o`00o`3o]/40okK10140okK100?o003o0?nf`@3o]/40
203o]/4Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00`00003ooooo
ooooo`04ooooo`050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf
`@040000003o]/40okK1000000<0okK100?o00000?nf`@3o]/401@3o]/401Ol00000okK10?nf`@3o
]/40000000<0okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@030?nf`A000000
00<0oooo0?nf`@3o]/402@3o]/400ol00000okK10?nf`@020?nf`@040000003o]/40okK100000080
okK100<000000?nf`Ol000000P3o]/400ol00000okK10?nf`@060?nf`@08o`00003o]/40okK10?nf
`Ol00000okK10000003o]/4200000080okK100<000000?nf`Ol000000P3o]/400`00003ooooooooo
o`02ooooo`0300000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool07Oooool;0?nf`@03o`00o`3o]/40okK100P0okK11Ol0000:0?nf`@03o`00o`3o]/40
okK10100okK11@3ooolK0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/40203o]/4P
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00`00003oooooooooo`04
ooooo`050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@0000020?nf`@04o`00
003o]/40okK1000000<0okK100?o00000?nf`@3o]/401@3o]/401?l00000okK10?nf`@3o]/420000
0080okK100@000000?nf`@3o]/4000000`3o]/400`000000okK10?nf`@0:0?nf`@D0oooo3@3o]/42
000000D0okK100@000000?nf`@3o]/4000000P3o]/400`000000okK1o`0000030?nf`@03o`00003o
]/40okK100<0okK10_l000030?nf`@09o`00003o]/4000000?nf`@000000okK10000003o]/7o0000
0080okK100@000000?nf`Oooool000001?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo01gooooo2`3o]/400ol00?l0okK10?nf`@080?nf
`@Go00002P3o]/400ol00?l0okK10?nf`@0`0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf
`@3o]/40203o]/4Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00`00
003oooooooooo`03ooooo`050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`@00
00020?nf`@040000003o]/40okK1000000<0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK1
0?nf`@030?nf`@030000003o]/40000000<0okK100D000000?nf`@3o]/40okK1o`000002000000d0
okK13P0000050?nf`@0500000?l00000okK10?nf`Ol000000`3o]/400`000000okK1o`0000040?nf
`@Go0000103o]/402_l00000okK10?nf`@000000okK10000003o]/4000000?nf`@0000020?nf`@04
0000003o]/7ooooo000000?ooooo00<00000ooooooooool06?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0Nooooo`/0okK100?o003o0?nf`@3o]/401`3o]/45o`0000/0
okK100?o003o0?nf`@3o]/40;`3o]/400ol00?l0okK10?nf`@0>0?nf`@03o`00o`3o]/40okK100T0
okK18?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00<00000oooooooo
ool00oooool01@000000okK10?nf`@3o]/4000000080okK100@000000?nf`@3o]/4000000P3o]/40
10000000okK10?nf`@0000030?nf`@03o`00003o]/40okK100D0okK100?o00000?nf`@3o]/400P3o
]/4010000000okK10?nf`Ol000030?nf`@800000103o]/4=00000140okK10P0000040?nf`@040000
003o]/40okK1000000<0okK100?o00000?nf`@3o]/402@3o]/402?l00000okK10?nf`Ol00000okK1
0000003o]/4000000P3o]/400`000000okK1000000020?nf`@0300000?oooooooooo00;ooooo00<0
0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0N
ooooo`/0okK100?o003o0?nf`@3o]/40203o]/43o`0000`0okK100?o003o0?nf`@3o]/40;`3o]/40
0ol00?l0okK10?nf`@0=0?nf`@03o`00o`3o]/40okK100T0okK18Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00`3o]/4000000?nf`@02
0?nf`@04o`00003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/401@000000okK1
0?nf`@3o]/7o000000L0okK100?o00000?nf`@3o]/400P3o]/4010000000okK10?nf`@0000040?nf
`@03o`00003o]/40okK10180okK13@0000050?nf`@050000003o]/40okK10?nf`@0000000`3o]/42
o`0000L0okK10ol000020?nf`@050000003o]/4000000?nf`Ol000000P3o]/400`000000okK10000
00020?nf`@0300000?oooooooooo00;ooooo00<00000ooooooooool06Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0Oooooo`/0okK100?o003o0?nf`@3o]/405P3o]/40
0ol00?l0okK10?nf`@0`0?nf`@03o`00o`3o]/40okK100/0okK100?o003o0?nf`@3o]/402P3o]/4Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00`00003oooooooooo`03
ooooo`050000003o]/40okK10?nf`@0000000P3o]/4010000000okK10?nf`Ol000020?nf`@040000
003o]/40okK1000000@0okK10_l000040?nf`@03o`00003o]/40okK100<0okK100D000000?nf`@3o
]/40okK1000000040?nf`@<000002P3o]/4700000140okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@030?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/400P3o]/401P00
0000okK10?nf`@000000okK100000080okK100<000000?nf`@0000000P3o]/400`00003ooooooooo
o`02ooooo`0300000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool08?ooool;0?nf`@03o`00o`3o]/40okK101H0okK100?o003o0?nf`@3o]/40<03o]/40
0ol00?l0okK10?nf`@090?nf`@03o`00o`3o]/40okK100X0okK18_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01[ooooo00<00000ooooooooool00oooool01@000000okK10?nf`@3o
]/4000000080okK100@000000?nf`@3o]/4000000P3o]/4010000000okK10?nf`@0000050?nf`@;o
000000<0okK1o`00003o]/401@3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100@0
okK12P00000E0?nf`@<000001@3o]/400`000000okK10?nf`@040?nf`@03o`00003o]/40okK100;o
0000103o]/4010000000okK10?nf`@0000020?nf`@030000003o]/4000000080okK100<000000?nf
`@0000001Oooool00`00003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo023ooooo303o]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK10180
okK13?l00?lC0?nf`@?o003o1`3o]/400ol00?l0okK10?nf`@0:0?nf`B?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Jooooo`0300000?oooooooooo00?ooooo00<0okK10000003o
]/400P3o]/4010000000okK10?nf`@0000020?nf`@040000003o]/40okK100000080okK100<00000
0?nf`@3o]/40103o]/400ol00000okK10?nf`@060?nf`@030000003o]/40okK10080okK100?o0000
0?nf`@3o]/403@3o]/4E000000P0okK100<000000?nf`@3o]/401@3o]/42o`0000D0okK100Co0000
0?nf`@3o]/4000000P3o]/402@000000okK10?nf`@000000okK10000003o]/7oooooo`000004oooo
o`0300000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool08Oooool<0?nf`@03o`00o`3o]/40okK101@0okK100?o003o0?nf`@3o]/403`3o]/43o`00o``0
okK10_l00?lD0?nf`@;o003o0P3o]/43o`00o`d0okK18oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo00<00000ooooooooool00oooool00`3o]/4000000?nf`@020?nf`@04
0000003o]/40okK100000080okK100@000000?nf`@3o]/4000000P3o]/42000000d0okK100<00000
0?nf`@3o]/400P3o]/43000000T0okK10P0000000ol0000000000?nf`@0L0?nf`@030000003o]/40
okK100/0okK10P0000001@3o]/4000000?nf`@3o]/4000000080okK100Oo00000?nf`@3o]/400000
0?nf`Oooool0000000Cooooo00<00000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`0Qooooo`d0okK100?o003o0?nf`@3o]/404`3o]/400ol00?l0okK1
0?nf`@0>0?nf`@03o`00o`3o]/40okK100l0okK100?o003o0?nf`@3o]/404`3o]/42o`00o`l0okK1
9?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00<00000ooooooooool0
0_ooool00`3o]/7o00000?nf`@020?nf`@050000003o]/40okK1o`00000000000P3o]/400ol00000
okK1000000040?nf`@8000002`3o]/400`000000okK10?nf`@050?nf`@<000000`3o]/43000000L0
okK14?l0000:0?nf`@030000003o]/40okK100T0okK10P0000020?nf`@070000003o]/40okK10?nf
`@000000okK1000000020?nf`@050000003o]/7oooooooooo`0000001?ooool00`00003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo027ooooo3@3o]/40
0ol00?l0okK10?nf`@0C0?nf`@03o`00o`3o]/40okK100d0okK100?o003o0?nf`@3o]/404@3o]/40
0ol00?l0okK10?nf`@0S0?nf`BCooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0M
ooooo`0400000?ooooooooooooooo`80okK100D000000?nf`@3o]/40okK1000000030?nf`@050000
003o]/40okK10000003o]/400`0000030?nf`@8000002P3o]/400`000000okK10?nf`@070?nf`@<0
00001`3o]/43o`000100okK10ol000080?nf`@030000003o]/40okK100H0okK10P0000030?nf`@03
o`00003o]/40okK10080000000D0okK10000003o]/40okK1000000020?nf`@03ooooo`00003ooooo
00?ooooo00<00000ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Rooooo`d0okK100?o003o0?nf`@3o]/404P3o]/400ol00?l0okK10?nf`@0<0?nf`@03
o`00o`3o]/40okK101<0okK100?o003o0?nf`@3o]/408P3o]/4Tooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07_ooool01000003oooooooooooooool20?nf`@050000003o]/40okK1
0?nf`@0000000`3o]/4010000000okK10?nf`@0000030?nf`@030000003o]/40okK10080okK10P00
00080?nf`@030000003o]/40okK100d0okK11?l000030?nf`@co00001`3o]/44o`0000@0okK10`00
00020?nf`@80000000?o00000000003o]/400P3o]/4200000080okK100@000000?nf`@3o]/400000
0P3o]/401@000000okK10?nf`@3o]/40000000Gooooo00<00000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Sooooo`d0okK100?o003o0?nf`@3o]/40
4@3o]/400ol00?l0okK10?nf`@0;0?nf`@03o`00o`3o]/40okK101D0okK100?o003o0?nf`@3o]/40
803o]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07oooool01?l0003ooooo
ooooooooool20?nf`@040000003o]/40okK1000000<0okK100@000000?nf`@3o]/4000000`3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40303o]/42
o`0000@0okK10ol0000<0?nf`@?o0000203o]/400ol00000okK10?nf`@040?nf`@8000001P3o]/40
0`000000okK10?nf`@020?nf`@040000003o]/40okK100000080okK100D000000?nf`@3o]/7ooooo
00000005ooooo`0300000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool08oooool>0?nf`@03o`00o`3o]/40okK10100okK100?o003o0?nf`@3o]/402`3o
]/400ol00?l0okK10?nf`@0E0?nf`@03o`00o`3o]/40okK101l0okK19_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01oooooo00@00000oooooooooooooooo0`3o]/400`000000okK1
0?nf`@0200000080okK10P0000000`3o]/400000000000020?nf`@8000001@3o]/4300000080okK1
00<000000?nf`@3o]/40303o]/400ol00000okK10?nf`@030?nf`@03o`00003o]/40okK10100okK1
00?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf`@0:0?nf`@800000103o]/4010000000okK1
0?nf`@0000020?nf`@050000003o]/40okK1ooooo`0000001Oooool00`00003oooooooooo`0Loooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Cooooo3P3o]/42o`00o`l0
okK100?o003o0?nf`@3o]/402`3o]/400ol00?l0okK10?nf`@0G0?nf`@03o`00o`3o]/40okK101h0
okK19_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00@00000oooooooo
oooooooo0P3o]/400`000000okK10?nf`@020?nf`@050000003o]/40okK10?nf`@0000000P3o]/40
10000000okK10?nf`@3o]/42000000H0okK10P00000>0?nf`@03o`00003o]/40okK100<0okK100?o
00000?nf`@3o]/400`3o]/49o`0000H0okK100?o00000?nf`@3o]/401@3o]/400ol00000okK10?nf
`@080?nf`@030000003o]/40okK100<0okK100?o00000?nf`@3o]/400P0000020?nf`@05o`00003o
]/40okK1ooooool000001Oooool00`00003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo02Cooooo403o]/43o`00o`/0okK100?o003o0?nf`@3o]/402`3o
]/400ol00?l0okK10?nf`@0I0?nf`@03o`00o`3o]/40okK101`0okK19oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo027ooooo00<00000ooooooooool00`3o]/400`000000okK10?nf
`@020?nf`@050000003o]/40okK10?nf`@0000000P3o]/400`00003o0000000000020?nf`@<00000
4@3o]/42o`0000D0okK100?o00000?nf`@3o]/400P3o]/42o`0000T0okK100?o00000?nf`@3o]/40
0`3o]/400ol00000okK10?nf`@050?nf`@03o`00003o]/40okK100H0okK10P0000040?nf`@800000
0P3o]/401@000000okK10?nf`@3o]/4000000080okK100?ooooo00000?ooool01?ooool00`00003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Gooooo
4P3o]/42o`00o`P0okK100?o003o0?nf`@3o]/40303o]/400ol00?l0okK10?nf`@0I0?nf`@03o`00
o`3o]/40okK101`0okK19oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool00`3o]/400`000000okK10?nf`@020?nf`@05o`00003o]/40okK1o`000000
0000103o]/400`000000okK10?nf`@020?nf`@8000003`3o]/400ol00000okK10?nf`@040?nf`@05
o`00003o]/40okK10?nf`Ol00000303o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK1
00@0okK100?o00000?nf`@3o]/401@3o]/42000000D0okK100D000000?nf`@3o]/40okK100000004
0?nf`@050000003o]/40okK1ooooo`0000001Oooool00`00003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Kooooo4`3o]/48o`00o`h0okK100?o003o
0?nf`@3o]/402`3o]/43o`0000d0okK100?o003o0?nf`@3o]/406P3o]/4Xooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool08_ooool01000003oooooooooooooool30?nf`@030000003o
]/40okK10080okK100@000000?nf`@3o]/40okK10P0000030?nf`@030000003o]/40okK100<0okK1
0P00000=0?nf`@03o`00003o]/40okK100<0okK100?o00000?nf`@3o]/400P3o]/400ol00000okK1
0?nf`@0;0?nf`@05o`00003o]/40okK10?nf`Ol000001P3o]/400ol00000okK10?nf`@040?nf`@03
0000003o]/40okK100@0okK100D000000?nf`@3o]/40okK1000000040?nf`@050000003o]/40okK1
ooooo`0000001Oooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo02Oooooo:03o]/400ol00?l0okK10?nf`@0:0?nf`@Go0000303o]/400ol0
0?l0okK10?nf`@0I0?nf`BWooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Soooo
o`0400000?ooooooooooooooo`<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@02
0?nf`@050000003o]/40okK10?nf`@0000001P3o]/42000000/0okK100?o00000?nf`@3o]/400`3o
]/401Ol00000okK10?nf`@3o]/7o000000l0okK100Go00000?nf`@3o]/40okK1o`0000040?nf`@03
o`00003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@05
0000003o]/40okK10?nf`Ol000000P3o]/42ooooo`0300000?oooooooooo00;ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0XooooobL0
okK100?o003o0?nf`@3o]/402P3o]/45o`0000`0okK100?o003o0?nf`@3o]/40603o]/4Zooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool2000000;ooooo0`3o]/42000000<0
okK10P0000020?nf`@03o`0000000000okK10080okK100Co00000000000000000000103o]/400`00
003o0000000000080?nf`@03o`00003o]/40okK10080okK100?o00000?nf`@3o]/400P3o]/400ol0
0000okK10?nf`@0=0?nf`@05o`00003o]/40okK10?nf`Ol00000103o]/400ol00000okK10?nf`@03
0?nf`@03o`00003o]/40okK10080okK10P0000001?l00000okK10?nf`@3o]/42000000<0okK100H0
00000?nf`@3o]/7ooooo00000?l00005ooooo`0300000?oooooooooo01oooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0:?oooolX0?nf`@03o`00o`3o]/40okK100T0okK1
1Ol0000<0?nf`@03o`00o`3o]/40okK101L0okK1:oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02Kooooo00<00000ooooo`3o]/40103o]/400`000000okK10?nf`@020?nf`@040000
003o]/40okK10?nf`@8000001@3o]/42000000D0okK10P0000060?nf`@03o`00003o]/40okK10080
okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@0=0?nf`@05o`00003o]/40okK10?nf
`Ol00000103o]/401?l00000okK10?nf`@3o]/42000000@0okK100<000000?nf`@3o]/400P3o]/42
000000@0okK100<000000?nf`@3o]/400_ooool00`00003oooooooooo`04ooooo`0300000?oooooo
oooo01oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:OoooolW0?nf
`@03o`00o`3o]/40okK100X0okK10ol0000=0?nf`@03o`00o`3o]/40okK101L0okK1:oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00<00000ooooo`3o]/40103o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK10080okK10P0000050?nf`@8000001@3o]/420000
00D0okK100?o00000?nf`@3o]/400P3o]/400ol00000okK10?nf`@020?nf`@03o`00003o]/40okK1
00/0okK100Go00000?nf`@3o]/40okK1o`0000040?nf`@05o`00003o]/40okK10?nf`@0000001@3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100H000000?nf`@3o]/40okK1
ooooo`000006ooooo`0300000?oooooooooo023ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0:_oooolV0?nf`@03o`00o`3o]/40okK101X0okK100?o003o0?nf`@3o]/40
5P3o]/4/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00`00003ooooo
0?nf`@040?nf`@030000003o]/40okK10080okK100<00000o`00000000000`3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/401Ol00000okK1
0?nf`@3o]/7o000000@0okK10_l0000:0?nf`@;o0000103o]/401Ol00000okK10?nf`@3o]/7o0000
00<0okK100?o00000?nf`@3o]/400P3o]/42000000@0okK100?o00000?nf`@3o]/400P3o]/420000
00<0okK100?oooooo`000?ooool01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo02_ooooo9P3o]/400ol00?l0okK10?nf`@0H0?nf`@03
o`00o`3o]/40okK101H0okK1;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02So
oooo00<00000ooooooooool01@3o]/400ol0000000000?nf`@040?nf`@050000003o]/40okK10?nf
`Ol000000P0000040?nf`@03o`0000000000okK100@0okK100?o00000000003o]/400P3o]/400ol0
0000okK10?nf`@020?nf`@03o`00003o]/40okK100<0okK10_l000060?nf`@;o00001@3o]/401Ol0
0000okK10?nf`@3o]/7o000000<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@02
0?nf`@800000103o]/400`000000okK10?nf`@020?nf`@03ooooo`00003ooooo00Gooooo00<00000
ooooooooool08_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0/oooo
obD0okK100?o003o0?nf`@3o]/40603o]/400ol00?l0okK10?nf`@0E0?nf`Bkooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Yooooo`80000000?ooooo0?nf`@3o]/40103o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK100<0okK10P0000040?nf`@8000001@3o]/401@00
0000okK10?nf`@3o]/7o000000@0okK10_l000050?nf`@Ko00001P3o]/401Ol00000okK10?nf`@3o
]/7o000000@0okK100D000000?nf`@3o]/40okK1000000040?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400P3o]/400oooool00000ooooo`06ooooo`0300000?oooooooooo02;ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0;OoooolT0?nf`@03o`00o`3o
]/40okK101P0okK100?o003o0?nf`@3o]/404`3o]/4`ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0:oooool00`00003ooooo0?nf`@050?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100@0
00000?nf`@3o]/40okK10_l000040?nf`@03o`00003o]/40okK100d0okK100Go00000?nf`@3o]/40
okK1o`0000040?nf`@050000003o]/40okK10?nf`@000000103o]/400`000000okK10?nf`@030?nf
`@04o`00003o]/40okK10?nf`@;ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0S
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02kooooo903o]/400ol0
0?l0okK10?nf`@0F0?nf`@03o`00o`3o]/40okK101<0okK1<Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02cooooo00<00000ooooo`3o]/401@3o]/42000000@0okK100<00000o`00
00000000103o]/400`00003o0000000000030?nf`@03o`0000000000okK100<0okK10P0000030?nf
`@;o00000`3o]/43o`0000X0okK10_l000020?nf`@;o00000P3o]/4200000003o`00003o]/40okK1
008000000`3o]/42000000@0okK10P0000030?nf`@;ooooo00?o0000ooooooooool01Oooool00`00
003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo033o
oooo8`3o]/42o`00oa@0okK10_l00?lE0?nf`C;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0]ooooo`03o`000000003ooooo00H0okK10P0000050?nf`@8000001@3o]/42000000<0
okK10P0000040?nf`@030000003o]/40okK10080okK10_l000040?nf`@[o00000`3o]/401Ol00000
okK10?nf`@3o]/40000000<0okK10P0000040?nf`@030000003o]/40okK10080okK10P0000040?nf
`@03ooooo`000000000000Oooooo00<00000ooooooooool09Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0aooooob@0okK100?o003o0?nf`@3o]/403`3o]/42o`00oaH0
okK1<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00<00000ooooo`3o
]/401P3o]/400`000000okK10?nf`@040?nf`@8000001@3o]/42000000<0okK10P0000030?nf`@<0
00000`3o]/400ol00000okK10?nf`@0;0?nf`@?o00000`3o]/401@000000okK10?nf`@3o]/400000
00@0okK10P0000040?nf`@030000003o]/40okK100<0okK100?ooooo00000?ooool01oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03;o
oooo903o]/400ol00?l0okK10?nf`@0=0?nf`@03o`00o`3o]/40okK101D0okK1=?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo033ooooo0P0000070?nf`@03o`0000000000okK100D0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@800000103o]/4010000000
okK10?nf`@3o]/4=o`0000<0okK10P0000000ol00000okK10?nf`@02000000<0okK10P0000050?nf
`@03o`00003o]/40okK100<0okK100?oooooo`000?ooool01oooool00`00003oooooooooo`0Woooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03?ooooo903o]/43o`00o`X0
okK10_l00?lG0?nf`CGooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0booooo`03
0000003o]/40okK100H0okK10P0000050?nf`@03o`0000000000okK100@0okK100?o00000000003o
]/400`3o]/400`000000okK10?nf`@020?nf`@03o`0000000000000000d0okK10`0000030?nf`@80
00000`3o]/42000000D0okK10P0000050?nf`@8000002Oooool00`00003oooooooooo`0Wooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo03Gooooo9@3o]/4:o`00oaL0okK1
=oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00<00000ooooo`3o]/40
1`3o]/42000000D0okK10P0000050?nf`@8000000`3o]/43000000@0okK11`0000030?nf`@<00000
103o]/42000000@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@03oooo
o`00003ooooo00Wooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0foooood@0okK1>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Cooooo00<00000ooooo`3o]/40203o]/400`000000okK10?nf`@040?nf`@8000001@3o
]/42000000@0okK10`0000080?nf`@<000001P3o]/400`000000okK10?nf`@030?nf`@03o`00003o
]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/400ooooooo0000ooooo`09ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0>?oooom0
0?nf`C[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0eooooo`03o`0000000000
000000P0okK100?o00000000003o]/401@3o]/400`00003o0000000000040?nf`@0300000?l00000
000000@0okK100@00000o`000000000000001`3o]/4500000003o`00003o]/40okK10080okK10P00
00050?nf`@800000103o]/400oooool0000000000009ooooo`800000;?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`0joooooc`0okK1??ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03Sooooo0P0000080?nf`@8000001`3o]/42000000D0okK10P000006
0?nf`@L000001`3o]/43000000@0okK10`0000040?nf`@;ooooo00<00000ooooooooool02?ooool0
0`00003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
03_ooooo>P3o]/4mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00`00
0000okK10?nf`@070?nf`@8000001`3o]/43000000@0okK11P00000:0?nf`@@000001P3o]/400`00
0000okK10?nf`@040?nf`@03ooooo`000000000000Wooooo0P00000_ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo03kooooo=@3o]/4oooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0>oooool200000003ooooo`3o]/40okK100H0okK100<00000o`000000
00001`3o]/43000000L0okK12P0000060?nf`@@000001@3o]/43000000Wooooo0P00000aooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo047ooooo;`3o]/52ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0?Oooool2000000;ooooo203o]/42000000P0okK1
1000000A0?nf`@8000001P3o]/400oooool000000000000;ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A?oooolY0?nf`DGooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0oooooo`0300000?oooooooooo00;ooooo1`3o
]/42000000X0okK10`0000070?nf`@L000001@3o]/42ooooo`8000003?ooool00`00003ooooooooo
o`0booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Oooooo8`3o]/58
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@?ooool00`00003oooooooooo`04
ooooo`H0okK10`00000:0?nf`@L000002@3o]/42ooooo`<000003Oooool00`00003oooooooooo`0c
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04[ooooo7@3o]/5;oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool00`00003o000000000006oooo
o`H0okK10`00000D0?nf`@03ooooo`0000000000008000003Oooool3000003Kooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0COoooolG0?nf`Dkooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`14ooooo`8000001oooool60?nf`@@000003@3o]/44000000ko
oooo0`00000iooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Kooooo
103o]/5Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0A_ooool3000000gooooo
00<0okK10000000000002`00000Aooooo`0300000?oooooooooo03[ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo04Wooooo0`00000Vooooo`80000000?o0000ooooooooool0>oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0C?ooool4000001oooooo0`000010ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@oooo
o`<000006?ooool4000004?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05?ooooo1000000Aooooo`<0
0000Aoooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Eoooool00`00003o00000000000900000003o`00
00000000000000800000B_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooooonfo`00017ooooo]_l0000:oooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0226757 0.0314986 0.000638513 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.25057 -0.0125 -6 -9 ]
[.25057 -0.0125 6 0 ]
[.47732 -0.0125 -6 -9 ]
[.47732 -0.0125 6 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.93084 -0.0125 -6 -9 ]
[.93084 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0315 -6 -4.5 ]
[-0.0125 .0315 0 4.5 ]
[-0.0125 .1592 -18 -4.5 ]
[-0.0125 .1592 0 4.5 ]
[-0.0125 .2869 -18 -4.5 ]
[-0.0125 .2869 0 4.5 ]
[-0.0125 .41461 -18 -4.5 ]
[-0.0125 .41461 0 4.5 ]
[-0.0125 .54231 -18 -4.5 ]
[-0.0125 .54231 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.25057 0 m
.25057 .61803 L
s
.47732 0 m
.47732 .61803 L
s
.70408 0 m
.70408 .61803 L
s
.93084 0 m
.93084 .61803 L
s
0 .1592 m
1 .1592 L
s
0 .2869 m
1 .2869 L
s
0 .41461 m
1 .41461 L
s
0 .54231 m
1 .54231 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.25057 0 m
.25057 .00625 L
s
[(10)] .25057 -0.0125 0 1 Mshowa
.47732 0 m
.47732 .00625 L
s
[(20)] .47732 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(30)] .70408 -0.0125 0 1 Mshowa
.93084 0 m
.93084 .00625 L
s
[(40)] .93084 -0.0125 0 1 Mshowa
.125 Mabswid
.06916 0 m
.06916 .00375 L
s
.11451 0 m
.11451 .00375 L
s
.15986 0 m
.15986 .00375 L
s
.20522 0 m
.20522 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38662 0 m
.38662 .00375 L
s
.43197 0 m
.43197 .00375 L
s
.52268 0 m
.52268 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.61338 0 m
.61338 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.74943 0 m
.74943 .00375 L
s
.79478 0 m
.79478 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.88549 0 m
.88549 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0315 m
.00625 .0315 L
s
[(0)] -0.0125 .0315 1 0 Mshowa
0 .1592 m
.00625 .1592 L
s
[(200)] -0.0125 .1592 1 0 Mshowa
0 .2869 m
.00625 .2869 L
s
[(400)] -0.0125 .2869 1 0 Mshowa
0 .41461 m
.00625 .41461 L
s
[(600)] -0.0125 .41461 1 0 Mshowa
0 .54231 m
.00625 .54231 L
s
[(800)] -0.0125 .54231 1 0 Mshowa
.125 Mabswid
0 .06342 m
.00375 .06342 L
s
0 .09535 m
.00375 .09535 L
s
0 .12728 m
.00375 .12728 L
s
0 .19113 m
.00375 .19113 L
s
0 .22305 m
.00375 .22305 L
s
0 .25498 m
.00375 .25498 L
s
0 .31883 m
.00375 .31883 L
s
0 .35076 m
.00375 .35076 L
s
0 .38268 m
.00375 .38268 L
s
0 .44653 m
.00375 .44653 L
s
0 .47846 m
.00375 .47846 L
s
0 .51038 m
.00375 .51038 L
s
0 .57423 m
.00375 .57423 L
s
0 .60616 m
.00375 .60616 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.25057 .61178 m
.25057 .61803 L
s
.47732 .61178 m
.47732 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.93084 .61178 m
.93084 .61803 L
s
.125 Mabswid
.06916 .61428 m
.06916 .61803 L
s
.11451 .61428 m
.11451 .61803 L
s
.15986 .61428 m
.15986 .61803 L
s
.20522 .61428 m
.20522 .61803 L
s
.29592 .61428 m
.29592 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.38662 .61428 m
.38662 .61803 L
s
.43197 .61428 m
.43197 .61803 L
s
.52268 .61428 m
.52268 .61803 L
s
.56803 .61428 m
.56803 .61803 L
s
.61338 .61428 m
.61338 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.74943 .61428 m
.74943 .61803 L
s
.79478 .61428 m
.79478 .61803 L
s
.84014 .61428 m
.84014 .61803 L
s
.88549 .61428 m
.88549 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0315 m
1 .0315 L
s
.99375 .1592 m
1 .1592 L
s
.99375 .2869 m
1 .2869 L
s
.99375 .41461 m
1 .41461 L
s
.99375 .54231 m
1 .54231 L
s
.125 Mabswid
.99625 .06342 m
1 .06342 L
s
.99625 .09535 m
1 .09535 L
s
.99625 .12728 m
1 .12728 L
s
.99625 .19113 m
1 .19113 L
s
.99625 .22305 m
1 .22305 L
s
.99625 .25498 m
1 .25498 L
s
.99625 .31883 m
1 .31883 L
s
.99625 .35076 m
1 .35076 L
s
.99625 .38268 m
1 .38268 L
s
.99625 .44653 m
1 .44653 L
s
.99625 .47846 m
1 .47846 L
s
.99625 .51038 m
1 .51038 L
s
.99625 .57423 m
1 .57423 L
s
.99625 .60616 m
1 .60616 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.04649 .37935 L
.06916 .37986 L
.09184 .38047 L
.11451 .38135 L
.13719 .38274 L
.15986 .38507 L
.18254 .38913 L
.20522 .39622 L
.22789 .40747 L
.25057 .42218 L
.27324 .43798 L
.29592 .4542 L
.31859 .47263 L
.34127 .49385 L
.36395 .51587 L
.38662 .53679 L
.4093 .55227 L
.43197 .56085 L
.45465 .56626 L
.47732 .57106 L
.5 .57571 L
.52268 .5799 L
.54535 .58316 L
.56803 .58532 L
.5907 .58667 L
.61338 .58761 L
.63605 .58839 L
.65873 .5891 L
.68141 .58982 L
.70408 .59058 L
.72676 .59141 L
.74943 .59237 L
.77211 .59348 L
.79478 .59479 L
.81746 .59627 L
.84014 .59785 L
.86281 .59938 L
.88549 .60069 L
.90816 .6017 L
.93084 .60243 L
.95351 .60294 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.04649 .37935 Mdot
.06916 .37986 Mdot
.09184 .38047 Mdot
.11451 .38135 Mdot
.13719 .38274 Mdot
.15986 .38507 Mdot
.18254 .38913 Mdot
.20522 .39622 Mdot
.22789 .40747 Mdot
.25057 .42218 Mdot
.27324 .43798 Mdot
.29592 .4542 Mdot
.31859 .47263 Mdot
.34127 .49385 Mdot
.36395 .51587 Mdot
.38662 .53679 Mdot
.4093 .55227 Mdot
.43197 .56085 Mdot
.45465 .56626 Mdot
.47732 .57106 Mdot
.5 .57571 Mdot
.52268 .5799 Mdot
.54535 .58316 Mdot
.56803 .58532 Mdot
.5907 .58667 Mdot
.61338 .58761 Mdot
.63605 .58839 Mdot
.65873 .5891 Mdot
.68141 .58982 Mdot
.70408 .59058 Mdot
.72676 .59141 Mdot
.74943 .59237 Mdot
.77211 .59348 Mdot
.79478 .59479 Mdot
.81746 .59627 Mdot
.84014 .59785 Mdot
.86281 .59938 Mdot
.88549 .60069 Mdot
.90816 .6017 Mdot
.93084 .60243 Mdot
.95351 .60294 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006_ooool2o`0003Kooooo0ol00004ooooo`;o0000<oooool5o`0000?ooooo0_l0000coooo
o`?o00001?ooool2o`0003Cooooo0ol00003ooooo`;o00004?ooool001Wooooo00Co0000oooooooo
oooo0000=_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0000aooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool0000dooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`0=ooooo`006Oooool01?l0003oooooooooool0000fooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000=?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0003Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`0_ooooo`Go
00000_ooool01?l0003oooooooooool0000?ooooo`006Oooool01?l0003oooooooooool0000foooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool0<Oooool2o`0000?ooooo00Co0000oooooooooooo0000
<Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000oooooo000Iooooo`04
o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000b
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000eooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`000003ooooo`04
o`000?ooooooooooo`0000oooooo000Iooooo`04o`000?ooooooooooo`0003Gooooo0_l00004oooo
o`04o`000?ooooooooooo`0003;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`00037ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
03?ooooo0_l00003ooooo`04o`000?ooooooooooo`0000oooooo000Jooooo`;o0000=oooool00ol0
003oooooooooo`03ooooo`;o0000=?ooool3o`0000Cooooo0_l0000cooooo`?o00001?ooool2o`00
03Gooooo00?o0000ooooooooool00_ooool2o`00013ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo000Eooooo`0300000?l0003o00000?oo00001ol000010000
007ooooo000Eooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool10000007o
oooo000Eooooo`0300000?oooooooooo00;ooooo0`3o000jooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00oooooo
0@000001ooooo`005Oooool01000003oooooooooooooool50?l003Wooooo00<0001oooooooooool0
>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0
3oooool10000007ooooo000Eooooo`0400000?ooooooooooooooo`D0o`00>Oooool00`0007oooooo
ooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001Gooooo00@00000oooooooooooooooo1@3o000iooooo`030000
Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000
Oooooooooooo00oooooo0@000001ooooo`003_ooool2o`0000Gooooo00<00000ooooooooool00_oo
ool30?l003[ooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000=ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool00oooool00`00003oooooooooo`0iooooo`030000Oooo
oooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo00oooooo0@000001ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?l0
003ooooo00?ooooo00<00000ooooooooool0>Oooool00`0007ooooooooooo`0jooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0>ooooo`7o00000@00
0001ooooo`003Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool0>Oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool000gooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo03Wooooo00<0
001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool03oooool10000007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool00oooool00`00003oooooooooo`0iooooo`030000Oooooooooooo03[ooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`003_ooool2o`0000Gooooo00<00000ooooooooool00oooool00`00003oooooooooo`0i
ooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0i
ooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`04oooo
o`0300000?oooooooooo03Sooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0ioooo
o`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`03
00000?oooooooooo00Cooooo00<00000ooooooooool0>?ooool00`0007ooooooooooo`0jooooo`03
0000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`40
00000Oooool001Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0hooooo`030000
Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000
Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo03Sooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?l0003o
oooo00Cooooo00<00000ooooooooool0>?ooool00`0007ooooooooooo`0jooooo`030000Oooooooo
oooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0>ooooo`7o00000@000001
ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo03Sooooo00<0001ooooo
ooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001ooooo
ooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool0>?ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`0hooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0
>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`04ooooo`0300000?oooooooooo03Sooooo00<0001oooooooooool0>_oo
ool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03ooo
ool10000007ooooo000Eooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0>?ooool0
0`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool0
0`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool01?ooool00`00
003oooooooooo`0hooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`00
07ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`04ooooo`0300000?oooooooooo03Sooooo00<0001oooooooooool0>_ooool00`0007oo
ooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007o
oooo000Eooooo`0300000?l0003ooooo00Cooooo00<00000ooooooooool0>?ooool00`0007oooooo
ooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0>ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`04ooooo`0300000?oo
oooooooo03Sooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooo
oooo00Cooooo00<00000ooooooooool0>?ooool00`0007ooooooooooo`0jooooo`030000Oooooooo
oooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool0
01Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0hooooo`030000Oooooooooooo
03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo03Oo
oooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wo
oooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Gooooo
00<00000ooooooooool0=oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo
00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<0
0000ooooooooool01Oooool00`00003oooooooooo`0gooooo`030000Oooooooooooo03[ooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo03Oooooo00<0001o
ooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Gooooo00<00000oooo
ooooool0=oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000o`000?oo
ool01Oooool00`00003oooooooooo`0gooooo`030000Oooooooooooo03[ooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00kooooo0Ol000010000007o
oooo000Eooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0=oooool00`0007oooooo
ooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool01Oooool00`00003ooooooooo
o`0gooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooooooo
o`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo03Oooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0i
ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eoooo
o`0300000?oooooooooo00Gooooo00<00000ooooooooool0=oooool00`0007ooooooooooo`0joooo
o`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?oooo
o`4000000Oooool001Gooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0gooooo`03
0000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`001Ol00003ooooo`;o00001?ooool2o`0000Gooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`0gooooo`030000Oooooooooooo03[ooooo
00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo
0@000001ooooo`0000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`05ooooo`0300000?oooooooooo
03Oooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
03Wooooo00<0001oooooooooool03oooool10000007ooooo0002ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?l00000
001o00D0001o00<000000000O`0007l0o@0007l1o`00004000000Oooool000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00`00003oooooooooo`05ooooo`0300000?oooooooooo03Oooooo00<0001oooooooooool0>_oo
ool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03ooo
ool10000007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Gooooo00<00000oooooooo
ool0=oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool00005o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool01_ooool00`00003oooooooooo`0fooooo`030000Oooooooooooo03[ooooo00<0001o
ooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001
ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooo
oooo00Kooooo00<00000ooooooooool0=_ooool00`0007ooooooooooo`0jooooo`030000Oooooooo
oooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool0
01Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0fooooo`030000Oooooooooooo
03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo03Ko
oooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wo
oooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool0=_ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo
00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`0fooooo`030000Oooooooooooo03[ooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`005Oooool00`00003o0000ooooo`06ooooo`0300000?oooooooooo03Kooooo00<0001o
ooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool03_ooool1o`00004000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00
003oooooooooo`0fooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`00
07ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003o
ooooooooo`06ooooo`0300000?oooooooooo03Kooooo00<0001oooooooooool0>_ooool00`0007oo
ooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007o
oooo000Eooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0=_ooool00`0007oooooo
ooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`0fooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooooooo
o`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo03Kooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0i
ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eoooo
o`0300000?oooooooooo00Kooooo00<00000ooooooooool0=_ooool00`0007ooooooooooo`0joooo
o`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?oooo
o`4000000Oooool001Gooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0fooooo`03
0000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`06ooooo`030000
0?oooooooooo03Kooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000
Oooooooooooo03Wooooo00<0001oooooooooool03_ooool1o`00004000000Oooool001Gooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`0fooooo`030000Oooooooooooo03[ooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo03Kooooo00<0001o
ooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool0=Oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`0eooooo`030000Oooooooooooo03[ooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`00
5Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo03Gooooo00<0001oooooooooool0
>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0
3oooool10000007ooooo000Eooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0=Ooo
ool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Ooo
ool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`0eooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool0
0`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00
003oooooooooo`07ooooo`0300000?oooooooooo03Gooooo00<0001oooooooooool0>_ooool00`00
07ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000
007ooooo000Eooooo`0300000?l0003ooooo00Oooooo00<00000ooooooooool0=Oooool00`0007oo
ooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oo
ooooooooo`0>ooooo`7o00000@000001ooooo`005Oooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo03Gooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000
Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool0=Oooool00`0007ooooooooooo`0jooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Ooo
ool001Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`0eooooo`030000Oooooooo
oooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooo
oooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo
03Gooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Oo
oooo00<00000ooooooooool0=Oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wo
oooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool000;ooooo
0ol00003ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`0eooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
00000?oooooooooo00Oooooo00<00000ooooooooool0=Oooool00`0007ooooooooooo`0jooooo`03
0000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`40
00000Oooool000Go00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00Cooooo00<00000o`00000007l01`0007l00`000000001o0000O`3k0000O`7o00000@000001oooo
o`0000Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool01oooool00`00003oooooooooo`0eooooo`030000Oooo
oooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo00oooooo0@000001ooooo`0000Coooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`0dooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oo
ooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`000_ooool2o`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
00Sooooo00<00000ooooooooool0=?ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo
03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool000?o
oooo00?o0000ooooooooool00_ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00So
oooo00<00000ooooooooool0=?ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wo
oooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo
00<00000ooooooooool02?ooool00`00003oooooooooo`0dooooo`030000Oooooooooooo03[ooooo
00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo
0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo03Cooooo00<0
001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool0=?ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`0dooooo`030000Oooooooooooo03[ooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001oooo
o`005Oooool00`00003o0000ooooo`08ooooo`0300000?oooooooooo03Cooooo00<0001ooooooooo
ool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool03_ooool1o`00004000000Oooool001Gooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`0dooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`08ooooo`0300000?oooooooooo03Cooooo00<0001oooooooooool0>_ooool00`0007oooooooooo
o`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000E
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0=?ooool00`0007ooooooooooo`0j
ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?
ooooo`4000000Oooool001Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0doooo
o`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0ioooo
o`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`08ooooo`03
00000?oooooooooo03Cooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`030000
0?oooooooooo00Sooooo00<00000ooooooooool0=?ooool00`0007ooooooooooo`0jooooo`030000
Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`400000
0Oooool001Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0dooooo`030000Oooo
oooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo00oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`08ooooo`0300000?oooooo
oooo03Cooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooo
oooo03Wooooo00<0001oooooooooool03_ooool1o`00004000000Oooool001Gooooo00<00000oooo
ooooool02Oooool00`00003oooooooooo`0cooooo`030000Oooooooooooo03[ooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001oooo
o`005Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo03?ooooo00<0001ooooooooo
ool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0
<oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0
>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool02Ooo
ool00`00003oooooooooo`0cooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Ooo
ool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool0
0`00003oooooooooo`09ooooo`0300000?oooooooooo03?ooooo00<0001oooooooooool0>_ooool0
0`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool1
0000007ooooo000Eooooo`0300000?oooooooooo00Sooooo0`3o0003ooooo`<0o`000oooool30?l0
02Sooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo00Oo
oooo1@3o00000oooool0o`000?l000030?l00003ooooo`3o0000o`0000<0o`000_ooool30?l000?o
oooo0`3o000Looooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oo
ooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`07ooooo`D0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000
003o0000o`0000<0o`0000<000000?l0003o00000`3o0002ooooo`<0o`005_ooool00`0007oooooo
ooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001Gooooo00<00000o`000?ooool01oooool50?l00003ooooo`3o
0000o`0000<0o`0000?ooooo0?l0003o00000`3o00000oooool0o`000?l000030?l00003ooooo`3o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`00003ooooo0?l000020?l0013ooooo00<0
001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool03_ooool1o`00004000000Oooool001Gooooo00<00000ooooooooool02?ooool3
0?l000?ooooo0`3o0003ooooo`<0o`000_ooool50?l00003ooooo`3o0000o`0000<0o`0000?ooooo
0?l0003o00000`3o00000oooool0o`000?l000030?l000;ooooo0`3o000:ooooo`030000Oooooooo
oooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooo
oooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0Jooooo`<0o`000oooool30?l0
00;ooooo1@3o00000oooool0o`000?l000030?l000030000003o0000o`0000<0o`002Oooool00`00
07ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`00
07ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool09_ooool30?l000;o
oooo1@3o00000oooool0o`000?l000030?l000Wooooo00<0001oooooooooool0>_ooool00`0007oo
ooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007o
oooo000Eooooo`0300000?oooooooooo02cooooo0`3o0002ooooo`D0o`0000<00000ooooo`3o0000
0P3o0004ooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003ooooooooo
o`0booooo`<0o`000_ooool50?l000?ooooo00<0001oooooooooool0>_ooool00`0007oooooooooo
o`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo0000
1?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0=ooo
ool50?l000?ooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo00001Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo03Oooooo1@3o0003ooooo`030000Oooooooooooo03[ooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`00
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003o00000000O`0h0000O`<0o`0000<0001o0000000000000`3o0034
0000O`7o00000@000001ooooo`001?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`0mooooo`D0o`00>_ooool00`0007oooooooooo
o`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo0000
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0mooooo`D0o`00>_ooool00`0007ooooooooooo`0iooooo`030000
Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo00000ooooooo0000oooo
o`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0mooooo`D0o`00>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wo
oooo00<0001oooooooooool03oooool10000007ooooo0002ooooo`;o00001?ooool2o`0000Cooooo
0_l00005ooooo`0300000?oooooooooo03kooooo0`3o00000oooool000000000000hooooo`030000
Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`400000
0Oooool001Gooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`02ooooo`<0o`00=Ooo
ool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03ooo
ool10000007ooooo000Eooooo`0300000?oooooooooo03oooooo00@0001ooooooooooooooooo1@3o
000dooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oooooooooo
o`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool0?oooool0100007oooooooooooooo
ool50?l003Cooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0oooooo`040000Oooooooo
ooooooooo`D0o`0000<00000ooooooooool0<Oooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?l0003o
oooo03oooooo00<0001oooooooooool00_ooool30?l000;ooooo00@000000?l0003o0000o`00;ooo
ool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03_oo
ool1o`00004000000Oooool001Gooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`07
ooooo`D0o`00;_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo03oooooo00<0001ooooo
ooooool01oooool50?l002kooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0ioooo
o`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0oooooo`03
0000Oooooooooooo00Oooooo1@3o000^ooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool0
?oooool00`0007ooooooooooo`08ooooo`<0o`0000?ooooo00000?ooool0;?ooool00`0007oooooo
ooooo`0iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo
000Eooooo`0300000?oooooooooo03oooooo00<0001oooooooooool03Oooool010000000o`000?l0
003o000Yooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool0?oooool00`0007oooooooooo
o`0=ooooo`D0o`00:?ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo03oooooo00<0001o
ooooooooool03Oooool50?l002Sooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0i
ooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003o0000ooooo`0ooooo
o`030000Oooooooooooo00gooooo1@3o000Xooooo`030000Oooooooooooo03Wooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0>ooooo`7o00000@000001ooooo`005Oooool00`00003o
ooooooooo`0oooooo`030000Oooooooooooo00kooooo0`3o00000oooool00000ooooo`0Vooooo`03
0000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`40
00000Oooool001Gooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`0Cooooo`040000
003o0000o`000?l002?ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0oooooo`030000
Oooooooooooo01?ooooo1@3o000Rooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0
>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool0?ooo
ool00`0007ooooooooooo`0Cooooo`D0o`008_ooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooo
oooo03oooooo00<0001oooooooooool04oooool50?l002;ooooo00<0001oooooooooool0>Oooool0
0`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00
003oooooooooo`0oooooo`030000Oooooooooooo01Cooooo0`3o00000`00003oooooooooo`0Poooo
o`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?oooo
o`4000000Oooool001Gooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`0Hooooo`03
00000?oooooooooo01oooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0oooooo`030000
Oooooooooooo01Wooooo00@000000?l0003o0000o`007Oooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`030000
0?l0003ooooo03oooooo00<0001oooooooooool06Oooool50?l001cooooo00<0001oooooooooool0
>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00kooooo0Ol000010000007ooooo
000Eooooo`0300000?oooooooooo03oooooo00<0001oooooooooool06Oooool50?l001cooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`0oooooo`030000Oooooooooooo01Wooooo1@3o000L
ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?
ooooo`4000000Oooool001Gooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`0Joooo
o`<0o`0000<00000ooooooooool06_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`0300000?oooooooooo03oo
oooo00<0001oooooooooool07_ooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo03Wo
oooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo
00<00000ooooooooool0?oooool00`0007ooooooooooo`0Oooooo`040000003o0000o`000?l001Oo
oooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oo
oooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`0000Cooooo0_l00005ooooo`03
00000?oooooooooo03oooooo00<0001oooooooooool07oooool50?l001Kooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`00
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`0oooooo`030000Oooooooooooo01oooooo1@3o000F
ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?
ooooo`4000000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l0H@0007l50?l000030000
000007l0001o09`0001o0Ol000010000007ooooo00001?oooooo0000o`000?l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0ooooo
o`030000Oooooooooooo023ooooo0`3o0002ooooo`040000003o0000o`000?l0017ooooo00<0001o
ooooooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001
ooooo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`0oooooo`030000Oooooooooooo02Gooooo
1@3o000@ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0?ooooo`4000000Oooool00005o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0?oooool00`00
07ooooooooooo`0Uooooo`D0o`0000<00000ooooo`3o00000P3o000;ooooo`030000Oooooooooooo
03Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool00004
ooooool0003o0000o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0ooooo
o`030000Oooooooooooo02Gooooo1@3o00000oooool0o`000?l000030?l000[ooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001oooo
o`005Oooool00`00003oooooooooo`0oooooo`030000Oooooooooooo02Kooooo0`3o0002ooooo`D0
o`0000<00000ooooo`3o00000P3o0005ooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<00000ooooooooool0
?oooool00`0007ooooooooooo`0[ooooo`D0o`0000?ooooo0?l0003o00000`3o0002ooooo`<0o`00
>oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Ooo
ool00`00003oooooooooo`0oooooo`030000Oooooooooooo02cooooo0`3o0002ooooo`D0o`0000<0
00000?l0003o00000`3o0002ooooo`<0o`00=Oooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0oooooo`030000Oooooooo
oooo037ooooo1@3o00000oooool0o`000?l000030?l000030000003o0000o`0000<0o`000_ooool3
0?l002oooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0?ooooo`4000000Oooool0
01Gooooo00<00000o`000?ooool0?oooool00`0007ooooooooooo`0booooo`<0o`000_ooool50?l0
0003ooooo`3o0000o`0000<0o`0000<000000?l0003o00000`3o0003ooooo`<0o`00:?ooool00`00
07ooooooooooo`0iooooo`030000Oooooooooooo00kooooo0Ol000010000007ooooo000Eooooo`03
00000?oooooooooo03oooooo00<0001oooooooooool0>?ooool30?l000;ooooo1@3o00000oooool0
o`000?l000030?l0008000001@3o0002ooooo`<0o`000oooool30?l000?ooooo0`3o000Fooooo`03
0000Oooooooooooo03Wooooo00<0001oooooooooool03oooool10000007ooooo000Eooooo`030000
0?oooooooooo03oooooo00<0001oooooooooool0>_ooool0100007ooooooooooooooool30?l000;o
oooo1@3o0002ooooo`D0o`0000<000000?l0003o00000`3o00000oooool0o`000?l000030?l00003
ooooo`3o0000o`0000<0o`000_ooool30?l000?ooooo0`3o0003ooooo`<0o`000oooool30?l000?o
oooo0`3o000dooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003ooooo
ooooo`0oooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool01oooool30?l000?ooooo
1@3o00000oooool0o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o0000
0`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0o`0000?ooooo0?l0003o0000
0`3o00000oooool0o`000?l000030?l00003ooooo`3o0000o`0000<0o`000_ooool30?l000?ooooo
0`3o0003ooooo`<0o`008_ooool00`0007ooooooooooo`0?ooooo`4000000Oooool001Gooooo00<0
0000ooooooooool0?oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo00kooooo0`3o
0002ooooo`D0o`0000?ooooo0?l0003o00000`3o00000oooool0o`000?l000030?l00003ooooo`3o
0000o`0000<0o`0000?ooooo0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000030000003o
0000o`0000<0o`0000?ooooo0?l0003o00000`3o0002ooooo`<0o`000oooool30?l000?ooooo0`3o
000@ooooo`030000Oooooooooooo00oooooo0@000001ooooo`005Oooool00`00003oooooooooo`0o
ooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool05?ooool30?l000?ooooo0`3o0003
ooooo`<0o`000_ooool50?l00003ooooo`3o0000o`0000<0o`0000?ooooo0?l0003o00000`3o0000
0oooool0o`000?l000030?l00003ooooo`3o0000o`0000<0o`0000?ooooo0?l0003o00000`3o0000
0oooool0o`000?l000030?l000030000003o0000o`0000<0o`0000<000000?l0003o00000`3o0000
0`000000o`000?l000030?l00003ooooo`3o0000o`0000<0o`000_ooool30?l000?ooooo0`3o0003
ooooo`<0o`000oooool30?l000?ooooo0`3o0004ooooo`4000000Oooool001Gooooo00<00000oooo
ooooool0?oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo02Kooooo0`3o0003oooo
o`<0o`000oooool30?l000?ooooo0`3o0003ooooo`<0o`000_ooool50?l00003ooooo`3o0000o`00
00<0o`0000?ooooo0?l0003o00000`3o00000oooool0o`000?l000030?l00003ooooo`3o0000o`00
00<0o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l00003ooooo`3o0000o`00
00<0o`0000?ooooo0?l0003o00000`3o00000oooool0o`000?l000030?l00003ooooo`3o0000o`00
00<0o`000oooool10000007ooooo000Eooooo`0300000?oooooooooo03oooooo00<0001ooooooooo
ool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo00Sooooo0`3o0003ooooo`<0
o`000oooool30?l000;ooooo1@3o00000oooool0o`000?l000030?l00003ooooo`3o0000o`0000<0
o`0000?ooooo0?l0003o00000`3o00000`000000o`000?l000030?l000030000003o0000o`0000<0
o`0000<000000?l0003o00000`3o00000`000000o`000?l000030?l000?ooooo0@000001ooooo`00
5Oooool00`00003o0000ooooo`0oooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0
>Oooool00`0007ooooooooooo`0Jooooo`<0o`000oooool30?l000?ooooo0`3o0002ooooo`D0o`00
00?ooooo0?l0003o00000`3o00000oooool0o`000?l000030?l00003ooooo`3o0000o`0000<0o`00
00?ooooo0?l0003o00000`3o0002ooooo`7o00000@000001ooooo`005Oooool00`00003ooooooooo
o`0oooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooooooo
o`0/ooooo`<0o`000oooool30?l000?ooooo0`3o0003ooooo`<0o`000oooool30?l000Cooooo0@00
0001ooooo`005Oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo0@000001
ooooo`005Ooooooo000000/000000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.59071, -123.457, \
0.166069, 5.89765}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(badInitialization1 = \ em;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation", "Subsection"],

Cell[BoxData[
    \(\(\(AnnularAllPlot[c1, rr1, rr2, #] &\)\  /@ \ 
        badInitialization1;\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EM experiment #3: bad initialization (full covariances)", "Section"],

Cell[CellGroupData[{

Cell["Number of Gaussians, assumes scalar covariances", "Subsection"],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 5;\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initBad = 
        ReplacePart[initFull, \ Table[ .5\ IdentityMatrix[2], {k}], 
          2];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[data1, initBad, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({0.03999999999999915`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection"],

Cell[CellGroupData[{

Cell["Initial model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // First];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.3 g
.01923 .68722 m
.02136 .69231 L
.02996 .71154 L
.03846 .72871 L
.03954 .73077 L
.05014 .75 L
.05769 .76261 L
.06185 .76923 L
.07476 .78846 L
.07692 .7915 L
.08899 .80769 L
.09615 .81672 L
.10466 .82692 L
.11538 .83907 L
.12196 .84615 L
.13462 .85908 L
.14112 .86538 L
.15385 .87711 L
.16245 .88462 L
.17308 .89343 L
.1864 .90385 L
.19231 .90825 L
.21154 .92172 L
.21359 .92308 L
.23077 .93396 L
.24503 .94231 L
.25 .94508 L
.26923 .95516 L
.28249 .96154 L
.28846 .96426 L
.30769 .97245 L
.32692 .97977 L
.32972 .98077 L
.01923 .98077 L
F
0 g
.01923 .68722 m
.02136 .69231 L
.02996 .71154 L
.03846 .72871 L
.03954 .73077 L
.05014 .75 L
.05769 .76261 L
.06185 .76923 L
.07476 .78846 L
.07692 .7915 L
.08899 .80769 L
.09615 .81672 L
.10466 .82692 L
.11538 .83907 L
.12196 .84615 L
.13462 .85908 L
.14112 .86538 L
.15385 .87711 L
.16245 .88462 L
.17308 .89343 L
.1864 .90385 L
.19231 .90825 L
.21154 .92172 L
.21359 .92308 L
.23077 .93396 L
.24503 .94231 L
.25 .94508 L
.26923 .95516 L
.28249 .96154 L
.28846 .96426 L
.30769 .97245 L
.32692 .97977 L
.32972 .98077 L
s
.3 g
.01923 .29205 m
.0207 .28846 L
.0291 .26923 L
.03843 .25 L
.03846 .24994 L
.04873 .23077 L
.05769 .21541 L
.06006 .21154 L
.07251 .19231 L
.07692 .1859 L
.08616 .17308 L
.09615 .16005 L
.10113 .15385 L
.11538 .13706 L
.11756 .13462 L
.13462 .11641 L
.13563 .11538 L
.15385 .09774 L
.15556 .09615 L
.17308 .08076 L
.17769 .07692 L
.19231 .06529 L
.20244 .05769 L
.21154 .05117 L
.23045 .03846 L
.23077 .03826 L
.25 .02647 L
.26274 .01923 L
.01923 .01923 L
F
0 g
.01923 .29205 m
.0207 .28846 L
.0291 .26923 L
.03843 .25 L
.03846 .24994 L
.04873 .23077 L
.05769 .21541 L
.06006 .21154 L
.07251 .19231 L
.07692 .1859 L
.08616 .17308 L
.09615 .16005 L
.10113 .15385 L
.11538 .13706 L
.11756 .13462 L
.13462 .11641 L
.13563 .11538 L
.15385 .09774 L
.15556 .09615 L
.17308 .08076 L
.17769 .07692 L
.19231 .06529 L
.20244 .05769 L
.21154 .05117 L
.23045 .03846 L
.23077 .03826 L
.25 .02647 L
.26274 .01923 L
s
.2 g
.01923 .78803 m
.0195 .78846 L
.03204 .80769 L
.03846 .81691 L
.04576 .82692 L
.05769 .84237 L
.06075 .84615 L
.07692 .86512 L
.07716 .86538 L
.09515 .88462 L
.09615 .88563 L
.11495 .90385 L
.11538 .90425 L
.13462 .92121 L
.13685 .92308 L
.15385 .9367 L
.16124 .94231 L
.17308 .95089 L
.18871 .96154 L
.19231 .96388 L
.21154 .97578 L
.22013 .98077 L
.01923 .98077 L
F
0 g
.01923 .78803 m
.0195 .78846 L
.03204 .80769 L
.03846 .81691 L
.04576 .82692 L
.05769 .84237 L
.06075 .84615 L
.07692 .86512 L
.07716 .86538 L
.09515 .88462 L
.09615 .88563 L
.11495 .90385 L
.11538 .90425 L
.13462 .92121 L
.13685 .92308 L
.15385 .9367 L
.16124 .94231 L
.17308 .95089 L
.18871 .96154 L
.19231 .96388 L
.21154 .97578 L
.22013 .98077 L
s
.2 g
.01923 .19124 m
.03078 .17308 L
.03846 .16176 L
.04406 .15385 L
.05769 .13567 L
.05852 .13462 L
.07427 .11538 L
.07692 .1123 L
.09144 .09615 L
.09615 .09115 L
.1102 .07692 L
.11538 .07191 L
.13078 .05769 L
.13462 .05431 L
.15348 .03846 L
.15385 .03816 L
.17308 .02333 L
.17868 .01923 L
.01923 .01923 L
F
0 g
.01923 .19124 m
.03078 .17308 L
.03846 .16176 L
.04406 .15385 L
.05769 .13567 L
.05852 .13462 L
.07427 .11538 L
.07692 .1123 L
.09144 .09615 L
.09615 .09115 L
.1102 .07692 L
.11538 .07191 L
.13078 .05769 L
.13462 .05431 L
.15348 .03846 L
.15385 .03816 L
.17308 .02333 L
.17868 .01923 L
s
.1 g
.01923 .86624 m
.03429 .88462 L
.03846 .88945 L
.05142 .90385 L
.05769 .9105 L
.0701 .92308 L
.07692 .9297 L
.09054 .94231 L
.09615 .94729 L
.11303 .96154 L
.11538 .96345 L
.13462 .97832 L
.13793 .98077 L
.01923 .98077 L
F
0 g
.01923 .86624 m
.03429 .88462 L
.03846 .88945 L
.05142 .90385 L
.05769 .9105 L
.0701 .92308 L
.07692 .9297 L
.09054 .94231 L
.09615 .94729 L
.11303 .96154 L
.11538 .96345 L
.13462 .97832 L
.13793 .98077 L
s
.1 g
.01923 .11305 m
.03268 .09615 L
.03846 .08923 L
.04917 .07692 L
.05769 .06757 L
.06706 .05769 L
.07692 .04774 L
.08652 .03846 L
.09615 .02952 L
.10775 .01923 L
.01923 .01923 L
F
0 g
.01923 .11305 m
.03268 .09615 L
.03846 .08923 L
.04917 .07692 L
.05769 .06757 L
.06706 .05769 L
.07692 .04774 L
.08652 .03846 L
.09615 .02952 L
.10775 .01923 L
s
.01923 .93431 m
.02682 .94231 L
.03846 .95408 L
.04615 .96154 L
.05769 .97228 L
.06723 .98077 L
.01923 .98077 L
F
.01923 .93431 m
.02682 .94231 L
.03846 .95408 L
.04615 .96154 L
.05769 .97228 L
.06723 .98077 L
s
.01923 .04501 m
.02523 .03846 L
.03846 .02462 L
.04382 .01923 L
.01923 .01923 L
F
.01923 .04501 m
.02523 .03846 L
.03846 .02462 L
.04382 .01923 L
s
.5 g
.98077 .64876 m
.9787 .65385 L
.97028 .67308 L
.96154 .69097 L
.96085 .69231 L
.95034 .71154 L
.94231 .72501 L
.93869 .73077 L
.92579 .75 L
.92308 .75381 L
.91153 .76923 L
.90385 .77885 L
.89577 .78846 L
.88462 .80097 L
.8783 .80769 L
.86538 .82072 L
.85889 .82692 L
.84615 .83847 L
.83718 .84615 L
.82692 .85451 L
.81269 .86538 L
.80769 .86902 L
.78846 .88218 L
.78469 .88462 L
.76923 .89411 L
.75196 .90385 L
.75 .90489 L
.73077 .91463 L
.71222 .92308 L
.71154 .92337 L
.69231 .93118 L
.67308 .9381 L
.66003 .94231 L
.65385 .94416 L
.63462 .94941 L
.61538 .95385 L
.59615 .95752 L
.57692 .96042 L
.56811 .96154 L
.55769 .96258 L
.53846 .96399 L
.51923 .96466 L
.5 .9646 L
.48077 .9638 L
.46154 .96225 L
.45462 .96154 L
.44231 .95995 L
.42308 .95689 L
.40385 .95303 L
.38462 .94838 L
.36538 .94289 L
.36351 .94231 L
.34615 .93653 L
.32692 .92928 L
.31219 .92308 L
.30769 .92107 L
.28846 .91185 L
.27333 .90385 L
.26923 .90156 L
.25 .8901 L
.24147 .88462 L
.23077 .87737 L
.21433 .86538 L
.21154 .86324 L
.19231 .84754 L
.1907 .84615 L
.17308 .83005 L
.16985 .82692 L
.15385 .81048 L
.15128 .80769 L
.13466 .78846 L
.13462 .7884 L
.11973 .76923 L
.11538 .76322 L
.10631 .75 L
.09615 .73397 L
.09424 .73077 L
.0834 .71154 L
.07692 .69892 L
.07372 .69231 L
.0651 .67308 L
.05769 .65441 L
.05748 .65385 L
.05082 .63462 L
.04507 .61538 L
.0402 .59615 L
.03846 .5884 L
.03617 .57692 L
.03297 .55769 L
.03058 .53846 L
.02898 .51923 L
.02816 .5 L
.02812 .48077 L
.02887 .46154 L
.03039 .44231 L
.03269 .42308 L
.03579 .40385 L
.03846 .39023 L
.0397 .38462 L
.04443 .36538 L
.05002 .34615 L
.05648 .32692 L
.05769 .32359 L
.06386 .30769 L
.0722 .28846 L
.07692 .27846 L
.08154 .26923 L
.09196 .25 L
.09615 .24278 L
.10352 .23077 L
.11538 .21289 L
.11633 .21154 L
.1305 .19231 L
.13462 .18707 L
.14618 .17308 L
.15385 .16435 L
.16356 .15385 L
.17308 .14412 L
.1829 .13462 L
.19231 .12598 L
.20454 .11538 L
.21154 .10962 L
.22896 .09615 L
.23077 .09483 L
.25 .08143 L
.25692 .07692 L
.26923 .06929 L
.28846 .05832 L
.28962 .05769 L
.30769 .04842 L
.32692 .03952 L
.32936 .03846 L
.34615 .03157 L
.36538 .02452 L
.38163 .01923 L
.98077 .01923 L
F
0 g
.98077 .64876 m
.9787 .65385 L
.97028 .67308 L
.96154 .69097 L
.96085 .69231 L
.95034 .71154 L
.94231 .72501 L
.93869 .73077 L
.92579 .75 L
.92308 .75381 L
.91153 .76923 L
.90385 .77885 L
.89577 .78846 L
.88462 .80097 L
.8783 .80769 L
.86538 .82072 L
.85889 .82692 L
.84615 .83847 L
.83718 .84615 L
.82692 .85451 L
.81269 .86538 L
.80769 .86902 L
.78846 .88218 L
.78469 .88462 L
.76923 .89411 L
.75196 .90385 L
.75 .90489 L
.73077 .91463 L
.71222 .92308 L
.71154 .92337 L
.69231 .93118 L
.67308 .9381 L
.66003 .94231 L
.65385 .94416 L
.63462 .94941 L
.61538 .95385 L
.59615 .95752 L
.57692 .96042 L
.56811 .96154 L
.55769 .96258 L
.53846 .96399 L
.51923 .96466 L
.5 .9646 L
.48077 .9638 L
.46154 .96225 L
.45462 .96154 L
.44231 .95995 L
.42308 .95689 L
.40385 .95303 L
.38462 .94838 L
Mistroke
.36538 .94289 L
.36351 .94231 L
.34615 .93653 L
.32692 .92928 L
.31219 .92308 L
.30769 .92107 L
.28846 .91185 L
.27333 .90385 L
.26923 .90156 L
.25 .8901 L
.24147 .88462 L
.23077 .87737 L
.21433 .86538 L
.21154 .86324 L
.19231 .84754 L
.1907 .84615 L
.17308 .83005 L
.16985 .82692 L
.15385 .81048 L
.15128 .80769 L
.13466 .78846 L
.13462 .7884 L
.11973 .76923 L
.11538 .76322 L
.10631 .75 L
.09615 .73397 L
.09424 .73077 L
.0834 .71154 L
.07692 .69892 L
.07372 .69231 L
.0651 .67308 L
.05769 .65441 L
.05748 .65385 L
.05082 .63462 L
.04507 .61538 L
.0402 .59615 L
.03846 .5884 L
.03617 .57692 L
.03297 .55769 L
.03058 .53846 L
.02898 .51923 L
.02816 .5 L
.02812 .48077 L
.02887 .46154 L
.03039 .44231 L
.03269 .42308 L
.03579 .40385 L
.03846 .39023 L
.0397 .38462 L
.04443 .36538 L
Mistroke
.05002 .34615 L
.05648 .32692 L
.05769 .32359 L
.06386 .30769 L
.0722 .28846 L
.07692 .27846 L
.08154 .26923 L
.09196 .25 L
.09615 .24278 L
.10352 .23077 L
.11538 .21289 L
.11633 .21154 L
.1305 .19231 L
.13462 .18707 L
.14618 .17308 L
.15385 .16435 L
.16356 .15385 L
.17308 .14412 L
.1829 .13462 L
.19231 .12598 L
.20454 .11538 L
.21154 .10962 L
.22896 .09615 L
.23077 .09483 L
.25 .08143 L
.25692 .07692 L
.26923 .06929 L
.28846 .05832 L
.28962 .05769 L
.30769 .04842 L
.32692 .03952 L
.32936 .03846 L
.34615 .03157 L
.36538 .02452 L
.38163 .01923 L
Mfstroke
.6 g
.44231 .05451 m
.46154 .05118 L
.48077 .04868 L
.5 .04702 L
.51923 .04617 L
.53846 .04614 L
.55769 .04692 L
.57692 .04853 L
.59615 .05098 L
.61538 .05427 L
.63147 .05769 L
.63462 .05844 L
.65385 .06351 L
.67308 .06952 L
.69231 .07651 L
.69335 .07692 L
.71154 .08454 L
.73077 .09368 L
.7356 .09615 L
.75 .10401 L
.76885 .11538 L
.76923 .11563 L
.78846 .12868 L
.79651 .13462 L
.80769 .14334 L
.8202 .15385 L
.82692 .15984 L
.84082 .17308 L
.84615 .17849 L
.85896 .19231 L
.86538 .19973 L
.87501 .21154 L
.88462 .22425 L
.88926 .23077 L
.90191 .25 L
.90385 .25315 L
.91314 .26923 L
.92305 .28846 L
.92308 .28851 L
.93176 .30769 L
.93934 .32692 L
.94231 .3353 L
.94585 .34615 L
.95135 .36538 L
.95588 .38462 L
.95947 .40385 L
.96154 .41791 L
.96214 .42308 L
.96393 .44231 L
.96483 .46154 L
.96486 .48077 L
.96401 .5 L
.9623 .51923 L
.96154 .52584 L
.9597 .53846 L
.95622 .55769 L
.95182 .57692 L
.94648 .59615 L
.94231 .60922 L
.94017 .61538 L
.93285 .63462 L
.92447 .65385 L
.92308 .65682 L
.91496 .67308 L
.90425 .69231 L
.90385 .69299 L
.89223 .71154 L
.88462 .7227 L
.87879 .73077 L
.86538 .74802 L
.86376 .75 L
.84693 .76923 L
.84615 .77006 L
.82802 .78846 L
.82692 .78951 L
.80769 .8068 L
.80664 .80769 L
.78846 .82225 L
.78221 .82692 L
.76923 .83609 L
.75381 .84615 L
.75 .8485 L
.73077 .85961 L
.71984 .86538 L
.71154 .86952 L
.69231 .87833 L
.67693 .88462 L
.67308 .88609 L
.65385 .89286 L
.63462 .8987 L
.61538 .90362 L
.61444 .90385 L
.59615 .90767 L
.57692 .91087 L
.55769 .91323 L
.53846 .91475 L
.51923 .91546 L
.5 .91535 L
.48077 .91441 L
.46154 .91264 L
.44231 .91003 L
.42308 .90656 L
.41062 .90385 L
.40385 .9022 L
.38462 .89692 L
.36538 .89069 L
.34904 .88462 L
.34615 .88346 L
.32692 .87517 L
.30769 .86575 L
.307 .86538 L
.28846 .8551 L
.27389 .84615 L
.26923 .84312 L
.25 .82966 L
.24635 .82692 L
.23077 .81454 L
.22276 .80769 L
.21154 .7975 L
.20223 .78846 L
.19231 .7782 L
.18416 .76923 L
.17308 .75616 L
.16816 .75 L
.15396 .73077 L
.15385 .73061 L
.14134 .71154 L
.13462 .70028 L
.13014 .69231 L
.12024 .67308 L
.11538 .66267 L
.11154 .65385 L
.10396 .63462 L
.09744 .61538 L
.09615 .61121 L
.09193 .59615 L
.08738 .57692 L
.08376 .55769 L
.08105 .53846 L
.07923 .51923 L
.07828 .5 L
.07821 .48077 L
.07899 .46154 L
.08065 .44231 L
.08318 .42308 L
.08661 .40385 L
.09094 .38462 L
.09615 .36555 L
.0962 .36538 L
.10243 .34615 L
.10968 .32692 L
.11538 .31343 L
.11798 .30769 L
.12741 .28846 L
.13462 .27518 L
.13804 .26923 L
.14997 .25 L
.15385 .2442 L
.16334 .23077 L
.17308 .218 L
.17829 .21154 L
.19231 .1953 L
.19504 .19231 L
.21154 .17534 L
.21388 .17308 L
.23077 .15764 L
.23519 .15385 L
.25 .14184 L
.25956 .13462 L
.26923 .12771 L
.28792 .11538 L
.28846 .11504 L
.30769 .10371 L
.32185 .09615 L
.32692 .0936 L
.34615 .08462 L
.36477 .07692 L
.36538 .07669 L
.38462 .06975 L
.40385 .06377 L
.42308 .0587 L
.42732 .05769 L
F
0 g
.44231 .05451 m
.46154 .05118 L
.48077 .04868 L
.5 .04702 L
.51923 .04617 L
.53846 .04614 L
.55769 .04692 L
.57692 .04853 L
.59615 .05098 L
.61538 .05427 L
.63147 .05769 L
.63462 .05844 L
.65385 .06351 L
.67308 .06952 L
.69231 .07651 L
.69335 .07692 L
.71154 .08454 L
.73077 .09368 L
.7356 .09615 L
.75 .10401 L
.76885 .11538 L
.76923 .11563 L
.78846 .12868 L
.79651 .13462 L
.80769 .14334 L
.8202 .15385 L
.82692 .15984 L
.84082 .17308 L
.84615 .17849 L
.85896 .19231 L
.86538 .19973 L
.87501 .21154 L
.88462 .22425 L
.88926 .23077 L
.90191 .25 L
.90385 .25315 L
.91314 .26923 L
.92305 .28846 L
.92308 .28851 L
.93176 .30769 L
.93934 .32692 L
.94231 .3353 L
.94585 .34615 L
.95135 .36538 L
.95588 .38462 L
.95947 .40385 L
.96154 .41791 L
.96214 .42308 L
.96393 .44231 L
.96483 .46154 L
Mistroke
.96486 .48077 L
.96401 .5 L
.9623 .51923 L
.96154 .52584 L
.9597 .53846 L
.95622 .55769 L
.95182 .57692 L
.94648 .59615 L
.94231 .60922 L
.94017 .61538 L
.93285 .63462 L
.92447 .65385 L
.92308 .65682 L
.91496 .67308 L
.90425 .69231 L
.90385 .69299 L
.89223 .71154 L
.88462 .7227 L
.87879 .73077 L
.86538 .74802 L
.86376 .75 L
.84693 .76923 L
.84615 .77006 L
.82802 .78846 L
.82692 .78951 L
.80769 .8068 L
.80664 .80769 L
.78846 .82225 L
.78221 .82692 L
.76923 .83609 L
.75381 .84615 L
.75 .8485 L
.73077 .85961 L
.71984 .86538 L
.71154 .86952 L
.69231 .87833 L
.67693 .88462 L
.67308 .88609 L
.65385 .89286 L
.63462 .8987 L
.61538 .90362 L
.61444 .90385 L
.59615 .90767 L
.57692 .91087 L
.55769 .91323 L
.53846 .91475 L
.51923 .91546 L
.5 .91535 L
.48077 .91441 L
.46154 .91264 L
Mistroke
.44231 .91003 L
.42308 .90656 L
.41062 .90385 L
.40385 .9022 L
.38462 .89692 L
.36538 .89069 L
.34904 .88462 L
.34615 .88346 L
.32692 .87517 L
.30769 .86575 L
.307 .86538 L
.28846 .8551 L
.27389 .84615 L
.26923 .84312 L
.25 .82966 L
.24635 .82692 L
.23077 .81454 L
.22276 .80769 L
.21154 .7975 L
.20223 .78846 L
.19231 .7782 L
.18416 .76923 L
.17308 .75616 L
.16816 .75 L
.15396 .73077 L
.15385 .73061 L
.14134 .71154 L
.13462 .70028 L
.13014 .69231 L
.12024 .67308 L
.11538 .66267 L
.11154 .65385 L
.10396 .63462 L
.09744 .61538 L
.09615 .61121 L
.09193 .59615 L
.08738 .57692 L
.08376 .55769 L
.08105 .53846 L
.07923 .51923 L
.07828 .5 L
.07821 .48077 L
.07899 .46154 L
.08065 .44231 L
.08318 .42308 L
.08661 .40385 L
.09094 .38462 L
.09615 .36555 L
.0962 .36538 L
.10243 .34615 L
Mistroke
.10968 .32692 L
.11538 .31343 L
.11798 .30769 L
.12741 .28846 L
.13462 .27518 L
.13804 .26923 L
.14997 .25 L
.15385 .2442 L
.16334 .23077 L
.17308 .218 L
.17829 .21154 L
.19231 .1953 L
.19504 .19231 L
.21154 .17534 L
.21388 .17308 L
.23077 .15764 L
.23519 .15385 L
.25 .14184 L
.25956 .13462 L
.26923 .12771 L
.28792 .11538 L
.28846 .11504 L
.30769 .10371 L
.32185 .09615 L
.32692 .0936 L
.34615 .08462 L
.36477 .07692 L
.36538 .07669 L
.38462 .06975 L
.40385 .06377 L
.42308 .0587 L
.42732 .05769 L
.44231 .05451 L
Mfstroke
.7 g
.42308 .11305 m
.44231 .1083 L
.46154 .10454 L
.48077 .10174 L
.5 .09989 L
.51923 .09897 L
.53846 .09899 L
.55769 .09993 L
.57692 .10181 L
.59615 .10465 L
.61538 .10848 L
.63462 .11332 L
.64179 .11538 L
.65385 .11922 L
.67308 .12623 L
.69231 .13444 L
.69269 .13462 L
.71154 .14393 L
.72917 .15385 L
.73077 .15481 L
.75 .16725 L
.75821 .17308 L
.76923 .18143 L
.78241 .19231 L
.78846 .19765 L
.80304 .21154 L
.80769 .21629 L
.82089 .23077 L
.82692 .23793 L
.83642 .25 L
.84615 .26352 L
.85 .26923 L
.86185 .28846 L
.86538 .29475 L
.87216 .30769 L
.88107 .32692 L
.88462 .33546 L
.88869 .34615 L
.8951 .36538 L
.90037 .38462 L
.90385 .40023 L
.90454 .40385 L
.90765 .42308 L
.90974 .44231 L
.91083 .46154 L
.91092 .48077 L
.91002 .5 L
.90812 .51923 L
.90522 .53846 L
.90385 .54592 L
.9013 .55769 L
.89632 .57692 L
.89025 .59615 L
.88462 .61145 L
.88304 .61538 L
.87462 .63462 L
.86538 .65296 L
.86491 .65385 L
.8538 .67308 L
.84615 .685 L
.84116 .69231 L
.82692 .71138 L
.8268 .71154 L
.81048 .73077 L
.80769 .73381 L
.79186 .75 L
.78846 .75325 L
.77046 .76923 L
.76923 .77025 L
.75 .78523 L
.74551 .78846 L
.73077 .79844 L
.71572 .80769 L
.71154 .81011 L
.69231 .82037 L
.67853 .82692 L
.67308 .82934 L
.65385 .83713 L
.63462 .84379 L
.62696 .84615 L
.61538 .84939 L
.59615 .85397 L
.57692 .85756 L
.55769 .86019 L
.53846 .86188 L
.51923 .86263 L
.5 .86244 L
.48077 .86132 L
.46154 .85925 L
.44231 .85621 L
.42308 .85218 L
.40385 .84712 L
.40058 .84615 L
.38462 .84097 L
.36538 .83369 L
.34984 .82692 L
.34615 .82519 L
.32692 .81538 L
.3135 .80769 L
.30769 .80413 L
.28846 .79128 L
.28456 .78846 L
.26923 .77661 L
.26045 .76923 L
.25 .75982 L
.23989 .75 L
.23077 .74048 L
.2221 .73077 L
.21154 .71795 L
.20661 .71154 L
.19307 .69231 L
.19231 .69115 L
.18124 .67308 L
.17308 .65807 L
.17094 .65385 L
.16203 .63462 L
.15441 .61538 L
.15385 .61382 L
.148 .59615 L
.14272 .57692 L
.13852 .55769 L
.13538 .53846 L
.13462 .53334 L
.13325 .51923 L
.13213 .5 L
.13199 .48077 L
.13285 .46154 L
.13462 .44271 L
.13469 .44231 L
.13753 .42308 L
.14139 .40385 L
.14631 .38462 L
.15231 .36538 L
.15385 .36096 L
.15945 .34615 L
.1678 .32692 L
.17308 .31607 L
.17744 .30769 L
.18848 .28846 L
.19231 .28233 L
.20105 .26923 L
.21154 .25487 L
.21533 .25 L
.23077 .23167 L
.23158 .23077 L
.25 .21167 L
.25013 .21154 L
.26923 .1942 L
.27147 .19231 L
.28846 .17884 L
.29636 .17308 L
.30769 .16531 L
.3261 .15385 L
.32692 .15337 L
.34615 .14286 L
.36327 .13462 L
.36538 .13367 L
.38462 .12568 L
.40385 .11883 L
.41485 .11538 L
F
0 g
.42308 .11305 m
.44231 .1083 L
.46154 .10454 L
.48077 .10174 L
.5 .09989 L
.51923 .09897 L
.53846 .09899 L
.55769 .09993 L
.57692 .10181 L
.59615 .10465 L
.61538 .10848 L
.63462 .11332 L
.64179 .11538 L
.65385 .11922 L
.67308 .12623 L
.69231 .13444 L
.69269 .13462 L
.71154 .14393 L
.72917 .15385 L
.73077 .15481 L
.75 .16725 L
.75821 .17308 L
.76923 .18143 L
.78241 .19231 L
.78846 .19765 L
.80304 .21154 L
.80769 .21629 L
.82089 .23077 L
.82692 .23793 L
.83642 .25 L
.84615 .26352 L
.85 .26923 L
.86185 .28846 L
.86538 .29475 L
.87216 .30769 L
.88107 .32692 L
.88462 .33546 L
.88869 .34615 L
.8951 .36538 L
.90037 .38462 L
.90385 .40023 L
.90454 .40385 L
.90765 .42308 L
.90974 .44231 L
.91083 .46154 L
.91092 .48077 L
.91002 .5 L
.90812 .51923 L
.90522 .53846 L
.90385 .54592 L
Mistroke
.9013 .55769 L
.89632 .57692 L
.89025 .59615 L
.88462 .61145 L
.88304 .61538 L
.87462 .63462 L
.86538 .65296 L
.86491 .65385 L
.8538 .67308 L
.84615 .685 L
.84116 .69231 L
.82692 .71138 L
.8268 .71154 L
.81048 .73077 L
.80769 .73381 L
.79186 .75 L
.78846 .75325 L
.77046 .76923 L
.76923 .77025 L
.75 .78523 L
.74551 .78846 L
.73077 .79844 L
.71572 .80769 L
.71154 .81011 L
.69231 .82037 L
.67853 .82692 L
.67308 .82934 L
.65385 .83713 L
.63462 .84379 L
.62696 .84615 L
.61538 .84939 L
.59615 .85397 L
.57692 .85756 L
.55769 .86019 L
.53846 .86188 L
.51923 .86263 L
.5 .86244 L
.48077 .86132 L
.46154 .85925 L
.44231 .85621 L
.42308 .85218 L
.40385 .84712 L
.40058 .84615 L
.38462 .84097 L
.36538 .83369 L
.34984 .82692 L
.34615 .82519 L
.32692 .81538 L
.3135 .80769 L
.30769 .80413 L
Mistroke
.28846 .79128 L
.28456 .78846 L
.26923 .77661 L
.26045 .76923 L
.25 .75982 L
.23989 .75 L
.23077 .74048 L
.2221 .73077 L
.21154 .71795 L
.20661 .71154 L
.19307 .69231 L
.19231 .69115 L
.18124 .67308 L
.17308 .65807 L
.17094 .65385 L
.16203 .63462 L
.15441 .61538 L
.15385 .61382 L
.148 .59615 L
.14272 .57692 L
.13852 .55769 L
.13538 .53846 L
.13462 .53334 L
.13325 .51923 L
.13213 .5 L
.13199 .48077 L
.13285 .46154 L
.13462 .44271 L
.13469 .44231 L
.13753 .42308 L
.14139 .40385 L
.14631 .38462 L
.15231 .36538 L
.15385 .36096 L
.15945 .34615 L
.1678 .32692 L
.17308 .31607 L
.17744 .30769 L
.18848 .28846 L
.19231 .28233 L
.20105 .26923 L
.21154 .25487 L
.21533 .25 L
.23077 .23167 L
.23158 .23077 L
.25 .21167 L
.25013 .21154 L
.26923 .1942 L
.27147 .19231 L
.28846 .17884 L
Mistroke
.29636 .17308 L
.30769 .16531 L
.3261 .15385 L
.32692 .15337 L
.34615 .14286 L
.36327 .13462 L
.36538 .13367 L
.38462 .12568 L
.40385 .11883 L
.41485 .11538 L
.42308 .11305 L
Mfstroke
.8 g
.44231 .16826 m
.46154 .16385 L
.48077 .1606 L
.5 .15848 L
.51923 .15746 L
.53846 .15753 L
.55769 .15871 L
.57692 .16101 L
.59615 .16445 L
.61538 .16908 L
.62895 .17308 L
.63462 .17496 L
.65385 .18216 L
.67308 .19079 L
.67615 .19231 L
.69231 .20099 L
.70943 .21154 L
.71154 .21295 L
.73077 .22692 L
.73557 .23077 L
.75 .24329 L
.75706 .25 L
.76923 .26261 L
.7751 .26923 L
.78846 .28581 L
.79043 .28846 L
.8035 .30769 L
.80769 .31457 L
.81462 .32692 L
.82402 .34615 L
.82692 .35284 L
.83186 .36538 L
.83826 .38462 L
.84332 .40385 L
.84615 .41745 L
.8471 .42308 L
.84965 .44231 L
.85101 .46154 L
.85119 .48077 L
.8502 .5 L
.84804 .51923 L
.84615 .53118 L
.84468 .53846 L
.8401 .55769 L
.83423 .57692 L
.82703 .59615 L
.82692 .59641 L
.81839 .61538 L
.8082 .63462 L
.80769 .63549 L
.79628 .65385 L
.78846 .66506 L
.78243 .67308 L
.76923 .68904 L
.76632 .69231 L
.75 .70915 L
.74749 .71154 L
.73077 .7263 L
.72524 .73077 L
.71154 .74105 L
.69833 .75 L
.69231 .75379 L
.67308 .76476 L
.66432 .76923 L
.65385 .77416 L
.63462 .78212 L
.61633 .78846 L
.61538 .78876 L
.59615 .79414 L
.57692 .79834 L
.55769 .80138 L
.53846 .8033 L
.51923 .80412 L
.5 .80383 L
.48077 .80244 L
.46154 .79991 L
.44231 .79623 L
.42308 .79134 L
.41353 .78846 L
.40385 .78518 L
.38462 .77767 L
.36644 .76923 L
.36538 .7687 L
.34615 .75811 L
.33325 .75 L
.32692 .7457 L
.30769 .73119 L
.30718 .73077 L
.28846 .71417 L
.28575 .71154 L
.26923 .69402 L
.26775 .69231 L
.25245 .67308 L
.25 .66969 L
.23941 .65385 L
.23077 .63918 L
.2283 .63462 L
.21891 .61538 L
.21154 .59743 L
.21107 .59615 L
.20465 .57692 L
.19958 .55769 L
.19577 .53846 L
.19319 .51923 L
.19231 .50903 L
.1918 .5 L
.19158 .48077 L
.19231 .46444 L
.19252 .46154 L
.19464 .44231 L
.19795 .42308 L
.20248 .40385 L
.20828 .38462 L
.21154 .37534 L
.21542 .36538 L
.224 .34615 L
.23077 .33295 L
.23413 .32692 L
.24598 .30769 L
.25 .30177 L
.25977 .28846 L
.26923 .27676 L
.27581 .26923 L
.28846 .25593 L
.29457 .25 L
.30769 .23823 L
.31677 .23077 L
.32692 .22303 L
.34363 .21154 L
.34615 .20993 L
.36538 .19863 L
.37759 .19231 L
.38462 .18896 L
.40385 .18074 L
.42308 .17387 L
.42552 .17308 L
F
0 g
.44231 .16826 m
.46154 .16385 L
.48077 .1606 L
.5 .15848 L
.51923 .15746 L
.53846 .15753 L
.55769 .15871 L
.57692 .16101 L
.59615 .16445 L
.61538 .16908 L
.62895 .17308 L
.63462 .17496 L
.65385 .18216 L
.67308 .19079 L
.67615 .19231 L
.69231 .20099 L
.70943 .21154 L
.71154 .21295 L
.73077 .22692 L
.73557 .23077 L
.75 .24329 L
.75706 .25 L
.76923 .26261 L
.7751 .26923 L
.78846 .28581 L
.79043 .28846 L
.8035 .30769 L
.80769 .31457 L
.81462 .32692 L
.82402 .34615 L
.82692 .35284 L
.83186 .36538 L
.83826 .38462 L
.84332 .40385 L
.84615 .41745 L
.8471 .42308 L
.84965 .44231 L
.85101 .46154 L
.85119 .48077 L
.8502 .5 L
.84804 .51923 L
.84615 .53118 L
.84468 .53846 L
.8401 .55769 L
.83423 .57692 L
.82703 .59615 L
.82692 .59641 L
.81839 .61538 L
.8082 .63462 L
.80769 .63549 L
Mistroke
.79628 .65385 L
.78846 .66506 L
.78243 .67308 L
.76923 .68904 L
.76632 .69231 L
.75 .70915 L
.74749 .71154 L
.73077 .7263 L
.72524 .73077 L
.71154 .74105 L
.69833 .75 L
.69231 .75379 L
.67308 .76476 L
.66432 .76923 L
.65385 .77416 L
.63462 .78212 L
.61633 .78846 L
.61538 .78876 L
.59615 .79414 L
.57692 .79834 L
.55769 .80138 L
.53846 .8033 L
.51923 .80412 L
.5 .80383 L
.48077 .80244 L
.46154 .79991 L
.44231 .79623 L
.42308 .79134 L
.41353 .78846 L
.40385 .78518 L
.38462 .77767 L
.36644 .76923 L
.36538 .7687 L
.34615 .75811 L
.33325 .75 L
.32692 .7457 L
.30769 .73119 L
.30718 .73077 L
.28846 .71417 L
.28575 .71154 L
.26923 .69402 L
.26775 .69231 L
.25245 .67308 L
.25 .66969 L
.23941 .65385 L
.23077 .63918 L
.2283 .63462 L
.21891 .61538 L
.21154 .59743 L
.21107 .59615 L
Mistroke
.20465 .57692 L
.19958 .55769 L
.19577 .53846 L
.19319 .51923 L
.19231 .50903 L
.1918 .5 L
.19158 .48077 L
.19231 .46444 L
.19252 .46154 L
.19464 .44231 L
.19795 .42308 L
.20248 .40385 L
.20828 .38462 L
.21154 .37534 L
.21542 .36538 L
.224 .34615 L
.23077 .33295 L
.23413 .32692 L
.24598 .30769 L
.25 .30177 L
.25977 .28846 L
.26923 .27676 L
.27581 .26923 L
.28846 .25593 L
.29457 .25 L
.30769 .23823 L
.31677 .23077 L
.32692 .22303 L
.34363 .21154 L
.34615 .20993 L
.36538 .19863 L
.37759 .19231 L
.38462 .18896 L
.40385 .18074 L
.42308 .17387 L
.42552 .17308 L
.44231 .16826 L
Mfstroke
.9 g
.48077 .22961 m
.5 .227 L
.51923 .2258 L
.53846 .22599 L
.55769 .22758 L
.57692 .23061 L
.57776 .23077 L
.59615 .23513 L
.61538 .24124 L
.63462 .24907 L
.63664 .25 L
.65385 .25881 L
.67083 .26923 L
.67308 .27076 L
.69231 .28531 L
.69601 .28846 L
.71154 .30315 L
.71584 .30769 L
.73077 .32546 L
.73187 .32692 L
.74497 .34615 L
.75 .35471 L
.75563 .36538 L
.76419 .38462 L
.76923 .39854 L
.77088 .40385 L
.77586 .42308 L
.77923 .44231 L
.78107 .46154 L
.78141 .48077 L
.78027 .5 L
.77763 .51923 L
.77345 .53846 L
.76923 .55312 L
.76767 .55769 L
.76018 .57692 L
.75082 .59615 L
.75 .59767 L
.73937 .61538 L
.73077 .62774 L
.72549 .63462 L
.71154 .65082 L
.70867 .65385 L
.69231 .66944 L
.68806 .67308 L
.67308 .68476 L
.6621 .69231 L
.65385 .69747 L
.63462 .70797 L
.62715 .71154 L
.61538 .71656 L
.59615 .72343 L
.57692 .7287 L
.56776 .73077 L
.55769 .73248 L
.53846 .73482 L
.51923 .73575 L
.5 .73529 L
.48077 .73341 L
.46452 .73077 L
.46154 .73008 L
.44231 .72523 L
.42308 .71877 L
.40595 .71154 L
.40385 .71054 L
.38462 .70034 L
.37181 .69231 L
.36538 .68786 L
.34667 .67308 L
.34615 .67263 L
.32692 .6539 L
.32688 .65385 L
.31086 .63462 L
.30769 .63031 L
.29778 .61538 L
.28846 .59881 L
.28712 .59615 L
.27856 .57692 L
.27186 .55769 L
.26923 .54859 L
.26686 .53846 L
.26346 .51923 L
.2616 .5 L
.26122 .48077 L
.26233 .46154 L
.26492 .44231 L
.26905 .42308 L
.26923 .42237 L
.27478 .40385 L
.28222 .38462 L
.28846 .37125 L
.29152 .36538 L
.30292 .34615 L
.30769 .33908 L
.31674 .32692 L
.32692 .3148 L
.33351 .30769 L
.34615 .29538 L
.35406 .28846 L
.36538 .27945 L
.37997 .26923 L
.38462 .26627 L
.40385 .25536 L
.41485 .25 L
.42308 .24641 L
.44231 .23923 L
.46154 .23366 L
.47422 .23077 L
F
0 g
.48077 .22961 m
.5 .227 L
.51923 .2258 L
.53846 .22599 L
.55769 .22758 L
.57692 .23061 L
.57776 .23077 L
.59615 .23513 L
.61538 .24124 L
.63462 .24907 L
.63664 .25 L
.65385 .25881 L
.67083 .26923 L
.67308 .27076 L
.69231 .28531 L
.69601 .28846 L
.71154 .30315 L
.71584 .30769 L
.73077 .32546 L
.73187 .32692 L
.74497 .34615 L
.75 .35471 L
.75563 .36538 L
.76419 .38462 L
.76923 .39854 L
.77088 .40385 L
.77586 .42308 L
.77923 .44231 L
.78107 .46154 L
.78141 .48077 L
.78027 .5 L
.77763 .51923 L
.77345 .53846 L
.76923 .55312 L
.76767 .55769 L
.76018 .57692 L
.75082 .59615 L
.75 .59767 L
.73937 .61538 L
.73077 .62774 L
.72549 .63462 L
.71154 .65082 L
.70867 .65385 L
.69231 .66944 L
.68806 .67308 L
.67308 .68476 L
.6621 .69231 L
.65385 .69747 L
.63462 .70797 L
.62715 .71154 L
Mistroke
.61538 .71656 L
.59615 .72343 L
.57692 .7287 L
.56776 .73077 L
.55769 .73248 L
.53846 .73482 L
.51923 .73575 L
.5 .73529 L
.48077 .73341 L
.46452 .73077 L
.46154 .73008 L
.44231 .72523 L
.42308 .71877 L
.40595 .71154 L
.40385 .71054 L
.38462 .70034 L
.37181 .69231 L
.36538 .68786 L
.34667 .67308 L
.34615 .67263 L
.32692 .6539 L
.32688 .65385 L
.31086 .63462 L
.30769 .63031 L
.29778 .61538 L
.28846 .59881 L
.28712 .59615 L
.27856 .57692 L
.27186 .55769 L
.26923 .54859 L
.26686 .53846 L
.26346 .51923 L
.2616 .5 L
.26122 .48077 L
.26233 .46154 L
.26492 .44231 L
.26905 .42308 L
.26923 .42237 L
.27478 .40385 L
.28222 .38462 L
.28846 .37125 L
.29152 .36538 L
.30292 .34615 L
.30769 .33908 L
.31674 .32692 L
.32692 .3148 L
.33351 .30769 L
.34615 .29538 L
.35406 .28846 L
.36538 .27945 L
Mistroke
.37997 .26923 L
.38462 .26627 L
.40385 .25536 L
.41485 .25 L
.42308 .24641 L
.44231 .23923 L
.46154 .23366 L
.47422 .23077 L
.48077 .22961 L
Mfstroke
1 g
.48077 .3218 m
.5 .3179 L
.51923 .31623 L
.53846 .31673 L
.55769 .31942 L
.57692 .32445 L
.58416 .32692 L
.59615 .33205 L
.61538 .3427 L
.62055 .34615 L
.63462 .35719 L
.64329 .36538 L
.65385 .37724 L
.65943 .38462 L
.6712 .40385 L
.67308 .40747 L
.67962 .42308 L
.68523 .44231 L
.68833 .46154 L
.68908 .48077 L
.68753 .5 L
.68364 .51923 L
.67722 .53846 L
.67308 .54803 L
.66801 .55769 L
.65543 .57692 L
.65385 .57899 L
.63849 .59615 L
.63462 .59982 L
.61538 .61507 L
.61493 .61538 L
.59615 .62649 L
.57753 .63462 L
.57692 .63483 L
.55769 .64061 L
.53846 .64405 L
.51923 .64529 L
.5 .64435 L
.48077 .6412 L
.46154 .63565 L
.45861 .63462 L
.44231 .62747 L
.42308 .61608 L
.42208 .61538 L
.40385 .60059 L
.39932 .59615 L
.38462 .57892 L
.38317 .57692 L
.37138 .55769 L
.36538 .54491 L
.36295 .53846 L
.35732 .51923 L
.35419 .5 L
.35341 .48077 L
.35493 .46154 L
.3588 .44231 L
.36517 .42308 L
.36538 .42253 L
.37433 .40385 L
.38462 .38764 L
.38686 .38462 L
.40376 .36538 L
.40385 .3653 L
.42308 .34907 L
.4272 .34615 L
.44231 .33697 L
.46154 .32806 L
.46433 .32692 L
F
0 g
.48077 .3218 m
.5 .3179 L
.51923 .31623 L
.53846 .31673 L
.55769 .31942 L
.57692 .32445 L
.58416 .32692 L
.59615 .33205 L
.61538 .3427 L
.62055 .34615 L
.63462 .35719 L
.64329 .36538 L
.65385 .37724 L
.65943 .38462 L
.6712 .40385 L
.67308 .40747 L
.67962 .42308 L
.68523 .44231 L
.68833 .46154 L
.68908 .48077 L
.68753 .5 L
.68364 .51923 L
.67722 .53846 L
.67308 .54803 L
.66801 .55769 L
.65543 .57692 L
.65385 .57899 L
.63849 .59615 L
.63462 .59982 L
.61538 .61507 L
.61493 .61538 L
.59615 .62649 L
.57753 .63462 L
.57692 .63483 L
.55769 .64061 L
.53846 .64405 L
.51923 .64529 L
.5 .64435 L
.48077 .6412 L
.46154 .63565 L
.45861 .63462 L
.44231 .62747 L
.42308 .61608 L
.42208 .61538 L
.40385 .60059 L
.39932 .59615 L
.38462 .57892 L
.38317 .57692 L
.37138 .55769 L
.36538 .54491 L
Mistroke
.36295 .53846 L
.35732 .51923 L
.35419 .5 L
.35341 .48077 L
.35493 .46154 L
.3588 .44231 L
.36517 .42308 L
.36538 .42253 L
.37433 .40385 L
.38462 .38764 L
.38686 .38462 L
.40376 .36538 L
.40385 .3653 L
.42308 .34907 L
.4272 .34615 L
.44231 .33697 L
.46154 .32806 L
.46433 .32692 L
.48077 .3218 L
Mfstroke
.4 g
.98077 .29417 m
.9784 .28846 L
.96977 .26923 L
.96154 .25277 L
.96007 .25 L
.94921 .23077 L
.94231 .21955 L
.9371 .21154 L
.92363 .19231 L
.92308 .19156 L
.90865 .17308 L
.90385 .16733 L
.89195 .15385 L
.88462 .14602 L
.8733 .13462 L
.86538 .12707 L
.85235 .11538 L
.84615 .11012 L
.82861 .09615 L
.82692 .09488 L
.80769 .08116 L
.80133 .07692 L
.78846 .06879 L
.7693 .05769 L
.76923 .05765 L
.75 .04765 L
.73077 .0387 L
.73023 .03846 L
.71154 .03073 L
.69231 .0237 L
.67863 .01923 L
.98077 .01923 L
F
0 g
.98077 .29417 m
.9784 .28846 L
.96977 .26923 L
.96154 .25277 L
.96007 .25 L
.94921 .23077 L
.94231 .21955 L
.9371 .21154 L
.92363 .19231 L
.92308 .19156 L
.90865 .17308 L
.90385 .16733 L
.89195 .15385 L
.88462 .14602 L
.8733 .13462 L
.86538 .12707 L
.85235 .11538 L
.84615 .11012 L
.82861 .09615 L
.82692 .09488 L
.80769 .08116 L
.80133 .07692 L
.78846 .06879 L
.7693 .05769 L
.76923 .05765 L
.75 .04765 L
.73077 .0387 L
.73023 .03846 L
.71154 .03073 L
.69231 .0237 L
.67863 .01923 L
s
.3 g
.98077 .7522 m
.9696 .76923 L
.96154 .78072 L
.95585 .78846 L
.94231 .80584 L
.94079 .80769 L
.92428 .82692 L
.92308 .82825 L
.90612 .84615 L
.90385 .84844 L
.8861 .86538 L
.88462 .86674 L
.86538 .8834 L
.86391 .88462 L
.84615 .8986 L
.83909 .90385 L
.82692 .91249 L
.81103 .92308 L
.80769 .9252 L
.78846 .93681 L
.77871 .94231 L
.76923 .9474 L
.75 .95705 L
.74036 .96154 L
.73077 .96579 L
.71154 .97367 L
.69231 .98074 L
.69223 .98077 L
.98077 .98077 L
F
0 g
.98077 .7522 m
.9696 .76923 L
.96154 .78072 L
.95585 .78846 L
.94231 .80584 L
.94079 .80769 L
.92428 .82692 L
.92308 .82825 L
.90612 .84615 L
.90385 .84844 L
.8861 .86538 L
.88462 .86674 L
.86538 .8834 L
.86391 .88462 L
.84615 .8986 L
.83909 .90385 L
.82692 .91249 L
.81103 .92308 L
.80769 .9252 L
.78846 .93681 L
.77871 .94231 L
.76923 .9474 L
.75 .95705 L
.74036 .96154 L
.73077 .96579 L
.71154 .97367 L
.69231 .98074 L
.69223 .98077 L
s
.3 g
.98077 .19077 m
.9688 .17308 L
.96154 .16306 L
.95452 .15385 L
.94231 .13877 L
.93878 .13462 L
.92308 .11716 L
.92139 .11538 L
.90385 .09778 L
.90213 .09615 L
.88462 .08029 L
.88068 .07692 L
.86538 .06444 L
.85661 .05769 L
.84615 .05003 L
.82926 .03846 L
.82692 .03693 L
.80769 .02502 L
.79763 .01923 L
.98077 .01923 L
F
0 g
.98077 .19077 m
.9688 .17308 L
.96154 .16306 L
.95452 .15385 L
.94231 .13877 L
.93878 .13462 L
.92308 .11716 L
.92139 .11538 L
.90385 .09778 L
.90213 .09615 L
.88462 .08029 L
.88068 .07692 L
.86538 .06444 L
.85661 .05769 L
.84615 .05003 L
.82926 .03846 L
.82692 .03693 L
.80769 .02502 L
.79763 .01923 L
s
.2 g
.98077 .83021 m
.96753 .84615 L
.96154 .85302 L
.95027 .86538 L
.94231 .87372 L
.93142 .88462 L
.92308 .89259 L
.91075 .90385 L
.90385 .90988 L
.88798 .92308 L
.88462 .92576 L
.86538 .94037 L
.86271 .94231 L
.84615 .95382 L
.83436 .96154 L
.82692 .96621 L
.80769 .9776 L
.80205 .98077 L
.98077 .98077 L
F
0 g
.98077 .83021 m
.96753 .84615 L
.96154 .85302 L
.95027 .86538 L
.94231 .87372 L
.93142 .88462 L
.92308 .89259 L
.91075 .90385 L
.90385 .90988 L
.88798 .92308 L
.88462 .92576 L
.86538 .94037 L
.86271 .94231 L
.84615 .95382 L
.83436 .96154 L
.82692 .96621 L
.80769 .9776 L
.80205 .98077 L
s
.2 g
.98077 .11281 m
.9664 .09615 L
.96154 .09081 L
.94831 .07692 L
.94231 .07093 L
.92839 .05769 L
.92308 .05287 L
.90637 .03846 L
.90385 .03639 L
.88462 .02131 L
.88182 .01923 L
.98077 .01923 L
F
0 g
.98077 .11281 m
.9664 .09615 L
.96154 .09081 L
.94831 .07692 L
.94231 .07093 L
.92839 .05769 L
.92308 .05287 L
.90637 .03846 L
.90385 .03639 L
.88462 .02131 L
.88182 .01923 L
s
.1 g
.98077 .89733 m
.97451 .90385 L
.96154 .91678 L
.95496 .92308 L
.94231 .93469 L
.93364 .94231 L
.92308 .95123 L
.91027 .96154 L
.90385 .96652 L
.88462 .98067 L
.88448 .98077 L
.98077 .98077 L
F
0 g
.98077 .89733 m
.97451 .90385 L
.96154 .91678 L
.95496 .92308 L
.94231 .93469 L
.93364 .94231 L
.92308 .95123 L
.91027 .96154 L
.90385 .96652 L
.88462 .98067 L
.88448 .98077 L
s
.1 g
.98077 .04574 m
.97346 .03846 L
.96154 .0271 L
.95289 .01923 L
.98077 .01923 L
F
0 g
.98077 .04574 m
.97346 .03846 L
.96154 .0271 L
.95289 .01923 L
s
.98077 .95843 m
.97738 .96154 L
.96154 .97558 L
.95543 .98077 L
.98077 .98077 L
F
.98077 .95843 m
.97738 .96154 L
.96154 .97558 L
.95543 .98077 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.351 0 0 r
.39881 .6037 .40512 .60371 .41519 .60613 .4089 .60625 Mtetra
.347 0 0 r
.4089 .60625 .41519 .60613 .42533 .60845 .41908 .60868 Mtetra
.342 0 0 r
.41908 .60868 .42533 .60845 .43555 .61064 .42932 .611 Mtetra
.336 0 0 r
.42932 .611 .43555 .61064 .44584 .61271 .43964 .61319 Mtetra
.328 0 0 r
.43964 .61319 .44584 .61271 .45621 .61464 .45004 .61524 Mtetra
.319 0 0 r
.45004 .61524 .45621 .61464 .46665 .61642 .46052 .61713 Mtetra
.308 0 0 r
.46052 .61713 .46665 .61642 .47716 .61803 .47106 .61885 Mtetra
.297 0 0 r
.47106 .61885 .47716 .61803 .48774 .61947 .48169 .62039 Mtetra
.283 0 0 r
.48169 .62039 .48774 .61947 .4984 .62072 .49238 .62175 Mtetra
.269 0 0 r
.49238 .62175 .4984 .62072 .50912 .62177 .50315 .6229 Mtetra
.253 0 0 r
.50315 .6229 .50912 .62177 .51992 .62261 .51398 .62383 Mtetra
.236 0 0 r
.51398 .62383 .51992 .62261 .53078 .62324 .52489 .62454 Mtetra
.218 0 0 r
.52489 .62454 .53078 .62324 .54171 .62363 .53586 .62502 Mtetra
.198 0 0 r
.53586 .62502 .54171 .62363 .5527 .62378 .5469 .62525 Mtetra
.177 0 0 r
.5469 .62525 .5527 .62378 .56375 .62369 .558 .62523 Mtetra
.154 0 0 r
.558 .62523 .56375 .62369 .57486 .62333 .56916 .62494 Mtetra
.13 0 0 r
.56916 .62494 .57486 .62333 .58604 .62272 .58039 .62438 Mtetra
.105 0 0 r
.58039 .62438 .58604 .62272 .59727 .62182 .59167 .62353 Mtetra
.078 0 0 r
.59167 .62353 .59727 .62182 .60855 .62065 .603 .6224 Mtetra
.05 0 0 r
.603 .6224 .60855 .62065 .61988 .61918 .61439 .62098 Mtetra
.021 0 0 r
.61439 .62098 .61988 .61918 .63126 .61743 .62583 .61925 Mtetra
0 0 0 r
.62583 .61925 .63126 .61743 .64269 .61538 .63732 .61722 Mtetra
.63732 .61722 .64269 .61538 .65416 .61302 .64885 .61488 Mtetra
.64885 .61488 .65416 .61302 .66568 .61036 .66042 .61222 Mtetra
.66042 .61222 .66568 .61036 .67723 .60739 .67203 .60925 Mtetra
.67203 .60925 .67723 .60739 .68881 .60411 .68368 .60596 Mtetra
.68368 .60596 .68881 .60411 .70043 .60051 .69536 .60235 Mtetra
.69536 .60235 .70043 .60051 .71208 .59661 .70707 .59842 Mtetra
.241 .74 .665 r
.70707 .59842 .71208 .59661 .72375 .5924 .7188 .59418 Mtetra
.275 .763 .681 r
.7188 .59418 .72375 .5924 .73545 .58787 .73056 .58961 Mtetra
.309 .786 .696 r
.73056 .58961 .73545 .58787 .74717 .58304 .74235 .58473 Mtetra
.343 .808 .711 r
.74235 .58473 .74717 .58304 .75891 .57791 .75415 .57953 Mtetra
.376 .829 .725 r
.75415 .57953 .75891 .57791 .77067 .57247 .76597 .57403 Mtetra
.408 .848 .738 r
.76597 .57403 .77067 .57247 .78244 .56674 .7778 .56823 Mtetra
.44 .867 .751 r
.7778 .56823 .78244 .56674 .79422 .56072 .78964 .56212 Mtetra
.47 .884 .762 r
.78964 .56212 .79422 .56072 .806 .55441 .80149 .55573 Mtetra
.5 .9 .773 r
.80149 .55573 .806 .55441 .8178 .54783 .81335 .54905 Mtetra
.528 .914 .784 r
.81335 .54905 .8178 .54783 .8296 .54097 .82521 .54209 Mtetra
.554 .927 .793 r
.82521 .54209 .8296 .54097 .8414 .53386 .83708 .53487 Mtetra
.58 .939 .802 r
.83708 .53487 .8414 .53386 .8532 .52649 .84894 .52738 Mtetra
.604 .949 .81 r
.84894 .52738 .8532 .52649 .865 .51887 .8608 .51964 Mtetra
.626 .959 .817 r
.8608 .51964 .865 .51887 .8768 .51102 .87266 .51167 Mtetra
.648 .967 .824 r
.87266 .51167 .8768 .51102 .88859 .50295 .88451 .50346 Mtetra
.667 .974 .83 r
.88451 .50346 .88859 .50295 .90038 .49466 .89636 .49503 Mtetra
.686 .979 .836 r
.89636 .49503 .90038 .49466 .91217 .48617 .9082 .48639 Mtetra
.703 .984 .841 r
.9082 .48639 .91217 .48617 .92394 .47748 .92003 .47756 Mtetra
.719 .988 .845 r
.92003 .47756 .92394 .47748 .93571 .46862 .93186 .46854 Mtetra
.734 .991 .849 r
.93186 .46854 .93571 .46862 .94747 .45958 .94367 .45935 Mtetra
.747 .994 .853 r
.94367 .45935 .94747 .45958 .95922 .45039 .95548 .44999 Mtetra
.759 .995 .857 r
.95548 .44999 .95922 .45039 .97096 .44105 .96727 .44048 Mtetra
.353 0 0 r
.39244 .60357 .39881 .6037 .4089 .60625 .40256 .60624 Mtetra
.348 0 0 r
.40256 .60624 .4089 .60625 .41908 .60868 .41276 .6088 Mtetra
.343 0 0 r
.41276 .6088 .41908 .60868 .42932 .611 .42303 .61124 Mtetra
.336 0 0 r
.42303 .61124 .42932 .611 .43964 .61319 .43338 .61354 Mtetra
.327 0 0 r
.43338 .61354 .43964 .61319 .45004 .61524 .44381 .6157 Mtetra
.318 0 0 r
.44381 .6157 .45004 .61524 .46052 .61713 .45432 .61771 Mtetra
.306 0 0 r
.45432 .61771 .46052 .61713 .47106 .61885 .4649 .61954 Mtetra
.294 0 0 r
.4649 .61954 .47106 .61885 .48169 .62039 .47556 .62119 Mtetra
.28 0 0 r
.47556 .62119 .48169 .62039 .49238 .62175 .48629 .62264 Mtetra
.265 0 0 r
.48629 .62264 .49238 .62175 .50315 .6229 .4971 .62389 Mtetra
.249 0 0 r
.4971 .62389 .50315 .6229 .51398 .62383 .50798 .62492 Mtetra
.231 0 0 r
.50798 .62492 .51398 .62383 .52489 .62454 .51893 .62571 Mtetra
.211 0 0 r
.51893 .62571 .52489 .62454 .53586 .62502 .52995 .62627 Mtetra
.19 0 0 r
.52995 .62627 .53586 .62502 .5469 .62525 .54103 .62658 Mtetra
.168 0 0 r
.54103 .62658 .5469 .62525 .558 .62523 .55218 .62662 Mtetra
.144 0 0 r
.55218 .62662 .558 .62523 .56916 .62494 .56339 .6264 Mtetra
.119 0 0 r
.56339 .6264 .56916 .62494 .58039 .62438 .57467 .6259 Mtetra
.093 0 0 r
.57467 .6259 .58039 .62438 .59167 .62353 .586 .62511 Mtetra
.065 0 0 r
.586 .62511 .59167 .62353 .603 .6224 .59739 .62402 Mtetra
.036 0 0 r
.59739 .62402 .603 .6224 .61439 .62098 .60883 .62263 Mtetra
.006 0 0 r
.60883 .62263 .61439 .62098 .62583 .61925 .62033 .62094 Mtetra
0 0 0 r
.62033 .62094 .62583 .61925 .63732 .61722 .63187 .61893 Mtetra
.63187 .61893 .63732 .61722 .64885 .61488 .64346 .6166 Mtetra
.64346 .6166 .64885 .61488 .66042 .61222 .65509 .61395 Mtetra
.65509 .61395 .66042 .61222 .67203 .60925 .66676 .61098 Mtetra
.66676 .61098 .67203 .60925 .68368 .60596 .67847 .60768 Mtetra
.67847 .60768 .68368 .60596 .69536 .60235 .69021 .60405 Mtetra
.229 .735 .675 r
.69021 .60405 .69536 .60235 .70707 .59842 .70198 .6001 Mtetra
.264 .759 .691 r
.70198 .6001 .70707 .59842 .7188 .59418 .71378 .59581 Mtetra
.299 .782 .706 r
.71378 .59581 .7188 .59418 .73056 .58961 .72561 .59121 Mtetra
.334 .805 .72 r
.72561 .59121 .73056 .58961 .74235 .58473 .73745 .58627 Mtetra
.367 .826 .734 r
.73745 .58627 .74235 .58473 .75415 .57953 .74932 .58102 Mtetra
.4 .846 .747 r
.74932 .58102 .75415 .57953 .76597 .57403 .7612 .57546 Mtetra
.433 .865 .76 r
.7612 .57546 .76597 .57403 .7778 .56823 .77309 .56958 Mtetra
.464 .882 .771 r
.77309 .56958 .7778 .56823 .78964 .56212 .785 .56339 Mtetra
.494 .898 .782 r
.785 .56339 .78964 .56212 .80149 .55573 .79692 .55691 Mtetra
.522 .913 .792 r
.79692 .55691 .80149 .55573 .81335 .54905 .80884 .55013 Mtetra
.55 .926 .801 r
.80884 .55013 .81335 .54905 .82521 .54209 .82076 .54307 Mtetra
.576 .938 .809 r
.82076 .54307 .82521 .54209 .83708 .53487 .83269 .53574 Mtetra
.6 .949 .817 r
.83269 .53574 .83708 .53487 .84894 .52738 .84461 .52814 Mtetra
.623 .958 .824 r
.84461 .52814 .84894 .52738 .8608 .51964 .85653 .52028 Mtetra
.645 .966 .83 r
.85653 .52028 .8608 .51964 .87266 .51167 .86845 .51217 Mtetra
.665 .973 .835 r
.86845 .51217 .87266 .51167 .88451 .50346 .88037 .50383 Mtetra
.684 .979 .84 r
.88037 .50383 .88451 .50346 .89636 .49503 .89227 .49526 Mtetra
.702 .984 .845 r
.89227 .49526 .89636 .49503 .9082 .48639 .90417 .48648 Mtetra
.718 .988 .849 r
.90417 .48648 .9082 .48639 .92003 .47756 .91606 .4775 Mtetra
.733 .991 .852 r
.91606 .4775 .92003 .47756 .93186 .46854 .92794 .46833 Mtetra
.746 .993 .855 r
.92794 .46833 .93186 .46854 .94367 .45935 .93981 .45898 Mtetra
.759 .995 .858 r
.93981 .45898 .94367 .45935 .95548 .44999 .95167 .44946 Mtetra
.771 .996 .861 r
.95167 .44946 .95548 .44999 .96727 .44048 .96352 .43979 Mtetra
.353 0 0 r
.386 .6033 .39244 .60357 .40256 .60624 .39615 .60609 Mtetra
.348 0 0 r
.39615 .60609 .40256 .60624 .41276 .6088 .40637 .60877 Mtetra
.342 0 0 r
.40637 .60877 .41276 .6088 .42303 .61124 .41668 .61133 Mtetra
.334 0 0 r
.41668 .61133 .42303 .61124 .43338 .61354 .42706 .61375 Mtetra
.325 0 0 r
.42706 .61375 .43338 .61354 .44381 .6157 .43752 .61603 Mtetra
.315 0 0 r
.43752 .61603 .44381 .6157 .45432 .61771 .44806 .61814 Mtetra
.303 0 0 r
.44806 .61814 .45432 .61771 .4649 .61954 .45868 .62008 Mtetra
.29 0 0 r
.45868 .62008 .4649 .61954 .47556 .62119 .46937 .62183 Mtetra
.276 0 0 r
.46937 .62183 .47556 .62119 .48629 .62264 .48014 .62339 Mtetra
.26 0 0 r
.48014 .62339 .48629 .62264 .4971 .62389 .49099 .62473 Mtetra
.242 0 0 r
.49099 .62473 .4971 .62389 .50798 .62492 .50191 .62585 Mtetra
.223 0 0 r
.50191 .62585 .50798 .62492 .51893 .62571 .5129 .62673 Mtetra
.203 0 0 r
.5129 .62673 .51893 .62571 .52995 .62627 .52396 .62737 Mtetra
.181 0 0 r
.52396 .62737 .52995 .62627 .54103 .62658 .53509 .62775 Mtetra
.158 0 0 r
.53509 .62775 .54103 .62658 .55218 .62662 .54629 .62787 Mtetra
.133 0 0 r
.54629 .62787 .55218 .62662 .56339 .6264 .55755 .62771 Mtetra
.106 0 0 r
.55755 .62771 .56339 .6264 .57467 .6259 .56888 .62726 Mtetra
.079 0 0 r
.56888 .62726 .57467 .6259 .586 .62511 .58026 .62652 Mtetra
.05 0 0 r
.58026 .62652 .586 .62511 .59739 .62402 .59171 .62548 Mtetra
.019 0 0 r
.59171 .62548 .59739 .62402 .60883 .62263 .6032 .62413 Mtetra
0 0 0 r
.6032 .62413 .60883 .62263 .62033 .62094 .61475 .62246 Mtetra
.61475 .62246 .62033 .62094 .63187 .61893 .62635 .62047 Mtetra
.62635 .62047 .63187 .61893 .64346 .6166 .638 .61816 Mtetra
.638 .61816 .64346 .6166 .65509 .61395 .64969 .61552 Mtetra
.64969 .61552 .65509 .61395 .66676 .61098 .66142 .61254 Mtetra
.66142 .61254 .66676 .61098 .67847 .60768 .67319 .60923 Mtetra
.218 .73 .687 r
.67319 .60923 .67847 .60768 .69021 .60405 .68499 .60559 Mtetra
.254 .755 .703 r
.68499 .60559 .69021 .60405 .70198 .6001 .69682 .60161 Mtetra
.29 .779 .718 r
.69682 .60161 .70198 .6001 .71378 .59581 .70869 .59729 Mtetra
.325 .802 .732 r
.70869 .59729 .71378 .59581 .72561 .59121 .72057 .59264 Mtetra
.359 .824 .746 r
.72057 .59264 .72561 .59121 .73745 .58627 .73248 .58766 Mtetra
.393 .844 .759 r
.73248 .58766 .73745 .58627 .74932 .58102 .74441 .58235 Mtetra
.426 .863 .771 r
.74441 .58235 .74932 .58102 .7612 .57546 .75636 .57672 Mtetra
.458 .881 .782 r
.75636 .57672 .7612 .57546 .77309 .56958 .76832 .57077 Mtetra
.488 .897 .792 r
.76832 .57077 .77309 .56958 .785 .56339 .78029 .5645 Mtetra
.518 .912 .802 r
.78029 .5645 .785 .56339 .79692 .55691 .79227 .55793 Mtetra
.546 .926 .811 r
.79227 .55793 .79692 .55691 .80884 .55013 .80425 .55106 Mtetra
.572 .938 .818 r
.80425 .55106 .80884 .55013 .82076 .54307 .81624 .5439 Mtetra
.597 .949 .825 r
.81624 .5439 .82076 .54307 .83269 .53574 .82823 .53646 Mtetra
.621 .958 .831 r
.82823 .53646 .83269 .53574 .84461 .52814 .84021 .52874 Mtetra
.643 .966 .837 r
.84021 .52874 .84461 .52814 .85653 .52028 .8522 .52076 Mtetra
.663 .973 .842 r
.8522 .52076 .85653 .52028 .86845 .51217 .86418 .51253 Mtetra
.683 .979 .846 r
.86418 .51253 .86845 .51217 .88037 .50383 .87615 .50405 Mtetra
.7 .984 .85 r
.87615 .50405 .88037 .50383 .89227 .49526 .88812 .49535 Mtetra
.717 .988 .853 r
.88812 .49535 .89227 .49526 .90417 .48648 .90008 .48642 Mtetra
.732 .991 .856 r
.90008 .48642 .90417 .48648 .91606 .4775 .91203 .47729 Mtetra
.746 .993 .859 r
.91203 .47729 .91606 .4775 .92794 .46833 .92396 .46797 Mtetra
.759 .995 .861 r
.92396 .46797 .92794 .46833 .93981 .45898 .93589 .45846 Mtetra
.771 .996 .863 r
.93589 .45846 .93981 .45898 .95167 .44946 .9478 .44879 Mtetra
.781 .996 .865 r
.9478 .44879 .95167 .44946 .96352 .43979 .95971 .43895 Mtetra
.352 0 0 r
.37951 .60288 .386 .6033 .39615 .60609 .38968 .60579 Mtetra
.347 0 0 r
.38968 .60579 .39615 .60609 .40637 .60877 .39993 .60859 Mtetra
.34 0 0 r
.39993 .60859 .40637 .60877 .41668 .61133 .41026 .61127 Mtetra
.332 0 0 r
.41026 .61127 .41668 .61133 .42706 .61375 .42067 .6138 Mtetra
.322 0 0 r
.42067 .6138 .42706 .61375 .43752 .61603 .43116 .61619 Mtetra
.311 0 0 r
.43116 .61619 .43752 .61603 .44806 .61814 .44174 .61841 Mtetra
.299 0 0 r
.44174 .61841 .44806 .61814 .45868 .62008 .45239 .62046 Mtetra
.285 0 0 r
.45239 .62046 .45868 .62008 .46937 .62183 .46312 .62231 Mtetra
.269 0 0 r
.46312 .62231 .46937 .62183 .48014 .62339 .47393 .62397 Mtetra
.252 0 0 r
.47393 .62397 .48014 .62339 .49099 .62473 .48481 .6254 Mtetra
.234 0 0 r
.48481 .6254 .49099 .62473 .50191 .62585 .49577 .62661 Mtetra
.214 0 0 r
.49577 .62661 .50191 .62585 .5129 .62673 .5068 .62758 Mtetra
.193 0 0 r
.5068 .62758 .5129 .62673 .52396 .62737 .51791 .6283 Mtetra
.17 0 0 r
.51791 .6283 .52396 .62737 .53509 .62775 .52909 .62876 Mtetra
.145 0 0 r
.52909 .62876 .53509 .62775 .54629 .62787 .54033 .62894 Mtetra
.119 0 0 r
.54033 .62894 .54629 .62787 .55755 .62771 .55164 .62884 Mtetra
.091 0 0 r
.55164 .62884 .55755 .62771 .56888 .62726 .56302 .62845 Mtetra
.062 0 0 r
.56302 .62845 .56888 .62726 .58026 .62652 .57445 .62776 Mtetra
.032 0 0 r
.57445 .62776 .58026 .62652 .59171 .62548 .58595 .62676 Mtetra
.001 0 0 r
.58595 .62676 .59171 .62548 .6032 .62413 .5975 .62545 Mtetra
0 0 0 r
.5975 .62545 .6032 .62413 .61475 .62246 .60911 .62381 Mtetra
.60911 .62381 .61475 .62246 .62635 .62047 .62076 .62184 Mtetra
.62076 .62184 .62635 .62047 .638 .61816 .63247 .61954 Mtetra
.63247 .61954 .638 .61816 .64969 .61552 .64422 .61691 Mtetra
.64422 .61691 .64969 .61552 .66142 .61254 .65601 .61393 Mtetra
.208 .726 .701 r
.65601 .61393 .66142 .61254 .67319 .60923 .66784 .61061 Mtetra
.245 .751 .716 r
.66784 .61061 .67319 .60923 .68499 .60559 .6797 .60695 Mtetra
.281 .776 .731 r
.6797 .60695 .68499 .60559 .69682 .60161 .6916 .60294 Mtetra
.316 .799 .746 r
.6916 .60294 .69682 .60161 .70869 .59729 .70352 .59859 Mtetra
.352 .821 .759 r
.70352 .59859 .70869 .59729 .72057 .59264 .71547 .5939 Mtetra
.386 .842 .772 r
.71547 .5939 .72057 .59264 .73248 .58766 .72744 .58887 Mtetra
.42 .862 .784 r
.72744 .58887 .73248 .58766 .74441 .58235 .73944 .58351 Mtetra
.452 .88 .795 r
.73944 .58351 .74441 .58235 .75636 .57672 .75145 .57781 Mtetra
.484 .897 .805 r
.75145 .57781 .75636 .57672 .76832 .57077 .76347 .57179 Mtetra
.514 .912 .814 r
.76347 .57179 .76832 .57077 .78029 .5645 .7755 .56544 Mtetra
.542 .925 .822 r
.7755 .56544 .78029 .5645 .79227 .55793 .78755 .55878 Mtetra
.569 .938 .829 r
.78755 .55878 .79227 .55793 .80425 .55106 .79959 .55182 Mtetra
.595 .949 .835 r
.79959 .55182 .80425 .55106 .81624 .5439 .81165 .54456 Mtetra
.619 .958 .841 r
.81165 .54456 .81624 .5439 .82823 .53646 .8237 .537 Mtetra
.641 .966 .846 r
.8237 .537 .82823 .53646 .84021 .52874 .83575 .52917 Mtetra
.662 .973 .85 r
.83575 .52917 .84021 .52874 .8522 .52076 .84779 .52107 Mtetra
.682 .979 .854 r
.84779 .52107 .8522 .52076 .86418 .51253 .85984 .51271 Mtetra
.7 .984 .857 r
.85984 .51271 .86418 .51253 .87615 .50405 .87187 .50411 Mtetra
.717 .988 .859 r
.87187 .50411 .87615 .50405 .88812 .49535 .8839 .49527 Mtetra
.732 .991 .862 r
.8839 .49527 .88812 .49535 .90008 .48642 .89592 .4862 Mtetra
.746 .993 .863 r
.89592 .4862 .90008 .48642 .91203 .47729 .90792 .47692 Mtetra
.759 .994 .865 r
.90792 .47692 .91203 .47729 .92396 .46797 .91992 .46745 Mtetra
.771 .995 .866 r
.91992 .46745 .92396 .46797 .93589 .45846 .9319 .45779 Mtetra
.782 .995 .867 r
.9319 .45779 .93589 .45846 .9478 .44879 .94387 .44795 Mtetra
.792 .995 .868 r
.94387 .44795 .9478 .44879 .95971 .43895 .95583 .43796 Mtetra
.35 0 0 r
.37295 .6023 .37951 .60288 .38968 .60579 .38315 .60533 Mtetra
.344 0 0 r
.38315 .60533 .38968 .60579 .39993 .60859 .39342 .60824 Mtetra
.336 0 0 r
.39342 .60824 .39993 .60859 .41026 .61127 .40378 .61103 Mtetra
.328 0 0 r
.40378 .61103 .41026 .61127 .42067 .6138 .41422 .61368 Mtetra
.317 0 0 r
.41422 .61368 .42067 .6138 .43116 .61619 .42474 .61618 Mtetra
.306 0 0 r
.42474 .61618 .43116 .61619 .44174 .61841 .43535 .61851 Mtetra
.292 0 0 r
.43535 .61851 .44174 .61841 .45239 .62046 .44603 .62066 Mtetra
.278 0 0 r
.44603 .62066 .45239 .62046 .46312 .62231 .4568 .62262 Mtetra
.261 0 0 r
.4568 .62262 .46312 .62231 .47393 .62397 .46764 .62436 Mtetra
.244 0 0 r
.46764 .62436 .47393 .62397 .48481 .6254 .47856 .62589 Mtetra
.224 0 0 r
.47856 .62589 .48481 .6254 .49577 .62661 .48956 .62719 Mtetra
.203 0 0 r
.48956 .62719 .49577 .62661 .5068 .62758 .50064 .62824 Mtetra
.181 0 0 r
.50064 .62824 .5068 .62758 .51791 .6283 .51179 .62904 Mtetra
.156 0 0 r
.51179 .62904 .51791 .6283 .52909 .62876 .52301 .62957 Mtetra
.131 0 0 r
.52301 .62957 .52909 .62876 .54033 .62894 .5343 .62982 Mtetra
.103 0 0 r
.5343 .62982 .54033 .62894 .55164 .62884 .54566 .62979 Mtetra
.074 0 0 r
.54566 .62979 .55164 .62884 .56302 .62845 .55709 .62945 Mtetra
.044 0 0 r
.55709 .62945 .56302 .62845 .57445 .62776 .56857 .62881 Mtetra
.012 0 0 r
.56857 .62881 .57445 .62776 .58595 .62676 .58012 .62785 Mtetra
0 0 0 r
.58012 .62785 .58595 .62676 .5975 .62545 .59173 .62657 Mtetra
.59173 .62657 .5975 .62545 .60911 .62381 .60339 .62496 Mtetra
.60339 .62496 .60911 .62381 .62076 .62184 .6151 .62302 Mtetra
.6151 .62302 .62076 .62184 .63247 .61954 .62686 .62073 Mtetra
.162 .696 .7 r
.62686 .62073 .63247 .61954 .64422 .61691 .63867 .6181 Mtetra
.199 .722 .716 r
.63867 .6181 .64422 .61691 .65601 .61393 .65052 .61512 Mtetra
.235 .748 .732 r
.65052 .61512 .65601 .61393 .66784 .61061 .66241 .61179 Mtetra
.272 .773 .747 r
.66241 .61179 .66784 .61061 .6797 .60695 .67433 .60811 Mtetra
.309 .797 .761 r
.67433 .60811 .6797 .60695 .6916 .60294 .68629 .60408 Mtetra
.345 .819 .775 r
.68629 .60408 .6916 .60294 .70352 .59859 .69828 .5997 Mtetra
.38 .841 .787 r
.69828 .5997 .70352 .59859 .71547 .5939 .71029 .59497 Mtetra
.414 .861 .799 r
.71029 .59497 .71547 .5939 .72744 .58887 .72233 .58989 Mtetra
.447 .879 .809 r
.72233 .58989 .72744 .58887 .73944 .58351 .73439 .58447 Mtetra
.479 .896 .819 r
.73439 .58447 .73944 .58351 .75145 .57781 .74646 .5787 Mtetra
.51 .911 .827 r
.74646 .5787 .75145 .57781 .76347 .57179 .75855 .57261 Mtetra
.539 .925 .835 r
.75855 .57261 .76347 .57179 .7755 .56544 .77065 .56618 Mtetra
.567 .938 .841 r
.77065 .56618 .7755 .56544 .78755 .55878 .78275 .55944 Mtetra
.593 .948 .847 r
.78275 .55944 .78755 .55878 .79959 .55182 .79486 .55238 Mtetra
.617 .958 .852 r
.79486 .55238 .79959 .55182 .81165 .54456 .80698 .54502 Mtetra
.64 .966 .856 r
.80698 .54502 .81165 .54456 .8237 .537 .81909 .53736 Mtetra
.661 .973 .86 r
.81909 .53736 .8237 .537 .83575 .52917 .83121 .52942 Mtetra
.681 .979 .863 r
.83121 .52942 .83575 .52917 .84779 .52107 .84332 .5212 Mtetra
.699 .984 .865 r
.84332 .5212 .84779 .52107 .85984 .51271 .85542 .51271 Mtetra
.716 .987 .867 r
.85542 .51271 .85984 .51271 .87187 .50411 .86752 .50398 Mtetra
.732 .99 .868 r
.86752 .50398 .87187 .50411 .8839 .49527 .87961 .495 Mtetra
.746 .992 .869 r
.87961 .495 .8839 .49527 .89592 .4862 .89168 .48579 Mtetra
.76 .994 .87 r
.89168 .48579 .89592 .4862 .90792 .47692 .90375 .47637 Mtetra
.772 .995 .871 r
.90375 .47637 .90792 .47692 .91992 .46745 .9158 .46675 Mtetra
.783 .995 .871 r
.9158 .46675 .91992 .46745 .9319 .45779 .92784 .45693 Mtetra
.793 .994 .872 r
.92784 .45693 .9319 .45779 .94387 .44795 .93987 .44694 Mtetra
.802 .994 .872 r
.93987 .44694 .94387 .44795 .95583 .43796 .95188 .43679 Mtetra
.346 0 0 r
.36634 .60154 .37295 .6023 .38315 .60533 .37656 .60469 Mtetra
.339 0 0 r
.37656 .60469 .38315 .60533 .39342 .60824 .38686 .60772 Mtetra
.331 0 0 r
.38686 .60772 .39342 .60824 .40378 .61103 .39724 .61062 Mtetra
.322 0 0 r
.39724 .61062 .40378 .61103 .41422 .61368 .40771 .61338 Mtetra
.311 0 0 r
.40771 .61338 .41422 .61368 .42474 .61618 .41826 .61598 Mtetra
.299 0 0 r
.41826 .61598 .42474 .61618 .43535 .61851 .42889 .61842 Mtetra
.285 0 0 r
.42889 .61842 .43535 .61851 .44603 .62066 .43961 .62067 Mtetra
.269 0 0 r
.43961 .62067 .44603 .62066 .4568 .62262 .45041 .62272 Mtetra
.252 0 0 r
.45041 .62272 .4568 .62262 .46764 .62436 .46129 .62457 Mtetra
.233 0 0 r
.46129 .62457 .46764 .62436 .47856 .62589 .47225 .62619 Mtetra
.212 0 0 r
.47225 .62619 .47856 .62589 .48956 .62719 .48329 .62757 Mtetra
.19 0 0 r
.48329 .62757 .48956 .62719 .50064 .62824 .49441 .62871 Mtetra
.166 0 0 r
.49441 .62871 .50064 .62824 .51179 .62904 .5056 .62958 Mtetra
.141 0 0 r
.5056 .62958 .51179 .62904 .52301 .62957 .51686 .63018 Mtetra
.114 0 0 r
.51686 .63018 .52301 .62957 .5343 .62982 .5282 .6305 Mtetra
.085 0 0 r
.5282 .6305 .5343 .62982 .54566 .62979 .53961 .63052 Mtetra
.055 0 0 r
.53961 .63052 .54566 .62979 .55709 .62945 .55108 .63024 Mtetra
.023 0 0 r
.55108 .63024 .55709 .62945 .56857 .62881 .56262 .62965 Mtetra
0 0 0 r
.56262 .62965 .56857 .62881 .58012 .62785 .57422 .62873 Mtetra
.57422 .62873 .58012 .62785 .59173 .62657 .58588 .62748 Mtetra
.58588 .62748 .59173 .62657 .60339 .62496 .59759 .6259 Mtetra
.115 .664 .699 r
.59759 .6259 .60339 .62496 .6151 .62302 .60936 .62398 Mtetra
.152 .691 .716 r
.60936 .62398 .6151 .62302 .62686 .62073 .62118 .6217 Mtetra
.189 .718 .732 r
.62118 .6217 .62686 .62073 .63867 .6181 .63305 .61908 Mtetra
.227 .745 .748 r
.63305 .61908 .63867 .6181 .65052 .61512 .64496 .6161 Mtetra
.264 .77 .763 r
.64496 .6161 .65052 .61512 .66241 .61179 .65691 .61276 Mtetra
.301 .794 .778 r
.65691 .61276 .66241 .61179 .67433 .60811 .66889 .60906 Mtetra
.338 .817 .791 r
.66889 .60906 .67433 .60811 .68629 .60408 .68091 .605 Mtetra
.374 .839 .804 r
.68091 .605 .68629 .60408 .69828 .5997 .69296 .60059 Mtetra
.409 .859 .815 r
.69296 .60059 .69828 .5997 .71029 .59497 .70504 .59582 Mtetra
.443 .878 .825 r
.70504 .59582 .71029 .59497 .72233 .58989 .71714 .59069 Mtetra
.475 .895 .834 r
.71714 .59069 .72233 .58989 .73439 .58447 .72926 .58521 Mtetra
.506 .911 .842 r
.72926 .58521 .73439 .58447 .74646 .5787 .7414 .57938 Mtetra
.536 .925 .849 r
.7414 .57938 .74646 .5787 .75855 .57261 .75355 .57322 Mtetra
.564 .937 .855 r
.75355 .57322 .75855 .57261 .77065 .56618 .76571 .56672 Mtetra
.591 .948 .86 r
.76571 .56672 .77065 .56618 .78275 .55944 .77788 .55989 Mtetra
.616 .958 .864 r
.77788 .55989 .78275 .55944 .79486 .55238 .79006 .55274 Mtetra
.639 .966 .868 r
.79006 .55274 .79486 .55238 .80698 .54502 .80224 .54527 Mtetra
.66 .973 .871 r
.80224 .54527 .80698 .54502 .81909 .53736 .81442 .53751 Mtetra
.681 .978 .873 r
.81442 .53751 .81909 .53736 .83121 .52942 .82659 .52945 Mtetra
.699 .983 .874 r
.82659 .52945 .83121 .52942 .84332 .5212 .83877 .52112 Mtetra
.716 .987 .875 r
.83877 .52112 .84332 .5212 .85542 .51271 .85093 .51251 Mtetra
.732 .99 .876 r
.85093 .51251 .85542 .51271 .86752 .50398 .86309 .50364 Mtetra
.747 .992 .876 r
.86309 .50364 .86752 .50398 .87961 .495 .87524 .49453 Mtetra
.76 .993 .877 r
.87524 .49453 .87961 .495 .89168 .48579 .88738 .48519 Mtetra
.772 .994 .876 r
.88738 .48519 .89168 .48579 .90375 .47637 .8995 .47562 Mtetra
.783 .994 .876 r
.8995 .47562 .90375 .47637 .9158 .46675 .91162 .46585 Mtetra
.793 .993 .876 r
.91162 .46585 .9158 .46675 .92784 .45693 .92372 .45589 Mtetra
.802 .992 .875 r
.92372 .45589 .92784 .45693 .93987 .44694 .9358 .44574 Mtetra
.811 .991 .875 r
.9358 .44574 .93987 .44694 .95188 .43679 .94787 .43543 Mtetra
.34 0 0 r
.35967 .6006 .36634 .60154 .37656 .60469 .3699 .60386 Mtetra
.333 0 0 r
.3699 .60386 .37656 .60469 .38686 .60772 .38023 .607 Mtetra
.325 0 0 r
.38023 .607 .38686 .60772 .39724 .61062 .39064 .61001 Mtetra
.315 0 0 r
.39064 .61001 .39724 .61062 .40771 .61338 .40113 .61287 Mtetra
.303 0 0 r
.40113 .61287 .40771 .61338 .41826 .61598 .41171 .61558 Mtetra
.29 0 0 r
.41171 .61558 .41826 .61598 .42889 .61842 .42237 .61812 Mtetra
.275 0 0 r
.42237 .61812 .42889 .61842 .43961 .62067 .43312 .62047 Mtetra
.258 0 0 r
.43312 .62047 .43961 .62067 .45041 .62272 .44396 .62262 Mtetra
.24 0 0 r
.44396 .62262 .45041 .62272 .46129 .62457 .45487 .62455 Mtetra
.22 0 0 r
.45487 .62455 .46129 .62457 .47225 .62619 .46587 .62626 Mtetra
.199 0 0 r
.46587 .62626 .47225 .62619 .48329 .62757 .47695 .62773 Mtetra
.175 0 0 r
.47695 .62773 .48329 .62757 .49441 .62871 .4881 .62895 Mtetra
.15 0 0 r
.4881 .62895 .49441 .62871 .5056 .62958 .49934 .62989 Mtetra
.123 0 0 r
.49934 .62989 .5056 .62958 .51686 .63018 .51065 .63057 Mtetra
.095 0 0 r
.51065 .63057 .51686 .63018 .5282 .6305 .52203 .63095 Mtetra
.065 0 0 r
.52203 .63095 .5282 .6305 .53961 .63052 .53348 .63103 Mtetra
.033 0 0 r
.53348 .63103 .53961 .63052 .55108 .63024 .54501 .6308 Mtetra
0 0 0 r
.54501 .6308 .55108 .63024 .56262 .62965 .55659 .63025 Mtetra
.55659 .63025 .56262 .62965 .57422 .62873 .56825 .62938 Mtetra
.56825 .62938 .57422 .62873 .58588 .62748 .57996 .62816 Mtetra
.106 .659 .716 r
.57996 .62816 .58588 .62748 .59759 .6259 .59173 .62661 Mtetra
.143 .687 .734 r
.59173 .62661 .59759 .6259 .60936 .62398 .60355 .6247 Mtetra
.181 .714 .75 r
.60355 .6247 .60936 .62398 .62118 .6217 .61543 .62244 Mtetra
.219 .741 .766 r
.61543 .62244 .62118 .6217 .63305 .61908 .62735 .61982 Mtetra
.257 .767 .781 r
.62735 .61982 .63305 .61908 .64496 .6161 .63932 .61684 Mtetra
.294 .791 .796 r
.63932 .61684 .64496 .6161 .65691 .61276 .65133 .61349 Mtetra
.332 .815 .809 r
.65133 .61349 .65691 .61276 .66889 .60906 .66337 .60977 Mtetra
.368 .837 .821 r
.66337 .60977 .66889 .60906 .68091 .605 .67546 .60569 Mtetra
.404 .858 .832 r
.67546 .60569 .68091 .605 .69296 .60059 .68757 .60124 Mtetra
.438 .877 .842 r
.68757 .60124 .69296 .60059 .70504 .59582 .69971 .59643 Mtetra
.471 .894 .851 r
.69971 .59643 .70504 .59582 .71714 .59069 .71187 .59125 Mtetra
.503 .91 .858 r
.71187 .59125 .71714 .59069 .72926 .58521 .72406 .58572 Mtetra
.533 .924 .865 r
.72406 .58572 .72926 .58521 .7414 .57938 .73626 .57983 Mtetra
.562 .936 .87 r
.73626 .57983 .7414 .57938 .75355 .57322 .74847 .57359 Mtetra
.589 .947 .874 r
.74847 .57359 .75355 .57322 .76571 .56672 .7607 .56701 Mtetra
.614 .957 .878 r
.7607 .56701 .76571 .56672 .77788 .55989 .77294 .5601 Mtetra
.638 .965 .88 r
.77294 .5601 .77788 .55989 .79006 .55274 .78518 .55286 Mtetra
.66 .972 .882 r
.78518 .55286 .79006 .55274 .80224 .54527 .79742 .5453 Mtetra
.68 .977 .884 r
.79742 .5453 .80224 .54527 .81442 .53751 .80966 .53743 Mtetra
.699 .982 .884 r
.80966 .53743 .81442 .53751 .82659 .52945 .8219 .52927 Mtetra
.716 .986 .885 r
.8219 .52927 .82659 .52945 .83877 .52112 .83414 .52081 Mtetra
.732 .988 .885 r
.83414 .52081 .83877 .52112 .85093 .51251 .84637 .51208 Mtetra
.747 .99 .884 r
.84637 .51208 .85093 .51251 .86309 .50364 .85859 .50309 Mtetra
.76 .991 .884 r
.85859 .50309 .86309 .50364 .87524 .49453 .8708 .49385 Mtetra
.773 .992 .883 r
.8708 .49385 .87524 .49453 .88738 .48519 .883 .48437 Mtetra
.784 .992 .882 r
.883 .48437 .88738 .48519 .8995 .47562 .89519 .47466 Mtetra
.794 .992 .881 r
.89519 .47466 .8995 .47562 .91162 .46585 .90736 .46474 Mtetra
.803 .991 .88 r
.90736 .46474 .91162 .46585 .92372 .45589 .91952 .45463 Mtetra
.812 .989 .879 r
.91952 .45463 .92372 .45589 .9358 .44574 .93166 .44433 Mtetra
.819 .988 .877 r
.93166 .44433 .9358 .44574 .94787 .43543 .94379 .43386 Mtetra
.334 0 0 r
.35293 .59946 .35967 .6006 .3699 .60386 .36319 .60282 Mtetra
.326 0 0 r
.36319 .60282 .3699 .60386 .38023 .607 .37354 .60607 Mtetra
.317 0 0 r
.37354 .60607 .38023 .607 .39064 .61001 .38397 .60918 Mtetra
.306 0 0 r
.38397 .60918 .39064 .61001 .40113 .61287 .39449 .61215 Mtetra
.293 0 0 r
.39449 .61215 .40113 .61287 .41171 .61558 .4051 .61496 Mtetra
.279 0 0 r
.4051 .61496 .41171 .61558 .42237 .61812 .41579 .6176 Mtetra
.263 0 0 r
.41579 .6176 .42237 .61812 .43312 .62047 .42657 .62004 Mtetra
.246 0 0 r
.42657 .62004 .43312 .62047 .44396 .62262 .43744 .62229 Mtetra
.227 0 0 r
.43744 .62229 .44396 .62262 .45487 .62455 .44839 .62431 Mtetra
.206 0 0 r
.44839 .62431 .45487 .62455 .46587 .62626 .45942 .62611 Mtetra
.183 0 0 r
.45942 .62611 .46587 .62626 .47695 .62773 .47054 .62766 Mtetra
.158 0 0 r
.47054 .62766 .47695 .62773 .4881 .62895 .48173 .62895 Mtetra
.132 0 0 r
.48173 .62895 .4881 .62895 .49934 .62989 .49301 .62997 Mtetra
.104 0 0 r
.49301 .62997 .49934 .62989 .51065 .63057 .50436 .63071 Mtetra
.074 0 0 r
.50436 .63071 .51065 .63057 .52203 .63095 .51579 .63115 Mtetra
.042 0 0 r
.51579 .63115 .52203 .63095 .53348 .63103 .52729 .63129 Mtetra
.01 0 0 r
.52729 .63129 .53348 .63103 .54501 .6308 .53886 .63111 Mtetra
0 0 0 r
.53886 .63111 .54501 .6308 .55659 .63025 .5505 .63061 Mtetra
.06 .625 .717 r
.5505 .63061 .55659 .63025 .56825 .62938 .5622 .62977 Mtetra
.097 .653 .735 r
.5622 .62977 .56825 .62938 .57996 .62816 .57396 .62859 Mtetra
.134 .682 .752 r
.57396 .62859 .57996 .62816 .59173 .62661 .58579 .62706 Mtetra
.172 .709 .768 r
.58579 .62706 .59173 .62661 .60355 .6247 .59767 .62517 Mtetra
.211 .736 .784 r
.59767 .62517 .60355 .6247 .61543 .62244 .6096 .62292 Mtetra
.249 .763 .8 r
.6096 .62292 .61543 .62244 .62735 .61982 .62158 .62031 Mtetra
.288 .788 .814 r
.62158 .62031 .62735 .61982 .63932 .61684 .6336 .61732 Mtetra
.325 .812 .827 r
.6336 .61732 .63932 .61684 .65133 .61349 .64567 .61396 Mtetra
.363 .834 .839 r
.64567 .61396 .65133 .61349 .66337 .60977 .65778 .61023 Mtetra
.399 .855 .85 r
.65778 .61023 .66337 .60977 .67546 .60569 .66992 .60612 Mtetra
.434 .874 .86 r
.66992 .60612 .67546 .60569 .68757 .60124 .6821 .60164 Mtetra
.468 .892 .868 r
.6821 .60164 .68757 .60124 .69971 .59643 .6943 .59679 Mtetra
.5 .908 .875 r
.6943 .59679 .69971 .59643 .71187 .59125 .70653 .59157 Mtetra
.53 .922 .881 r
.70653 .59157 .71187 .59125 .72406 .58572 .71877 .58598 Mtetra
.56 .935 .885 r
.71877 .58598 .72406 .58572 .73626 .57983 .73104 .58003 Mtetra
.587 .946 .889 r
.73104 .58003 .73626 .57983 .74847 .57359 .74332 .57372 Mtetra
.612 .955 .892 r
.74332 .57372 .74847 .57359 .7607 .56701 .75561 .56706 Mtetra
.636 .963 .894 r
.75561 .56706 .7607 .56701 .77294 .5601 .76791 .56007 Mtetra
.659 .97 .895 r
.76791 .56007 .77294 .5601 .78518 .55286 .78022 .55274 Mtetra
.679 .976 .896 r
.78022 .55274 .78518 .55286 .79742 .5453 .79252 .54508 Mtetra
.698 .98 .895 r
.79252 .54508 .79742 .5453 .80966 .53743 .80483 .53711 Mtetra
.716 .984 .895 r
.80483 .53711 .80966 .53743 .8219 .52927 .81714 .52884 Mtetra
.732 .986 .894 r
.81714 .52884 .8219 .52927 .83414 .52081 .82944 .52027 Mtetra
.747 .988 .893 r
.82944 .52027 .83414 .52081 .84637 .51208 .84173 .51142 Mtetra
.761 .989 .891 r
.84173 .51142 .84637 .51208 .85859 .50309 .85401 .5023 Mtetra
.773 .99 .89 r
.85401 .5023 .85859 .50309 .8708 .49385 .86629 .49293 Mtetra
.784 .99 .888 r
.86629 .49293 .8708 .49385 .883 .48437 .87855 .48331 Mtetra
.795 .989 .886 r
.87855 .48331 .883 .48437 .89519 .47466 .89079 .47347 Mtetra
.804 .988 .885 r
.89079 .47347 .89519 .47466 .90736 .46474 .90303 .46341 Mtetra
.812 .987 .883 r
.90303 .46341 .90736 .46474 .91952 .45463 .91524 .45315 Mtetra
.82 .985 .881 r
.91524 .45315 .91952 .45463 .93166 .44433 .92744 .4427 Mtetra
.827 .983 .879 r
.92744 .4427 .93166 .44433 .94379 .43386 .93963 .43208 Mtetra
.325 0 0 r
.34614 .5981 .35293 .59946 .36319 .60282 .35642 .60156 Mtetra
.317 0 0 r
.35642 .60156 .36319 .60282 .37354 .60607 .36679 .60492 Mtetra
.307 0 0 r
.36679 .60492 .37354 .60607 .38397 .60918 .37725 .60813 Mtetra
.295 0 0 r
.37725 .60813 .38397 .60918 .39449 .61215 .38779 .6112 Mtetra
.282 0 0 r
.38779 .6112 .39449 .61215 .4051 .61496 .39843 .61411 Mtetra
.267 0 0 r
.39843 .61411 .4051 .61496 .41579 .6176 .40915 .61684 Mtetra
.25 0 0 r
.40915 .61684 .41579 .6176 .42657 .62004 .41996 .61938 Mtetra
.231 0 0 r
.41996 .61938 .42657 .62004 .43744 .62229 .43086 .62171 Mtetra
.211 0 0 r
.43086 .62171 .43744 .62229 .44839 .62431 .44184 .62383 Mtetra
.189 0 0 r
.44184 .62383 .44839 .62431 .45942 .62611 .45291 .6257 Mtetra
.165 0 0 r
.45291 .6257 .45942 .62611 .47054 .62766 .46406 .62733 Mtetra
.139 0 0 r
.46406 .62733 .47054 .62766 .48173 .62895 .4753 .6287 Mtetra
.111 0 0 r
.4753 .6287 .48173 .62895 .49301 .62997 .48661 .62979 Mtetra
.082 0 0 r
.48661 .62979 .49301 .62997 .50436 .63071 .49801 .63059 Mtetra
.051 0 0 r
.49801 .63059 .50436 .63071 .51579 .63115 .50948 .6311 Mtetra
.018 0 0 r
.50948 .6311 .51579 .63115 .52729 .63129 .52102 .63129 Mtetra
.016 .591 .717 r
.52102 .63129 .52729 .63129 .53886 .63111 .53264 .63116 Mtetra
.052 .619 .735 r
.53264 .63116 .53886 .63111 .5505 .63061 .54433 .6307 Mtetra
.089 .647 .753 r
.54433 .6307 .5505 .63061 .5622 .62977 .55608 .6299 Mtetra
.126 .676 .77 r
.55608 .6299 .5622 .62977 .57396 .62859 .56789 .62875 Mtetra
.165 .704 .787 r
.56789 .62875 .57396 .62859 .58579 .62706 .57977 .62724 Mtetra
.203 .731 .803 r
.57977 .62724 .58579 .62706 .59767 .62517 .5917 .62537 Mtetra
.242 .758 .818 r
.5917 .62537 .59767 .62517 .6096 .62292 .60369 .62313 Mtetra
.281 .783 .833 r
.60369 .62313 .6096 .62292 .62158 .62031 .61573 .62052 Mtetra
.319 .807 .846 r
.61573 .62052 .62158 .62031 .6336 .61732 .62781 .61753 Mtetra
.357 .83 .858 r
.62781 .61753 .6336 .61732 .64567 .61396 .63994 .61416 Mtetra
.394 .852 .868 r
.63994 .61416 .64567 .61396 .65778 .61023 .65211 .61041 Mtetra
.429 .871 .877 r
.65211 .61041 .65778 .61023 .66992 .60612 .66431 .60628 Mtetra
.463 .889 .885 r
.66431 .60628 .66992 .60612 .6821 .60164 .67655 .60177 Mtetra
.496 .905 .892 r
.67655 .60177 .6821 .60164 .6943 .59679 .68881 .59687 Mtetra
.527 .919 .897 r
.68881 .59687 .6943 .59679 .70653 .59157 .7011 .5916 Mtetra
.557 .932 .901 r
.7011 .5916 .70653 .59157 .71877 .58598 .71341 .58596 Mtetra
.585 .943 .904 r
.71341 .58596 .71877 .58598 .73104 .58003 .72574 .57995 Mtetra
.611 .953 .906 r
.72574 .57995 .73104 .58003 .74332 .57372 .73809 .57357 Mtetra
.635 .961 .908 r
.73809 .57357 .74332 .57372 .75561 .56706 .75044 .56684 Mtetra
.657 .968 .908 r
.75044 .56684 .75561 .56706 .76791 .56007 .76281 .55976 Mtetra
.678 .973 .908 r
.76281 .55976 .76791 .56007 .78022 .55274 .77518 .55235 Mtetra
.698 .978 .907 r
.77518 .55235 .78022 .55274 .79252 .54508 .78755 .5446 Mtetra
.715 .981 .906 r
.78755 .5446 .79252 .54508 .80483 .53711 .79992 .53652 Mtetra
.732 .984 .904 r
.79992 .53652 .80483 .53711 .81714 .52884 .81229 .52814 Mtetra
.747 .986 .902 r
.81229 .52814 .81714 .52884 .82944 .52027 .82465 .51947 Mtetra
.76 .987 .9 r
.82465 .51947 .82944 .52027 .84173 .51142 .83701 .5105 Mtetra
.773 .987 .897 r
.83701 .5105 .84173 .51142 .85401 .5023 .84936 .50126 Mtetra
.784 .987 .895 r
.84936 .50126 .85401 .5023 .86629 .49293 .86169 .49176 Mtetra
.795 .986 .893 r
.86169 .49176 .86629 .49293 .87855 .48331 .87401 .48201 Mtetra
.804 .985 .89 r
.87401 .48201 .87855 .48331 .89079 .47347 .88632 .47203 Mtetra
.813 .984 .888 r
.88632 .47203 .89079 .47347 .90303 .46341 .89862 .46183 Mtetra
.82 .982 .885 r
.89862 .46183 .90303 .46341 .91524 .45315 .91089 .45143 Mtetra
.827 .98 .883 r
.91089 .45143 .91524 .45315 .92744 .4427 .92315 .44083 Mtetra
.833 .978 .881 r
.92315 .44083 .92744 .4427 .93963 .43208 .9354 .43006 Mtetra
.315 0 0 r
.3393 .59651 .34614 .5981 .35642 .60156 .3496 .60008 Mtetra
.306 0 0 r
.3496 .60008 .35642 .60156 .36679 .60492 .35999 .60353 Mtetra
.295 0 0 r
.35999 .60353 .36679 .60492 .37725 .60813 .37046 .60684 Mtetra
.283 0 0 r
.37046 .60684 .37725 .60813 .38779 .6112 .38103 .61001 Mtetra
.268 0 0 r
.38103 .61001 .38779 .6112 .39843 .61411 .39169 .61301 Mtetra
.252 0 0 r
.39169 .61301 .39843 .61411 .40915 .61684 .40244 .61583 Mtetra
.234 0 0 r
.40244 .61583 .40915 .61684 .41996 .61938 .41328 .61846 Mtetra
.215 0 0 r
.41328 .61846 .41996 .61938 .43086 .62171 .42421 .62088 Mtetra
.193 0 0 r
.42421 .62088 .43086 .62171 .44184 .62383 .43523 .62308 Mtetra
.17 0 0 r
.43523 .62308 .44184 .62383 .45291 .6257 .44633 .62503 Mtetra
.144 0 0 r
.44633 .62503 .45291 .6257 .46406 .62733 .45752 .62674 Mtetra
.117 0 0 r
.45752 .62674 .46406 .62733 .4753 .6287 .46879 .62817 Mtetra
.088 0 0 r
.46879 .62817 .4753 .6287 .48661 .62979 .48015 .62933 Mtetra
.057 0 0 r
.48015 .62933 .48661 .62979 .49801 .63059 .49158 .6302 Mtetra
0 .556 .718 r
.49158 .6302 .49801 .63059 .50948 .6311 .5031 .63076 Mtetra
.009 .584 .735 r
.5031 .63076 .50948 .6311 .52102 .63129 .51469 .63101 Mtetra
.044 .612 .753 r
.51469 .63101 .52102 .63129 .53264 .63116 .52635 .63092 Mtetra
.081 .641 .771 r
.52635 .63092 .53264 .63116 .54433 .6307 .53808 .63051 Mtetra
.119 .669 .789 r
.53808 .63051 .54433 .6307 .55608 .6299 .54988 .62974 Mtetra
.157 .697 .806 r
.54988 .62974 .55608 .6299 .56789 .62875 .56175 .62862 Mtetra
.196 .725 .822 r
.56175 .62862 .56789 .62875 .57977 .62724 .57368 .62713 Mtetra
.235 .752 .837 r
.57368 .62713 .57977 .62724 .5917 .62537 .58567 .62528 Mtetra
.274 .778 .851 r
.58567 .62528 .5917 .62537 .60369 .62313 .59771 .62305 Mtetra
.313 .802 .864 r
.59771 .62305 .60369 .62313 .61573 .62052 .6098 .62044 Mtetra
.351 .825 .876 r
.6098 .62044 .61573 .62052 .62781 .61753 .62194 .61745 Mtetra
.388 .847 .886 r
.62194 .61745 .62781 .61753 .63994 .61416 .63413 .61407 Mtetra
.424 .867 .895 r
.63413 .61407 .63994 .61416 .65211 .61041 .64636 .6103 Mtetra
.459 .885 .903 r
.64636 .6103 .65211 .61041 .66431 .60628 .65862 .60614 Mtetra
.492 .901 .909 r
.65862 .60614 .66431 .60628 .67655 .60177 .67092 .6016 Mtetra
.524 .915 .914 r
.67092 .6016 .67655 .60177 .68881 .59687 .68324 .59666 Mtetra
.554 .928 .917 r
.68324 .59666 .68881 .59687 .7011 .5916 .6956 .59135 Mtetra
.582 .939 .92 r
.6956 .59135 .7011 .5916 .71341 .58596 .70797 .58565 Mtetra
.608 .949 .921 r
.70797 .58565 .71341 .58596 .72574 .57995 .72037 .57958 Mtetra
.633 .957 .921 r
.72037 .57958 .72574 .57995 .73809 .57357 .73277 .57314 Mtetra
.655 .964 .921 r
.73277 .57314 .73809 .57357 .75044 .56684 .74519 .56634 Mtetra
.677 .97 .92 r
.74519 .56634 .75044 .56684 .76281 .55976 .75762 .55918 Mtetra
.696 .974 .919 r
.75762 .55918 .76281 .55976 .77518 .55235 .77006 .55167 Mtetra
.714 .978 .916 r
.77006 .55167 .77518 .55235 .78755 .5446 .78249 .54383 Mtetra
.731 .98 .914 r
.78249 .54383 .78755 .5446 .79992 .53652 .79493 .53566 Mtetra
.746 .982 .911 r
.79493 .53566 .79992 .53652 .81229 .52814 .80736 .52717 Mtetra
.76 .983 .908 r
.80736 .52717 .81229 .52814 .82465 .51947 .81979 .51839 Mtetra
.772 .983 .905 r
.81979 .51839 .82465 .51947 .83701 .5105 .83221 .50931 Mtetra
.784 .983 .902 r
.83221 .50931 .83701 .5105 .84936 .50126 .84462 .49995 Mtetra
.794 .982 .899 r
.84462 .49995 .84936 .50126 .86169 .49176 .85702 .49032 Mtetra
.804 .981 .896 r
.85702 .49032 .86169 .49176 .87401 .48201 .8694 .48045 Mtetra
.812 .98 .893 r
.8694 .48045 .87401 .48201 .88632 .47203 .88177 .47033 Mtetra
.82 .979 .89 r
.88177 .47033 .88632 .47203 .89862 .46183 .89413 .46 Mtetra
.827 .977 .887 r
.89413 .46 .89862 .46183 .91089 .45143 .90646 .44945 Mtetra
.833 .974 .884 r
.90646 .44945 .91089 .45143 .92315 .44083 .91878 .43871 Mtetra
.839 .972 .882 r
.91878 .43871 .92315 .44083 .9354 .43006 .93109 .4278 Mtetra
.303 0 0 r
.3324 .59468 .3393 .59651 .3496 .60008 .34271 .59835 Mtetra
.293 0 0 r
.34271 .59835 .3496 .60008 .35999 .60353 .35312 .60189 Mtetra
.281 0 0 r
.35312 .60189 .35999 .60353 .37046 .60684 .36362 .6053 Mtetra
.268 0 0 r
.36362 .6053 .37046 .60684 .38103 .61001 .37422 .60856 Mtetra
.253 0 0 r
.37422 .60856 .38103 .61001 .39169 .61301 .3849 .61165 Mtetra
.236 0 0 r
.3849 .61165 .39169 .61301 .40244 .61583 .39568 .61456 Mtetra
.217 0 0 r
.39568 .61456 .40244 .61583 .41328 .61846 .40654 .61727 Mtetra
.196 0 0 r
.40654 .61727 .41328 .61846 .42421 .62088 .4175 .61978 Mtetra
.173 0 0 r
.4175 .61978 .42421 .62088 .43523 .62308 .42855 .62205 Mtetra
.149 0 0 r
.42855 .62205 .43523 .62308 .44633 .62503 .43969 .62408 Mtetra
.122 0 0 r
.43969 .62408 .44633 .62503 .45752 .62674 .45091 .62586 Mtetra
.094 0 0 r
.45091 .62586 .45752 .62674 .46879 .62817 .46222 .62736 Mtetra
0 .522 .718 r
.46222 .62736 .46879 .62817 .48015 .62933 .47361 .62859 Mtetra
0 .549 .735 r
.47361 .62859 .48015 .62933 .49158 .6302 .48509 .62951 Mtetra
.003 .577 .753 r
.48509 .62951 .49158 .6302 .5031 .63076 .49664 .63013 Mtetra
.038 .605 .771 r
.49664 .63013 .5031 .63076 .51469 .63101 .50828 .63042 Mtetra
.074 .633 .789 r
.50828 .63042 .51469 .63101 .52635 .63092 .51999 .63039 Mtetra
.112 .662 .807 r
.51999 .63039 .52635 .63092 .53808 .63051 .53177 .63001 Mtetra
.15 .69 .823 r
.53177 .63001 .53808 .63051 .54988 .62974 .54362 .62928 Mtetra
.189 .718 .84 r
.54362 .62928 .54988 .62974 .56175 .62862 .55553 .62818 Mtetra
.228 .745 .855 r
.55553 .62818 .56175 .62862 .57368 .62713 .56751 .62672 Mtetra
.268 .771 .869 r
.56751 .62672 .57368 .62713 .58567 .62528 .57955 .62488 Mtetra
.307 .795 .882 r
.57955 .62488 .58567 .62528 .59771 .62305 .59165 .62266 Mtetra
.345 .819 .894 r
.59165 .62266 .59771 .62305 .6098 .62044 .6038 .62005 Mtetra
.382 .84 .904 r
.6038 .62005 .6098 .62044 .62194 .61745 .616 .61705 Mtetra
.419 .86 .912 r
.616 .61705 .62194 .61745 .63413 .61407 .62824 .61366 Mtetra
.454 .879 .919 r
.62824 .61366 .63413 .61407 .64636 .6103 .64053 .60988 Mtetra
.488 .895 .925 r
.64053 .60988 .64636 .6103 .65862 .60614 .65285 .60569 Mtetra
.519 .91 .929 r
.65285 .60569 .65862 .60614 .67092 .6016 .66521 .60112 Mtetra
.55 .923 .932 r
.66521 .60112 .67092 .6016 .68324 .59666 .6776 .59614 Mtetra
.578 .934 .934 r
.6776 .59614 .68324 .59666 .6956 .59135 .69001 .59078 Mtetra
.605 .944 .935 r
.69001 .59078 .6956 .59135 .70797 .58565 .70245 .58503 Mtetra
.63 .952 .935 r
.70245 .58503 .70797 .58565 .72037 .57958 .71491 .5789 Mtetra
.653 .959 .934 r
.71491 .5789 .72037 .57958 .73277 .57314 .72738 .5724 Mtetra
.674 .965 .932 r
.72738 .5724 .73277 .57314 .74519 .56634 .73986 .56552 Mtetra
.694 .969 .93 r
.73986 .56552 .74519 .56634 .75762 .55918 .75236 .55828 Mtetra
.712 .973 .927 r
.75236 .55828 .75762 .55918 .77006 .55167 .76486 .55069 Mtetra
.729 .975 .924 r
.76486 .55069 .77006 .55167 .78249 .54383 .77736 .54276 Mtetra
.744 .977 .921 r
.77736 .54276 .78249 .54383 .79493 .53566 .78986 .53449 Mtetra
.758 .978 .917 r
.78986 .53449 .79493 .53566 .80736 .52717 .80235 .52591 Mtetra
.771 .978 .913 r
.80235 .52591 .80736 .52717 .81979 .51839 .81485 .51701 Mtetra
.783 .978 .91 r
.81485 .51701 .81979 .51839 .83221 .50931 .82733 .50782 Mtetra
.793 .978 .906 r
.82733 .50782 .83221 .50931 .84462 .49995 .8398 .49834 Mtetra
.803 .977 .902 r
.8398 .49834 .84462 .49995 .85702 .49032 .85226 .4886 Mtetra
.812 .975 .898 r
.85226 .4886 .85702 .49032 .8694 .48045 .86471 .4786 Mtetra
.82 .974 .895 r
.86471 .4786 .8694 .48045 .88177 .47033 .87714 .46835 Mtetra
.827 .972 .891 r
.87714 .46835 .88177 .47033 .89413 .46 .88956 .45788 Mtetra
.833 .97 .888 r
.88956 .45788 .89413 .46 .90646 .44945 .90196 .4472 Mtetra
.839 .968 .885 r
.90196 .4472 .90646 .44945 .91878 .43871 .91434 .43632 Mtetra
.844 .965 .882 r
.91434 .43632 .91878 .43871 .93109 .4278 .9267 .42527 Mtetra
.289 0 0 r
.32544 .5926 .3324 .59468 .34271 .59835 .33577 .59636 Mtetra
.278 0 0 r
.33577 .59636 .34271 .59835 .35312 .60189 .3462 .59999 Mtetra
.266 0 0 r
.3462 .59999 .35312 .60189 .36362 .6053 .35672 .60349 Mtetra
.252 0 0 r
.35672 .60349 .36362 .6053 .37422 .60856 .36734 .60684 Mtetra
.235 0 0 r
.36734 .60684 .37422 .60856 .3849 .61165 .37805 .61001 Mtetra
.217 0 0 r
.37805 .61001 .3849 .61165 .39568 .61456 .38885 .61301 Mtetra
.197 0 0 r
.38885 .61301 .39568 .61456 .40654 .61727 .39974 .6158 Mtetra
.175 0 0 r
.39974 .6158 .40654 .61727 .4175 .61978 .41073 .61838 Mtetra
.151 0 0 r
.41073 .61838 .4175 .61978 .42855 .62205 .42181 .62073 Mtetra
0 .465 .702 r
.42181 .62073 .42855 .62205 .43969 .62408 .43298 .62283 Mtetra
0 .489 .718 r
.43298 .62283 .43969 .62408 .45091 .62586 .44424 .62468 Mtetra
0 .515 .735 r
.44424 .62468 .45091 .62586 .46222 .62736 .45558 .62625 Mtetra
0 .542 .752 r
.45558 .62625 .46222 .62736 .47361 .62859 .46701 .62753 Mtetra
0 .569 .77 r
.46701 .62753 .47361 .62859 .48509 .62951 .47853 .62852 Mtetra
.032 .597 .788 r
.47853 .62852 .48509 .62951 .49664 .63013 .49013 .62918 Mtetra
.068 .625 .806 r
.49013 .62918 .49664 .63013 .50828 .63042 .5018 .62953 Mtetra
.105 .653 .824 r
.5018 .62953 .50828 .63042 .51999 .63039 .51355 .62953 Mtetra
.144 .681 .84 r
.51355 .62953 .51999 .63039 .53177 .63001 .52538 .62919 Mtetra
.182 .709 .857 r
.52538 .62919 .53177 .63001 .54362 .62928 .53728 .62849 Mtetra
.222 .736 .872 r
.53728 .62849 .54362 .62928 .55553 .62818 .54925 .62742 Mtetra
.261 .762 .886 r
.54925 .62742 .55553 .62818 .56751 .62672 .56128 .62598 Mtetra
.3 .787 .899 r
.56128 .62598 .56751 .62672 .57955 .62488 .57337 .62415 Mtetra
.339 .81 .91 r
.57337 .62415 .57955 .62488 .59165 .62266 .58552 .62194 Mtetra
.376 .832 .92 r
.58552 .62194 .59165 .62266 .6038 .62005 .59772 .61933 Mtetra
.413 .852 .928 r
.59772 .61933 .6038 .62005 .616 .61705 .60998 .61633 Mtetra
.448 .871 .935 r
.60998 .61633 .616 .61705 .62824 .61366 .62228 .61292 Mtetra
.482 .888 .94 r
.62228 .61292 .62824 .61366 .64053 .60988 .63462 .60912 Mtetra
.514 .902 .944 r
.63462 .60912 .64053 .60988 .65285 .60569 .647 .60491 Mtetra
.545 .916 .947 r
.647 .60491 .65285 .60569 .66521 .60112 .65942 .6003 Mtetra
.574 .927 .948 r
.65942 .6003 .66521 .60112 .6776 .59614 .67187 .59529 Mtetra
.601 .937 .949 r
.67187 .59529 .6776 .59614 .69001 .59078 .68435 .58989 Mtetra
.626 .945 .948 r
.68435 .58989 .69001 .59078 .70245 .58503 .69685 .58409 Mtetra
.649 .952 .946 r
.69685 .58409 .70245 .58503 .71491 .5789 .70937 .5779 Mtetra
.671 .958 .944 r
.70937 .5779 .71491 .5789 .72738 .5724 .7219 .57133 Mtetra
.691 .963 .941 r
.7219 .57133 .72738 .5724 .73986 .56552 .73445 .56438 Mtetra
.709 .966 .938 r
.73445 .56438 .73986 .56552 .75236 .55828 .74701 .55707 Mtetra
.726 .969 .934 r
.74701 .55707 .75236 .55828 .76486 .55069 .75957 .54939 Mtetra
.742 .971 .93 r
.75957 .54939 .76486 .55069 .77736 .54276 .77214 .54137 Mtetra
.756 .972 .926 r
.77214 .54137 .77736 .54276 .78986 .53449 .7847 .53301 Mtetra
.769 .972 .921 r
.7847 .53301 .78986 .53449 .80235 .52591 .79726 .52433 Mtetra
.781 .972 .917 r
.79726 .52433 .80235 .52591 .81485 .51701 .80982 .51533 Mtetra
.792 .972 .912 r
.80982 .51533 .81485 .51701 .82733 .50782 .82237 .50603 Mtetra
.801 .971 .908 r
.82237 .50603 .82733 .50782 .8398 .49834 .8349 .49644 Mtetra
.81 .97 .904 r
.8349 .49644 .8398 .49834 .85226 .4886 .84743 .48657 Mtetra
.818 .968 .899 r
.84743 .48657 .85226 .4886 .86471 .4786 .85994 .47645 Mtetra
.825 .966 .895 r
.85994 .47645 .86471 .4786 .87714 .46835 .87243 .46608 Mtetra
.832 .964 .892 r
.87243 .46608 .87714 .46835 .88956 .45788 .88491 .45548 Mtetra
.838 .962 .888 r
.88491 .45548 .88956 .45788 .90196 .4472 .89737 .44467 Mtetra
.843 .96 .885 r
.89737 .44467 .90196 .4472 .91434 .43632 .90981 .43365 Mtetra
.848 .958 .881 r
.90981 .43365 .91434 .43632 .9267 .42527 .92223 .42246 Mtetra
.273 0 0 r
.31843 .59025 .32544 .5926 .33577 .59636 .32878 .5941 Mtetra
.262 0 0 r
.32878 .5941 .33577 .59636 .3462 .59999 .33923 .59782 Mtetra
.248 0 0 r
.33923 .59782 .3462 .59999 .35672 .60349 .34977 .6014 Mtetra
.233 0 0 r
.34977 .6014 .35672 .60349 .36734 .60684 .3604 .60483 Mtetra
.216 0 0 r
.3604 .60483 .36734 .60684 .37805 .61001 .37114 .60808 Mtetra
.197 0 0 r
.37114 .60808 .37805 .61001 .38885 .61301 .38196 .61116 Mtetra
0 .415 .689 r
.38196 .61116 .38885 .61301 .39974 .6158 .39288 .61403 Mtetra
0 .436 .703 r
.39288 .61403 .39974 .6158 .41073 .61838 .4039 .61668 Mtetra
0 .459 .719 r
.4039 .61668 .41073 .61838 .42181 .62073 .41501 .6191 Mtetra
0 .483 .735 r
.41501 .6191 .42181 .62073 .43298 .62283 .42621 .62127 Mtetra
0 .508 .751 r
.42621 .62127 .43298 .62283 .44424 .62468 .4375 .62318 Mtetra
0 .534 .769 r
.4375 .62318 .44424 .62468 .45558 .62625 .44888 .62482 Mtetra
0 .56 .786 r
.44888 .62482 .45558 .62625 .46701 .62753 .46035 .62616 Mtetra
.027 .588 .804 r
.46035 .62616 .46701 .62753 .47853 .62852 .4719 .62719 Mtetra
.063 .616 .822 r
.4719 .62719 .47853 .62852 .49013 .62918 .48354 .62791 Mtetra
.099 .644 .839 r
.48354 .62791 .49013 .62918 .5018 .62953 .49526 .6283 Mtetra
.137 .672 .856 r
.49526 .6283 .5018 .62953 .51355 .62953 .50705 .62834 Mtetra
.176 .699 .872 r
.50705 .62834 .51355 .62953 .52538 .62919 .51892 .62803 Mtetra
.215 .726 .887 r
.51892 .62803 .52538 .62919 .53728 .62849 .53087 .62736 Mtetra
.254 .752 .901 r
.53087 .62736 .53728 .62849 .54925 .62742 .54288 .62631 Mtetra
.293 .777 .914 r
.54288 .62631 .54925 .62742 .56128 .62598 .55496 .62489 Mtetra
.332 .8 .925 r
.55496 .62489 .56128 .62598 .57337 .62415 .56711 .62308 Mtetra
.37 .822 .935 r
.56711 .62308 .57337 .62415 .58552 .62194 .57931 .62087 Mtetra
.406 .843 .943 r
.57931 .62087 .58552 .62194 .59772 .61933 .59157 .61826 Mtetra
.442 .861 .949 r
.59157 .61826 .59772 .61933 .60998 .61633 .60388 .61525 Mtetra
.476 .878 .954 r
.60388 .61525 .60998 .61633 .62228 .61292 .61623 .61184 Mtetra
.509 .893 .958 r
.61623 .61184 .62228 .61292 .63462 .60912 .62863 .60801 Mtetra
.539 .907 .96 r
.62863 .60801 .63462 .60912 .647 .60491 .64108 .60378 Mtetra
.568 .918 .961 r
.64108 .60378 .647 .60491 .65942 .6003 .65355 .59914 Mtetra
.596 .928 .961 r
.65355 .59914 .65942 .6003 .67187 .59529 .66606 .59409 Mtetra
.621 .937 .96 r
.66606 .59409 .67187 .59529 .68435 .58989 .6786 .58864 Mtetra
.645 .944 .958 r
.6786 .58864 .68435 .58989 .69685 .58409 .69116 .58279 Mtetra
.667 .95 .955 r
.69116 .58279 .69685 .58409 .70937 .5779 .70374 .57655 Mtetra
.687 .955 .951 r
.70374 .57655 .70937 .5779 .7219 .57133 .71634 .56991 Mtetra
.706 .958 .947 r
.71634 .56991 .7219 .57133 .73445 .56438 .72895 .5629 Mtetra
.723 .961 .943 r
.72895 .5629 .73445 .56438 .74701 .55707 .74157 .55551 Mtetra
.738 .963 .938 r
.74157 .55551 .74701 .55707 .75957 .54939 .7542 .54776 Mtetra
.753 .964 .934 r
.7542 .54776 .75957 .54939 .77214 .54137 .76683 .53965 Mtetra
.766 .965 .929 r
.76683 .53965 .77214 .54137 .7847 .53301 .77946 .5312 Mtetra
.778 .965 .924 r
.77946 .5312 .7847 .53301 .79726 .52433 .79209 .52242 Mtetra
.789 .965 .919 r
.79209 .52242 .79726 .52433 .80982 .51533 .80471 .51332 Mtetra
.799 .964 .914 r
.80471 .51332 .80982 .51533 .82237 .50603 .81732 .50391 Mtetra
.808 .963 .909 r
.81732 .50391 .82237 .50603 .8349 .49644 .82992 .49421 Mtetra
.816 .962 .904 r
.82992 .49421 .8349 .49644 .84743 .48657 .84251 .48423 Mtetra
.823 .96 .9 r
.84251 .48423 .84743 .48657 .85994 .47645 .85508 .47399 Mtetra
.83 .958 .895 r
.85508 .47399 .85994 .47645 .87243 .46608 .86764 .4635 Mtetra
.836 .956 .891 r
.86764 .4635 .87243 .46608 .88491 .45548 .88017 .45277 Mtetra
.842 .954 .887 r
.88017 .45277 .88491 .45548 .89737 .44467 .89269 .44183 Mtetra
.846 .952 .884 r
.89269 .44183 .89737 .44467 .90981 .43365 .9052 .43068 Mtetra
.851 .949 .88 r
.9052 .43068 .90981 .43365 .92223 .42246 .91768 .41935 Mtetra
.256 0 0 r
.31136 .58763 .31843 .59025 .32878 .5941 .32173 .59155 Mtetra
.243 0 0 r
.32173 .59155 .32878 .5941 .33923 .59782 .3322 .59535 Mtetra
0 .358 .671 r
.3322 .59535 .33923 .59782 .34977 .6014 .34276 .59901 Mtetra
0 .374 .682 r
.34276 .59901 .34977 .6014 .3604 .60483 .35342 .60252 Mtetra
0 .392 .693 r
.35342 .60252 .3604 .60483 .37114 .60808 .36417 .60585 Mtetra
0 .41 .706 r
.36417 .60585 .37114 .60808 .38196 .61116 .37502 .609 Mtetra
0 .431 .72 r
.37502 .609 .38196 .61116 .39288 .61403 .38597 .61194 Mtetra
0 .453 .735 r
.38597 .61194 .39288 .61403 .4039 .61668 .39701 .61466 Mtetra
0 .476 .75 r
.39701 .61466 .4039 .61668 .41501 .6191 .40814 .61715 Mtetra
0 .5 .767 r
.40814 .61715 .41501 .6191 .42621 .62127 .41938 .61939 Mtetra
0 .525 .784 r
.41938 .61939 .42621 .62127 .4375 .62318 .4307 .62136 Mtetra
0 .552 .801 r
.4307 .62136 .4375 .62318 .44888 .62482 .44211 .62305 Mtetra
.023 .578 .819 r
.44211 .62305 .44888 .62482 .46035 .62616 .45362 .62444 Mtetra
.058 .606 .836 r
.45362 .62444 .46035 .62616 .4719 .62719 .46521 .62552 Mtetra
.094 .633 .854 r
.46521 .62552 .4719 .62719 .48354 .62791 .47688 .62629 Mtetra
.132 .661 .87 r
.47688 .62629 .48354 .62791 .49526 .6283 .48864 .62671 Mtetra
.17 .688 .886 r
.48864 .62671 .49526 .6283 .50705 .62834 .50048 .62679 Mtetra
.209 .715 .901 r
.50048 .62679 .50705 .62834 .51892 .62803 .5124 .62652 Mtetra
.247 .74 .915 r
.5124 .62652 .51892 .62803 .53087 .62736 .52439 .62587 Mtetra
.286 .765 .927 r
.52439 .62587 .53087 .62736 .54288 .62631 .53645 .62485 Mtetra
.325 .788 .938 r
.53645 .62485 .54288 .62631 .55496 .62489 .54858 .62344 Mtetra
.362 .81 .948 r
.54858 .62344 .55496 .62489 .56711 .62308 .56077 .62164 Mtetra
.399 .831 .956 r
.56077 .62164 .56711 .62308 .57931 .62087 .57302 .61943 Mtetra
.435 .85 .962 r
.57302 .61943 .57931 .62087 .59157 .61826 .58533 .61683 Mtetra
.469 .867 .967 r
.58533 .61683 .59157 .61826 .60388 .61525 .5977 .61381 Mtetra
.502 .882 .97 r
.5977 .61381 .60388 .61525 .61623 .61184 .61011 .61038 Mtetra
.533 .895 .972 r
.61011 .61038 .61623 .61184 .62863 .60801 .62257 .60654 Mtetra
.562 .907 .972 r
.62257 .60654 .62863 .60801 .64108 .60378 .63507 .60228 Mtetra
.589 .918 .972 r
.63507 .60228 .64108 .60378 .65355 .59914 .6476 .59761 Mtetra
.615 .926 .97 r
.6476 .59761 .65355 .59914 .66606 .59409 .66017 .59252 Mtetra
.639 .934 .968 r
.66017 .59252 .66606 .59409 .6786 .58864 .67277 .58703 Mtetra
.661 .94 .964 r
.67277 .58703 .6786 .58864 .69116 .58279 .68539 .58113 Mtetra
.682 .945 .96 r
.68539 .58113 .69116 .58279 .70374 .57655 .69804 .57483 Mtetra
.701 .949 .956 r
.69804 .57483 .70374 .57655 .71634 .56991 .7107 .56814 Mtetra
.718 .952 .951 r
.7107 .56814 .71634 .56991 .72895 .5629 .72337 .56105 Mtetra
.734 .954 .946 r
.72337 .56105 .72895 .5629 .74157 .55551 .73606 .55359 Mtetra
.749 .955 .941 r
.73606 .55359 .74157 .55551 .7542 .54776 .74875 .54576 Mtetra
.762 .956 .935 r
.74875 .54576 .7542 .54776 .76683 .53965 .76144 .53757 Mtetra
.774 .957 .93 r
.76144 .53757 .76683 .53965 .77946 .5312 .77414 .52903 Mtetra
.785 .956 .925 r
.77414 .52903 .77946 .5312 .79209 .52242 .78682 .52016 Mtetra
.796 .956 .919 r
.78682 .52016 .79209 .52242 .80471 .51332 .79951 .51096 Mtetra
.805 .955 .914 r
.79951 .51096 .80471 .51332 .81732 .50391 .81218 .50145 Mtetra
.813 .954 .909 r
.81218 .50145 .81732 .50391 .82992 .49421 .82485 .49164 Mtetra
.821 .952 .904 r
.82485 .49164 .82992 .49421 .84251 .48423 .8375 .48155 Mtetra
.828 .951 .899 r
.8375 .48155 .84251 .48423 .85508 .47399 .85014 .4712 Mtetra
.834 .949 .895 r
.85014 .4712 .85508 .47399 .86764 .4635 .86275 .46059 Mtetra
.839 .947 .89 r
.86275 .46059 .86764 .4635 .88017 .45277 .87536 .44974 Mtetra
.844 .945 .886 r
.87536 .44974 .88017 .45277 .89269 .44183 .88794 .43867 Mtetra
.849 .943 .882 r
.88794 .43867 .89269 .44183 .9052 .43068 .9005 .4274 Mtetra
.853 .941 .879 r
.9005 .4274 .9052 .43068 .91768 .41935 .91304 .41594 Mtetra
0 .344 .681 r
.30425 .58472 .31136 .58763 .32173 .59155 .31463 .58872 Mtetra
0 .357 .689 r
.31463 .58872 .32173 .59155 .3322 .59535 .32512 .59259 Mtetra
0 .372 .699 r
.32512 .59259 .3322 .59535 .34276 .59901 .33569 .59633 Mtetra
0 .388 .71 r
.33569 .59633 .34276 .59901 .35342 .60252 .34637 .5999 Mtetra
0 .406 .722 r
.34637 .5999 .35342 .60252 .36417 .60585 .35715 .6033 Mtetra
0 .426 .735 r
.35715 .6033 .36417 .60585 .37502 .609 .36802 .60652 Mtetra
0 .447 .75 r
.36802 .60652 .37502 .609 .38597 .61194 .37899 .60953 Mtetra
0 .469 .765 r
.37899 .60953 .38597 .61194 .39701 .61466 .39006 .61231 Mtetra
0 .492 .781 r
.39006 .61231 .39701 .61466 .40814 .61715 .40122 .61486 Mtetra
0 .517 .798 r
.40122 .61486 .40814 .61715 .41938 .61939 .41248 .61716 Mtetra
0 .542 .815 r
.41248 .61716 .41938 .61939 .4307 .62136 .42384 .61918 Mtetra
.02 .568 .832 r
.42384 .61918 .4307 .62136 .44211 .62305 .43528 .62092 Mtetra
.054 .595 .849 r
.43528 .62092 .44211 .62305 .45362 .62444 .44682 .62237 Mtetra
.09 .622 .866 r
.44682 .62237 .45362 .62444 .46521 .62552 .45845 .6235 Mtetra
.126 .649 .882 r
.45845 .6235 .46521 .62552 .47688 .62629 .47016 .6243 Mtetra
.164 .675 .898 r
.47016 .6243 .47688 .62629 .48864 .62671 .48196 .62477 Mtetra
.202 .702 .913 r
.48196 .62477 .48864 .62671 .50048 .62679 .49384 .62488 Mtetra
.241 .727 .926 r
.49384 .62488 .50048 .62679 .5124 .62652 .5058 .62463 Mtetra
.279 .752 .939 r
.5058 .62463 .5124 .62652 .52439 .62587 .51783 .62401 Mtetra
.317 .775 .949 r
.51783 .62401 .52439 .62587 .53645 .62485 .52994 .62301 Mtetra
.355 .797 .959 r
.52994 .62301 .53645 .62485 .54858 .62344 .54212 .62161 Mtetra
.391 .817 .966 r
.54212 .62161 .54858 .62344 .56077 .62164 .55436 .61982 Mtetra
.427 .836 .973 r
.55436 .61982 .56077 .62164 .57302 .61943 .56666 .61762 Mtetra
.461 .853 .977 r
.56666 .61762 .57302 .61943 .58533 .61683 .57903 .61501 Mtetra
.494 .869 .98 r
.57903 .61501 .58533 .61683 .5977 .61381 .59144 .61198 Mtetra
.525 .882 .982 r
.59144 .61198 .5977 .61381 .61011 .61038 .60391 .60854 Mtetra
.554 .894 .982 r
.60391 .60854 .61011 .61038 .62257 .60654 .61643 .60468 Mtetra
.582 .905 .981 r
.61643 .60468 .62257 .60654 .63507 .60228 .62898 .60039 Mtetra
.608 .914 .979 r
.62898 .60039 .63507 .60228 .6476 .59761 .64158 .59569 Mtetra
.632 .922 .976 r
.64158 .59569 .6476 .59761 .66017 .59252 .6542 .59057 Mtetra
.654 .928 .973 r
.6542 .59057 .66017 .59252 .67277 .58703 .66686 .58504 Mtetra
.675 .933 .968 r
.66686 .58504 .67277 .58703 .68539 .58113 .67955 .57909 Mtetra
.694 .938 .964 r
.67955 .57909 .68539 .58113 .69804 .57483 .69225 .57273 Mtetra
.712 .941 .959 r
.69225 .57273 .69804 .57483 .7107 .56814 .70497 .56598 Mtetra
.728 .943 .953 r
.70497 .56598 .7107 .56814 .72337 .56105 .71771 .55883 Mtetra
.743 .945 .947 r
.71771 .55883 .72337 .56105 .73606 .55359 .73046 .5513 Mtetra
.757 .946 .942 r
.73046 .5513 .73606 .55359 .74875 .54576 .74321 .5434 Mtetra
.769 .947 .936 r
.74321 .5434 .74875 .54576 .76144 .53757 .75597 .53513 Mtetra
.781 .947 .93 r
.75597 .53513 .76144 .53757 .77414 .52903 .76872 .5265 Mtetra
.791 .947 .924 r
.76872 .5265 .77414 .52903 .78682 .52016 .78148 .51754 Mtetra
.801 .946 .919 r
.78148 .51754 .78682 .52016 .79951 .51096 .79423 .50824 Mtetra
.809 .945 .913 r
.79423 .50824 .79951 .51096 .81218 .50145 .80696 .49864 Mtetra
.817 .944 .908 r
.80696 .49864 .81218 .50145 .82485 .49164 .81969 .48873 Mtetra
.824 .942 .903 r
.81969 .48873 .82485 .49164 .8375 .48155 .83241 .47853 Mtetra
.83 .941 .898 r
.83241 .47853 .8375 .48155 .85014 .4712 .84511 .46806 Mtetra
.836 .939 .893 r
.84511 .46806 .85014 .4712 .86275 .46059 .85779 .45734 Mtetra
.841 .937 .889 r
.85779 .45734 .86275 .46059 .87536 .44974 .87045 .44638 Mtetra
.846 .935 .884 r
.87045 .44638 .87536 .44974 .88794 .43867 .8831 .43519 Mtetra
.85 .933 .88 r
.8831 .43519 .88794 .43867 .9005 .4274 .89572 .42379 Mtetra
.854 .931 .877 r
.89572 .42379 .9005 .4274 .91304 .41594 .90832 .41221 Mtetra
0 .357 .706 r
.29709 .58151 .30425 .58472 .31463 .58872 .30749 .58558 Mtetra
0 .37 .715 r
.30749 .58558 .31463 .58872 .32512 .59259 .31798 .58952 Mtetra
0 .386 .726 r
.31798 .58952 .32512 .59259 .33569 .59633 .32858 .59332 Mtetra
0 .403 .737 r
.32858 .59332 .33569 .59633 .34637 .5999 .33927 .59696 Mtetra
0 .421 .75 r
.33927 .59696 .34637 .5999 .35715 .6033 .35007 .60043 Mtetra
0 .441 .764 r
.35007 .60043 .35715 .6033 .36802 .60652 .36096 .6037 Mtetra
0 .462 .779 r
.36096 .6037 .36802 .60652 .37899 .60953 .37196 .60677 Mtetra
0 .484 .794 r
.37196 .60677 .37899 .60953 .39006 .61231 .38305 .60962 Mtetra
0 .508 .81 r
.38305 .60962 .39006 .61231 .40122 .61486 .39424 .61222 Mtetra
0 .532 .827 r
.39424 .61222 .40122 .61486 .41248 .61716 .40553 .61457 Mtetra
.018 .557 .844 r
.40553 .61457 .41248 .61716 .42384 .61918 .41691 .61665 Mtetra
.051 .583 .86 r
.41691 .61665 .42384 .61918 .43528 .62092 .42839 .61844 Mtetra
.086 .609 .877 r
.42839 .61844 .43528 .62092 .44682 .62237 .43996 .61993 Mtetra
.122 .636 .893 r
.43996 .61993 .44682 .62237 .45845 .6235 .45162 .6211 Mtetra
.159 .662 .908 r
.45162 .6211 .45845 .6235 .47016 .6243 .46338 .62194 Mtetra
.196 .687 .922 r
.46338 .62194 .47016 .6243 .48196 .62477 .47521 .62244 Mtetra
.234 .712 .936 r
.47521 .62244 .48196 .62477 .49384 .62488 .48713 .62258 Mtetra
.272 .736 .948 r
.48713 .62258 .49384 .62488 .5058 .62463 .49913 .62236 Mtetra
.31 .76 .958 r
.49913 .62236 .5058 .62463 .51783 .62401 .51121 .62176 Mtetra
.347 .781 .967 r
.51121 .62176 .51783 .62401 .52994 .62301 .52336 .62077 Mtetra
.383 .802 .975 r
.52336 .62077 .52994 .62301 .54212 .62161 .53559 .61939 Mtetra
.418 .82 .981 r
.53559 .61939 .54212 .62161 .55436 .61982 .54788 .6176 Mtetra
.452 .838 .985 r
.54788 .6176 .55436 .61982 .56666 .61762 .56023 .6154 Mtetra
.485 .853 .988 r
.56023 .6154 .56666 .61762 .57903 .61501 .57264 .61279 Mtetra
.516 .867 .989 r
.57264 .61279 .57903 .61501 .59144 .61198 .58511 .60975 Mtetra
.546 .88 .99 r
.58511 .60975 .59144 .61198 .60391 .60854 .59764 .6063 Mtetra
.573 .89 .988 r
.59764 .6063 .60391 .60854 .61643 .60468 .6102 .60241 Mtetra
.599 .9 .986 r
.6102 .60241 .61643 .60468 .62898 .60039 .62282 .59811 Mtetra
.624 .908 .983 r
.62282 .59811 .62898 .60039 .64158 .59569 .63547 .59337 Mtetra
.646 .915 .98 r
.63547 .59337 .64158 .59569 .6542 .59057 .64815 .58822 Mtetra
.667 .92 .975 r
.64815 .58822 .6542 .59057 .66686 .58504 .66087 .58264 Mtetra
.687 .925 .97 r
.66087 .58264 .66686 .58504 .67955 .57909 .67361 .57665 Mtetra
.705 .928 .965 r
.67361 .57665 .67955 .57909 .69225 .57273 .68638 .57024 Mtetra
.721 .931 .959 r
.68638 .57024 .69225 .57273 .70497 .56598 .69916 .56343 Mtetra
.737 .933 .953 r
.69916 .56343 .70497 .56598 .71771 .55883 .71196 .55622 Mtetra
.75 .935 .947 r
.71196 .55622 .71771 .55883 .73046 .5513 .72477 .54862 Mtetra
.763 .936 .941 r
.72477 .54862 .73046 .5513 .74321 .5434 .73759 .54064 Mtetra
.775 .936 .935 r
.73759 .54064 .74321 .5434 .75597 .53513 .75041 .53229 Mtetra
.786 .936 .929 r
.75041 .53229 .75597 .53513 .76872 .5265 .76323 .52359 Mtetra
.795 .936 .923 r
.76323 .52359 .76872 .5265 .78148 .51754 .77605 .51454 Mtetra
.804 .935 .917 r
.77605 .51454 .78148 .51754 .79423 .50824 .78886 .50515 Mtetra
.812 .934 .911 r
.78886 .50515 .79423 .50824 .80696 .49864 .80166 .49545 Mtetra
.82 .933 .906 r
.80166 .49545 .80696 .49864 .81969 .48873 .81445 .48544 Mtetra
.826 .932 .9 r
.81445 .48544 .81969 .48873 .83241 .47853 .82723 .47514 Mtetra
.832 .93 .895 r
.82723 .47514 .83241 .47853 .84511 .46806 .83999 .46457 Mtetra
.838 .929 .891 r
.83999 .46457 .84511 .46806 .85779 .45734 .85274 .45374 Mtetra
.843 .927 .886 r
.85274 .45374 .85779 .45734 .87045 .44638 .86546 .44266 Mtetra
.847 .925 .882 r
.86546 .44266 .87045 .44638 .8831 .43519 .87817 .43136 Mtetra
.851 .923 .878 r
.87817 .43136 .8831 .43519 .89572 .42379 .89085 .41985 Mtetra
.854 .921 .874 r
.89085 .41985 .89572 .42379 .90832 .41221 .90352 .40814 Mtetra
0 .369 .731 r
.28988 .57799 .29709 .58151 .30749 .58558 .30029 .58212 Mtetra
0 .384 .741 r
.30029 .58212 .30749 .58558 .31798 .58952 .3108 .58612 Mtetra
0 .399 .752 r
.3108 .58612 .31798 .58952 .32858 .59332 .32141 .58998 Mtetra
0 .416 .764 r
.32141 .58998 .32858 .59332 .33927 .59696 .33212 .59368 Mtetra
0 .435 .777 r
.33212 .59368 .33927 .59696 .35007 .60043 .34294 .59721 Mtetra
0 .455 .791 r
.34294 .59721 .35007 .60043 .36096 .6037 .35385 .60054 Mtetra
0 .476 .806 r
.35385 .60054 .36096 .6037 .37196 .60677 .36487 .60367 Mtetra
0 .499 .821 r
.36487 .60367 .37196 .60677 .38305 .60962 .37599 .60656 Mtetra
0 .522 .837 r
.37599 .60656 .38305 .60962 .39424 .61222 .3872 .60922 Mtetra
.017 .546 .853 r
.3872 .60922 .39424 .61222 .40553 .61457 .39852 .61162 Mtetra
.049 .571 .869 r
.39852 .61162 .40553 .61457 .41691 .61665 .40993 .61374 Mtetra
.083 .596 .885 r
.40993 .61374 .41691 .61665 .42839 .61844 .42144 .61557 Mtetra
.118 .622 .901 r
.42144 .61557 .42839 .61844 .43996 .61993 .43304 .6171 Mtetra
.154 .647 .916 r
.43304 .6171 .43996 .61993 .45162 .6211 .44474 .61831 Mtetra
.19 .672 .93 r
.44474 .61831 .45162 .6211 .46338 .62194 .45653 .61919 Mtetra
.227 .696 .943 r
.45653 .61919 .46338 .62194 .47521 .62244 .4684 .61971 Mtetra
.264 .72 .954 r
.4684 .61971 .47521 .62244 .48713 .62258 .48036 .61988 Mtetra
.302 .743 .965 r
.48036 .61988 .48713 .62258 .49913 .62236 .4924 .61968 Mtetra
.338 .764 .974 r
.4924 .61968 .49913 .62236 .51121 .62176 .50452 .6191 Mtetra
.374 .785 .981 r
.50452 .6191 .51121 .62176 .52336 .62077 .51672 .61813 Mtetra
.409 .803 .987 r
.51672 .61813 .52336 .62077 .53559 .61939 .52898 .61675 Mtetra
.443 .821 .991 r
.52898 .61675 .53559 .61939 .54788 .6176 .54132 .61497 Mtetra
.475 .836 .994 r
.54132 .61497 .54788 .6176 .56023 .6154 .55372 .61277 Mtetra
.506 .85 .995 r
.55372 .61277 .56023 .6154 .57264 .61279 .56619 .61015 Mtetra
.536 .863 .995 r
.56619 .61015 .57264 .61279 .58511 .60975 .57871 .60711 Mtetra
.564 .874 .994 r
.57871 .60711 .58511 .60975 .59764 .6063 .59128 .60364 Mtetra
.59 .884 .992 r
.59128 .60364 .59764 .6063 .6102 .60241 .60391 .59973 Mtetra
.614 .892 .989 r
.60391 .59973 .6102 .60241 .62282 .59811 .61657 .5954 Mtetra
.637 .899 .985 r
.61657 .5954 .62282 .59811 .63547 .59337 .62928 .59064 Mtetra
.659 .905 .98 r
.62928 .59064 .63547 .59337 .64815 .58822 .64202 .58545 Mtetra
.678 .91 .975 r
.64202 .58545 .64815 .58822 .66087 .58264 .6548 .57983 Mtetra
.696 .914 .969 r
.6548 .57983 .66087 .58264 .67361 .57665 .6676 .57379 Mtetra
.713 .918 .963 r
.6676 .57379 .67361 .57665 .68638 .57024 .68043 .56733 Mtetra
.729 .92 .957 r
.68043 .56733 .68638 .57024 .69916 .56343 .69327 .56046 Mtetra
.743 .922 .951 r
.69327 .56046 .69916 .56343 .71196 .55622 .70613 .55319 Mtetra
.756 .923 .945 r
.70613 .55319 .71196 .55622 .72477 .54862 .719 .54553 Mtetra
.768 .924 .938 r
.719 .54553 .72477 .54862 .73759 .54064 .73188 .53748 Mtetra
.779 .924 .932 r
.73188 .53748 .73759 .54064 .75041 .53229 .74476 .52906 Mtetra
.789 .924 .926 r
.74476 .52906 .75041 .53229 .76323 .52359 .75765 .52027 Mtetra
.798 .924 .92 r
.75765 .52027 .76323 .52359 .77605 .51454 .77053 .51114 Mtetra
.807 .923 .914 r
.77053 .51114 .77605 .51454 .78886 .50515 .7834 .50167 Mtetra
.814 .923 .908 r
.7834 .50167 .78886 .50515 .80166 .49545 .79627 .49188 Mtetra
.821 .922 .903 r
.79627 .49188 .80166 .49545 .81445 .48544 .80912 .48177 Mtetra
.828 .92 .898 r
.80912 .48177 .81445 .48544 .82723 .47514 .82196 .47138 Mtetra
.833 .919 .893 r
.82196 .47138 .82723 .47514 .83999 .46457 .83479 .4607 Mtetra
.838 .918 .888 r
.83479 .4607 .83999 .46457 .85274 .45374 .84759 .44977 Mtetra
.843 .916 .883 r
.84759 .44977 .85274 .45374 .86546 .44266 .86038 .43858 Mtetra
.847 .915 .879 r
.86038 .43858 .86546 .44266 .87817 .43136 .87315 .42717 Mtetra
.851 .913 .875 r
.87315 .42717 .87817 .43136 .89085 .41985 .8859 .41555 Mtetra
.854 .911 .871 r
.8859 .41555 .89085 .41985 .90352 .40814 .89863 .40373 Mtetra
0 .382 .755 r
.28262 .57416 .28988 .57799 .30029 .58212 .29304 .57834 Mtetra
0 .396 .765 r
.29304 .57834 .30029 .58212 .3108 .58612 .30357 .5824 Mtetra
0 .412 .776 r
.30357 .5824 .3108 .58612 .32141 .58998 .3142 .58631 Mtetra
0 .43 .789 r
.3142 .58631 .32141 .58998 .33212 .59368 .32493 .59006 Mtetra
0 .449 .802 r
.32493 .59006 .33212 .59368 .34294 .59721 .33576 .59364 Mtetra
0 .469 .816 r
.33576 .59364 .34294 .59721 .35385 .60054 .34669 .59702 Mtetra
0 .49 .831 r
.34669 .59702 .35385 .60054 .36487 .60367 .35773 .6002 Mtetra
0 .512 .846 r
.35773 .6002 .36487 .60367 .37599 .60656 .36887 .60314 Mtetra
.017 .535 .861 r
.36887 .60314 .37599 .60656 .3872 .60922 .38011 .60584 Mtetra
.048 .559 .877 r
.38011 .60584 .3872 .60922 .39852 .61162 .39145 .60828 Mtetra
.08 .583 .892 r
.39145 .60828 .39852 .61162 .40993 .61374 .40289 .61045 Mtetra
.114 .607 .907 r
.40289 .61045 .40993 .61374 .42144 .61557 .41443 .61232 Mtetra
.149 .632 .921 r
.41443 .61232 .42144 .61557 .43304 .6171 .42606 .61388 Mtetra
.185 .656 .935 r
.42606 .61388 .43304 .6171 .44474 .61831 .43779 .61512 Mtetra
.221 .68 .947 r
.43779 .61512 .44474 .61831 .45653 .61919 .44961 .61603 Mtetra
.257 .703 .959 r
.44961 .61603 .45653 .61919 .4684 .61971 .46152 .61658 Mtetra
.293 .725 .969 r
.46152 .61658 .4684 .61971 .48036 .61988 .47352 .61677 Mtetra
.329 .746 .977 r
.47352 .61677 .48036 .61988 .4924 .61968 .4856 .61659 Mtetra
.365 .766 .985 r
.4856 .61659 .4924 .61968 .50452 .6191 .49776 .61602 Mtetra
.399 .785 .99 r
.49776 .61602 .50452 .6191 .51672 .61813 .51 .61506 Mtetra
.433 .802 .994 r
.51 .61506 .51672 .61813 .52898 .61675 .52231 .61369 Mtetra
.465 .818 .997 r
.52231 .61369 .52898 .61675 .54132 .61497 .5347 .61191 Mtetra
.496 .832 .998 r
.5347 .61191 .54132 .61497 .55372 .61277 .54715 .60971 Mtetra
.525 .845 .998 r
.54715 .60971 .55372 .61277 .56619 .61015 .55966 .60708 Mtetra
.553 .856 .997 r
.55966 .60708 .56619 .61015 .57871 .60711 .57223 .60403 Mtetra
.579 .866 .995 r
.57223 .60403 .57871 .60711 .59128 .60364 .58485 .60054 Mtetra
.604 .875 .992 r
.58485 .60054 .59128 .60364 .60391 .59973 .59753 .59662 Mtetra
.627 .883 .988 r
.59753 .59662 .60391 .59973 .61657 .5954 .61025 .59226 Mtetra
.648 .889 .983 r
.61025 .59226 .61657 .5954 .62928 .59064 .62301 .58747 Mtetra
.668 .894 .978 r
.62301 .58747 .62928 .59064 .64202 .58545 .63581 .58224 Mtetra
.687 .899 .973 r
.63581 .58224 .64202 .58545 .6548 .57983 .64864 .57658 Mtetra
.704 .903 .967 r
.64864 .57658 .6548 .57983 .6676 .57379 .6615 .5705 Mtetra
.72 .905 .961 r
.6615 .5705 .6676 .57379 .68043 .56733 .67439 .56399 Mtetra
.734 .908 .954 r
.67439 .56399 .68043 .56733 .69327 .56046 .68729 .55707 Mtetra
.748 .909 .948 r
.68729 .55707 .69327 .56046 .70613 .55319 .70021 .54974 Mtetra
.76 .911 .941 r
.70021 .54974 .70613 .55319 .719 .54553 .71315 .54202 Mtetra
.771 .911 .935 r
.71315 .54202 .719 .54553 .73188 .53748 .72609 .5339 Mtetra
.782 .912 .929 r
.72609 .5339 .73188 .53748 .74476 .52906 .73903 .52541 Mtetra
.791 .912 .922 r
.73903 .52541 .74476 .52906 .75765 .52027 .75198 .51655 Mtetra
.8 .912 .916 r
.75198 .51655 .75765 .52027 .77053 .51114 .76492 .50734 Mtetra
.808 .911 .91 r
.76492 .50734 .77053 .51114 .7834 .50167 .77786 .49778 Mtetra
.815 .911 .905 r
.77786 .49778 .7834 .50167 .79627 .49188 .79078 .4879 Mtetra
.822 .91 .899 r
.79078 .4879 .79627 .49188 .80912 .48177 .8037 .47771 Mtetra
.828 .909 .894 r
.8037 .47771 .80912 .48177 .82196 .47138 .81661 .46722 Mtetra
.833 .908 .889 r
.81661 .46722 .82196 .47138 .83479 .4607 .82949 .45645 Mtetra
.838 .906 .884 r
.82949 .45645 .83479 .4607 .84759 .44977 .84237 .44541 Mtetra
.843 .905 .88 r
.84237 .44541 .84759 .44977 .86038 .43858 .85522 .43413 Mtetra
.847 .904 .876 r
.85522 .43413 .86038 .43858 .87315 .42717 .86805 .42261 Mtetra
.85 .902 .872 r
.86805 .42261 .87315 .42717 .8859 .41555 .88086 .41088 Mtetra
.853 .901 .868 r
.88086 .41088 .8859 .41555 .89863 .40373 .89364 .39896 Mtetra
0 .394 .777 r
.27531 .56999 .28262 .57416 .29304 .57834 .28575 .57422 Mtetra
0 .409 .788 r
.28575 .57422 .29304 .57834 .30357 .5824 .29629 .57833 Mtetra
0 .425 .799 r
.29629 .57833 .30357 .5824 .3142 .58631 .30693 .58229 Mtetra
0 .442 .812 r
.30693 .58229 .3142 .58631 .32493 .59006 .31768 .58609 Mtetra
0 .461 .825 r
.31768 .58609 .32493 .59006 .33576 .59364 .32853 .58971 Mtetra
0 .481 .839 r
.32853 .58971 .33576 .59364 .34669 .59702 .33948 .59314 Mtetra
0 .502 .853 r
.33948 .59314 .34669 .59702 .35773 .6002 .35054 .59635 Mtetra
.018 .524 .868 r
.35054 .59635 .35773 .6002 .36887 .60314 .3617 .59934 Mtetra
.047 .546 .883 r
.3617 .59934 .36887 .60314 .38011 .60584 .37296 .60208 Mtetra
.079 .569 .897 r
.37296 .60208 .38011 .60584 .39145 .60828 .38433 .60455 Mtetra
.111 .592 .911 r
.38433 .60455 .39145 .60828 .40289 .61045 .3958 .60675 Mtetra
.145 .616 .925 r
.3958 .60675 .40289 .61045 .41443 .61232 .40736 .60866 Mtetra
.18 .639 .938 r
.40736 .60866 .41443 .61232 .42606 .61388 .41903 .61025 Mtetra
.215 .662 .95 r
.41903 .61025 .42606 .61388 .43779 .61512 .43079 .61152 Mtetra
.25 .685 .961 r
.43079 .61152 .43779 .61512 .44961 .61603 .44264 .61245 Mtetra
.285 .706 .971 r
.44264 .61245 .44961 .61603 .46152 .61658 .45458 .61302 Mtetra
.321 .727 .979 r
.45458 .61302 .46152 .61658 .47352 .61677 .46662 .61323 Mtetra
.355 .747 .986 r
.46662 .61323 .47352 .61677 .4856 .61659 .47874 .61307 Mtetra
.389 .765 .992 r
.47874 .61307 .4856 .61659 .49776 .61602 .49094 .61251 Mtetra
.422 .782 .996 r
.49094 .61251 .49776 .61602 .51 .61506 .50322 .61155 Mtetra
.454 .798 .998 r
.50322 .61155 .51 .61506 .52231 .61369 .51557 .61019 Mtetra
.485 .812 1 r
.51557 .61019 .52231 .61369 .5347 .61191 .528 .60841 Mtetra
.514 .825 1 r
.528 .60841 .5347 .61191 .54715 .60971 .5405 .6062 Mtetra
.542 .837 .999 r
.5405 .6062 .54715 .60971 .55966 .60708 .55306 .60357 Mtetra
.568 .847 .997 r
.55306 .60357 .55966 .60708 .57223 .60403 .56568 .6005 Mtetra
.592 .856 .994 r
.56568 .6005 .57223 .60403 .58485 .60054 .57835 .597 Mtetra
.616 .864 .99 r
.57835 .597 .58485 .60054 .59753 .59662 .59108 .59306 Mtetra
.637 .871 .985 r
.59108 .59306 .59753 .59662 .61025 .59226 .60385 .58867 Mtetra
.658 .877 .98 r
.60385 .58867 .61025 .59226 .62301 .58747 .61667 .58385 Mtetra
.676 .882 .975 r
.61667 .58385 .62301 .58747 .63581 .58224 .62952 .57859 Mtetra
.694 .886 .969 r
.62952 .57859 .63581 .58224 .64864 .57658 .64241 .57289 Mtetra
.71 .89 .963 r
.64241 .57289 .64864 .57658 .6615 .5705 .65533 .56677 Mtetra
.725 .892 .956 r
.65533 .56677 .6615 .5705 .67439 .56399 .66827 .56021 Mtetra
.738 .895 .95 r
.66827 .56021 .67439 .56399 .68729 .55707 .68123 .55324 Mtetra
.751 .896 .943 r
.68123 .55324 .68729 .55707 .70021 .54974 .69421 .54586 Mtetra
.763 .897 .937 r
.69421 .54586 .70021 .54974 .71315 .54202 .70721 .53807 Mtetra
.773 .898 .93 r
.70721 .53807 .71315 .54202 .72609 .5339 .72021 .52989 Mtetra
.783 .899 .924 r
.72021 .52989 .72609 .5339 .73903 .52541 .73321 .52133 Mtetra
.792 .899 .918 r
.73321 .52133 .73903 .52541 .75198 .51655 .74622 .5124 Mtetra
.801 .899 .912 r
.74622 .5124 .75198 .51655 .76492 .50734 .75922 .50311 Mtetra
.808 .899 .906 r
.75922 .50311 .76492 .50734 .77786 .49778 .77222 .49348 Mtetra
.815 .898 .901 r
.77222 .49348 .77786 .49778 .79078 .4879 .78522 .48351 Mtetra
.821 .898 .895 r
.78522 .48351 .79078 .4879 .8037 .47771 .7982 .47324 Mtetra
.827 .897 .89 r
.7982 .47324 .8037 .47771 .81661 .46722 .81116 .46266 Mtetra
.833 .896 .885 r
.81116 .46266 .81661 .46722 .82949 .45645 .82411 .4518 Mtetra
.837 .895 .881 r
.82411 .4518 .82949 .45645 .84237 .44541 .83705 .44067 Mtetra
.842 .894 .876 r
.83705 .44067 .84237 .44541 .85522 .43413 .84996 .42929 Mtetra
.845 .893 .872 r
.84996 .42929 .85522 .43413 .86805 .42261 .86286 .41768 Mtetra
.849 .892 .868 r
.86286 .41768 .86805 .42261 .88086 .41088 .87573 .40584 Mtetra
.852 .89 .865 r
.87573 .40584 .88086 .41088 .89364 .39896 .88858 .39381 Mtetra
0 .406 .798 r
.26797 .56549 .27531 .56999 .28575 .57422 .27842 .56976 Mtetra
0 .42 .809 r
.27842 .56976 .28575 .57422 .29629 .57833 .28897 .57391 Mtetra
0 .437 .821 r
.28897 .57391 .29629 .57833 .30693 .58229 .29962 .57791 Mtetra
0 .454 .833 r
.29962 .57791 .30693 .58229 .31768 .58609 .31038 .58174 Mtetra
0 .473 .846 r
.31038 .58174 .31768 .58609 .32853 .58971 .32125 .5854 Mtetra
0 .492 .859 r
.32125 .5854 .32853 .58971 .33948 .59314 .33222 .58887 Mtetra
.02 .513 .873 r
.33222 .58887 .33948 .59314 .35054 .59635 .3433 .59212 Mtetra
.048 .534 .887 r
.3433 .59212 .35054 .59635 .3617 .59934 .35448 .59514 Mtetra
.078 .556 .9 r
.35448 .59514 .3617 .59934 .37296 .60208 .36577 .59791 Mtetra
.109 .578 .914 r
.36577 .59791 .37296 .60208 .38433 .60455 .37716 .60042 Mtetra
.142 .6 .927 r
.37716 .60042 .38433 .60455 .3958 .60675 .38865 .60265 Mtetra
.175 .622 .939 r
.38865 .60265 .3958 .60675 .40736 .60866 .40024 .60458 Mtetra
.209 .644 .951 r
.40024 .60458 .40736 .60866 .41903 .61025 .41193 .6062 Mtetra
.243 .666 .961 r
.41193 .6062 .41903 .61025 .43079 .61152 .42372 .60749 Mtetra
.277 .687 .971 r
.42372 .60749 .43079 .61152 .44264 .61245 .43561 .60844 Mtetra
.312 .707 .979 r
.43561 .60844 .44264 .61245 .45458 .61302 .44759 .60903 Mtetra
.346 .726 .985 r
.44759 .60903 .45458 .61302 .46662 .61323 .45965 .60926 Mtetra
.379 .744 .991 r
.45965 .60926 .46662 .61323 .47874 .61307 .47181 .6091 Mtetra
.411 .761 .995 r
.47181 .6091 .47874 .61307 .49094 .61251 .48405 .60855 Mtetra
.443 .777 .998 r
.48405 .60855 .49094 .61251 .50322 .61155 .49637 .6076 Mtetra
.473 .792 .999 r
.49637 .6076 .50322 .61155 .51557 .61019 .50877 .60624 Mtetra
.502 .805 .999 r
.50877 .60624 .51557 .61019 .528 .60841 .52124 .60445 Mtetra
.529 .817 .998 r
.52124 .60445 .528 .60841 .5405 .6062 .53378 .60224 Mtetra
.555 .827 .996 r
.53378 .60224 .5405 .6062 .55306 .60357 .54638 .5996 Mtetra
.58 .837 .994 r
.54638 .5996 .55306 .60357 .56568 .6005 .55905 .59652 Mtetra
.603 .845 .99 r
.55905 .59652 .56568 .6005 .57835 .597 .57177 .593 Mtetra
.625 .853 .986 r
.57177 .593 .57835 .597 .59108 .59306 .58455 .58903 Mtetra
.646 .859 .981 r
.58455 .58903 .59108 .59306 .60385 .58867 .59738 .58462 Mtetra
.665 .864 .975 r
.59738 .58462 .60385 .58867 .61667 .58385 .61025 .57977 Mtetra
.682 .869 .969 r
.61025 .57977 .61667 .58385 .62952 .57859 .62315 .57448 Mtetra
.699 .873 .963 r
.62315 .57448 .62952 .57859 .64241 .57289 .6361 .56874 Mtetra
.714 .876 .957 r
.6361 .56874 .64241 .57289 .65533 .56677 .64907 .56257 Mtetra
.728 .879 .951 r
.64907 .56257 .65533 .56677 .66827 .56021 .66207 .55598 Mtetra
.741 .881 .944 r
.66207 .55598 .66827 .56021 .68123 .55324 .67509 .54895 Mtetra
.753 .883 .938 r
.67509 .54895 .68123 .55324 .69421 .54586 .68813 .54152 Mtetra
.764 .884 .931 r
.68813 .54152 .69421 .54586 .70721 .53807 .70118 .53367 Mtetra
.774 .885 .925 r
.70118 .53367 .70721 .53807 .72021 .52989 .71424 .52543 Mtetra
.784 .885 .919 r
.71424 .52543 .72021 .52989 .73321 .52133 .72731 .51681 Mtetra
.792 .886 .913 r
.72731 .51681 .73321 .52133 .74622 .5124 .74038 .50781 Mtetra
.8 .886 .907 r
.74038 .50781 .74622 .5124 .75922 .50311 .75344 .49845 Mtetra
.808 .886 .901 r
.75344 .49845 .75922 .50311 .77222 .49348 .76651 .48874 Mtetra
.814 .886 .896 r
.76651 .48874 .77222 .49348 .78522 .48351 .77956 .4787 Mtetra
.82 .885 .891 r
.77956 .4787 .78522 .48351 .7982 .47324 .7926 .46834 Mtetra
.826 .885 .886 r
.7926 .46834 .7982 .47324 .81116 .46266 .80563 .45768 Mtetra
.831 .884 .881 r
.80563 .45768 .81116 .46266 .82411 .4518 .81864 .44674 Mtetra
.836 .883 .876 r
.81864 .44674 .82411 .4518 .83705 .44067 .83164 .43552 Mtetra
.84 .883 .872 r
.83164 .43552 .83705 .44067 .84996 .42929 .84462 .42405 Mtetra
.844 .882 .868 r
.84462 .42405 .84996 .42929 .86286 .41768 .85757 .41234 Mtetra
.847 .881 .864 r
.85757 .41234 .86286 .41768 .87573 .40584 .87051 .40042 Mtetra
.85 .88 .861 r
.87051 .40042 .87573 .40584 .88858 .39381 .88342 .38829 Mtetra
0 .417 .818 r
.26058 .56064 .26797 .56549 .27842 .56976 .27104 .56495 Mtetra
0 .431 .828 r
.27104 .56495 .27842 .56976 .28897 .57391 .2816 .56913 Mtetra
0 .447 .839 r
.2816 .56913 .28897 .57391 .29962 .57791 .29227 .57316 Mtetra
0 .465 .851 r
.29227 .57316 .29962 .57791 .31038 .58174 .30304 .57703 Mtetra
0 .483 .864 r
.30304 .57703 .31038 .58174 .32125 .5854 .31393 .58072 Mtetra
.022 .502 .876 r
.31393 .58072 .32125 .5854 .33222 .58887 .32491 .58421 Mtetra
.05 .522 .889 r
.32491 .58421 .33222 .58887 .3433 .59212 .33601 .58749 Mtetra
.078 .542 .902 r
.33601 .58749 .3433 .59212 .35448 .59514 .34721 .59054 Mtetra
.108 .563 .915 r
.34721 .59054 .35448 .59514 .36577 .59791 .35852 .59334 Mtetra
.139 .584 .927 r
.35852 .59334 .36577 .59791 .37716 .60042 .36993 .59587 Mtetra
.171 .605 .939 r
.36993 .59587 .37716 .60042 .38865 .60265 .38145 .59813 Mtetra
.204 .626 .95 r
.38145 .59813 .38865 .60265 .40024 .60458 .39306 .60008 Mtetra
.237 .647 .96 r
.39306 .60008 .40024 .60458 .41193 .6062 .40478 .60172 Mtetra
.27 .667 .969 r
.40478 .60172 .41193 .6062 .42372 .60749 .4166 .60302 Mtetra
.303 .687 .976 r
.4166 .60302 .42372 .60749 .43561 .60844 .42852 .60399 Mtetra
.336 .706 .983 r
.42852 .60399 .43561 .60844 .44759 .60903 .44053 .60459 Mtetra
.368 .723 .988 r
.44053 .60459 .44759 .60903 .45965 .60926 .45263 .60483 Mtetra
.4 .74 .992 r
.45263 .60483 .45965 .60926 .47181 .6091 .46482 .60468 Mtetra
.431 .756 .995 r
.46482 .60468 .47181 .6091 .48405 .60855 .4771 .60413 Mtetra
.461 .77 .997 r
.4771 .60413 .48405 .60855 .49637 .6076 .48946 .60318 Mtetra
.489 .784 .997 r
.48946 .60318 .49637 .6076 .50877 .60624 .50189 .60182 Mtetra
.517 .796 .996 r
.50189 .60182 .50877 .60624 .52124 .60445 .51441 .60003 Mtetra
.543 .807 .995 r
.51441 .60003 .52124 .60445 .53378 .60224 .52699 .59781 Mtetra
.567 .816 .992 r
.52699 .59781 .53378 .60224 .54638 .5996 .53964 .59516 Mtetra
.591 .825 .988 r
.53964 .59516 .54638 .5996 .55905 .59652 .55235 .59206 Mtetra
.612 .833 .984 r
.55235 .59206 .55905 .59652 .57177 .593 .56512 .58852 Mtetra
.633 .84 .98 r
.56512 .58852 .57177 .593 .58455 .58903 .57795 .58454 Mtetra
.652 .846 .974 r
.57795 .58454 .58455 .58903 .59738 .58462 .59083 .5801 Mtetra
.67 .851 .969 r
.59083 .5801 .59738 .58462 .61025 .57977 .60375 .57522 Mtetra
.687 .855 .963 r
.60375 .57522 .61025 .57977 .62315 .57448 .61671 .56989 Mtetra
.702 .859 .957 r
.61671 .56989 .62315 .57448 .6361 .56874 .62971 .56412 Mtetra
.717 .862 .951 r
.62971 .56412 .6361 .56874 .64907 .56257 .64273 .55791 Mtetra
.73 .865 .944 r
.64273 .55791 .64907 .56257 .66207 .55598 .65579 .55127 Mtetra
.742 .867 .938 r
.65579 .55127 .66207 .55598 .67509 .54895 .66887 .5442 Mtetra
.754 .869 .932 r
.66887 .5442 .67509 .54895 .68813 .54152 .68196 .53671 Mtetra
.765 .87 .925 r
.68196 .53671 .68813 .54152 .70118 .53367 .69507 .52882 Mtetra
.774 .871 .919 r
.69507 .52882 .70118 .53367 .71424 .52543 .70819 .52052 Mtetra
.783 .872 .913 r
.70819 .52052 .71424 .52543 .72731 .51681 .72132 .51183 Mtetra
.792 .872 .907 r
.72132 .51183 .72731 .51681 .74038 .50781 .73445 .50277 Mtetra
.799 .873 .902 r
.73445 .50277 .74038 .50781 .75344 .49845 .74758 .49334 Mtetra
.806 .873 .896 r
.74758 .49334 .75344 .49845 .76651 .48874 .7607 .48357 Mtetra
.813 .873 .891 r
.7607 .48357 .76651 .48874 .77956 .4787 .77381 .47345 Mtetra
.819 .873 .886 r
.77381 .47345 .77956 .4787 .7926 .46834 .78692 .46302 Mtetra
.824 .872 .881 r
.78692 .46302 .7926 .46834 .80563 .45768 .80001 .45228 Mtetra
.829 .872 .876 r
.80001 .45228 .80563 .45768 .81864 .44674 .81309 .44126 Mtetra
.834 .872 .872 r
.81309 .44126 .81864 .44674 .83164 .43552 .82614 .42996 Mtetra
.838 .871 .868 r
.82614 .42996 .83164 .43552 .84462 .42405 .83918 .4184 Mtetra
.841 .871 .864 r
.83918 .4184 .84462 .42405 .85757 .41234 .8522 .40661 Mtetra
.845 .87 .86 r
.8522 .40661 .85757 .41234 .87051 .40042 .8652 .3946 Mtetra
.848 .869 .857 r
.8652 .3946 .87051 .40042 .88342 .38829 .87817 .38238 Mtetra
0 .427 .835 r
.25315 .55545 .26058 .56064 .27104 .56495 .26362 .55978 Mtetra
0 .441 .845 r
.26362 .55978 .27104 .56495 .2816 .56913 .27419 .56398 Mtetra
0 .457 .856 r
.27419 .56398 .2816 .56913 .29227 .57316 .28487 .56804 Mtetra
.002 .474 .867 r
.28487 .56804 .29227 .57316 .30304 .57703 .29566 .57193 Mtetra
.026 .492 .879 r
.29566 .57193 .30304 .57703 .31393 .58072 .30656 .57565 Mtetra
.052 .51 .891 r
.30656 .57565 .31393 .58072 .32491 .58421 .31756 .57916 Mtetra
.079 .529 .903 r
.31756 .57916 .32491 .58421 .33601 .58749 .32867 .58247 Mtetra
.107 .549 .915 r
.32867 .58247 .33601 .58749 .34721 .59054 .33989 .58553 Mtetra
.137 .569 .926 r
.33989 .58553 .34721 .59054 .35852 .59334 .35122 .58835 Mtetra
.168 .589 .937 r
.35122 .58835 .35852 .59334 .36993 .59587 .36265 .59091 Mtetra
.199 .609 .947 r
.36265 .59091 .36993 .59587 .38145 .59813 .37419 .59317 Mtetra
.23 .629 .957 r
.37419 .59317 .38145 .59813 .39306 .60008 .38584 .59514 Mtetra
.262 .648 .965 r
.38584 .59514 .39306 .60008 .40478 .60172 .39758 .59679 Mtetra
.295 .667 .973 r
.39758 .59679 .40478 .60172 .4166 .60302 .40943 .59811 Mtetra
.326 .685 .979 r
.40943 .59811 .4166 .60302 .42852 .60399 .42137 .59909 Mtetra
.358 .702 .984 r
.42137 .59909 .42852 .60399 .44053 .60459 .43341 .5997 Mtetra
.389 .719 .988 r
.43341 .5997 .44053 .60459 .45263 .60483 .44555 .59994 Mtetra
.419 .734 .991 r
.44555 .59994 .45263 .60483 .46482 .60468 .45777 .59979 Mtetra
.448 .749 .993 r
.45777 .59979 .46482 .60468 .4771 .60413 .47008 .59925 Mtetra
.476 .762 .993 r
.47008 .59925 .4771 .60413 .48946 .60318 .48248 .5983 Mtetra
.503 .774 .993 r
.48248 .5983 .48946 .60318 .50189 .60182 .49496 .59693 Mtetra
.529 .785 .991 r
.49496 .59693 .50189 .60182 .51441 .60003 .50751 .59513 Mtetra
.554 .795 .989 r
.50751 .59513 .51441 .60003 .52699 .59781 .52013 .5929 Mtetra
.577 .804 .986 r
.52013 .5929 .52699 .59781 .53964 .59516 .53283 .59023 Mtetra
.599 .813 .982 r
.53283 .59023 .53964 .59516 .55235 .59206 .54559 .58712 Mtetra
.62 .82 .977 r
.54559 .58712 .55235 .59206 .56512 .58852 .5584 .58356 Mtetra
.639 .826 .972 r
.5584 .58356 .56512 .58852 .57795 .58454 .57128 .57955 Mtetra
.657 .832 .967 r
.57128 .57955 .57795 .58454 .59083 .5801 .5842 .57509 Mtetra
.674 .837 .961 r
.5842 .57509 .59083 .5801 .60375 .57522 .59717 .57018 Mtetra
.69 .841 .955 r
.59717 .57018 .60375 .57522 .61671 .56989 .61019 .56482 Mtetra
.705 .845 .949 r
.61019 .56482 .61671 .56989 .62971 .56412 .62324 .55902 Mtetra
.718 .848 .943 r
.62324 .55902 .62971 .56412 .64273 .55791 .63632 .55277 Mtetra
.731 .85 .937 r
.63632 .55277 .64273 .55791 .65579 .55127 .64943 .54608 Mtetra
.743 .853 .931 r
.64943 .54608 .65579 .55127 .66887 .5442 .66256 .53897 Mtetra
.754 .854 .925 r
.66256 .53897 .66887 .5442 .68196 .53671 .67572 .53143 Mtetra
.764 .856 .919 r
.67572 .53143 .68196 .53671 .69507 .52882 .68888 .52349 Mtetra
.773 .857 .913 r
.68888 .52349 .69507 .52882 .70819 .52052 .70206 .51513 Mtetra
.782 .858 .907 r
.70206 .51513 .70819 .52052 .72132 .51183 .71525 .50639 Mtetra
.79 .859 .901 r
.71525 .50639 .72132 .51183 .73445 .50277 .72843 .49727 Mtetra
.797 .86 .896 r
.72843 .49727 .73445 .50277 .74758 .49334 .74162 .48778 Mtetra
.804 .86 .89 r
.74162 .48778 .74758 .49334 .7607 .48357 .75481 .47794 Mtetra
.811 .86 .885 r
.75481 .47794 .7607 .48357 .77381 .47345 .76798 .46776 Mtetra
.816 .86 .88 r
.76798 .46776 .77381 .47345 .78692 .46302 .78115 .45725 Mtetra
.822 .86 .876 r
.78115 .45725 .78692 .46302 .80001 .45228 .7943 .44644 Mtetra
.827 .86 .871 r
.7943 .44644 .80001 .45228 .81309 .44126 .80744 .43534 Mtetra
.831 .86 .867 r
.80744 .43534 .81309 .44126 .82614 .42996 .82056 .42397 Mtetra
.835 .86 .863 r
.82056 .42397 .82614 .42996 .83918 .4184 .83366 .41233 Mtetra
.839 .86 .86 r
.83366 .41233 .83918 .4184 .8522 .40661 .84674 .40046 Mtetra
.842 .859 .856 r
.84674 .40046 .8522 .40661 .8652 .3946 .8598 .38837 Mtetra
.845 .859 .853 r
.8598 .38837 .8652 .3946 .87817 .38238 .87283 .37607 Mtetra
0 .436 .849 r
.24569 .5499 .25315 .55545 .26362 .55978 .25616 .55424 Mtetra
0 .45 .859 r
.25616 .55424 .26362 .55978 .27419 .56398 .26675 .55846 Mtetra
.009 .466 .87 r
.26675 .55846 .27419 .56398 .28487 .56804 .27744 .56254 Mtetra
.031 .482 .88 r
.27744 .56254 .28487 .56804 .29566 .57193 .28824 .56645 Mtetra
.055 .499 .891 r
.28824 .56645 .29566 .57193 .30656 .57565 .29915 .57018 Mtetra
.081 .517 .902 r
.29915 .57018 .30656 .57565 .31756 .57916 .31017 .57371 Mtetra
.108 .535 .913 r
.31017 .57371 .31756 .57916 .32867 .58247 .32129 .57703 Mtetra
.136 .554 .924 r
.32129 .57703 .32867 .58247 .33989 .58553 .33253 .58011 Mtetra
.165 .573 .934 r
.33253 .58011 .33989 .58553 .35122 .58835 .34388 .58294 Mtetra
.195 .592 .944 r
.34388 .58294 .35122 .58835 .36265 .59091 .35533 .58551 Mtetra
.225 .61 .953 r
.35533 .58551 .36265 .59091 .37419 .59317 .36689 .58778 Mtetra
.256 .629 .961 r
.36689 .58778 .37419 .59317 .38584 .59514 .37856 .58976 Mtetra
.286 .647 .968 r
.37856 .58976 .38584 .59514 .39758 .59679 .39033 .59142 Mtetra
.317 .665 .974 r
.39033 .59142 .39758 .59679 .40943 .59811 .4022 .59275 Mtetra
.348 .681 .979 r
.4022 .59275 .40943 .59811 .42137 .59909 .41417 .59372 Mtetra
.378 .697 .983 r
.41417 .59372 .42137 .59909 .43341 .5997 .42624 .59434 Mtetra
.407 .713 .986 r
.42624 .59434 .43341 .5997 .44555 .59994 .43841 .59458 Mtetra
.436 .727 .987 r
.43841 .59458 .44555 .59994 .45777 .59979 .45067 .59443 Mtetra
.463 .74 .988 r
.45067 .59443 .45777 .59979 .47008 .59925 .46301 .59389 Mtetra
.49 .752 .988 r
.46301 .59389 .47008 .59925 .48248 .5983 .47544 .59293 Mtetra
.516 .764 .986 r
.47544 .59293 .48248 .5983 .49496 .59693 .48796 .59155 Mtetra
.54 .774 .984 r
.48796 .59155 .49496 .59693 .50751 .59513 .50055 .58974 Mtetra
.563 .783 .981 r
.50055 .58974 .50751 .59513 .52013 .5929 .51321 .5875 Mtetra
.585 .792 .978 r
.51321 .5875 .52013 .5929 .53283 .59023 .52595 .58482 Mtetra
.606 .799 .974 r
.52595 .58482 .53283 .59023 .54559 .58712 .53875 .58169 Mtetra
.625 .806 .969 r
.53875 .58169 .54559 .58712 .5584 .58356 .55162 .57811 Mtetra
.644 .812 .964 r
.55162 .57811 .5584 .58356 .57128 .57955 .56454 .57408 Mtetra
.661 .818 .959 r
.56454 .57408 .57128 .57955 .5842 .57509 .57751 .56959 Mtetra
.677 .822 .953 r
.57751 .56959 .5842 .57509 .59717 .57018 .59053 .56465 Mtetra
.692 .827 .947 r
.59053 .56465 .59717 .57018 .61019 .56482 .60359 .55926 Mtetra
.706 .83 .941 r
.60359 .55926 .61019 .56482 .62324 .55902 .61669 .55342 Mtetra
.719 .833 .935 r
.61669 .55342 .62324 .55902 .63632 .55277 .62983 .54713 Mtetra
.731 .836 .929 r
.62983 .54713 .63632 .55277 .64943 .54608 .64299 .54041 Mtetra
.743 .838 .923 r
.64299 .54041 .64943 .54608 .66256 .53897 .65618 .53325 Mtetra
.753 .84 .917 r
.65618 .53325 .66256 .53897 .67572 .53143 .66939 .52567 Mtetra
.763 .842 .912 r
.66939 .52567 .67572 .53143 .68888 .52349 .68261 .51767 Mtetra
.772 .843 .906 r
.68261 .51767 .68888 .52349 .70206 .51513 .69585 .50927 Mtetra
.78 .845 .9 r
.69585 .50927 .70206 .51513 .71525 .50639 .70909 .50048 Mtetra
.788 .846 .895 r
.70909 .50048 .71525 .50639 .72843 .49727 .72234 .4913 Mtetra
.795 .846 .89 r
.72234 .4913 .72843 .49727 .74162 .48778 .73558 .48175 Mtetra
.802 .847 .885 r
.73558 .48175 .74162 .48778 .75481 .47794 .74883 .47185 Mtetra
.808 .848 .88 r
.74883 .47185 .75481 .47794 .76798 .46776 .76206 .46161 Mtetra
.814 .848 .875 r
.76206 .46161 .76798 .46776 .78115 .45725 .77529 .45104 Mtetra
.819 .848 .871 r
.77529 .45104 .78115 .45725 .7943 .44644 .7885 .44016 Mtetra
.824 .848 .866 r
.7885 .44016 .7943 .44644 .80744 .43534 .8017 .42899 Mtetra
.828 .849 .863 r
.8017 .42899 .80744 .43534 .82056 .42397 .81488 .41755 Mtetra
.832 .849 .859 r
.81488 .41755 .82056 .42397 .83366 .41233 .82805 .40584 Mtetra
.836 .849 .855 r
.82805 .40584 .83366 .41233 .84674 .40046 .84119 .39389 Mtetra
.839 .848 .852 r
.84119 .39389 .84674 .40046 .8598 .38837 .85431 .38173 Mtetra
.842 .848 .849 r
.85431 .38173 .8598 .38837 .87283 .37607 .86741 .36935 Mtetra
0 .445 .862 r
.23819 .54398 .24569 .5499 .25616 .55424 .24867 .54834 Mtetra
.016 .458 .871 r
.24867 .54834 .25616 .55424 .26675 .55846 .25926 .55257 Mtetra
.037 .473 .881 r
.25926 .55257 .26675 .55846 .27744 .56254 .26997 .55665 Mtetra
.059 .489 .891 r
.26997 .55665 .27744 .56254 .28824 .56645 .28078 .56057 Mtetra
.083 .505 .901 r
.28078 .56057 .28824 .56645 .29915 .57018 .2917 .56431 Mtetra
.109 .522 .911 r
.2917 .56431 .29915 .57018 .31017 .57371 .30273 .56785 Mtetra
.135 .54 .921 r
.30273 .56785 .31017 .57371 .32129 .57703 .31387 .57117 Mtetra
.163 .557 .93 r
.31387 .57117 .32129 .57703 .33253 .58011 .32513 .57426 Mtetra
.191 .575 .939 r
.32513 .57426 .33253 .58011 .34388 .58294 .33649 .5771 Mtetra
.22 .593 .948 r
.33649 .5771 .34388 .58294 .35533 .58551 .34796 .57967 Mtetra
.249 .61 .955 r
.34796 .57967 .35533 .58551 .36689 .58778 .35955 .58195 Mtetra
.279 .628 .962 r
.35955 .58195 .36689 .58778 .37856 .58976 .37123 .58393 Mtetra
.309 .645 .968 r
.37123 .58393 .37856 .58976 .39033 .59142 .38303 .58559 Mtetra
.338 .661 .973 r
.38303 .58559 .39033 .59142 .4022 .59275 .39492 .58692 Mtetra
.367 .676 .976 r
.39492 .58692 .4022 .59275 .41417 .59372 .40692 .58789 Mtetra
.396 .691 .979 r
.40692 .58789 .41417 .59372 .42624 .59434 .41902 .58851 Mtetra
.424 .705 .981 r
.41902 .58851 .42624 .59434 .43841 .59458 .43122 .58874 Mtetra
.451 .718 .982 r
.43122 .58874 .43841 .59458 .45067 .59443 .4435 .58859 Mtetra
.477 .731 .982 r
.4435 .58859 .45067 .59443 .46301 .59389 .45588 .58804 Mtetra
.502 .742 .981 r
.45588 .58804 .46301 .59389 .47544 .59293 .46835 .58707 Mtetra
.526 .753 .979 r
.46835 .58707 .47544 .59293 .48796 .59155 .4809 .58568 Mtetra
.549 .762 .976 r
.4809 .58568 .48796 .59155 .50055 .58974 .49353 .58386 Mtetra
.571 .771 .973 r
.49353 .58386 .50055 .58974 .51321 .5875 .50623 .58161 Mtetra
.592 .779 .969 r
.50623 .58161 .51321 .5875 .52595 .58482 .51901 .5789 Mtetra
.611 .786 .965 r
.51901 .5789 .52595 .58482 .53875 .58169 .53185 .57576 Mtetra
.63 .793 .96 r
.53185 .57576 .53875 .58169 .55162 .57811 .54476 .57215 Mtetra
.647 .798 .955 r
.54476 .57215 .55162 .57811 .56454 .57408 .55772 .5681 Mtetra
.663 .804 .95 r
.55772 .5681 .56454 .57408 .57751 .56959 .57074 .56358 Mtetra
.679 .808 .944 r
.57074 .56358 .57751 .56959 .59053 .56465 .58381 .55861 Mtetra
.693 .812 .939 r
.58381 .55861 .59053 .56465 .60359 .55926 .59692 .55319 Mtetra
.706 .816 .933 r
.59692 .55319 .60359 .55926 .61669 .55342 .61007 .54732 Mtetra
.719 .819 .927 r
.61007 .54732 .61669 .55342 .62983 .54713 .62326 .541 Mtetra
.731 .822 .921 r
.62326 .541 .62983 .54713 .64299 .54041 .63647 .53423 Mtetra
.741 .824 .916 r
.63647 .53423 .64299 .54041 .65618 .53325 .64971 .52704 Mtetra
.752 .826 .91 r
.64971 .52704 .65618 .53325 .66939 .52567 .66298 .51941 Mtetra
.761 .828 .904 r
.66298 .51941 .66939 .52567 .68261 .51767 .67626 .51137 Mtetra
.77 .83 .899 r
.67626 .51137 .68261 .51767 .69585 .50927 .68955 .50292 Mtetra
.778 .831 .894 r
.68955 .50292 .69585 .50927 .70909 .50048 .70285 .49408 Mtetra
.785 .833 .888 r
.70285 .49408 .70909 .50048 .72234 .4913 .71615 .48485 Mtetra
.792 .834 .883 r
.71615 .48485 .72234 .4913 .73558 .48175 .72946 .47525 Mtetra
.799 .835 .879 r
.72946 .47525 .73558 .48175 .74883 .47185 .74276 .46529 Mtetra
.805 .835 .874 r
.74276 .46529 .74883 .47185 .76206 .46161 .75606 .45499 Mtetra
.81 .836 .87 r
.75606 .45499 .76206 .46161 .77529 .45104 .76934 .44436 Mtetra
.816 .836 .865 r
.76934 .44436 .77529 .45104 .7885 .44016 .78262 .43343 Mtetra
.82 .837 .861 r
.78262 .43343 .7885 .44016 .8017 .42899 .79588 .42219 Mtetra
.825 .837 .858 r
.79588 .42219 .8017 .42899 .81488 .41755 .80912 .41068 Mtetra
.829 .837 .854 r
.80912 .41068 .81488 .41755 .82805 .40584 .82235 .39891 Mtetra
.832 .838 .851 r
.82235 .39891 .82805 .40584 .84119 .39389 .83555 .3869 Mtetra
.836 .838 .848 r
.83555 .3869 .84119 .39389 .85431 .38173 .84873 .37466 Mtetra
.839 .838 .845 r
.84873 .37466 .85431 .38173 .86741 .36935 .86189 .36222 Mtetra
.024 .452 .873 r
.23065 .5377 .23819 .54398 .24867 .54834 .24114 .54206 Mtetra
.043 .465 .881 r
.24114 .54206 .24867 .54834 .25926 .55257 .25174 .54629 Mtetra
.064 .48 .89 r
.25174 .54629 .25926 .55257 .26997 .55665 .26245 .55037 Mtetra
.087 .495 .899 r
.26245 .55037 .26997 .55665 .28078 .56057 .27328 .55429 Mtetra
.111 .51 .908 r
.27328 .55429 .28078 .56057 .2917 .56431 .28421 .55803 Mtetra
.135 .526 .917 r
.28421 .55803 .2917 .56431 .30273 .56785 .29526 .56157 Mtetra
.161 .543 .926 r
.29526 .56157 .30273 .56785 .31387 .57117 .30641 .56489 Mtetra
.188 .559 .934 r
.30641 .56489 .31387 .57117 .32513 .57426 .31768 .56798 Mtetra
.216 .576 .942 r
.31768 .56798 .32513 .57426 .33649 .5771 .32906 .57082 Mtetra
.244 .593 .949 r
.32906 .57082 .33649 .5771 .34796 .57967 .34055 .57339 Mtetra
.272 .609 .955 r
.34055 .57339 .34796 .57967 .35955 .58195 .35215 .57567 Mtetra
.3 .625 .961 r
.35215 .57567 .35955 .58195 .37123 .58393 .36386 .57764 Mtetra
.329 .641 .965 r
.36386 .57764 .37123 .58393 .38303 .58559 .37568 .5793 Mtetra
.357 .656 .969 r
.37568 .5793 .38303 .58559 .39492 .58692 .3876 .58062 Mtetra
.385 .67 .972 r
.3876 .58062 .39492 .58692 .40692 .58789 .39962 .58159 Mtetra
.412 .684 .974 r
.39962 .58159 .40692 .58789 .41902 .58851 .41175 .5822 Mtetra
.438 .697 .975 r
.41175 .5822 .41902 .58851 .43122 .58874 .42397 .58242 Mtetra
.464 .709 .975 r
.42397 .58242 .43122 .58874 .4435 .58859 .43629 .58226 Mtetra
.488 .721 .974 r
.43629 .58226 .4435 .58859 .45588 .58804 .4487 .5817 Mtetra
.512 .731 .973 r
.4487 .5817 .45588 .58804 .46835 .58707 .4612 .58072 Mtetra
.535 .741 .97 r
.4612 .58072 .46835 .58707 .4809 .58568 .47378 .57931 Mtetra
.557 .75 .967 r
.47378 .57931 .4809 .58568 .49353 .58386 .48645 .57748 Mtetra
.577 .758 .964 r
.48645 .57748 .49353 .58386 .50623 .58161 .49919 .5752 Mtetra
.597 .766 .96 r
.49919 .5752 .50623 .58161 .51901 .5789 .512 .57248 Mtetra
.616 .773 .956 r
.512 .57248 .51901 .5789 .53185 .57576 .52489 .56931 Mtetra
.633 .779 .951 r
.52489 .56931 .53185 .57576 .54476 .57215 .53783 .56569 Mtetra
.65 .785 .946 r
.53783 .56569 .54476 .57215 .55772 .5681 .55084 .5616 Mtetra
.665 .79 .941 r
.55084 .5616 .55772 .5681 .57074 .56358 .56391 .55707 Mtetra
.68 .794 .935 r
.56391 .55707 .57074 .56358 .58381 .55861 .57702 .55207 Mtetra
.693 .798 .93 r
.57702 .55207 .58381 .55861 .59692 .55319 .59018 .54661 Mtetra
.706 .802 .924 r
.59018 .54661 .59692 .55319 .61007 .54732 .60338 .54071 Mtetra
.718 .805 .919 r
.60338 .54071 .61007 .54732 .62326 .541 .61661 .53435 Mtetra
.729 .808 .913 r
.61661 .53435 .62326 .541 .63647 .53423 .62988 .52756 Mtetra
.74 .811 .908 r
.62988 .52756 .63647 .53423 .64971 .52704 .64317 .52032 Mtetra
.749 .813 .902 r
.64317 .52032 .64971 .52704 .66298 .51941 .65649 .51266 Mtetra
.759 .815 .897 r
.65649 .51266 .66298 .51941 .67626 .51137 .66982 .50457 Mtetra
.767 .817 .892 r
.66982 .50457 .67626 .51137 .68955 .50292 .68317 .49608 Mtetra
.775 .818 .887 r
.68317 .49608 .68955 .50292 .70285 .49408 .69653 .48719 Mtetra
.782 .82 .882 r
.69653 .48719 .70285 .49408 .71615 .48485 .70989 .47791 Mtetra
.789 .821 .877 r
.70989 .47791 .71615 .48485 .72946 .47525 .72325 .46826 Mtetra
.796 .822 .873 r
.72325 .46826 .72946 .47525 .74276 .46529 .73661 .45826 Mtetra
.802 .823 .868 r
.73661 .45826 .74276 .46529 .75606 .45499 .74997 .4479 Mtetra
.807 .824 .864 r
.74997 .4479 .75606 .45499 .76934 .44436 .76331 .43722 Mtetra
.812 .825 .86 r
.76331 .43722 .76934 .44436 .78262 .43343 .77665 .42623 Mtetra
.817 .825 .856 r
.77665 .42623 .78262 .43343 .79588 .42219 .78997 .41494 Mtetra
.821 .826 .853 r
.78997 .41494 .79588 .42219 .80912 .41068 .80327 .40337 Mtetra
.825 .827 .849 r
.80327 .40337 .80912 .41068 .82235 .39891 .81656 .39154 Mtetra
.829 .827 .846 r
.81656 .39154 .82235 .39891 .83555 .3869 .82982 .37947 Mtetra
.832 .827 .843 r
.82982 .37947 .83555 .3869 .84873 .37466 .84306 .36717 Mtetra
.835 .828 .841 r
.84306 .36717 .84873 .37466 .86189 .36222 .85628 .35467 Mtetra
.051 .459 .881 r
.22308 .53105 .23065 .5377 .24114 .54206 .23358 .5354 Mtetra
.07 .471 .889 r
.23358 .5354 .24114 .54206 .25174 .54629 .24419 .53962 Mtetra
.091 .485 .897 r
.24419 .53962 .25174 .54629 .26245 .55037 .25491 .5437 Mtetra
.113 .499 .905 r
.25491 .5437 .26245 .55037 .27328 .55429 .26574 .54761 Mtetra
.136 .514 .913 r
.26574 .54761 .27328 .55429 .28421 .55803 .27669 .55134 Mtetra
.161 .529 .921 r
.27669 .55134 .28421 .55803 .29526 .56157 .28774 .55488 Mtetra
.186 .545 .929 r
.28774 .55488 .29526 .56157 .30641 .56489 .29891 .55819 Mtetra
.212 .56 .936 r
.29891 .55819 .30641 .56489 .31768 .56798 .3102 .56127 Mtetra
.239 .576 .942 r
.3102 .56127 .31768 .56798 .32906 .57082 .32159 .5641 Mtetra
.266 .592 .948 r
.32159 .5641 .32906 .57082 .34055 .57339 .3331 .56666 Mtetra
.293 .607 .953 r
.3331 .56666 .34055 .57339 .35215 .57567 .34472 .56893 Mtetra
.32 .622 .958 r
.34472 .56893 .35215 .57567 .36386 .57764 .35645 .57089 Mtetra
.347 .636 .961 r
.35645 .57089 .36386 .57764 .37568 .5793 .36828 .57254 Mtetra
.374 .65 .964 r
.36828 .57254 .37568 .5793 .3876 .58062 .38023 .57385 Mtetra
.4 .664 .966 r
.38023 .57385 .3876 .58062 .39962 .58159 .39228 .57481 Mtetra
.426 .676 .967 r
.39228 .57481 .39962 .58159 .41175 .5822 .40443 .5754 Mtetra
.451 .689 .967 r
.40443 .5754 .41175 .5822 .42397 .58242 .41668 .57561 Mtetra
.475 .7 .967 r
.41668 .57561 .42397 .58242 .43629 .58226 .42902 .57544 Mtetra
.499 .711 .966 r
.42902 .57544 .43629 .58226 .4487 .5817 .44146 .57485 Mtetra
.521 .72 .964 r
.44146 .57485 .4487 .5817 .4612 .58072 .45399 .57386 Mtetra
.543 .73 .961 r
.45399 .57386 .4612 .58072 .47378 .57931 .46661 .57244 Mtetra
.563 .738 .958 r
.46661 .57244 .47378 .57931 .48645 .57748 .47931 .57058 Mtetra
.583 .746 .954 r
.47931 .57058 .48645 .57748 .49919 .5752 .49208 .56829 Mtetra
.601 .753 .95 r
.49208 .56829 .49919 .5752 .512 .57248 .50494 .56555 Mtetra
.619 .76 .946 r
.50494 .56555 .512 .57248 .52489 .56931 .51786 .56235 Mtetra
.635 .766 .941 r
.51786 .56235 .52489 .56931 .53783 .56569 .53085 .5587 Mtetra
.651 .771 .937 r
.53085 .5587 .53783 .56569 .55084 .5616 .5439 .5546 Mtetra
.666 .776 .931 r
.5439 .5546 .55084 .5616 .56391 .55707 .557 .55003 Mtetra
.68 .78 .926 r
.557 .55003 .56391 .55707 .57702 .55207 .57016 .545 Mtetra
.693 .784 .921 r
.57016 .545 .57702 .55207 .59018 .54661 .58337 .53952 Mtetra
.705 .788 .916 r
.58337 .53952 .59018 .54661 .60338 .54071 .59661 .53358 Mtetra
.717 .791 .91 r
.59661 .53358 .60338 .54071 .61661 .53435 .6099 .5272 Mtetra
.728 .794 .905 r
.6099 .5272 .61661 .53435 .62988 .52756 .62321 .52036 Mtetra
.738 .797 .9 r
.62321 .52036 .62988 .52756 .64317 .52032 .63656 .51309 Mtetra
.747 .8 .895 r
.63656 .51309 .64317 .52032 .65649 .51266 .64992 .50539 Mtetra
.756 .802 .89 r
.64992 .50539 .65649 .51266 .66982 .50457 .66331 .49727 Mtetra
.764 .804 .885 r
.66331 .49727 .66982 .50457 .68317 .49608 .67671 .48874 Mtetra
.772 .806 .88 r
.67671 .48874 .68317 .49608 .69653 .48719 .69012 .4798 Mtetra
.779 .807 .875 r
.69012 .4798 .69653 .48719 .70989 .47791 .70354 .47049 Mtetra
.786 .809 .871 r
.70354 .47049 .70989 .47791 .72325 .46826 .71696 .46079 Mtetra
.792 .81 .867 r
.71696 .46079 .72325 .46826 .73661 .45826 .73038 .45074 Mtetra
.798 .811 .862 r
.73038 .45074 .73661 .45826 .74997 .4479 .74379 .44034 Mtetra
.803 .812 .858 r
.74379 .44034 .74997 .4479 .76331 .43722 .75719 .42961 Mtetra
.808 .813 .855 r
.75719 .42961 .76331 .43722 .77665 .42623 .77059 .41857 Mtetra
.813 .814 .851 r
.77059 .41857 .77665 .42623 .78997 .41494 .78397 .40723 Mtetra
.817 .815 .848 r
.78397 .40723 .78997 .41494 .80327 .40337 .79733 .39561 Mtetra
.821 .816 .845 r
.79733 .39561 .80327 .40337 .81656 .39154 .81068 .38373 Mtetra
.825 .817 .842 r
.81068 .38373 .81656 .39154 .82982 .37947 .824 .3716 Mtetra
.828 .817 .839 r
.824 .3716 .82982 .37947 .84306 .36717 .83731 .35925 Mtetra
.831 .818 .836 r
.83731 .35925 .84306 .36717 .85628 .35467 .85059 .34669 Mtetra
.077 .464 .887 r
.21548 .52402 .22308 .53105 .23358 .5354 .22599 .52836 Mtetra
.096 .477 .895 r
.22599 .52836 .23358 .5354 .24419 .53962 .2366 .53257 Mtetra
.117 .489 .902 r
.2366 .53257 .24419 .53962 .25491 .5437 .24733 .53663 Mtetra
.138 .503 .909 r
.24733 .53663 .25491 .5437 .26574 .54761 .25817 .54053 Mtetra
.161 .517 .916 r
.25817 .54053 .26574 .54761 .27669 .55134 .26913 .54424 Mtetra
.185 .531 .923 r
.26913 .54424 .27669 .55134 .28774 .55488 .2802 .54776 Mtetra
.209 .546 .929 r
.2802 .54776 .28774 .55488 .29891 .55819 .29138 .55106 Mtetra
.235 .56 .935 r
.29138 .55106 .29891 .55819 .3102 .56127 .30268 .55412 Mtetra
.26 .575 .941 r
.30268 .55412 .3102 .56127 .32159 .5641 .31409 .55693 Mtetra
.286 .589 .946 r
.31409 .55693 .32159 .5641 .3331 .56666 .32561 .55948 Mtetra
.312 .604 .95 r
.32561 .55948 .3331 .56666 .34472 .56893 .33725 .56173 Mtetra
.338 .618 .953 r
.33725 .56173 .34472 .56893 .35645 .57089 .34899 .56368 Mtetra
.364 .631 .956 r
.34899 .56368 .35645 .57089 .36828 .57254 .36085 .56531 Mtetra
.389 .644 .958 r
.36085 .56531 .36828 .57254 .38023 .57385 .37281 .5666 Mtetra
.414 .657 .959 r
.37281 .5666 .38023 .57385 .39228 .57481 .38488 .56754 Mtetra
.438 .668 .959 r
.38488 .56754 .39228 .57481 .40443 .5754 .39706 .56812 Mtetra
.462 .68 .959 r
.39706 .56812 .40443 .5754 .41668 .57561 .40933 .56831 Mtetra
.485 .69 .958 r
.40933 .56831 .41668 .57561 .42902 .57544 .4217 .56811 Mtetra
.507 .7 .957 r
.4217 .56811 .42902 .57544 .44146 .57485 .43417 .56751 Mtetra
.529 .709 .954 r
.43417 .56751 .44146 .57485 .45399 .57386 .44673 .5665 Mtetra
.549 .718 .951 r
.44673 .5665 .45399 .57386 .46661 .57244 .45938 .56505 Mtetra
.568 .726 .948 r
.45938 .56505 .46661 .57244 .47931 .57058 .47211 .56318 Mtetra
.587 .734 .945 r
.47211 .56318 .47931 .57058 .49208 .56829 .48492 .56086 Mtetra
.605 .74 .941 r
.48492 .56086 .49208 .56829 .50494 .56555 .49781 .55809 Mtetra
.621 .747 .936 r
.49781 .55809 .50494 .56555 .51786 .56235 .51077 .55488 Mtetra
.637 .752 .932 r
.51077 .55488 .51786 .56235 .53085 .5587 .5238 .5512 Mtetra
.652 .758 .927 r
.5238 .5512 .53085 .5587 .5439 .5546 .53689 .54707 Mtetra
.666 .763 .922 r
.53689 .54707 .5439 .5546 .557 .55003 .55004 .54247 Mtetra
.68 .767 .917 r
.55004 .54247 .557 .55003 .57016 .545 .56324 .53742 Mtetra
.692 .771 .912 r
.56324 .53742 .57016 .545 .58337 .53952 .57648 .53191 Mtetra
.704 .775 .907 r
.57648 .53191 .58337 .53952 .59661 .53358 .58978 .52594 Mtetra
.715 .778 .902 r
.58978 .52594 .59661 .53358 .6099 .5272 .60311 .51952 Mtetra
.725 .781 .897 r
.60311 .51952 .6099 .5272 .62321 .52036 .61647 .51266 Mtetra
.735 .784 .892 r
.61647 .51266 .62321 .52036 .63656 .51309 .62987 .50535 Mtetra
.744 .787 .887 r
.62987 .50535 .63656 .51309 .64992 .50539 .64328 .49762 Mtetra
.753 .789 .882 r
.64328 .49762 .64992 .50539 .66331 .49727 .65672 .48946 Mtetra
.761 .791 .878 r
.65672 .48946 .66331 .49727 .67671 .48874 .67018 .48089 Mtetra
.768 .793 .873 r
.67018 .48089 .67671 .48874 .69012 .4798 .68364 .47192 Mtetra
.776 .795 .869 r
.68364 .47192 .69012 .4798 .70354 .47049 .69711 .46256 Mtetra
.782 .797 .865 r
.69711 .46256 .70354 .47049 .71696 .46079 .71059 .45283 Mtetra
.788 .798 .861 r
.71059 .45283 .71696 .46079 .73038 .45074 .72406 .44273 Mtetra
.794 .8 .857 r
.72406 .44273 .73038 .45074 .74379 .44034 .73753 .43229 Mtetra
.799 .801 .853 r
.73753 .43229 .74379 .44034 .75719 .42961 .75099 .42152 Mtetra
.804 .802 .849 r
.75099 .42152 .75719 .42961 .77059 .41857 .76444 .41044 Mtetra
.809 .803 .846 r
.76444 .41044 .77059 .41857 .78397 .40723 .77788 .39905 Mtetra
.813 .805 .843 r
.77788 .39905 .78397 .40723 .79733 .39561 .79131 .38739 Mtetra
.817 .806 .84 r
.79131 .38739 .79733 .39561 .81068 .38373 .80471 .37546 Mtetra
.821 .806 .837 r
.80471 .37546 .81068 .38373 .824 .3716 .8181 .36329 Mtetra
.824 .807 .835 r
.8181 .36329 .824 .3716 .83731 .35925 .83146 .35089 Mtetra
.827 .808 .832 r
.83146 .35089 .83731 .35925 .85059 .34669 .8448 .33828 Mtetra
.102 .469 .892 r
.20785 .51663 .21548 .52402 .22599 .52836 .21837 .52094 Mtetra
.121 .481 .898 r
.21837 .52094 .22599 .52836 .2366 .53257 .22899 .52512 Mtetra
.141 .493 .905 r
.22899 .52512 .2366 .53257 .24733 .53663 .23972 .52916 Mtetra
.162 .506 .911 r
.23972 .52916 .24733 .53663 .25817 .54053 .25057 .53303 Mtetra
.184 .519 .917 r
.25057 .53303 .25817 .54053 .26913 .54424 .26154 .53672 Mtetra
.208 .532 .923 r
.26154 .53672 .26913 .54424 .2802 .54776 .27262 .54022 Mtetra
.231 .546 .928 r
.27262 .54022 .2802 .54776 .29138 .55106 .28381 .54349 Mtetra
.255 .56 .933 r
.28381 .54349 .29138 .55106 .30268 .55412 .29512 .54653 Mtetra
.28 .573 .938 r
.29512 .54653 .30268 .55412 .31409 .55693 .30654 .54932 Mtetra
.305 .587 .942 r
.30654 .54932 .31409 .55693 .32561 .55948 .31808 .55184 Mtetra
.33 .6 .945 r
.31808 .55184 .32561 .55948 .33725 .56173 .32973 .55407 Mtetra
.354 .613 .948 r
.32973 .55407 .33725 .56173 .34899 .56368 .3415 .556 Mtetra
.379 .625 .95 r
.3415 .556 .34899 .56368 .36085 .56531 .35337 .5576 Mtetra
.403 .637 .951 r
.35337 .5576 .36085 .56531 .37281 .5666 .36536 .55887 Mtetra
.427 .649 .951 r
.36536 .55887 .37281 .5666 .38488 .56754 .37745 .55979 Mtetra
.45 .66 .951 r
.37745 .55979 .38488 .56754 .39706 .56812 .38964 .56034 Mtetra
.472 .671 .95 r
.38964 .56034 .39706 .56812 .40933 .56831 .40194 .56051 Mtetra
.494 .681 .949 r
.40194 .56051 .40933 .56831 .4217 .56811 .41434 .56029 Mtetra
.515 .69 .947 r
.41434 .56029 .4217 .56811 .43417 .56751 .42683 .55966 Mtetra
.535 .699 .945 r
.42683 .55966 .43417 .56751 .44673 .5665 .43942 .55862 Mtetra
.554 .707 .942 r
.43942 .55862 .44673 .5665 .45938 .56505 .4521 .55716 Mtetra
.573 .714 .938 r
.4521 .55716 .45938 .56505 .47211 .56318 .46486 .55525 Mtetra
.59 .721 .935 r
.46486 .55525 .47211 .56318 .48492 .56086 .47771 .55291 Mtetra
.607 .728 .931 r
.47771 .55291 .48492 .56086 .49781 .55809 .49063 .55012 Mtetra
.623 .734 .927 r
.49063 .55012 .49781 .55809 .51077 .55488 .50363 .54688 Mtetra
.638 .74 .922 r
.50363 .54688 .51077 .55488 .5238 .5512 .51669 .54317 Mtetra
.652 .745 .918 r
.51669 .54317 .5238 .5512 .53689 .54707 .52982 .53901 Mtetra
.666 .75 .913 r
.52982 .53901 .53689 .54707 .55004 .54247 .543 .53439 Mtetra
.679 .754 .908 r
.543 .53439 .55004 .54247 .56324 .53742 .55625 .52931 Mtetra
.691 .758 .903 r
.55625 .52931 .56324 .53742 .57648 .53191 .56954 .52377 Mtetra
.702 .762 .899 r
.56954 .52377 .57648 .53191 .58978 .52594 .58287 .51777 Mtetra
.713 .765 .894 r
.58287 .51777 .58978 .52594 .60311 .51952 .59625 .51132 Mtetra
.723 .769 .889 r
.59625 .51132 .60311 .51952 .61647 .51266 .60966 .50443 Mtetra
.732 .772 .884 r
.60966 .50443 .61647 .51266 .62987 .50535 .6231 .49709 Mtetra
.741 .774 .88 r
.6231 .49709 .62987 .50535 .64328 .49762 .63657 .48932 Mtetra
.75 .777 .875 r
.63657 .48932 .64328 .49762 .65672 .48946 .65006 .48113 Mtetra
.758 .779 .871 r
.65006 .48113 .65672 .48946 .67018 .48089 .66356 .47253 Mtetra
.765 .781 .867 r
.66356 .47253 .67018 .48089 .68364 .47192 .67708 .46353 Mtetra
.772 .783 .862 r
.67708 .46353 .68364 .47192 .69711 .46256 .6906 .45414 Mtetra
.778 .785 .858 r
.6906 .45414 .69711 .46256 .71059 .45283 .70413 .44437 Mtetra
.784 .787 .855 r
.70413 .44437 .71059 .45283 .72406 .44273 .71766 .43424 Mtetra
.79 .789 .851 r
.71766 .43424 .72406 .44273 .73753 .43229 .73119 .42376 Mtetra
.795 .79 .848 r
.73119 .42376 .73753 .43229 .75099 .42152 .74471 .41296 Mtetra
.8 .792 .844 r
.74471 .41296 .75099 .42152 .76444 .41044 .75822 .40183 Mtetra
.805 .793 .841 r
.75822 .40183 .76444 .41044 .77788 .39905 .77171 .39041 Mtetra
.809 .794 .838 r
.77171 .39041 .77788 .39905 .79131 .38739 .78519 .37871 Mtetra
.813 .795 .835 r
.78519 .37871 .79131 .38739 .80471 .37546 .79866 .36674 Mtetra
.817 .797 .833 r
.79866 .36674 .80471 .37546 .8181 .36329 .81211 .35453 Mtetra
.82 .798 .83 r
.81211 .35453 .8181 .36329 .83146 .35089 .82553 .34209 Mtetra
.823 .799 .828 r
.82553 .34209 .83146 .35089 .8448 .33828 .83893 .32944 Mtetra
.126 .473 .895 r
.2002 .50886 .20785 .51663 .21837 .52094 .21071 .51313 Mtetra
.144 .484 .901 r
.21071 .51313 .21837 .52094 .22899 .52512 .22134 .51728 Mtetra
.164 .496 .906 r
.22134 .51728 .22899 .52512 .23972 .52916 .23209 .52129 Mtetra
.185 .508 .911 r
.23209 .52129 .23972 .52916 .25057 .53303 .24294 .52513 Mtetra
.206 .52 .917 r
.24294 .52513 .25057 .53303 .26154 .53672 .25392 .52879 Mtetra
.229 .533 .922 r
.25392 .52879 .26154 .53672 .27262 .54022 .265 .53225 Mtetra
.252 .545 .926 r
.265 .53225 .27262 .54022 .28381 .54349 .27621 .5355 Mtetra
.275 .558 .93 r
.27621 .5355 .28381 .54349 .29512 .54653 .28753 .53851 Mtetra
.298 .571 .934 r
.28753 .53851 .29512 .54653 .30654 .54932 .29897 .54126 Mtetra
.322 .583 .937 r
.29897 .54126 .30654 .54932 .31808 .55184 .31052 .54375 Mtetra
.346 .596 .939 r
.31052 .54375 .31808 .55184 .32973 .55407 .32218 .54595 Mtetra
.369 .608 .941 r
.32218 .54595 .32973 .55407 .3415 .556 .33396 .54785 Mtetra
.392 .619 .942 r
.33396 .54785 .3415 .556 .35337 .5576 .34586 .54942 Mtetra
.415 .631 .943 r
.34586 .54942 .35337 .5576 .36536 .55887 .35786 .55066 Mtetra
.438 .641 .943 r
.35786 .55066 .36536 .55887 .37745 .55979 .36997 .55155 Mtetra
.46 .652 .942 r
.36997 .55155 .37745 .55979 .38964 .56034 .38219 .55207 Mtetra
.481 .662 .941 r
.38219 .55207 .38964 .56034 .40194 .56051 .39451 .55221 Mtetra
.501 .671 .94 r
.39451 .55221 .40194 .56051 .41434 .56029 .40693 .55196 Mtetra
.521 .68 .937 r
.40693 .55196 .41434 .56029 .42683 .55966 .41945 .55131 Mtetra
.54 .688 .935 r
.41945 .55131 .42683 .55966 .43942 .55862 .43207 .55024 Mtetra
.559 .696 .932 r
.43207 .55024 .43942 .55862 .4521 .55716 .44477 .54874 Mtetra
.576 .703 .928 r
.44477 .54874 .4521 .55716 .46486 .55525 .45756 .54681 Mtetra
.593 .71 .925 r
.45756 .54681 .46486 .55525 .47771 .55291 .47044 .54444 Mtetra
.609 .716 .921 r
.47044 .54444 .47771 .55291 .49063 .55012 .48339 .54162 Mtetra
.624 .722 .917 r
.48339 .54162 .49063 .55012 .50363 .54688 .49642 .53835 Mtetra
.639 .728 .913 r
.49642 .53835 .50363 .54688 .51669 .54317 .50952 .53462 Mtetra
.652 .733 .908 r
.50952 .53462 .51669 .54317 .52982 .53901 .52269 .53043 Mtetra
.665 .737 .904 r
.52269 .53043 .52982 .53901 .543 .53439 .53591 .52578 Mtetra
.678 .742 .899 r
.53591 .52578 .543 .53439 .55625 .52931 .54919 .52067 Mtetra
.689 .746 .895 r
.54919 .52067 .55625 .52931 .56954 .52377 .56253 .5151 Mtetra
.7 .75 .89 r
.56253 .5151 .56954 .52377 .58287 .51777 .5759 .50908 Mtetra
.71 .753 .886 r
.5759 .50908 .58287 .51777 .59625 .51132 .58932 .5026 Mtetra
.72 .757 .881 r
.58932 .5026 .59625 .51132 .60966 .50443 .60278 .49568 Mtetra
.729 .76 .877 r
.60278 .49568 .60966 .50443 .6231 .49709 .61627 .48831 Mtetra
.738 .762 .872 r
.61627 .48831 .6231 .49709 .63657 .48932 .62978 .48052 Mtetra
.746 .765 .868 r
.62978 .48052 .63657 .48932 .65006 .48113 .64332 .4723 Mtetra
.754 .768 .864 r
.64332 .4723 .65006 .48113 .66356 .47253 .65687 .46367 Mtetra
.761 .77 .86 r
.65687 .46367 .66356 .47253 .67708 .46353 .67044 .45463 Mtetra
.768 .772 .856 r
.67044 .45463 .67708 .46353 .6906 .45414 .68402 .44521 Mtetra
.774 .774 .852 r
.68402 .44521 .6906 .45414 .70413 .44437 .6976 .43541 Mtetra
.78 .776 .849 r
.6976 .43541 .70413 .44437 .71766 .43424 .71118 .42525 Mtetra
.786 .778 .845 r
.71118 .42525 .71766 .43424 .73119 .42376 .72476 .41475 Mtetra
.791 .78 .842 r
.72476 .41475 .73119 .42376 .74471 .41296 .73834 .40391 Mtetra
.796 .781 .839 r
.73834 .40391 .74471 .41296 .75822 .40183 .7519 .39275 Mtetra
.801 .783 .836 r
.7519 .39275 .75822 .40183 .77171 .39041 .76546 .3813 Mtetra
.805 .784 .833 r
.76546 .3813 .77171 .39041 .78519 .37871 .779 .36957 Mtetra
.809 .786 .831 r
.779 .36957 .78519 .37871 .79866 .36674 .79252 .35757 Mtetra
.813 .787 .828 r
.79252 .35757 .79866 .36674 .81211 .35453 .80603 .34533 Mtetra
.816 .788 .826 r
.80603 .34533 .81211 .35453 .82553 .34209 .81951 .33285 Mtetra
.819 .789 .824 r
.81951 .33285 .82553 .34209 .83893 .32944 .83298 .32017 Mtetra
.149 .477 .897 r
.19252 .50071 .2002 .50886 .21071 .51313 .20304 .50495 Mtetra
.167 .487 .901 r
.20304 .50495 .21071 .51313 .22134 .51728 .21367 .50905 Mtetra
.186 .498 .906 r
.21367 .50905 .22134 .51728 .23209 .52129 .22442 .51302 Mtetra
.206 .509 .911 r
.22442 .51302 .23209 .52129 .24294 .52513 .23529 .51682 Mtetra
.227 .521 .915 r
.23529 .51682 .24294 .52513 .25392 .52879 .24627 .52044 Mtetra
.248 .532 .919 r
.24627 .52044 .25392 .52879 .265 .53225 .25736 .52386 Mtetra
.27 .544 .923 r
.25736 .52386 .265 .53225 .27621 .5355 .26858 .52707 Mtetra
.293 .556 .926 r
.26858 .52707 .27621 .5355 .28753 .53851 .27991 .53004 Mtetra
.315 .568 .929 r
.27991 .53004 .28753 .53851 .29897 .54126 .29136 .53276 Mtetra
.338 .58 .931 r
.29136 .53276 .29897 .54126 .31052 .54375 .30292 .53521 Mtetra
.36 .591 .933 r
.30292 .53521 .31052 .54375 .32218 .54595 .3146 .53737 Mtetra
.383 .602 .934 r
.3146 .53737 .32218 .54595 .33396 .54785 .3264 .53923 Mtetra
.405 .613 .935 r
.3264 .53923 .33396 .54785 .34586 .54942 .33831 .54077 Mtetra
.426 .624 .935 r
.33831 .54077 .34586 .54942 .35786 .55066 .35033 .54197 Mtetra
.448 .634 .934 r
.35033 .54197 .35786 .55066 .36997 .55155 .36245 .54282 Mtetra
.468 .644 .933 r
.36245 .54282 .36997 .55155 .38219 .55207 .37469 .54331 Mtetra
.489 .653 .932 r
.37469 .54331 .38219 .55207 .39451 .55221 .38703 .54342 Mtetra
.508 .662 .93 r
.38703 .54342 .39451 .55221 .40693 .55196 .39948 .54313 Mtetra
.527 .67 .928 r
.39948 .54313 .40693 .55196 .41945 .55131 .41202 .54245 Mtetra
.545 .678 .925 r
.41202 .54245 .41945 .55131 .43207 .55024 .42466 .54134 Mtetra
.562 .685 .922 r
.42466 .54134 .43207 .55024 .44477 .54874 .43739 .53982 Mtetra
.579 .692 .919 r
.43739 .53982 .44477 .54874 .45756 .54681 .45021 .53786 Mtetra
.595 .699 .915 r
.45021 .53786 .45756 .54681 .47044 .54444 .46312 .53545 Mtetra
.61 .705 .911 r
.46312 .53545 .47044 .54444 .48339 .54162 .4761 .5326 Mtetra
.625 .711 .907 r
.4761 .5326 .48339 .54162 .49642 .53835 .48917 .5293 Mtetra
.639 .716 .903 r
.48917 .5293 .49642 .53835 .50952 .53462 .5023 .52554 Mtetra
.652 .721 .899 r
.5023 .52554 .50952 .53462 .52269 .53043 .5155 .52132 Mtetra
.664 .726 .895 r
.5155 .52132 .52269 .53043 .53591 .52578 .52876 .51665 Mtetra
.676 .73 .891 r
.52876 .51665 .53591 .52578 .54919 .52067 .54208 .51151 Mtetra
.687 .734 .886 r
.54208 .51151 .54919 .52067 .56253 .5151 .55545 .50591 Mtetra
.698 .738 .882 r
.55545 .50591 .56253 .5151 .5759 .50908 .56887 .49986 Mtetra
.708 .742 .878 r
.56887 .49986 .5759 .50908 .58932 .5026 .58233 .49335 Mtetra
.717 .745 .874 r
.58233 .49335 .58932 .5026 .60278 .49568 .59583 .4864 Mtetra
.726 .748 .869 r
.59583 .4864 .60278 .49568 .61627 .48831 .60937 .47901 Mtetra
.735 .751 .865 r
.60937 .47901 .61627 .48831 .62978 .48052 .62293 .47119 Mtetra
.743 .754 .861 r
.62293 .47119 .62978 .48052 .64332 .4723 .63651 .46295 Mtetra
.75 .756 .857 r
.63651 .46295 .64332 .4723 .65687 .46367 .65011 .45429 Mtetra
.757 .759 .854 r
.65011 .45429 .65687 .46367 .67044 .45463 .66373 .44523 Mtetra
.764 .761 .85 r
.66373 .44523 .67044 .45463 .68402 .44521 .67736 .43578 Mtetra
.77 .763 .847 r
.67736 .43578 .68402 .44521 .6976 .43541 .69099 .42596 Mtetra
.776 .766 .843 r
.69099 .42596 .6976 .43541 .71118 .42525 .70463 .41578 Mtetra
.782 .768 .84 r
.70463 .41578 .71118 .42525 .72476 .41475 .71826 .40524 Mtetra
.787 .769 .837 r
.71826 .40524 .72476 .41475 .73834 .40391 .73189 .39438 Mtetra
.792 .771 .834 r
.73189 .39438 .73834 .40391 .7519 .39275 .74551 .3832 Mtetra
.797 .773 .831 r
.74551 .3832 .7519 .39275 .76546 .3813 .75912 .37172 Mtetra
.801 .775 .829 r
.75912 .37172 .76546 .3813 .779 .36957 .77272 .35996 Mtetra
.805 .776 .826 r
.77272 .35996 .779 .36957 .79252 .35757 .7863 .34794 Mtetra
.809 .778 .824 r
.7863 .34794 .79252 .35757 .80603 .34533 .79986 .33567 Mtetra
.812 .779 .822 r
.79986 .33567 .80603 .34533 .81951 .33285 .81341 .32317 Mtetra
.815 .78 .82 r
.81341 .32317 .81951 .33285 .83298 .32017 .82693 .31046 Mtetra
.17 .479 .897 r
.18481 .49219 .19252 .50071 .20304 .50495 .19534 .49638 Mtetra
.188 .489 .901 r
.19534 .49638 .20304 .50495 .21367 .50905 .20598 .50044 Mtetra
.207 .499 .905 r
.20598 .50044 .21367 .50905 .22442 .51302 .21673 .50435 Mtetra
.226 .51 .909 r
.21673 .50435 .22442 .51302 .23529 .51682 .2276 .5081 Mtetra
.246 .521 .912 r
.2276 .5081 .23529 .51682 .24627 .52044 .23859 .51167 Mtetra
.267 .532 .916 r
.23859 .51167 .24627 .52044 .25736 .52386 .2497 .51505 Mtetra
.288 .543 .919 r
.2497 .51505 .25736 .52386 .26858 .52707 .26092 .51821 Mtetra
.309 .554 .921 r
.26092 .51821 .26858 .52707 .27991 .53004 .27226 .52113 Mtetra
.331 .565 .923 r
.27226 .52113 .27991 .53004 .29136 .53276 .28372 .5238 Mtetra
.352 .576 .925 r
.28372 .5238 .29136 .53276 .30292 .53521 .2953 .52621 Mtetra
.373 .586 .926 r
.2953 .52621 .30292 .53521 .3146 .53737 .30699 .52833 Mtetra
.395 .597 .927 r
.30699 .52833 .3146 .53737 .3264 .53923 .3188 .53014 Mtetra
.416 .607 .927 r
.3188 .53014 .3264 .53923 .33831 .54077 .33072 .53164 Mtetra
.436 .617 .927 r
.33072 .53164 .33831 .54077 .35033 .54197 .34276 .5328 Mtetra
.456 .626 .926 r
.34276 .5328 .35033 .54197 .36245 .54282 .3549 .53361 Mtetra
.476 .635 .925 r
.3549 .53361 .36245 .54282 .37469 .54331 .36716 .53406 Mtetra
.495 .644 .923 r
.36716 .53406 .37469 .54331 .38703 .54342 .37952 .53413 Mtetra
.514 .653 .921 r
.37952 .53413 .38703 .54342 .39948 .54313 .39199 .5338 Mtetra
.532 .66 .918 r
.39199 .5338 .39948 .54313 .41202 .54245 .40455 .53308 Mtetra
.549 .668 .916 r
.40455 .53308 .41202 .54245 .42466 .54134 .41721 .53194 Mtetra
.566 .675 .913 r
.41721 .53194 .42466 .54134 .43739 .53982 .42997 .53038 Mtetra
.582 .682 .909 r
.42997 .53038 .43739 .53982 .45021 .53786 .44282 .52838 Mtetra
.597 .688 .906 r
.44282 .52838 .45021 .53786 .46312 .53545 .45575 .52595 Mtetra
.611 .694 .902 r
.45575 .52595 .46312 .53545 .4761 .5326 .46877 .52306 Mtetra
.625 .699 .898 r
.46877 .52306 .4761 .5326 .48917 .5293 .48186 .51973 Mtetra
.638 .705 .894 r
.48186 .51973 .48917 .5293 .5023 .52554 .49502 .51594 Mtetra
.651 .71 .89 r
.49502 .51594 .5023 .52554 .5155 .52132 .50826 .51169 Mtetra
.663 .714 .886 r
.50826 .51169 .5155 .52132 .52876 .51665 .52155 .50698 Mtetra
.674 .719 .882 r
.52155 .50698 .52876 .51665 .54208 .51151 .53491 .50182 Mtetra
.685 .723 .878 r
.53491 .50182 .54208 .51151 .55545 .50591 .54832 .49619 Mtetra
.696 .727 .874 r
.54832 .49619 .55545 .50591 .56887 .49986 .56178 .49011 Mtetra
.705 .73 .87 r
.56178 .49011 .56887 .49986 .58233 .49335 .57528 .48358 Mtetra
.714 .734 .866 r
.57528 .48358 .58233 .49335 .59583 .4864 .58882 .47661 Mtetra
.723 .737 .862 r
.58882 .47661 .59583 .4864 .60937 .47901 .6024 .46919 Mtetra
.731 .74 .858 r
.6024 .46919 .60937 .47901 .62293 .47119 .616 .46135 Mtetra
.739 .743 .855 r
.616 .46135 .62293 .47119 .63651 .46295 .62963 .45308 Mtetra
.747 .746 .851 r
.62963 .45308 .63651 .46295 .65011 .45429 .64328 .4444 Mtetra
.754 .748 .848 r
.64328 .4444 .65011 .45429 .66373 .44523 .65695 .43532 Mtetra
.76 .751 .844 r
.65695 .43532 .66373 .44523 .67736 .43578 .67062 .42585 Mtetra
.766 .753 .841 r
.67062 .42585 .67736 .43578 .69099 .42596 .68431 .41601 Mtetra
.772 .755 .838 r
.68431 .41601 .69099 .42596 .70463 .41578 .69799 .4058 Mtetra
.778 .758 .835 r
.69799 .4058 .70463 .41578 .71826 .40524 .71168 .39525 Mtetra
.783 .76 .832 r
.71168 .39525 .71826 .40524 .73189 .39438 .72536 .38437 Mtetra
.788 .762 .829 r
.72536 .38437 .73189 .39438 .74551 .3832 .73904 .37317 Mtetra
.792 .763 .827 r
.73904 .37317 .74551 .3832 .75912 .37172 .75271 .36167 Mtetra
.797 .765 .824 r
.75271 .36167 .75912 .37172 .77272 .35996 .76636 .3499 Mtetra
.801 .767 .822 r
.76636 .3499 .77272 .35996 .7863 .34794 .78 .33785 Mtetra
.804 .769 .82 r
.78 .33785 .7863 .34794 .79986 .33567 .79362 .32557 Mtetra
.808 .77 .818 r
.79362 .32557 .79986 .33567 .81341 .32317 .80722 .31305 Mtetra
.811 .772 .816 r
.80722 .31305 .81341 .32317 .82693 .31046 .8208 .30032 Mtetra
.191 .482 .896 r
.17708 .4833 .18481 .49219 .19534 .49638 .18761 .48743 Mtetra
.208 .491 .9 r
.18761 .48743 .19534 .49638 .20598 .50044 .19826 .49143 Mtetra
.226 .5 .903 r
.19826 .49143 .20598 .50044 .21673 .50435 .20902 .49529 Mtetra
.245 .51 .906 r
.20902 .49529 .21673 .50435 .2276 .5081 .2199 .49898 Mtetra
.264 .52 .909 r
.2199 .49898 .2276 .5081 .23859 .51167 .23089 .5025 Mtetra
.284 .531 .911 r
.23089 .5025 .23859 .51167 .2497 .51505 .242 .50582 Mtetra
.304 .541 .914 r
.242 .50582 .2497 .51505 .26092 .51821 .25323 .50892 Mtetra
.324 .551 .916 r
.25323 .50892 .26092 .51821 .27226 .52113 .26458 .51179 Mtetra
.345 .561 .917 r
.26458 .51179 .27226 .52113 .28372 .5238 .27605 .51441 Mtetra
.365 .572 .918 r
.27605 .51441 .28372 .5238 .2953 .52621 .28764 .51676 Mtetra
.386 .582 .919 r
.28764 .51676 .2953 .52621 .30699 .52833 .29935 .51883 Mtetra
.406 .591 .919 r
.29935 .51883 .30699 .52833 .3188 .53014 .31117 .52059 Mtetra
.426 .601 .919 r
.31117 .52059 .3188 .53014 .33072 .53164 .3231 .52204 Mtetra
.445 .61 .918 r
.3231 .52204 .33072 .53164 .34276 .5328 .33515 .52315 Mtetra
.464 .619 .917 r
.33515 .52315 .34276 .5328 .3549 .53361 .34732 .52392 Mtetra
.483 .628 .916 r
.34732 .52392 .3549 .53361 .36716 .53406 .35959 .52432 Mtetra
.501 .636 .914 r
.35959 .52432 .36716 .53406 .37952 .53413 .37197 .52434 Mtetra
.519 .644 .912 r
.37197 .52434 .37952 .53413 .39199 .5338 .38445 .52398 Mtetra
.536 .651 .909 r
.38445 .52398 .39199 .5338 .40455 .53308 .39704 .52321 Mtetra
.552 .658 .906 r
.39704 .52321 .40455 .53308 .41721 .53194 .40973 .52203 Mtetra
.568 .665 .903 r
.40973 .52203 .41721 .53194 .42997 .53038 .42251 .52043 Mtetra
.583 .672 .9 r
.42251 .52043 .42997 .53038 .44282 .52838 .43538 .51839 Mtetra
.598 .678 .897 r
.43538 .51839 .44282 .52838 .45575 .52595 .44834 .51592 Mtetra
.612 .684 .893 r
.44834 .51592 .45575 .52595 .46877 .52306 .46138 .513 Mtetra
.625 .689 .89 r
.46138 .513 .46877 .52306 .48186 .51973 .4745 .50964 Mtetra
.638 .694 .886 r
.4745 .50964 .48186 .51973 .49502 .51594 .4877 .50581 Mtetra
.65 .699 .882 r
.4877 .50581 .49502 .51594 .50826 .51169 .50096 .50153 Mtetra
.662 .704 .878 r
.50096 .50153 .50826 .51169 .52155 .50698 .51429 .4968 Mtetra
.673 .708 .874 r
.51429 .4968 .52155 .50698 .53491 .50182 .52768 .4916 Mtetra
.683 .712 .87 r
.52768 .4916 .53491 .50182 .54832 .49619 .54113 .48595 Mtetra
.693 .716 .867 r
.54113 .48595 .54832 .49619 .56178 .49011 .55462 .47985 Mtetra
.702 .72 .863 r
.55462 .47985 .56178 .49011 .57528 .48358 .56816 .47329 Mtetra
.711 .723 .859 r
.56816 .47329 .57528 .48358 .58882 .47661 .58175 .4663 Mtetra
.72 .727 .855 r
.58175 .4663 .58882 .47661 .6024 .46919 .59536 .45886 Mtetra
.728 .73 .852 r
.59536 .45886 .6024 .46919 .616 .46135 .60901 .45099 Mtetra
.736 .733 .848 r
.60901 .45099 .616 .46135 .62963 .45308 .62268 .44271 Mtetra
.743 .736 .845 r
.62268 .44271 .62963 .45308 .64328 .4444 .63638 .43401 Mtetra
.75 .738 .842 r
.63638 .43401 .64328 .4444 .65695 .43532 .65009 .42491 Mtetra
.756 .741 .838 r
.65009 .42491 .65695 .43532 .67062 .42585 .66382 .41542 Mtetra
.762 .743 .835 r
.66382 .41542 .67062 .42585 .68431 .41601 .67755 .40556 Mtetra
.768 .746 .833 r
.67755 .40556 .68431 .41601 .69799 .4058 .69129 .39534 Mtetra
.774 .748 .83 r
.69129 .39534 .69799 .4058 .71168 .39525 .70503 .38478 Mtetra
.779 .75 .827 r
.70503 .38478 .71168 .39525 .72536 .38437 .71876 .37388 Mtetra
.784 .752 .825 r
.71876 .37388 .72536 .38437 .73904 .37317 .73249 .36267 Mtetra
.788 .754 .822 r
.73249 .36267 .73904 .37317 .75271 .36167 .74621 .35116 Mtetra
.792 .756 .82 r
.74621 .35116 .75271 .36167 .76636 .3499 .75992 .33937 Mtetra
.796 .758 .818 r
.75992 .33937 .76636 .3499 .78 .33785 .77361 .32731 Mtetra
.8 .76 .816 r
.77361 .32731 .78 .33785 .79362 .32557 .78729 .31501 Mtetra
.804 .762 .814 r
.78729 .31501 .79362 .32557 .80722 .31305 .80095 .30248 Mtetra
.807 .763 .813 r
.80095 .30248 .80722 .31305 .8208 .30032 .81459 .28975 Mtetra
.21 .484 .895 r
.16933 .47404 .17708 .4833 .18761 .48743 .17987 .4781 Mtetra
.227 .492 .897 r
.17987 .4781 .18761 .48743 .19826 .49143 .19052 .48204 Mtetra
.244 .501 .9 r
.19052 .48204 .19826 .49143 .20902 .49529 .20128 .48583 Mtetra
.262 .51 .903 r
.20128 .48583 .20902 .49529 .2199 .49898 .21217 .48946 Mtetra
.281 .52 .905 r
.21217 .48946 .2199 .49898 .23089 .5025 .22317 .49291 Mtetra
.3 .529 .907 r
.22317 .49291 .23089 .5025 .242 .50582 .23429 .49616 Mtetra
.319 .539 .908 r
.23429 .49616 .242 .50582 .25323 .50892 .24553 .4992 Mtetra
.338 .548 .91 r
.24553 .4992 .25323 .50892 .26458 .51179 .25688 .50201 Mtetra
.358 .558 .911 r
.25688 .50201 .26458 .51179 .27605 .51441 .26836 .50457 Mtetra
.377 .568 .911 r
.26836 .50457 .27605 .51441 .28764 .51676 .27996 .50686 Mtetra
.397 .577 .912 r
.27996 .50686 .28764 .51676 .29935 .51883 .29167 .50887 Mtetra
.416 .586 .911 r
.29167 .50887 .29935 .51883 .31117 .52059 .30351 .51058 Mtetra
.435 .595 .911 r
.30351 .51058 .31117 .52059 .3231 .52204 .31546 .51197 Mtetra
.453 .604 .91 r
.31546 .51197 .3231 .52204 .33515 .52315 .32752 .51303 Mtetra
.472 .612 .909 r
.32752 .51303 .33515 .52315 .34732 .52392 .3397 .51374 Mtetra
.489 .62 .907 r
.3397 .51374 .34732 .52392 .35959 .52432 .35199 .51409 Mtetra
.507 .628 .905 r
.35199 .51409 .35959 .52432 .37197 .52434 .36438 .51407 Mtetra
.523 .635 .903 r
.36438 .51407 .37197 .52434 .38445 .52398 .37689 .51365 Mtetra
.54 .643 .9 r
.37689 .51365 .38445 .52398 .39704 .52321 .38949 .51284 Mtetra
.555 .649 .897 r
.38949 .51284 .39704 .52321 .40973 .52203 .4022 .51161 Mtetra
.57 .656 .894 r
.4022 .51161 .40973 .52203 .42251 .52043 .415 .50997 Mtetra
.585 .662 .891 r
.415 .50997 .42251 .52043 .43538 .51839 .4279 .50789 Mtetra
.599 .668 .888 r
.4279 .50789 .43538 .51839 .44834 .51592 .44088 .50538 Mtetra
.612 .674 .885 r
.44088 .50538 .44834 .51592 .46138 .513 .45395 .50243 Mtetra
.625 .679 .881 r
.45395 .50243 .46138 .513 .4745 .50964 .4671 .49903 Mtetra
.637 .684 .878 r
.4671 .49903 .4745 .50964 .4877 .50581 .48032 .49517 Mtetra
.649 .689 .874 r
.48032 .49517 .4877 .50581 .50096 .50153 .49361 .49086 Mtetra
.66 .693 .87 r
.49361 .49086 .50096 .50153 .51429 .4968 .50698 .48609 Mtetra
.671 .698 .867 r
.50698 .48609 .51429 .4968 .52768 .4916 .5204 .48087 Mtetra
.681 .702 .863 r
.5204 .48087 .52768 .4916 .54113 .48595 .53388 .47519 Mtetra
.69 .706 .859 r
.53388 .47519 .54113 .48595 .55462 .47985 .54741 .46906 Mtetra
.7 .71 .856 r
.54741 .46906 .55462 .47985 .56816 .47329 .56099 .46249 Mtetra
.708 .713 .852 r
.56099 .46249 .56816 .47329 .58175 .4663 .57461 .45547 Mtetra
.717 .717 .849 r
.57461 .45547 .58175 .4663 .59536 .45886 .58827 .44801 Mtetra
.725 .72 .845 r
.58827 .44801 .59536 .45886 .60901 .45099 .60196 .44013 Mtetra
.732 .723 .842 r
.60196 .44013 .60901 .45099 .62268 .44271 .61567 .43182 Mtetra
.739 .726 .839 r
.61567 .43182 .62268 .44271 .63638 .43401 .62941 .42311 Mtetra
.746 .729 .836 r
.62941 .42311 .63638 .43401 .65009 .42491 .64317 .414 Mtetra
.752 .731 .833 r
.64317 .414 .65009 .42491 .66382 .41542 .65694 .4045 Mtetra
.758 .734 .83 r
.65694 .4045 .66382 .41542 .67755 .40556 .67072 .39463 Mtetra
.764 .736 .827 r
.67072 .39463 .67755 .40556 .69129 .39534 .68451 .3844 Mtetra
.769 .739 .825 r
.68451 .3844 .69129 .39534 .70503 .38478 .6983 .37382 Mtetra
.775 .741 .822 r
.6983 .37382 .70503 .38478 .71876 .37388 .71208 .36291 Mtetra
.779 .743 .82 r
.71208 .36291 .71876 .37388 .73249 .36267 .72586 .3517 Mtetra
.784 .746 .818 r
.72586 .3517 .73249 .36267 .74621 .35116 .73964 .34018 Mtetra
.788 .748 .816 r
.73964 .34018 .74621 .35116 .75992 .33937 .7534 .32838 Mtetra
.792 .75 .814 r
.7534 .32838 .75992 .33937 .77361 .32731 .76715 .31632 Mtetra
.796 .752 .812 r
.76715 .31632 .77361 .32731 .78729 .31501 .78088 .30402 Mtetra
.799 .753 .811 r
.78088 .30402 .78729 .31501 .80095 .30248 .7946 .29148 Mtetra
.803 .755 .809 r
.7946 .29148 .80095 .30248 .81459 .28975 .8083 .27874 Mtetra
.229 .485 .892 r
.16157 .46441 .16933 .47404 .17987 .4781 .1721 .4684 Mtetra
.245 .493 .895 r
.1721 .4684 .17987 .4781 .19052 .48204 .18276 .47226 Mtetra
.261 .502 .897 r
.18276 .47226 .19052 .48204 .20128 .48583 .19353 .47598 Mtetra
.279 .51 .899 r
.19353 .47598 .20128 .48583 .21217 .48946 .20442 .47954 Mtetra
.296 .519 .9 r
.20442 .47954 .21217 .48946 .22317 .49291 .21542 .48292 Mtetra
.314 .528 .902 r
.21542 .48292 .22317 .49291 .23429 .49616 .22655 .4861 Mtetra
.333 .537 .903 r
.22655 .4861 .23429 .49616 .24553 .4992 .23779 .48907 Mtetra
.351 .546 .904 r
.23779 .48907 .24553 .4992 .25688 .50201 .24916 .49181 Mtetra
.37 .555 .904 r
.24916 .49181 .25688 .50201 .26836 .50457 .26065 .4943 Mtetra
.388 .564 .904 r
.26065 .4943 .26836 .50457 .27996 .50686 .27225 .49653 Mtetra
.407 .572 .904 r
.27225 .49653 .27996 .50686 .29167 .50887 .28398 .49847 Mtetra
.425 .581 .904 r
.28398 .49847 .29167 .50887 .30351 .51058 .29582 .50011 Mtetra
.443 .589 .903 r
.29582 .50011 .30351 .51058 .31546 .51197 .30778 .50144 Mtetra
.461 .597 .902 r
.30778 .50144 .31546 .51197 .32752 .51303 .31986 .50244 Mtetra
.478 .605 .9 r
.31986 .50244 .32752 .51303 .3397 .51374 .33205 .50309 Mtetra
.495 .613 .898 r
.33205 .50309 .3397 .51374 .35199 .51409 .34435 .50339 Mtetra
.511 .62 .896 r
.34435 .50339 .35199 .51409 .36438 .51407 .35677 .50331 Mtetra
.527 .628 .894 r
.35677 .50331 .36438 .51407 .37689 .51365 .36929 .50284 Mtetra
.543 .634 .891 r
.36929 .50284 .37689 .51365 .38949 .51284 .38191 .50198 Mtetra
.558 .641 .889 r
.38191 .50198 .38949 .51284 .4022 .51161 .39463 .5007 Mtetra
.572 .647 .886 r
.39463 .5007 .4022 .51161 .415 .50997 .40746 .49901 Mtetra
.586 .653 .883 r
.40746 .49901 .415 .50997 .4279 .50789 .42037 .49689 Mtetra
.6 .659 .88 r
.42037 .49689 .4279 .50789 .44088 .50538 .43338 .49434 Mtetra
.612 .664 .876 r
.43338 .49434 .44088 .50538 .45395 .50243 .44647 .49135 Mtetra
.625 .67 .873 r
.44647 .49135 .45395 .50243 .4671 .49903 .45965 .4879 Mtetra
.636 .675 .87 r
.45965 .4879 .4671 .49903 .48032 .49517 .4729 .48401 Mtetra
.648 .679 .866 r
.4729 .48401 .48032 .49517 .49361 .49086 .48622 .47967 Mtetra
.658 .684 .863 r
.48622 .47967 .49361 .49086 .50698 .48609 .49961 .47487 Mtetra
.669 .688 .859 r
.49961 .47487 .50698 .48609 .5204 .48087 .51307 .46962 Mtetra
.679 .692 .856 r
.51307 .46962 .5204 .48087 .53388 .47519 .52658 .46392 Mtetra
.688 .696 .852 r
.52658 .46392 .53388 .47519 .54741 .46906 .54014 .45777 Mtetra
.697 .7 .849 r
.54014 .45777 .54741 .46906 .56099 .46249 .55376 .45117 Mtetra
.705 .704 .846 r
.55376 .45117 .56099 .46249 .57461 .45547 .56742 .44413 Mtetra
.713 .707 .843 r
.56742 .44413 .57461 .45547 .58827 .44801 .58111 .43665 Mtetra
.721 .71 .839 r
.58111 .43665 .58827 .44801 .60196 .44013 .59484 .42875 Mtetra
.728 .713 .836 r
.59484 .42875 .60196 .44013 .61567 .43182 .6086 .42044 Mtetra
.735 .716 .833 r
.6086 .42044 .61567 .43182 .62941 .42311 .62238 .41171 Mtetra
.742 .719 .831 r
.62238 .41171 .62941 .42311 .64317 .414 .63618 .40259 Mtetra
.748 .722 .828 r
.63618 .40259 .64317 .414 .65694 .4045 .65 .39308 Mtetra
.754 .725 .825 r
.65 .39308 .65694 .4045 .67072 .39463 .66382 .3832 Mtetra
.76 .728 .823 r
.66382 .3832 .67072 .39463 .68451 .3844 .67766 .37297 Mtetra
.765 .73 .82 r
.67766 .37297 .68451 .3844 .6983 .37382 .69149 .36239 Mtetra
.77 .733 .818 r
.69149 .36239 .6983 .37382 .71208 .36291 .70533 .35148 Mtetra
.775 .735 .816 r
.70533 .35148 .71208 .36291 .72586 .3517 .71916 .34026 Mtetra
.78 .737 .814 r
.71916 .34026 .72586 .3517 .73964 .34018 .73299 .32874 Mtetra
.784 .739 .812 r
.73299 .32874 .73964 .34018 .7534 .32838 .7468 .31694 Mtetra
.788 .741 .81 r
.7468 .31694 .7534 .32838 .76715 .31632 .76061 .30488 Mtetra
.792 .744 .808 r
.76061 .30488 .76715 .31632 .78088 .30402 .7744 .29258 Mtetra
.795 .746 .807 r
.7744 .29258 .78088 .30402 .7946 .29148 .78817 .28005 Mtetra
.799 .748 .806 r
.78817 .28005 .7946 .29148 .8083 .27874 .80193 .26731 Mtetra
.246 .487 .89 r
.15378 .45443 .16157 .46441 .1721 .4684 .16432 .45833 Mtetra
.261 .494 .891 r
.16432 .45833 .1721 .4684 .18276 .47226 .17498 .46211 Mtetra
.277 .502 .893 r
.17498 .46211 .18276 .47226 .19353 .47598 .18575 .46575 Mtetra
.294 .51 .894 r
.18575 .46575 .19353 .47598 .20442 .47954 .19665 .46923 Mtetra
.311 .518 .895 r
.19665 .46923 .20442 .47954 .21542 .48292 .20766 .47252 Mtetra
.328 .526 .896 r
.20766 .47252 .21542 .48292 .22655 .4861 .21879 .47563 Mtetra
.345 .534 .897 r
.21879 .47563 .22655 .4861 .23779 .48907 .23004 .47852 Mtetra
.363 .543 .897 r
.23004 .47852 .23779 .48907 .24916 .49181 .24141 .48118 Mtetra
.381 .551 .898 r
.24141 .48118 .24916 .49181 .26065 .4943 .25291 .4836 Mtetra
.398 .56 .897 r
.25291 .4836 .26065 .4943 .27225 .49653 .26452 .48575 Mtetra
.416 .568 .897 r
.26452 .48575 .27225 .49653 .28398 .49847 .27626 .48762 Mtetra
.433 .576 .896 r
.27626 .48762 .28398 .49847 .29582 .50011 .28811 .4892 Mtetra
.451 .584 .895 r
.28811 .4892 .29582 .50011 .30778 .50144 .30008 .49046 Mtetra
.467 .591 .894 r
.30008 .49046 .30778 .50144 .31986 .50244 .31217 .49139 Mtetra
.484 .599 .892 r
.31217 .49139 .31986 .50244 .33205 .50309 .32437 .49198 Mtetra
.5 .606 .89 r
.32437 .49198 .33205 .50309 .34435 .50339 .33669 .49221 Mtetra
.516 .613 .888 r
.33669 .49221 .34435 .50339 .35677 .50331 .34912 .49207 Mtetra
.531 .62 .886 r
.34912 .49207 .35677 .50331 .36929 .50284 .36165 .49155 Mtetra
.546 .627 .883 r
.36165 .49155 .36929 .50284 .38191 .50198 .37429 .49063 Mtetra
.56 .633 .88 r
.37429 .49063 .38191 .50198 .39463 .5007 .38704 .4893 Mtetra
.574 .639 .878 r
.38704 .4893 .39463 .5007 .40746 .49901 .39988 .48756 Mtetra
.587 .645 .875 r
.39988 .48756 .40746 .49901 .42037 .49689 .41281 .48539 Mtetra
.6 .65 .872 r
.41281 .48539 .42037 .49689 .43338 .49434 .42584 .4828 Mtetra
.612 .656 .869 r
.42584 .4828 .43338 .49434 .44647 .49135 .43896 .47976 Mtetra
.624 .661 .865 r
.43896 .47976 .44647 .49135 .45965 .4879 .45215 .47628 Mtetra
.635 .666 .862 r
.45215 .47628 .45965 .4879 .4729 .48401 .46543 .47235 Mtetra
.646 .67 .859 r
.46543 .47235 .4729 .48401 .48622 .47967 .47878 .46797 Mtetra
.657 .675 .856 r
.47878 .46797 .48622 .47967 .49961 .47487 .4922 .46315 Mtetra
.667 .679 .852 r
.4922 .46315 .49961 .47487 .51307 .46962 .50568 .45787 Mtetra
.676 .683 .849 r
.50568 .45787 .51307 .46962 .52658 .46392 .51923 .45214 Mtetra
.685 .687 .846 r
.51923 .45214 .52658 .46392 .54014 .45777 .53283 .44596 Mtetra
.694 .691 .843 r
.53283 .44596 .54014 .45777 .55376 .45117 .54647 .43934 Mtetra
.702 .695 .84 r
.54647 .43934 .55376 .45117 .56742 .44413 .56016 .43228 Mtetra
.71 .698 .837 r
.56016 .43228 .56742 .44413 .58111 .43665 .5739 .4248 Mtetra
.718 .701 .834 r
.5739 .4248 .58111 .43665 .59484 .42875 .58766 .41688 Mtetra
.725 .705 .831 r
.58766 .41688 .59484 .42875 .6086 .42044 .60146 .40855 Mtetra
.732 .708 .828 r
.60146 .40855 .6086 .42044 .62238 .41171 .61528 .39982 Mtetra
.738 .711 .825 r
.61528 .39982 .62238 .41171 .63618 .40259 .62913 .39069 Mtetra
.744 .714 .823 r
.62913 .39069 .63618 .40259 .65 .39308 .64299 .38118 Mtetra
.75 .716 .82 r
.64299 .38118 .65 .39308 .66382 .3832 .65686 .3713 Mtetra
.756 .719 .818 r
.65686 .3713 .66382 .3832 .67766 .37297 .67074 .36106 Mtetra
.761 .722 .816 r
.67074 .36106 .67766 .37297 .69149 .36239 .68462 .35048 Mtetra
.766 .724 .814 r
.68462 .35048 .69149 .36239 .70533 .35148 .69851 .33957 Mtetra
.771 .727 .812 r
.69851 .33957 .70533 .35148 .71916 .34026 .71239 .32836 Mtetra
.776 .729 .81 r
.71239 .32836 .71916 .34026 .73299 .32874 .72627 .31684 Mtetra
.78 .731 .808 r
.72627 .31684 .73299 .32874 .7468 .31694 .74013 .30505 Mtetra
.784 .734 .806 r
.74013 .30505 .7468 .31694 .76061 .30488 .75399 .293 Mtetra
.788 .736 .805 r
.75399 .293 .76061 .30488 .7744 .29258 .76784 .28071 Mtetra
.791 .738 .804 r
.76784 .28071 .7744 .29258 .78817 .28005 .78166 .26818 Mtetra
.794 .74 .802 r
.78166 .26818 .78817 .28005 .80193 .26731 .79548 .25545 Mtetra
.262 .488 .887 r
.14597 .44409 .15378 .45443 .16432 .45833 .15652 .44791 Mtetra
.277 .495 .888 r
.15652 .44791 .16432 .45833 .17498 .46211 .16718 .45159 Mtetra
.292 .502 .889 r
.16718 .45159 .17498 .46211 .18575 .46575 .17796 .45514 Mtetra
.308 .509 .89 r
.17796 .45514 .18575 .46575 .19665 .46923 .18886 .45853 Mtetra
.324 .517 .89 r
.18886 .45853 .19665 .46923 .20766 .47252 .19988 .46174 Mtetra
.341 .525 .891 r
.19988 .46174 .20766 .47252 .21879 .47563 .21101 .46476 Mtetra
.357 .532 .891 r
.21101 .46476 .21879 .47563 .23004 .47852 .22227 .46756 Mtetra
.374 .54 .891 r
.22227 .46756 .23004 .47852 .24141 .48118 .23365 .47014 Mtetra
.391 .548 .891 r
.23365 .47014 .24141 .48118 .25291 .4836 .24515 .47248 Mtetra
.408 .556 .891 r
.24515 .47248 .25291 .4836 .26452 .48575 .25677 .47455 Mtetra
.425 .564 .89 r
.25677 .47455 .26452 .48575 .27626 .48762 .26851 .47634 Mtetra
.441 .571 .889 r
.26851 .47634 .27626 .48762 .28811 .4892 .28038 .47784 Mtetra
.457 .579 .887 r
.28038 .47784 .28811 .4892 .30008 .49046 .29236 .47902 Mtetra
.473 .586 .886 r
.29236 .47902 .30008 .49046 .31217 .49139 .30446 .47988 Mtetra
.489 .593 .884 r
.30446 .47988 .31217 .49139 .32437 .49198 .31667 .4804 Mtetra
.505 .6 .882 r
.31667 .4804 .32437 .49198 .33669 .49221 .329 .48057 Mtetra
.519 .607 .88 r
.329 .48057 .33669 .49221 .34912 .49207 .34144 .48036 Mtetra
.534 .613 .878 r
.34144 .48036 .34912 .49207 .36165 .49155 .35399 .47978 Mtetra
.548 .619 .875 r
.35399 .47978 .36165 .49155 .37429 .49063 .36664 .4788 Mtetra
.562 .625 .873 r
.36664 .4788 .37429 .49063 .38704 .4893 .3794 .47742 Mtetra
.575 .631 .87 r
.3794 .47742 .38704 .4893 .39988 .48756 .39226 .47562 Mtetra
.588 .637 .867 r
.39226 .47562 .39988 .48756 .41281 .48539 .40522 .4734 Mtetra
.6 .642 .864 r
.40522 .4734 .41281 .48539 .42584 .4828 .41827 .47076 Mtetra
.612 .647 .861 r
.41827 .47076 .42584 .4828 .43896 .47976 .4314 .46768 Mtetra
.623 .652 .858 r
.4314 .46768 .43896 .47976 .45215 .47628 .44462 .46416 Mtetra
.634 .657 .855 r
.44462 .46416 .45215 .47628 .46543 .47235 .45792 .46019 Mtetra
.645 .662 .852 r
.45792 .46019 .46543 .47235 .47878 .46797 .4713 .45578 Mtetra
.655 .666 .849 r
.4713 .45578 .47878 .46797 .4922 .46315 .48474 .45092 Mtetra
.665 .67 .846 r
.48474 .45092 .4922 .46315 .50568 .45787 .49825 .44561 Mtetra
.674 .675 .843 r
.49825 .44561 .50568 .45787 .51923 .45214 .51183 .43986 Mtetra
.683 .678 .84 r
.51183 .43986 .51923 .45214 .53283 .44596 .52546 .43366 Mtetra
.691 .682 .837 r
.52546 .43366 .53283 .44596 .54647 .43934 .53914 .42702 Mtetra
.699 .686 .834 r
.53914 .42702 .54647 .43934 .56016 .43228 .55286 .41995 Mtetra
.707 .689 .831 r
.55286 .41995 .56016 .43228 .5739 .4248 .56663 .41244 Mtetra
.714 .693 .828 r
.56663 .41244 .5739 .4248 .58766 .41688 .58043 .40452 Mtetra
.721 .696 .825 r
.58043 .40452 .58766 .41688 .60146 .40855 .59427 .39618 Mtetra
.728 .699 .823 r
.59427 .39618 .60146 .40855 .61528 .39982 .60813 .38744 Mtetra
.735 .702 .82 r
.60813 .38744 .61528 .39982 .62913 .39069 .62201 .37831 Mtetra
.741 .705 .818 r
.62201 .37831 .62913 .39069 .64299 .38118 .63591 .3688 Mtetra
.746 .708 .816 r
.63591 .3688 .64299 .38118 .65686 .3713 .64983 .35892 Mtetra
.752 .711 .814 r
.64983 .35892 .65686 .3713 .67074 .36106 .66375 .34868 Mtetra
.757 .714 .811 r
.66375 .34868 .67074 .36106 .68462 .35048 .67768 .33811 Mtetra
.762 .716 .809 r
.67768 .33811 .68462 .35048 .69851 .33957 .69161 .32721 Mtetra
.767 .719 .808 r
.69161 .32721 .69851 .33957 .71239 .32836 .70554 .316 Mtetra
.771 .721 .806 r
.70554 .316 .71239 .32836 .72627 .31684 .71947 .3045 Mtetra
.776 .724 .804 r
.71947 .3045 .72627 .31684 .74013 .30505 .73339 .29272 Mtetra
.78 .726 .803 r
.73339 .29272 .74013 .30505 .75399 .293 .7473 .28068 Mtetra
.783 .728 .802 r
.7473 .28068 .75399 .293 .76784 .28071 .7612 .2684 Mtetra
.787 .731 .8 r
.7612 .2684 .76784 .28071 .78166 .26818 .77508 .25589 Mtetra
.79 .733 .799 r
.77508 .25589 .78166 .26818 .79548 .25545 .78895 .24318 Mtetra
.277 .489 .883 r
.13815 .43341 .14597 .44409 .15652 .44791 .1487 .43712 Mtetra
.291 .495 .884 r
.1487 .43712 .15652 .44791 .16718 .45159 .15937 .44071 Mtetra
.306 .502 .885 r
.15937 .44071 .16718 .45159 .17796 .45514 .17015 .44416 Mtetra
.321 .509 .885 r
.17015 .44416 .17796 .45514 .18886 .45853 .18105 .44745 Mtetra
.337 .516 .885 r
.18105 .44745 .18886 .45853 .19988 .46174 .19208 .45057 Mtetra
.352 .523 .885 r
.19208 .45057 .19988 .46174 .21101 .46476 .20322 .45349 Mtetra
.368 .53 .885 r
.20322 .45349 .21101 .46476 .22227 .46756 .21448 .45621 Mtetra
.384 .538 .885 r
.21448 .45621 .22227 .46756 .23365 .47014 .22586 .45869 Mtetra
.4 .545 .885 r
.22586 .45869 .23365 .47014 .24515 .47248 .23737 .46094 Mtetra
.416 .552 .884 r
.23737 .46094 .24515 .47248 .25677 .47455 .249 .46292 Mtetra
.432 .559 .883 r
.249 .46292 .25677 .47455 .26851 .47634 .26075 .46463 Mtetra
.448 .567 .882 r
.26075 .46463 .26851 .47634 .28038 .47784 .27262 .46604 Mtetra
.464 .574 .88 r
.27262 .46604 .28038 .47784 .29236 .47902 .28461 .46715 Mtetra
.479 .581 .879 r
.28461 .46715 .29236 .47902 .30446 .47988 .29672 .46793 Mtetra
.494 .587 .877 r
.29672 .46793 .30446 .47988 .31667 .4804 .30894 .46838 Mtetra
.509 .594 .875 r
.30894 .46838 .31667 .4804 .329 .48057 .32128 .46847 Mtetra
.523 .6 .873 r
.32128 .46847 .329 .48057 .34144 .48036 .33374 .46819 Mtetra
.537 .606 .87 r
.33374 .46819 .34144 .48036 .35399 .47978 .3463 .46754 Mtetra
.55 .612 .868 r
.3463 .46754 .35399 .47978 .36664 .4788 .35897 .4665 Mtetra
.563 .618 .865 r
.35897 .4665 .36664 .4788 .3794 .47742 .37174 .46506 Mtetra
.576 .624 .863 r
.37174 .46506 .3794 .47742 .39226 .47562 .38462 .46321 Mtetra
.588 .629 .86 r
.38462 .46321 .39226 .47562 .40522 .4734 .39759 .46094 Mtetra
.6 .635 .857 r
.39759 .46094 .40522 .4734 .41827 .47076 .41066 .45824 Mtetra
.612 .64 .854 r
.41066 .45824 .41827 .47076 .4314 .46768 .42381 .45511 Mtetra
.623 .645 .851 r
.42381 .45511 .4314 .46768 .44462 .46416 .43705 .45155 Mtetra
.633 .649 .848 r
.43705 .45155 .44462 .46416 .45792 .46019 .45037 .44755 Mtetra
.643 .654 .845 r
.45037 .44755 .45792 .46019 .4713 .45578 .46377 .4431 Mtetra
.653 .658 .842 r
.46377 .4431 .4713 .45578 .48474 .45092 .47724 .43821 Mtetra
.663 .662 .839 r
.47724 .43821 .48474 .45092 .49825 .44561 .49078 .43287 Mtetra
.672 .666 .837 r
.49078 .43287 .49825 .44561 .51183 .43986 .50438 .42709 Mtetra
.68 .67 .834 r
.50438 .42709 .51183 .43986 .52546 .43366 .51804 .42087 Mtetra
.688 .674 .831 r
.51804 .42087 .52546 .43366 .53914 .42702 .53175 .41421 Mtetra
.696 .678 .828 r
.53175 .41421 .53914 .42702 .55286 .41995 .54551 .40712 Mtetra
.704 .681 .826 r
.54551 .40712 .55286 .41995 .56663 .41244 .55931 .39961 Mtetra
.711 .685 .823 r
.55931 .39961 .56663 .41244 .58043 .40452 .57314 .39167 Mtetra
.718 .688 .82 r
.57314 .39167 .58043 .40452 .59427 .39618 .58701 .38333 Mtetra
.725 .691 .818 r
.58701 .38333 .59427 .39618 .60813 .38744 .60091 .37459 Mtetra
.731 .694 .816 r
.60091 .37459 .60813 .38744 .62201 .37831 .61483 .36546 Mtetra
.737 .697 .813 r
.61483 .36546 .62201 .37831 .63591 .3688 .62878 .35595 Mtetra
.743 .7 .811 r
.62878 .35595 .63591 .3688 .64983 .35892 .64273 .34607 Mtetra
.748 .703 .809 r
.64273 .34607 .64983 .35892 .66375 .34868 .6567 .33585 Mtetra
.753 .706 .807 r
.6567 .33585 .66375 .34868 .67768 .33811 .67068 .32528 Mtetra
.758 .709 .806 r
.67068 .32528 .67768 .33811 .69161 .32721 .68465 .3144 Mtetra
.763 .711 .804 r
.68465 .3144 .69161 .32721 .70554 .316 .69863 .3032 Mtetra
.767 .714 .802 r
.69863 .3032 .70554 .316 .71947 .3045 .71261 .29172 Mtetra
.772 .717 .801 r
.71261 .29172 .71947 .3045 .73339 .29272 .72658 .27996 Mtetra
.776 .719 .799 r
.72658 .27996 .73339 .29272 .7473 .28068 .74054 .26794 Mtetra
.779 .721 .798 r
.74054 .26794 .7473 .28068 .7612 .2684 .75449 .25567 Mtetra
.783 .724 .797 r
.75449 .25567 .7612 .2684 .77508 .25589 .76842 .24319 Mtetra
.786 .726 .796 r
.76842 .24319 .77508 .25589 .78895 .24318 .78234 .2305 Mtetra
.292 .49 .88 r
.13032 .42238 .13815 .43341 .1487 .43712 .14087 .42599 Mtetra
.305 .496 .88 r
.14087 .42599 .1487 .43712 .15937 .44071 .15154 .42947 Mtetra
.319 .502 .88 r
.15154 .42947 .15937 .44071 .17015 .44416 .16233 .43282 Mtetra
.334 .508 .88 r
.16233 .43282 .17015 .44416 .18105 .44745 .17323 .436 Mtetra
.349 .515 .88 r
.17323 .436 .18105 .44745 .19208 .45057 .18426 .43902 Mtetra
.364 .521 .88 r
.18426 .43902 .19208 .45057 .20322 .45349 .19541 .44184 Mtetra
.379 .528 .88 r
.19541 .44184 .20322 .45349 .21448 .45621 .20667 .44446 Mtetra
.394 .535 .879 r
.20667 .44446 .21448 .45621 .22586 .45869 .21806 .44685 Mtetra
.409 .542 .878 r
.21806 .44685 .22586 .45869 .23737 .46094 .22958 .44899 Mtetra
.424 .549 .877 r
.22958 .44899 .23737 .46094 .249 .46292 .24121 .45088 Mtetra
.44 .556 .876 r
.24121 .45088 .249 .46292 .26075 .46463 .25297 .4525 Mtetra
.455 .562 .875 r
.25297 .4525 .26075 .46463 .27262 .46604 .26485 .45383 Mtetra
.469 .569 .873 r
.26485 .45383 .27262 .46604 .28461 .46715 .27684 .45485 Mtetra
.484 .576 .872 r
.27684 .45485 .28461 .46715 .29672 .46793 .28896 .45554 Mtetra
.498 .582 .87 r
.28896 .45554 .29672 .46793 .30894 .46838 .30119 .45591 Mtetra
.512 .588 .868 r
.30119 .45591 .30894 .46838 .32128 .46847 .31354 .45592 Mtetra
.526 .594 .865 r
.31354 .45592 .32128 .46847 .33374 .46819 .32601 .45557 Mtetra
.539 .6 .863 r
.32601 .45557 .33374 .46819 .3463 .46754 .33858 .45485 Mtetra
.552 .606 .861 r
.33858 .45485 .3463 .46754 .35897 .4665 .35126 .45374 Mtetra
.565 .612 .858 r
.35126 .45374 .35897 .4665 .37174 .46506 .36405 .45224 Mtetra
.577 .617 .856 r
.36405 .45224 .37174 .46506 .38462 .46321 .37694 .45032 Mtetra
.589 .622 .853 r
.37694 .45032 .38462 .46321 .39759 .46094 .38993 .448 Mtetra
.6 .627 .85 r
.38993 .448 .39759 .46094 .41066 .45824 .40301 .44525 Mtetra
.611 .632 .847 r
.40301 .44525 .41066 .45824 .42381 .45511 .41619 .44207 Mtetra
.622 .637 .845 r
.41619 .44207 .42381 .45511 .43705 .45155 .42945 .43847 Mtetra
.632 .642 .842 r
.42945 .43847 .43705 .45155 .45037 .44755 .44279 .43442 Mtetra
.642 .646 .839 r
.44279 .43442 .45037 .44755 .46377 .4431 .45621 .42994 Mtetra
.651 .651 .836 r
.45621 .42994 .46377 .4431 .47724 .43821 .4697 .42501 Mtetra
.661 .655 .834 r
.4697 .42501 .47724 .43821 .49078 .43287 .48326 .41965 Mtetra
.669 .659 .831 r
.48326 .41965 .49078 .43287 .50438 .42709 .49689 .41384 Mtetra
.678 .663 .828 r
.49689 .41384 .50438 .42709 .51804 .42087 .51058 .4076 Mtetra
.686 .667 .825 r
.51058 .4076 .51804 .42087 .53175 .41421 .52431 .40092 Mtetra
.693 .67 .823 r
.52431 .40092 .53175 .41421 .54551 .40712 .5381 .39382 Mtetra
.701 .674 .82 r
.5381 .39382 .54551 .40712 .55931 .39961 .55193 .3863 Mtetra
.708 .677 .818 r
.55193 .3863 .55931 .39961 .57314 .39167 .5658 .37836 Mtetra
.715 .681 .816 r
.5658 .37836 .57314 .39167 .58701 .38333 .57971 .37001 Mtetra
.721 .684 .813 r
.57971 .37001 .58701 .38333 .60091 .37459 .59364 .36127 Mtetra
.727 .687 .811 r
.59364 .36127 .60091 .37459 .61483 .36546 .6076 .35214 Mtetra
.733 .69 .809 r
.6076 .35214 .61483 .36546 .62878 .35595 .62158 .34264 Mtetra
.739 .693 .807 r
.62158 .34264 .62878 .35595 .64273 .34607 .63558 .33277 Mtetra
.744 .696 .805 r
.63558 .33277 .64273 .34607 .6567 .33585 .64959 .32256 Mtetra
.749 .699 .804 r
.64959 .32256 .6567 .33585 .67068 .32528 .66361 .31201 Mtetra
.754 .702 .802 r
.66361 .31201 .67068 .32528 .68465 .3144 .67763 .30114 Mtetra
.759 .704 .8 r
.67763 .30114 .68465 .3144 .69863 .3032 .69165 .28996 Mtetra
.763 .707 .799 r
.69165 .28996 .69863 .3032 .71261 .29172 .70568 .2785 Mtetra
.768 .71 .798 r
.70568 .2785 .71261 .29172 .72658 .27996 .71969 .26676 Mtetra
.772 .712 .796 r
.71969 .26676 .72658 .27996 .74054 .26794 .73371 .25477 Mtetra
.775 .715 .795 r
.73371 .25477 .74054 .26794 .75449 .25567 .74771 .24253 Mtetra
.779 .717 .794 r
.74771 .24253 .75449 .25567 .76842 .24319 .76169 .23007 Mtetra
.782 .719 .793 r
.76169 .23007 .76842 .24319 .78234 .2305 .77567 .21741 Mtetra
.305 .49 .876 r
.12247 .41102 .13032 .42238 .14087 .42599 .13303 .41452 Mtetra
.318 .496 .876 r
.13303 .41452 .14087 .42599 .15154 .42947 .1437 .41789 Mtetra
.332 .502 .876 r
.1437 .41789 .15154 .42947 .16233 .43282 .15449 .42112 Mtetra
.345 .508 .876 r
.15449 .42112 .16233 .43282 .17323 .436 .1654 .4242 Mtetra
.359 .514 .875 r
.1654 .4242 .17323 .436 .18426 .43902 .17643 .4271 Mtetra
.374 .52 .875 r
.17643 .4271 .18426 .43902 .19541 .44184 .18758 .42981 Mtetra
.388 .526 .874 r
.18758 .42981 .19541 .44184 .20667 .44446 .19885 .43232 Mtetra
.403 .533 .873 r
.19885 .43232 .20667 .44446 .21806 .44685 .21025 .43461 Mtetra
.417 .539 .872 r
.21025 .43461 .21806 .44685 .22958 .44899 .22177 .43666 Mtetra
.432 .546 .871 r
.22177 .43666 .22958 .44899 .24121 .45088 .23341 .43845 Mtetra
.446 .552 .87 r
.23341 .43845 .24121 .45088 .25297 .4525 .24517 .43996 Mtetra
.461 .558 .868 r
.24517 .43996 .25297 .4525 .26485 .45383 .25705 .4412 Mtetra
.475 .565 .867 r
.25705 .4412 .26485 .45383 .27684 .45485 .26906 .44212 Mtetra
.489 .571 .865 r
.26906 .44212 .27684 .45485 .28896 .45554 .28118 .44273 Mtetra
.502 .577 .863 r
.28118 .44273 .28896 .45554 .30119 .45591 .29342 .44301 Mtetra
.516 .583 .861 r
.29342 .44301 .30119 .45591 .31354 .45592 .30578 .44294 Mtetra
.529 .589 .859 r
.30578 .44294 .31354 .45592 .32601 .45557 .31826 .44251 Mtetra
.542 .594 .856 r
.31826 .44251 .32601 .45557 .33858 .45485 .33084 .44172 Mtetra
.554 .6 .854 r
.33084 .44172 .33858 .45485 .35126 .45374 .34354 .44054 Mtetra
.566 .605 .852 r
.34354 .44054 .35126 .45374 .36405 .45224 .35634 .43896 Mtetra
.578 .611 .849 r
.35634 .43896 .36405 .45224 .37694 .45032 .36924 .43699 Mtetra
.589 .616 .846 r
.36924 .43699 .37694 .45032 .38993 .448 .38224 .4346 Mtetra
.6 .621 .844 r
.38224 .4346 .38993 .448 .40301 .44525 .39534 .4318 Mtetra
.611 .626 .841 r
.39534 .4318 .40301 .44525 .41619 .44207 .40853 .42857 Mtetra
.621 .63 .838 r
.40853 .42857 .41619 .44207 .42945 .43847 .42181 .42492 Mtetra
.631 .635 .836 r
.42181 .42492 .42945 .43847 .44279 .43442 .43517 .42083 Mtetra
.64 .639 .833 r
.43517 .42083 .44279 .43442 .45621 .42994 .44861 .41631 Mtetra
.65 .643 .831 r
.44861 .41631 .45621 .42994 .4697 .42501 .46212 .41135 Mtetra
.659 .648 .828 r
.46212 .41135 .4697 .42501 .48326 .41965 .47571 .40595 Mtetra
.667 .652 .825 r
.47571 .40595 .48326 .41965 .49689 .41384 .48936 .40012 Mtetra
.675 .655 .823 r
.48936 .40012 .49689 .41384 .51058 .4076 .50307 .39386 Mtetra
.683 .659 .82 r
.50307 .39386 .51058 .4076 .52431 .40092 .51683 .38717 Mtetra
.691 .663 .818 r
.51683 .38717 .52431 .40092 .5381 .39382 .53065 .38005 Mtetra
.698 .667 .816 r
.53065 .38005 .5381 .39382 .55193 .3863 .54451 .37252 Mtetra
.705 .67 .813 r
.54451 .37252 .55193 .3863 .5658 .37836 .55841 .36458 Mtetra
.711 .673 .811 r
.55841 .36458 .5658 .37836 .57971 .37001 .57235 .35623 Mtetra
.718 .677 .809 r
.57235 .35623 .57971 .37001 .59364 .36127 .58632 .34749 Mtetra
.724 .68 .807 r
.58632 .34749 .59364 .36127 .6076 .35214 .60031 .33837 Mtetra
.73 .683 .805 r
.60031 .33837 .6076 .35214 .62158 .34264 .61433 .32888 Mtetra
.735 .686 .803 r
.61433 .32888 .62158 .34264 .63558 .33277 .62837 .31903 Mtetra
.741 .689 .802 r
.62837 .31903 .63558 .33277 .64959 .32256 .64242 .30883 Mtetra
.746 .692 .8 r
.64242 .30883 .64959 .32256 .66361 .31201 .65648 .2983 Mtetra
.751 .695 .798 r
.65648 .2983 .66361 .31201 .67763 .30114 .67054 .28745 Mtetra
.755 .698 .797 r
.67054 .28745 .67763 .30114 .69165 .28996 .68461 .2763 Mtetra
.76 .7 .796 r
.68461 .2763 .69165 .28996 .70568 .2785 .69868 .26486 Mtetra
.764 .703 .794 r
.69868 .26486 .70568 .2785 .71969 .26676 .71275 .25315 Mtetra
.768 .706 .793 r
.71275 .25315 .71969 .26676 .73371 .25477 .7268 .24119 Mtetra
.772 .708 .792 r
.7268 .24119 .73371 .25477 .74771 .24253 .74086 .22898 Mtetra
.775 .711 .791 r
.74086 .22898 .74771 .24253 .76169 .23007 .7549 .21656 Mtetra
.778 .713 .791 r
.7549 .21656 .76169 .23007 .77567 .21741 .76892 .20393 Mtetra
.318 .491 .872 r
.11461 .39934 .12247 .41102 .13303 .41452 .12517 .40271 Mtetra
.33 .496 .872 r
.12517 .40271 .13303 .41452 .1437 .41789 .13584 .40597 Mtetra
.343 .502 .871 r
.13584 .40597 .1437 .41789 .15449 .42112 .14664 .40908 Mtetra
.356 .507 .871 r
.14664 .40908 .15449 .42112 .1654 .4242 .15755 .41204 Mtetra
.37 .513 .87 r
.15755 .41204 .1654 .4242 .17643 .4271 .16859 .41482 Mtetra
.383 .519 .869 r
.16859 .41482 .17643 .4271 .18758 .42981 .17974 .41742 Mtetra
.397 .524 .869 r
.17974 .41742 .18758 .42981 .19885 .43232 .19102 .41982 Mtetra
.411 .53 .868 r
.19102 .41982 .19885 .43232 .21025 .43461 .20242 .42199 Mtetra
.425 .537 .866 r
.20242 .42199 .21025 .43461 .22177 .43666 .21394 .42393 Mtetra
.439 .543 .865 r
.21394 .42393 .22177 .43666 .23341 .43845 .22558 .42562 Mtetra
.453 .549 .864 r
.22558 .42562 .23341 .43845 .24517 .43996 .23735 .42703 Mtetra
.466 .555 .862 r
.23735 .42703 .24517 .43996 .25705 .4412 .24924 .42816 Mtetra
.48 .561 .86 r
.24924 .42816 .25705 .4412 .26906 .44212 .26125 .42899 Mtetra
.493 .567 .858 r
.26125 .42899 .26906 .44212 .28118 .44273 .27339 .42951 Mtetra
.506 .572 .857 r
.27339 .42951 .28118 .44273 .29342 .44301 .28564 .42969 Mtetra
.519 .578 .854 r
.28564 .42969 .29342 .44301 .30578 .44294 .298 .42954 Mtetra
.532 .584 .852 r
.298 .42954 .30578 .44294 .31826 .44251 .31048 .42903 Mtetra
.544 .589 .85 r
.31048 .42903 .31826 .44251 .33084 .44172 .32308 .42815 Mtetra
.556 .594 .848 r
.32308 .42815 .33084 .44172 .34354 .44054 .33578 .4269 Mtetra
.567 .6 .845 r
.33578 .4269 .34354 .44054 .35634 .43896 .34859 .42525 Mtetra
.579 .605 .843 r
.34859 .42525 .35634 .43896 .36924 .43699 .36151 .42321 Mtetra
.589 .61 .84 r
.36151 .42321 .36924 .43699 .38224 .4346 .37452 .42076 Mtetra
.6 .615 .838 r
.37452 .42076 .38224 .4346 .39534 .4318 .38764 .4179 Mtetra
.61 .619 .835 r
.38764 .4179 .39534 .4318 .40853 .42857 .40084 .41462 Mtetra
.62 .624 .833 r
.40084 .41462 .40853 .42857 .42181 .42492 .41414 .41092 Mtetra
.63 .628 .83 r
.41414 .41092 .42181 .42492 .43517 .42083 .42751 .40679 Mtetra
.639 .633 .828 r
.42751 .40679 .43517 .42083 .44861 .41631 .44097 .40223 Mtetra
.648 .637 .825 r
.44097 .40223 .44861 .41631 .46212 .41135 .45451 .39723 Mtetra
.657 .641 .823 r
.45451 .39723 .46212 .41135 .47571 .40595 .46811 .39181 Mtetra
.665 .645 .82 r
.46811 .39181 .47571 .40595 .48936 .40012 .48179 .38595 Mtetra
.673 .649 .818 r
.48179 .38595 .48936 .40012 .50307 .39386 .49552 .37967 Mtetra
.68 .652 .816 r
.49552 .37967 .50307 .39386 .51683 .38717 .50931 .37296 Mtetra
.688 .656 .813 r
.50931 .37296 .51683 .38717 .53065 .38005 .52315 .36584 Mtetra
.695 .66 .811 r
.52315 .36584 .53065 .38005 .54451 .37252 .53704 .3583 Mtetra
.702 .663 .809 r
.53704 .3583 .54451 .37252 .55841 .36458 .55097 .35035 Mtetra
.708 .667 .807 r
.55097 .35035 .55841 .36458 .57235 .35623 .56494 .34201 Mtetra
.714 .67 .805 r
.56494 .34201 .57235 .35623 .58632 .34749 .57894 .33327 Mtetra
.72 .673 .803 r
.57894 .33327 .58632 .34749 .60031 .33837 .59297 .32416 Mtetra
.726 .676 .801 r
.59297 .32416 .60031 .33837 .61433 .32888 .60703 .31468 Mtetra
.732 .679 .8 r
.60703 .31468 .61433 .32888 .62837 .31903 .6211 .30485 Mtetra
.737 .682 .798 r
.6211 .30485 .62837 .31903 .64242 .30883 .63519 .29467 Mtetra
.742 .685 .796 r
.63519 .29467 .64242 .30883 .65648 .2983 .64929 .28416 Mtetra
.747 .688 .795 r
.64929 .28416 .65648 .2983 .67054 .28745 .6634 .27334 Mtetra
.751 .691 .794 r
.6634 .27334 .67054 .28745 .68461 .2763 .67751 .26222 Mtetra
.756 .694 .793 r
.67751 .26222 .68461 .2763 .69868 .26486 .69162 .25081 Mtetra
.76 .697 .791 r
.69162 .25081 .69868 .26486 .71275 .25315 .70573 .23913 Mtetra
.764 .699 .79 r
.70573 .23913 .71275 .25315 .7268 .24119 .71984 .2272 Mtetra
.768 .702 .79 r
.71984 .2272 .7268 .24119 .74086 .22898 .73394 .21504 Mtetra
.771 .705 .789 r
.73394 .21504 .74086 .22898 .7549 .21656 .74803 .20265 Mtetra
.775 .707 .788 r
.74803 .20265 .7549 .21656 .76892 .20393 .76211 .19006 Mtetra
.33 .492 .868 r
.10673 .38735 .11461 .39934 .12517 .40271 .1173 .39059 Mtetra
.342 .497 .868 r
.1173 .39059 .12517 .40271 .13584 .40597 .12798 .39371 Mtetra
.354 .501 .867 r
.12798 .39371 .13584 .40597 .14664 .40908 .13877 .3967 Mtetra
.367 .507 .866 r
.13877 .3967 .14664 .40908 .15755 .41204 .14969 .39953 Mtetra
.379 .512 .865 r
.14969 .39953 .15755 .41204 .16859 .41482 .16073 .4022 Mtetra
.392 .517 .864 r
.16073 .4022 .16859 .41482 .17974 .41742 .17189 .40468 Mtetra
.406 .523 .863 r
.17189 .40468 .17974 .41742 .19102 .41982 .18317 .40695 Mtetra
.419 .528 .862 r
.18317 .40695 .19102 .41982 .20242 .42199 .19457 .40901 Mtetra
.432 .534 .861 r
.19457 .40901 .20242 .42199 .21394 .42393 .2061 .41083 Mtetra
.445 .54 .859 r
.2061 .41083 .21394 .42393 .22558 .42562 .21775 .41241 Mtetra
.458 .546 .858 r
.21775 .41241 .22558 .42562 .23735 .42703 .22952 .41371 Mtetra
.472 .551 .856 r
.22952 .41371 .23735 .42703 .24924 .42816 .24142 .41474 Mtetra
.484 .557 .854 r
.24142 .41474 .24924 .42816 .26125 .42899 .25343 .41546 Mtetra
.497 .563 .852 r
.25343 .41546 .26125 .42899 .27339 .42951 .26557 .41588 Mtetra
.51 .568 .85 r
.26557 .41588 .27339 .42951 .28564 .42969 .27783 .41597 Mtetra
.522 .574 .848 r
.27783 .41597 .28564 .42969 .298 .42954 .2902 .41573 Mtetra
.534 .579 .846 r
.2902 .41573 .298 .42954 .31048 .42903 .30269 .41513 Mtetra
.546 .584 .844 r
.30269 .41513 .31048 .42903 .32308 .42815 .31529 .41417 Mtetra
.557 .589 .842 r
.31529 .41417 .32308 .42815 .33578 .4269 .32801 .41283 Mtetra
.568 .594 .839 r
.32801 .41283 .33578 .4269 .34859 .42525 .34083 .41111 Mtetra
.579 .599 .837 r
.34083 .41111 .34859 .42525 .36151 .42321 .35376 .409 Mtetra
.59 .604 .835 r
.35376 .409 .36151 .42321 .37452 .42076 .36678 .40649 Mtetra
.6 .609 .832 r
.36678 .40649 .37452 .42076 .38764 .4179 .37991 .40357 Mtetra
.61 .613 .83 r
.37991 .40357 .38764 .4179 .40084 .41462 .39313 .40023 Mtetra
.619 .618 .827 r
.39313 .40023 .40084 .41462 .41414 .41092 .40644 .39648 Mtetra
.629 .622 .825 r
.40644 .39648 .41414 .41092 .42751 .40679 .41983 .3923 Mtetra
.638 .626 .822 r
.41983 .3923 .42751 .40679 .44097 .40223 .43331 .3877 Mtetra
.646 .631 .82 r
.43331 .3877 .44097 .40223 .45451 .39723 .44686 .38268 Mtetra
.655 .635 .818 r
.44686 .38268 .45451 .39723 .46811 .39181 .46048 .37722 Mtetra
.663 .639 .815 r
.46048 .37722 .46811 .39181 .48179 .38595 .47418 .37134 Mtetra
.67 .642 .813 r
.47418 .37134 .48179 .38595 .49552 .37967 .48793 .36504 Mtetra
.678 .646 .811 r
.48793 .36504 .49552 .37967 .50931 .37296 .50175 .35832 Mtetra
.685 .65 .809 r
.50175 .35832 .50931 .37296 .52315 .36584 .51561 .35118 Mtetra
.692 .653 .807 r
.51561 .35118 .52315 .36584 .53704 .3583 .52953 .34364 Mtetra
.699 .657 .805 r
.52953 .34364 .53704 .3583 .55097 .35035 .54349 .33569 Mtetra
.705 .66 .803 r
.54349 .33569 .55097 .35035 .56494 .34201 .55749 .32735 Mtetra
.711 .664 .801 r
.55749 .32735 .56494 .34201 .57894 .33327 .57152 .31862 Mtetra
.717 .667 .799 r
.57152 .31862 .57894 .33327 .59297 .32416 .58558 .30952 Mtetra
.723 .67 .798 r
.58558 .30952 .59297 .32416 .60703 .31468 .59967 .30006 Mtetra
.728 .673 .796 r
.59967 .30006 .60703 .31468 .6211 .30485 .61378 .29024 Mtetra
.733 .676 .795 r
.61378 .29024 .6211 .30485 .63519 .29467 .6279 .28009 Mtetra
.738 .679 .793 r
.6279 .28009 .63519 .29467 .64929 .28416 .64204 .26961 Mtetra
.743 .682 .792 r
.64204 .26961 .64929 .28416 .6634 .27334 .65619 .25882 Mtetra
.748 .685 .791 r
.65619 .25882 .6634 .27334 .67751 .26222 .67035 .24773 Mtetra
.752 .688 .79 r
.67035 .24773 .67751 .26222 .69162 .25081 .6845 .23636 Mtetra
.756 .691 .789 r
.6845 .23636 .69162 .25081 .70573 .23913 .69866 .22472 Mtetra
.76 .693 .788 r
.69866 .22472 .70573 .23913 .71984 .2272 .71281 .21283 Mtetra
.764 .696 .787 r
.71281 .21283 .71984 .2272 .73394 .21504 .72696 .20071 Mtetra
.768 .699 .786 r
.72696 .20071 .73394 .21504 .74803 .20265 .7411 .18837 Mtetra
.771 .701 .786 r
.7411 .18837 .74803 .20265 .76211 .19006 .75523 .17582 Mtetra
.341 .493 .865 r
.09884 .37504 .10673 .38735 .1173 .39059 .10941 .37815 Mtetra
.353 .497 .864 r
.10941 .37815 .1173 .39059 .12798 .39371 .1201 .38114 Mtetra
.364 .502 .863 r
.1201 .38114 .12798 .39371 .13877 .3967 .1309 .384 Mtetra
.376 .506 .862 r
.1309 .384 .13877 .3967 .14969 .39953 .14182 .3867 Mtetra
.389 .511 .861 r
.14182 .3867 .14969 .39953 .16073 .4022 .15286 .38924 Mtetra
.401 .516 .86 r
.15286 .38924 .16073 .4022 .17189 .40468 .16402 .39159 Mtetra
.413 .521 .858 r
.16402 .39159 .17189 .40468 .18317 .40695 .17531 .39374 Mtetra
.426 .527 .857 r
.17531 .39374 .18317 .40695 .19457 .40901 .18671 .39567 Mtetra
.439 .532 .856 r
.18671 .39567 .19457 .40901 .2061 .41083 .19825 .39738 Mtetra
.451 .537 .854 r
.19825 .39738 .2061 .41083 .21775 .41241 .2099 .39883 Mtetra
.464 .543 .852 r
.2099 .39883 .21775 .41241 .22952 .41371 .22168 .40002 Mtetra
.476 .548 .851 r
.22168 .40002 .22952 .41371 .24142 .41474 .23358 .40094 Mtetra
.489 .554 .849 r
.23358 .40094 .24142 .41474 .25343 .41546 .2456 .40156 Mtetra
.501 .559 .847 r
.2456 .40156 .25343 .41546 .26557 .41588 .25774 .40187 Mtetra
.513 .564 .845 r
.25774 .40187 .26557 .41588 .27783 .41597 .27 .40186 Mtetra
.525 .569 .843 r
.27 .40186 .27783 .41597 .2902 .41573 .28239 .40152 Mtetra
.536 .574 .841 r
.28239 .40152 .2902 .41573 .30269 .41513 .29488 .40083 Mtetra
.547 .579 .838 r
.29488 .40083 .30269 .41513 .31529 .41417 .30749 .39978 Mtetra
.558 .584 .836 r
.30749 .39978 .31529 .41417 .32801 .41283 .32021 .39836 Mtetra
.569 .589 .834 r
.32021 .39836 .32801 .41283 .34083 .41111 .33304 .39657 Mtetra
.58 .594 .832 r
.33304 .39657 .34083 .41111 .35376 .409 .34598 .39438 Mtetra
.59 .599 .829 r
.34598 .39438 .35376 .409 .36678 .40649 .35902 .3918 Mtetra
.6 .603 .827 r
.35902 .3918 .36678 .40649 .37991 .40357 .37215 .38882 Mtetra
.609 .608 .825 r
.37215 .38882 .37991 .40357 .39313 .40023 .38538 .38543 Mtetra
.619 .612 .822 r
.38538 .38543 .39313 .40023 .40644 .39648 .39871 .38162 Mtetra
.628 .616 .82 r
.39871 .38162 .40644 .39648 .41983 .3923 .41212 .3774 Mtetra
.636 .621 .818 r
.41212 .3774 .41983 .3923 .43331 .3877 .42561 .37276 Mtetra
.645 .625 .815 r
.42561 .37276 .43331 .3877 .44686 .38268 .43918 .36769 Mtetra
.653 .629 .813 r
.43918 .36769 .44686 .38268 .46048 .37722 .45282 .36221 Mtetra
.661 .633 .811 r
.45282 .36221 .46048 .37722 .47418 .37134 .46653 .3563 Mtetra
.668 .636 .809 r
.46653 .3563 .47418 .37134 .48793 .36504 .48031 .34998 Mtetra
.675 .64 .807 r
.48031 .34998 .48793 .36504 .50175 .35832 .49415 .34325 Mtetra
.683 .644 .805 r
.49415 .34325 .50175 .35832 .51561 .35118 .50804 .3361 Mtetra
.689 .647 .803 r
.50804 .3361 .51561 .35118 .52953 .34364 .52198 .32855 Mtetra
.696 .651 .801 r
.52198 .32855 .52953 .34364 .54349 .33569 .53596 .3206 Mtetra
.702 .654 .799 r
.53596 .3206 .54349 .33569 .55749 .32735 .54999 .31227 Mtetra
.708 .658 .798 r
.54999 .31227 .55749 .32735 .57152 .31862 .56405 .30355 Mtetra
.714 .661 .796 r
.56405 .30355 .57152 .31862 .58558 .30952 .57814 .29447 Mtetra
.72 .664 .794 r
.57814 .29447 .58558 .30952 .59967 .30006 .59226 .28502 Mtetra
.725 .667 .793 r
.59226 .28502 .59967 .30006 .61378 .29024 .60641 .27523 Mtetra
.73 .67 .792 r
.60641 .27523 .61378 .29024 .6279 .28009 .62057 .2651 Mtetra
.735 .673 .79 r
.62057 .2651 .6279 .28009 .64204 .26961 .63474 .25465 Mtetra
.74 .676 .789 r
.63474 .25465 .64204 .26961 .65619 .25882 .64893 .2439 Mtetra
.744 .679 .788 r
.64893 .2439 .65619 .25882 .67035 .24773 .66312 .23284 Mtetra
.749 .682 .787 r
.66312 .23284 .67035 .24773 .6845 .23636 .67732 .22151 Mtetra
.753 .685 .786 r
.67732 .22151 .6845 .23636 .69866 .22472 .69152 .20992 Mtetra
.757 .688 .785 r
.69152 .20992 .69866 .22472 .71281 .21283 .70572 .19807 Mtetra
.76 .69 .785 r
.70572 .19807 .71281 .21283 .72696 .20071 .71991 .186 Mtetra
.764 .693 .784 r
.71991 .186 .72696 .20071 .7411 .18837 .7341 .17371 Mtetra
.767 .696 .784 r
.7341 .17371 .7411 .18837 .75523 .17582 .74828 .16122 Mtetra
.352 .494 .861 r
.09094 .36245 .09884 .37504 .10941 .37815 .10151 .36542 Mtetra
.363 .497 .86 r
.10151 .36542 .10941 .37815 .1201 .38114 .1122 .36827 Mtetra
.374 .502 .859 r
.1122 .36827 .1201 .38114 .1309 .384 .12301 .37098 Mtetra
.386 .506 .858 r
.12301 .37098 .1309 .384 .14182 .3867 .13393 .37355 Mtetra
.397 .511 .856 r
.13393 .37355 .14182 .3867 .15286 .38924 .14498 .37595 Mtetra
.409 .515 .855 r
.14498 .37595 .15286 .38924 .16402 .39159 .15615 .37817 Mtetra
.421 .52 .854 r
.15615 .37817 .16402 .39159 .17531 .39374 .16743 .38019 Mtetra
.433 .525 .852 r
.16743 .38019 .17531 .39374 .18671 .39567 .17884 .38199 Mtetra
.445 .53 .851 r
.17884 .38199 .18671 .39567 .19825 .39738 .19038 .38357 Mtetra
.457 .535 .849 r
.19038 .38357 .19825 .39738 .2099 .39883 .20204 .3849 Mtetra
.469 .54 .847 r
.20204 .3849 .2099 .39883 .22168 .40002 .21382 .38597 Mtetra
.481 .545 .845 r
.21382 .38597 .22168 .40002 .23358 .40094 .22572 .38677 Mtetra
.493 .55 .843 r
.22572 .38677 .23358 .40094 .2456 .40156 .23775 .38728 Mtetra
.504 .555 .842 r
.23775 .38728 .2456 .40156 .25774 .40187 .2499 .38748 Mtetra
.516 .56 .839 r
.2499 .38748 .25774 .40187 .27 .40186 .26217 .38737 Mtetra
.527 .565 .837 r
.26217 .38737 .27 .40186 .28239 .40152 .27455 .38693 Mtetra
.538 .57 .835 r
.27455 .38693 .28239 .40152 .29488 .40083 .28705 .38614 Mtetra
.549 .575 .833 r
.28705 .38614 .29488 .40083 .30749 .39978 .29967 .385 Mtetra
.56 .58 .831 r
.29967 .385 .30749 .39978 .32021 .39836 .3124 .3835 Mtetra
.57 .585 .829 r
.3124 .3835 .32021 .39836 .33304 .39657 .32524 .38162 Mtetra
.58 .589 .826 r
.32524 .38162 .33304 .39657 .34598 .39438 .33818 .37936 Mtetra
.59 .594 .824 r
.33818 .37936 .34598 .39438 .35902 .3918 .35123 .37671 Mtetra
.599 .598 .822 r
.35123 .37671 .35902 .3918 .37215 .38882 .36437 .37367 Mtetra
.609 .603 .82 r
.36437 .37367 .37215 .38882 .38538 .38543 .37762 .37021 Mtetra
.618 .607 .818 r
.37762 .37021 .38538 .38543 .39871 .38162 .39095 .36636 Mtetra
.626 .611 .815 r
.39095 .36636 .39871 .38162 .41212 .3774 .40437 .36208 Mtetra
.635 .615 .813 r
.40437 .36208 .41212 .3774 .42561 .37276 .41788 .3574 Mtetra
.643 .619 .811 r
.41788 .3574 .42561 .37276 .43918 .36769 .43146 .3523 Mtetra
.651 .623 .809 r
.43146 .3523 .43918 .36769 .45282 .36221 .44512 .34679 Mtetra
.659 .627 .807 r
.44512 .34679 .45282 .36221 .46653 .3563 .45885 .34086 Mtetra
.666 .631 .805 r
.45885 .34086 .46653 .3563 .48031 .34998 .47265 .33452 Mtetra
.673 .634 .803 r
.47265 .33452 .48031 .34998 .49415 .34325 .48651 .32777 Mtetra
.68 .638 .801 r
.48651 .32777 .49415 .34325 .50804 .3361 .50042 .32061 Mtetra
.687 .642 .799 r
.50042 .32061 .50804 .3361 .52198 .32855 .51438 .31306 Mtetra
.693 .645 .797 r
.51438 .31306 .52198 .32855 .53596 .3206 .52839 .30512 Mtetra
.699 .649 .796 r
.52839 .30512 .53596 .3206 .54999 .31227 .54245 .29679 Mtetra
.705 .652 .794 r
.54245 .29679 .54999 .31227 .56405 .30355 .55654 .28808 Mtetra
.711 .655 .793 r
.55654 .28808 .56405 .30355 .57814 .29447 .57066 .27902 Mtetra
.716 .658 .791 r
.57066 .27902 .57814 .29447 .59226 .28502 .58481 .26959 Mtetra
.722 .662 .79 r
.58481 .26959 .59226 .28502 .60641 .27523 .59898 .25983 Mtetra
.727 .665 .789 r
.59898 .25983 .60641 .27523 .62057 .2651 .61318 .24973 Mtetra
.732 .668 .787 r
.61318 .24973 .62057 .2651 .63474 .25465 .62739 .23931 Mtetra
.736 .671 .786 r
.62739 .23931 .63474 .25465 .64893 .2439 .64162 .22859 Mtetra
.741 .674 .785 r
.64162 .22859 .64893 .2439 .66312 .23284 .65585 .21758 Mtetra
.745 .677 .784 r
.65585 .21758 .66312 .23284 .67732 .22151 .67009 .20629 Mtetra
.749 .68 .784 r
.67009 .20629 .67732 .22151 .69152 .20992 .68433 .19475 Mtetra
.753 .682 .783 r
.68433 .19475 .69152 .20992 .70572 .19807 .69857 .18295 Mtetra
.757 .685 .782 r
.69857 .18295 .70572 .19807 .71991 .186 .71281 .17093 Mtetra
.76 .688 .782 r
.71281 .17093 .71991 .186 .7341 .17371 .72704 .15869 Mtetra
.764 .691 .782 r
.72704 .15869 .7341 .17371 .74828 .16122 .74127 .14626 Mtetra
.362 .494 .857 r
.08303 .34957 .09094 .36245 .10151 .36542 .09361 .35239 Mtetra
.373 .498 .856 r
.09361 .35239 .10151 .36542 .1122 .36827 .1043 .35509 Mtetra
.383 .502 .855 r
.1043 .35509 .1122 .36827 .12301 .37098 .11511 .35767 Mtetra
.394 .506 .853 r
.11511 .35767 .12301 .37098 .13393 .37355 .12604 .36009 Mtetra
.405 .51 .852 r
.12604 .36009 .13393 .37355 .14498 .37595 .13709 .36235 Mtetra
.417 .515 .851 r
.13709 .36235 .14498 .37595 .15615 .37817 .14826 .36443 Mtetra
.428 .519 .849 r
.14826 .36443 .15615 .37817 .16743 .38019 .15955 .36631 Mtetra
.439 .524 .847 r
.15955 .36631 .16743 .38019 .17884 .38199 .17096 .36798 Mtetra
.451 .528 .846 r
.17096 .36798 .17884 .38199 .19038 .38357 .1825 .36943 Mtetra
.462 .533 .844 r
.1825 .36943 .19038 .38357 .20204 .3849 .19416 .37063 Mtetra
.474 .538 .842 r
.19416 .37063 .20204 .3849 .21382 .38597 .20595 .37158 Mtetra
.485 .543 .84 r
.20595 .37158 .21382 .38597 .22572 .38677 .21786 .37226 Mtetra
.497 .548 .839 r
.21786 .37226 .22572 .38677 .23775 .38728 .22989 .37265 Mtetra
.508 .552 .837 r
.22989 .37265 .23775 .38728 .2499 .38748 .24204 .37274 Mtetra
.519 .557 .835 r
.24204 .37274 .2499 .38748 .26217 .38737 .25431 .37252 Mtetra
.53 .562 .832 r
.25431 .37252 .26217 .38737 .27455 .38693 .2667 .37197 Mtetra
.54 .567 .83 r
.2667 .37197 .27455 .38693 .28705 .38614 .27921 .37108 Mtetra
.551 .571 .828 r
.27921 .37108 .28705 .38614 .29967 .385 .29183 .36985 Mtetra
.561 .576 .826 r
.29183 .36985 .29967 .385 .3124 .3835 .30457 .36826 Mtetra
.571 .58 .824 r
.30457 .36826 .3124 .3835 .32524 .38162 .31741 .3663 Mtetra
.581 .585 .822 r
.31741 .3663 .32524 .38162 .33818 .37936 .33036 .36396 Mtetra
.59 .589 .82 r
.33036 .36396 .33818 .37936 .35123 .37671 .34342 .36124 Mtetra
.599 .594 .817 r
.34342 .36124 .35123 .37671 .36437 .37367 .35657 .35812 Mtetra
.608 .598 .815 r
.35657 .35812 .36437 .37367 .37762 .37021 .36983 .35461 Mtetra
.617 .602 .813 r
.36983 .35461 .37762 .37021 .39095 .36636 .38317 .3507 Mtetra
.625 .606 .811 r
.38317 .3507 .39095 .36636 .40437 .36208 .39661 .34638 Mtetra
.634 .61 .809 r
.39661 .34638 .40437 .36208 .41788 .3574 .41012 .34165 Mtetra
.642 .614 .807 r
.41012 .34165 .41788 .3574 .43146 .3523 .42372 .33651 Mtetra
.649 .618 .805 r
.42372 .33651 .43146 .3523 .44512 .34679 .4374 .33097 Mtetra
.657 .622 .803 r
.4374 .33097 .44512 .34679 .45885 .34086 .45114 .32501 Mtetra
.664 .626 .801 r
.45114 .32501 .45885 .34086 .47265 .33452 .46496 .31865 Mtetra
.671 .629 .799 r
.46496 .31865 .47265 .33452 .48651 .32777 .47883 .31189 Mtetra
.678 .633 .797 r
.47883 .31189 .48651 .32777 .50042 .32061 .49277 .30473 Mtetra
.684 .636 .796 r
.49277 .30473 .50042 .32061 .51438 .31306 .50675 .29718 Mtetra
.69 .64 .794 r
.50675 .29718 .51438 .31306 .52839 .30512 .52079 .28924 Mtetra
.696 .643 .793 r
.52079 .28924 .52839 .30512 .54245 .29679 .53486 .28092 Mtetra
.702 .647 .791 r
.53486 .28092 .54245 .29679 .55654 .28808 .54898 .27223 Mtetra
.708 .65 .79 r
.54898 .27223 .55654 .28808 .57066 .27902 .56313 .26318 Mtetra
.713 .653 .788 r
.56313 .26318 .57066 .27902 .58481 .26959 .57731 .25378 Mtetra
.719 .656 .787 r
.57731 .25378 .58481 .26959 .59898 .25983 .59152 .24404 Mtetra
.724 .659 .786 r
.59152 .24404 .59898 .25983 .61318 .24973 .60574 .23398 Mtetra
.728 .663 .785 r
.60574 .23398 .61318 .24973 .62739 .23931 .61999 .2236 Mtetra
.733 .666 .784 r
.61999 .2236 .62739 .23931 .64162 .22859 .63425 .21292 Mtetra
.737 .669 .783 r
.63425 .21292 .64162 .22859 .65585 .21758 .64852 .20195 Mtetra
.742 .672 .782 r
.64852 .20195 .65585 .21758 .67009 .20629 .6628 .19071 Mtetra
.746 .674 .781 r
.6628 .19071 .67009 .20629 .68433 .19475 .67708 .17922 Mtetra
.75 .677 .781 r
.67708 .17922 .68433 .19475 .69857 .18295 .69137 .16748 Mtetra
.753 .68 .78 r
.69137 .16748 .69857 .18295 .71281 .17093 .70565 .15551 Mtetra
.757 .683 .78 r
.70565 .15551 .71281 .17093 .72704 .15869 .71993 .14333 Mtetra
.76 .686 .78 r
.71993 .14333 .72704 .15869 .74127 .14626 .7342 .13096 Mtetra
.372 .495 .854 r
.0751 .33641 .08303 .34957 .09361 .35239 .08569 .33908 Mtetra
.382 .499 .853 r
.08569 .33908 .09361 .35239 .1043 .35509 .09638 .34164 Mtetra
.392 .502 .851 r
.09638 .34164 .1043 .35509 .11511 .35767 .1072 .34406 Mtetra
.402 .506 .85 r
.1072 .34406 .11511 .35767 .12604 .36009 .11813 .34634 Mtetra
.413 .51 .848 r
.11813 .34634 .12604 .36009 .13709 .36235 .12918 .34845 Mtetra
.424 .514 .846 r
.12918 .34845 .13709 .36235 .14826 .36443 .14036 .35038 Mtetra
.435 .518 .845 r
.14036 .35038 .14826 .36443 .15955 .36631 .15165 .35212 Mtetra
.446 .522 .843 r
.15165 .35212 .15955 .36631 .17096 .36798 .16307 .35366 Mtetra
.457 .527 .841 r
.16307 .35366 .17096 .36798 .1825 .36943 .17461 .35497 Mtetra
.468 .531 .84 r
.17461 .35497 .1825 .36943 .19416 .37063 .18628 .35604 Mtetra
.479 .536 .838 r
.18628 .35604 .19416 .37063 .20595 .37158 .19807 .35686 Mtetra
.489 .54 .836 r
.19807 .35686 .20595 .37158 .21786 .37226 .20998 .35741 Mtetra
.5 .545 .834 r
.20998 .35741 .21786 .37226 .22989 .37265 .22201 .35768 Mtetra
.511 .55 .832 r
.22201 .35768 .22989 .37265 .24204 .37274 .23417 .35765 Mtetra
.521 .554 .83 r
.23417 .35765 .24204 .37274 .25431 .37252 .24645 .35732 Mtetra
.532 .559 .828 r
.24645 .35732 .25431 .37252 .2667 .37197 .25884 .35666 Mtetra
.542 .563 .826 r
.25884 .35666 .2667 .37197 .27921 .37108 .27135 .35567 Mtetra
.552 .568 .824 r
.27135 .35567 .27921 .37108 .29183 .36985 .28398 .35434 Mtetra
.562 .572 .822 r
.28398 .35434 .29183 .36985 .30457 .36826 .29672 .35266 Mtetra
.572 .577 .819 r
.29672 .35266 .30457 .36826 .31741 .3663 .30957 .35061 Mtetra
.581 .581 .817 r
.30957 .35061 .31741 .3663 .33036 .36396 .32253 .34819 Mtetra
.59 .585 .815 r
.32253 .34819 .33036 .36396 .34342 .36124 .33559 .3454 Mtetra
.599 .589 .813 r
.33559 .3454 .34342 .36124 .35657 .35812 .34875 .34221 Mtetra
.608 .594 .811 r
.34875 .34221 .35657 .35812 .36983 .35461 .36201 .33864 Mtetra
.616 .598 .809 r
.36201 .33864 .36983 .35461 .38317 .3507 .37537 .33467 Mtetra
.624 .602 .807 r
.37537 .33467 .38317 .3507 .39661 .34638 .38881 .3303 Mtetra
.632 .606 .805 r
.38881 .3303 .39661 .34638 .41012 .34165 .40234 .32553 Mtetra
.64 .609 .803 r
.40234 .32553 .41012 .34165 .42372 .33651 .41596 .32035 Mtetra
.648 .613 .801 r
.41596 .32035 .42372 .33651 .4374 .33097 .42964 .31477 Mtetra
.655 .617 .799 r
.42964 .31477 .4374 .33097 .45114 .32501 .4434 .3088 Mtetra
.662 .621 .798 r
.4434 .3088 .45114 .32501 .46496 .31865 .45723 .30242 Mtetra
.669 .624 .796 r
.45723 .30242 .46496 .31865 .47883 .31189 .47113 .29564 Mtetra
.675 .628 .794 r
.47113 .29564 .47883 .31189 .49277 .30473 .48508 .28847 Mtetra
.682 .631 .793 r
.48508 .28847 .49277 .30473 .50675 .29718 .49908 .28092 Mtetra
.688 .635 .791 r
.49908 .28092 .50675 .29718 .52079 .28924 .51314 .27298 Mtetra
.694 .638 .79 r
.51314 .27298 .52079 .28924 .53486 .28092 .52724 .26467 Mtetra
.699 .642 .788 r
.52724 .26467 .53486 .28092 .54898 .27223 .54138 .256 Mtetra
.705 .645 .787 r
.54138 .256 .54898 .27223 .56313 .26318 .55556 .24697 Mtetra
.71 .648 .786 r
.55556 .24697 .56313 .26318 .57731 .25378 .56977 .2376 Mtetra
.715 .651 .784 r
.56977 .2376 .57731 .25378 .59152 .24404 .584 .22789 Mtetra
.72 .654 .783 r
.584 .22789 .59152 .24404 .60574 .23398 .59826 .21786 Mtetra
.725 .658 .782 r
.59826 .21786 .60574 .23398 .61999 .2236 .61254 .20753 Mtetra
.73 .661 .781 r
.61254 .20753 .61999 .2236 .63425 .21292 .62683 .19689 Mtetra
.734 .664 .781 r
.62683 .19689 .63425 .21292 .64852 .20195 .64114 .18597 Mtetra
.738 .667 .78 r
.64114 .18597 .64852 .20195 .6628 .19071 .65546 .17478 Mtetra
.742 .67 .779 r
.65546 .17478 .6628 .19071 .67708 .17922 .66978 .16334 Mtetra
.746 .672 .779 r
.66978 .16334 .67708 .17922 .69137 .16748 .6841 .15166 Mtetra
.75 .675 .778 r
.6841 .15166 .69137 .16748 .70565 .15551 .69843 .13975 Mtetra
.753 .678 .778 r
.69843 .13975 .70565 .15551 .71993 .14333 .71276 .12764 Mtetra
.757 .681 .778 r
.71276 .12764 .71993 .14333 .7342 .13096 .72708 .11533 Mtetra
.381 .496 .851 r
.06717 .323 .0751 .33641 .08569 .33908 .07775 .32551 Mtetra
.391 .499 .849 r
.07775 .32551 .08569 .33908 .09638 .34164 .08846 .32791 Mtetra
.4 .503 .848 r
.08846 .32791 .09638 .34164 .1072 .34406 .09928 .33018 Mtetra
.41 .506 .846 r
.09928 .33018 .1072 .34406 .11813 .34634 .11021 .3323 Mtetra
.42 .51 .844 r
.11021 .3323 .11813 .34634 .12918 .34845 .12127 .33426 Mtetra
.431 .514 .843 r
.12127 .33426 .12918 .34845 .14036 .35038 .13245 .33605 Mtetra
.441 .517 .841 r
.13245 .33605 .14036 .35038 .15165 .35212 .14375 .33764 Mtetra
.451 .521 .839 r
.14375 .33764 .15165 .35212 .16307 .35366 .15517 .33903 Mtetra
.462 .526 .837 r
.15517 .33903 .16307 .35366 .17461 .35497 .16671 .3402 Mtetra
.472 .53 .835 r
.16671 .3402 .17461 .35497 .18628 .35604 .17838 .34113 Mtetra
.483 .534 .833 r
.17838 .34113 .18628 .35604 .19807 .35686 .19017 .34182 Mtetra
.493 .538 .832 r
.19017 .34182 .19807 .35686 .20998 .35741 .20209 .34224 Mtetra
.504 .543 .83 r
.20209 .34224 .20998 .35741 .22201 .35768 .21413 .34238 Mtetra
.514 .547 .828 r
.21413 .34238 .22201 .35768 .23417 .35765 .22629 .34224 Mtetra
.524 .552 .826 r
.22629 .34224 .23417 .35765 .24645 .35732 .23856 .34179 Mtetra
.534 .556 .824 r
.23856 .34179 .24645 .35732 .25884 .35666 .25096 .34102 Mtetra
.544 .56 .822 r
.25096 .34102 .25884 .35666 .27135 .35567 .26348 .33993 Mtetra
.554 .565 .819 r
.26348 .33993 .27135 .35567 .28398 .35434 .27611 .3385 Mtetra
.563 .569 .817 r
.27611 .3385 .28398 .35434 .29672 .35266 .28886 .33672 Mtetra
.572 .573 .815 r
.28886 .33672 .29672 .35266 .30957 .35061 .30171 .33458 Mtetra
.581 .577 .813 r
.30171 .33458 .30957 .35061 .32253 .34819 .31467 .33208 Mtetra
.59 .581 .811 r
.31467 .33208 .32253 .34819 .33559 .3454 .32774 .3292 Mtetra
.599 .585 .809 r
.32774 .3292 .33559 .3454 .34875 .34221 .34091 .32595 Mtetra
.607 .589 .807 r
.34091 .32595 .34875 .34221 .36201 .33864 .35418 .32231 Mtetra
.615 .593 .805 r
.35418 .32231 .36201 .33864 .37537 .33467 .36754 .31828 Mtetra
.623 .597 .803 r
.36754 .31828 .37537 .33467 .38881 .3303 .381 .31386 Mtetra
.631 .601 .801 r
.381 .31386 .38881 .3303 .40234 .32553 .39454 .30904 Mtetra
.639 .605 .8 r
.39454 .30904 .40234 .32553 .41596 .32035 .40816 .30383 Mtetra
.646 .609 .798 r
.40816 .30383 .41596 .32035 .42964 .31477 .42186 .29822 Mtetra
.653 .612 .796 r
.42186 .29822 .42964 .31477 .4434 .3088 .43564 .29222 Mtetra
.66 .616 .794 r
.43564 .29222 .4434 .3088 .45723 .30242 .44948 .28582 Mtetra
.667 .62 .793 r
.44948 .28582 .45723 .30242 .47113 .29564 .46339 .27903 Mtetra
.673 .623 .791 r
.46339 .27903 .47113 .29564 .48508 .28847 .47736 .27186 Mtetra
.679 .627 .79 r
.47736 .27186 .48508 .28847 .49908 .28092 .49138 .2643 Mtetra
.685 .63 .788 r
.49138 .2643 .49908 .28092 .51314 .27298 .50546 .25637 Mtetra
.691 .634 .787 r
.50546 .25637 .51314 .27298 .52724 .26467 .51958 .24807 Mtetra
.697 .637 .785 r
.51958 .24807 .52724 .26467 .54138 .256 .53374 .23942 Mtetra
.702 .64 .784 r
.53374 .23942 .54138 .256 .55556 .24697 .54795 .23042 Mtetra
.707 .643 .783 r
.54795 .23042 .55556 .24697 .56977 .2376 .56218 .22107 Mtetra
.713 .647 .782 r
.56218 .22107 .56977 .2376 .584 .22789 .57644 .2114 Mtetra
.717 .65 .781 r
.57644 .2114 .584 .22789 .59826 .21786 .59073 .20141 Mtetra
.722 .653 .78 r
.59073 .20141 .59826 .21786 .61254 .20753 .60504 .19111 Mtetra
.727 .656 .779 r
.60504 .19111 .61254 .20753 .62683 .19689 .61937 .18052 Mtetra
.731 .659 .779 r
.61937 .18052 .62683 .19689 .64114 .18597 .63371 .16965 Mtetra
.735 .662 .778 r
.63371 .16965 .64114 .18597 .65546 .17478 .64807 .15852 Mtetra
.739 .665 .777 r
.64807 .15852 .65546 .17478 .66978 .16334 .66243 .14714 Mtetra
.743 .668 .777 r
.66243 .14714 .66978 .16334 .6841 .15166 .67679 .13551 Mtetra
.747 .671 .777 r
.67679 .13551 .6841 .15166 .69843 .13975 .69116 .12367 Mtetra
.75 .674 .776 r
.69116 .12367 .69843 .13975 .71276 .12764 .70553 .11162 Mtetra
.753 .676 .776 r
.70553 .11162 .71276 .12764 .72708 .11533 .71989 .09938 Mtetra
.39 .498 .848 r
.05922 .30934 .06717 .323 .07775 .32551 .06981 .31169 Mtetra
.399 .5 .846 r
.06981 .31169 .07775 .32551 .08846 .32791 .08052 .31392 Mtetra
.408 .503 .844 r
.08052 .31392 .08846 .32791 .09928 .33018 .09134 .31603 Mtetra
.418 .506 .842 r
.09134 .31603 .09928 .33018 .11021 .3323 .10228 .318 Mtetra
.427 .51 .841 r
.10228 .318 .11021 .3323 .12127 .33426 .11335 .3198 Mtetra
.437 .513 .839 r
.11335 .3198 .12127 .33426 .13245 .33605 .12453 .32143 Mtetra
.447 .517 .837 r
.12453 .32143 .13245 .33605 .14375 .33764 .13583 .32288 Mtetra
.457 .521 .835 r
.13583 .32288 .14375 .33764 .15517 .33903 .14726 .32412 Mtetra
.467 .525 .833 r
.14726 .32412 .15517 .33903 .16671 .3402 .1588 .32514 Mtetra
.477 .529 .831 r
.1588 .32514 .16671 .3402 .17838 .34113 .17048 .32594 Mtetra
.487 .533 .83 r
.17048 .32594 .17838 .34113 .19017 .34182 .18227 .32648 Mtetra
.497 .537 .828 r
.18227 .32648 .19017 .34182 .20209 .34224 .19419 .32677 Mtetra
.507 .541 .826 r
.19419 .32677 .20209 .34224 .21413 .34238 .20623 .32678 Mtetra
.517 .545 .824 r
.20623 .32678 .21413 .34238 .22629 .34224 .21839 .32651 Mtetra
.527 .549 .822 r
.21839 .32651 .22629 .34224 .23856 .34179 .23067 .32594 Mtetra
.536 .553 .82 r
.23067 .32594 .23856 .34179 .25096 .34102 .24307 .32506 Mtetra
.546 .557 .818 r
.24307 .32506 .25096 .34102 .26348 .33993 .25559 .32386 Mtetra
.555 .562 .816 r
.25559 .32386 .26348 .33993 .27611 .3385 .26823 .32232 Mtetra
.564 .566 .814 r
.26823 .32232 .27611 .3385 .28886 .33672 .28098 .32045 Mtetra
.573 .57 .811 r
.28098 .32045 .28886 .33672 .30171 .33458 .29384 .31822 Mtetra
.582 .574 .809 r
.29384 .31822 .30171 .33458 .31467 .33208 .3068 .31563 Mtetra
.59 .578 .808 r
.3068 .31563 .31467 .33208 .32774 .3292 .31988 .31268 Mtetra
.599 .582 .806 r
.31988 .31268 .32774 .3292 .34091 .32595 .33305 .30935 Mtetra
.607 .586 .804 r
.33305 .30935 .34091 .32595 .35418 .32231 .34633 .30564 Mtetra
.615 .59 .802 r
.34633 .30564 .35418 .32231 .36754 .31828 .3597 .30156 Mtetra
.622 .593 .8 r
.3597 .30156 .36754 .31828 .381 .31386 .37316 .29708 Mtetra
.63 .597 .798 r
.37316 .29708 .381 .31386 .39454 .30904 .38671 .29222 Mtetra
.637 .601 .796 r
.38671 .29222 .39454 .30904 .40816 .30383 .40034 .28697 Mtetra
.644 .605 .795 r
.40034 .28697 .40816 .30383 .42186 .29822 .41405 .28133 Mtetra
.651 .608 .793 r
.41405 .28133 .42186 .29822 .43564 .29222 .42784 .2753 Mtetra
.658 .612 .791 r
.42784 .2753 .43564 .29222 .44948 .28582 .4417 .26888 Mtetra
.665 .615 .79 r
.4417 .26888 .44948 .28582 .46339 .27903 .45562 .26208 Mtetra
.671 .619 .788 r
.45562 .26208 .46339 .27903 .47736 .27186 .46961 .2549 Mtetra
.677 .622 .787 r
.46961 .2549 .47736 .27186 .49138 .2643 .48365 .24734 Mtetra
.683 .626 .785 r
.48365 .24734 .49138 .2643 .50546 .25637 .49774 .23942 Mtetra
.689 .629 .784 r
.49774 .23942 .50546 .25637 .51958 .24807 .51188 .23114 Mtetra
.694 .633 .783 r
.51188 .23114 .51958 .24807 .53374 .23942 .52607 .2225 Mtetra
.7 .636 .782 r
.52607 .2225 .53374 .23942 .54795 .23042 .5403 .21352 Mtetra
.705 .639 .781 r
.5403 .21352 .54795 .23042 .56218 .22107 .55455 .20421 Mtetra
.71 .642 .78 r
.55455 .20421 .56218 .22107 .57644 .2114 .56885 .19457 Mtetra
.714 .645 .779 r
.56885 .19457 .57644 .2114 .59073 .20141 .58316 .18462 Mtetra
.719 .649 .778 r
.58316 .18462 .59073 .20141 .60504 .19111 .5975 .17437 Mtetra
.724 .652 .777 r
.5975 .17437 .60504 .19111 .61937 .18052 .61186 .16383 Mtetra
.728 .655 .777 r
.61186 .16383 .61937 .18052 .63371 .16965 .62624 .15301 Mtetra
.732 .658 .776 r
.62624 .15301 .63371 .16965 .64807 .15852 .64063 .14194 Mtetra
.736 .661 .776 r
.64063 .14194 .64807 .15852 .66243 .14714 .65502 .13061 Mtetra
.74 .664 .775 r
.65502 .13061 .66243 .14714 .67679 .13551 .66943 .11906 Mtetra
.743 .666 .775 r
.66943 .11906 .67679 .13551 .69116 .12367 .68384 .10728 Mtetra
.747 .669 .775 r
.68384 .10728 .69116 .12367 .70553 .11162 .69825 .0953 Mtetra
.75 .672 .775 r
.69825 .0953 .70553 .11162 .71989 .09938 .71266 .08313 Mtetra
.399 .499 .845 r
.05125 .29544 .05922 .30934 .06981 .31169 .06185 .29762 Mtetra
.407 .501 .843 r
.06185 .29762 .06981 .31169 .08052 .31392 .07257 .29969 Mtetra
.416 .504 .841 r
.07257 .29969 .08052 .31392 .09134 .31603 .0834 .30163 Mtetra
.425 .507 .839 r
.0834 .30163 .09134 .31603 .10228 .318 .09434 .30344 Mtetra
.434 .51 .837 r
.09434 .30344 .10228 .318 .11335 .3198 .10541 .30508 Mtetra
.443 .513 .836 r
.10541 .30508 .11335 .3198 .12453 .32143 .1166 .30656 Mtetra
.453 .517 .834 r
.1166 .30656 .12453 .32143 .13583 .32288 .1279 .30784 Mtetra
.462 .52 .832 r
.1279 .30784 .13583 .32288 .14726 .32412 .13933 .30893 Mtetra
.472 .524 .83 r
.13933 .30893 .14726 .32412 .1588 .32514 .15088 .30981 Mtetra
.481 .527 .828 r
.15088 .30981 .1588 .32514 .17048 .32594 .16256 .31046 Mtetra
.491 .531 .826 r
.16256 .31046 .17048 .32594 .18227 .32648 .17435 .31086 Mtetra
.501 .535 .824 r
.17435 .31086 .18227 .32648 .19419 .32677 .18627 .31101 Mtetra
.51 .539 .822 r
.18627 .31101 .19419 .32677 .20623 .32678 .19832 .31089 Mtetra
.52 .543 .82 r
.19832 .31089 .20623 .32678 .21839 .32651 .21048 .31049 Mtetra
.529 .547 .818 r
.21048 .31049 .21839 .32651 .23067 .32594 .22277 .3098 Mtetra
.538 .551 .816 r
.22277 .3098 .23067 .32594 .24307 .32506 .23517 .3088 Mtetra
.547 .555 .814 r
.23517 .3088 .24307 .32506 .25559 .32386 .24769 .30749 Mtetra
.556 .559 .812 r
.24769 .30749 .25559 .32386 .26823 .32232 .26033 .30585 Mtetra
.565 .563 .81 r
.26033 .30585 .26823 .32232 .28098 .32045 .27308 .30387 Mtetra
.574 .567 .808 r
.27308 .30387 .28098 .32045 .29384 .31822 .28595 .30155 Mtetra
.582 .571 .806 r
.28595 .30155 .29384 .31822 .3068 .31563 .29892 .29887 Mtetra
.59 .575 .804 r
.29892 .29887 .3068 .31563 .31988 .31268 .312 .29584 Mtetra
.598 .579 .802 r
.312 .29584 .31988 .31268 .33305 .30935 .32518 .29243 Mtetra
.606 .582 .8 r
.32518 .29243 .33305 .30935 .34633 .30564 .33846 .28866 Mtetra
.614 .586 .799 r
.33846 .28866 .34633 .30564 .3597 .30156 .35183 .28451 Mtetra
.622 .59 .797 r
.35183 .28451 .3597 .30156 .37316 .29708 .3653 .27998 Mtetra
.629 .594 .795 r
.3653 .27998 .37316 .29708 .38671 .29222 .37886 .27507 Mtetra
.636 .597 .793 r
.37886 .27507 .38671 .29222 .40034 .28697 .3925 .26978 Mtetra
.643 .601 .792 r
.3925 .26978 .40034 .28697 .41405 .28133 .40622 .26411 Mtetra
.65 .604 .79 r
.40622 .26411 .41405 .28133 .42784 .2753 .42002 .25805 Mtetra
.656 .608 .789 r
.42002 .25805 .42784 .2753 .4417 .26888 .43389 .25162 Mtetra
.663 .612 .787 r
.43389 .25162 .4417 .26888 .45562 .26208 .44783 .2448 Mtetra
.669 .615 .786 r
.44783 .2448 .45562 .26208 .46961 .2549 .46183 .23762 Mtetra
.675 .618 .784 r
.46183 .23762 .46961 .2549 .48365 .24734 .47588 .23006 Mtetra
.681 .622 .783 r
.47588 .23006 .48365 .24734 .49774 .23942 .49 .22215 Mtetra
.686 .625 .782 r
.49 .22215 .49774 .23942 .51188 .23114 .50416 .21388 Mtetra
.692 .628 .781 r
.50416 .21388 .51188 .23114 .52607 .2225 .51836 .20526 Mtetra
.697 .632 .78 r
.51836 .20526 .52607 .2225 .5403 .21352 .53261 .19631 Mtetra
.702 .635 .779 r
.53261 .19631 .5403 .21352 .55455 .20421 .54689 .18703 Mtetra
.707 .638 .778 r
.54689 .18703 .55455 .20421 .56885 .19457 .56121 .17743 Mtetra
.712 .641 .777 r
.56121 .17743 .56885 .19457 .58316 .18462 .57555 .16752 Mtetra
.716 .644 .776 r
.57555 .16752 .58316 .18462 .5975 .17437 .58992 .15731 Mtetra
.721 .647 .776 r
.58992 .15731 .5975 .17437 .61186 .16383 .60431 .14683 Mtetra
.725 .651 .775 r
.60431 .14683 .61186 .16383 .62624 .15301 .61872 .13607 Mtetra
.729 .654 .775 r
.61872 .13607 .62624 .15301 .64063 .14194 .63314 .12505 Mtetra
.733 .657 .774 r
.63314 .12505 .64063 .14194 .65502 .13061 .64757 .11379 Mtetra
.737 .66 .774 r
.64757 .11379 .65502 .13061 .66943 .11906 .66201 .1023 Mtetra
.74 .662 .774 r
.66201 .1023 .66943 .11906 .68384 .10728 .67646 .0906 Mtetra
.744 .665 .774 r
.67646 .0906 .68384 .10728 .69825 .0953 .69091 .07869 Mtetra
.747 .668 .774 r
.69091 .07869 .69825 .0953 .71266 .08313 .70537 .06659 Mtetra
.407 .5 .842 r
.04328 .28131 .05125 .29544 .06185 .29762 .05388 .28332 Mtetra
.415 .502 .84 r
.05388 .28332 .06185 .29762 .07257 .29969 .0646 .28523 Mtetra
.423 .505 .838 r
.0646 .28523 .07257 .29969 .0834 .30163 .07544 .287 Mtetra
.432 .507 .836 r
.07544 .287 .0834 .30163 .09434 .30344 .08639 .28864 Mtetra
.44 .51 .834 r
.08639 .28864 .09434 .30344 .10541 .30508 .09746 .29012 Mtetra
.449 .513 .832 r
.09746 .29012 .10541 .30508 .1166 .30656 .10865 .29143 Mtetra
.458 .516 .83 r
.10865 .29143 .1166 .30656 .1279 .30784 .11996 .29256 Mtetra
.467 .52 .828 r
.11996 .29256 .1279 .30784 .13933 .30893 .1314 .29349 Mtetra
.476 .523 .826 r
.1314 .29349 .13933 .30893 .15088 .30981 .14295 .29421 Mtetra
.486 .527 .824 r
.14295 .29421 .15088 .30981 .16256 .31046 .15463 .29471 Mtetra
.495 .53 .823 r
.15463 .29471 .16256 .31046 .17435 .31086 .16643 .29497 Mtetra
.504 .534 .821 r
.16643 .29497 .17435 .31086 .18627 .31101 .17835 .29498 Mtetra
.513 .538 .819 r
.17835 .29498 .18627 .31101 .19832 .31089 .1904 .29473 Mtetra
.522 .541 .817 r
.1904 .29473 .19832 .31089 .21048 .31049 .20256 .2942 Mtetra
.531 .545 .815 r
.20256 .2942 .21048 .31049 .22277 .3098 .21485 .29338 Mtetra
.54 .549 .813 r
.21485 .29338 .22277 .3098 .23517 .3088 .22726 .29226 Mtetra
.549 .553 .811 r
.22726 .29226 .23517 .3088 .24769 .30749 .23978 .29083 Mtetra
.557 .557 .809 r
.23978 .29083 .24769 .30749 .26033 .30585 .25242 .28908 Mtetra
.566 .56 .807 r
.25242 .28908 .26033 .30585 .27308 .30387 .26517 .287 Mtetra
.574 .564 .805 r
.26517 .287 .27308 .30387 .28595 .30155 .27804 .28458 Mtetra
.583 .568 .803 r
.27804 .28458 .28595 .30155 .29892 .29887 .29102 .28182 Mtetra
.591 .572 .801 r
.29102 .28182 .29892 .29887 .312 .29584 .3041 .2787 Mtetra
.598 .576 .799 r
.3041 .2787 .312 .29584 .32518 .29243 .31728 .27522 Mtetra
.606 .579 .797 r
.31728 .27522 .32518 .29243 .33846 .28866 .33057 .27138 Mtetra
.614 .583 .796 r
.33057 .27138 .33846 .28866 .35183 .28451 .34395 .26717 Mtetra
.621 .587 .794 r
.34395 .26717 .35183 .28451 .3653 .27998 .35742 .26258 Mtetra
.628 .59 .792 r
.35742 .26258 .3653 .27998 .37886 .27507 .37099 .25763 Mtetra
.635 .594 .791 r
.37099 .25763 .37886 .27507 .3925 .26978 .38464 .25229 Mtetra
.642 .597 .789 r
.38464 .25229 .3925 .26978 .40622 .26411 .39837 .24659 Mtetra
.648 .601 .787 r
.39837 .24659 .40622 .26411 .42002 .25805 .41217 .2405 Mtetra
.655 .604 .786 r
.41217 .2405 .42002 .25805 .43389 .25162 .42605 .23405 Mtetra
.661 .608 .785 r
.42605 .23405 .43389 .25162 .44783 .2448 .44 .22722 Mtetra
.667 .611 .783 r
.44 .22722 .44783 .2448 .46183 .23762 .45402 .22003 Mtetra
.673 .615 .782 r
.45402 .22003 .46183 .23762 .47588 .23006 .46809 .21248 Mtetra
.678 .618 .781 r
.46809 .21248 .47588 .23006 .49 .22215 .48222 .20458 Mtetra
.684 .621 .78 r
.48222 .20458 .49 .22215 .50416 .21388 .49639 .19632 Mtetra
.689 .625 .779 r
.49639 .19632 .50416 .21388 .51836 .20526 .51062 .18773 Mtetra
.694 .628 .778 r
.51062 .18773 .51836 .20526 .53261 .19631 .52489 .1788 Mtetra
.699 .631 .777 r
.52489 .1788 .53261 .19631 .54689 .18703 .53919 .16955 Mtetra
.704 .634 .776 r
.53919 .16955 .54689 .18703 .56121 .17743 .55353 .15999 Mtetra
.709 .637 .775 r
.55353 .15999 .56121 .17743 .57555 .16752 .5679 .15012 Mtetra
.713 .641 .775 r
.5679 .15012 .57555 .16752 .58992 .15731 .5823 .13997 Mtetra
.718 .644 .774 r
.5823 .13997 .58992 .15731 .60431 .14683 .59672 .12953 Mtetra
.722 .647 .773 r
.59672 .12953 .60431 .14683 .61872 .13607 .61115 .11883 Mtetra
.726 .65 .773 r
.61115 .11883 .61872 .13607 .63314 .12505 .62561 .10788 Mtetra
.73 .653 .773 r
.62561 .10788 .63314 .12505 .64757 .11379 .64008 .09668 Mtetra
.734 .656 .773 r
.64008 .09668 .64757 .11379 .66201 .1023 .65455 .08526 Mtetra
.737 .659 .772 r
.65455 .08526 .66201 .1023 .67646 .0906 .66904 .07363 Mtetra
.741 .662 .772 r
.66904 .07363 .67646 .0906 .69091 .07869 .68353 .0618 Mtetra
.744 .664 .772 r
.68353 .0618 .69091 .07869 .70537 .06659 .69802 .04978 Mtetra
.415 .502 .84 r
.03528 .26697 .04328 .28131 .05388 .28332 .0459 .26881 Mtetra
.422 .504 .837 r
.0459 .26881 .05388 .28332 .0646 .28523 .05663 .27054 Mtetra
.43 .506 .835 r
.05663 .27054 .0646 .28523 .07544 .287 .06747 .27214 Mtetra
.438 .508 .833 r
.06747 .27214 .07544 .287 .08639 .28864 .07843 .27361 Mtetra
.446 .511 .831 r
.07843 .27361 .08639 .28864 .09746 .29012 .0895 .27492 Mtetra
.455 .514 .829 r
.0895 .27492 .09746 .29012 .10865 .29143 .1007 .27607 Mtetra
.463 .516 .827 r
.1007 .27607 .10865 .29143 .11996 .29256 .11201 .27704 Mtetra
.472 .52 .825 r
.11201 .27704 .11996 .29256 .1314 .29349 .12345 .27781 Mtetra
.481 .523 .823 r
.12345 .27781 .1314 .29349 .14295 .29421 .13501 .27838 Mtetra
.49 .526 .821 r
.13501 .27838 .14295 .29421 .15463 .29471 .14669 .27872 Mtetra
.499 .529 .819 r
.14669 .27872 .15463 .29471 .16643 .29497 .15849 .27883 Mtetra
.507 .533 .817 r
.15849 .27883 .16643 .29497 .17835 .29498 .17041 .2787 Mtetra
.516 .536 .815 r
.17041 .2787 .17835 .29498 .1904 .29473 .18246 .27831 Mtetra
.525 .54 .813 r
.18246 .27831 .1904 .29473 .20256 .2942 .19463 .27764 Mtetra
.533 .544 .811 r
.19463 .27764 .20256 .2942 .21485 .29338 .20692 .27669 Mtetra
.542 .547 .809 r
.20692 .27669 .21485 .29338 .22726 .29226 .21933 .27545 Mtetra
.55 .551 .808 r
.21933 .27545 .22726 .29226 .23978 .29083 .23185 .27391 Mtetra
.559 .555 .806 r
.23185 .27391 .23978 .29083 .25242 .28908 .2445 .27204 Mtetra
.567 .558 .804 r
.2445 .27204 .25242 .28908 .26517 .287 .25725 .26986 Mtetra
.575 .562 .802 r
.25725 .26986 .26517 .287 .27804 .28458 .27012 .26734 Mtetra
.583 .566 .8 r
.27012 .26734 .27804 .28458 .29102 .28182 .2831 .26449 Mtetra
.591 .569 .798 r
.2831 .26449 .29102 .28182 .3041 .2787 .29618 .26128 Mtetra
.598 .573 .796 r
.29618 .26128 .3041 .2787 .31728 .27522 .30937 .25773 Mtetra
.606 .576 .795 r
.30937 .25773 .31728 .27522 .33057 .27138 .32266 .25381 Mtetra
.613 .58 .793 r
.32266 .25381 .33057 .27138 .34395 .26717 .33605 .24954 Mtetra
.62 .584 .791 r
.33605 .24954 .34395 .26717 .35742 .26258 .34953 .2449 Mtetra
.627 .587 .79 r
.34953 .2449 .35742 .26258 .37099 .25763 .3631 .23989 Mtetra
.634 .591 .788 r
.3631 .23989 .37099 .25763 .38464 .25229 .37675 .23452 Mtetra
.64 .594 .787 r
.37675 .23452 .38464 .25229 .39837 .24659 .39049 .22878 Mtetra
.647 .598 .785 r
.39049 .22878 .39837 .24659 .41217 .2405 .40431 .22267 Mtetra
.653 .601 .784 r
.40431 .22267 .41217 .2405 .42605 .23405 .4182 .21619 Mtetra
.659 .605 .782 r
.4182 .21619 .42605 .23405 .44 .22722 .43215 .20936 Mtetra
.665 .608 .781 r
.43215 .20936 .44 .22722 .45402 .22003 .44618 .20216 Mtetra
.671 .611 .78 r
.44618 .20216 .45402 .22003 .46809 .21248 .46027 .19461 Mtetra
.676 .615 .779 r
.46027 .19461 .46809 .21248 .48222 .20458 .47441 .18671 Mtetra
.682 .618 .778 r
.47441 .18671 .48222 .20458 .49639 .19632 .4886 .17848 Mtetra
.687 .621 .777 r
.4886 .17848 .49639 .19632 .51062 .18773 .50285 .1699 Mtetra
.692 .624 .776 r
.50285 .1699 .51062 .18773 .52489 .1788 .51713 .161 Mtetra
.697 .628 .775 r
.51713 .161 .52489 .1788 .53919 .16955 .53146 .15179 Mtetra
.702 .631 .774 r
.53146 .15179 .53919 .16955 .55353 .15999 .54582 .14226 Mtetra
.706 .634 .774 r
.54582 .14226 .55353 .15999 .5679 .15012 .56021 .13245 Mtetra
.711 .637 .773 r
.56021 .13245 .5679 .15012 .5823 .13997 .57464 .12234 Mtetra
.715 .64 .773 r
.57464 .12234 .5823 .13997 .59672 .12953 .58908 .11196 Mtetra
.719 .643 .772 r
.58908 .11196 .59672 .12953 .61115 .11883 .60355 .10132 Mtetra
.723 .646 .772 r
.60355 .10132 .61115 .11883 .62561 .10788 .61804 .09043 Mtetra
.727 .649 .772 r
.61804 .09043 .62561 .10788 .64008 .09668 .63254 .07931 Mtetra
.731 .652 .771 r
.63254 .07931 .64008 .09668 .65455 .08526 .64705 .06796 Mtetra
.734 .655 .771 r
.64705 .06796 .65455 .08526 .66904 .07363 .66157 .0564 Mtetra
.738 .658 .771 r
.66157 .0564 .66904 .07363 .68353 .0618 .6761 .04464 Mtetra
.741 .661 .771 r
.6761 .04464 .68353 .0618 .69802 .04978 .69064 .03271 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.36706 .9902 m
.3452 .97407 L
.3329 .9644 L
.3194 .95325 L
.30266 .9386 L
.2936 .93027 L
.27562 .9128 L
.2678 .9048 L
.25128 .887 L
.242 .87644 L
.22927 .8612 L
.2162 .84459 L
.20932 .8354 L
.19121 .8096 L
.1904 .80839 L
.17477 .7838 L
.1646 .76647 L
.15987 .758 L
.1464 .7322 L
.1388 .71637 L
.13427 .7064 L
.1234 .6806 L
.11372 .6548 L
.113 .65276 L
.10519 .629 L
.09776 .6032 L
.0914 .5774 L
.0872 .55756 L
.08607 .5516 L
.08175 .5258 L
.07843 .5 L
.07608 .4742 L
.0747 .4484 L
.07429 .4226 L
.07483 .3968 L
.07634 .371 L
.07882 .3452 L
.08227 .3194 L
.08672 .2936 L
.0872 .29111 L
.09219 .2678 L
.09869 .242 L
.10626 .2162 L
.113 .19588 L
.11494 .1904 L
.12478 .1646 L
.13581 .1388 L
.1388 .13228 L
.14812 .113 L
.16178 .0872 L
Mistroke
.1646 .08217 L
.17687 .0614 L
.1904 .04025 L
.19352 .0356 L
.21187 .0098 L
Mfstroke
.0098 .46552 m
.01102 .4742 L
.0152 .5 L
.02039 .5258 L
.02661 .5516 L
.03389 .5774 L
.0356 .58299 L
.04226 .6032 L
.05178 .629 L
.0614 .65233 L
.06248 .6548 L
.07444 .6806 L
.0872 .70544 L
.08772 .7064 L
.10242 .7322 L
.113 .74933 L
.11863 .758 L
.1365 .7838 L
.1388 .78695 L
.15619 .8096 L
.1646 .8199 L
.1779 .8354 L
.1904 .84917 L
.2019 .8612 L
.2162 .87539 L
.22854 .887 L
.242 .89903 L
.25831 .9128 L
.2678 .92043 L
.29188 .9386 L
.2936 .93983 L
.3194 .95745 L
.3303 .9644 L
.3452 .97343 L
.371 .98791 L
.37531 .9902 L
s
.0098 .28715 m
.01261 .2678 L
.0172 .242 L
.0228 .2162 L
.02945 .1904 L
.0356 .16955 L
.03717 .1646 L
.04601 .1388 L
.056 .113 L
.0614 .10021 L
.06721 .0872 L
.0797 .0614 L
.0872 .0471 L
.09355 .0356 L
.10885 .0098 L
s
.9902 .90793 m
.98772 .9128 L
.97374 .9386 L
.9644 .95452 L
.95831 .9644 L
.94128 .9902 L
s
.9902 .28332 m
.98212 .2678 L
.96755 .242 L
.9644 .23673 L
.95148 .2162 L
.9386 .1972 L
.93376 .1904 L
.91424 .1646 L
.9128 .16278 L
.89272 .1388 L
.887 .13235 L
.86894 .113 L
.8612 .10514 L
.84255 .0872 L
.8354 .08066 L
.81309 .0614 L
.8096 .05853 L
.7838 .03847 L
.7799 .0356 L
.758 .02027 L
.74196 .0098 L
s
.9902 .21817 m
.98876 .2162 L
.96896 .1904 L
.9644 .1848 L
.94712 .1646 L
.9386 .15519 L
.92297 .1388 L
.9128 .12868 L
.89616 .113 L
.887 .1048 L
.86619 .0872 L
.8612 .08319 L
.8354 .06359 L
.83236 .0614 L
.8096 .0458 L
.79359 .0356 L
.7838 .02966 L
.758 .01504 L
.74811 .0098 L
s
.0098 .07321 m
.02582 .0614 L
.0356 .05453 L
.0614 .03758 L
.06458 .0356 L
.0872 .02221 L
.11007 .0098 L
s
.9902 .64451 m
.98578 .6548 L
.97384 .6806 L
.9644 .69924 L
.96058 .7064 L
.9459 .7322 L
.9386 .74414 L
.9297 .758 L
.9128 .78249 L
.91185 .7838 L
.89219 .8096 L
.887 .81601 L
.8705 .8354 L
.8612 .84572 L
.84653 .8612 L
.8354 .87233 L
.81992 .887 L
.8096 .89629 L
.79019 .9128 L
.7838 .91797 L
.758 .93763 L
.75667 .9386 L
.7322 .95548 L
.71831 .9644 L
.7064 .97167 L
.6806 .98635 L
.67339 .9902 L
s
.0098 .98013 m
.02827 .9902 L
s
.9902 .10863 m
.98079 .0872 L
.96829 .0614 L
.9644 .05389 L
.95442 .0356 L
.9391 .0098 L
s
0 g
.03 w
.76753 .42432 Mdot
.69731 .37627 Mdot
.37129 .59562 Mdot
.42909 .62528 Mdot
.35083 .37657 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.48039 .3183 m
.5 .31433 L
.51961 .31263 L
.53922 .31313 L
.55882 .31588 L
.57843 .32101 L
.58581 .32353 L
.59804 .32876 L
.61765 .33961 L
.62292 .34314 L
.63725 .35439 L
.6461 .36275 L
.65686 .37483 L
.66255 .38235 L
.67455 .40196 L
.67647 .40566 L
.68314 .42157 L
.68887 .44118 L
.69203 .46078 L
.69279 .48039 L
.69121 .5 L
.68724 .51961 L
.6807 .53922 L
.67647 .54898 L
.6713 .55882 L
.65847 .57843 L
.65686 .58054 L
.6412 .59804 L
.63725 .60178 L
.61765 .61733 L
.61719 .61765 L
.59804 .62897 L
.57905 .63725 L
.57843 .63748 L
.55882 .64337 L
.53922 .64688 L
.51961 .64814 L
.5 .64718 L
.48039 .64396 L
.46078 .63831 L
.4578 .63725 L
.44118 .62997 L
.42157 .61835 L
.42055 .61765 L
.40196 .60256 L
.39734 .59804 L
.38235 .58046 L
.38088 .57843 L
.36886 .55882 L
.36275 .54579 L
Mistroke
.36027 .53922 L
.35452 .51961 L
.35133 .5 L
.35054 .48039 L
.35209 .46078 L
.35603 .44118 L
.36253 .42157 L
.36275 .42101 L
.37187 .40196 L
.38235 .38544 L
.38464 .38235 L
.40188 .36275 L
.40196 .36266 L
.42157 .34611 L
.42578 .34314 L
.44118 .33378 L
.46078 .32469 L
.46363 .32353 L
.48039 .3183 L
Mfstroke
.48039 .22431 m
.5 .22164 L
.51961 .22042 L
.53922 .22061 L
.55882 .22224 L
.57843 .22533 L
.57928 .22549 L
.59804 .22994 L
.61765 .23617 L
.63725 .24415 L
.63932 .2451 L
.65686 .25409 L
.67418 .26471 L
.67647 .26626 L
.69608 .2811 L
.69986 .28431 L
.71569 .29929 L
.72007 .30392 L
.73529 .32204 L
.73642 .32353 L
.74977 .34314 L
.7549 .35186 L
.76064 .36275 L
.76937 .38235 L
.77451 .39655 L
.77619 .40196 L
.78127 .42157 L
.78471 .44118 L
.78658 .46078 L
.78693 .48039 L
.78576 .5 L
.78307 .51961 L
.77881 .53922 L
.77451 .55416 L
.77292 .55882 L
.76529 .57843 L
.75574 .59804 L
.7549 .59959 L
.74407 .61765 L
.73529 .63024 L
.72991 .63725 L
.71569 .65378 L
.71276 .65686 L
.69608 .67276 L
.69175 .67647 L
.67647 .68839 L
.66528 .69608 L
.65686 .70134 L
.63725 .71205 L
.62964 .71569 L
Mistroke
.61765 .72081 L
.59804 .72781 L
.57843 .73319 L
.56909 .73529 L
.55882 .73704 L
.53922 .73942 L
.51961 .74037 L
.5 .7399 L
.48039 .73798 L
.46383 .73529 L
.46078 .73459 L
.44118 .72965 L
.42157 .72306 L
.40411 .71569 L
.40196 .71467 L
.38235 .70427 L
.36929 .69608 L
.36275 .69154 L
.34366 .67647 L
.34314 .67601 L
.32353 .65691 L
.32348 .65686 L
.30715 .63725 L
.30392 .63287 L
.29381 .61765 L
.28431 .60075 L
.28295 .59804 L
.27421 .57843 L
.26738 .55882 L
.26471 .54955 L
.26229 .53922 L
.25882 .51961 L
.25692 .5 L
.25654 .48039 L
.25767 .46078 L
.26032 .44118 L
.26453 .42157 L
.26471 .42085 L
.27036 .40196 L
.27795 .38235 L
.28431 .36873 L
.28744 .36275 L
.29906 .34314 L
.30392 .33593 L
.31315 .32353 L
.32353 .31117 L
.33024 .30392 L
.34314 .29137 L
.3512 .28431 L
.36275 .27513 L
Mistroke
.37761 .26471 L
.38235 .26169 L
.40196 .25056 L
.41318 .2451 L
.42157 .24144 L
.44118 .23412 L
.46078 .22844 L
.47372 .22549 L
.48039 .22431 L
Mfstroke
.44118 .16175 m
.46078 .15726 L
.48039 .15395 L
.5 .15178 L
.51961 .15074 L
.53922 .15082 L
.55882 .15202 L
.57843 .15436 L
.59804 .15787 L
.61765 .16259 L
.63148 .16667 L
.63725 .16858 L
.65686 .17592 L
.67647 .18472 L
.67961 .18627 L
.69608 .19512 L
.71353 .20588 L
.71569 .20732 L
.73529 .22157 L
.74019 .22549 L
.7549 .23826 L
.7621 .2451 L
.77451 .25796 L
.7805 .26471 L
.79412 .28161 L
.79613 .28431 L
.80945 .30392 L
.81373 .31094 L
.82079 .32353 L
.83037 .34314 L
.83333 .34996 L
.83836 .36275 L
.84489 .38235 L
.85005 .40196 L
.85294 .41583 L
.8539 .42157 L
.85651 .44118 L
.85789 .46078 L
.85808 .48039 L
.85707 .5 L
.85486 .51961 L
.85294 .53179 L
.85144 .53922 L
.84676 .55882 L
.84079 .57843 L
.83344 .59804 L
.83333 .5983 L
.82463 .61765 L
.81424 .63725 L
.81373 .63815 L
Mistroke
.80209 .65686 L
.79412 .6683 L
.78797 .67647 L
.77451 .69275 L
.77154 .69608 L
.7549 .71325 L
.75234 .71569 L
.73529 .73074 L
.72966 .73529 L
.71569 .74578 L
.70222 .7549 L
.69608 .75876 L
.67647 .76995 L
.66754 .77451 L
.65686 .77953 L
.63725 .78765 L
.61861 .79412 L
.61765 .79442 L
.59804 .79991 L
.57843 .80419 L
.55882 .80729 L
.53922 .80925 L
.51961 .81008 L
.5 .80979 L
.48039 .80837 L
.46078 .80579 L
.44118 .80204 L
.42157 .79705 L
.41184 .79412 L
.40196 .79077 L
.38235 .78312 L
.36382 .77451 L
.36275 .77397 L
.34314 .76317 L
.32998 .7549 L
.32353 .75052 L
.30392 .73572 L
.3034 .73529 L
.28431 .71837 L
.28155 .71569 L
.26471 .69782 L
.26319 .69608 L
.2476 .67647 L
.2451 .67302 L
.2343 .65686 L
.22549 .6419 L
.22297 .63725 L
.2134 .61765 L
.20588 .59934 L
.2054 .59804 L
Mistroke
.19886 .57843 L
.19369 .55882 L
.18981 .53922 L
.18718 .51961 L
.18627 .5092 L
.18576 .5 L
.18553 .48039 L
.18627 .46374 L
.1865 .46078 L
.18865 .44118 L
.19202 .42157 L
.19664 .40196 L
.20256 .38235 L
.20588 .3729 L
.20984 .36275 L
.21859 .34314 L
.22549 .32968 L
.22891 .32353 L
.241 .30392 L
.2451 .29788 L
.25506 .28431 L
.26471 .27239 L
.27142 .26471 L
.28431 .25115 L
.29055 .2451 L
.30392 .23309 L
.31318 .22549 L
.32353 .2176 L
.34056 .20588 L
.34314 .20424 L
.36275 .19273 L
.37519 .18627 L
.38235 .18286 L
.40196 .17448 L
.42157 .16747 L
.42406 .16667 L
.44118 .16175 L
Mfstroke
.42157 .10546 m
.44118 .10062 L
.46078 .09679 L
.48039 .09393 L
.5 .09205 L
.51961 .09111 L
.53922 .09112 L
.55882 .09208 L
.57843 .094 L
.59804 .0969 L
.61765 .1008 L
.63725 .10574 L
.64457 .10784 L
.65686 .11175 L
.67647 .11891 L
.69608 .12727 L
.69647 .12745 L
.71569 .13694 L
.73366 .14706 L
.73529 .14804 L
.7549 .16072 L
.76328 .16667 L
.77451 .17519 L
.78794 .18627 L
.79412 .19173 L
.80899 .20588 L
.81373 .21073 L
.82718 .22549 L
.83333 .23279 L
.84302 .2451 L
.85294 .25888 L
.85686 .26471 L
.86894 .28431 L
.87255 .29072 L
.87946 .30392 L
.88855 .32353 L
.89216 .33223 L
.89631 .34314 L
.90285 .36275 L
.90822 .38235 L
.91176 .39828 L
.91247 .40196 L
.91565 .42157 L
.91778 .44118 L
.91888 .46078 L
.91898 .48039 L
.91806 .5 L
.91613 .51961 L
.91317 .53922 L
.91176 .54682 L
Mistroke
.90917 .55882 L
.90409 .57843 L
.8979 .59804 L
.89216 .61363 L
.89055 .61765 L
.88196 .63725 L
.87255 .65596 L
.87206 .65686 L
.86074 .67647 L
.85294 .68863 L
.84784 .69608 L
.83333 .71552 L
.8332 .71569 L
.81656 .73529 L
.81373 .7384 L
.79758 .7549 L
.79412 .75821 L
.77576 .77451 L
.77451 .77555 L
.7549 .79082 L
.75032 .79412 L
.73529 .8043 L
.71995 .81373 L
.71569 .81619 L
.69608 .82665 L
.68203 .83333 L
.67647 .8358 L
.65686 .84374 L
.63725 .85053 L
.62944 .85294 L
.61765 .85624 L
.59804 .86091 L
.57843 .86457 L
.55882 .86725 L
.53922 .86897 L
.51961 .86974 L
.5 .86955 L
.48039 .86841 L
.46078 .8663 L
.44118 .8632 L
.42157 .85909 L
.40196 .85392 L
.39863 .85294 L
.38235 .84766 L
.36275 .84023 L
.3469 .83333 L
.34314 .83157 L
.32353 .82157 L
.30984 .81373 L
.30392 .8101 L
Mistroke
.28431 .79699 L
.28034 .79412 L
.26471 .78203 L
.25576 .77451 L
.2451 .76491 L
.23479 .7549 L
.22549 .7452 L
.21665 .73529 L
.20588 .72222 L
.20085 .71569 L
.18705 .69608 L
.18627 .69489 L
.17499 .67647 L
.16667 .66117 L
.16449 .65686 L
.15541 .63725 L
.14764 .61765 L
.14706 .61605 L
.14109 .59804 L
.13571 .57843 L
.13143 .55882 L
.12823 .53922 L
.12745 .53399 L
.12606 .51961 L
.12492 .5 L
.12478 .48039 L
.12565 .46078 L
.12745 .44159 L
.12752 .44118 L
.13042 .42157 L
.13436 .40196 L
.13937 .38235 L
.14549 .36275 L
.14706 .35824 L
.15278 .34314 L
.16129 .32353 L
.16667 .31246 L
.17112 .30392 L
.18237 .28431 L
.18627 .27806 L
.19519 .26471 L
.20588 .25007 L
.20975 .2451 L
.22549 .22641 L
.22632 .22549 L
.2451 .20601 L
.24523 .20588 L
.26471 .1882 L
.26699 .18627 L
.28431 .17255 L
Mistroke
.29237 .16667 L
.30392 .15874 L
.32269 .14706 L
.32353 .14657 L
.34314 .13586 L
.36059 .12745 L
.36275 .12648 L
.38235 .11834 L
.40196 .11135 L
.41318 .10784 L
.42157 .10546 L
Mfstroke
.44118 .04577 m
.46078 .04238 L
.48039 .03983 L
.5 .03814 L
.51961 .03727 L
.53922 .03724 L
.55882 .03804 L
.57843 .03968 L
.59804 .04217 L
.61765 .04553 L
.63405 .04902 L
.63725 .04978 L
.65686 .05495 L
.67647 .06108 L
.69608 .06821 L
.69715 .06863 L
.71569 .0764 L
.73529 .08571 L
.74022 .08824 L
.7549 .09624 L
.77412 .10784 L
.77451 .10809 L
.79412 .1214 L
.80233 .12745 L
.81373 .13635 L
.82648 .14706 L
.83333 .15317 L
.8475 .16667 L
.85294 .17218 L
.866 .18627 L
.87255 .19384 L
.88236 .20588 L
.89216 .21884 L
.89689 .22549 L
.9098 .2451 L
.91176 .24831 L
.92124 .26471 L
.93135 .28431 L
.93137 .28437 L
.94023 .30392 L
.94795 .32353 L
.95098 .33207 L
.95459 .34314 L
.9602 .36275 L
.96482 .38235 L
.96848 .40196 L
.97059 .4163 L
.97121 .42157 L
.97302 .44118 L
.97394 .46078 L
Mistroke
.97397 .48039 L
.97311 .5 L
.97136 .51961 L
.97059 .52635 L
.96872 .53922 L
.96516 .55882 L
.96068 .57843 L
.95523 .59804 L
.95098 .61136 L
.9488 .61765 L
.94134 .63725 L
.93279 .65686 L
.93137 .65989 L
.9231 .67647 L
.91218 .69608 L
.91176 .69677 L
.89993 .71569 L
.89216 .72707 L
.88622 .73529 L
.87255 .75288 L
.87089 .7549 L
.85373 .77451 L
.85294 .77536 L
.83445 .79412 L
.83333 .79518 L
.81373 .81281 L
.81265 .81373 L
.79412 .82857 L
.78774 .83333 L
.77451 .84268 L
.75878 .85294 L
.7549 .85534 L
.73529 .86666 L
.72415 .87255 L
.71569 .87677 L
.69608 .88574 L
.6804 .89216 L
.67647 .89366 L
.65686 .90057 L
.63725 .90651 L
.61765 .91154 L
.61668 .91176 L
.59804 .91567 L
.57843 .91893 L
.55882 .92133 L
.53922 .92289 L
.51961 .92361 L
.5 .92349 L
.48039 .92253 L
.46078 .92073 L
Mistroke
.44118 .91807 L
.42157 .91453 L
.40887 .91176 L
.40196 .91008 L
.38235 .90471 L
.36275 .89835 L
.34608 .89216 L
.34314 .89098 L
.32353 .88253 L
.30392 .87292 L
.30321 .87255 L
.28431 .86207 L
.26946 .85294 L
.26471 .84985 L
.2451 .83612 L
.24137 .83333 L
.22549 .8207 L
.21733 .81373 L
.20588 .80333 L
.19639 .79412 L
.18627 .78366 L
.17796 .77451 L
.16667 .76118 L
.16166 .7549 L
.14717 .73529 L
.14706 .73513 L
.13431 .71569 L
.12745 .70421 L
.12289 .69608 L
.11279 .67647 L
.10784 .66586 L
.10392 .65686 L
.0962 .63725 L
.08955 .61765 L
.08824 .61339 L
.08393 .59804 L
.07929 .57843 L
.0756 .55882 L
.07284 .53922 L
.07098 .51961 L
.07001 .5 L
.06994 .48039 L
.07074 .46078 L
.07243 .44118 L
.07501 .42157 L
.0785 .40196 L
.08292 .38235 L
.08824 .36291 L
.08828 .36275 L
.09464 .34314 L
Mistroke
.10202 .32353 L
.10784 .30977 L
.11049 .30392 L
.1201 .28431 L
.12745 .27077 L
.13094 .26471 L
.14311 .2451 L
.14706 .23918 L
.15674 .22549 L
.16667 .21247 L
.17198 .20588 L
.18627 .18932 L
.18906 .18627 L
.20588 .16898 L
.20827 .16667 L
.22549 .15092 L
.23 .14706 L
.2451 .13482 L
.25485 .12745 L
.26471 .12041 L
.28376 .10784 L
.28431 .1075 L
.30392 .09594 L
.31836 .08824 L
.32353 .08563 L
.34314 .07647 L
.36212 .06863 L
.36275 .06839 L
.38235 .06132 L
.40196 .05522 L
.42157 .05005 L
.42589 .04902 L
.44118 .04577 L
Mfstroke
.9902 .29013 m
.98778 .28431 L
.97898 .26471 L
.97059 .24793 L
.96909 .2451 L
.95802 .22549 L
.95098 .21405 L
.94567 .20588 L
.93194 .18627 L
.93137 .18551 L
.91666 .16667 L
.91176 .16081 L
.89964 .14706 L
.89216 .13908 L
.88062 .12745 L
.87255 .11976 L
.85926 .10784 L
.85294 .10247 L
.83505 .08824 L
.83333 .08694 L
.81373 .07295 L
.80724 .06863 L
.79412 .06034 L
.77458 .04902 L
.77451 .04898 L
.7549 .03878 L
.73529 .02965 L
.73475 .02941 L
.71569 .02153 L
.69608 .01436 L
.68214 .0098 L
s
.9902 .65167 m
.98809 .65686 L
.9795 .67647 L
.97059 .69471 L
.96988 .69608 L
.95917 .71569 L
.95098 .72942 L
.94729 .73529 L
.93414 .7549 L
.93137 .75879 L
.9196 .77451 L
.91176 .78432 L
.90353 .79412 L
.89216 .80687 L
.88572 .81373 L
.87255 .82701 L
.86592 .83333 L
.85294 .84511 L
.84379 .85294 L
.83333 .86146 L
.81882 .87255 L
.81373 .87626 L
.79412 .88968 L
.79027 .89216 L
.77451 .90183 L
.7569 .91176 L
.7549 .91283 L
.73529 .92276 L
.71638 .93137 L
.71569 .93167 L
.69608 .93963 L
.67647 .94669 L
.66317 .95098 L
.65686 .95287 L
.63725 .95822 L
.61765 .96275 L
.59804 .96649 L
.57843 .96945 L
.56945 .97059 L
.55882 .97165 L
.53922 .97309 L
.51961 .97378 L
.5 .97371 L
.48039 .97289 L
.46078 .97132 L
.45373 .97059 L
.44118 .96897 L
.42157 .96584 L
.40196 .96192 L
.38235 .95717 L
Mistroke
.36275 .95157 L
.36083 .95098 L
.34314 .94509 L
.32353 .93769 L
.30851 .93137 L
.30392 .92932 L
.28431 .91993 L
.26889 .91176 L
.26471 .90943 L
.2451 .89775 L
.2364 .89216 L
.22549 .88477 L
.20873 .87255 L
.20588 .87036 L
.18627 .85435 L
.18464 .85294 L
.16667 .83652 L
.16338 .83333 L
.14706 .81657 L
.14445 .81373 L
.1275 .79412 L
.12745 .79406 L
.11228 .77451 L
.10784 .76838 L
.09859 .7549 L
.08824 .73855 L
.08628 .73529 L
.07524 .71569 L
.06863 .70282 L
.06536 .69608 L
.05657 .67647 L
.04902 .65744 L
.0488 .65686 L
.04201 .63725 L
.03615 .61765 L
.03118 .59804 L
.02941 .59013 L
.02708 .57843 L
.02381 .55882 L
.02137 .53922 L
.01974 .51961 L
.01891 .5 L
.01887 .48039 L
.01963 .46078 L
.02118 .44118 L
.02353 .42157 L
.02669 .40196 L
.02941 .38808 L
.03067 .38235 L
.0355 .36275 L
Mistroke
.0412 .34314 L
.04779 .32353 L
.04902 .32013 L
.05531 .30392 L
.06381 .28431 L
.06863 .27412 L
.07333 .26471 L
.08395 .2451 L
.08824 .23774 L
.09575 .22549 L
.10784 .20726 L
.10881 .20588 L
.12326 .18627 L
.12745 .18093 L
.13924 .16667 L
.14706 .15777 L
.15697 .14706 L
.16667 .13715 L
.17668 .12745 L
.18627 .11865 L
.19874 .10784 L
.20588 .10197 L
.22365 .08824 L
.22549 .08688 L
.2451 .07322 L
.25215 .06863 L
.26471 .06085 L
.28431 .04966 L
.2855 .04902 L
.30392 .03956 L
.32353 .03049 L
.32601 .02941 L
.34314 .02238 L
.36275 .01519 L
.3793 .0098 L
Mfstroke
.9902 .75714 m
.97881 .77451 L
.97059 .78623 L
.96479 .79412 L
.95098 .81183 L
.94944 .81373 L
.93259 .83333 L
.93137 .83469 L
.91409 .85294 L
.91176 .85527 L
.89367 .87255 L
.89216 .87393 L
.87255 .89091 L
.87104 .89216 L
.85294 .90641 L
.84574 .91176 L
.83333 .92058 L
.81713 .93137 L
.81373 .93354 L
.79412 .94538 L
.78417 .95098 L
.77451 .95618 L
.7549 .96601 L
.74507 .97059 L
.73529 .97492 L
.71569 .98296 L
.69608 .99017 L
.696 .9902 L
s
.0098 .69089 m
.01197 .69608 L
.02074 .71569 L
.02941 .73319 L
.03051 .73529 L
.04132 .7549 L
.04902 .76776 L
.05326 .77451 L
.06643 .79412 L
.06863 .79722 L
.08093 .81373 L
.08824 .82293 L
.0969 .83333 L
.10784 .84572 L
.11454 .85294 L
.12745 .86612 L
.13408 .87255 L
.14706 .88451 L
.15584 .89216 L
.16667 .90115 L
.18025 .91176 L
.18627 .91625 L
.20588 .92998 L
.20797 .93137 L
.22549 .94247 L
.24003 .95098 L
.2451 .95381 L
.26471 .96408 L
.27823 .97059 L
.28431 .97337 L
.30392 .98171 L
.32353 .98918 L
.32638 .9902 L
s
.9902 .18471 m
.97799 .16667 L
.97059 .15646 L
.96343 .14706 L
.95098 .13168 L
.94738 .12745 L
.93137 .10966 L
.92966 .10784 L
.91176 .0899 L
.91002 .08824 L
.89216 .07206 L
.88815 .06863 L
.87255 .0559 L
.8636 .04902 L
.85294 .04121 L
.83572 .02941 L
.83333 .02786 L
.81373 .01571 L
.80347 .0098 L
s
.0098 .28797 m
.0113 .28431 L
.01987 .26471 L
.02938 .2451 L
.02941 .24503 L
.03988 .22549 L
.04902 .20983 L
.05144 .20588 L
.06413 .18627 L
.06863 .17974 L
.07805 .16667 L
.08824 .15338 L
.09331 .14706 L
.10784 .12994 L
.11006 .12745 L
.12745 .10889 L
.12848 .10784 L
.14706 .08985 L
.14881 .08824 L
.16667 .07254 L
.17137 .06863 L
.18627 .05677 L
.1966 .04902 L
.20588 .04237 L
.22517 .02941 L
.22549 .0292 L
.2451 .01718 L
.25809 .0098 L
s
.9902 .83668 m
.9767 .85294 L
.97059 .85995 L
.9591 .87255 L
.95098 .88105 L
.93988 .89216 L
.93137 .90029 L
.91881 .91176 L
.91176 .91792 L
.89559 .93137 L
.89216 .93411 L
.87255 .94901 L
.86982 .95098 L
.85294 .96272 L
.84092 .97059 L
.83333 .97535 L
.81373 .98697 L
.80797 .9902 L
s
.0098 .79368 m
.01008 .79412 L
.02287 .81373 L
.02941 .82312 L
.03685 .83333 L
.04902 .84908 L
.05214 .85294 L
.06863 .87228 L
.06887 .87255 L
.08721 .89216 L
.08824 .89319 L
.1074 .91176 L
.10784 .91217 L
.12745 .92946 L
.12973 .93137 L
.14706 .94527 L
.1546 .95098 L
.16667 .95973 L
.18261 .97059 L
.18627 .97298 L
.20588 .98511 L
.21465 .9902 L
s
.9902 .10522 m
.97554 .08824 L
.97059 .08279 L
.9571 .06863 L
.95098 .06252 L
.93679 .04902 L
.93137 .0441 L
.91433 .02941 L
.91176 .0273 L
.89216 .01193 L
.88931 .0098 L
s
.0098 .18519 m
.02158 .16667 L
.02941 .15512 L
.03512 .14706 L
.04902 .12853 L
.04986 .12745 L
.06592 .10784 L
.06863 .1047 L
.08343 .08824 L
.08824 .08314 L
.10256 .06863 L
.10784 .06351 L
.12354 .04902 L
.12745 .04557 L
.14668 .02941 L
.14706 .02911 L
.16667 .01398 L
.17238 .0098 L
s
.9902 .90512 m
.98381 .91176 L
.97059 .92496 L
.96388 .93137 L
.95098 .94322 L
.94214 .95098 L
.93137 .96007 L
.91832 .97059 L
.91176 .97566 L
.89216 .9901 L
.89202 .9902 L
s
.0098 .87342 m
.02516 .89216 L
.02941 .89708 L
.04262 .91176 L
.04902 .91854 L
.06167 .93137 L
.06863 .93812 L
.08251 .95098 L
.08824 .95606 L
.10544 .97059 L
.10784 .97253 L
.12745 .9877 L
.13083 .9902 L
s
.9902 .03683 m
.98274 .02941 L
.97059 .01783 L
.96177 .0098 L
s
.0098 .10547 m
.02351 .08824 L
.02941 .08118 L
.04033 .06863 L
.04902 .05909 L
.05857 .04902 L
.06863 .03887 L
.07841 .02941 L
.08824 .0203 L
.10006 .0098 L
s
.9902 .96741 m
.98674 .97059 L
.97059 .9849 L
.96436 .9902 L
s
.0098 .94282 m
.01754 .95098 L
.02941 .96298 L
.03726 .97059 L
.04902 .98154 L
.05874 .9902 L
s
.0098 .03609 m
.01593 .02941 L
.02941 .0153 L
.03487 .0098 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool2o`0000[ooooo0_l0000>ooooo`8000004oooool2000003Gooooo1?l0
000Aooooo`;o00003Oooool2o`0000_ooooo0_l00007ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooo`<0000000?o000001TI6@0I6AT0200I6AT00ol00000<c<c03<c
<`0903<c<`03o`00001<C4`0C4a<00/0C4a<0`00000B06IVIP<00000>`1oOgl2o`000140IVIV0_l0
000=oda<C003o`00000c<c<0<c<c00X0<c<c00?o000001TI6@0I6AT01?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool200000003o`00000I6AT06ATI00P06ATI00?o
000003<c<`0c<c<02@0c<c<00ol00000C4a<04a<C00;04a<C0030000001VIVH0IVIV0100IVIV0`00
001007moO`?o0000401VIVH2o`0000coC4a<00?o000003<c<`0c<c<02P0c<c<00ol000006ATIoooo
o`03ooooo`0300000?oooooooooo0<oooooo0009ooooo`0600000?ooooooooooooooo`00003o0000
2P0I6AT00ol00000<c<c03<c<`0803<c<`;o0000301<C4`2000000l0IVIV00@00000o`0000000000
0000AP1oOgl2o`000100IVIV0_l0000;oda<C0;o00002`0c<c<00ol0003oooooooooo`02ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0500000?ooooooooooooooool000002P0I6AT00ol00000
<c<c03<c<`0803<c<`03o`00001<C4`0C4a<00X0C4a<0P00000@06IVIP030000001oOgl0Ogmo0200
Ogmo2000000R07moO`;o0000401VIVH00ol0003oC4a<oda<C00:oda<C003o`00000c<c<0<c<c00T0
<c<c00Go0000oooooooooooooooo0000003Aooooo`002Oooool01000003oooooooooooooool:01TI
6@03o`00000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`02P1<C4`00`000000IVIV06IVIP0>06IV
IP8000006@1oOgl:000000P0VIVI2`00000I07moO`;o00003`1VIVH00ol0003oC4a<oda<C00:oda<
C003o`00000c<c<0<c<c00P0<c<c1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003o
ooooooooooooool901TI6@03o`00000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`02`1<C4`00`00
0000IVIV06IVIP0<06IVIP800000601oOgl3000001d0VIVI0`00000H07moO`03o`00001VIVH0IVIV
00d0IVIV00?o0000oda<C?m<C4`02_m<C4`00ol00000<c<c03<c<`0703<c<`Cooooo00<00000oooo
ooooool0coooool000Wooooo00@00000oooooooooooooooo200I6AT00ol00000<c<c03<c<`0803<c
<`;o00002`1<C4`2000000d0IVIV0P00000F07moO`@000008`2IVIT01?l00000000000000000000E
07moO`;o00003P1VIVH00ol0003oC4a<oda<C00:oda<C003o`00000c<c<0<c<c00H0<c<c1?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool701TI6@03o`00000c<c<0
<c<c00P0<c<c00?o000004a<C01<C4`02@1<C4`2000000h0IVIV00<0000007moO`1oOgl04`1oOgl3
000002/0VIVI0`00000D07moO`;o00003@1VIVH2o`0000_oC4a<00?o000003<c<`0c<c<01@0c<c<4
ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`H06ATI00?o0000
03<c<`0c<c<0200c<c<00ol00000C4a<04a<C00904a<C0030000001VIVH0IVIV00`0IVIV0P00000B
07moO`@00000<@2IVIT400000180Ogmo0_l0000=06IVIP03o`000?m<C4coC4a<00WoC4a<00?o0000
03<c<`0c<c<0100c<c<4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooo
ooooo`D06ATI00?o000003<c<`0c<c<0200c<c<00ol00000C4a<04a<C00904a<C0030000001VIVH0
IVIV00/0IVIV0P00000A07moO`<00000>@2IVIT300000140Ogmo00?o000006IVIP1VIVH02`1VIVH0
0ol0003oC4a<oda<C009oda<C003o`00000c<c<0<c<c00<0<c<c1?ooool00`00003oooooooooo`3?
ooooo`002Oooool01000003oooooooooooooool401TI6@03o`00000c<c<0<c<c00T0<c<c00?o0000
04a<C01<C4`0201<C4`00ol00000IVIV06IVIP0:06IVIP800000401oOgl3000003l0VIVI0`00000?
07moO`;o0000301VIVH00ol0003oC4a<oda<C009oda<C003o`00000c<c<0<c<c0080<c<c1?ooool0
0`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool301TI6@03o`00000c<c<0
<c<c00T0<c<c00?o000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0:06IVIP030000001oOgl0
Ogmo00h0Ogmo0P00001509VIV@030000001oOgl0Ogmo00h0Ogmo0_l0000;06IVIP03o`000?m<C4co
C4a<00WoC4a<00Co000003<c<`0c<c<0<c<c1?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003oooooooooooooool301TI6@03o`00000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`0201<
C4`00`000000IVIV06IVIP0:06IVIP030000001oOgl0Ogmo00h0Ogmo00<0000009VIV@2IVIT0AP2I
VIT00ol00000Ogmo07moO`0?07moO`03o`00001VIVH0IVIV00T0IVIV00?o0000oda<C?m<C4`02Om<
C4`00ol00000<c<c03<c<`04ooooo`0300000?oooooooooo08_ooooo0_l00012ooooo`002Oooool0
1000003oooooooooooooool201TI6@03o`00000c<c<0<c<c00L0<c<c0_l0000:04a<C0030000001V
IVH0IVIV00T0IVIV00<00000o`00001oOgl03P1oOgl00`00003o000009VIV@0M09VIV@l000007@2I
VIT3000000h0Ogmo0_l0000;06IVIP;o00002_m<C4`00ol00000<c<cooooo`03ooooo`0300000?oo
oooooooo08Sooooo0ol000000ooooooo0000ooooo`11ooooo`002Oooool01000003ooooooooooooo
ool201TI6@03o`00000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`02@1<C4`00`000000IVIV06IV
IP0906IVIP030000001oOgl0Ogmo00d0Ogmo0P00000I09VIV@L000003`2c/k<7000001T0VIVI0P00
000>07moO`03o`00001VIVH0IVIV00X0IVIV00?o0000oda<C?m<C4`01om<C4`00ol00000<c<coooo
o`03ooooo`0300000?oooooooooo08Kooooo0_l00004ooooo`;o0000@Oooool000Wooooo00H00000
oooooooooooooooo01TI6Ol0000803<c<`03o`00001<C4`0C4a<00T0C4a<00<0000006IVIP1VIVH0
2@1VIVH00`000000Ogmo07moO`0<07moO`800000602IVIT3000001d0/k>c0`00000H09VIV@030000
001oOgl0Ogmo00`0Ogmo00?o000006IVIP1VIVH02P1VIVH00ol0003oC4a<oda<C007oda<C003o`00
0?oooooooooo00;ooooo00<00000ooooooooool0Poooool3o`0000Kooooo00?o0000ooooool00000
@?ooool000Wooooo00D00000ooooooooooooooooo`00000903<c<`03o`00001<C4`0C4a<00L0C4a<
00?o00000000001VIVH02P1VIVH00ol00000Ogmo07moO`0;07moO`8000005@2IVIT5000002<0/k>c
00@00000o`000000000000005@2IVIT2000000d0Ogmo00?o000006IVIP1VIVH02P1VIVH00ol0003o
C4a<oda<C007oda<C005o`000?ooooooooooooooo`000000P_ooool3o`0000Wooooo00?o0000oooo
ool00000@?ooool000Wooooo00@00000oooooooooooooooo2@0c<c<00ol00000C4a<04a<C00704a<
C0030000001VIVH0IVIV00X0IVIV00<0000007moO`1oOgl02`1oOgl00`000000VIVI09VIV@0C09VI
V@800000;02c/k<3000001@0VIVI0P00000<07moO`03o`00001VIVH0IVIV00X0IVIV00?o0000oda<
C?m<C4`01_m<C4`4ooooo`0300000?oooooooooo07kooooo0_l0000<ooooo`04o`000?oooooooooo
o`0003oooooo0009ooooo`0400000?ooooooooooooooo`P0<c<c00?o000004a<C01<C4`01`1<C4`0
0`000000IVIV06IVIP0906IVIP800000301oOgl200000180VIVI1000000a0;>c/`@000004P2IVIT0
0ol00000Ogmo07moO`0:07moO`;o00002`1VIVH00ol0003oC4a<oda<C005oda<C0Cooooo00<00000
ooooooooool0Noooool3o`0000kooooo00Go0000ooooooooooooooooo`00000nooooo`002Oooool0
1000003oooooooooooooool703<c<`03o`00001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH02@1V
IVH00`000000Ogmo07moO`0;07moO`030000002IVIT0VIVI00l0VIVI0`00000i0;>c/`8000004@2I
VIT00`000000Ogmo07moO`0;07moO`03o`00001VIVH0IVIV00T0IVIV00?o0000oda<C?m<C4`01?m<
C4`4ooooo`0300000?oooooooooo07Wooooo0_l0000@ooooo`03okfYaOl0003ooooo00;ooooo00?o
0000ooooooooool0??ooool000Wooooo00@00000oooooooooooooooo1`0c<c<00ol00000C4a<04a<
C00704a<C003o`00001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl02`1oOgl00`000000VIVI09VI
V@0?09VIV@030000002c/k<0/k>c03`0/k>c0P00000@09VIV@030000001oOgl0Ogmo00X0Ogmo00?o
000006IVIP1VIVH02@1VIVH00ol0003oC4a<oda<C004oda<C0Cooooo00<00000ooooooooool0M_oo
ool3o`00017ooooo0_nmZLD00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03_ooooo0009
ooooo`0400000?ooooooooooooooo`H0<c<c00?o000004a<C01<C4`01`1<C4`00`000000IVIV06IV
IP0806IVIP030000001oOgl0Ogmo00/0Ogmo00<0000009VIV@2IVIT03P2IVIT200000440/k>c0P00
000?09VIV@030000001oOgl0Ogmo00X0Ogmo00?o000006IVIP1VIVH02@1VIVH00ol0003oC4a<oda<
C003oda<C0Cooooo00<00000ooooooooool0M?ooool2o`0001?ooooo0onmZLD00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03_ooooo0009ooooo`0400000?ooooooooooooooo`D0<c<c00?o
000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0906IVIP030000001oOgl0Ogmo00X0Ogmo00<0
000009VIV@2IVIT03@2IVIT2000004D0/k>c00<0000009VIV@2IVIT03@2IVIT00`000000Ogmo07mo
O`0:07moO`03o`00001VIVH0IVIV00T0IVIV00?o0000oda<C?m<C4`00_m<C4`4ooooo`0300000?oo
oooooooo077ooooo0ol0000Dooooo`;o_:S50_nmZLD00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03[ooooo0009ooooo`0400000?ooooooooooooooo`@0<c<c00?o000004a<C01<C4`01`1<
C4`00`000000IVIV06IVIP0906IVIP030000001oOgl0Ogmo00X0Ogmo00<0000009VIV@2IVIT0302I
VIT2000004P0/k>c0P00000>09VIV@8000002`1oOgl00ol00000IVIV06IVIP0906IVIP04o`000?m<
C4coC4a<oda<C0Cooooo00<00000ooooooooool0K_ooool3o`0001Gooooo00?o^jO5okbXaOnlZ<D0
0_nlZ<D00onmZLGo0000okjYa@05ooooo`03o`000?oooooooooo03Wooooo0009ooooo`0400000?oo
ooooooooooooo`<0<c<c00?o000004a<C01<C4`0201<C4`00ol00000IVIV06IVIP0806IVIP030000
001oOgl0Ogmo00T0Ogmo00<00000o`00002IVIT03@2IVIT00`000000/k>c0;>c/`0J0;>c/aD00000
6`2c/k<2000000h0VIVI00<0000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP0806IVIP04o`00
0?m<C4coC4a<oda<C0Cooooo00<00000ooooooooool0K?ooool2o`0001Oooooo0onkYlD2okbXa@05
okfYaOnnZLGo_ZW5o`000?nnZLD01?ooool00ol0003oooooooooo`0iooooo`002Oooool01000003o
ooooooooooooool303<c<`03o`00001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH0201VIVH00`00
0000Ogmo07moO`0907moO`030000002IVIT0VIVI00`0VIVI0P00000I0;>c/`@000005@3<c<`40000
01T0/k>c00?o000009VIV@2IVIT0302IVIT00`000000Ogmo07moO`0907moO`03o`00001VIVH0IVIV
00P0IVIV00?o0000oda<C?m<C4`01?ooool00`00003oooooooooo`1Yooooo`?o00005oooool00onk
Y/Go^jO5ok^Wa@02ok^Wa@07okbXaOnmZLGo_JW5okfYaOnnZLGo0000okn[aP05ooooo`03o`000?oo
oooooooo03Sooooo0009ooooo`0400000?ooooooooooooooo`80<c<c00?o000004a<C01<C4`01`1<
C4`00`000000IVIV06IVIP0806IVIP03o`00001oOgl0Ogmo00T0Ogmo00<0000009VIV@2IVIT02`2I
VIT2000001H0/k>c1@00000M0<c<c0<0000000?o00000;>c/`2c/k<0502c/k<00`000000VIVI09VI
V@0<09VIV@03o`00001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH0201VIVH00ol0003oC4a<oooo
o`03ooooo`0300000?oooooooooo06Oooooo0_l0000Iooooo`;o^jK51?nkYlD4okfYa@04okjYaOl0
003o_j_6okn[aPGooooo00?o0000ooooooooool0=oooool000Wooooo00@00000oooooooooooooooo
0P0c<c<00ol00000C4a<04a<C00704a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl0
2@1oOgl00ol00000VIVI09VIV@0;09VIV@030000002c/k<0/k>c01@0/k>c0P0000000ol00000c<c<
0<c<c00S0<c<c0<00000502c/k<00`000000VIVI09VIV@0<09VIV@030000001oOgl0Ogmo00P0Ogmo
00?o000006IVIP1VIVH0201VIVH00ol0003oC4a<ooooo`03ooooo`0300000?oooooooooo06Cooooo
0ol0000Jooooo`Co^jK50_nkYlD00onlZ<Go_JW5okfYa@02okfYa@04okn[a_l0003o_j_6okn[aPGo
oooo00?o0000ooooooooool0=oooool000Wooooo00H00000oooooooooooooooo03<c<ol0000904a<
C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl02@1oOgl00`000000VIVI09VIV@0;09VI
V@030000002c/k<0/k>c0180/k>c0`00000[0<c<c08000004`2c/k<00`000000VIVI09VIV@0;09VI
V@030000001oOgl0Ogmo00T0Ogmo00?o000006IVIP1VIVH0201VIVH00ol0003oooooooooo`02oooo
o`0300000?oooooooooo06;ooooo0_l0000Looooo`;o^ZK50onkY/D01?nkYlGo_:S5okbXaOnlZ<D2
okfYa@;o_Z[600?o0000okn[a_no[<H01_ooool00ol0003oooooooooo`0fooooo`002Oooool01P00
003oooooooooooooool0<c<co`0000P0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07mo
O`0907moO`030000002IVIT0VIVI00/0VIVI00<000000;>c/`2c/k<0402c/k<300000300c<c<0P00
000B0;>c/`030000002IVIT0VIVI00/0VIVI00<0000007moO`1oOgl02@1oOgl00ol00000IVIV06IV
IP0706IVIP03o`000?oooooooooo00;ooooo00<00000ooooooooool0Goooool3o`0001cooooo00Co
^JG5okZVaOnjY/Go^ZK50onkY/D4okbXa@05okfYaOnnZ/Ko_Z[6okjZa_l000000ono[<H6ooooo`03
o`000?oooooooooo03Gooooo0009ooooo`0500000?ooooooooooooooool00000201<C4`00ol00000
IVIV06IVIP0806IVIP03o`00001oOgl0Ogmo00P0Ogmo00<0000009VIV@2IVIT02P2IVIT200000140
/k>c0P00000e0<c<c0<00000402c/k<2000000`0VIVI00?o000007moO`1oOgl02@1oOgl00ol00000
IVIV06IVIP0706IVIP05o`000?ooooooooooooooo`000000Goooool2o`0001kooooo0_niYLD4okZV
a@03ok^VaOnkYlGo^jO500?o_:S51?nnZ/H01?l0003o_jc6okn/a_no[<H6ooooo`03o`000?oooooo
oooo03Gooooo0009ooooo`0400000?ooooooooooooooo`T0C4a<00<0000006IVIP1VIVH01`1VIVH0
0`000000Ogmo07moO`0807moO`030000002IVIT0VIVI00X0VIVI00<000000;>c/`2c/k<03`2c/k<2
000003X0c<c<0P00000@0;>c/`030000002IVIT0VIVI00X0VIVI00<0000007moO`1oOgl0201oOgl0
0ol00000IVIV06IVIP0706IVIPCooooo00<00000ooooooooool0F_ooool3o`0001oooooo1?niYLD2
okZVa@03okZWaOnkYlGo^jO500;o^jO500?o_:S5okfYa_nmZLH00onnZ/H01?l0003o_jc6okn/a_no
[<H7ooooo`03o`000?oooooooooo03Cooooo0009ooooo`0400000?ooooooooooooooo`P0C4a<00<0
000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0807moO`030000002IVIT0VIVI00X0VIVI00<0
00000;>c/`2c/k<03`2c/k<00`000000c<c<0<c<c00l0<c<c0030000002c/k<0/k>c00h0/k>c00<0
000009VIV@2IVIT02P2IVIT00`000000Ogmo07moO`0807moO`03o`00001VIVH0IVIV00H0IVIV1?oo
ool00`00003oooooooooo`1Gooooo`?o00008Oooool2okRTa@?o^JG500Co^ZK5okZWaOnjYlGo^ZO5
0_nkYlD00onlZ<Ko_JW6okfYaP02okfYaP05okjZa_noZlKo0000okn[a_no[<H00_o0[LH7ooooo`03
o`000?oooooooooo03?ooooo0009ooooo`0400000?ooooooooooooooo`L0C4a<00<0000006IVIP1V
IVH01`1VIVH00`000000Ogmo07moO`0807moO`030000002IVIT0VIVI00X0VIVI00<000000;>c/`2c
/k<03@2c/k<00`00003o0000000000100<c<c003o`00002c/k<0/k>c00h0/k>c00?o000009VIV@2I
VIT02P2IVIT00`000000Ogmo07moO`0807moO`03o`00001VIVH0IVIV00D0IVIV1?ooool00`00003o
ooooooooo`1Eooooo`;o00008_ooool01?ngXlGo^:C5okRTaOnhY<D3okVUa@Co^ZO500Co^jO5okbX
a_nlZ<Ko_:S60_nmZLH01OnnZ/Ko_j_6okn[a_l0003o_jc600Co`:g61_ooool00ol0003ooooooooo
o`0cooooo`002Oooool01000003oooooooooooooool704a<C003o`00001VIVH0IVIV00L0IVIV00?o
000007moO`1oOgl0201oOgl00`000000VIVI09VIV@0:09VIV@030000002c/k<0/k>c00`0/k>c00<0
00000<c<c03<c<`0@P3<c<`2000000l0/k>c00<0000009VIV@2IVIT02@2IVIT00`000000Ogmo07mo
O`0807moO`03o`00001VIVH0IVIV00D0IVIV1?ooool00`00003oooooooooo`1Booooo`?o00008ooo
ool2okNSa@Co^:C500?o^JG5okVVaOniY/D00onjYlD4okbXaP06okfYa_nnZ/Ko_Z[6okjZa_noZlKo
00000_no[<H2ol2]aP03ol6^aooooooooooo00Gooooo00?o0000ooooooooool0<_ooool000Wooooo
00@00000oooooooooooooooo1`1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00L0
Ogmo00<0000009VIV@2IVIT02P2IVIT00`000000/k>c0;>c/`0<0;>c/`030000003<c<`0c<c<04D0
c<c<00<000000;>c/`2c/k<0302c/k<00`000000VIVI09VIV@0:09VIV@030000001oOgl0Ogmo00P0
Ogmo00?o000006IVIP1VIVH0101VIVH4ooooo`0300000?oooooooooo053ooooo0_l0000Tooooo`03
okJSaOngXlGo]j?500;o]j?50_nhY<D00onhYLGo^JK5okVVa@02okVVa@03okZWaOnkZ<Ko^jS600?o
_:S61?nnZ/H01Ono[<Ko0000okn/a_no[<Ko`:g600?o`Jk71_ooool00ol0003oooooooooo`0boooo
o`002Oooool01000003oooooooooooooool604a<C0030000001VIVH0IVIV00L0IVIV00<0000007mo
O`1oOgl0201oOgl00`000000VIVI09VIV@0909VIV@030000002c/k<0/k>c00`0/k>c00<000000<c<
c03<c<`0703<c<`?000001`0c<c<00?o00000;>c/`2c/k<0302c/k<00`000000VIVI09VIV@0:09VI
V@03o`00001oOgl0Ogmo00P0Ogmo00?o000006IVIP1VIVH00`1VIVH4ooooo`0300000?oooooooooo
04gooooo0ol0000Uooooo`?o]Z?50ongXlD01?nhY<Go^:G5okRUaOnhYLD2okVVa@03okZWa_nkZ<Ko
^jS600;o^jS600?o_:S6okfYa_nmZLH00_nnZ/H2okn[aP03o`000?no[<Ko`:g700Co`Jk71oooool0
0ol0003oooooooooo`0aooooo`002Oooool01000003oooooooooooooool504a<C0030000001VIVH0
IVIV00L0IVIV00<0000007moO`1oOgl0201oOgl00`000000VIVI09VIV@0909VIV@030000002c/k<0
/k>c00`0/k>c00<000000<c<c03<c<`05P3<c<`4000000;o000000<000000>KViP3Vi^H03@3Vi^H0
1?l00000000000000000000I0<c<c08000003@2c/k<2000000/0VIVI00<0000007moO`1oOgl0201o
Ogl00ol00000IVIV06IVIP0206IVIPCooooo00<00000ooooooooool0Boooool2o`0002Oooooo1?nf
XlD2okNSa@03okNTa_nhYLGo^:G500;o^:G500Co^JK5okZWa_njYlKo^ZO60_nkZ<H01OnlZLKo_JW6
okfYa_nmZLKo_Z[600?o_j_600Co0000ol2]aoo0[LOo`:g70_o1[/L00oo2[lOoooooooooo`06oooo
o`03o`000?oooooooooo033ooooo0009ooooo`0400000?ooooooooooooooo`D0C4a<00<0000006IV
IP1VIVH01`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00T0VIVI00<000000;>c
/`2c/k<02`2c/k<00`00003o00000<c<c00E0<c<c0<000006P3Vi^H3000001P0c<c<00<000000;>c
/`2c/k<0302c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00P0Ogmo00?o000006IV
IP1VIVH00P1VIVH4ooooo`0300000?oooooooooo04Sooooo0ol0000Xooooo`;o]:;60onfXlD4okNT
aP;o^:G500?o^JK6okZWa_njYlH00_njYlH01?nkZ<Ko_:W6okbYa_nlZLH2okfYaPCo_j_600Go0000
ol2]aoo0[LOo`:g7ol6^a`03ol:_a`Oooooo00?o0000ooooooooool0<?ooool000Wooooo00@00000
oooooooooooooooo101<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00L0Ogmo00<0
000009VIV@2IVIT02@2IVIT00`000000/k>c0;>c/`0;0;>c/`030000003<c<`0c<c<01D0c<c<00<0
00000>KViP3Vi^H07P3Vi^H3000001H0c<c<00?o00000;>c/`2c/k<02`2c/k<00`000000VIVI09VI
V@0909VIV@030000001oOgl0Ogmo00P0Ogmo00Co000006IVIP1VIVH0IVIV1?ooool00`00003ooooo
ooooo`15ooooo`?o0000:Oooool00oncXLKo]:;6okBRaP02okBRaP03okJSaOnfY<Ko]ZC600?o]jC6
00Co^:G5okVVa_niY/Ko^JK60_njYlH00onkZ<Ko_:W6okbYaP02okbYaP03okfYa_nnZlKo_Z_600?o
_j_600Co0000ol2]aoo0[LOo`:g71?o2[lL8ooooo`03o`000?oooooooooo02oooooo0009ooooo`04
00000?ooooooooooooooo`<0C4a<00<0000006IVIP1VIVH01`1VIVH00ol00000Ogmo07moO`0707mo
O`03o`00002IVIT0VIVI00T0VIVI00<000000;>c/`2c/k<02`2c/k<00`000000c<c<0<c<c00B0<c<
c0@00000903Vi^H3000001@0c<c<00<000000;>c/`2c/k<02`2c/k<00`000000VIVI09VIV@0909VI
V@03o`00001oOgl0Ogmo00P0Ogmo00?o000006IVIP1VIVH01?ooool00`00003oooooooooo`13oooo
o`;o0000:oooool3ok>QaP;o]:;600Co]J?6okJTa_nfY<Ko]ZC60ongY<H4okVVaP04okZWa_nkZ<Ko
^jS6ok^XaP;o_:W600?o_J[6okj[a_nnZlH00_nnZlH01OnoZlKo_jc7o`000?no[<Oo`:g700;o`Jk7
0oo2[lL9ooooo`03o`000?oooooooooo02kooooo0009ooooo`0400000?ooooooooooooooo`<0C4a<
00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0VIVI
00?o00000;>c/`2c/k<02`2c/k<00ol00000c<c<0<c<c00A0<c<c0800000:`3Vi^H00`000000c<c<
0<c<c00A0<c<c0030000002c/k<0/k>c00/0/k>c00<0000009VIV@2IVIT02@2IVIT00`000000Ogmo
07moO`0807moO`03o`00001VIVH0IVIV00Cooooo00<00000ooooooooool0@?ooool3o`0002_ooooo
00?o/Z36ok>Qa_ncXLH00_ncXLH01?ndX/Ko]J?6okFSa_neXlH3okJTaP03okNTa_nhYLKo^:G600?o
^JK61?nkZ<H01?nlZLKo_J[6okfZa_nmZ/H2okj[aP05okj/aono[<Oo_jc7o`000?o0[/L01?o1[/L0
0oo2[lOo`k38ol>`b008ooooo`03o`000?oooooooooo02kooooo0009ooooo`0400000?oooooooooo
ooooo`80C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0
VIVI00T0VIVI00<000000;>c/`2c/k<02`2c/k<00`000000c<c<0<c<c00@0<c<c0030000003Vi^H0
i^KV02`0i^KV0P00000B0<c<c0030000002c/k<0/k>c00/0/k>c00<0000009VIV@2IVIT0202IVIT0
0`000000Ogmo07moO`0807moO`03o`00001VIVH0IVIV00Cooooo00<00000ooooooooool0?_ooool2
o`0002cooooo00Co/Io6ok:Pa_nbX<Ko/Z360oncXLH4okFSaP;o]ZC600?o]jC6okRUa_nhYLH00_nh
YLH00oniY/Ko^ZO6okZWaP03ok^XaPCo_J[600Ko_Z_6okj/aonn[<Oo_Zc7okn/aol00002ol2^a`;o
`Jk700Co`[38ol>`b?o3/<So`k382Oooool00ol0003oooooooooo`0]ooooo`002Oooool01000003o
ooooooooooooool204a<C0030000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01`1oOgl00`00
0000VIVI09VIV@0809VIV@030000002c/k<0/k>c00/0/k>c00<000000<c<c03<c<`0403<c<`00`00
0000i^KV0>KViP0_0>KViP030000003<c<`0c<c<0100c<c<00?o00000;>c/`2c/k<02`2c/k<00ol0
0000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00P0Ogmo00?o000006IVI_ooool00oooool00`00
003oooooooooo`0kooooo`?o0000;Oooool3ok6OaP?o/Z3600?o/j76okBRa_ndX/H00oneXlH4okNT
aP;o^:G600?o^JK6okZWa_njYlH00_njYlH00onkZ<Ko_:W7okbYa`03okfZaPCo_Zc700Go`:k7o`00
0?o0[/Oo`:k7ol6^a`03ol:`b0;o`k3800?oa;;8ooooooooool01oooool00ol0003oooooooooo`0/
ooooo`002Oooool01P00003oooooooooooooool0C4a<000000T0IVIV00<0000007moO`1oOgl01`1o
Ogl00`000000VIVI09VIV@0809VIV@030000002c/k<0/k>c00/0/k>c00<000000<c<c03<c<`03`3<
c<`00`00003o00000>KViP0b0>KViP03o`0000000000c<c<0100c<c<00<000000;>c/`2c/k<02`2c
/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00?o000006IVI_ooool00ooo
ool00`00003oooooooooo`0iooooo`;o0000;_ooool00on_W/Ko/Io6ok6OaP02ok6OaP;o/Z3600?o
/Z76okBRa_ndX/H00_ndX/H00oneXlKo]ZC6okJTaP03okNTaP04okRUa_niY/Ko^JK6okVVaP;o^ZO6
00?o^jS7okbYaonlZLL00_nlZLL00onmZ/Ko_J_7okf[a`03okj/a`04okn]aol0003o`:k7ol6_b0Co
`[3800Co`k38olBbb?o4//Soa;;82?ooool00ol0003oooooooooo`0/ooooo`002Oooool01P00003o
ooooooooooooool0C4a<000000P0IVIV00?o000007moO`1oOgl01`1oOgl00ol00000VIVI09VIV@09
09VIV@030000002c/k<0/k>c00X0/k>c00?o00000<c<c03<c<`03`3<c<`00`000000i^KV0>KViP0e
0>KViP030000003<c<`0c<c<00l0c<c<00<000000;>c/`2c/k<02P2c/k<00`000000VIVI09VIV@08
09VIV@030000001oOgl0Ogmo00L0Ogmo00?o000006IVI_ooool00oooool00`00003oooooooooo`0f
ooooo`?o0000;_ooool4ojnNaP;o/Io600?o/J37ok:Qa_nbXLH00_nbXLH2okBRaP04okBSaonfY<Ko
]ZC6okJTaP?o]jC61?niY/H01?njYlKo^jS7ok^XaonkZ<L2okbYa`03okbZaonmZlOo_J_700;o_J_7
00Co_Zc7okn]aono[LOo00000oo1[lP2ol:`b005ol>ab?o4//Soa;;8olBbb?o5/lT02Oooool00ol0
003oooooooooo`0[ooooo`002Oooool01@00003oooooooooooooool0000000T0IVIV00<0000007mo
O`1oOgl01`1oOgl00`000000VIVI09VIV@0809VIV@030000002c/k<0/k>c00X0/k>c00<000000<c<
c03<c<`03P3<c<`2000003T0i^KV00<000000<c<c03<c<`03`3<c<`00`000000/k>c0;>c/`0:0;>c
/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl01`1oOgl00ol0003oooooooooo`02oooo
o`0300000?oooooooooo03?ooooo0ol0000`ooooo`;o[Yk70on_W/H00onaWlKo/J37ok6Pa`04ok:Q
aP04okBRa_ndXlOo]:?7okBSa`?o]ZC600?o]jC6okRVaonhY/L00_niY/H00onjYlOo^jS7ok^Xa`02
ok^Xa`04okbYaonlZ/Oo_:[7okbZa`;o_J_700Go_Zc7okn]aono[LOo_jg7o`000003ol6_b005ol:`
b?o3/LSo`k78ol>ab?o4//P00oo5/lT8ooooo`03o`000?oooooooooo02_ooooo0009ooooo`050000
0?ooooooooooooooo`000000201VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0
VIVI00?o00000;>c/`2c/k<02P2c/k<00`000000c<c<0<c<c00>0<c<c0030000003Vi^H0i^KV03X0
i^KV00?o00000000003<c<`03`3<c<`00`000000/k>c0;>c/`0:0;>c/`03o`00002IVIT0VIVI00P0
VIVI00<0000007moO`1oOgl01`1oOgl01Ol0003oooooooooooooool0000003?ooooo0_l0000aoooo
o`04ojfMaon^W/Oo[Yk7ojjNa`?o[ik61?naX<L2ok:QaP03ok>RaondXlOo]:?700;o]:?70_nfY<H0
1OnfYLOo^:K7okRVaonhY/Oo^JK600?o^ZO70_nkZ<L00onkZLOo_:[7okbZa`02okbZa`05okf[aonn
[<Oo_Zc7okj/aono[LL00_o0[/P01?l0003o`Jo8ol6_b?o2/<P3ol>ab0CoaK?92Oooool00ol0003o
ooooooooo`0Zooooo`002Oooool01@00003ooooooooooooooooo000000P0IVIV00<0000007moO`1o
Ogl01`1oOgl00`000000VIVI09VIV@0809VIV@030000002c/k<0/k>c00X0/k>c00<000000<c<c03<
c<`03P3<c<`00`000000i^KV0>KViP0l0>KViP030000003<c<`0c<c<00d0c<c<00<000000;>c/`2c
/k<02P2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00L0Ogmo00Go0000oooooooo
oooooooo0000000`ooooo`?o0000<Oooool4ojfMa`?o[Yk700?o[ik6ok2Oaon`WlL00onaX<L01?nb
XLKo/j;7ok>RaoncX/L2okBSa`03okFTaonfYLOo]ZG700;o]ZG70_nhY/L4okZWa`04ok^XaonkZLOo
^jW7ok^Ya`;o_:[700Go_Jc8okj/aonn[<Oo_Zc7okn^b003ol2^b003o`000?o1[lSo`[3800;o`[38
00?o`k78olBbbOo4//T00_o5/lT00oo6]<Woooooooooo`08ooooo`03o`000?oooooooooo02Wooooo
0009ooooo`0400000?ooooooooooooooo`T0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI
09VIV@0809VIV@030000002c/k<0/k>c00X0/k>c00<000000<c<c03<c<`03@3<c<`200000400i^KV
00<000000<c<c03<c<`03@3<c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00P0VIVI
00<0000007moO`1oOgl01`1oOgl4ooooo`0300000?oooooooooo02cooooo0_l0000cooooo`;oZic7
0on]WLL2ojjNa`03ojnNaon`WlOo/9o700;o/9o700?o/J37ok:QaoncX/L00oncX/L01?ndXlOo]JC7
okFTaoneY<L3okJUa`03okRVaonhYlOo^:O700?o^ZO71?nkZLL01OnlZ/Oo_Jc8okf/b?nm[<So_Zc7
00?o_jk80_o0[/P00ol0003o`[38ol:`b002ol:`b0?oa;;900CoaK?9olJdbOo6]<Woa[C92Oooool0
0ol0003oooooooooo`0Yooooo`002Oooool01000003oooooooooooooool806IVIP030000001oOgl0
Ogmo00L0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0
c<c<00d0c<c<00<000000>KViP3Vi^H0@@3Vi^H00ol00000c<c<0<c<c00<0<c<c0030000002c/k<0
/k>c00X0/k>c00<0000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0607moO`Cooooo00<00000
ooooooooool0:Oooool3o`0003?ooooo00CoZY_7oj^Laon[W<OoZic70on]WLL4ojnNa`;o/9o700Co
/J37ok:QaonbXLOo/Z770oncX/L4okFTa`;o]ZG700?o]jK7okRWaonhYlL00_nhYlL00onjYlOo^ZW7
okZYa`03ok^Ya`04okb[b?nm[<So_Jc8okf/b0Co_jk800Co`:k8ol6`b?l0003o`K380_o2/<P2ol>b
b@;oa;;900CoaKC9olJdbOo6]<Woa[C92_ooool00ol0003oooooooooo`0Xooooo`002Oooool01000
003oooooooooooooool806IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0202IVIT0
0`000000/k>c0;>c/`0:0;>c/`03o`00003<c<`0c<c<00`0c<c<00<000000>KViP3Vi^H0@P3Vi^H0
0`000000c<c<0<c<c00=0<c<c003o`00002c/k<0/k>c00X0/k>c00<0000009VIV@2IVIT01`2IVIT0
0`000000Ogmo07moO`0607moO`Cooooo00<00000ooooooooool09oooool2o`0003?ooooo00?oZ9[8
ojZKaonZVlL00_nZVlL3oj^La`03ojfMaon]W/Oo[Ik700?o[ik700Co/9o7ok6PaonaX<Oo/J370onb
XLL00oncX/Oo]:?7okBSa`03okFTa`Co]jK70_nhYlL00oniZ<So^ZW7okZYa`02okZYa`05ok^Yaonl
ZlSo_:_8okb[b?nm[<P00_nn[LP3okn^b0;o`K3800?o0000ol6`b?o2/<P00oo3//T01Oo4//WoaKC9
olFdbOo5]<Woa[C900;oakK:2_ooool00ol0003oooooooooo`0Wooooo`002Oooool01000003ooooo
ooooooooool806IVIP030000001oOgl0Ogmo00H0Ogmo00?o000009VIV@2IVIT01`2IVIT00ol00000
/k>c0;>c/`0:0;>c/`030000003<c<`0c<c<00`0c<c<00?o00000>KViP3Vi^H07P3Vi^H8000001h0
i^KV00<000000<c<c03<c<`03@3<c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00L0
VIVI00<0000007moO`1oOgl01P1oOgl4ooooo`0300000?oooooooooo02Cooooo0ol0000cooooo`04
ojNIb?nXV/SoZ9[8ojRJb0?oZY_70_n[W<L00on/WLSo[Ik7ojfNa`02ojfNa`03ojnNaon_WlSo/J37
00?o/J370_nbXLL00oncX/So]:?7okBSa`02okBSa`03okFTaonfYLSo]ZG800?o]jK700Co^:O7okVX
b?niZ<So^JS80_njZLL01OnkZ/So_:_8okb[b?nlZlSo_Jc800Co_Zg800Ko_jk8ol2_bOo0[lWo`K38
o`000?o2/LT3ol>bb@03olBcb_o5]<WoaKC900;oaKC90oo7]/X:ooooo`03o`000?oooooooooo02Oo
oooo0009ooooo`0400000?ooooooooooooooo`L0IVIV00<0000007moO`1oOgl01`1oOgl00`000000
VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`0303<c<`00`000000
i^KV0>KViP0I0>KViPH00000203oool4000001/0i^KV00<000000<c<c03<c<`0303<c<`00`000000
/k>c0;>c/`0:0;>c/`030000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl01@1oOgl4ooooo`03
00000?oooooooooo02;ooooo0_l0000dooooo`CoYiW80onXV/P00onZVlOoZYc8ojbMb003ojbMb0;o
[Ik700Co[Yo8ojnOb?n_WlSo[io80onaX<L4ok>Rb0;o]:?700?o]:C8okJUb?nfYLP00_nfYLP00ong
Y/Oo^:O8okRWb003okVXb005okZYaonkZ/So^j[8ok^Zb?nlZlP00onm[<P2okj]b006okn^bOo0[lWo
`:o9ol2_bOo1/<So00000_o2/LT01?o3//Woa;?:olBcb_o4/lX2olFdb@;oa[K:0_o7]/X00oo8^<_o
ooooooooo`08ooooo`03o`000?oooooooooo02Kooooo0009ooooo`0400000?ooooooooooooooo`H0
IVIV00?o00000000001oOgl01`1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0
/k>c00<000000<c<c03<c<`0303<c<`00`000000i^KV0>KViP0G0>KViP<000004P3oool4000001P0
i^KV00<000000<c<c03<c<`0303<c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00P0
VIVI00<0000007moO`1oOgl0101oOgl4ooooo`0300000?oooooooooo01oooooo0ol0000eooooo`;o
YIW80onWVLP2ojRJb004ojVKb?nZW<SoZYc8ojZLb0?o[9g800Co[Ik7ojjOb?n^WlSo[Yo80on_WlP0
0onaX<Oo/J;8ok6Rb003ok>Rb004okBSaondY<So]:C8okBTb0;o]ZG800?o]jK8okRWb?nhYlP00_nh
YlP00oniZ<So^ZW8okZYb003ok^Zb0Co_Jc800Co_Zg8okn^bOno[/Wo_jk90_o0[lT01?o1/<Wo0000
ol:abOo2/LT4olBcbP05olFdbOo6]/[oa[K:olJfb_o7]/X00oo8^</:ooooo`03o`000?oooooooooo
02Gooooo0009ooooo`0400000?ooooooooooooooo`H0IVIV00<0000007moO`1oOgl01`1oOgl00`00
0000VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0/k>c00?o00000<c<c03<c<`0303<c<`00`00
0000i^KV0>KViP0E0>KViP8000006@3oool2000001H0i^KV00<000000<c<c03<c<`0303<c<`00`00
0000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0101oOgl4oooo
o`0300000?oooooooooo01cooooo0ol0000fooooo`04oj>HbOnUVLSoYIW8ojFIb0?oYiW81?nYVlP3
ojZLb003ojbMb?n/W/So[Yo800?o[Yo80_n_WlP00on`XLSo/J;8ok6Rb002ok6Rb003ok>Rb?ncXlSo
]:C800?o]:C800Co]ZG8okNVb?ngY/So]jK80_nhYlP00oniZ<Wo^ZW8okZYb002okZYb003ok^Zb?nl
ZlWo_:_900;o_Jc800?o_Zg9okn^bOno[/T00_no[/T01Oo0[lWo`K39ol6`bOl0003o`[7900;o`k;:
0oo4/lX3olJfbP05olNgboo8^<_ob;S;olRhboo9^L/02_ooool00ol0003oooooooooo`0Uooooo`00
2Oooool01000003oooooooooooooool606IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2I
VIT01`2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3V
i^H0503Vi^H2000001d0oooo00<000000>KViP3Vi^H0503Vi^H00`000000c<c<0<c<c00<0<c<c003
0000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0407moO`Co
oooo00<00000ooooooooool06_ooool2o`0003Kooooo00?oXYO9oj>HbOnSV<T00_nSV<T3ojFIb003
ojNIb?nWV/WoYi[900?oZI_80_nZW<P01?n[WLWo[9k8ojbNb?n/W/P3ojjOb0Co/:780_naX/P01?nb
XlSo/j?8ok>Sb?ncXlP3okBTb0Co]jK800Co^:O8okVXbOniZ<Wo^JS90_njZLP01OnkZlWo_:_9okb[
bOnlZlWo_Jc800?o_Zg90_no[/T01Oo0/<[o`K39ol6`bOo1/<Wo000000Co`k;:00Coa;?:olFeb_o5
]L[oa[K:0oo7]l/01?o8^<_obKW;olViboo9^L/:ooooo`03o`000?oooooooooo02Cooooo0009oooo
o`0400000?ooooooooooooooo`D0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@07
09VIV@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`0303<c<`00`000000i^KV0>KViP0C
0>KViP030000003oool0oooo01h0oooo00?o00000>KViP3Vi^H0503Vi^H00`000000c<c<0<c<c00;
0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`04
07moO`Cooooo00<00000ooooooooool05oooool3o`0003?ooooo00CoWYG:oj2Fb_nPU/[oX9K:0onR
UlT3oj>Hb@;oYIW800CoYIW9ojNJbOnWV/WoYi[90onYVlP4oj^Mb@?o[9k800?o[Yo8ojjPb?n`XLP0
0on`XLP01?naX/So/Z?8ok:Sb?nbXlP3ok>Sb003okBTb?neYLWo]JG900;o]jK800?o^:O9okVXbOni
Z<T00_niZ<T01?njZLSo^j_9ok^[bOnkZlT2okb[b@Co_Zg900Go_jk9ol2`b_o0/<[o`;3:ol6`b@02
o`000004ol:bb_o3//[o`k;:olBdb`?oaKG:00Coa[O;olNgboo7]l_oakO;0oo9^L/00oo:^lcooooo
ooooo`09ooooo`03o`000?oooooooooo02?ooooo0009ooooo`0400000?ooooooooooooooo`D0IVIV
00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0/k>c
00<000000<c<c03<c<`02`3<c<`00`000000i^KV0>KViP0B0>KViP8000008P3oool2000001D0i^KV
00?o00000<c<c03<c<`02`3<c<`00ol00000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00L0VIVI
00<0000007moO`1oOgl00`1oOgl4ooooo`0300000?oooooooooo01Kooooo0_l0000cooooo`04oibD
bonNUL[oWYG:oijEbP?oX9K:0onRUlT00onSV<WoY9S9ojFIb@03ojFIb@?oYi[900?oZI_8ojVLbOn[
WLT00on[WLT2ojbNb004ojfObOn^X<So[Z38ojjPb0;o/:7800?o/:;9ok:Sb?nbXlP00_nbXlP2ok>S
b005okBUbOneYLWo]JG9okFUbOngY/P00onhYlT2okVXb@03okZZbOnkZlWo^j_900;o^j_900?o_:_9
okf]bOnm[LT00onn[LT2ol2`bP?o000000Co`[;:o`000?o2//[o`k;:0oo4]</01Oo5]L[oa[O;olJg
boo6]l_oakO;00;ob;W<00CobKW;olZkc?o:^lcob[_<2_ooool00ol0003oooooooooo`0Sooooo`00
2Oooool01000003oooooooooooooool506IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2I
VIT01`2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3V
i^H04@3Vi^H00`000000oooo0?ooo`0T0?ooo`030000003Vi^H0i^KV01<0i^KV00<000000<c<c03<
c<`02`3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI00<0000007moO`1o
Ogl00`1oOgl4ooooo`0300000?oooooooooo01Kooooo00?o0000ooooool00000;oooool00onKTl_o
W9C;oibDb`02oibDb`;oWYG:0onPU/X2oj:Gb@04oj:Hb_nTV<WoY9S9ojBHb@?oYIW90_nWV/T01?nW
VlWoZIc9ojVLbOnYW<T2oj^Mb@03oj^NbOn]WlWo[Io900;o[Io90_n^X<P01?n`XLSo/:;9ok2RbOn`
X/T2ok:Sb003ok:TbOndYLWo]:G900;o]:G90_neYLT4okRWb@04okVXbOnjZ/Wo^Z[9okZZb@;o^j_9
00?o_:c:okf]bOnm[LT00_nm[LT01?nn[LWo0000o`000?l00002ol2`bP04ol6aboo2//[o`[;:o`00
00?oa;C;00?oaKK;olJgboo6]l/00_o6]l/3olRic0Cob[_<2oooool00ol0003oooooooooo`0Roooo
o`002Oooool01000003oooooooooooooool406IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VI
V@2IVIT01`2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KV
iP3Vi^H04@3Vi^H00`000000oooo0?ooo`0V0?ooo`03o`00003Vi^H0i^KV0180i^KV00<000000<c<
c03<c<`02`3<c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00L0VIVI00<0000007mo
O`1oOgl00P1oOgl4ooooo`0300000?oooooooooo01Kooooo00Co0000oooooooooooo0000:_ooool0
0onGTLcoVI;;oiVBb`03oi^Cb`?oW9C;0onNULX00onPU/[oX9O:oj:HbP03oj:HbP?oY9S900?oYIW9
ojJJb_nWVlT00onWVlT2ojVLb@04oj^MbOn[W/WoZik9oj^Nb@?o[Io900?o[Z38ojnQbOn`X/T00on`
X/T01?nbXlSo/ZC9ok:TbOnbY<T3okBUb@03okFUbOnfYlWo]ZO900?o^:O91?njZ/T01OnkZlWo_:c:
okb/b_nl[<[o_Jg900?o00000ono[lX01?o0/<[o`K7;ol6aboo2//X2ol>cb`03o`000?o4]<_oaKK;
00;oaKK;0_o6]l/2olNhc0;ob;W<00?obK_<olZkc?o:^l`00_o;_Ld:ooooo`03o`000?oooooooooo
02;ooooo0009ooooo`0400000?ooooooooooooooo`@0IVIV00<0000007moO`1oOgl01`1oOgl00`00
0000VIVI09VIV@0709VIV@03o`00002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02`3<c<`00`00
0000i^KV0>KViP0A0>KViP030000003oool0oooo02P0oooo00<000000>KViP3Vi^H04P3Vi^H00`00
0000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT01`2IVIT00`00
0000Ogmo07moO`0207moO`Cooooo00<00000ooooooooool05Oooool00omZP=Oo0000ooooo`02oooo
o`03o`000?oooooooooo02;ooooo00?oTho=oiF@c?nET<`00onGTL`3oiVBb`?oVi?;00?oW9C;oifE
bonNU//00_nNU//3oj2GbP?oXYS:0_nTV<T01?nTVL[oYY[:ojJJb_nVV/X3ojNKb@03ojVLbOnZWL[o
Zik900?oZik90_n]WlT01?n]X<[o[j79ojnQbOn_XLT3ok2Rb@Co/ZC90_ndYLT00oneY/[o]ZO9okJW
b@02okJWb@03okRWbOnhZL[o^:W:00?o^Z[90_nl[<X3o`0000?o_Zk:0_no[lX01?o0/<_o`K7;ol6a
boo1/L/4ol>cb`05o`000?o5]/_oaKK;olFfboo6]l/00oo7^<`01?o8^LcobK_<olVkc?o:^l`3ol^m
c@_ooooo00?o0000ooooooooool08Oooool000Wooooo00@00000oooooooooooooooo101VIVH00`00
0000Ogmo07moO`0707moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`00
0000c<c<0<c<c00:0<c<c003o`00003Vi^H0i^KV0180i^KV00<000000?ooo`3oool0:@3oool00`00
0000i^KV0>KViP0A0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c/`2c/k<02@2c/k<00`00
0000VIVI09VIV@0709VIV@030000001oOgl0Ogmo0080Ogmo1?ooool00`00003oooooooooo`0Eoooo
o`04o`000?mZP=OoJX3Gofb1eP;oKX7E0_m`P]DMooooo`04ohn>c_nAS/goTHk=oi6>c@;oTho=0onE
T<`3oiNAc0;oVI;;0_nKTl/01?nKU<coWIG;oifEbonMUL/3oijFb`?oX9O:00?oXYS:oj:HbonTVLX0
0onTVLX2ojJJbP;oYi_900CoZ9c:ojZMb_nZWL[oZYg:0on[W/T4ojfPbP?o[j7900?o/:;9ok6Sb_na
XlX00onbY<T4okFVbP;o]ZO900?o]jS:okRYb_nhZLX00_nhZLX01?njZ/Wo0000o`000?l00002okb/
bPCo_Zk:00Go_jo:ol2`boo0/<_o`;3;ol6ab`02ol:cb`?o`k?;00Co0000olFfboo5]/_oa[S<0oo7
^<`01Oo8^/gobK_<olVkc?o9^lcob[c=00?obkg=00?oc;o>ooooooooool02Oooool00ol0003ooooo
ooooo`0Pooooo`002Oooool01000003oooooooooooooool406IVIP030000001oOgl0Ogmo00L0Ogmo
00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<00/0c<c<
00<000000>KViP3Vi^H04@3Vi^H00`000000oooo0?ooo`0[0?ooo`030000003Vi^H0i^KV0100i^KV
00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI
00<0000007moO`1oOgl00P1oOgl4ooooo`0300000?oooooooooo01Gooooo00Go0000oooooomZP=Oo
JX3Gofb1eP02ofj1e@;oL8;E00?oLX;DogB3e?mdPm@00_mfQ=<2ogR5d`;oNhGB0ommQ]85ooooo`03
ohB9d?n6R]3oQX[@00;oR8_?0on:S<l2ohb=cP?oShk>0onAS/d2oi>?c@?oUI3<0_nGTL`00onIT/_o
VI?<oi^Dc003oi^Dc0;oWIG;0onNU//2oj2GbP04oj6HbonRV<_oXYS;oj:Hb`?oY9W:00?oYY[:ojJK
bonXW<X00onXW<X3ojZMbP03oj^NbOn/Wl[o[9o:00?o[J3:0_n_XLT00on`X/[o/J?:ok6SbP02ok6S
bP03ok:TbOncYL[o/jG:00?o]JK:00Go]ZO9okNXb_ngZ<[o]jS:okRYbP03o`0000?o^Z_:00?o_:c:
okb]bonl[L/00_nn[/X01Ono/<_o`;3;ol2`boo0/<_o`K;<00Co`[?;00Co`k?;olBec?o4]Lco0000
0oo6^<`01Oo7^<cob;[=olRjcOo8^/gobK_<00?ob[c=00?obkg=olboc_o<_lh02oooool00ol0003o
ooooooooo`0Pooooo`002Oooool01000003oooooooooooooool306IVIP030000001oOgl0Ogmo00L0
Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00X0
c<c<00<000000>KViP3Vi^H04@3Vi^H00`000000oooo0?ooo`0/0?ooo`030000003Vi^H0i^KV0140
i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00L0
VIVI00@0000007moO`1oOgl0Ogmo1?ooool00`00003oooooooooo`0Eooooo`04o`000?ooooooJ7oG
ofQoe`;oJX3G0_m^PMD2og22e@03og:2e?mdPmCoM8?D00;oMXCC0_mhQM<2og^5dP;oOHKB0_moQm42
oh68d@?oQ8W@0_n6R]02ohR;c`?oRXc?0_n<SLh3ohn>cP;oTHk=0_nCSld2oiF@c003oiFAcOnGT/go
Ui;=00?oVI?<0onKU<`3oifEb`03oijFbonOUlcoXIS;00?oXIS;0_nRV</2ojBIbP04ojBJbonVVl_o
YY_;ojJKb`?oZ9c:0_nZWLX00onZW/_o[9o:ojbObP02ojbObP03ojfPb_n^XL_o/:;:00?o/:;:0_na
XlX00onbY<_o/jG:ok>UbP02ok>UbP04okFVb_nfYl_o]ZO;okNXbP?o00000oniZ//2okZ[bP05ok^]
bonl[L_o_:g;okb]bonn[/X00ono/</01?o0/<_o`K;<ol6bc?o1//`2ol:cb`06ol>dc?o4]Lcoa;G<
olBec?o5]lgo00000_o6^<`3olRjc@05olVlc_o:_<gob[c=olZlcOo;_/h00oo<_lh<ooooo`03o`00
0?oooooooooo01oooooo0009ooooo`0400000?ooooooooooooooo`<0IVIV00<0000007moO`1oOgl0
1`1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`0
2P3<c<`00`000000i^KV0>KViP0@0>KViP030000003oool0oooo02h0oooo00<000000>KViP3Vi^H0
403Vi^H00`000000c<c<0<c<c00;0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT0
1`2IVIT010000000Ogmo07moO`1oOgl4ooooo`0300000?oooooooooo01Gooooo00?o0000oooooooo
ool00_mXOmL00omZP=OoK87Fofb1eP02ofj1eP;oL8;E0_mdPm@2ogJ4d`;oN8GC0_mkQM82ogf6dP;o
OhOA0_n1R=42ohB9d0?oQX[@0_n8Rll2ohZ<c`;oS8g>0_n?S/h00on>S/ooT8o>oi2?cP02oi:@cPCo
UI7=0_nGT/d3oiVCc0;oViC<0onMU/`3oinGc0?oXIS;00?oXYS;oj>IbonTV//00onTV//3ojJKb`03
ojRLb_nXWL_oZYk;00?oZYk;0_n/WlX01?n/X<_o[Z7;ojjQbon^XL/3ok2RbPCo/ZC;0_ncYLX00ond
Y/_o]ZO;o`000002o`000003okNXb_nhZL_o^:W;00?o^J[;00Go^Z_:ok^]bonk[L_o^jg;okb]b`02
okf_b`?o_k3;1?o1//`01Oo2/l_o`kC<ol>dc?o3]<coa;G<00?oaKO=00Co0000olNicOo7^Lgob;[=
0oo9_<h01Oo:_<gobkk>ol^nc_o;_/koc;o>00;ocL7?3?ooool00ol0003oooooooooo`0Nooooo`00
2Oooool01000003oooooooooooooool306IVIP03o`00001oOgl0Ogmo00L0Ogmo00<0000009VIV@2I
VIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00X0c<c<00<000000>KViP3V
i^H0403Vi^H00`000000oooo0?ooo`0^0?ooo`030000003Vi^H0i^KV0100i^KV00<000000<c<c03<
c<`02`3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI00@0000007moO`1o
Ogl0Ogmo1?ooool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00;oJ7oG0_mZP=L2ofb1
eP;oKX7F00?oL8;Eog:3e?mbPm@00_meQ=@2ogN5d`;oNHGC0_mlQ]82ogj7dP;oPHSB0_n3RM43ohF:
d@;oQh_@0_n:S=02ohb=c`CoSXk?0_n@Slh2oi:@cP?oUI7=0_nGT/d2oiVCc004oiVDcOnKU<coViC<
oi^Dc0?oWIK<0onOUl`00onQV<_oXIS<oj>Ib`02oj>Ib`?oY9[;0_nVVl/01?nWW<_oZ9g;ojRMbonX
WL/3ojZNb`04ojbOb_n/X<_o[:3;ojbPb`?o[Z7;00?o/:;:ok2Sbon`Xl/00onbY</01?ncYL[o]:K;
o`000?l00002okJWb`03okJYbonhZL_o^:W;00;o^:W;00?o^J[;okZ/bonk[L/00_nk[L/00onl[/co
_Jo;okf_b`02okf_b`03okn`boo0/Lco`;7<00?o`K;<0oo3]<`01_o4]/goaKO=olFgcOo5]lgoa[W=
o`0000;oakW=00Cob;_>olVlc_o9_<kobKc>0oo;_/h01?o<`<oocL7?olg1coo=`Ll2olk3d0[ooooo
00?o0000ooooooooool07_ooool000Wooooo00@00000oooooooooooooooo0`1VIVH00`000000Ogmo
07moO`0607moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<
0<c<c00:0<c<c0030000003Vi^H0i^KV0100i^KV00<000000?ooo`3oool0<03oool00`000000i^KV
0>KViP0@0>KViP03o`00003<c<`0c<c<00/0c<c<00<000000;>c/`2c/k<01`2c/k<00ol00000VIVI
09VIV@0709VIV@040000001oOgl0Ogmo07moO`Cooooo00<00000ooooooooool05Oooool01Ol0003o
ooooooooooooooooIWoH00;oJ83G0_mZPML2ofj1eP;oL8;E0_mbPm@2ogF4e0;oMhGC0_miQM<2ogb6
dP;oOXOB0_n1R=82oh>9d@?oQH[A0_n7Rm02ohZ<d0;oS8g?0on>S/l2oi2?cP?oTY3>00CoUI7=oiBB
c_nGTlgoUi?=1?nIU<d3oi^Dc0;oWIK<0onOUl`3oj6Hc0?oXiW;00?oY9[;ojFKc?nWW</00onWW</3
ojRMb`03ojZNbon[Wl_o[:3;00?o[:3;0_n^XL/00on_X/_o/:?;ok2Sb`02ok2Sb`04ok:Tbol0003o
0000o`0000;o]:K;00Co]ZO;okJYbonfZL_o]ZW;0_nhZL/01OniZlco^Zc;okZ/bonj[<_o^jg;00?o
_:k<0_nm[l/00onn/Lco`;7<ol2ac002ol2ac004ol6bc?o2]<co`[C<ol>dc0?oa;K=00GoaKO=olJi
cOo6^Lgoa[W=o`000003olRkcP04olVlc_o:_/kob[k>ol^ncP?oc<3?00CocL7?olk3d?o>`m3oc/?@
2oooool00ol0003oooooooooo`0Mooooo`002Oooool01000003oooooooooooooool306IVIP030000
001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000
003<c<`0c<c<00X0c<c<00<000000>KViP3Vi^H03`3Vi^H00`000000oooo0?ooo`0b0?ooo`03o`00
003Vi^H0i^KV00l0i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`080;>c/`030000
002IVIT0VIVI00H0VIVI00@0000007moO`1oOgl0Ogmo1?ooool00`00003oooooooooo`0Dooooo`03
o`000?oooooooooo00?ooooo00?oIWoHofR0eomXP=L00_mZPML00om/PMKoKh;Fofn2eP02og63eP;o
MHCD0_mgQM<2ogV5d`;oO8KB0omnQm82oh68dP;oPhWA0_n5R]42ohN;d0?oRXc@0_n<SLl01?n>S/oo
SXo?oi2@con@T<l3oi:AcP?oU9;>0_nGTld3oiVDc@;oViC<00?oViK=oifGcOnMUld01?nOUl`2oj6H
c0;oXiW;00CoXi[<ojFKc?nUVlcoYI_<0onWW</2ojRMb`04ojVNc?n[Wl_oZio;oj^Ob`?o[:3;1?n_
X//01?n`Xl_o0000o`000?l00002ok:Vb`?o]:K;1?nfZL/01?nhZL_o^J_<okV[c?niZl`2okZ/b`Co
_:k<00Co_Jo;okjac?nn/Lco_[7<0_o0/L`01Oo1/lgo`[C<ol:dc?o2]<co`kK=00?oa;K=0oo6^Ld0
1Oo7^lkob;_>o`000?o8^lkobKg?00?ob[k>0oo<`<l01?o=`m3oc/?@olk3d?o>`m02olo5d0_ooooo
00?o0000ooooooooool07?ooool000Wooooo00@00000oooooooooooooooo0`1VIVH00`000000Ogmo
07moO`0607moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<
0<c<c00:0<c<c0030000003Vi^H0i^KV00l0i^KV00<000000?ooo`3oool0<`3oool00`000000i^KV
0>KViP0>0>KViP030000003<c<`0c<c<00/0c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI
09VIV@0609VIV@040000001oOgl0Ogmo07moO`Cooooo00<00000ooooooooool05?ooool00ol0003o
ooooooooo`03ooooo`;oHgoI0_mXP=L2ofZ1e`03ofb1e_m_P]KoKh;F00;oLH?F00?oLhCEogJ5e?mf
QM@00_mhQ]@2og^6d`?oOHOC0_n0R=82oh:9dP;oQH_A0_n7S=43ohV=d0;oS8k@0on>Sll2oi2@c`?o
TY7>0onDT/h2oiNCc@03oiVDcOnIU<koViK=00?oViK=0_nMUld3oinGc003oj6Hc?nQVLgoXi[<00?o
Xi[<0onUVl`00onWW<_oYig<ojVNc003ojVNc0?oZio;00Co[:3;ojfRc?n]X/co[j;;0ol00003ok6U
c0?o/ZK;00?o]:K;okFXc?neZ<`00_nfZL/00ongZ/co^J_<okV[c002okV[c003okZ/bonk[Lco^jg<
00?o_:k<00Go_K3=okjac?nn/Lco_[7<ol2ac003ol6cc@05ol:dc?o3]/go`kK=ol>fcOo4]/d00_o5
^<h01_o6^Lgoak_>olNkc_o7^lkob;_>o`0000;obKg?00Cob[k>ol_0coo;`<ooc<3?0oo=`m001?o>
`m3oclG@olo5d?o?aM0;ooooo`03o`000?oooooooooo01cooooo0009ooooo`0400000?oooooooooo
ooooo`<0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0
/k>c00P0/k>c00<000000<c<c03<c<`02@3<c<`00`000000i^KV0>KViP0?0>KViP030000003oool0
oooo03@0oooo00<000000>KViP3Vi^H03P3Vi^H00`000000c<c<0<c<c00;0<c<c0030000002c/k<0
/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`04ooooo`0300000?oooooo
oooo01Cooooo00?o0000ooooooooool01?ooool00omSOmWoIWoHofIof002ofR0f0;oJh7G0_m_P]H2
og63eP03og>4eOmfQMCoMXGD00;oN8KD0_mkQ]<3ogf7d`;oP8SB0_n2RM82ohF;d@;oQhcA0on9SM02
ohb>d0?oSXo?0_n@T<l2oi:AcP;oU9;>00?oU9;?oiNCc_nGTlh00onIU<h3oi^Fc@?oWIO=00?oWiO<
oinHcOnQVLd00_nQVLd3oj>Jc0;oYI_<00CoYIc=ojNMc?nWWLcoYig<0onYW/`2oj^Ob`03oj^Qc?n]
X/co000000;o000000?o[j;;ojnTc?naYL`00onaYL`2ok:Vb`05ok>Wc?neZ<co]JS<okFXc?nfZL/0
0ongZ/`2okV[c003okV]cOnk[Lco^jg<00;o^jg<00Ko_:k<okf`cOnm/<go_K3=okjac?no//d3ol6c
c@05ol:ec_o3]/go`kK=ol>fcOo4^<h00oo5^<h4olNkcP04olVmcol0003obKg?olVmc`?obl3?00Co
c<;@olg3d?o=`m3ocL?@0oo?aM02om37d@_ooooo00?o0000ooooooooool06oooool000Wooooo00@0
0000oooooooooooooooo0P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00L0VIVI
00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV00l0i^KV
00<000000?ooo`3oool0=@3oool00`000000i^KV0>KViP0>0>KViP030000003<c<`0c<c<00X0c<c<
00?o00000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0709VIV@03o`00001oOgl0Ogmo00Cooooo
00<00000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`;oHgoI0_mVOmP2ofR0f003of^1
eom]P]OoKH;G00;oKh?F0_mbQ=H2ogJ5e0;oN8KD0_mkQ]<2ogf7d`;oP8SB0_n2RM83ohF;d@;oQhcA
0_n9SM02ohb>d0;oSXo?00?oSXo@oi2@d?n@T=000_nBTLl4oiBBc`;oUi?>0onIU<h00onKU/goViK>
oifGcP02oifGcP?oWiS=0onQVLd00onSV/coXi_=ojFLc@03ojFLc@?oYig<00?oZIk<ojVPcOn[XL`0
0ol00002ojfRc004ojjScOn_Y<co[jC<ojnTc0;o/JG<00?o/ZK=ok>Wc?ncYl`00_ncYl`00oneZ<co
]ZW=okJYc@03okNZc004okV[c?ni[Lgo^Jg=okV]c@;o^jg<00Go_:o=okf`cOnm/<go_K3=okjbcP03
oknbc@05ol6ccOo2]Lko`[G>ol:ec_o3]/d00oo4^<h2olFhcP07olJjcoo7^lkoak_>olNkc_o8_Loo
bKg?o`000002olZod005ol_0coo<`]3oc<;@olc2d?o=`m000_o>aM401?o?aM3od<OAom37dOoAbM8<
ooooo`03o`000?oooooooooo01[ooooo0009ooooo`0400000?ooooooooooooooo`80IVIV00<00000
07moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c00<00000
0<c<c03<c<`02P3<c<`00ol00000i^KV0>KViP0>0>KViP030000003oool0oooo03H0oooo00<00000
0>KViP3Vi^H03P3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<00000
09VIV@2IVIT01`2IVIT00`000000Ogmo07moO`04ooooo`0300000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool2of5nf@03ofAofOmVP=WoIX3I00;oJh7G0_m]P]L2ofn3eP03og:4e_mdQMGo
M8GE00;oMhKE0_mjQm@2ogb8e0;oOhWC0_n1R]<3ohB;dP;oQXcB0_n9SM42oh^>d@CoSXo@0_n@T=02
oi:Ac`?oU9;?0_nGTlh2oiVDcP04oiVEconKU/koViK>oi^FcP?oWIO>0_nOV<d2oj6Ic@04oj6Kc_nS
VlgoXi_=oj>Kc@?oYIc=0_nWWL`01?nXWlgo0000o`000?l00003oj^Qc0Co[Z?=0_n_Y<`01?naYLco
/ZK=ok:VcOnbY/d2ok>Wc003okBXcOnfZLgo]ZW=00;o]ZW=00?o]j[<okR/cOnh[<d00oni[Ld01Onk
[Lco_:o=okb_cOnl[lgo_K3=00?o_[;>0_no//d01?o0]<ko`[G>ol:ec_o2]Lh4olBhcP05olFhc_o6
^/ooa[[?olJjcoo7^lh00_o8_Ll01?o9_Loob[o@o`000?o:_m03olc2d006olg4dOo>aM7oc/GAolk5
dOo?am;od<OA0ooAbM8;ooooo`03o`000?oooooooooo01[ooooo0009ooooo`0400000?oooooooooo
ooooo`80IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0
/k>c00P0/k>c00<000000<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0>0>KViP030000003oool0
oooo03H0oooo00<000000>KViP3Vi^H03P3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c/k<0
/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`04ooooo`0300000?oooooo
oooo01Cooooo00?o0000ooooooooool01_ooool2of5nf@04ofAofOmVP=WoJ87HofR1f0;oJh;H0_m_
PmH2og:4eP;oM8GE0_mgQ]D2ogZ7e0;oO8SD0_moRM<2oh6:d`?oQ8_B0_n6S=82ohV=d@;oRhkA0on>
Sm02oi2@d0?oTY7?00CoU9;?oiBCd?nGU<ooUiC?1?nIULl3oi^FcP;oWIO>00?oWiS=oinJc_nQVlh0
0onQVlh3oj>Kc@03ojFLcOnVW/ko000000;o000000GoZ9o=ojVPcOnYX<goZJ3=oj^Qc002ojbRc@?o
[Z?=00?o[jC<ok2UcOn`YLd00onbY/d01?ncYlco]:S=okBXcOndZ<d2okJYc@03okJ[c_nh[<go^:c=
00;o^:c=00?o^Jg=okZ^c_nl[ld00_nl[ld00onm/Lko_[;>okjbcP02okjbcP05oknbcOo0]<ko`;C>
ol2dc_o2]Lh00_o3]ll2olBhcP05olFjcoo6^/ooa[[?olJjcoo7_=000oo8_Ll2olZod004o`000?o;
`]7obl;Aolc2d0?ocLCA00?oc/GAolo7d_o?am800ooAbM82om;<d`_ooooo00?o0000ooooooooool0
6Oooool000Wooooo00@00000oooooooooooooooo0P1VIVH00`000000Ogmo07moO`0607moO`030000
002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00:0<c<c0030000
003Vi^H0i^KV00h0i^KV00<000000?ooo`3oool0>03oool00`000000i^KV0>KViP0>0>KViP030000
003<c<`0c<c<00X0c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0609VIV@030000
001oOgl0Ogmo00Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`07ooooo`;oGgkJ
00?oHGoJofJ0fOmVP=T00_mXPMP00om[P]SoKX?Gofj3e`02og24e`;oLhGF0_mfQ]H2ogZ7e0;oO8SD
0omoRM<2oh6:d`;oQ8_B0_n6S=82ohV=d@?oRhkA00CoSXo@ohf@dOn@TM7oT97A0onBT]03oiBCd0;o
UiC?0onIULl2oi^FcP03oi^HconMVLooWIW?00?oWi[>0onQVlh2oj>Kc@?o000000CoYYk>ojROcOnX
WlgoZ9o=0_nYX<d01?nZXLko[:;=ojbRcOn/X/d2ojjSc@03ojjTc_n`YLgo/:G=00;o/:G=00?o/ZK=
ok:Xc_ndZ<d00ondZ<d01?nfZLgo]Z_>okJ[c_nfZlh2okR/c@05okV^c_nj[/ko^Zk>okZ^c_nl[ld0
0onm/Lh2okjbcP05oknccoo0]<ko`;C>ol2dc_o1]/l00oo3]ll01Oo4^<koaK[?olFjcoo5^/ooa[[?
00?oakc@00Oob;g?olVod?o9_m3ob[o@ol_2dOl0003obl;A00?ocLCA1?o?am800oo@bM?odLWBom;<
d`02om;<d`_ooooo00?o0000ooooooooool06Oooool000Wooooo00@00000oooooooooooooooo0P1V
IVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<0202c
/k<00`000000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV00h0i^KV00<000000?ooo`3oool0>03o
ool00`000000i^KV0>KViP0>0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c/`2c/k<0202c
/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00Cooooo00<00000ooooooooool04ooo
ool00ol0003oooooooooo`08ooooo`;oGgkJ00CoHGoJofB0fOmVPMWoIX7I0_m[P]P2ofj3e`;oL8CG
0_mcQMH2ogJ6eP03ogR7eOmkR=GoNhSE00?oOXWD0_n1Rm@2oh><d`;oQXgC0_n8S]83oh^?dP?oSI3A
0_n@TM43oi:Bd0;oU9?@0onGU<l00onIULooVIK@oi^Hc`03oi^Hc`;oWIW?0onOV/h01?nQVlkoXYc?
o`000?l00002ojBMcP?oYYk>00?oZ9o=ojRPc_nZXLh00onZXLh00on/X/go[:?>ojjTcP03ojjTcP;o
/:G=00Co/JO>ok:Xc_nbZ<ko/ZS>0ondZ<d4okJ[cP04okR/cOni[/ko^Jk>okV^cP;o^Zk>1?nm/Lh0
1Onn//ko_k??oknccono/loo`;C>00?o`KK?0_o3]ll01?o4^M3oaK[?olFjcoo5^/l3olNld004olRn
dOo9_m3obKo@olVod0;ob/7A00Cobl;Ao`000?o=a=;ocLCA1?o?am82om39d`?od/cC0_oCc]@;oooo
o`03o`000?oooooooooo01Sooooo0009ooooo`0400000?ooooooooooooooo`80IVIV00<0000007mo
O`1oOgl01P1oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<
c03<c<`02P3<c<`00`000000i^KV0>KViP0>0>KViP030000003oool0oooo03P0oooo00<000000>KV
iP3Vi^H03P3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`04ooooo`0300000?oooooooooo01?ooooo00?o0000oooo
ooooool02?ooool2oeanf`;oHGoJ00CoI83IofJ1fOmVPMWoJH;I0_m/PmP2og24e`?oLhGF0_mfQ]H0
0omhQmGoNhSEog^8e@03ogj9e0;oPH_D0_n3S=<2ohJ=d`;oR8kB0on;Sm82ohf@d@?oT97A0_nBT]00
0onDTm3oU9CAoiNEd002oiNEd0?oVIK@0onKV<l2oifIc`;oWi[>0ol000001?nRW<ooY9g>ojBMc_nT
WLh2ojJNcP04ojJOconXX<koZ:3>ojRPcP;oZZ7>00CoZj;?ojbSc_n/Xlko[:?>0on^Y<h01?n`YLgo
/JO>ok6Wc_naYlh3ok:XcP03okBXcOneZ/ko]J[>00?o]Z_>1?ni[/h00onj[/ko^k3?ok^`c`03okfa
cP04okjccono/loo_k??okncc`Co`KK?00Go`kO?olBid?o4^M3oa;W@olFjc`02olJld005olNld?o8
_]7ob;kAolRndOo9_m000oo:`M42olg4dP04o`000?o?am;oclOBolo7dP?od<WC0_oAc=@01OoBc=?o
dlkDom?>e?oCc]Coe=7F00_ooooo00?o0000ooooooooool05oooool000Wooooo00@00000oooooooo
oooooooo0P1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c
/`2c/k<0202c/k<00`000000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV00h0i^KV00<000000?oo
o`3oool0>03oool00`000000i^KV0>KViP0>0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c
/`2c/k<0202c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00Cooooo00<00000oooo
ooooool04oooool00ol0003oooooooooo`09ooooo`03oeanfomOOm_oGgoK00;oHX3J0_mVPMT00omY
P]WoK8?Hofb3f002ofn4f0;oLXGG0_mdQ]L2ogN7e`;oNhSE0_mnRM@2oh6;e0;oPhcC0on6SM<2ohR>
dP04oh^?d_n:T=?oSI7BohfAdP?oSi;B0_nBTm43oiBDd@?oUiG@0onIU]000onKV<ooViW@oifJd003
o`0000;oWi_?0onRW<l00onTWLkoY9k?ojJOc`03ojJOc`;oZ:3>00CoZZ7>oj^Rcon[X/ooZj;?0on/
Xlh00on^Y<ko[jK?ojnVc`03ok6WcP;o/ZS>00?o/jW?okFZc_neZ/h00_neZ/h00onfZlko]jg?okN]
c`02okV^cP03okZ_conk/<oo^k3?00;o^k3?00Go_K7>okjcconn/loo_[??okncc`02ol2fd0;o`KK?
00Go`[S@olBid?o4^M3oa;W@olFkd@03olJld004olNndOo8_]7ob;kAolRnd@?ob/7A0_o<`m801?o=
a=;o0000olk6doo?am83om39d`?odLcD0_oBc]D00ooCc]Coe=7FomCAeP0;ooooo`03o`000?oooooo
oooo01Oooooo0009ooooo`0600000?ooooooooooooooo`1VIVH00000201oOgl00`000000VIVI09VI
V@0709VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02P3<c<`00`000000i^KV0>KV
iP0=0>KViP030000003oool0oooo03T0oooo00<000000>KViP3Vi^H03P3Vi^H00`000000c<c<0<c<
c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07mo
O`04ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool2oeanf`;oGgoK00?o
HX3JofB1f_mTPMX00_mWP]X2ofb3f0;oKhCH0_mbQML2ogB6e`03ogN7eomjRMKoNXWF00;oOH[F0_mo
RmD2oh:<e0?oQHgD0_n8Sm<3ohZ@d`;oSI7B0on?T]82oi:Cd@?oU9CA00?oUiG@oiNFdOnIV=400_nI
V=43o`0000?oWI[@0_nOVll2oj:Lc`04oj:Md?nTW/ooY9k?ojBNc`?oYYo?00?oZ:3>ojVRconYX/l0
0on[X/l2ojbScP03ojfUcon_Y/oo[jK?00;o[jK?00?o/JO>ok6XconcZLl00oncZLl2okFZcP04okJ/
cong[Loo]jg?okN]c`Co^Zo?0_nk/<l01Onl/]3o_[??okjcconn/loo_[G@00?o`;K@1?o2^=001Oo4
^M3oaK_AolFkdOo5^m7oa[c@00?oakkA00Cob;kAolW1d_o9`M;ob/7A0_o<`m801?o=a]Coc/KColk6
dol00002olo9e004om39dooAc=GodLcEom7<e0;od/kE00Godm7FomCAe_oDdMKoe=7FomGCe`0;oooo
o`03o`000?oooooooooo01Kooooo0009ooooo`0600000?ooooooooooooooo`1VIVH00000201oOgl0
0`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02P3<c<`0
0`000000i^KV0>KViP0=0>KViP030000003oool0oooo03T0oooo00<000000>KViP3Vi^H03P3Vi^H0
0`000000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT0
0`000000Ogmo07moO`04ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool02_ooool0
0omJO]coG7oLoeaog002of:0fP;oI87J00?oIh;JofZ3fOmZPmT00_m]Q=T2og26f0;oM8KG0_mgQmL2
ogZ9eP;oOH[F0_moRmD2oh:<e0?oQHgD0_n8Sm<3ohZ@d`;oSI7B0_n?T]800onBTm7oTYCBoiBEdP02
oiBEdP;oUiKA0ol000000onIV=7oViW@oi^Id002oifJd004oijKdOnPW=3oX9c@oj2Ld0?oXYg@0_nT
W/l2ojJOc`03ojNQd?nYX/ooZJ;?00;oZJ;?00?oZj;?oj^Td?n]YLl00on]YLl2ojnVc`04ok2Wd?na
Z<oo/JS?ok6Xc`?o/jW?1?nf[<l00ong[Loo^:o@okR_d003okZ_c`Co_;;@00Go_[??okjed?nn]M3o
_[G@ol2fd002ol6hd@?o`[S@0oo5^m401Oo6_M;oakkAolNndOo7_]7ob<3C00?obL7B00?ob/?Colc3
d_o=a]@00_o=a]@01?o>a]?oclWDo`000?o?bM@3om7<e@03om;>e_oBc]Godm7F00;odm7F00Coe=7F
omGCeooEdmOoe]KH2oooool00ol0003oooooooooo`0Eooooo`002Oooool01P00003ooooooooooooo
ool0IVIV000000P0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000
003<c<`0c<c<00X0c<c<00<000000>KViP3Vi^H03@3Vi^H00`000000oooo0?ooo`0i0?ooo`030000
003Vi^H0i^KV00h0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`080;>c/`030000
002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01?ooool00`00003oooooooooo`0Booooo`03o`00
0?oooooooooo00cooooo00CoFWkLoeaog?mLOmcoGh3K0_mRPM/2ofN2fP;oJX?I0_m]Q=T00om`Q]So
LhOHog>7f002ogJ8f0;oNHWG0_mlRmL3ogn<eP;oPXcD0_n5SM@00on8Sm?oQhoDohZAe002ohZAe0;o
SI;C0_n?Tm<3oi:DdP04oiBEd_l0003o0000o`0000;oUiKA0_nIV=400onKVM3oVi[AoijKd@03oijK
d@?oX9c@0_nRWM000onTW/ooYIo@ojFOd003ojNQd0;oZJ;?00CoZJ?@oj^Td?n[Y=3oZjC@0on]YLl0
1?n_Y/oo/:O@ok2Wd?n`Ym03ok6Xc`03ok>YcondZm3o]:_@00;o]Zc?00?o]jk@okR_d?nh[m000_nh
[m000onj[loo^k7@ok^ad003okbbd0?o_[G@00?o_kOAol6hdOo1^=400_o1^=401?o2^=3o`k[Aol>j
dOo5^m43olJmdP05olNndOo8`=?ob<3ColS0doo9`M800_o:`m<01?o<aMCocLKDolg6e?o=a]@3olo9
e003o`000?o@bmGodLcE00;od/kF0ooCdMH2omCCe`04omGCeooFe]Soe]KHomOIf@[ooooo00?o0000
ooooooooool05Oooool000Wooooo00H00000oooooooooooooooo06IVIP00000807moO`030000002I
VIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c0090<c<c0030000003V
i^H0i^KV00h0i^KV00<000000?ooo`3oool0>P3oool00`000000i^KV0>KViP0=0>KViP030000003<
c<`0c<c<00X0c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0609VIV@030000001o
Ogl0Ogmo00Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`;oEgkM0_mL
Om`01?mOP=_oHX7Kof:1fomUP]/2ofR3fP;oKHCI0_m`Q]P2og>7f0;oMXSH0_miRML2ogb;e`;oOhcF
0_n2SMH2ohB>e@?oQhoD0on:TM@2ohfBd`;oSi?C0ol00002oiBEdP;oUiKA00?oUiSBoiVId_nIVM80
0onKV]43oijKd@;oX9c@00?oX9gAoj:NdOnRW]401?nUWm000onWXM3oYj;AojVSd003ojVSd0?oZjC@
00?o[JG?ojjVd?n^Y]000on`Ym02ok6Xc`05ok:Zd?ndZm3o]:_@okB[d?nf[<l00ong[]02okR_d003
okV`dOnk/M3o^k7@00;o^k7@00Co_;;@okfddOnm]=7o_[G@0ono]m42ol6hd@05ol:jd_o3^]7o`k[A
ol>jdOo4_M<00oo6_M83olS0d`;obL?D00Gob/?Colc5e?o<aMCoc<GDolg6e002olk8e@04olo9e?o@
bmGo0000om7>e`?od/kF00Codm7Gom?Ae_oDdmOoe=?G0_oFe]T01?oFe]SoemWIomOIfOoHfmX:oooo
o`03o`000?oooooooooo01Cooooo0009ooooo`0600000?ooooooooooooooo`1VIVH00000201oOgl0
0`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02@3<c<`0
0`000000i^KV0>KViP0>0>KViP030000003oool0oooo03X0oooo00<000000>KViP3Vi^H03@3Vi^H0
0`000000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01P2IVIT0
0`000000Ogmo07moO`04ooooo`0300000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool0
0omGO]goFWoMoeYog@02oef0g0;oHX7K00?oIH;KofR3f_mXPmX00_m[QMX00om^Q][oLHOIog67f@03
ogJ8f0;oNHWG0_mlRmL2ogn<eP;oPXgF0_n4S]D3ohN?e0;oRY7D00OoSI;Co`000?l0003o0000ohnC
donBU=;oTIGD00?oU9KC0onGV=82oiVIdP?oVi[A00?oWY_AoijLd_nPWM400onPWM42oj:Nd@;oYIo@
00CoYJ7AojNRdOnWX]7oYj;A0onYXm02oj^Td003ojbVdOn^Y]3o[ZK@00;o[ZK@00?o/:O@ok2YdOnb
Z]000onbZ]000ondZm3o]JgAokF]d@03okN^d0Co^K3A0_nk/M001Onl/m7o_KCAokfddOnm]=7o_[KB
00?o_kOA1?o2^]801Oo3^]7oa;gColBmdoo4_M?oa[gB00;oakoC00Cob<3ColW3e?o9`mCob/GE0oo<
aM@02_o=b=Koc/SEolk8eOo>b=Gocl_Fom3;eOoAc]Oo0000om7>eooBc]H2om?Ae`04omCCf?oDdmOo
e]KIomKFf@;oe]WJ00CoemWIomSKf_oHfm[ofMkK2_ooool00ol0003oooooooooo`0Cooooo`002Ooo
ool01P00003oooooooooooooool0IVIV000000P0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000
/k>c0;>c/`080;>c/`030000003<c<`0c<c<00T0c<c<00<000000>KViP3Vi^H03P3Vi^H00`000000
oooo0?ooo`0j0?ooo`030000003Vi^H0i^KV00d0i^KV00<000000<c<c03<c<`02P3<c<`00`000000
/k>c0;>c/`080;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01?ooool00`00003o
ooooooooo`0Booooo`03o`000?oooooooooo00kooooo00CoE7gNoeYogOmJOmgoGH3L0_mPPM`2of>2
g0;oJ8?J0_m[QMX00om^Q][oLHOIog67f@02ogB8f@;oN8[H0_mkRmP2ogj<e`;oPHkG0_n4SmH3ohJ@
eP03ohVAeOl0003o000000;oS9?E0_n?U=@3oi6Ee0?oU9KC0_nGV=800onIVM;oVI[Coi^Kd`02oi^K
d`?oWYcB0onPWM400onRW]7oXj3BojFQd@03ojFQd@?oYj;A00?oZJ?@ojZUdOn/Y]400on/Y]42ojjV
d004ojjXdOn`ZM7o/:WAok2Yd@;o/Z[@00?o/jcAokF]dOne[M400_ne[M400ong[]3o]k3AokN`d@03
okV`d@Co_;?A00Go_KCAokjfd_nn]];o_[KBokngd@02ol6id`;o`[[B00Go`kcColBmdoo4_M?oa;gC
olJoe003olNod`03olS2e?o9`mCob/GE00;ob/GE00Goc<GDolg8e_o=b=KocLSFolk8e@02olo;eP?o
dLkG00?o0000om;@f?oCdML00_oDdmP00ooDe]Woe]KIomKIfP02omKIfP?of=_J00?ofMkKomWQg?oo
ool02?ooool00ol0003oooooooooo`0Cooooo`002Oooool01P00003oooooooooooooool0IVIV0000
00P0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<
00T0c<c<00<000000>KViP3Vi^H03P3Vi^H00`000000oooo0?ooo`0i0?ooo`030000003Vi^H0i^KV
00h0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI
00H0VIVI00<0000007moO`1oOgl01?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo
00oooooo00CoE7gNoeMog_mJP=goFX3M0_mPPM`00omSP]coIXCLofJ4g002ofV5f`;oKHKK0_maQmT2
ogB8f@;oN8[H0_mkRmP2ogj<e`;oPHkG0_n4SmH3o`0000;oRI7E0on<TmD2ohnDe0;oTIGD0_nDU]<0
0onDV=CoUiWDoiNIe003oiVJd`?oVi_C0onNW=800onPWM7oXIoCoj>PdP02oj>PdP?oYJ7A0_nWX]40
1?nXY=;oZZGAojZUdOnZYM43ojbVd@Co[ZSA0_n`ZM44ok>/d@;o]JgA00?o]ZoBokN`dOng/=400_ng
/=400oni/=7o^[;BokZbdP02okbcd@05okbfdonn]];o_[KBokjfd_no^=<00oo1^M<01Oo2^];o`kcC
ol>ldoo3_=?oa;gC00?oa[oD00CoakoColS2e?o8`]CobLCF0oo:aMD3olg8eP;oc/_G00Cocl_Fom3>
eoo@c]OodLkG0_oBd=P00ol0003odm?IomCCf002omCFf@?oe]WJ0_oGfm/01OoHfm[ofMkKomWNfooI
hMcof^?M00Wooooo00?o0000ooooooooool04_ooool000Wooooo00H00000oooooooooooooooo06IV
IP00000807moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<
0<c<c0090<c<c0030000003Vi^H0i^KV00h0i^KV00<000000?ooo`3oool0>@3oool00`000000i^KV
0>KViP0>0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI
09VIV@0609VIV@030000001oOgl0Ogmo00Cooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`0?ooooo`;oDGgO00CoEgoNoeZ0gOmJP=goGH7M0_mQPmd2ofJ4g0;oJHGK00?oKHKKog28fom`
R=/00_mcRMX2ogJ;fP;oNHcI0_mnS=L01On1S]Oo0000o`000?l0003oQ8oF00;oQY3F0_n9TMD2ohbC
e@03ohbDe_n>UMKoSYGF00;oTIKE1?nDV=@2oiNIe0?oVI[C0_nKVm<2oijLdP04oijNdonQWm?oXIoC
oj6Od`?oXj3B00?oYJ7AojFSdonXY=800onXY=83ojZUd@03ojbVdOn/Ym;o[:OB00?o[ZSA00?o/:WA
ok6[d_naZm800onc[=44okJ_dP;o]k3A00Co^;;CokZbd_nj/];o^[;B1?nl]]<01Onn]];o_kSCoknh
dono^=?o`KWC00?o`[_D00?o`kcColBneOo6_m@00_o6_m@2olO2e@05olS2e?o9a=KobLCFolW4e_o:
aMD00_o;amH01?o=b=Koc/_Golk;eoo?cMP3om3>e`05om7@fOoBd=Sodm?Io`000?oDe]X00ooDe]T2
omKIfP;oem_K0_oHg]`00ooIg]_ofN7Lom[Sg@02om[VgPSooooo00?o0000ooooooooool04_ooool0
00Wooooo00H00000oooooooooooooooo06IVIP00000807moO`030000002IVIT0VIVI00L0VIVI00<0
00000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c0090<c<c0030000003Vi^H0i^KV00h0i^KV00<0
00000?ooo`3oool0>@3oool00`000000i^KV0>KViP0>0>KViP030000003<c<`0c<c<00X0c<c<00<0
00000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00Cooooo00<0
0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03oe5mgomDO]ooE7kO00;oFX3M00Co
GH7Mof63gOmQPmgoI8CM0_mWQM`2off6f`;oL8SK0_mcRMX2ogJ;fP04ogV<fOl0003o0000o`0000;o
P8oH0_n3T=P3ohJAe`;oRI;G0on<U=H2ohjEeP;oTIKE0onDV=@2oiNIe0;oVI[C00CoVI_DoibLe?nL
W=CoW9cD0onNW]<2oj6Od`;oXj3B00CoXj;CojFSdonUXm?oYJ?C0onXY=82ojZUd@04ojZVdon/Ym;o
[:OBojbWdP;o[ZSA00?o[j[Cok6[d_naZm800_naZm800onc[=7o]:kCokB^d`03okJ_dPCo^;;C00?o
^[;Bok^edonk]M<00onl]]<3oknhd`05ol2keOo2^mCo`[_Dol:ke?o3_]D00oo4_]D01?o6_mCoal;E
olO2eOo8a=L3olW4eP06ol[7eoo;amKoblOFol_7e_o<b]Soc/_G0oo?cMP02Oo@c]OodM3Iom7@fOoB
dm[odm?IomCFf_l0003oe=KJomCFf@02omKIfP07omKLg?oGfm_of=kLomSNg?oHhMgofN7Lom[Sg@02
om[VgP03om[Yg_oooooooooo00Oooooo00?o0000ooooooooool04Oooool000Wooooo00H00000oooo
oooooooooooo06IVIP00000807moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c
/k<00`000000c<c<0<c<c0090<c<c0030000003Vi^H0i^KV00h0i^KV00<000000?ooo`3oool0>@3o
ool00`000000i^KV0>KViP0>0>KViP030000003<c<`0c<c<00X0c<c<00<000000;>c/`2c/k<0202c
/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00Cooooo00<00000ooooooooool04Ooo
ool00ol0003oooooooooo`0Aooooo`;oCWgP00?oE7kOoeN0g_mGP=h00_mKPMh2of63g@03ofB4gOmW
QMcoIhGL00;oJhOL00?oKXSLog6:fomaR]/00ol00002ogV<f@;oOHgI0_n0SmP2oh>@f0?oQY7G0_n9
T]L2ohbDeP;oSYGF0onAU]D00onDV=CoU9WFoiNJe@02oiNJe@?oVI_D0onLW=@00onNW]?oWYoEoj6P
e002oj6Pe0?oXj;C0onUXm<00onXY=;oZ:GCojZVd`03ojZVd`03ojbWd_n]ZM?o[JWC00?o[j[C0_na
Zm800onb[M?o]:kCokB^d`02okB^d`03okJ_d_nf/M?o][7C00;o^;;C00?o^KCDok^edonk]M<00_nk
]M<01?nl]]?o_KSDokfhe?no^=<3ol2ke@05ol:ke?o3_]Go`kkEol>neOo4_]D00_o5`MH01Oo7`]Go
b<CGolS4eoo8a=OobLCF00?ob/OG00?oblOFolc:f?o<b]P00oo?cMP2om3@f@03om7@fOoBdm[od]?J
00?oe=KJ00?o0000omCIfooFfMX00_oFg=`01ooGg]gof=kLomSQgOoHhMgofNCNomWVgooJi]h00_oJ
jMh00ooJjmooooooooooo`07ooooo`03o`000?oooooooooo013ooooo0009ooooo`0600000?oooooo
ooooooooo`1VIVH00000201oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c
00<000000<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0>0>KViP030000003oool0oooo03P0oooo
00<000000>KViP3Vi^H03P3Vi^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00P0/k>c
00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`04ooooo`0300000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00om>ON3oDGkPoe5nh002oeN0gP03oe^1g_mNPmkoGX?N00;oHXCN
0_mWQM`01Om[Qmco0000o`000?l0003oLH[K00;oMH_K0_mhSM/2og^>fP;oOi3J0_n2TMT3ohFBf@;o
R9CH0_n;UMP3ohjFe`;oTISF0onDVMH3oiNJe@;oVI_D0_nLW=@01?nLW]GoWYoEoijOeOnNWmD3oj6P
e003oj>RdonSXmGoYZCD00;oYZCD0onXYM<2ojZVd`03oj^Xe?n]ZM?o[JWC00;o[JWC00?o[j[Cok2/
e?n`[=@00onb[M<2okB^d`05okB`e?nf/M?o][7CokJadonh/]<00oni]=@2ok^ed`05okbgeOnm^=Co
_KSDokfhe?nn^]H00oo0^mD3ol>ne@05olC0eoo5`MKoaL7FolG1e_o6a=L00oo8a=L3ol[7e`;obl[I
00Coc<[Holg=fOo=cMWoclgH0oo@d=T3om;CfP07om?FfooDe][oe=WKomCIfol0003oeMcLomKLg002
omONg@07omSQg_oHhMgofNCNomWTg_oIi]oofNWOom[YgP02om[[g`03om[^h?oJl>7ooooo00Kooooo
00?o0000ooooooooool04?ooool000Wooooo00H00000oooooooooooooooo06IVIP00000807moO`03
0000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00:0<c<c003
0000003Vi^H0i^KV00h0i^KV00<000000?ooo`3oool0>03oool00`000000i^KV0>KViP0>0>KViP03
0000003<c<`0c<c<00T0c<c<00<000000;>c/`2c/k<0202c/k<00`000000VIVI09VIV@0709VIV@03
o`00001oOgl0Ogmo00Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`04
odimh?mAO^3oE83PoeB0h0;oF8;P0_mNPmh01OmRQ=ko0000o`000?l0003oJHON00;oK8WM0_maR]/2
ogF;f`;oN8gK0_mkS]X2ogn@fP;oPY7I0on5T]T2ohRDf0;oRiGH0on>U]L2oi6HeP;oU9WF0_nGV]D0
1?nFW=OoVIgFoiVMe_nIWMH3oibNe@;oWYoE0_nQX=@01?nQX]KoXj?Eoj>SeOnSXmD3ojJTe003ojRU
donYYmGoZJOE00?oZjSD0_n]ZM<00on^ZmGo/:cDok2/e002ok2/e003ok:]donb[mGo];3D00?o];3D
00?o][7CokNceOng/mD00oni]=@4okbge@05okfhe?nn^]Ko_[[Fokjje_o0^mD00_o1_MH01Oo3_]Go
a<3GolC0eoo4`=OoaL7F00?oa/CG00Cob<CGolW7f?o9amSob/OG0_o;b]T01?o<cM[ocLgIolg=fOo=
cMT2olk@fP04om3@fOoAdm_odM?Kom;CfP;odmKK00CodmWLomCIfooEg=co00000_oFg]h01_oGg]go
f>7NomSQg_oHi=oofNCNomWVg`;ofNWO00?ofNcPom[[gooJk^000_oJl>400ooIl^7oooooooooo`05
ooooo`03o`000?oooooooooo00oooooo0009ooooo`0600000?ooooooooooooooo`1VIVH00000201o
Ogl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02P3<
c<`00`000000i^KV0>KViP0>0>KViP030000003oool0oooo03P0oooo00<000000>KViP3Vi^H03P3V
i^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2I
VIT00`000000Ogmo07moO`04ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool04ooo
ool2odYmh@04odinhOmDP>3oE83PoeR2h0?o000000?oGhGOofF6g_mUQ]h00_mYQmh00om/RMgoL8_M
og2;g@02og><g@;oMhkL0_mkS]X2ogn@fP?oPY7I0_n5T]T2ohRDf0;oRiGH0_n>U]L00on>V=WoTIWH
oi6If003oiBJe`?oUYcG0onIWMH2oibNe@03oijOeOnNXMKoWZ7F00?oXJ;F0onSXmD00onVY=CoYZKF
ojVWe@03ojVWe@03oj^Xe?n/Z]Ko[Z_E00?o[Z_E0_n`[=@01?n`[]Ko/ZoEok:_eOnb[mD2okB`e003
okFbe_ng/mGo]k?E00;o]k?E00?o^KCDokZfe_nj]]H00_nl]mD01Onm^MKo_[[Fokjje_nn^]Ko_kcG
00?o`KgF00Co`/3HolC0eoo4`=Ooa<3G0oo6a=L01_o7a]WobLOHolW7f?o9amSob/WIol_:f@?oc<gJ
00CocLgIolk@f_o>d=[ocm?L0ooAdm/02?oAe]codmKKom?Ig?oCfMcoe=cMomGLg?oFg]ko00000_oG
h]l01_oHhMkof>COomSTgooHin3of>[QomWYg`;ofNcP00?ofNkQomWahOoJl>400_oIl^400ooHmn7o
ooooooooo`03ooooo`?o00004?ooool000Wooooo00@00000oooooooooooooooo0P1VIVH00`000000
Ogmo07moO`0607moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<02@2c/k<00`000000
c<c<0<c<c0090<c<c0030000003Vi^H0i^KV00l0i^KV00<000000?ooo`3oool0=P3oool00`000000
i^KV0>KViP0>0>KViP030000003<c<`0c<c<00X0c<c<00?o00000;>c/`2c/k<0202c/k<00`000000
VIVI09VIV@0709VIV@030000001oOgl0Ogmo00Cooooo00<00000ooooooooool04Oooool00ol0003o
ooooooooo`0Dooooo`;oBWgQ0ol000001?mEP^7oFh?Ooe^3gomOQMl2of>6g`;oIhSO0_m/RMd2og2;
g@;oLhcM0_mgS]`2ogZ?g0;oOY7K0_n1T]/2ohBCfP?oR9GJ0_n;U]T3ohjHf@;oTIWH0onDV]L2oiJL
e`;oVIgF00?oVIkHoibPeonLX=L01?nNXMH2oj6ReP;oXj?E00CoY:GFojJVe_nVY]KoYZKF0_nYYmD0
1?nYZMKo[:[FojbZe_n/Z]H3ojj[e@04ok2/e?n`[]Ko/:kFok2^eP;o/ZoE00Co/k7GokFbe_ne/]Ko
]K;F0_ng/mD01Onh]MKo^[KFokZfe_nj]]Ko^kWG00?o_KWF00Go_[[Foknleono_=Oo_kcGol6meP03
ol;0f004olC0eoo5`mSoaL?HolK4e`?oalKI00CobLOHol[9fOo:bMWoblcK0oo<cMX00oo=cm_oc]3J
oloCg002oloCg005om7CfooAe]codMKLom;IgOoCfM`00_oDg=d01?oEgmooe]kNomORgol00002omOT
h007omSTgooHin3of>[QomSZhOoHk>7ofNcPomW^h@02omWah@03omSch_oIl^7of?OQ00;oe_SQ00Co
eO[Qom?khOl0003o00000_ooool00ol0003oooooooooo`0>ooooo`002Oooool01000003ooooooooo
ooooool206IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01P2IVIT00`00003o0000
0;>c/`090;>c/`030000003<c<`0c<c<00T0c<c<00<000000>KViP3Vi^H03`3Vi^H00`000000oooo
0?ooo`0e0?ooo`030000003Vi^H0i^KV00l0i^KV00<000000<c<c03<c<`02P3<c<`00`000000/k>c
0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl01?ooool00`00003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01Cooooo0_l00002odYnhP;oDH3Q00CoEH;QoeV3hOmOQMoo
GhGO0_mSQ]l01OmWR=ooJXWOofZ9gomZRMooKX_N00;oLXgN0omgS]`2ogZ?g0;oOY7K0_n1T]/2ohBC
fP?oR9GJ0_n;U]T2ohjHf@;oTIWH0_nDV]L01?nCW=WoUYgHoiJMf?nFWMP3oiVNf0;oW:3G0_nNXMH0
0onOXmSoXJCGoj6Te`04ojBUeP03ojJVe_nWZ=OoZJWF00?oZJWF0on/Z]H00on^ZmGo[ZgGok2^eP03
ok2^eP06ok:_eOnc/MOo/k7Gok>aeone/]Ko][CG1?nh]MH01_nj]]Ko^kWGok^ieonk^MOo_KWFokjl
f0?o_kcG00Go`KoIol;0f?o2`=So`/3Hol?2f@03olG3f0?oalKI0_o8bMX01Oo:bMWoblcKol_<foo;
c=_oc<gJ00;ocLoK0oo?dm`2om3Fg@05om7Fg?oBfMgod]WMom?Lg_oDg=d00_oEgml01OoFh^3oen;O
omOTh?l0003oenOQ00;oen[R00?of>[QomS/hOoHkn800_oHlN801ooIlN7of??RomOeh_oFmn;oeOWR
omKhhOoEn^400_oCnn401Oo?oMoocOkOol[ng_oooooo0000013ooooo0009ooooo`0400000?oooooo
ooooooooo`80IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c
/k<0/k>c00P0/k>c00<000000<c<c03<c<`02@3<c<`00`000000i^KV0>KViP0?0>KViP030000003o
ool0oooo03D0oooo00<000000>KViP3Vi^H03`3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c
/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`04ooooo`0300000?oo
oooooooo013ooooo00?o0000ooooooooool04_ooool3o`0000;ooooo00Co@gcSodYnh_m>P>;oCX3R
0_mBP^801?mIPn7oGHGQoef5hOmQQn42ofN8g`?oJXWO00?oKX_Nog:=g_mbSMh00_mfS]h2ogV@g@;o
OI;M0_n0Tm`2ohBEg0?oQiKK0_n:V=/3ohfIfP;oT9[J0onCW=T3oiJMf0;oVIkH00?oW:3GoibQf?nL
XMP00onOXmP2oj6Te`;oY:GF00CoY:OHojNXeonWZ=OoYjSG0onYZMH2ojbZeP04ojb/eon^[MOo[ZgG
ojj]e`;o/:kF00Go/K3Gok>aeonc/MOo/k7GokBdf003okJde`;o^;GF00Go^KSHok^ieonk^MOo^kWG
okbkf@03okjlf005oknleoo1_mWo`KoIol6ofOo2`=P00oo3`]T01?o5`mSoa/KJolK6f_o7a]T3olS9
fP?oblcK0_o<cm`01?o=cm_oc];MolkBgOo?dm`2om3Fg@;odMWN00God]WMom?Lg_oCg=koe=oPomGO
g`02omKRh003omKUhOoGi>3o000000;oen[R00?oengRomS/hOoHkn800_oHlN801?oGm>?of??RomOe
h_oFmn82omGihP06om?jh_oAo>7odo_Qolomgoo=o]oob_kN0_o5o]`00ol0003oooooooooo`0>oooo
o`002Oooool01000003oooooooooooooool206IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00X0c<c<00<000000>KV
iP3Vi^H03P3Vi^H00`000000oooo0?ooo`0e0?ooo`030000003Vi^H0i^KV00h0i^KV00<000000<c<
c03<c<`02`3<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00P0VIVI00<0000007mo
O`1oOgl01?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo0ol00006oooo
o`05od=lhom6O^?oCX3Rodj0h_mBP^800_mFQ>82oef5h@03of67hOmTR>7oI8SQ00;oJ8[P0_m/S>02
og:=gP;oMXkN0_miT=d2ogfBg@;oP9?L0_n4UM`3ohNFf`;oRYSK0on=VMX2oi2JfP;oTicI0_nFWMP0
0onFWm[oVJ3IoiVPf@04oibQf0;oWj?H00?oXJCGoj:VfOnRY]T00onTYmP3ojNXe`03ojVYe_nZZmSo
[:cG00?o[:cG00?o[ZgGojn_f?n_[mP00ona/=L01?nc/MOo];CHokBdf?nd]=P2okJde`05okNgfOni
^=So^KSHokVhf?nk^ML00onl^mT01Onn_=So_kkIoknnfOno_]Wo`KoI00;o`L;J0_o3`]T2olC5f`05
olK6f_o7b=_oalSKolO8foo8bMX00_o9c=`00oo;c=_oc<oLolc?g002olgBgP04olkBgOo?e]kocmKN
om3Fg@;odMWN0_oBg>001OoCg=koe=oPomCOh?oDh^7oe^;P00;oe^GQ00?oe^ORomK[hol000000_oG
kN800ooGkn?oe_;SomSahP02omOdh`0?omKfhooEn>?odo[SomGih_oCn^;odOcQolomhOo=oMoobokO
olGng?o2o]_oaOkLol;nfooooooo000000oooooo0009ooooo`0400000?ooooooooooooooo`80IVIV
00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c
00<000000<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0>0>KViP030000003oool0oooo03D0oooo
00<000000>KViP3Vi^H03P3Vi^H00ol00000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c
00<0000009VIV@2IVIT01`2IVIT010000000Ogmo07moO`1oOgl4ooooo`0300000?oooooooooo013o
oooo00?o0000ooooooooool03?ooool3o`0000Wooooo0_lnO><01Om6O^?oBX3SodZ0hom>P^?oEXCR
00;oFXGR0_mNQn82ofB8h@;oJ8[P00?oK8cPog2>h?m`S^000_mdSml2ogRAg`;oNi?O0_n0Tm`3ohBE
g0;oQiKK00?oRYSKohVIg?n=Vm`00_n=Vm`2oi2Lf`?oTigK0onFWmX2oiVPf@;oW:7H00?oW:?JoinU
fOnOYMT01?nRY]T2ojBWf0;oYjSG00CoYj[IojZ[f?nZZmSoZZ_H0_n/[=L00on][]Wo[joHojn_f002
ojn_f003ok6`eonb/mWo/[?I00?o];CH00Ko][CGokNgfOng]mWo]kOIokVhf?nj^]X3okbkf@05okfn
f_no_]Wo_kkIoknnfOno`M/00oo1`]X01?o2aMcoa<GKolC5foo4aM/3olO8f`;ob<cM00CobLcLol[?
gOo:cmgoc<oL0_o=d]h01_o>eMoocmKNoloFg_o?e]kod=WOom7IgP;od]cP0_oBgn401_oDgn3oe>;Q
omCRhOoEiN;oe^GQomKWhP;oe^_S00?oe^gTo`000?oGkn<00_oFl^<01?oFm>CoeoCSomKfhooEn><2
om?jh`08ololh_o=oN7ocogQolgmgoo;o]ooaOkLol;nfonoo]X3ooooo`03o`000?oooooooooo00go
oooo0009ooooo`0400000?ooooooooooooooo`80IVIV00<0000007moO`1oOgl01P1oOgl00`000000
VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02P3<c<`00`000000
i^KV0>KViP0?0>KViP030000003oool0oooo03<0oooo00<000000>KViP3Vi^H03`3Vi^H00`000000
c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT010000000
Ogmo07moO`1oOgl4ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool02Oooool3o`00
00gooooo00?o?WcSod9ni?m2O^@00_m:P><01Om>P^?oDXCSoeZ5h_mJQN;oGXOR00;oHXWR0_mVRn82
ofb<h0;oL8kP0_mdSml2ogRAg`;oNi?O0_moU=h2oh>FgP;oQYSM0on9VM`3ohfKg0;oT9cK0onCWM/2
oiJOfP03oiVPfOnIX]_oVJ;K00?oW:?J0_nOYMT2oj:Vf@04oj:Xf_nUZM[oYJWJojFYfP?oYj[I00?o
ZZ_HojZ]f_nZ[MX00on][]T2ojn_f003ok2bf_nb/mWo/[?I00;o/[?I00?o];CHokFff_ne]]X00_ng
]mT01Onh^][o^[[JokZjf_nj^][o_;_I00?o_KkJ00Go_kkIoko1fono`M_o_l7Kol72fP03ol;5g004
olC5foo5b=coaLSLolO8f`;ob<cM00KobLoNol[?gOo:cmgob/oMol_Bgoo=d]h3olkEg`05oloFg_o@
fMood=WOom3LhOoBg>000_oBgn42om?RhP06omCRhOoEiN;oeNGRomGXhooEjnCoe^_S0_oFkN@01?l0
003oeO;UomKbhooFm>@2omCfi005om?hi?oAn^?odo[Sololh_o=oN400_o;o^000oo5o]go`_kLokkn
fP05ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooo`80IVIV00<0
000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c00<0
00000<c<c03<c<`02P3<c<`00`000000i^KV0>KViP0?0>KViP030000003oool0oooo03<0oooo00<0
00000>KViP3Vi^H03`3Vi^H00`000000c<c<0<c<c00:0<c<c0030000002c/k<0/k>c00P0/k>c00<0
000009VIV@2IVIT01`2IVIT010000000Ogmo07moO`1oOgl4ooooo`0300000?oooooooooo013ooooo
00?o0000ooooooooool01_ooool3o`00017ooooo00Co>WcTod9ni?m6P>CoAX3T0_m;P^@01?mBQ>?o
EhKToeN6i?mKR>@2of:9hP03ofJ;h_mZSN;oJXgR00?oKXoR00?oLY7QogJBhOmfT^400omkTml2ognD
gP;oPiKN0_n6V=d3ohVIg0;oSI_L00?oT9cKoi2NgOn@W]d00_nCWm`2oiJQg0CoVJ;K0_nLXmX00onO
YMWoWjKKoinVf`03oj:XfP?oYJWJ00?oYj[IojR/fonZ[MX00onZ[MX00on][]Wo[K7Kojfaf`03ok2b
fP;o/[?I00Go/kGKokFff_ne]][o]KKJokJif`03okRjfP06okZjf_nk_M_o^kgKok^mfonm_][o_/7L
0ono`M/01Oo1a=go`/GLol;5g?o2aMco`lOM00?oaLSL00?oa/_NolS<gOo9cmh00_o9cmh01?o:cmgo
bm;Ool_Bgoo<eN42olkEg`;oc]WQ00God=WOom3LhOo@g>7odMoRom;Oh@02om?RhP;odnGS01KoeNGR
omGXhooEjnCoeN_TomC^iOoFkNCoe_3TomGbiOl0003oe?GUom?giOoDm^CodoSTom7jhoo@nn?ocOcR
ol_mhOo8o^3obokPolGngOo2o]co__kJ1_ooool00ol0003oooooooooo`0=ooooo`002Oooool01000
003oooooooooooooool306IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT0
0`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00X0c<c<00<000000>KViP3Vi^H03`3Vi^H0
0`000000oooo0?ooo`0a0?ooo`030000003Vi^H0i^KV00l0i^KV00<000000<c<c03<c<`02P3<c<`0
0`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI00<0000007moO`1oOgl00P1oOgl4
ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool00oooool3o`0001Gooooo00Go>WcT
ociniOm6P>CoAX3Tod^2i002odn4i@;oEhKT00CoFhSToen:i?mOR^CoI8cT0_mZSN83ofj?hP03og:A
hOmfT^7oMY;Q00;oNYCQ0_mnU^03oh:Hg`;oQIWO0_n9Vmh2ohbLgPCoT9kM0_nCWm`2oiJQg0;oVJ;K
00?oVJCMoibUg?nLYM`01?nOY]/2oj:XfP;oYJWJ00CoYJ_KojR/fonX[=_oZ:cK0_nZ[MX00on[/=_o
[K7Kojfaf`02ojfaf`03ok2bf_n`]=_o/kGK00?o/kGK00Ko]KKJokJifonf^M_o][WKokRjf_ni_=`3
ok^mf`05okc0gOnn`Mco_/7Lokk1g?no`M/00oo1a=d01Oo2aMco`lOMol?7gOo3amgoaLSL00;oa/_N
0oo9cmh2olWBh004ol_Bgoo<eN7oc=GQolgHhP?oc]WQ00KocmcRom3LhOoAgn;odMoRom7Ri?oCh^82
om?Uh`04om?Xi?oCjnGodn_UomG[i0;oe>kU00goe?3Uom?ci_oEl^Goe?GUo`000?oAnNGoco[Tom7j
hoo@nn?ocOcRol_mhOo8o^3o`_kM00;o__kK00?o^?cHooooooooool01Oooool00ol0003ooooooooo
o`0=ooooo`002Oooool01000003oooooooooooooool306IVIP030000001oOgl0Ogmo00H0Ogmo00<0
000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00X0c<c<00<0
00000>KViP3Vi^H0403Vi^H00`000000oooo0?ooo`0_0?ooo`03o`00003Vi^H0i^KV00l0i^KV00<0
00000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00L0VIVI00<0
000007moO`1oOgl00P1oOgl4ooooo`0300000?oooooooooo00oooooo00Co0000oooooooooooooooo
0ol0000Hooooo`;o=G_U00Co?WkUod:0iOm7P^KoAh;V0_m?Q>D00omCQ^GoF8SUoeR8i@02oen:i003
ofB<i?mXS^CoJ8kT00;oK93S0_m`T^<2ogJBh@;oNYCQ0_mnU^03oh:Hg`;oQIWO0_n9Vmh2ohbLgP;o
T9kM00?oSioOoi>Qg_nCXMh00onFXmd3oiVTg@;oW:GL0_nOY]/01?nOZMgoXZ[Loj:Zg?nRZ]`3ojF[
f`03ojR/fonX[mcoZ:oL00?oZk3K0_n]/M/01?n^/mco/;CKok2dfon`]=/2ok>ef`05ok>hg?nf^M_o
][WKokJifonf^md00oni_=`01Onk_M_o_<3Mokc0gOnl`=go_/7L00?o_/?N00?o`LCMol;7g_o2amh0
0_o3amd2olC;g`04olK;g_o7c]ooalkOolW?gP?obM;P00?ob]GRolcEhOo=f>800_o=f>801Oo>fN7o
cmcRoloLh_o@gnCodMoR00;odN;T00?od^GUom?UhooCj>@00_oCjnD2om?^iP08omC^iOoDl>Godo?V
om;ei_oAmnKodoOUom7iiOl00002olglh`07ol_mh_o8oN7o`_kNokkng?nkoM_o__kKokSlf008oooo
o`03o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooo`<0IVIV00<0000007mo
O`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<
c03<c<`02P3<c<`00`000000i^KV0>KViP0A0>KViP03o`00003oool0oooo02d0oooo00<000000>KV
iP3Vi^H0403Vi^H00`000000c<c<0<c<c00;0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VI
V@2IVIT01`2IVIT00`000000Ogmo07moO`0207moO`Cooooo00<00000ooooooooool03oooool4o`00
01cooooo0_leNnD00oljONGo?X3VodN2iP02od^4iP;oD8OV00?oF8SUoeb;iOmLRnD00_mQSND2ofR>
i0;oK93S00?oL9;SogBDhomdU><00_miU^83ogfGhP;oPIWQ0_n4Vn42ohRLh0?oS9kO0on?Wml2oi>Q
gP?oUZ?M00?oVJCMoiVVgonLYmh00_nLYmh3oinYg@?oXZ[L00?oYJ_KojF]gOnX[m`00onX[m`00on[
/=_oZk;Mojjcg003ojjcg003ok2dfona]mgo/KOM00?o/kSL00Go][WKokJkgOnf^mgo][_MokVlg003
okVogP03okc0gOnl`moo_/?N00;o_/?N00Co_lKOol;7g_o2amko`/ON0oo4bml2olG>h@05olO>goo8
dN7ob=7QolSAhOo9d^000_o:eN800oo;f>?ocMSRolgHhP02olgLh`06oloLh_o@gnCod=oTom3RiOoA
h^Cod^GU0_oBj>H02?oBk>Oodn_Uom?^i_oCk^Kod_7Wom;ciooClnKod_GV0_oAmnH02_o?nNGocO_U
o`000?o=o>?obogRolSmhOo2o]ko__kLok_mfoncnmL:ooooo`03o`000?oooooooooo00gooooo0009
ooooo`0400000?ooooooooooooooo`<0IVIV00<0000007moO`1oOgl01P1oOgl00`000000VIVI09VI
V@0709VIV@030000002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02`3<c<`00`000000i^KV0>KV
iP0@0>KViP030000003oool0oooo02`0oooo00<000000>KViP3Vi^H04@3Vi^H00`000000c<c<0<c<
c00;0<c<c0030000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07mo
O`0207moO`Cooooo00<00000ooooooooool03oooool2o`0001oooooo00Go<7_UocEmi_leONKo?X3V
od>2i`02od^4iP03oe27i_mERNOoEHWW00;oG8_U00?oHHgUofF?iOmUSnD00_mZTND2ofjCi@;oM9CS
0_miU^83ogfGhP;oPIWQ0_n4Vn42ohRLh0?oS9kO0_n?Wml00onCXMkoTZ?Poi:Sh002oiJUg`?oVJKO
0onLYmh00onOZMgoWj_Ooin[g`02oj:/gP?oYJgM0_nX[m`01?nX/MkoZk;Moj^bgOn[/]d2ojjcg003
ojjfg_na]mgo/KOM00;o/KOM00?o/kSLokBjg_nd^]h00_nf^md01Ong_]oo^KoNokVog_ni_mko^/;P
00?o_<?O00Go_/?Noko6gonoa]oo_lKOol;7gP02ol;:h004olC;goo5c^7oaLkQolG>h@?ob=7Q0_o8
eN<01?o:eN;obmSSol_Hhoo<g>D2olgLh`;oc]oU00Kod=oTom3RiOo@iNKod>GVom3YiooBj>H2om;/
i`03om7^iooCk^Kod_7W00;od_?W00god?KWolohiooAmnKocoWUolgkiOo;o>Cob?gSo`000?o2o^3o
__gNok_mg?ncnmSo[o[F00cooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooo
oooooooo0`1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00L0VIVI00<000000;>c
/`2c/k<0202c/k<00`000000c<c<0<c<c00:0<c<c0030000003Vi^H0i^KV0140i^KV00<000000?oo
o`3oool0:P3oool00`000000i^KV0>KViP0A0>KViP030000003<c<`0c<c<00/0c<c<00<000000;>c
/`2c/k<0202c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00<0Ogmo1?ooool00`00
003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo00Co:g[UocEmi_liOnOo>GoW0_m3P^L0
1Om7QNOoC8OXoeF9iomERNOoFH_W00;oGXkW0_mUSnD2ofZAi@;oKY?U0_mcUND2ogNGi0;oNiWT0_mo
Vn<3ohBLh`;oQikR0_n;X>82ohnRh@CoTZ?P0_nFYMl2oiVVg`;oW:ON00?oW:WPoin[gonOZml00_nO
Zml2oj:/gP03ojF]gOnV/=ooY[3O00?oZ;7N00?oZk;Mojbegon/]Ml00on^]]h2ok6gg@05ok:jgond
^]ko];[NokBjg_ne_N000ong_]l01Oni_mko^/;Pok[2h?nj`^3o_<?O00;o_LKQ0_noa]l2ol39h@05
ol;:h?o3cN;o`lgRol?=h_o5c^400_o6dN<00oo8dN7ob=GSolSEh`02olWHi@04ol_Hhoo<g>Goc=cU
olcOiP;oc]oU00Coc^;VolkVioo>i^Ood>GV0_o@jNL00oo@k>Sod^cWom7^i`02om7aj004om3dj?oB
lnOod?KWolohi`;ocO[V00Wobo_VolSliOo2oN;oaOgRol;nh?l0003o^ogLok?kf?n_n]H03Oooool0
0ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool306IVIP030000001oOgl0
Ogmo00L0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0
c<c<00/0c<c<00<000000>KViP3Vi^H04@3Vi^H00`000000oooo0?ooo`0X0?ooo`03o`00003Vi^H0
i^KV0180i^KV00<000000<c<c03<c<`02`3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0
VIVI00L0VIVI00<0000007moO`1oOgl00`1oOgl4ooooo`0300000?oooooooooo01;ooooo00?o0000
ooooooooool07Oooool2ob]ji@;o>GoW00Co?X;Wod>5j?m3QNSoC8OX0_mARNP01OmFS>SoGXkWoej>
iomNS^OoHi3W00;oJ9;W0_m/U>L2og>Ei@;oMiOT0_mkVN@2ognKh`?oQ9cS0_n7W^82oh^PhP;oSj;Q
0_nBXn000onBYN;oUZORoiJWhP03oiVXh@?oW:WP0_nOZml00onO[N7oXjoPoj>_h004ojJ`g`03ojRa
g_nY]>3o[;GO00?o[;GO00?o[[KNojnih?n_^N000onb^]l01Ond^]ko]KgPokFmh?ne_N3o]kkO00;o
^<7Q0_nj`^001OnkaN;o_LKQokg6hOnma^7o_/WS00?o`<WQ00?o`LgSol?=h_o3cN800_o4dN@01?o6
dN?oamCTolODi?o8eN<2olWHi@;ob]_V00Goc=cUolcOi_o<gnKoc>;XolkRiP02olkVi`;oc^WX00Oo
d>WWom3/j?o@k>SocnoYoloajOoAlNSod?CX00;oc_KX00_ocOSXol_jioo=n^Kobo_VolSliOo2oN;o
_ogPok_mg_ngo=_o[o[Go`00000?ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oo
ooooooooooooo`<0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0709VIV@030000
002c/k<0/k>c00P0/k>c00<000000<c<c03<c<`02`3<c<`00`000000i^KV0>KViP0B0>KViP03o`00
00000000oooo02H0oooo0P00000D0>KViP030000003<c<`0c<c<00/0c<c<00<000000;>c/`2c/k<0
202c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00<0Ogmo1?ooool00`00003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01gooooo00Ko9W[UobYli_lZO>Ko=7oWocV2j?m3QNP2odR7
j@;oDHWX00?oEXcXoe^>jOmKS^T00_mPTNT2ofRBi`;oK9CW00?oLIKWogJHi_mfV>H00_mjV^H3ogjL
i@;oPYkU0_n6X>@2oh^Ri0?oSZCS0onBYN82oiJWhP?oVJSQ00?oW:WPoib/h_nO[N400onO[N42oj>_
h0;oY[3O00CoY[;QojVdh?nY]>3oZKCP0_n/]Ml00on/^>7o[kWPojnih002ojnih003ok:jgonb_>7o
/[cQ00;o]KgP00Go]L3RokS1hOnh`N7o^<7QokW4h`03ok_5hP05okg6hOnnbN?o_/WSokk9hoo0bN40
0_o1cN<3olCAi0;oaMCV00CoamCTolOHi_o7f>KobMSU0oo:fnH01_o:gnSoc=oVolcRj?o<h^SocNKY
olkVi`;oc^WX0_o>k>T04oo@k>SocnoYoloajOo?lNWoc_CYolcfjOo>m^SocOSXol_jioo8nnKoaOcU
ol;mi?nooN;o^ogPokOlgOn^n]SoZ_WEojGgd_l000003oooool00ol0003oooooooooo`0<ooooo`00
2Oooool01000003oooooooooooooool406IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2I
VIT01`2IVIT00`000000/k>c0;>c/`080;>c/`030000003<c<`0c<c<00/0c<c<00<000000>KViP3V
i^H04`3Vi^H00`000000oooo0?ooo`0R0?ooo`8000005@3Vi^H00`000000c<c<0<c<c00;0<c<c003
0000002c/k<0/k>c00P0/k>c00<0000009VIV@2IVIT01`2IVIT00ol00000Ogmo07moO`0407moO`Co
oooo00<00000ooooooooool05?ooool2o`0001kooooo00Ko87WUobYli_l_OnOo;goWocV2j?lnQNT2
odR7j@03odf:jOmBSN[oDXgZ00;oFhkY00?oH97YofFCjOmUTnT00_mZU^T2ofnHj@;oMYSV0_mjV^H3
ogjLi@;oPYkU0_n6X>@2oh^Ri0?oSZCS00?oTZGRoi6Wi?nEZN@00_nEZN@3oiV[h`;oW:cR0_nO[N40
0onO/>?oXk7Roj>ahP02oj>ahP;oY[;Q00?oZKCPojVfh_nY]^800on/^>42ojnih0;o[k_R00?o/[cQ
ok>ohone`>800one`>801Onh`N7o^LCSokW4honia>?o^lGR00;o_<ST0_nnbN<2oko<i@04ol7=hoo2
d>Go`]3UolCAi0?oaMCV00?oaMOWolOHi_o8fnP00_o8fnP01Oo:fnKob]oXol[Oj?o:h^Woc>;X00;o
cNKY00Goc>WZolkYj?o>k>Woc^cYolg_jP02olgbj`0?oloajOo>m>Woc?KYol[hjOo8n^SoaO_Wol;l
i_o5o>Go`_gTokomh_nkoN3o]ocMojkjf?nZnMGoYOOB00;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`002Oooool01000003oooooooooooooool406IVIP030000001oOgl0
Ogmo00L0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0
c<c<00/0c<c<00<000000>KViP3Vi^H04`3Vi^H00`00003o00000?ooo`0O0?ooo`8000005P3Vi^H0
0`000000c<c<0<c<c00;0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT01`2IVIT0
0`000000Ogmo07moO`0407moO`Cooooo00<00000ooooooooool05_ooool00ol0003oooooooooo`0L
ooooo`;o87WU0_l_OnL01OldP^Wo?XGYocj5jOm4R>[oBH_[00;oDXgZ00?oF8oZoefBjomMT^/00_mU
TnT2ofZFj@04ofnHjOmcV^SoLi[Xog>Jj0;oN9cX0_mmW^P2oh6Pi`?oQJ;W0_n:Y>H2ohjVi@?oTJOT
0onEZN@00onIZn?oVJgUoib_i002oib_i0?oWk3S0_nS/N801?nS]>CoY[GSojJehonV]N<3ojVfhP03
ojbhhOn]^^Co[K[T00;o[k_R00Co/;kUok>ohonc_n?o/koS0_ne`>82okK3i0;o^LCS0_nianD00onl
b>Co_<cVokc<iP02oko<i@;o_m3V00Go`]3Uol;Cioo2dnOo`]?WolGDiP02olGGi`03olGKjOo8fnSo
b=_X00;ob=oY00Kob]oXol[RjOo:i^_ob^K[olgVjOo<jNX2olc/j`0Bol__k?o=kn[ocO;[olgbjoo;
m>_obOO[olOhj_o:n>Wob?[XolGkioo2o>Ko_ocTok_lh_ngo=oo/__MojWieonUmmCoX?GA1Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooo
ooooo`@0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0709VIV@030000002c/k<0
/k>c00T0/k>c00<000000<c<c03<c<`02`3<c<`00`000000i^KV0>KViP0E0>KViP030000003oool0
oooo01`0oooo00<000000>KViP3Vi^H05P3Vi^H00`000000c<c<0<c<c00;0<c<c0030000002c/k<0
/k>c00T0/k>c00<0000009VIV@2IVIT01`2IVIT00`000000Ogmo07moO`0407moO`Cooooo00<00000
ooooooooool05oooool00ol0003oooooooooo`0Looooo`03oaYhi?lNNnGo:GkW00;o;h;Y00?o>XGZ
ocn8joloR>/00_m9Rn/01?m?SN_oE93/oefBjomMT^/2of:Dj`;oIiO[00CoKIW[og>Jj?mcV^SoLi[X
0_mhW>P2ogfNj0;oPJ3W0on5X^L2ohZTiP;oSZKU00?oTJOToi6ZionAZ^L00_nE[>H3oiV]i@?oW:oT
00?oWk3SoinbiOnO/^D00onS]>@00onV]N?oY[SVojJhiP03ojVii@03ojfji?n]_NKo[KgV00?o/;kU
00Ko/koSok?3i_nc`nKo/l?VokK3i?nganH3okW7i@04ok[;ionlc>Ko_<cVokc<iP;o_LoX00?o_m3V
ol3Cj?o0dnP00_o2dnL2ol?Gj@04olGGioo5fnWoaM_YolKNj`;ob=oY00Cob>;[olSVk?o8i^cob^K[
0_o:jN`00oo9k>goc>c[ol__k002ol[bk005olSdk?o;m>_obOO[olOhj_o5n^T00_o2nnP01onoo>Ko
^ocTokOlh_n^n]coZOWIojCge_nOmM802?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00cooooo0009ooooo`0400000?ooooooooooooooo`@0IVIV00<0000007moO`1oOgl01`1oOgl0
0`000000VIVI09VIV@0709VIV@030000002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`0303<c<`0
0`000000i^KV0>KViP0E0>KViP030000003oool0oooo01T0oooo0P00000H0>KViP030000003<c<`0
c<c<00/0c<c<00<000000;>c/`2c/k<02@2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0
Ogmo00@0Ogmo1?ooool00`00003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00Co4gKS
oaikiOlNNnGo;h;Y0_ldQNX2ocn8j`04odF;k?m;S^goBhk]oeB@k0;oFY?/0_mOU^d2ofNGj`;oKIW[
00?oLIc[ogJNj_mfW^X00_mkX>X3oh2Rj@;oQ:CY0_n9Y^P3ohfXi`?oTJ[W0_nE[>H00onI[NGoV;3W
oiR`i`03oibaiP?oWk;U00?oXkCToj>gionV^>H00onV^>H00onY^NGoZ[cWojfmiP03ojfmiP03ok2n
iOn``^Oo/<;W00;o/l?V00Go]<KXokO7i_nganKo]lOVokW7i@03ok[;i`04okc<i_nmcnSo_LoXokgB
jP?o`=?X00?o`=OZol?GjOo3enT00_o3fn/01Oo5fnWoa]k[olKNjoo6h^cob>;[00;ob>K/0_o8jNd0
1oo:jNcobNc]olW_kOo9kngoao;^ol[bk?o8m>`00_o7mn`02oo4n>_o`_[ZokkkjOo2nnSo_ocVok_l
i?ngo>;o[_[LojWifOnTmmKoWoGB00Wooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`002Oooool01000003oooooooooooooool506IVIP030000001oOgl0Ogmo00L0Ogmo00<0
000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<00`0c<c<00<0
00000>KViP3Vi^H05@3Vi^H3000001H0oooo0P00000I0>KViP03o`00003<c<`0c<c<00`0c<c<00<0
00000;>c/`2c/k<02@2c/k<00`000000VIVI09VIV@0709VIV@030000001oOgl0Ogmo00D0Ogmo1?oo
ool00`00003oooooooooo`0Iooooo`;o00007_ooool00olHN^Go7GgVoaemiP02ocB5jP04ocZ8k?m0
Rngo@8_]od^>k@;oD97]0_mJTn`2oenFk@03ofFHkOmZVngoJY_]00;oKig]0_mfW^X2og^PjP?oP:;Y
0_n4Y>T2ohVVj003ohfXion<Zn[oS:_Z00;oT:cY0onD[^P3oiR`i`03oibai_nL]>WoWkKX00;oWkKX
0onS]nL2ojJhiP04ojJkj?nZ_>OoZ[cWojZli`;o[KgV0_n]`NP00on``^Oo/LGYok75j@03okC6j005
okO7i_ngb^So]l[XokO:j?njbnL00_njc^T01OnmcnSo_M;ZokgBj_nmd^[o`=?X00;o`=OZ00?o`M[/
ol?Kjoo3fn/00_o3g^`01Oo6g^_oa^;/olGUk_o5iNkob>K/00;ob>W]00Goanc^olK_koo6knoobNo]
olObkP02olKdkP0<olCgkOo7mncoa?S[ol;jj_nnnnWo^o_WokOkiOnbnn;oZOWLojCgf?nNmMCoVO;A
3?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?oo
ooooooooooooo`D0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0709VIV@030000
002c/k<0/k>c00T0/k>c00<000000<c<c03<c<`0303<c<`00ol00000i^KV0>KViP0H0>KViP040000
0?l00000000000000100oooo0P00000J0>KViP030000003<c<`0c<c<00`0c<c<00<000000;>c/`2c
/k<02@2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00D0Ogmo1?ooool00`00003o
ooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo0_l6Lml2oaemiP03ob>0j?l_Q>[o=HS/00;o
@8_]00?oAXk^oe2AkOm@TNd00_mFU>h00omLUnkoHY[_of:Jk`02ofZKk@;oKig]0omdX>d2ogVRk0;o
OZC/0_n3Yn/3ohRXj`;oS:_Z0_n@[>T00onD[^SoU;7[oiBaj`02oiRbjP?oW;CY0onO]^P00onS]nOo
Xk[Yoj>jj@03ojJkj006ojZlionZ_nWoZ[oYojZojOn]`NSo[/CZ1?naaNT00onda^So]<WZokC9jP02
okO:j0;o]lk[00?o^/kYok_Bjonkd^/00_nmd^X2okkFk003ol3Gj_o1f^co`M[/00;o`Mk^00Go`mk/
ol?Rk_o3h^ko`nG_olGUkP02olGYk`05olC/l?o7k>koa^o_olK_koo4l^l00_o3m>l00oo6m>koa?O]
ol7hk@02okkjj`07okOkionbn^Go[_[RojSig_nSmm_oW_GGohg]b`0?ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo1@1VIVH00`00
0000Ogmo07moO`0707moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<02P2c/k<00ol0
0000c<c<0<c<c00<0<c<c0030000003Vi^H0i^KV01/0i^KV0`0000090?ooo`@00000703Vi^H00`00
0000c<c<0<c<c00<0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT0202IVIT00`00
0000Ogmo07moO`0507moO`Cooooo00<00000ooooooooool07?ooool00ol0003oooooooooo`0Koooo
o`;o1W?O00Co2gOQoaaoiolLOnOo:HCZ0_leR>`00olkRngo@Ho^odbBk`03oe:Ek`03oeRHl?mRV^oo
HY[_00;oIic_0_m]Wnl2og:Rk`;oMjC^0_mmYnh3oh:YkP;oQZ_]0_n;[N`3ohn_k0?oU;7[0_nH/^X0
0onL]>WoVkO[oi^gj`03oinhjP03oj>jjOnS_NcoXkg/00?oY[k[0_nZ_nT01?nZ`nco[/CZojk4j_n^
a>X2ok75j@;o/LS[00?o]<WZokC=k?ndcN`00_ngc^/2okSAk@05ok_Bjonke^go^mK]ok_FkOnne^`0
0_nnf^h00oo1f^co`Mk^ol7NkP02ol3Rl006ol?Rk_o3iNoo`nG_ol;Yl?o5jNooa>c`0_o3ko001_o1
l_7oa?;_ol?dkoo3m>oo`?K_okghkP;o^_W/00Oo__[[okOkionbn^Go[_[RojSig_nSmm_oW_GG01;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooo
ooooooooool606IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000
/k>c0;>c/`090;>c/`030000003<c<`0c<c<00d0c<c<00<000000>KViP3Vi^H07@3Vi^H9000001l0
i^KV00<000000<c<c03<c<`0303<c<`00`000000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00P0
VIVI00<0000007moO`1oOgl01P1oOgl01Ol0003oooooooooooooool0000001oooooo00?o0000oooo
ooooool06oooool2o`1ag005o`Aeg_lLOnOo77oWob:3jOl_Qn`00_leRnd2od6?kP?oDYG_0_mHV?00
0omNVo3oI9kaofBNl@02offOk`;oLZ;_0_mgY>h2ogfWkP?oPZW^0_n6Znd2oh^]k003ohn_k?n?/^ko
Sk;^00;oTk?]0onG]N`3oi^gj`03oinhj_nO^ngoXkg/00?oXkg/00?oY[k[ojK2kOnV`^d00onZ`n`0
0on^a>[o[/O]ojk7k@02ok78j`;o/Lc^00Go]<g/okC@k_ndd>ko]=3^okSAk@02okSEk`;o^mK]0_nk
fNl01?nnf^ko_Mg`okgMl?nmhO42ol3Rl0;o`>Ga00Oo`nG_ol;Yl?o1k?7o`Ncaoko_l_o3ko3o`O;a
00;o_oC`00?o_?K`ol3fkonmn>h00_njnN`01_nbn^So[OWUojShhOnSmmkoWOGJoiSbeACooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooo
ool706IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c
/`090;>c/`030000003<c<`0c<c<00d0c<c<00<000000>KViP3Vi^H0@P3Vi^H00`00003o00000<c<
c00=0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT0202IVIT00ol00000Ogmo07mo
O`0707moO`0500000?ooooooooooooooo`0000008?ooool2o`0001gooooo0_l0KmT01?l9NN7o5WkV
oab2j?lYQn/2ocF;k@03ocb?kom2To3o@Y?`00;oCYKa00?oE9WaoeZLl_mJW?800_mTW_42ofZQl@;o
L:Ca0_meY_42og^Yl0?oP:_`0_n5[^l3ohZ`k`;oSk;^0_nC/nd00onG]NcoUkS_oiNhk`03oi^jkP;o
Wk_]0_nS_N`2oj?0kP03ojK2kOnVaNooY/G_00?oZ/K^00Go[/O]ojk;kon^bnoo[/__ok7<kP02ok7?
l0;o]=3^0_nde?000onheNoo]mWaokOIl@02ok_Ik`;o^]ga00Co_Mg`okgQlOnliO?o_>Gc0_o0iO40
1Onoj?;o_^ccokk/loo1k?7o_nob00;o__7b00go^oCbokodl?nlm_3o^OS_okKikOnbnN_o[OWXojSh
iOnSmn7oWOGMoiObf?nAl=CoQNW:01Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0;ooooo`002Oooool01000003oooooooooooooool706IVIP030000001oOgl0Ogmo00H0Ogmo00<0
000009VIV@2IVIT0202IVIT00ol00000/k>c0;>c/`090;>c/`030000003<c<`0c<c<00h0c<c<00<0
00000>KViP3Vi^H0@03Vi^H00`000000c<c<0<c<c00>0<c<c0030000002c/k<0/k>c00T0/k>c00<0
000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`0707moO`0500000?ooooooooooooooo`000000
8_ooool00ol0003oooooooooo`0Kooooo`;o06gE00Co073Ho`mmi?lLP^So78;X0_l_Rnd01?lfSnoo
@Y?`od:Cl?m9U_82odnJl`;oFYcb0_mQWo<01?mWXo?oKJKcoffVlom]Y_<2og>Xl`;oNjW`00?oP:_`
ogj^l_n3/?800_n3/?82ohRbl@?oSKCa0_nB]_03oiNhk`03oi^jk_nJ_O3oV[g`00?oW[o_00?oXl3^
oj;4l?nRa?000onVaNl00onZa^koZ/[`oj[:l002ojk;k`;o[Lka00?o/Lo`ok7Cl_nado800_nde?02
okCHlP03okOIlOngg??o]mcc00;o^]ga0_njhO<01Onii?Co_>Gcok_Xm?nkj?Co_nSb00;o_^cc0_nl
k_<01OnjlO?o__7bok_dl_nim_7o]OO`00;o/OS^00So[OS[ojSgj?nRm^CoWOCPoh[/d_n4jLgoO^G8
ogSR`aSooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`002Oooool01000
003oooooooooooooool706IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT01`2IVIT0
0`000000/k>c0;>c/`0:0;>c/`030000003<c<`0c<c<00h0c<c<00<000000>KViP3Vi^H0?P3Vi^H0
0`000000c<c<0<c<c00>0<c<c0030000002c/k<0/k>c00T0/k>c00<0000009VIV@2IVIT02@2IVIT0
0`000000Ogmo07moO`0607moO`0300000?oooooooooo00;ooooo00<00000ooooooooool08Oooool0
0ol0003oooooooooo`0Mooooo`05o`1^dol0M=_o5H7VoaF1i_lKQNT00_lYRnd3ocfCl@;oCi[c0_mF
W_<2oefQm004of>TmOm]Y_?oKJKcoffVl`;oLjSc0_mhZo<2ogj^lP?oPk3b0_n8/_400on=]?7oS;Oc
oi6ilP03oi6ilP;oU[_a00?oV[g`oiW0lonI`?<00onN`_800onRa?3oX/Ocoj;7l`03ojK8lP03oj[:
l?nYcO?oZLgc00;o[Lka0_n]d_<01Onado;o/=Odok3Gm?n`eoCo]=Sb00;o/m_d00Ko]mccokKPm?nf
h?Co]^3dok[Qlonii?@2okSWmP03ok_Xm?njjoCo^^_d00;o^>ke00Co_>kcok[alonglo?o]?Gb0_n`
m_002On/mnko/OS^ojghjonXmnSoX_KToigdh?mliL[oM^75og3M`00Kooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo201VIVH00`00
0000Ogmo07moO`0607moO`030000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<02P2c/k<00`00
0000c<c<0<c<c00>0<c<c0030000003Vi^H0i^KV03`0i^KV00?o00000<c<c03<c<`03`3<c<`00`00
0000/k>c0;>c/`090;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl01`1oOgl00`00
003oooooooooo`02ooooo`0300000?oooooooooo02;ooooo00?o0000ooooooooool07Oooool01_l0
I<Ko07;Fo`ioi?l>OnCo58CVob::j`;o:Hk^00?o=i?aocjGl_lnUo800_m;Vo<00omAWoGoF:;foeRR
mP02of>Tm@;oJJSe0_m`ZoD2ogJ^m@?oO;3e0_n1/o@2ohNem0;oS;Oc0_nA^O801?n@_?GoUKkdoiFn
m?nE__@3oiW0l`03oik2l_nMaOCoWLGd00?oX/Oc00CoY/SbojG<m?nUc?CoZLgc0onYdOD00on]d_?o
[=KfojcFmP02ok3Gm0;o[m[f00?o/m_dok;Om_nbgoH00_nfh?@01OnehoKo]>OgokCWmonhioKo]^_f
00;o]>gg0_nhk_D00onfl?Go/o;dojodl`02oj_el@09ok3fl?n/mnkoYoK[oj;fj?nLm>CoU_;OohW/
eOm^gL;oJ=Vl01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Ooo
ool01000003oooooooooooooool806IVIP030000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0
202IVIT00`000000/k>c0;>c/`0:0;>c/`03o`00003<c<`0c<c<00h0c<c<0P00000k0>KViP030000
003<c<`0c<c<00l0c<c<00<000000;>c/`2c/k<02@2c/k<00`000000VIVI09VIV@0809VIV@030000
001oOgl0Ogmo00L0Ogmo00<0000006IVI_ooool00oooool00`00003oooooooooo`0Sooooo`03o`00
0?oooooooooo01gooooo00?o0671o`1XbOl0MmT00_l6ON401?lKR>Wo:Hk^obV>k_l`To02ocjGlP;o
AI_d00?oC9ofoeRRm_mHX_H00_mOY_H2ofJYm`?oKJgg0_mc/?L2ogVcm`;oOkKg0_n5^?H3oh^jmP;o
T;ce00CoUKkdoi?2m_nC`_KoTl;f0_nHa?D00onMaOCoW<Wgoic9m`03oj7;m@03ojG<m?nTcoKoY<of
00;oZM7e0_nXe?L00on/e_KoZmWhoj_In002ojoJmP;o[]kh00Co/]ofok7Rn?n_i_Wo[nKi0_ndioL2
ok;Yn003ojo/n?ndkOOo/O3f00;o[_7e00_oZ_?dojodlon[mO7oZoGaojOekonRm>_oU_;Soho_g_n9
k=WoP^WCofKH_`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool000Wo
oooo00@00000oooooooooooooooo201VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI
00P0VIVI00<000000;>c/`2c/k<02`2c/k<00`000000c<c<0<c<c00?0<c<c0030000003Vi^H0i^KV
03L0i^KV00<000000<c<c03<c<`03`3<c<`00`000000/k>c0;>c/`0:0;>c/`030000002IVIT0VIVI
00P0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIVooooo`03ooooo`0300000?oooooooooo
02Cooooo0_l0000Pooooo`04o`1K]?l0JLKo07WHo`F0h0?o8Xg/0_lhUo82ocnLm003odNPm_mDY?Oo
E:Cg00;oFjOh0omRZoP00omY[oWoL;;iog2bn@02ogJen@;oO;Si1?n3^oT2ohRmn0;oS[og0_nC`_H2
oi;5n@;oUlOh00CoW<Wgoi_<nOnKc?WoVlci0_nOc_P01OnTcoKoXm?hoj?Cn?nSdoSoZ=Cg00;oY]Si
00KoZmWhoj[MnOnZgOWoZ]giojkNn?n]hOT2oj_TnP07ojoVnOn]j?Wo[NSiojgXnOnbjOSo[nchojc^
m`02ojW`mP0;ojkamOnZloCoY_?boj7ckonKl^_oUO7Woho_h_n8k=goPNWGog[UdOmGc[H09?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0500000?oooooooooo
ooooool00000201VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0VIVI00P0VIVI00<00000
0;>c/`2c/k<02`2c/k<00`000000c<c<0<c<c00?0<c<c0030000003Vi^H0i^KV03@0i^KV0P00000A
0<c<c0030000002c/k<0/k>c00X0/k>c00?o000009VIV@2IVIT0202IVIT00`000000Ogmo07moO`07
07moO`030000001VIVH0IVIV00Cooooo00<00000ooooooooool09_ooool00ol0003oooooooooo`0O
ooooo`03o`1N]ol0K/Wo07gK00;o38GS00Co4h[Vob>AkOlaUo7o<IOa0_liW?<3odnUm`;oEZWi00?o
GJgiofF`n_mU/?X00_m`/_T2ogJen@;oO;Si0_n3^oT2oh2mn`;oQ/3j0on<`oT00onBaOWoT<Skoi38
n`02oiG:nP;oVlci0_nId?/2oikAnP;oXm?h0_nReoX00onVf?WoYM_kojGKn`02oj[Mn@04ojSPn_nU
ho_oYN?koj_TnP;oZ>Oj0_n]j?T03_nZjoWoYngioj?_monSkoOoZO3fojGamOnPlO;oV_7_oiC`jon>
k^KoQncQoh3XfomiiMGoL^7?9oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo0009ooooo`0500000?ooooooooooooooool00000201VIVH00`000000Ogmo07moO`0807moO`03
0000002IVIT0VIVI00P0VIVI00<000000;>c/`2c/k<02`2c/k<00`000000c<c<0<c<c00?0<c<c003
o`0000000000i^KV0340i^KV0P00000B0<c<c0030000002c/k<0/k>c00X0/k>c00<0000009VIV@2I
VIT0202IVIT00`00003o000007moO`0807moO`030000001VIVH0IVIV00Cooooo00<00000oooooooo
ool09oooool00ol0003oooooooooo`0Pooooo`05och00?l0L/go07_Fo`1ke_l<R><00_lKT>X01?lS
UNgo<Y_boc:Kl_ljXO@2odVUm`;oDJ[i00?oFJkjofF`n_mU/?X00_m/]?/3og>gn`;oN[_k00?oP;gk
ogg0o?mm`?`00on4`o`2oh[6n`03oi38non=bogoSL_m00?oTlgl00CoVM3koiOCo?nGdocoW=Gk0onJ
f?d01?nOf_coWMgmoigMoOnSg_`3oj3Ro006ojGSnonSi_coWnSkoioXnonUj_[oXNci0onMkOP02_nS
koOoW^oeoiW_l_nCknooSNgZohK[iOmoj=ooN>CIog7PdomYg<`Zooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool000Wooooo00D00000ooooooooooooooooo`00000906IVIP03
o`00001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`0;0;>c/`03
o`00003<c<`0c<c<0140c<c<00<000000>KViP3Vi^H0;@3Vi^H2000001<0c<c<00<000000;>c/`2c
/k<02`2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1V
IVH01?ooool00`00003oooooooooo`0Xooooo`03o`000?oooooooooo02?ooooo00Go07C:o`1me?lC
S^Ko4hkVoa^Cj@02ob^Jl003ocBPlom3YOOo@jGg00;oBj[i00?oDjojof2bnomP/_/00omX]_`2ofnj
o0;oM[gl00CoOL3logW3o_mi`okoNL?n0_n0a_h2ohO8o@04ohg;oOn;c_koRlknoh_>oP;oTM3m00?o
Um?loiCFo_nDe_h00_nJf?d2oiOKoP03oigMoOnJgogoV]om00;oX>;l00GoWNCmoiWVo?nIi_coWnSk
oi_YnP02oiK[n0;oWNgh00SoV>gfoi;]l_n<k>koQ^[YogkWi?mgi=koL>3GofSKd2kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`002Oooool01P00003oooooooooooooool0
C4a<o`0000P0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0909VIV@030000002c
/k<0/k>c00/0/k>c00<000000<c<c03<c<`04@3<c<`2000002`0i^KV00<000000<c<c03<c<`04P3<
c<`00`000000/k>c0;>c/`0;0;>c/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0201o
Ogl010000000IVIV06IVIP1VIVH4ooooo`0300000?oooooooooo02Wooooo0_l0000Uooooo`05o`1T
/Ol0KKco07oBo`B8g?lDTND00_lTVNd3ocbUm@;oAJ[h0_m=[oT00omF]?_oHkSlof>ho002of^ko@04
og:oo_m^`OkoK/7nofk1oP;oM/Go0_mmb?l01?n4bokoP<kooh3>oon0c_l2ohOAo`03ohkCo_n:e_oo
R]Ko00;oTMSo0_n=fol01?nDgOkoT=onoi3Oo_nGh_d3oi;So003oiWVo?nDio_oSnSh00;oRNSe00So
TN_foh_Zl_n4j>goONKXogKSh_m_gmcoIm_DodO6^c;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`002Oooool01P00003oooooooooooooool0C4a<o`0000T0IVIV00<00000
07moO`1oOgl01`1oOgl00`000000VIVI09VIV@0809VIV@030000002c/k<0/k>c00`0/k>c00<00000
0<c<c03<c<`04P3<c<`00`000000i^KV0>KViP0W0>KViP800000503<c<`00ol00000/k>c0;>c/`0;
0;>c/`03o`0000000000VIVI00T0VIVI00<0000007moO`1oOgl0201oOgl010000000IVIV06IVIP1V
IVH4ooooo`0300000?oooooooooo02_ooooo00?o0000ooooooooool09_ooool01?l0K[So07S3o`B;
f_lDUN@2obFMk003objSl?lnZ_Ko?Z[f00;oAZoh0_m?]?X2oeRio0?oHKkm0_mY`_h2og76o`;oNL[o
0_n0c_l2ogc?o`03oh?Coomne?ooO]Co00;oQ]So0_n=fol01?n9g?koQ=gmohCMoOn;hOd2ohKQn`;o
SNCk00?oR>Ghoh;TmOmkho000_mdhN/01OmliNcoMN;WofgNh?m=blOoALFo03Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`002Oooool01000003oooooooooooooool204a<
C003o`00001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0201oOgl00`000000VIVI09VIV@0809VI
V@030000002c/k<0/k>c00`0/k>c0P00000C0<c<c0<00000903Vi^H2000001@0c<c<0P00000>0;>c
/`030000002IVIT0VIVI00P0VIVI00<0000007moO`1oOgl0201oOgl00`000000IVIV06IVIP0206IV
IPCooooo00<00000ooooooooool0;?ooool00ol0003oooooooooo`0Xooooo`03o`1_/ol0NKoo08C<
00?o5ISR0_l_Ynl01?lh[_;oB;ChodRdn?m8]?P2oe:jnP;oF[ol0_mS`od00om/b?koI/SmofK8o@03
ofk=oP04ogOAoomad_goLM;mogWFoP?oLmKl00GoO=[logKJn_mff_[oO]kjogSMm`02og7LlP;oNN3d
00KoL]k_of_LjOmSf>;oFmCKoe??dom;b//jooooo`05o`000?ooooooooooooooool000002oooool0
00Wooooo00@00000oooooooooooooooo0P1<C4`00ol00000IVIV06IVIP0606IVIP030000001oOgl0
Ogmo00P0Ogmo00<0000009VIV@2IVIT02@2IVIT00ol00000/k>c0;>c/`0=0;>c/`030000003<c<`0
c<c<01<0c<c<1000000N0>KViP8000005@3<c<`00`000000/k>c0;>c/`0=0;>c/`030000002IVIT0
VIVI00T0VIVI00<0000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0306IVIPCooooo00<00000
ooooooooool0;Oooool00ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool0Q/P00_l5
TM@01?l=V=Wo7j;ToanRi?lXZNP2ocZbl@;o@kSd0_m=__L2oeK3n@;oGlSk0_mHaoL2of;=n@03of_A
nomTdOOoI=7g00;oKMKi00SoI]CdoekBkomNd^ooImOaof3DjomHdNCoD<gModO8e@;o?l?<00?o>;g4
ooooooooool0?Oooool01?l0003oooooooooool0000;ooooo`002Oooool01000003ooooooooooooo
ool304a<C003o`00001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl0201oOgl00`000000VIVI09VI
V@0909VIV@030000002c/k<0/k>c00d0/k>c00<000000<c<c03<c<`05P3<c<`3000001L0i^KV1000
000F0<c<c003o`00002c/k<0/k>c00d0/k>c00<0000009VIV@2IVIT02@2IVIT00ol00000Ogmo07mo
O`0707moO`03o`00001VIVH0IVIV00@0IVIV1?ooool00`00003oooooooooo`0^ooooo`;o0000:?oo
ool00ol0003oooooooooo`07ooooo`05oaP00?l0R/3o6:;JoaRRf_lQZMh00olc/nT00olm^^go=KOV
ocFgiP02ocnmjP03odW3kOm1`>Ko@L3V00;oBlKY0_m2`n801?m<bNKoA<GNocc0e_lc^le7ooooo`03
o`000?oooooo000000_ooooo0009ooooo`0400000?ooooooooooooooo`<0C4a<00?o000006IVIP1V
IVH01`1VIVH00`000000Ogmo07moO`0807moO`030000002IVIT0VIVI00T0VIVI00<000000;>c/`2c
/k<03@2c/k<00`000000c<c<0<c<c00H0<c<c0@000003`3Vi^H200000003o`0000000000c<c<01P0
c<c<00<000000;>c/`2c/k<03@2c/k<00ol00000VIVI09VIV@0909VIV@030000001oOgl0Ogmo00P0
Ogmo00<0000006IVIP1VIVH0101VIVH4ooooo`0300000?oooooooooo033ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000_ooooo0009ooooo`040000
0?ooooooooooooooo`<0C4a<00?o000006IVIP1VIVH0201VIVH00ol00000Ogmo07moO`0707moO`03
0000002IVIT0VIVI00X0VIVI00<000000;>c/`2c/k<03@2c/k<00`000000c<c<0<c<c00K0<c<c0l0
0000703<c<`00`000000/k>c0;>c/`0=0;>c/`030000002IVIT0VIVI00T0VIVI00<0000007moO`1o
Ogl02@1oOgl00`000000IVIV06IVIP0406IVIPCooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo06Oooooo00?o0000ooooool000002_ooool000Wooooo
00@00000oooooooooooooooo101<C4`00ol00000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00P0
Ogmo00<0000009VIV@2IVIT02P2IVIT00`000000/k>c0;>c/`0=0;>c/`030000003<c<`0c<c<04<0
c<c<0P00000?0;>c/`030000002IVIT0VIVI00T0VIVI00<0000007moO`1oOgl02@1oOgl00`000000
IVIV06IVIP0506IVIPCooooo00<00000ooooooooool0<_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo06Sooooo0_l0000:ooooo`002Oooool01000003oooooooooooooool404a<C003
o`00001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl0201oOgl00`000000VIVI09VIV@0909VIV@03
0000002c/k<0/k>c00h0/k>c00<000000<c<c03<c<`0@@3<c<`00`000000/k>c0;>c/`0>0;>c/`03
0000002IVIT0VIVI00T0VIVI00?o000007moO`1oOgl02@1oOgl00`000000IVIV06IVIP0606IVIPCo
oooo00<00000ooooooooool0<oooool2o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0000[o
oooo0009ooooo`0400000?ooooooooooooooo`D0C4a<00?o000006IVIP1VIVH01`1VIVH00`000000
Ogmo07moO`0907moO`030000002IVIT0VIVI00T0VIVI0P00000?0;>c/`03o`0000000000000003d0
c<c<0P0000000ol00000/k>c0;>c/`0=0;>c/`800000302IVIT00`000000Ogmo07moO`0807moO`03
0000001VIVH0IVIV00L0IVIV00D00000oooooooooooooooo0000000gooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0Hoooool4o`0000gooooo0009ooooo`0400000?oooooooooooooo
o`H0C4a<00?o000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0807moO`03o`00002IVIT0VIVI
00/0VIVI00<000000;>c/`2c/k<03`2c/k<2000003X0c<c<00<000000;>c/`2c/k<03`2c/k<00`00
0000VIVI09VIV@0;09VIV@030000001oOgl0Ogmo00T0Ogmo00<0000006IVIP1VIVH01`1VIVH01@00
003oooooooooooooool0000003Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1P
ooooo`?o00004Oooool000Wooooo00@00000oooooooooooooooo1`1<C4`00ol00000IVIV06IVIP07
06IVIP030000001oOgl0Ogmo00P0Ogmo00<0000009VIV@2IVIT02`2IVIT00`000000/k>c0;>c/`0@
0;>c/`030000003<c<`0c<c<03D0c<c<0P00000A0;>c/`030000002IVIT0VIVI00/0VIVI00<00000
07moO`1oOgl02@1oOgl00`000000IVIV06IVIP0706IVIP0300000?oooooooooo00;ooooo00<00000
ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l0000D
ooooo`002Oooool01000003oooooooooooooool704a<C003o`00001VIVH0IVIV00P0IVIV00?o0000
07moO`1oOgl0201oOgl00`000000VIVI09VIV@0;09VIV@8000004@2c/k<2000003<0c<c<0P00000B
0;>c/`030000002IVIT0VIVI00/0VIVI00<0000007moO`1oOgl02@1oOgl00`000000IVIV06IVIP07
06IVIP030000001<C4cooooo00?ooooo00<00000ooooooooool0>?ooool2o`0001kooooo00?o0000
ooooooooool0F?ooool4o`0001Sooooo0009ooooo`0400000?ooooooooooooooo`L0C4a<00?o0000
06IVIP1VIVH0201VIVH00`000000Ogmo07moO`0907moO`030000002IVIT0VIVI00`0VIVI00<00000
0;>c/`2c/k<0402c/k<2000002l0c<c<0P00000C0;>c/`030000002IVIT0VIVI00`0VIVI00<00000
07moO`1oOgl0201oOgl00`000000IVIV06IVIP0806IVIP030000001<C4cooooo00?ooooo00<00000
ooooooooool0>_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo1?l0000L
ooooo`002Oooool01000003oooooooooooooool804a<C003o`00001VIVH0IVIV00P0IVIV00<00000
07moO`1oOgl02@1oOgl00`000000VIVI09VIV@0<09VIV@030000002c/k<0/k>c0140/k>c0`00000Y
0<c<c0<00000502c/k<00`000000VIVI09VIV@0<09VIV@030000001oOgl0Ogmo00P0Ogmo00<00000
06IVIP1VIVH0201VIVH00`000000C4a<04a<C004ooooo`0300000?oooooooooo03_ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o00008?ooool000Wooooo00@00000oooo
oooooooooooo2@1<C4`00ol00000IVIV06IVIP0706IVIP030000001oOgoo000000X0Ogmo00<00000
09VIV@2IVIT0302IVIT00`000000/k>c0;>c/`0C0;>c/`8000009@3<c<`2000001H0/k>c00?o0000
09VIV@2IVIT0302IVIT00`000000Ogmo07moO`0907moO`030000001VIVH0IVIV00P0IVIV00<00000
04a<C01<C4`01?ooool00`00003oooooooooo`0looooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0COooool4o`0002?ooooo0009ooooo`0500000?ooooooooooooooool000002@1<C4`0
0ol00000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00X0Ogmo00<0000009VIV@2IVIT0302IVIT2
000001D0/k>c1@00000N0<c<c08000005P2c/k<2000000d0VIVI0P00000;07moO`030000001VIVH0
IVIV00P0IVIV00@0000004a<C01<C4`0C4a<1?ooool00`00003oooooooooo`0mooooo`;o00006Ooo
ool00ol0003oooooooooo`19ooooo`Co00009oooool000Wooooo00D00000ooooooooooooooooo`00
000904a<C003o`00001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl02P1oOgl00ol00000VIVI09VI
V@0=09VIV@800000602c/k<3000001@0c<c<1`00000E0;>c/`<000003P2IVIT00`000000Ogmo07mo
O`0:07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`00P1<C4`4ooooo`0300000?oo
oooooooo03oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15ooooo`Co0000:ooo
ool000Wooooo00H00000oooooooooooooooo03<c<ol0000904a<C003o`00001VIVH0IVIV00P0IVIV
00<0000007moO`1oOgl02P1oOgl00`000000VIVI09VIV@0>09VIV@030000002c/k<0/k>c01P0/k>c
5000000K0;>c/`030000002IVIT0VIVI00h0VIVI00<0000007moO`1oOgl02P1oOgl00ol00000IVIV
06IVIP0806IVIP030000001<C4`0C4a<00<0C4a<1?ooool00`00003oooooooooo`10ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0002oooooo0009ooooo`0400000?oo
ooooooooooooo`80<c<c00?o000004a<C01<C4`01`1<C4`00ol00000IVIV06IVIP0806IVIP030000
001oOgl0Ogmo00X0Ogmo0P00000?09VIV@03o`0000000000/k>c04D0/k>c00?o000009VIV@2IVIT0
3P2IVIT00`000000Ogmo07moO`0907moO`8000002P1VIVH00`000000C4a<04a<C00404a<C0Cooooo
00<00000ooooooooool0@Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo
1?l0000booooo`002Oooool01000003oooooooooooooool203<c<`03o`00001<C4`0C4a<00P0C4a<
00?o000006IVIP1VIVH0201VIVH00ol00000Ogmo07moO`0;07moO`030000002IVIT0VIVI00h0VIVI
0P0000120;>c/`<000003`2IVIT00`000000Ogmo07moO`0907moO`030000001VIVH0IVIV00X0IVIV
00<0000004a<C01<C4`0101<C4`4ooooo`0300000?oooooooooo04;ooooo0_l0000Cooooo`03o`00
0?oooooooooo03_ooooo1?l0000fooooo`002Oooool01000003oooooooooooooool303<c<`03o`00
001<C4`0C4a<00P0C4a<00?o000006IVIP1VIVH0201VIVH00`000000Ogmo07moO`0;07moO`030000
002IVIT0VIVI00l0VIVI0P00000n0;>c/`8000004@2IVIT00`000000Ogmo07moO`0907moO`030000
001VIVH0IVIV00X0IVIV00<0000004a<C01<C4`01@1<C4`4ooooo`0300000?oooooooooo04Cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0gooooo`Co0000>_ooool000Wooooo00@0
0000oooooooooooooooo0`0c<c<00ol00000C4a<04a<C00804a<C003o`00001VIVH0IVIV00T0IVIV
00<0000007moO`1oOgl02`1oOgl00`000000VIVI09VIV@0@09VIV@030000002c/k<0/k>c03X0/k>c
00<0000009VIV@2IVIT03`2IVIT2000000`0Ogmo00<0000006IVIP1VIVH02@1VIVH00`000000C4a<
04a<C00604a<C0Cooooo00<00000ooooooooool0AOooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03?ooooo1?l0000nooooo`002Oooool01000003oooooooooooooool403<c<`;o0000
2@1<C4`00ol00000IVIV06IVIP0906IVIP800000301oOgl200000100VIVI00?o0000000000000000
=P2c/k<300000003o`00002IVIT0VIVI00h0VIVI0P00000=07moO`030000001VIVH0IVIV00T0IVIV
00<0000004a<C01<C4`01`1<C4`01Ol0003oooooooooooooool0000004Sooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0`ooooo`?o0000@_ooool000Wooooo00@00000oooooooooooo
oooo1P0c<c<00ol00000C4a<04a<C00704a<C003o`00001VIVH0IVIV00X0IVIV00<0000007moO`1o
Ogl02`1oOgl200000140VIVI0`00000`0;>c/`<000004P2IVIT2000000h0Ogmo00<0000006IVIP1V
IVH02@1VIVH00`000000C4a<04a<C00804a<C005o`000?ooooooooooooooo`000000BOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l00015ooooo`002Oooool01000003o
ooooooooooooool703<c<`03o`00001<C4`0C4a<00L0C4a<00?o000006IVIP1VIVH02P1VIVH00`00
0000Ogmo07moO`0<07moO`030000002IVIT0VIVI0140VIVI1000000[0;>c/`030000002IVIT0VIVI
0180VIVI00<0000007moO`1oOgl0301oOgl2000000/0IVIV00<0000004a<C01<C4`0201<C4`00ol0
003oooooooooo`02ooooo`0300000?oooooooooo04Sooooo0_l0000=ooooo`03o`000?oooooooooo
02Sooooo1?l00019ooooo`002Oooool01000003oooooooooooooool703<c<`03o`00001<C4`0C4a<
00P0C4a<00?o000006IVIP1VIVH02P1VIVH00`000000Ogmo07moO`0<07moO`03o`00002IVIT0VIVI
01@0VIVI0`00000T0;>c/`@000004`2IVIT2000000h0Ogmo00<0000006IVIP1VIVH02@1VIVH00`00
003o000004a<C00904a<C003o`00000c<c?ooooo00?ooooo00<00000ooooooooool0B_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0001=ooooo`002Oooool01000003o
ooooooooooooool803<c<`03o`00001<C4`0C4a<00P0C4a<00?o000006IVIP1VIVH02P1VIVH00`00
0000Ogmo07moO`0<07moO`030000002IVIT0VIVI01H0VIVI1000000J0;>c/`H000005@2IVIT20000
0100Ogmo00<0000006IVIP1VIVH02@1VIVH00`000000C4a<04a<C00804a<C003o`00000c<c<0<c<c
00Cooooo00<00000ooooooooool0Boooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
027ooooo0ol0001Aooooo`002Oooool01000003oooooooooooooool903<c<`03o`00001<C4`0C4a<
00P0C4a<00?o000006IVIP1VIVH02P1VIVH00`000000Ogmo07moO`0<07moO`8000006P2IVIT70000
0100/k>c0`00000J09VIV@030000001oOgl0Ogmo00h0Ogmo0P00000;06IVIP030000001<C4`0C4a<
00T0C4a<00?o000003<c<`0c<c<01?ooool00`00003oooooooooo`1<ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0009ooooo`0400000?oooooooooooooo
o`X0<c<c00?o000004a<C01<C4`0201<C4`00ol00000IVIV06IVIP0:06IVIP030000001oOgl0Ogmo
00d0Ogmo0P00000O09VIVA000000702IVIT00`000000Ogmo07moO`0>07moO`030000001VIVH0IVIV
00X0IVIV00<0000004a<C01<C4`02@1<C4`01?l00000<c<c03<c<`0c<c<4ooooo`0300000?oooooo
oooo04gooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001Hooooo`002Oooool01@00
003ooooooooooooooooo000000T0<c<c00?o000004a<C01<C4`02@1<C4`00ol00000IVIV06IVIP0:
06IVIP03o`0000000000Ogmo00h0Ogmo0`00001509VIV@80000000?o000007moO`1oOgl03@1oOgl0
0`00003o000006IVIP0:06IVIP8000002P1<C4`2o`0000@0<c<c1?ooool00`00003oooooooooo`1?
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`0005cooooo0009oooo
o`0500000?ooooooooooooooool000002P0c<c<00ol00000C4a<04a<C00904a<C003o`00001VIVH0
IVIV00/0IVIV00<0000007moO`1oOgl03`1oOgl200000440VIVI0P00000A07moO`030000001VIVH0
IVIV00X0IVIV00<0000004a<C01<C4`02@1<C4`00ol00000<c<c03<c<`0403<c<`Cooooo00<00000
ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001P
ooooo`002Oooool01P00003oooooooooooooool06ATIo`0000X0<c<c00?o000004a<C01<C4`02@1<
C4`00ol00000IVIV06IVIP0;06IVIP8000004@1oOgl2000003d0VIVI0P00000B07moO`030000001V
IVH0IVIV00X0IVIV00<0000004a<C01<C4`02@1<C4`00ol00000<c<c03<c<`0503<c<`Cooooo00<0
0000ooooooooool0DOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0
001Sooooo`002Oooool01000003oooooooooooooool201TI6@03o`00000c<c<0<c<c00P0<c<c0_l0
000:04a<C003o`00001VIVH0IVIV00`0IVIV00<0000007moO`1oOgl0401oOgl3000003H0VIVI1000
000A07moO`80000000?o000006IVIP1VIVH02P1VIVH00`000000C4a<04a<C00904a<C003o`00000c
<c<0<c<c00H0<c<c1?ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0003ooooooooo
o`0:ooooo`Co0000Ioooool000Wooooo00@00000oooooooooooooooo0`0I6AT00ol00000<c<c03<c
<`0903<c<`03o`00001<C4`0C4a<00P0C4a<00?o000006IVIP1VIVH0301VIVH00ol00000000007mo
O`0B07moO`<00000<02IVIT3000001@0Ogmo00<0000006IVIP1VIVH0301VIVH00`000000C4a<04a<
C00904a<C003o`00000c<c<0<c<c00L0<c<c1?ooool00`00003oooooooooo`1Dooooo`04o`000?oo
ooooooooo`0000Sooooo1?l0001[ooooo`002Oooool01000003oooooooooooooool401TI6@03o`00
000c<c<0<c<c00T0<c<c00?o000004a<C01<C4`0201<C4`3o`0000d0IVIV0P00000D07moO`@00000
:`2IVIT00`000000Ogmo07moO`0C07moO`8000003P1VIVH00`000000C4a<04a<C00904a<C003o`00
000c<c<0<c<c00P0<c<c00Go0000oooooooooooooooo0000001Gooooo`03o`000?oooooo000000Go
oooo0ol0001_ooooo`002Oooool01000003oooooooooooooool501TI6@03o`00000c<c<0<c<c00T0
<c<c00?o000004a<C01<C4`02P1<C4`00ol00000IVIV06IVIP0<06IVIP0300000?l00000Ogmo01D0
Ogmo00@00000o`000000000000008@2IVIT6000001@0Ogmo00?o00000000001VIVH03@1VIVH00`00
003o000004a<C00:04a<C003o`00000c<c<0<c<c00P0<c<c00<00000ooooooooool00_ooool00`00
003oooooooooo`1Fooooo`;o000000?oooooo`000?l000000_l0001booooo`002Oooool01000003o
ooooooooooooool601TI6@03o`00000c<c<0<c<c00P0<c<c00?o000004a<C01<C4`02`1<C4`00ol0
0000IVIV06IVIP0=06IVIP030000001oOgl0Ogmo01L0Ogmo0`00000J09VIV@@00000601oOgl30000
00h0IVIV00<0000004a<C01<C4`02P1<C4`00ol00000<c<c03<c<`0903<c<`0300000?oooooooooo
00;ooooo00<00000ooooooooool0Eoooool2o`0007Kooooo0009ooooo`0400000?oooooooooooooo
o`L06ATI00?o000003<c<`0c<c<0200c<c<00ol00000C4a<04a<C00;04a<C003o`00001VIVH0IVIV
00d0IVIV0P00000J07moO`X000001P2IVIT:000001T0Ogmo0`00000?06IVIP800000301<C4`00ol0
0000<c<c03<c<`0903<c<`030000000I6AWooooo00?ooooo00<00000ooooooooool0coooool000Wo
oooo00@00000oooooooooooooooo200I6AT00ol00000<c<c03<c<`0803<c<`03o`00001<C4`0C4a<
00/0C4a<00?o000006IVIP1VIVH03P1VIVH200000280Ogmo1P00000R07moO`030000001VIVH0IVIV
00l0IVIV00<0000004a<C01<C4`02`1<C4`00ol00000<c<c03<c<`0903<c<`03o`00000I6AT06ATI
00Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo2@0I6AT00ol0
0000<c<c03<c<`0803<c<`?o00002`1<C4`3o`0000l0IVIV00<00000o`0000000000A01oOgl30000
00l0IVIV0P0000000ol00000C4a<04a<C00904a<C0?o00002P0c<c<2000000<06ATI1?ooool00`00
003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool:01TI6@03o`00000c<c<0<c<c
00X0<c<c00?o000004a<C01<C4`02`1<C4`00ol00000IVIV06IVIP0?06IVIP<00000?P1oOgl30000
0140IVIV00<0000004a<C01<C4`02`1<C4`00ol00000<c<c03<c<`0:03<c<`030000000I6AT06ATI
00<06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01@00003ooooooooooooooooo0000
00X06ATI00?o000003<c<`0c<c<02P0c<c<00ol00000C4a<04a<C00;04a<C0;o00004P1VIVH40000
03T0Ogmo00<0000006IVIP1VIVH0401VIVH2000000d0C4a<00?o000003<c<`0c<c<02P0c<c<00ol0
00006ATI01TI6@0401TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00H00000oooooooo
oooooooo00000?l0000:01TI6@;o00002`0c<c<00ol00000C4a<04a<C00<04a<C003o`00001VIVH0
IVIV01<0IVIV00<0000007moO`1oOgl0<P1oOgl01?l00000000000000000000A06IVIP8000003@1<
C4`2o`0000`0<c<c00<0000001TI6@0I6AT01@0I6AT4ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0600000?ooooooooooooooo`00003o0000300I6AT00ol00000<c<c03<c<`0903<c<`03o`00
001<C4`0C4a<00`0C4a<0_l0000C06IVIP03o`000000000000000300Ogmo0P00000C06IVIP800000
3P1<C4`00ol00000<c<c03<c<`0;03<c<`030000000I6AT06ATI00H06ATI1?ooool00`00003ooooo
ooooo`3?ooooo`002Oooool01000003oooooooooooooool200000003o`00000I6AT06ATI00X06ATI
00?o000003<c<`0c<c<02@0c<c<2o`0000h0C4a<0_l0000D06IVIPL000009@1oOgl4000001@0IVIV
00<0000004a<C01<C4`03@1<C4`00ol00000<c<c03<c<`0;03<c<`030000000I6AT06ATI00L06ATI
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool300000003o`00
000I6AT06ATI00X06ATI00?o000003<c<`0c<c<02P0c<c<00ol00000C4a<04a<C00=04a<C0;o0000
6@1VIVH4000001X0Ogmo1`00000F06IVIP8000003`1<C4`00ol00000<c<c03<c<`0;03<c<`030000
000I6AT06ATI00P06ATI00Go0000oooooooooooooooo0000003Aooooo`002Oooool01000003ooooo
ooooooooool4000000;o00002`0I6AT00ol00000<c<c03<c<`0:03<c<`?o00003P1<C4`3o`0001X0
IVIV600000000ol00000000006IVIP0J06IVIP800000401<C4`00ol00000<c<c03<c<`0:03<c<`80
00002P0I6AT2o`0000?ooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooo
oooo1P0000000ol000006ATI01TI6@0901TI6@03o`00000c<c<0<c<c00`0<c<c00?o000004a<C01<
C4`03P1<C4`2o`0004/0IVIV0P00000@04a<C0;o00002`0c<c<2000000/06ATI00?o000000000?oo
ool00oooool00`00003oooooooooo`3?ooooo`002Oooool01000003oooooooooooooool700000003
o`00000I6AT06ATI00T06ATI00?o000003<c<`0c<c<0300c<c<2o`000100C4a<0ol0001406IVIP@0
0000401<C4`2o`0000`0<c<c00<0000001TI6@0I6AT02P0I6AT00ol00000000000000004ooooo`03
00000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`P0000000?o000001TI6@0I
6AT02@0I6AT2o`0000h0<c<c00?o000004a<C01<C4`0401<C4`2o`000400IVIV00?o00000000001<
C4`04@1<C4`2o`0000d0<c<c00?o000001TI6@0I6AT02P0I6AT01?l000000000000000000004oooo
o`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool0coooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009oooookH00000dOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool000Wooooo]_l0000AoooookKo00002_ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool04?ooool2o`00oa7ooooo00<0003o
ooooooooool0GOooool3o`00ob7ooooo00?o003oooooooooool02?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`0:
ooooo`03o`000?oooooooooo00cooooo0P00000Dooooo`800000=Oooool3000001?ooooo0P00000>
ooooo`03o`000000003ooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0>ooooo`;o003o00?oooooo`00ooooool04?ooool00`00
0?ooooooooooo`1Oooooo`?o003o7oooool00ol00?ooooooooooo`08ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo
00Wooooo00<00000o`000?ooool02oooool3000001;ooooo1000000jooooo`<000004_ooool20000
00kooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo00cooooo0_l00?l2ooooo`03o`00oooooooooooo00oo
oooo00<0003oooooooooool0HOooool4o`00oakooooo00?o003oooooooooool01oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool04?ooool30000047o
oooo0P00000Booooo`8000003Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02oooool01Ol00?oooooo
oooooooooooo003o017ooooo00<0003oooooooooool0I?ooool00ol00?ooooooo`00o`0Nooooo`03
o`00oooooooooooo00Kooooo00?o0000ooooooooool03oooool01Ol0003oooooooooooooool00000
00[ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo
013ooooo00<00000ooooooooool0A?ooool2000001;ooooo00<00000ooooooooool02oooool00`00
003oooooooooo`09ooooo`0500000?ooooooooooooooool000002_ooool000Wooooo00?o0000oooo
ooooool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00oooooo00<0003ooooo
ooooool0IOooool01?l00?ooooooo`00ool00?lLooooo`03o`00oooooooooooo00Kooooo00?o0000
ooooooooool03oooool01?l0003oooooooooo`00000:ooooo`0300000?oooooooooo00Wooooo00<0
0000o`000?ooool02oooool00`00003o0000ooooo`0>ooooo`<00000BOooool3000000oooooo00?o
000000000?ooool02oooool00ol000000000ooooo`0:ooooo`0400000?ooooooooooo`0000[ooooo
0009ooooo`03o`000?oooooooooo00Oooooo0ol00?l4ooooo`03o`00oooooooooooo00oooooo00<0
003oooooooooool0Ioooool2o`00o`03ooooool00?oo003o01_ooooo00?o003oooooooooool01Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool02?oo
ool2000000cooooo0P00000>ooooo`<000007?oooolG000001cooooo0`00000>ooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool02Oooool00ol0003oooooo`00000:ooooo`002Oooool0
0ol0003oooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool0
0`000?ooooooooooo`1Yooooo`03o`00oooooooooooo00;o003o6Oooool00ol00?ooooooooooo`05
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`08
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0G
ooooo`H000005oooool7000001Sooooo00<00000ooooooooool03?ooool2000000cooooo00<00000
ooooooooool02_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03oooool00`000?ooooooooooo`1[oooo
o`04o`00ooooooooooooooooo`;o003o6?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02?ooool00`00003oooooooooo`08ooooo`03o`000?oooooo
oooo00[ooooo00<00000o`000?ooool03?ooool00`00003o00000000000Fooooo`0400000?l00000
0000000002Cooooo0`00000Fooooo`8000003_ooool2000000_ooooo00?o000000000?ooool02Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`03ooooo`;o003o2?ooool0
0ol00?ooooooooooo`0>ooooo`030000oooooooooooo06gooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`07ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02Oooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo01?ooooo1000000[ooooo`@000005?ooool2
000000kooooo00<00000ooooooooool02_ooool00`00003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`04o`000?ooooooooooooooo`;o003o2Oooool00ol00?ooooooooooo`0>
ooooo`030000oooooooooooo06oooooo0_l00?l3ooooo`03o`00oooooooooooo01Gooooo00?o003o
ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00<00000
ooooooooool02Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00cooooo00<00000
ooooooooool04Oooool3000003?ooooo0P00000Dooooo`0300000?oooooooooo00cooooo00<00000
ooooooooool02_ooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`04o`000?ooooooooooo`00o`_ooooo00?o003oooooooooool03_ooool00`000?ooooooooooo`1a
ooooo`03o`00oooooooooooo00;o003o5_ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`09ooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0Aooooo`0300000?oooooo
oooo03Kooooo0P00000Cooooo`0300000?oooooooooo00cooooo00<00000ooooooooool02Oooool0
0`00003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo003o
00_ooooo00?o003oooooooooool03_ooool00`000?ooooooooooo`1cooooo`04o`00oooooooooooo
ooooo`;o003o5Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool00`00003oooooooooo`08ooooo`0300000?l0003ooooo00Wooooo00?o0000
00000?ooool02oooool30000017ooooo0`00000kooooo`<000004Oooool00`00003o00000000000<
ooooo`8000002_ooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00[ooooo00?o003oooooooooool03oooool00`000?ooooooooooo`1doooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool04_ooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00`00003oooooooooo`08oooo
o`0300000?oooooooooo00Wooooo00<00000ooooooooool02oooool00`00003oooooooooo`0?oooo
o`<00000@Oooool2000001;ooooo00<00000ooooooooool02oooool00`00003oooooooooo`08oooo
o`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool02_ooool00ol00?ooooooooooo`0>ooooo`030000oooooooooooo07Kooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo00;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Sooooo00<00000oooooooo
ool02Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0A?ooool20000017ooooo00<00000ooooooooool02oooool00`00003oooooooooo`08ooooo`03
00000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
2Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo07Sooooo0_l00?l3ooooo`03o`00
oooooooooooo017ooooo00Go003oooooooooooooooooo`00000Aooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo0P00000?oooo
o`0300000?l00000000004Wooooo00?o00000000000000003oooool00`00003oooooooooo`0;oooo
o`0300000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00kooooo00<0003ooooooooo
ool0N_ooool01Ol00?oooooooooooooooooo003o01;ooooo00Go003oooooooooooooooooo`00000A
ooooo`05o`000?ooooooooooooooo`0000002_ooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0JoooooaL000007?oo
ool00`00003oooooooooo`0=ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02Ooo
ool01@00003ooooooooooooooooo000000[ooooo0009ooooo`03o`000?oooooooooo00Sooooo00?o
003oooooooooool03_ooool00`000?ooooooooooo`1looooo`05o`00ooooooooooooooooool00?l0
4_ooool01?l00?ooooooooooool0000Aooooo`04o`000?oooooooooo000000[ooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00gooooo0P00000Foooo
o`L000005oooool7000001Kooooo0P00000>ooooo`0300000?oooooooooo00[ooooo00<00000oooo
ooooool02Oooool01000003oooooooooool0000:ooooo`002Oooool00ol0003oooooooooo`08oooo
o`03o`00oooooooooooo00kooooo00<0003oooooooooool0OOooool01Ol00?oooooooooooooooooo
003o017ooooo00Co003ooooooooooooo00004Oooool00ol0003ooooo0000000:ooooo`0300000?oo
oooooooo00Sooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0<ooooo`8000005_oo
ool00ol000000000ooooo`0Tooooo`8000005_ooool00`00003oooooooooo`0<ooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool02Oooool00`00003oooooo`00000:ooooo`002Oooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo00oooooo00<0003oooooooooool0OOooool0
0ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00oooooo00?o003oooooool000004Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00<00000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`8000005?ooool300000003o`000?oooooooooo02Oooooo1000000C
ooooo`8000003Oooool00ol000000000ooooo`0:ooooo`0300000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`0>oooo
o`030000oooooooooooo07oooooo00?o003oooooooooool00_ooool2o`00oa7ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000oooo
ooooool02_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01;ooooo0P00000aoooo
o`0300000?oooooooooo01;ooooo0P00000=ooooo`0300000?oooooooooo00Wooooo00<00000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`07ooooo`03
o`00oooooooooooo00kooooo00<0003oooooooooool0P?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03
00000?oooooooooo00Sooooo00<00000ooooooooool02Oooool2000000cooooo0P00000Cooooo`80
0000=?ooool3000001?ooooo00?o0000ooooooooool02oooool00`00003oooooooooo`09ooooo`03
00000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
1_ooool00ol00?ooooooooooo`0>ooooo`030000oooooooooooo08;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1_ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0
2oooool00`00003oooooooooo`0?ooooo`0400000?l000000000000003Wooooo0`00000Aooooo`03
00000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo00?o003oooooooooool0
3Oooool00`000?ooooooooooo`24ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
3?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`0nooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0
2oooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`03o`00oooo
oooooooo08Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0;ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00Sooooo00<00000ooooooooool02oooool00`00003oooooooooo`0>ooooo`800000@_oo
ool20000013ooooo00<00000ooooooooool02oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool0
0ol00?ooooooooooo`0>ooooo`030000oooooooooooo08Gooooo00?o003oooooooooool01?ooool0
0ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`0>ooooo`0300000?oooooooooo04Cooooo0P00000?ooooo`0300000?oooooo
oooo00_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`05ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool03Oooool00`00
0?ooooooooooo`27ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool02Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`08ooooo`0300000?oooooooooo00[ooooo00?o000000000?ooool03Oooool00`00
003o00000000000Pooooo`T000008?ooool2000000kooooo0P00000<ooooo`0300000?oooooooooo
00Sooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo00kooooo00<0003oooooooooool0R?ooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool06_ooool7000000Wo
oooo1`00000Kooooo`8000003_ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`04ooooo`03o`00oooooooooooo00kooooo00<0003oooooooooool0ROooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?ooool2000000_ooooo
00<00000ooooooooool03?ooool2000001Oooooo1P00000Gooooo`<000006_ooool00ol0003ooooo
ooooo`0<ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Cooooo00?o
003oooooooooool03Oooool00`000?ooooooooooo`0eoooooaT0okK1?Oooool00ol00?oooooooooo
o`03ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool03oooool01Ol0003ooooooooo
ooooool0000000Wooooo00<00000ooooooooool02?ooool00`00003oooooooooo`0:ooooo`030000
0?oooooooooo00_ooooo0P00000Eooooo`0400000?l000000000000001T0okK11oooool300000003
o`000?oooooooooo01Gooooo00<00000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00D00000ooooooooooooooooo`00000:ooooo`002Oooool00ol0003o
ooooooooo`04ooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool0<_oooolO0?nf`C[o
oooo00?o003oooooooooool00oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00Go0000oooooooooooooooo00000009ooooo`0300000?oooooooooo00Sooooo00<00000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`0300000?oooooooooo01Cooooo00<00000oooo
o`3o]/407P3o]/48ooooo`<000005Oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo
00Wooooo00<00000ooooooooool02?ooool01@00003ooooooooooooooooo000000[ooooo0009oooo
o`03o`000?oooooooooo00Cooooo00?o003oooooooooool03?ooool00`000?ooooooooooo`0`oooo
obD0okK1>?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool03oooool01?l0003oooooooooo`000009ooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool02Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo01;ooooo0`00000T
0?nf`@Sooooo0`00000Cooooo`0300000?oooooooooo00cooooo00<00000ooooooooool02Oooool0
0`00003oooooooooo`08ooooo`0400000?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooo
oooo00?ooooo00?o003oooooooooool03Oooool00`000?ooooooooooo`0]ooooob/0okK1=_ooool0
0ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooo`000009ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02Ooo
ool00`00003oooooooooo`0;ooooo`0300000?oooooooooo017ooooo0P00000Z0?nf`@Sooooo00<0
0000ooooooooool04Oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool02?ooool01000003oooooooooool0000:ooooo`002Oooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo00gooooo00<0003oooooooooool0:_oooola0?nf`CCooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooo`0000002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00<0
0000ooooooooool02_ooool2000001;ooooo00<00000o`00003o]/40;P3o]/46ooooo`04o`000000
000000000000013ooooo0P00000=ooooo`03o`000?oooooooooo00Sooooo00<00000o`000?ooool0
2?ooool00`00003oooooo`00000:ooooo`002Oooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo00gooooo00<0003oooooooooool0:?oooolg0?nf`C;ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02_oo
ool00`00003oooooooooo`0?ooooo`030?nf`@000000000003@0okK11oooool20000013ooooo00<0
0000ooooooooool02oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Wooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0=
ooooo`03o`00oooooooooooo02Gooooo>`3o]/4booooo`03o`00oooooooooooo00?ooooo00?o003o
ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00<00000
ooooooooool02?ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00[ooooo00<00000
ooooooooool03Oooool20?nf`@800000=`3o]/48ooooo`0300000?oooooooooo00kooooo00<00000
ooooooooool02oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0=oooo
o`030000oooooooooooo02Cooooo?@3o]/4aooooo`03o`00oooooooooooo00Cooooo00Go003ooooo
ooooooooooooo`00000Aooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool02?ooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo00[ooooo00<00000o`000?ooool03Oooool2
0?nf`@030000003o]/40okK103P0okK12?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00_ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`05o`000?ooooooooooooooool00?l03oooool00`000?ooooooooooo`0S
oooood80okK1;oooool00ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00017ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00<0
0000ooooooooool02_ooool00`00003oooooooooo`0;ooooo`<0okK100<000000?nf`@3o]/40?03o
]/45ooooo`8000004?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooo
oooo003o00kooooo00<0003oooooooooool08_oooom60?nf`Bkooooo00?o003oooooooooool01?oo
ool00ol00?ooooooo`00000Aooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01ooo
ool00`00003oooooooooo`08ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02_oo
ool40?nf`@030000003o]/40okK103l0okK11Oooool2000000oooooo00<00000ooooooooool02_oo
ool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?oo
ool000Wooooo00Go0000ooooooooooooooooo`00o`0>ooooo`030000oooooooooooo027oooooB03o
]/4]ooooo`03o`00oooooooooooo00Cooooo00?o003oooooool000004Oooool00ol0003ooooooooo
o`05ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`0:ooooo`0300000?oooooooooo00[ooooo0`3o]/42000001d0okK13`00000G0?nf`@Kooooo00?o
0000ooooooooool03Oooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00<0
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool01Ol0003ooooooooooooo
oooo003o00kooooo00<0003oooooooooool08?oooom:0?nf`Bgooooo00?o003oooooooooool01Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool01ooo
ool00`00003oooooooooo`08ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool02_oo
ool20?nf`@800000603o]/44000000;o000000<000000?nf`@3o]/403@3o]/44000001@0okK11_oo
ool2000000kooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00Co0000oooooooooooo003o3_oo
ool00`000?ooooooooooo`0Poooood`0okK1;?ooool00ol00?ooooooooooo`05ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo00Sooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`80okK100<0
00000?nf`@3o]/405@3o]/43000001X0okK10`00000B0?nf`@Oooooo00<00000ooooooooool03?oo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool01?l0003oooooooooool00?l>ooooo`030000oooo
oooooooo01koooooD03o]/4[ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?oo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo0`3o]/400`000000okK10?nf
`@0D0?nf`@800000803o]/4400000100okK11_ooool00ol0003oooooooooo`0;ooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool01oooool00`00003oooooooooo`04ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`04o`000?ooooooooooo`00o`kooooo00<0003oooooooooool07Ooo
oomB0?nf`B_ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo00<00000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00<00000ooooooooool02Oooool30?nf`@030000003o]/40okK10180okK100<0
0000o`00000000009P3o]/400ol0000000000000000>0?nf`@Kooooo00<00000ooooooooool02ooo
ool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`002Oooool01?l0003oooooooooool00?l>ooooo`030000oooo
oooooooo01coooooE03o]/4Zooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?oo
ool00`00003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo0`3o]/400`000000okK10?nf
`@0A0?nf`@800000;03o]/400`000000okK10?nf`@0<0?nf`@Gooooo00<00000ooooooooool02ooo
ool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`002Oooool01?l0003oooooooooool00?l>ooooo`030000oooo
oooooooo01_oooooEP3o]/4Zooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02?oo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo0`3o]/400`000000okK10?nf
`@0@0?nf`@800000;`3o]/42000000d0okK11Oooool00`00003oooooooooo`0;ooooo`0300000?oo
oooooooo00Wooooo00<00000ooooooooool01oooool00`00003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooo003o00kooooo00<0003oooooooooool06ooooomH
0?nf`B[ooooo00Go003oooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooo`000000
2Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
2?ooool30?nf`@030000003o]/40okK10100okK100<000000?nf`@3o]/40<@3o]/400`000000okK1
0?nf`@0;0?nf`@Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`030000
0?oooooooooo00Oooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooo`00o`0>ooooo`030000oooooooooooo01[oooooFP3o]/4Yooooo`05o`00oooo
ooooooooooooool000004Oooool01Ol0003oooooooooooooool0000000Sooooo00<00000oooooooo
ool02?ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo0`3o]/400`000000
okK10?nf`@0@0?nf`@03o`00003o]/40okK103<0okK10P00000<0?nf`@Gooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Oooooo00D00000oooooooo
ooooooooo`00000:ooooo`002Oooool00ol0003oooooo`00o`0>ooooo`030000oooooooooooo01Wo
ooooF`3o]/4Zooooo`04o`00ooooooooooooo`00017ooooo00Go0000oooooooooooooooo00000008
ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`07
ooooo`<0okK100?o00000?nf`@3o]/40403o]/400`000000okK10?nf`@0f0?nf`@030000003o]/40
okK100T0okK11_ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Wooooo00<00000
ooooooooool01oooool01@00003ooooooooooooooooo000000[ooooo0009ooooo`03o`000?oooooo
003o00kooooo00<0003oooooooooool06OoooomL0?nf`BWooooo00Co003ooooooooooooo00004Ooo
ool01?l0003oooooooooo`000009ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
2?ooool00`00003oooooooooo`08ooooo`<0okK100<000000?nf`@3o]/403`3o]/400`000000okK1
0?nf`@0h0?nf`@030000003o]/40okK100T0okK11_ooool00`00003oooooooooo`0:ooooo`030000
0?oooooooooo00Sooooo00<00000ooooooooool02?ooool01000003oooooooooool0000:ooooo`00
2Oooool00ol0003oooooo`00o`0>ooooo`030000oooooooooooo01SoooooGP3o]/4Yooooo`03o`00
oooooooo0000017ooooo00Co0000ooooooooool000002Oooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo00Wooooo00<00000ooooooooool01oooool30?nf`@030000003o]/40okK100l0
okK100<000000?nf`@3o]/40>P3o]/400ol00000okK10?nf`@090?nf`@Kooooo00?o0000oooooooo
ool02Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Oooooo00@00000oooooooo
oooo00002_ooool000Wooooo00?o0000ooooool00?l03Oooool00`000?ooooooooooo`0Hooooof00
okK1:_ooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0000000Wooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo0`3o]/400`000000
okK10?nf`@0>0?nf`@800000?P3o]/400`000000okK10?nf`@090?nf`@Gooooo00<00000oooooooo
ool02_ooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000ooooool0
00002_ooool000Wooooo00?o0000ooooooooool03Oooool00`000?ooooooooooo`0Gooooof80okK1
:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Kooooo0`3o]/400`000000okK1
0?nf`@0>0?nf`@030000003o]/40okK103l0okK100<000000?nf`@3o]/402@3o]/44ooooo`030000
0?oooooooooo00_ooooo00<00000ooooooooool01oooool00`00003oooooooooo`08ooooo`03o`00
0?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo00gooooo00<0003oooooooooool05_oo
oomS0?nf`BWooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool02?ooool00`00003oooooooooo`06ooooo`<0okK100<0
00000?nf`@3o]/403P3o]/400`000000okK10?nf`@110?nf`@03o`00003o]/40okK100P0okK11Ooo
ool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0=ooooo`030000oooooooo
oooo01KoooooI03o]/4Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01oooool3
0?nf`@03o`00003o]/40okK100d0okK100<000000?nf`@3o]/40@`3o]/400`000000okK10?nf`@08
0?nf`@Gooooo00?o0000ooooooooool02_ooool00`00003oooooooooo`08ooooo`0300000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03?ooool00`00
0?ooooooooooo`0FooooofH0okK19oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Oooooo00<00000ooooooooool01oooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo
00Kooooo103o]/400`000000okK10?nf`@0<0?nf`@03o`00003o]/40okK104D0okK100<000000?nf
`@3o]/40203o]/45ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00co
oooo00<0003oooooooooool05OoooomW0?nf`BOooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`06ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003o
ooooooooo`06ooooo`@0okK100<000000?nf`@3o]/403@3o]/400`000000okK10?nf`@0K0?nf`@l0
0000703o]/400`000000okK10?nf`@070?nf`@Gooooo00<00000ooooooooool02_ooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool03?ooool00`000?ooooooooooo`0EooooofP0okK19_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo00Kooooo0`3o]/400`000000okK10?nf`@0=0?nf`@030000
003o]/40okK101T0okK10`00000?0?nf`@0300000?l00000okK101X0okK100?o00000?nf`@3o]/40
1`3o]/45ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00cooooo00<0
003oooooooooool05?oooomY0?nf`BKooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`06ooooo`<0okK100<000000?nf`@3o]/403@3o]/400`000000okK10?nf`@0F0?nf`@0400000?l0
00000000000001@0okK10P00000I0?nf`@030000003o]/40okK100L0okK11Oooool00`00003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0<ooooo`030000oooooooooooo01CoooooJP3o
]/4Uooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00`00003ooooooooo
o`07ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01_ooool30?nf`@03o`00003o
]/40okK100`0okK100<000000?nf`@3o]/40503o]/43000001X0okK10P00000H0?nf`@030000003o
]/40okK100L0okK11?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0;
ooooo`030000oooooooooooo01CoooooK03o]/4Tooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000
ooooooooool01_ooool40?nf`@030000003o]/40okK100/0okK100<000000?nf`@3o]/40503o]/40
0`000000okK10?nf`@0M0?nf`@8000005`3o]/400`000000okK10?nf`@070?nf`@Cooooo00<00000
ooooooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool02oooool00`000?ooooooooooo`0Coooo
ofd0okK19?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00<00000oooo
ooooool01_ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Gooooo103o]/400`00
0000okK10?nf`@0;0?nf`@03o`00003o]/40okK101@0okK100<000000?nf`@3o]/40803o]/400ol0
000000000?nf`@0E0?nf`@030000003o]/40okK100H0okK11Oooool00ol0003oooooooooo`09oooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`0;ooooo`030000oooooooooooo01?oooooKP3o]/4Sooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`06ooooo`03
00000?oooooooooo00Sooooo00<00000ooooooooool01Oooool40?nf`@030000003o]/40okK100/0
okK100<000000?nf`@3o]/404`3o]/400ol00000okK10?nf`@0S0?nf`@030000003o]/40okK101<0
okK100<000000?nf`@3o]/401`3o]/45ooooo`0300000?oooooooooo00Sooooo00<00000oooooooo
ool02?ooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo00_ooooo00<0003oooooooooool04_oooom_0?nf`B?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`05ooooo`@0okK100<000000?nf`@3o]/402`3o]/400`000000okK1
0?nf`@0C0?nf`@030000003o]/40okK102D0okK100<000000?nf`@3o]/404`3o]/400`000000okK1
0?nf`@060?nf`@Gooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08ooooo`030000
0?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02ooo
ool00`000?ooooooooooo`0Booooog00okK18_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00Gooooo103o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK10180okK100<0
00000?nf`@3o]/409`3o]/400`000000okK10?nf`@0B0?nf`@030000003o]/40okK100L0okK11Ooo
ool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0;ooooo`030000oooooooo
oooo017ooooo703o]/43o`0003`0okK10ol0000D0?nf`B7ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`04ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`@0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@0B
0?nf`@030000003o]/40okK102T0okK100<000000?nf`@3o]/404P3o]/400`000000okK10?nf`@07
0?nf`@Cooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08ooooo`0300000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02oooool00`00
0?ooooooooooo`0@oooooa`0okK11Ol0000j0?nf`@Go00004`3o]/4Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo
00Oooooo00<00000ooooooooool01?ooool50?nf`@030000003o]/40okK100X0okK100?o00000?nf
`@3o]/404P3o]/400`000000okK10?nf`@0[0?nf`@030000003o]/40okK10140okK100<000000?nf
`@3o]/401`3o]/44ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00_o
oooo00<0003oooooooooool04?oooolL0?nf`@Go0000>P3o]/45o`0001@0okK18?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool01_ooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo00Gooooo103o]/400`000000okK10?nf`@0;0?nf`@03
0000003o]/40okK10140okK100<000000?nf`@3o]/40;@3o]/400ol00000okK10?nf`@0A0?nf`@03
0000003o]/40okK100L0okK11?ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Oo
oooo00<00000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`0;ooooo`030000oooooooooooo00oooooo7@3o]/45o`0003X0okK11Ol0000D0?nf`B3ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool01oooool00`00003oooooooooo`04ooooo`D0okK100?o00000?nf`@3o]/40
2P3o]/400`000000okK10?nf`@0A0?nf`@030000003o]/40okK102l0okK100<000000?nf`@3o]/40
403o]/400`000000okK10?nf`@070?nf`@Cooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool02oooool00`000?ooooooooooo`0?oooooah0okK10ol0000F0?nf`@L0oooo7`3o
]/43o`0001D0okK18?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Cooooo1@3o
]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK10100okK100?o00000?nf`@3o]/403`3o
]/470?oooaX0okK100<000000?nf`@3o]/40403o]/400`000000okK10?nf`@070?nf`@Cooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool02oooool00`000?ooooooooooo`0?
oooooc<0okK13`3ooold0?nf`Aoooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01oooool00`00003oooooooooo`04
ooooo`D0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0@0?nf`@030000003o]/40
okK100/0okK13`3ooolG0?nf`@030000003o]/40okK10100okK100<000000?nf`@3o]/401`3o]/43
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01_ooool00`00003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00_ooooo00<0003ooooo
ooooool03_oooolb0?nf`A<0oooo<P3o]/4Oooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool01?ooool50?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/40403o]/400`00
0000okK10?nf`@0:0?nf`A<0oooo5@3o]/400`000000okK10?nf`@0@0?nf`@03o`00003o]/40okK1
00L0okK11?ooool00`00003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00<00000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0;ooooo`03
0000oooooooooooo00kooooo<03o]/4G0?oooc00okK17oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo00<00000ooooooooool01_ooool00`00003oooooooooo`07ooooo`03
00000?oooooooooo00Cooooo1@3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK100l0
okK100<000000?nf`@3o]/402@3o]/4G0?oooa@0okK100<000000?nf`@3o]/403`3o]/400`000000
okK10?nf`@070?nf`@Cooooo00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`03
00000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
2oooool00`000?ooooooooooo`0>ooooobl0okK16P3oool_0?nf`Akooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`04ooooo`D0okK100<000000?nf`@3o]/402P3o]/400`000000okK1
0?nf`@0?0?nf`@030000003o]/40okK100P0okK16P3ooolB0?nf`@030000003o]/40okK100l0okK1
00<000000?nf`@3o]/40203o]/43ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo00_ooooo00<0003oooooooooool03Oooool_0?nf`A`0oooo8@3o]/43o`0000X0okK17_oo
ool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooo`0000002Oooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00?ooooo1@3o]/400`000000okK10?nf`@0:0?nf`@030000
003o]/40okK100l0okK100<000000?nf`@3o]/40203o]/4L0?oooa80okK100<000000?nf`@3o]/40
3`3o]/400`000000okK10?nf`@070?nf`@?ooooo00?o0000ooooooooool02Oooool00`00003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool02oooool00`000?ooooooooooo`0=ooooobh0okK17P3ooolO0?nf`@Go00002@3o
]/4Nooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooooooo00000009ooooo`030000
0?oooooooooo00Oooooo00<00000ooooooooool00oooool50?nf`@030000003o]/40okK100X0okK1
00<000000?nf`@3o]/403`3o]/400`000000okK10?nf`@070?nf`Ah0oooo4P3o]/400`000000okK1
0?nf`@0>0?nf`@030000003o]/40okK100L0okK10oooool00`00003oooooooooo`09ooooo`030000
0?oooooooooo00Oooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0;ooooo`030000oooooooooooo00gooooo;@3o]/4P0?oooah0okK11Ol0
00090?nf`Akooooo00?o0000ooooooooool03oooool01Ol0003oooooooooooooool0000000Wooooo
00<00000ooooooooool01oooool00`00003oooooooooo`03ooooo`D0okK100<000000?nf`@3o]/40
2P3o]/400`000000okK10?nf`@0?0?nf`@030000003o]/40okK100H0okK1803ooolA0?nf`@030000
003o]/40okK100h0okK100<000000?nf`@3o]/401`3o]/43ooooo`0300000?oooooooooo00Wooooo
00<00000ooooooooool01oooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00_ooooo00<0003oooooooooool03Oooool]0?nf`B00oooo7P3o
]/45o`0000T0okK17_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooo`000000
2Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00?ooooo1@3o]/400`000000okK1
0?nf`@0:0?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o]/401`3o]/4P0?oooa40okK1
00<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@070?nf`@?ooooo00<00000ooooooooool0
2Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool02oooool00`000?ooooooooooo`0=ooooob/0okK18`3o
oolN0?nf`@?o00002P3o]/4Nooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooooooo
00000008ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool01?ooool40?nf`@030000
003o]/40okK100X0okK100<000000?nf`@3o]/403`3o]/400`000000okK10?nf`@050?nf`B<0oooo
4@3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK100H0okK11?ooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0;ooooo`030000oooooooooooo00gooooo:P3o
]/4U0?ooob/0okK17Oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooo`000000
2?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Cooooo103o]/400`000000okK1
0?nf`@0:0?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o]/401@3o]/4U0?oooa00okK1
00<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@070?nf`@?ooooo00<00000ooooooooool0
2?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool02oooool00`000?ooooooooooo`0<ooooob/0okK19@3o
ool[0?nf`Agooooo00?o0000ooooooooool03oooool01Ol0003oooooooooooooool0000000Sooooo
00<00000ooooooooool01oooool00`00003oooooooooo`03ooooo`D0okK100<000000?nf`@3o]/40
2P3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK100D0okK19@3oool@0?nf`@030000
003o]/40okK100h0okK100<000000?nf`@3o]/401`3o]/43ooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool01oooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00_ooooo00<0003oooooooooool03?oooolZ0?nf`BL0oooo:P3o
]/4Mooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooooooo00000008ooooo`030000
0?oooooooooo00Oooooo00<00000ooooooooool00oooool50?nf`@030000003o]/40okK100X0okK1
00<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@040?nf`BL0oooo3`3o]/400`000000okK1
0?nf`@0>0?nf`@030000003o]/40okK100L0okK10oooool00`00003oooooooooo`08ooooo`030000
0?oooooooooo00Oooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0;ooooo`030000oooooooooooo00cooooo:P3o]/4W0?ooobX0okK17Ooo
ool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooo`0000002?ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00?ooooo1@3o]/400`000000okK10?nf`@0:0?nf`@030000
003o]/40okK100h0okK100<000000?nf`@3o]/40103o]/4W0?ooo`l0okK100<000000?nf`@3o]/40
3P3o]/400`000000okK10?nf`@070?nf`@?ooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`07ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooool00?l02oooool00`000?ooooooooooo`0<ooooobT0okK1:@3ooolY0?nf`Agooooo00?o
0000ooooooooool03oooool01Ol0003oooooooooooooool0000000Sooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`03ooooo`D0okK100?o00000?nf`@3o]/402P3o]/400`000000okK1
0?nf`@0>0?nf`@030000003o]/40okK100<0okK1:@3oool>0?nf`@030000003o]/40okK100h0okK1
00<000000?nf`@3o]/401`3o]/43ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
1oooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooo003o00_ooooo00<0003oooooooooool03?oooolY0?nf`BT0oooo:@3o]/4Mooooo`03o`000?oo
oooooooo00oooooo00Go0000oooooooooooooooo00000008ooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool00oooool50?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/40
3P3o]/400`000000okK10?nf`@030?nf`BT0oooo3P3o]/400`000000okK10?nf`@0>0?nf`@030000
003o]/40okK100L0okK10oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooo`00
o`0;ooooo`030000oooooooooooo00cooooo:@3o]/4Y0?ooobT0okK17Oooool00ol0003ooooooooo
o`0?ooooo`05o`000?ooooooooooooooo`0000002?ooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo00?ooooo1@3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100h0okK1
00<000000?nf`@3o]/40103o]/4Y0?ooo`h0okK100<000000?nf`@3o]/403P3o]/400`000000okK1
0?nf`@070?nf`@?ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooool00?l02ooo
ool00`000?ooooooooooo`0<ooooobT0okK1:@3ooolY0?nf`Agooooo00?o0000ooooooooool03ooo
ool01Ol0003oooooooooooooool0000000Sooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`03ooooo`D0okK100<000000?nf`@3o]/402@3o]/400`000000okK10?nf`@0>0?nf`@030000
003o]/40okK100@0okK1:@3oool>0?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o]/40
1`3o]/43ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo003o00_ooooo00<0
003oooooooooool03?oooolX0?nf`B/0oooo:03o]/4Mooooo`03o`000?oooooooooo00oooooo00Go
0000oooooooooooooooo00000008ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
0oooool50?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/403P3o]/400`000000okK1
0?nf`@030?nf`B/0oooo3@3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK100L0okK1
0oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`002Oooool01?l0003oooooooooool00?l:ooooo`030000
oooooooooooo00cooooo:03o]/4[0?ooobP0okK17Oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooo`0000002?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00?o
oooo1@3o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o
]/400`3o]/4[0?ooo`d0okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@070?nf`@?o
oooo00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool000Wooooo00Co0000oooooooooooo003o2_ooool00`000?oo
ooooooooo`0;ooooobT0okK1:`3ooolX0?nf`Agooooo00?o0000ooooooooool03oooool01Ol0003o
ooooooooooooool0000000Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`02oooo
o`H0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK1
0080okK1:`3oool=0?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o]/401`3o]/43oooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`04o`000?ooooooooooo`00o`[ooooo00<0003ooooo
ooooool02ooooolY0?nf`B/0oooo:03o]/4Mooooo`03o`000?oooooooooo00oooooo00Go0000oooo
oooooooooooo00000008ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00_ooool6
0?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@02
0?nf`B/0oooo3@3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK100L0okK10oooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`002Oooool01?l0003oooooooooool00?l:ooooo`030000oooooooo
oooo00_ooooo:@3o]/4[0?ooobP0okK17Oooool00ol0003oooooooooo`0?ooooo`05o`000?oooooo
ooooooooo`0000002?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00;ooooo1P3o
]/400ol00000okK10?nf`@0:0?nf`@030000003o]/40okK100h0okK100<000000?nf`@3o]/400P3o
]/4[0?ooo`d0okK100<000000?nf`@3o]/403P3o]/400`000000okK10?nf`@070?nf`@?ooooo00<0
0000ooooooooool02?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool000Wooooo00Co0000oooooooooooo003o2_ooool00`000?oooooooooo
o`0;ooooobT0okK1:`3ooolX0?nf`Agooooo00?o0000ooooooooool03oooool01Ol0003ooooooooo
ooooool0000000Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`02ooooo`H0okK1
00<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK10080okK1
:`3oool<0?nf`@030000003o]/40okK100l0okK100<000000?nf`@3o]/401`3o]/43ooooo`030000
0?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool00?l02_ooool00`000?oooooo
ooooo`0;ooooobP0okK1:`3ooolX0?nf`Agooooo00?o0000ooooooooool03oooool01Ol0003ooooo
ooooooooool0000000Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`03ooooo`D0
okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK10080
okK1:`3oool<0?nf`@030000003o]/40okK100l0okK100<000000?nf`@3o]/401`3o]/43ooooo`03
00000?oooooooooo00Sooooo00<00000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool00?l02_ooool00`000?oo
ooooooooo`0;ooooobP0okK1:`3ooolX0?nf`Agooooo00?o0000ooooooooool03oooool01Ol0003o
ooooooooooooool0000000Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`03oooo
o`D0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK1
0080okK1:`3oool<0?nf`@030000003o]/40okK100l0okK100<000000?nf`@3o]/401`3o]/43oooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool01_ooool00`00003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool00?l02_ooool00`00
0?ooooooooooo`0;ooooobT0okK1:@3ooolY0?nf`Agooooo00?o0000ooooooooool03oooool01Ol0
003oooooooooooooool0000000Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`03
ooooo`D0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40
okK100<0okK1:@3oool=0?nf`@030000003o]/40okK100l0okK100<000000?nf`@3o]/401`3o]/42
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01_ooool00`00003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`05o`000?ooooooooooooooool00?l02_ooool0
0`000?ooooooooooo`0;ooooobT0okK1:@3ooolY0?nf`Agooooo00?o0000ooooooooool03oooool0
1Ol0003oooooooooooooool0000000Sooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`03ooooo`D0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@0>0?nf`@030000003o
]/40okK10080okK1:@3oool<0?nf`@030000003o]/40okK100l0okK100<000000?nf`@3o]/40203o
]/42ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool02?ooool00`000?ooooooooooo`0:ooooobT0okK1:@3ooolY0?nf`Agooooo00?o0000
ooooooooool03oooool01Ol0003oooooooooooooool0000000Sooooo00<00000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`D0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf
`@0>0?nf`@030000003o]/40okK10080okK1:@3oool<0?nf`@03o`00003o]/40okK100l0okK100<0
00000?nf`@3o]/40203o]/42ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool02?ooool00`000?ooooooooooo`0:ooooobT0okK1:@3ooolY
0?nf`Agooooo00?o0000ooooooooool03oooool01Ol0003oooooooooooooool0000000Sooooo00<0
0000ooooooooool01oooool00`00003oooooooooo`03ooooo`D0okK100<000000?nf`@3o]/402`3o
]/400ol00000okK10?nf`@0?0?nf`@04o`00003o]/40okK10?nf`BT0oooo2`3o]/400`000000okK1
0?nf`@0@0?nf`@030000003o]/40okK100P0okK10_ooool00`00003oooooooooo`08ooooo`030000
0?oooooooooo00Oooooo00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00<0003oooooooooool02_oo
oolZ0?nf`BL0oooo:P3o]/4Mooooo`03o`000?oooooooooo00oooooo00Go0000oooooooooooooooo
00000009ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00_ooool60?nf`@030000
003o]/40okK100X0okK100<000000?nf`@3o]/403`3o]/400`000000okK10?nf`@020?nf`BL0oooo
303o]/400`000000okK10?nf`@0?0?nf`@03o`00003o]/40okK100T0okK100?ooooo00000?ooool0
2_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`08ooooo`03o`00oooo
oooooooo00[ooooo:P3o]/4W0?ooobX0okK17Oooool00ol0003oooooooooo`0?ooooo`05o`000?oo
ooooooooooooo`0000002Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00;ooooo
1P3o]/400`000000okK10?nf`@0:0?nf`@030000003o]/40okK10100okK100@000000?nf`@3o]/40
okK19`3oool;0?nf`@030000003o]/40okK10100okK100<000000?nf`@3o]/402@3o]/400oooool0
0000ooooo`09ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Sooooo
00<0003oooooooooool02_ooool[0?nf`BD0oooo:`3o]/4Mooooo`03o`000?oooooooooo00oooooo
00Go0000oooooooooooooooo00000009ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool00_ooool60?nf`@030000003o]/40okK100X0okK100<000000?nf`@3o]/40403o]/400`000000
okK10?nf`@020?nf`BD0oooo303o]/400`000000okK10?nf`@0@0?nf`@030000003o]/40okK100T0
okK100?ooooo00000?ooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`07ooooo`030000oooooooooooo00_ooooo;03o]/4S0?ooob/0okK17Oooool00ol0003ooooo
ooooo`0?ooooo`05o`000?ooooooooooooooo`0000002Oooool00`00003oooooooooo`07ooooo`03
00000?oooooooooo00?ooooo1@3o]/400`000000okK10?nf`@0;0?nf`@030000003o]/40okK10100
okK100<000000?nf`@3o]/400`3o]/4S0?ooo`/0okK100<000000?nf`@3o]/40403o]/400`000000
okK10?nf`@0:0?nf`@03ooooo`00003ooooo00Wooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool02?ooool00`000?ooooooooooo`0:ooooob`0okK18P3oool[0?nf`Akooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool02?ooool00`00003oooooooooo`02ooooo`H0okK100<000000?nf`@3o]/40
2P3o]/400`000000okK10?nf`@0@0?nf`@030000003o]/40okK100<0okK18P3oool<0?nf`@030000
003o]/40okK10100okK100<000000?nf`@3o]/402@3o]/400oooool00000ooooo`09ooooo`030000
0?oooooooooo00Sooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Sooooo00<0003oooooooooool02_oo
ool]0?nf`B00oooo;03o]/4Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool00_oo
ool60?nf`@030000003o]/40okK100/0okK100<000000?nf`@3o]/40403o]/400`000000okK10?nf
`@030?nf`B00oooo303o]/400`000000okK10?nf`@0@0?nf`@030000003o]/40okK100X0okK100?o
oooo00000?ooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`07
ooooo`030000oooooooooooo00[ooooo903o]/43o`0000L0okK17P3oool]0?nf`Akooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Kooooo00<00000
ooooooooool02?ooool00`00003oooooooooo`02ooooo`H0okK100<000000?nf`@3o]/402`3o]/40
0`000000okK10?nf`@0A0?nf`@030000003o]/40okK100<0okK17P3oool<0?nf`@030000003o]/40
okK10140okK100<000000?nf`@3o]/402P3o]/400oooool00000ooooo`09ooooo`0300000?oooooo
oooo00Sooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`04ooooo`03o`00oooooooooooo00Oooooo00<0003oooooooooool02_oooolS0?nf
`@Go00001`3o]/4L0?ooobh0okK17_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00;ooooo00<00000ooooooooool01oooool00`00003oooooooooo`08ooooo`0400000?oooooooooo
ooooo`L0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@0A0?nf`@030000003o]/40
okK100<0okK1703oool<0?nf`@030000003o]/40okK10140okK100<000000?nf`@3o]/402`3o]/40
0`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo
00Oooooo00<0003oooooooooool02_oooolR0?nf`@Go0000203o]/4I0?oooc00okK17_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00`00
003oooooooooo`08ooooo`0300000?oooooooooo00;ooooo1P3o]/400`000000okK10?nf`@0;0?nf
`@030000003o]/40okK10180okK100<000000?nf`@3o]/400`3o]/4I0?ooo`d0okK100?o00000?nf
`@3o]/404P3o]/400ol00000okK10?nf`@0;0?nf`@0300000?oooooooooo00Sooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo00Gooooo00?o003oooooooooool01oooool00`000?ooooooooooo`0:ooooob80
okK11Ol0000:0?nf`AD0oooo<@3o]/4Oooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo00Sooooo00<00000oooooooo
ool00_ooool60?nf`@030000003o]/40okK100/0okK100?o00000?nf`@3o]/404`3o]/400ol00000
okK10?nf`@040?nf`AD0oooo3P3o]/400`000000okK10?nf`@0C0?nf`@030000003o]/40okK100X0
okK100?ooooo00000?ooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`07ooooo`030000oooooooooooo00[ooooo8`3o]/43o`0000d0okK14@3ooolc0?nf`Aoooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool02?ooool01000003oooooooooooooool70?nf`@030000003o]/40okK100X0
okK100<000000?nf`@3o]/40503o]/400`000000okK10?nf`@050?nf`A40oooo3`3o]/400`000000
okK10?nf`@0D0?nf`@030000003o]/40okK100X0okK100<00000ooooooooool02?ooool00`00003o
ooooooooo`08ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`07ooooo`030000oooooooooooo00_ooooo
;03o]/43o`0000D0okK13@3ooole0?nf`Aoooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`04ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool02?ooool00`00003ooooo
ooooo`02ooooo`H0okK100<000000?nf`@3o]/402`3o]/400`000000okK10?nf`@0D0?nf`@030000
003o]/40okK100H0okK13@3oool@0?nf`@030000003o]/40okK101@0okK100<000000?nf`@3o]/40
2`3o]/400`00003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`06ooooo`03o`00oooo
oooooooo00Oooooo00<0003oooooooooool02_ooool[0?nf`@Go0000203o]/450?ooocP0okK18?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo1`3o]/400`000000okK10?nf
`@0;0?nf`@030000003o]/40okK101@0okK10P00000:0?nf`@D0oooo4P3o]/42000001H0okK100<0
00000?nf`@3o]/402`3o]/400`00003oooooooooo`09ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`06
ooooo`03o`00oooooooooooo00Oooooo00<0003oooooooooool02_ooool[0?nf`@Go0000A@3o]/4P
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`06
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool00_ooool70?nf`@030000003o]/40
okK100/0okK100<000000?nf`@3o]/405P3o]/42000001d0okK10P00000G0?nf`@030000003o]/40
okK100`0okK100<00000ooooooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooooooo`07ooooo`030000oooooooooooo00_ooooo:P3o]/45o`0004D0okK18?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool01_ooool00`00
003oooooooooo`08ooooo`0300000?oooooooooo00;ooooo1`3o]/400`000000okK10?nf`@0;0?nf
`@030000003o]/40okK101L0okK10`00000H0?nf`@800000603o]/400ol00000okK10?nf`@0<0?nf
`@0300000?oooooooooo00Wooooo00<00000ooooooooool02?ooool00`00003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Kooooo00?o003ooooooooo
ool01oooool00`000?ooooooooooo`0;ooooob/0okK10ol000150?nf`B7ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool01oooool00`00003oooooooooo`02ooooo`L0okK100<000000?nf`@3o]/40303o]/400`00003o
00000?nf`@0I0?nf`@030000003o]/40okK10140okK11000000I0?nf`@030000003o]/40okK100`0
okK100<00000ooooooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool01oooool00ol00?oooooo
ooooo`07ooooo`030000oooooooooooo00_oooooLP3o]/4Qooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool00oooool70?nf`@03o`00003o]/40okK100`0okK100<000000?nf`@3o]/40
603o]/400ol0000000000000000>0?nf`@<00000703o]/400`000000okK10?nf`@0=0?nf`@030000
0?oooooooooo00Wooooo00<00000ooooooooool02?ooool00`00003oooooooooo`08ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01ooo
ool00`000?ooooooooooo`0<ooooog00okK18?ooool00ol00?ooooooo`00000Aooooo`03o`000?oo
oooooooo00Gooooo00<00000ooooooooool01oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00?ooooo1P3o]/400`000000okK10?nf`@0=0?nf`@030000003o]/40okK101X0okK13P00
000N0?nf`@030000003o]/40okK100d0okK100<00000ooooooooool02_ooool00`00003ooooooooo
o`08ooooo`0300000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool02?ooool00ol00?ooooooooooo`07ooooo`030000oooooooooooo00_oooooK`3o]/4P
ooooo`04o`00ooooooooooooo`00017ooooo00?o0000ooooooooool01_ooool00`00003ooooooooo
o`07ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool00oooool70?nf`@030000003o
]/40okK100d0okK100<000000?nf`@3o]/40A03o]/400ol00000okK10?nf`@0>0?nf`@0300000?oo
oooooooo00Wooooo00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`03o`000?oo
oooo000000[ooooo0009ooooo`03o`000?oooooooooo00Sooooo00?o003oooooooooool01oooool0
0`000?ooooooooooo`0<ooooofh0okK18?ooool01?l00?ooooooooooool0000Aooooo`03o`000?oo
oooooooo00Kooooo00<00000ooooooooool01oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00?ooooo1P3o]/400`000000okK10?nf`@0>0?nf`@030000003o]/40okK104<0okK100<0
00000?nf`@3o]/403@3o]/400`00003oooooooooo`0:ooooo`0300000?oooooooooo00Oooooo00<0
0000o`000?ooool02?ooool00`00003oooooo`00000:ooooo`002Oooool00ol0003oooooooooo`09
ooooo`03o`00oooooooooooo00Kooooo00<0003oooooooooool03?oooom]0?nf`B3ooooo00Go003o
ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo1P3o]/400`000000okK10?nf
`@0?0?nf`@030000003o]/40okK10440okK100<000000?nf`@3o]/403P3o]/400`00003ooooooooo
o`0:ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02?ooool00`00003oooooo`00
000:ooooo`002Oooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo00Kooooo00<0003o
ooooooooool02ooooom]0?nf`B3ooooo00Go003oooooooooooooooooo`00000Aooooo`03o`000?oo
oooooooo00Oooooo00<00000ooooooooool01oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00;ooooo1`3o]/400`000000okK10?nf`@0?0?nf`@030000003o]/40okK103l0okK100<0
00000?nf`@3o]/403P3o]/400ol0003oooooooooo`0:ooooo`0300000?oooooooooo00Oooooo00<0
0000ooooooooool02?ooool01000003oooooooooool0000:ooooo`002Oooool00ol0003ooooooooo
o`0:ooooo`03o`00oooooooooooo00Kooooo00<0003oooooooooool03?oooom/0?nf`B3ooooo00Go
003oooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool0
2?ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00;ooooo1`3o]/400`00003o0000
0?nf`@0?0?nf`@800000?@3o]/400`00003o00000?nf`@0?0?nf`@030000003o]/7ooooo00[ooooo
00<00000ooooooooool02?ooool00`00003oooooooooo`07ooooo`0500000?ooooooooooooooool0
00002_ooool000Wooooo00?o0000ooooooooool02oooool00ol00?ooooooooooo`05ooooo`030000
oooooooooooo00goooooJP3o]/4Pooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
2?ooool00`00003oooooooooo`03ooooo`L0okK100<000000?nf`@3o]/40403o]/400`000000okK1
0?nf`@0i0?nf`@030000003o]/40okK100l0okK100<000000?nf`Oooool02oooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo00Oooooo00D00000ooooooooooooooooo`00000:ooooo`00
2Oooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo00Gooooo00<0003oooooooooool0
3OoooomY0?nf`B7ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Sooooo00<00000ooooooooool01oooool00`00003oooooooooo`09ooooo`030000
0?oooooooooo00;ooooo203o]/400`000000okK10?nf`@0@0?nf`@030000003o]/40okK103L0okK1
00<000000?nf`@3o]/403`3o]/400`000000okK1ooooo`0;ooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool01oooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo00cooooo00?o003oooooooooool01Oooool00`000?oooooooooo
o`0=ooooofP0okK18?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooool000002?ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool00oooool80?nf`@030000003o]/40okK10100okK100<000000?nf`@3o]/40=03o
]/4200000140okK100?o00000?nf`@3o]/402oooool00ol0003oooooooooo`09ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0<ooooo`03o`00oooooooooooo00Gooooo00<0003oooooooooool03OoooomW
0?nf`B7ooooo00?o003oooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?ooool0
000000Wooooo00<00000ooooooooool01oooool00`00003oooooooooo`09ooooo`0300000?oooooo
oooo00;ooooo2@3o]/400`000000okK10?nf`@0@0?nf`@03o`0000000000okK10380okK100?o0000
0?nf`@3o]/404@3o]/400`000000okK1ooooo`0:ooooo`0300000?oooooooooo00Wooooo00<00000
ooooooooool01oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo00cooooo00?o003oooooooooool01Oooool00`000?ooooooooooo`0>oooo
ofH0okK18?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
o`0000002_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00<00000oooo
ooooool00oooool80?nf`@030000003o]/40okK10180okK10P00000_0?nf`@8000004`3o]/400`00
0000okK10?nf`@0;ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool01oooool00`00
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00go
oooo00?o003oooooooooool01Oooool00`000?ooooooooooo`0>ooooof@0okK18Oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooool000002Oooool00`00
003oooooooooo`07ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool00oooool80?nf
`@030000003o]/40okK101<0okK10P00000[0?nf`@800000503o]/400`000000okK10?nf`@0;oooo
o`0300000?oooooooooo00Wooooo00<00000ooooooooool01oooool00`00003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo00gooooo00?o003ooooooooo
ool01Oooool00`000?ooooooooooo`0?ooooof80okK18_ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00oooooo00Co0000ooooooooool000002_ooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo00Sooooo00<00000ooooooooool01?ooool80?nf`@030000003o]/40okK1
01@0okK100<000000?nf`@3o]/409`3o]/400ol00000okK10?nf`@0C0?nf`@03o`00003o]/40okK1
00_ooooo00?o0000ooooooooool02_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool03_ooool00ol00?oo
ooooooooo`05ooooo`030000oooooooooooo00ooooooH03o]/4Rooooo`03o`00oooooooooooo00Go
oooo00?o0000ooooooooool03oooool01Ol0003oooooooooooooool0000000Wooooo00<00000oooo
ooooool01oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Cooooo203o]/420000
01@0okK100?o00000000000000008`3o]/44000001@0okK10P0000020?nf`@cooooo00<00000oooo
ooooool02Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Gooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool03oooool00ol00?ooooooooooo`05ooooo`03
0000oooooooooooo00koooooG`3o]/4Rooooo`03o`00oooooooooooo00Kooooo00?o0000oooooooo
ool03oooool01Ol0003oooooooooooooool0000000Wooooo00<00000ooooooooool02?ooool00`00
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo2P3o]/400`000000okK10?nf`@0D0?nf
`@<000007P3o]/42000001L0okK100@000000?nf`@3o]/40okK13?ooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Gooooo00<0003ooooo
ooooool03_oooomN0?nf`B7ooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00<00000ooooooooool01oooool00`00003oooooooooo`08oooo
o`0300000?oooooooooo00Wooooo00<00000ooooooooool00oooool:0?nf`@030000003o]/40okK1
01H0okK11000000H0?nf`@800000603o]/400ol00000okK10?nf`@020?nf`@_ooooo00<00000oooo
ooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`05ooooo`03
0000oooooooooooo00ooooooG03o]/4Rooooo`03o`00oooooooooooo00Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`03o`000000003ooooo00Sooooo00<00000oooooooo
ool02?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00?ooooo2P3o]/42000001X0
okK100@00000o`000000000000003@3o]/47000001P0okK10P0000040?nf`@_ooooo00?o0000oooo
ooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`05ooooo`03
0000oooooooooooo00ooooooFP3o]/4Rooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00?ooooo2`3o]/400`000000
okK10?nf`@0K0?nf`@d000007P3o]/400`000000okK10?nf`@030?nf`@_ooooo00<00000oooooooo
ool02_ooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool04Oooool00ol00?ooooooooooo`05ooooo`030000
oooooooooooo013oooooF03o]/4Sooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0
2Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00?ooooo2`3o]/400`000000okK1
0?nf`@140?nf`@030000003o]/40okK100<0okK12oooool00`00003oooooooooo`0:ooooo`030000
0?oooooooooo00Sooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo00Cooooo00<0003oooooooooool04Ooo
oomE0?nf`BCooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Cooooo00<00000ooooooooool01oooool00`00003oooooooooo`08ooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool00oooool;0?nf`@030000003o]/40okK10480okK100<0
00000?nf`@3o]/400P3o]/4<ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00`00003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo01?ooooo00?o003oooooooooool01?ooool00`000?ooooooooooo`0Aoooooe<0okK19?ooool0
0ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`03ooooo`/0okK100?o00000000003o]/40?P3o]/4200000003o`00003o]/40
okK10080okK12oooool2000000cooooo00<00000ooooooooool02?ooool00`00003o0000ooooo`08
ooooo`0300000?oooooo000000[ooooo0009ooooo`03o`000?oooooooooo01?ooooo00?o003ooooo
ooooool01?ooool00`000?ooooooooooo`0Coooooe00okK19Oooool00ol00?ooooooooooo`0:oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00`00003oooooooooo`08oooo
o`0300000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04oooo
o`/0okK10P00000k0?nf`@8000001P3o]/4;ooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooo000000[ooooo0009ooooo`03
o`000?oooooooooo01Cooooo00?o003oooooooooool01?ooool00`000?ooooooooooo`0Cooooodh0
okK19Oooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00Sooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`04ooooo``0okK10P00000h0?nf`@03o`00003o]/40okK100D0
okK12oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00Wooooo00<00000oooooooo
ool02?ooool01000003oooooooooool0000:ooooo`002Oooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo00?ooooo00<0003oooooooooool05?oooom<0?nf`BGooooo00?o003ooooooooo
ool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00<00000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00_ooooo0P000005ooooo`d0
okK10P00000d0?nf`@8000001`3o]/4;ooooo`0300000?oooooooooo00_ooooo00<00000oooooooo
ool02Oooool00`00003oooooooooo`08ooooo`0500000?ooooooooooooooool000002_ooool000Wo
oooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`04ooooo`030000oooooooooooo01Co
ooooBP3o]/4Vooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`07ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02_ooool00`00003o
ooooooooo`0<ooooo`0300000?oooooooooo00?ooooo3P3o]/400`000000okK10?nf`@0_0?nf`@80
0000203o]/4;ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool02Oooool00`00003o
ooooooooo`07ooooo`0300000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool05_ooool00ol00?ooooooooooo`04ooooo`030000oooooooooooo01Gooooo
AP3o]/4Wooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`08ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool02_ooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo00Cooooo3@3o]/43000002`0okK10P0000080?nf`@cooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Oooooo
00<00000ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`0Fooooo`03o`00oooooooooooo00Cooooo00<0003oooooooooool05_oooom40?nf`BOooooo00?o
003oooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00<0
0000ooooooooool02?ooool2000000_ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`04ooooo`l0okK10`00000W0?nf`@8000002@3o]/4<ooooo`03o`000?oooooooooo00cooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool05oooool00ol00?ooooooooooo`04
ooooo`030000oooooooooooo01Oooooo@03o]/4Xooooo`03o`00oooooooooooo00oooooo00?o0000
ooooooooool03oooool00ol0003ooooo00000009ooooo`03o`000000003ooooo00Sooooo00<00000
ooooooooool02_ooool00`00003oooooooooo`0<ooooo`8000001_ooool@0?nf`@0400000?l00000
0000000001l0okK1100000090?nf`@cooooo0P00000=ooooo`8000002oooool00`00003ooooooooo
o`08ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool06?ooool00ol00?ooooooooooo`04ooooo`030000oooooooooooo01Sooooo?03o]/4Y
ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooo0000000:
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`0300000?oooooooooo00Gooooo4P3o]/44000001@0okK11`00000;0?nf`@gooooo00<00000
ooooooooool03?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Wooooo00<00000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Ioooo
o`03o`00oooooooooooo00Cooooo00<0003oooooooooool06?oooolj0?nf`BWooooo00?o003ooooo
ooooool04Oooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo000000[ooooo00<00000
ooooooooool02?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00gooooo00<00000
ooooooooool01OoooolE0?nf`@L000001P3o]/4700000140okK13?ooool2000000kooooo00<00000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool06_ooool00ol00?ooooooooooo`03oooo
o`030000oooooooooooo01_ooooo=@3o]/4[ooooo`03o`00oooooooooooo017ooooo00?o0000oooo
ooooool03oooool01Ol0003oooooooooooooool0000000[ooooo00<00000ooooooooool02?ooool0
0`00003oooooooooo`0:ooooo`8000003_ooool00`00003o000000000007oooooaT0okK11P00000F
0?nf`@cooooo00?o000000000?ooool03_ooool00`00003oooooooooo`0:ooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Kooooo`03o`00oooooooooooo00?ooooo00<0003oooooooooool07Oooool_0?nf
`Bgooooo00?o003oooooooooool04_ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooo
ooooo`0000002_ooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00<00000
ooooooooool03_ooool00`00003oooooooooo`07ooooobl0okK13Oooool20000013ooooo00<00000
ooooooooool02oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`04oooo
o`030000oooooooooooo01oooooo:@3o]/4_ooooo`03o`00oooooooooooo01?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Sooooo00<00000oooo
ooooool02Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00kooooo0`000009oooo
obT0okK13oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool02Oooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01cooooo00?o003oooooooooool00oooool00`000?ooooooooooo`0Rooooob<0
okK1<Oooool00ol00?ooooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo00Wooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00Wooooo8`3o]/4@ooooo`80
00004?ooool2000000gooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01gooooo00?o003oooooooooool0
0oooool00`000?ooooooooooo`0Toooooad0okK1<oooool00ol00?ooooooooooo`0Eooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01?ooool00`00003oooooooooo`08ooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool02oooool20000017ooooo00?o0000000000000000
2ooooolM0?nf`@oooooo0P0000000ol000000000ooooo`0?ooooo`8000003Oooool2000000[ooooo
00<00000o`000?ooool02?ooool00`00003oooooo`00000:ooooo`002Oooool00ol0003ooooooooo
o`0Nooooo`03o`00oooooooooooo00;ooooo00<0003oooooooooool09ooooolG0?nf`CKooooo00?o
003oooooooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00cooooo00<0
0000ooooooooool04Oooool3000000_ooooo5`3o]/4Aooooo`0300000?oooooooooo013ooooo0P00
000>ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02Oooool00`00003oooooo`00
000:ooooo`002Oooool00ol0003oooooooooo`0Oooooo`03o`00oooooooooooo00;ooooo00<0003o
ooooooooool0;oooool40?nf`Coooooo00?o003oooooooooool05_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Gooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool04oooool30000017ooooo103o]/4H
ooooo`<000004_ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00<00000
ooooooooool02Oooool01000003oooooooooool0000:ooooo`002Oooool00ol0003oooooooooo`0P
ooooo`03o`00oooooooooooo00;ooooo00<0003oooooooooool0L?ooool00ol00?ooooooooooo`0G
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol000000000ooooo`09
ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool03?ooool00`00003o0000ooooo`0E
ooooo`0400000?l000000000000002Gooooo0P0000000ol000000000ooooo`0Cooooo`03o`000?oo
oooooooo00gooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`0500000?oo
ooooooooooooool000002_ooool000Wooooo00?o0000ooooooooool08Oooool00ol00?oooooooooo
o`02ooooo`030000oooooooooooo06kooooo00?o003oooooooooool06?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`0:ooooo`03o`000000003ooooo00gooooo00<00000ooooooooool05oooool3000001oooooo0`00
000Gooooo`8000003_ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Sooooo00<0
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0R
ooooo`03o`00oooooooooooo00;ooooo00<0003oooooooooool0K?ooool00ol00?ooooooooooo`0I
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00`00003oooooooooo`08
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool03?ooool2000001[ooooo1000000D
ooooo`L000006?ooool2000000kooooo0P00000<ooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Soooo
o`05o`00ooooooooooooooooo`000?l0KOooool00ol00?ooooooooooo`0Jooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`08ooooo`03o`000?oooooo
oooo00_ooooo00<00000ooooooooool03Oooool2000001cooooo5000000Mooooo`8000003oooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool01?ooool0
0ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Tooooo`05o`00oooooooooooo
ooooo`000?l0J_ooool2o`00oagooooo00?o0000ooooooooool03oooool00ol0003ooooo0000000:
ooooo`0300000?oooooooooo00Sooooo0P00000<ooooo`03o`000000003ooooo00kooooo0P000019
ooooo`8000004?ooool00ol0003oooooooooo`0:ooooo`0300000?l0003ooooo00Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Uoooo
o`04o`00ooooooooooooooooo`80003oIoooool00ol00?ooooooooooo`0Mooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooool000002_ooool00`00003oooooooooo`09ooooo`0300000?oo
oooooooo00_ooooo00<00000ooooooooool03_ooool2000004Gooooo0P00000@ooooo`8000003?oo
ool00`00003oooooooooo`09ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool09_ooool00ol00?ooooooooooo`02ooooo`030000oooooooo
oooo06?ooooo00?o003oooooooooool07_ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooo
ooooooooo`0000002_ooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0P00
000@ooooo`<00000?oooool30000017ooooo00<00000ooooooooool02oooool00`00003ooooooooo
o`09ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool09oooool01Ol00?ooooooooooooooool0003o06Cooooo00?o003oooooooooool07ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool04?oo
ool00`00003o00000000000jooooo`03o`000000003ooooo013ooooo0P0000000ol0003ooooooooo
o`0:ooooo`8000002oooool00`00003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo02Sooooo00Go003ooooooooooooooooo0000o`1Rooooo`03o`00oooo
oooooooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo00Sooooo0P00000;ooooo`0300000?oooooooooo00cooooo00?o000000000?ooool04_oo
ool00`00003oooooooooo`0eooooo`8000004_ooool00`00003oooooooooo`0<ooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`0Yooooo`;o003o0_ooool00`000?ooooooooooo`1Nooooo`03o`00oooooooo
oooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool02Oooool2000000kooooo00<00000ooooooooool04Oooool3
0000033ooooo1000000Booooo`8000003_ooool00`00003oooooooooo`0:ooooo`0300000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:oooool01?l0
0?ooooooooooo`000?mNooooo`03o`00oooooooooooo023ooooo00?o003oooooool000004Oooool0
0ol0003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02_ooool0
0`00003oooooooooo`0<ooooo`0300000?oooooooooo01?ooooo0`00000Zooooo`<000005Oooool0
0`00003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool02Oooool0
0ol0003oooooo`00000:ooooo`002Oooool00ol0003oooooooooo`0/ooooo`;o003o00?oooooo`00
ooooool0Foooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo0000017ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o0000oooo
ooooool03?ooool00`00003o00000000000Eooooo`80000000?o00000000000000000P00000Ooooo
o`@000005_ooool2000000oooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`8000000_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0^ooooo`03
o`00ooooool0003o05Wooooo0_l00?lTooooo`03o`00oooooooo0000017ooooo00?o0000oooooooo
ool01_ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo0P00000?ooooo`80
00006_ooool4000001Cooooo1`00000Hooooo`8000004?ooool00`00003oooooooooo`09ooooo`80
00002_ooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo02oooooo00?o003oooooo`000?l0Eoooool00ol00?ooooooooooo`0Sooooo`04o`00
ooooooooooooo`00017ooooo00?o0000ooooooooool01oooool00`00003oooooooooo`09ooooo`03
00000?oooooooooo00_ooooo00<00000ooooooooool03_ooool2000001cooooo5000000Mooooo`80
00004?ooool2000000_ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo033ooooo00?o003oooooo`000?l0
EOooool00ol00?ooooooooooo`0Sooooo`05o`00ooooooooooooooooool000004Oooool00ol0003o
ooooooooo`08ooooo`0300000?oooooooooo00Wooooo00?o000000000?ooool02oooool00ol00000
00000000000?ooooo`0300000?l00000000004Sooooo00?o000000000?ooool03oooool00ol00000
0000ooooo`0;ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0aooooo`03o`00ooooool0003o05?ooooo
00?o003oooooooooool09?ooool01Ol00?oooooooooooooooooo0000017ooooo00?o0000oooooooo
ool02Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00cooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`13ooooo`8000004?ooool2000000gooooo00<00000oooooooo
ool02_ooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo03;ooooo0_l00?l20000odoooooo0_l00?lVooooo`03o`00oooooooooooo00;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00[ooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`0?ooooo`<00000?_ooool40000017ooooo
00<00000ooooooooool03?ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0=?ooool2o`00o`030000oooo
oooooooo04[ooooo0_l00?lXooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooo`00000;ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool03?oo
ool00`00003oooooooooo`0Aooooo`<00000>?ooool3000001?ooooo0P00000>ooooo`0300000?oo
oooooooo00Wooooo0P000008ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo03Kooooo00?o003o0000ooooool0BOooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooo
oooo00?ooooo00?o0000ooooooooool03oooool01?l0003oooooooooo`00000;ooooo`03o`000?oo
oooooooo00[ooooo00<00000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`0400000?l0
000000000000033ooooo0`0000000ol0003oooooooooo`0Booooo`8000003Oooool200000003o`00
0?oooooooooo00Wooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`0gooooo`;o003oAoooool2o`00obWooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooo`0000002oooool00`00003ooooo
ooooo`0:ooooo`0300000?oooooooooo00cooooo0`00000Fooooo`<00000:_ooool3000001Kooooo
0P00000>ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`0iooooo`;o003oA?ooool00ol00?oooooooooo
o`0Xooooo`03o`00oooooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool02_ooool2000000oooooo0P00
000Gooooo`@000008_ooool4000001Sooooo00<00000ooooooooool03Oooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0>oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo02Wooooo00?o003o
ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00<00000
ooooooooool02Oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00kooooo00<00000
ooooooooool06?ooool6000001Kooooo1P00000Jooooo`8000003oooool00`00003oooooooooo`0;
ooooo`0300000?oooooooooo00Wooooo00?o0000ooooool000002_ooool000Wooooo00?o0000oooo
ooooool0??ooool2o`00ockooooo0_l00?l[ooooo`03o`00oooooooooooo00Kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Wooooo00?o00000000
0?ooool02oooool00ol0000000000000000>ooooo`03o`0000000000000001gooooo00<00000o`00
000000004`00000Looooo`@000003_ooool200000003o`000?oooooooooo00Wooooo0P0000000ol0
003oooooooooo`08ooooo`8000000_ooool00ol0003oooooooooo`08ooooo`002Oooool01?l0003o
ooooo`00ool00?llooooo`030000ool00?oooooo03Wooooo0ol00?l/ooooo`03o`00oooooooooooo
00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`0300000?oooooooooo
00[ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0>ooooo`800000Boooool20000
017ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool000Wooooo00Go0000ooooooooooooooooo`00o`0loooo
o`030000ool00?oooooo03Oooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool2000000_ooooo00<00000oooo
ooooool03?ooool20000013ooooo0`000016ooooo`8000004_ooool00`00003oooooooooo`0;oooo
o`0300000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo03[ooooo00<0003oo`00ool0
0?l0=Oooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo00Wooooo0_l0000>ooooo`03
00000?oooooooooo013ooooo00<00000o`000?ooool0@Oooool00ol000000000ooooo`0Aooooo`;o
00003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo]_l0000AoooookKo00002_oo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(AnnularAllPlot[c1, rr1, rr2, em // Last];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.44231 .11459 m
.46154 .11355 L
.48077 .11334 L
.5 .11394 L
.51923 .11535 L
.51967 .11538 L
.53846 .11759 L
.55769 .12066 L
.57692 .12455 L
.59615 .12929 L
.61457 .13462 L
.61538 .13487 L
.63462 .14142 L
.65385 .14888 L
.66546 .15385 L
.67308 .15733 L
.69231 .16686 L
.70383 .17308 L
.71154 .1775 L
.73077 .18938 L
.73522 .19231 L
.75 .20262 L
.7619 .21154 L
.76923 .21736 L
.78506 .23077 L
.78846 .23382 L
.80542 .25 L
.80769 .2523 L
.82346 .26923 L
.82692 .27319 L
.83951 .28846 L
.84615 .29711 L
.8538 .30769 L
.86538 .32506 L
.86655 .32692 L
.87784 .34615 L
.88462 .35891 L
.88782 .36538 L
.89656 .38462 L
.90385 .40299 L
.90416 .40385 L
.9106 .42308 L
.91599 .44231 L
.92034 .46154 L
.92308 .4767 L
.92368 .48077 L
.92598 .5 L
.92729 .51923 L
.9276 .53846 L
.92691 .55769 L
.9252 .57692 L
.92308 .59261 L
.92245 .59615 L
.91859 .61538 L
.91362 .63462 L
.90749 .65385 L
.90385 .6638 L
.90011 .67308 L
.89138 .69231 L
.88462 .70546 L
.88123 .71154 L
.86948 .73077 L
.86538 .73689 L
.85595 .75 L
.84615 .76243 L
.84039 .76923 L
.82692 .78394 L
.82247 .78846 L
.80769 .80241 L
.80166 .80769 L
.78846 .81847 L
.77721 .82692 L
.76923 .83252 L
.75 .84486 L
.74783 .84615 L
.73077 .85566 L
.71154 .86514 L
.711 .86538 L
.69231 .87335 L
.67308 .88045 L
.66023 .88462 L
.65385 .88649 L
.63462 .89152 L
.61538 .89561 L
.59615 .89881 L
.57692 .90113 L
.55769 .90259 L
.53846 .90322 L
.51923 .90302 L
.5 .90199 L
.48077 .90015 L
.46154 .89749 L
.44231 .89401 L
.42308 .88969 L
.40413 .88462 L
.40385 .88453 L
.38462 .87843 L
.36538 .87143 L
.3505 .86538 L
.34615 .86349 L
.32692 .85448 L
.31084 .84615 L
.30769 .84442 L
.28846 .83316 L
.27862 .82692 L
.26923 .82062 L
.25133 .80769 L
.25 .80668 L
.23077 .79111 L
.22769 .78846 L
.21154 .7737 L
.20694 .76923 L
.19231 .75412 L
.18855 .75 L
.17308 .73187 L
.17219 .73077 L
.15762 .71154 L
.15385 .70618 L
.14465 .69231 L
.13462 .67576 L
.1331 .67308 L
.12291 .65385 L
.11538 .63792 L
.11394 .63462 L
.10618 .61538 L
.09952 .59615 L
.09615 .58506 L
.09395 .57692 L
.08944 .55769 L
.08594 .53846 L
.08346 .51923 L
.08197 .5 L
.08149 .48077 L
.08203 .46154 L
.08359 .44231 L
.08619 .42308 L
.08987 .40385 L
.09465 .38462 L
.09615 .37935 L
.10063 .36538 L
.10784 .34615 L
.11538 .32896 L
.11636 .32692 L
.12634 .30769 L
.13462 .2936 L
.13787 .28846 L
.15115 .26923 L
.15385 .26564 L
.16644 .25 L
.17308 .24242 L
.18405 .23077 L
.19231 .22263 L
.20446 .21154 L
.21154 .20551 L
.22839 .19231 L
.23077 .19056 L
.25 .17747 L
.25703 .17308 L
.26923 .16597 L
.28846 .15588 L
.29266 .15385 L
.30769 .14709 L
.32692 .13946 L
.34081 .13462 L
.34615 .13291 L
.36538 .12741 L
.38462 .12286 L
.40385 .11922 L
.42308 .11647 L
.43232 .11538 L
F
0 g
.44231 .11459 m
.46154 .11355 L
.48077 .11334 L
.5 .11394 L
.51923 .11535 L
.51967 .11538 L
.53846 .11759 L
.55769 .12066 L
.57692 .12455 L
.59615 .12929 L
.61457 .13462 L
.61538 .13487 L
.63462 .14142 L
.65385 .14888 L
.66546 .15385 L
.67308 .15733 L
.69231 .16686 L
.70383 .17308 L
.71154 .1775 L
.73077 .18938 L
.73522 .19231 L
.75 .20262 L
.7619 .21154 L
.76923 .21736 L
.78506 .23077 L
.78846 .23382 L
.80542 .25 L
.80769 .2523 L
.82346 .26923 L
.82692 .27319 L
.83951 .28846 L
.84615 .29711 L
.8538 .30769 L
.86538 .32506 L
.86655 .32692 L
.87784 .34615 L
.88462 .35891 L
.88782 .36538 L
.89656 .38462 L
.90385 .40299 L
.90416 .40385 L
.9106 .42308 L
.91599 .44231 L
.92034 .46154 L
.92308 .4767 L
.92368 .48077 L
.92598 .5 L
.92729 .51923 L
.9276 .53846 L
.92691 .55769 L
Mistroke
.9252 .57692 L
.92308 .59261 L
.92245 .59615 L
.91859 .61538 L
.91362 .63462 L
.90749 .65385 L
.90385 .6638 L
.90011 .67308 L
.89138 .69231 L
.88462 .70546 L
.88123 .71154 L
.86948 .73077 L
.86538 .73689 L
.85595 .75 L
.84615 .76243 L
.84039 .76923 L
.82692 .78394 L
.82247 .78846 L
.80769 .80241 L
.80166 .80769 L
.78846 .81847 L
.77721 .82692 L
.76923 .83252 L
.75 .84486 L
.74783 .84615 L
.73077 .85566 L
.71154 .86514 L
.711 .86538 L
.69231 .87335 L
.67308 .88045 L
.66023 .88462 L
.65385 .88649 L
.63462 .89152 L
.61538 .89561 L
.59615 .89881 L
.57692 .90113 L
.55769 .90259 L
.53846 .90322 L
.51923 .90302 L
.5 .90199 L
.48077 .90015 L
.46154 .89749 L
.44231 .89401 L
.42308 .88969 L
.40413 .88462 L
.40385 .88453 L
.38462 .87843 L
.36538 .87143 L
.3505 .86538 L
.34615 .86349 L
Mistroke
.32692 .85448 L
.31084 .84615 L
.30769 .84442 L
.28846 .83316 L
.27862 .82692 L
.26923 .82062 L
.25133 .80769 L
.25 .80668 L
.23077 .79111 L
.22769 .78846 L
.21154 .7737 L
.20694 .76923 L
.19231 .75412 L
.18855 .75 L
.17308 .73187 L
.17219 .73077 L
.15762 .71154 L
.15385 .70618 L
.14465 .69231 L
.13462 .67576 L
.1331 .67308 L
.12291 .65385 L
.11538 .63792 L
.11394 .63462 L
.10618 .61538 L
.09952 .59615 L
.09615 .58506 L
.09395 .57692 L
.08944 .55769 L
.08594 .53846 L
.08346 .51923 L
.08197 .5 L
.08149 .48077 L
.08203 .46154 L
.08359 .44231 L
.08619 .42308 L
.08987 .40385 L
.09465 .38462 L
.09615 .37935 L
.10063 .36538 L
.10784 .34615 L
.11538 .32896 L
.11636 .32692 L
.12634 .30769 L
.13462 .2936 L
.13787 .28846 L
.15115 .26923 L
.15385 .26564 L
.16644 .25 L
.17308 .24242 L
Mistroke
.18405 .23077 L
.19231 .22263 L
.20446 .21154 L
.21154 .20551 L
.22839 .19231 L
.23077 .19056 L
.25 .17747 L
.25703 .17308 L
.26923 .16597 L
.28846 .15588 L
.29266 .15385 L
.30769 .14709 L
.32692 .13946 L
.34081 .13462 L
.34615 .13291 L
.36538 .12741 L
.38462 .12286 L
.40385 .11922 L
.42308 .11647 L
.43232 .11538 L
.44231 .11459 L
Mfstroke
.2 g
.40385 .19138 m
.42308 .18775 L
.44231 .18518 L
.46154 .18365 L
.48077 .18313 L
.5 .1836 L
.51923 .18507 L
.53846 .18752 L
.55769 .19097 L
.56401 .19231 L
.57692 .19545 L
.59615 .201 L
.61538 .20764 L
.6254 .21154 L
.63462 .21544 L
.65385 .22449 L
.6658 .23077 L
.67308 .23487 L
.69231 .24674 L
.69719 .25 L
.71154 .26027 L
.72302 .26923 L
.73077 .2757 L
.7449 .28846 L
.75 .2934 L
.76371 .30769 L
.76923 .3139 L
.78002 .32692 L
.78846 .33804 L
.79419 .34615 L
.8065 .36538 L
.80769 .3674 L
.81711 .38462 L
.8262 .40385 L
.82692 .40551 L
.83384 .42308 L
.84014 .44231 L
.84515 .46154 L
.84615 .46592 L
.8489 .48077 L
.85141 .5 L
.85271 .51923 L
.8528 .53846 L
.85166 .55769 L
.84926 .57692 L
.84615 .59363 L
.84556 .59615 L
.84049 .61538 L
.83398 .63462 L
.82692 .65168 L
.82593 .65385 L
.81615 .67308 L
.80769 .68737 L
.80449 .69231 L
.79065 .71154 L
.78846 .71431 L
.77424 .73077 L
.76923 .73604 L
.75468 .75 L
.75 .75411 L
.731 .76923 L
.73077 .7694 L
.71154 .78241 L
.70146 .78846 L
.69231 .79352 L
.67308 .80296 L
.6621 .80769 L
.65385 .81093 L
.63462 .81754 L
.61538 .82293 L
.59735 .82692 L
.59615 .82715 L
.57692 .83025 L
.55769 .8323 L
.53846 .83333 L
.51923 .83335 L
.5 .83238 L
.48077 .83042 L
.46154 .82747 L
.45851 .82692 L
.44231 .82349 L
.42308 .81847 L
.40385 .81239 L
.39095 .80769 L
.38462 .80518 L
.36538 .79675 L
.34876 .78846 L
.34615 .78706 L
.32692 .77595 L
.31639 .76923 L
.30769 .76329 L
.28988 .75 L
.28846 .74887 L
.26923 .73238 L
.26749 .73077 L
.25 .7134 L
.24825 .71154 L
.23159 .69231 L
.23077 .69129 L
.21711 .67308 L
.21154 .6649 L
.20453 .65385 L
.19365 .63462 L
.19231 .63204 L
.18434 .61538 L
.17646 .59615 L
.17308 .58671 L
.16995 .57692 L
.16475 .55769 L
.1608 .53846 L
.15809 .51923 L
.15659 .5 L
.15632 .48077 L
.15728 .46154 L
.1595 .44231 L
.16301 .42308 L
.16788 .40385 L
.17308 .38763 L
.17417 .38462 L
.18203 .36538 L
.19155 .34615 L
.19231 .34476 L
.20296 .32692 L
.21154 .31435 L
.21649 .30769 L
.23077 .29043 L
.23254 .28846 L
.25 .27077 L
.25166 .26923 L
.26923 .25426 L
.27474 .25 L
.28846 .24022 L
.30337 .23077 L
.30769 .22825 L
.32692 .21804 L
.34103 .21154 L
.34615 .20938 L
.36538 .20214 L
.38462 .19616 L
.39969 .19231 L
F
0 g
.40385 .19138 m
.42308 .18775 L
.44231 .18518 L
.46154 .18365 L
.48077 .18313 L
.5 .1836 L
.51923 .18507 L
.53846 .18752 L
.55769 .19097 L
.56401 .19231 L
.57692 .19545 L
.59615 .201 L
.61538 .20764 L
.6254 .21154 L
.63462 .21544 L
.65385 .22449 L
.6658 .23077 L
.67308 .23487 L
.69231 .24674 L
.69719 .25 L
.71154 .26027 L
.72302 .26923 L
.73077 .2757 L
.7449 .28846 L
.75 .2934 L
.76371 .30769 L
.76923 .3139 L
.78002 .32692 L
.78846 .33804 L
.79419 .34615 L
.8065 .36538 L
.80769 .3674 L
.81711 .38462 L
.8262 .40385 L
.82692 .40551 L
.83384 .42308 L
.84014 .44231 L
.84515 .46154 L
.84615 .46592 L
.8489 .48077 L
.85141 .5 L
.85271 .51923 L
.8528 .53846 L
.85166 .55769 L
.84926 .57692 L
.84615 .59363 L
.84556 .59615 L
.84049 .61538 L
.83398 .63462 L
.82692 .65168 L
Mistroke
.82593 .65385 L
.81615 .67308 L
.80769 .68737 L
.80449 .69231 L
.79065 .71154 L
.78846 .71431 L
.77424 .73077 L
.76923 .73604 L
.75468 .75 L
.75 .75411 L
.731 .76923 L
.73077 .7694 L
.71154 .78241 L
.70146 .78846 L
.69231 .79352 L
.67308 .80296 L
.6621 .80769 L
.65385 .81093 L
.63462 .81754 L
.61538 .82293 L
.59735 .82692 L
.59615 .82715 L
.57692 .83025 L
.55769 .8323 L
.53846 .83333 L
.51923 .83335 L
.5 .83238 L
.48077 .83042 L
.46154 .82747 L
.45851 .82692 L
.44231 .82349 L
.42308 .81847 L
.40385 .81239 L
.39095 .80769 L
.38462 .80518 L
.36538 .79675 L
.34876 .78846 L
.34615 .78706 L
.32692 .77595 L
.31639 .76923 L
.30769 .76329 L
.28988 .75 L
.28846 .74887 L
.26923 .73238 L
.26749 .73077 L
.25 .7134 L
.24825 .71154 L
.23159 .69231 L
.23077 .69129 L
.21711 .67308 L
Mistroke
.21154 .6649 L
.20453 .65385 L
.19365 .63462 L
.19231 .63204 L
.18434 .61538 L
.17646 .59615 L
.17308 .58671 L
.16995 .57692 L
.16475 .55769 L
.1608 .53846 L
.15809 .51923 L
.15659 .5 L
.15632 .48077 L
.15728 .46154 L
.1595 .44231 L
.16301 .42308 L
.16788 .40385 L
.17308 .38763 L
.17417 .38462 L
.18203 .36538 L
.19155 .34615 L
.19231 .34476 L
.20296 .32692 L
.21154 .31435 L
.21649 .30769 L
.23077 .29043 L
.23254 .28846 L
.25 .27077 L
.25166 .26923 L
.26923 .25426 L
.27474 .25 L
.28846 .24022 L
.30337 .23077 L
.30769 .22825 L
.32692 .21804 L
.34103 .21154 L
.34615 .20938 L
.36538 .20214 L
.38462 .19616 L
.39969 .19231 L
.40385 .19138 L
Mfstroke
.3 g
.44231 .22997 m
.46154 .228 L
.48077 .22721 L
.5 .22756 L
.51923 .22907 L
.53307 .23077 L
.53846 .23172 L
.55769 .23554 L
.57692 .24056 L
.59615 .24683 L
.60463 .25 L
.61538 .25443 L
.63462 .26345 L
.6455 .26923 L
.65385 .27404 L
.67308 .28637 L
.67607 .28846 L
.69231 .30073 L
.70067 .30769 L
.71154 .3175 L
.72112 .32692 L
.73077 .33728 L
.73838 .34615 L
.75 .36111 L
.75305 .36538 L
.76552 .38462 L
.76923 .39102 L
.77603 .40385 L
.78478 .42308 L
.78846 .43242 L
.79191 .44231 L
.7975 .46154 L
.80163 .48077 L
.80433 .5 L
.80563 .51923 L
.80551 .53846 L
.80396 .55769 L
.80094 .57692 L
.79637 .59615 L
.79017 .61538 L
.78846 .61994 L
.78219 .63462 L
.77223 .65385 L
.76923 .65894 L
.76001 .67308 L
.75 .68644 L
.74514 .69231 L
.73077 .70785 L
.72699 .71154 L
.71154 .72521 L
.70451 .73077 L
.69231 .73955 L
.67569 .75 L
.67308 .75149 L
.65385 .7614 L
.63549 .76923 L
.63462 .76957 L
.61538 .77616 L
.59615 .78133 L
.57692 .78517 L
.55769 .78777 L
.55001 .78846 L
.53846 .78915 L
.51923 .78937 L
.50023 .78846 L
.5 .78844 L
.48077 .78636 L
.46154 .78313 L
.44231 .77871 L
.42308 .77308 L
.4119 .76923 L
.40385 .76616 L
.38462 .75786 L
.3689 .75 L
.36538 .74809 L
.34615 .73666 L
.33726 .73077 L
.32692 .72337 L
.31195 .71154 L
.30769 .7079 L
.29098 .69231 L
.28846 .68976 L
.27329 .67308 L
.26923 .66819 L
.25826 .65385 L
.25 .64179 L
.24548 .63462 L
.23468 .61538 L
.23077 .6075 L
.22567 .59615 L
.2183 .57692 L
.21247 .55769 L
.21154 .5542 L
.20813 .53846 L
.20522 .51923 L
.20371 .5 L
.20362 .48077 L
.20496 .46154 L
.20776 .44231 L
.21154 .42512 L
.2121 .42308 L
.21808 .40385 L
.22581 .38462 L
.23077 .37424 L
.2355 .36538 L
.2474 .34615 L
.25 .34241 L
.2619 .32692 L
.26923 .31847 L
.27958 .30769 L
.28846 .29935 L
.30142 .28846 L
.30769 .28367 L
.32692 .27064 L
.32923 .26923 L
.34615 .2598 L
.36538 .25082 L
.36735 .25 L
.38462 .2435 L
.40385 .23765 L
.42308 .23317 L
.43643 .23077 L
F
0 g
.44231 .22997 m
.46154 .228 L
.48077 .22721 L
.5 .22756 L
.51923 .22907 L
.53307 .23077 L
.53846 .23172 L
.55769 .23554 L
.57692 .24056 L
.59615 .24683 L
.60463 .25 L
.61538 .25443 L
.63462 .26345 L
.6455 .26923 L
.65385 .27404 L
.67308 .28637 L
.67607 .28846 L
.69231 .30073 L
.70067 .30769 L
.71154 .3175 L
.72112 .32692 L
.73077 .33728 L
.73838 .34615 L
.75 .36111 L
.75305 .36538 L
.76552 .38462 L
.76923 .39102 L
.77603 .40385 L
.78478 .42308 L
.78846 .43242 L
.79191 .44231 L
.7975 .46154 L
.80163 .48077 L
.80433 .5 L
.80563 .51923 L
.80551 .53846 L
.80396 .55769 L
.80094 .57692 L
.79637 .59615 L
.79017 .61538 L
.78846 .61994 L
.78219 .63462 L
.77223 .65385 L
.76923 .65894 L
.76001 .67308 L
.75 .68644 L
.74514 .69231 L
.73077 .70785 L
.72699 .71154 L
.71154 .72521 L
Mistroke
.70451 .73077 L
.69231 .73955 L
.67569 .75 L
.67308 .75149 L
.65385 .7614 L
.63549 .76923 L
.63462 .76957 L
.61538 .77616 L
.59615 .78133 L
.57692 .78517 L
.55769 .78777 L
.55001 .78846 L
.53846 .78915 L
.51923 .78937 L
.50023 .78846 L
.5 .78844 L
.48077 .78636 L
.46154 .78313 L
.44231 .77871 L
.42308 .77308 L
.4119 .76923 L
.40385 .76616 L
.38462 .75786 L
.3689 .75 L
.36538 .74809 L
.34615 .73666 L
.33726 .73077 L
.32692 .72337 L
.31195 .71154 L
.30769 .7079 L
.29098 .69231 L
.28846 .68976 L
.27329 .67308 L
.26923 .66819 L
.25826 .65385 L
.25 .64179 L
.24548 .63462 L
.23468 .61538 L
.23077 .6075 L
.22567 .59615 L
.2183 .57692 L
.21247 .55769 L
.21154 .5542 L
.20813 .53846 L
.20522 .51923 L
.20371 .5 L
.20362 .48077 L
.20496 .46154 L
.20776 .44231 L
.21154 .42512 L
Mistroke
.2121 .42308 L
.21808 .40385 L
.22581 .38462 L
.23077 .37424 L
.2355 .36538 L
.2474 .34615 L
.25 .34241 L
.2619 .32692 L
.26923 .31847 L
.27958 .30769 L
.28846 .29935 L
.30142 .28846 L
.30769 .28367 L
.32692 .27064 L
.32923 .26923 L
.34615 .2598 L
.36538 .25082 L
.36735 .25 L
.38462 .2435 L
.40385 .23765 L
.42308 .23317 L
.43643 .23077 L
.44231 .22997 L
Mfstroke
.4 g
.44231 .26548 m
.46154 .26304 L
.48077 .26196 L
.5 .2622 L
.51923 .26375 L
.53846 .26661 L
.55139 .26923 L
.55769 .2708 L
.57692 .27639 L
.59615 .28345 L
.60777 .28846 L
.61538 .29209 L
.63462 .30249 L
.64311 .30769 L
.65385 .31487 L
.66983 .32692 L
.67308 .32959 L
.69125 .34615 L
.69231 .34721 L
.70887 .36538 L
.71154 .36864 L
.72349 .38462 L
.73077 .3957 L
.73562 .40385 L
.74559 .42308 L
.75 .43306 L
.7536 .44231 L
.75982 .46154 L
.76435 .48077 L
.76724 .5 L
.76852 .51923 L
.76819 .53846 L
.76622 .55769 L
.76254 .57692 L
.75705 .59615 L
.75 .61447 L
.74959 .61538 L
.73993 .63462 L
.73077 .64945 L
.72772 .65385 L
.71244 .67308 L
.71154 .67408 L
.6932 .69231 L
.69231 .6931 L
.67308 .70829 L
.66838 .71154 L
.65385 .72059 L
.63462 .73055 L
.63414 .73077 L
.61538 .73851 L
.59615 .74473 L
.57692 .74936 L
.574 .75 L
.55769 .75252 L
.53846 .75428 L
.51923 .75471 L
.5 .75382 L
.48077 .75162 L
.47058 .75 L
.46154 .74811 L
.44231 .74322 L
.42308 .73692 L
.40764 .73077 L
.40385 .72909 L
.38462 .71961 L
.37058 .71154 L
.36538 .70827 L
.34615 .69479 L
.34294 .69231 L
.32692 .67875 L
.32088 .67308 L
.30769 .65943 L
.30278 .65385 L
.28846 .6356 L
.28776 .63462 L
.27529 .61538 L
.26923 .60454 L
.26502 .59615 L
.25672 .57692 L
.25024 .55769 L
.25 .55691 L
.24547 .53846 L
.24235 .51923 L
.24083 .5 L
.24093 .48077 L
.24266 .46154 L
.24609 .44231 L
.25 .42719 L
.25133 .42308 L
.25851 .40385 L
.26786 .38462 L
.26923 .38214 L
.27971 .36538 L
.28846 .35352 L
.29455 .34615 L
.30769 .33215 L
.3132 .32692 L
.32692 .31529 L
.33716 .30769 L
.34615 .30169 L
.36538 .29066 L
.36974 .28846 L
.38462 .28177 L
.40385 .27473 L
.42308 .26934 L
.42352 .26923 L
F
0 g
.44231 .26548 m
.46154 .26304 L
.48077 .26196 L
.5 .2622 L
.51923 .26375 L
.53846 .26661 L
.55139 .26923 L
.55769 .2708 L
.57692 .27639 L
.59615 .28345 L
.60777 .28846 L
.61538 .29209 L
.63462 .30249 L
.64311 .30769 L
.65385 .31487 L
.66983 .32692 L
.67308 .32959 L
.69125 .34615 L
.69231 .34721 L
.70887 .36538 L
.71154 .36864 L
.72349 .38462 L
.73077 .3957 L
.73562 .40385 L
.74559 .42308 L
.75 .43306 L
.7536 .44231 L
.75982 .46154 L
.76435 .48077 L
.76724 .5 L
.76852 .51923 L
.76819 .53846 L
.76622 .55769 L
.76254 .57692 L
.75705 .59615 L
.75 .61447 L
.74959 .61538 L
.73993 .63462 L
.73077 .64945 L
.72772 .65385 L
.71244 .67308 L
.71154 .67408 L
.6932 .69231 L
.69231 .6931 L
.67308 .70829 L
.66838 .71154 L
.65385 .72059 L
.63462 .73055 L
.63414 .73077 L
.61538 .73851 L
Mistroke
.59615 .74473 L
.57692 .74936 L
.574 .75 L
.55769 .75252 L
.53846 .75428 L
.51923 .75471 L
.5 .75382 L
.48077 .75162 L
.47058 .75 L
.46154 .74811 L
.44231 .74322 L
.42308 .73692 L
.40764 .73077 L
.40385 .72909 L
.38462 .71961 L
.37058 .71154 L
.36538 .70827 L
.34615 .69479 L
.34294 .69231 L
.32692 .67875 L
.32088 .67308 L
.30769 .65943 L
.30278 .65385 L
.28846 .6356 L
.28776 .63462 L
.27529 .61538 L
.26923 .60454 L
.26502 .59615 L
.25672 .57692 L
.25024 .55769 L
.25 .55691 L
.24547 .53846 L
.24235 .51923 L
.24083 .5 L
.24093 .48077 L
.24266 .46154 L
.24609 .44231 L
.25 .42719 L
.25133 .42308 L
.25851 .40385 L
.26786 .38462 L
.26923 .38214 L
.27971 .36538 L
.28846 .35352 L
.29455 .34615 L
.30769 .33215 L
.3132 .32692 L
.32692 .31529 L
.33716 .30769 L
.34615 .30169 L
Mistroke
.36538 .29066 L
.36974 .28846 L
.38462 .28177 L
.40385 .27473 L
.42308 .26934 L
.42352 .26923 L
.44231 .26548 L
Mfstroke
.5 g
.40385 .30766 m
.42308 .3012 L
.44231 .29656 L
.46154 .29358 L
.48077 .29218 L
.5 .29228 L
.51923 .29388 L
.53846 .29697 L
.55769 .3016 L
.57652 .30769 L
.57692 .30784 L
.59615 .31583 L
.61538 .32574 L
.61745 .32692 L
.63462 .33785 L
.6459 .34615 L
.65385 .35261 L
.66782 .36538 L
.67308 .37074 L
.68533 .38462 L
.69231 .39357 L
.6995 .40385 L
.71093 .42308 L
.71154 .42422 L
.71999 .44231 L
.72694 .46154 L
.73077 .47534 L
.73192 .48077 L
.73501 .5 L
.73628 .51923 L
.73571 .53846 L
.73326 .55769 L
.73077 .57015 L
.72882 .57692 L
.72224 .59615 L
.71325 .61538 L
.71154 .61852 L
.70146 .63462 L
.69231 .64675 L
.68621 .65385 L
.67308 .66716 L
.66638 .67308 L
.65385 .68286 L
.63955 .69231 L
.63462 .69519 L
.61538 .70488 L
.59859 .71154 L
.59615 .71237 L
.57692 .71792 L
.55769 .72173 L
.53846 .72393 L
.51923 .72459 L
.5 .72375 L
.48077 .72142 L
.46154 .71757 L
.44231 .71216 L
.44039 .71154 L
.42308 .70507 L
.40385 .69617 L
.3966 .69231 L
.38462 .68522 L
.36697 .67308 L
.36538 .67188 L
.34615 .65559 L
.34431 .65385 L
.32692 .63541 L
.32625 .63462 L
.31165 .61538 L
.30769 .60941 L
.29985 .59615 L
.29046 .57692 L
.28846 .57221 L
.28322 .55769 L
.27797 .53846 L
.2746 .51923 L
.27307 .5 L
.27338 .48077 L
.27556 .46154 L
.27972 .44231 L
.286 .42308 L
.28846 .41694 L
.29465 .40385 L
.30604 .38462 L
.30769 .3822 L
.32078 .36538 L
.32692 .35863 L
.33992 .34615 L
.34615 .3409 L
.36538 .32707 L
.36561 .32692 L
.38462 .31617 L
.40377 .30769 L
F
0 g
.40385 .30766 m
.42308 .3012 L
.44231 .29656 L
.46154 .29358 L
.48077 .29218 L
.5 .29228 L
.51923 .29388 L
.53846 .29697 L
.55769 .3016 L
.57652 .30769 L
.57692 .30784 L
.59615 .31583 L
.61538 .32574 L
.61745 .32692 L
.63462 .33785 L
.6459 .34615 L
.65385 .35261 L
.66782 .36538 L
.67308 .37074 L
.68533 .38462 L
.69231 .39357 L
.6995 .40385 L
.71093 .42308 L
.71154 .42422 L
.71999 .44231 L
.72694 .46154 L
.73077 .47534 L
.73192 .48077 L
.73501 .5 L
.73628 .51923 L
.73571 .53846 L
.73326 .55769 L
.73077 .57015 L
.72882 .57692 L
.72224 .59615 L
.71325 .61538 L
.71154 .61852 L
.70146 .63462 L
.69231 .64675 L
.68621 .65385 L
.67308 .66716 L
.66638 .67308 L
.65385 .68286 L
.63955 .69231 L
.63462 .69519 L
.61538 .70488 L
.59859 .71154 L
.59615 .71237 L
.57692 .71792 L
.55769 .72173 L
Mistroke
.53846 .72393 L
.51923 .72459 L
.5 .72375 L
.48077 .72142 L
.46154 .71757 L
.44231 .71216 L
.44039 .71154 L
.42308 .70507 L
.40385 .69617 L
.3966 .69231 L
.38462 .68522 L
.36697 .67308 L
.36538 .67188 L
.34615 .65559 L
.34431 .65385 L
.32692 .63541 L
.32625 .63462 L
.31165 .61538 L
.30769 .60941 L
.29985 .59615 L
.29046 .57692 L
.28846 .57221 L
.28322 .55769 L
.27797 .53846 L
.2746 .51923 L
.27307 .5 L
.27338 .48077 L
.27556 .46154 L
.27972 .44231 L
.286 .42308 L
.28846 .41694 L
.29465 .40385 L
.30604 .38462 L
.30769 .3822 L
.32078 .36538 L
.32692 .35863 L
.33992 .34615 L
.34615 .3409 L
.36538 .32707 L
.36561 .32692 L
.38462 .31617 L
.40377 .30769 L
.40385 .30766 L
Mfstroke
.6 g
.44231 .32557 m
.46154 .32193 L
.48077 .32012 L
.5 .32007 L
.51923 .32172 L
.53846 .32509 L
.54636 .32692 L
.55769 .33025 L
.57692 .33732 L
.59553 .34615 L
.59615 .34649 L
.61538 .35809 L
.62559 .36538 L
.63462 .37263 L
.64765 .38462 L
.65385 .39106 L
.66472 .40385 L
.67308 .41527 L
.67811 .42308 L
.68852 .44231 L
.69231 .45074 L
.69636 .46154 L
.70189 .48077 L
.70525 .5 L
.7065 .51923 L
.70564 .53846 L
.70259 .55769 L
.6972 .57692 L
.69231 .5896 L
.68921 .59615 L
.67816 .61538 L
.67308 .62264 L
.66331 .63462 L
.65385 .64443 L
.6432 .65385 L
.63462 .66042 L
.61538 .67254 L
.61441 .67308 L
.59615 .68171 L
.57692 .68846 L
.56187 .69231 L
.55769 .69309 L
.53846 .69582 L
.51923 .69676 L
.5 .69598 L
.48077 .69348 L
.47412 .69231 L
.46154 .68924 L
.44231 .68316 L
.42308 .67509 L
.41893 .67308 L
.40385 .66478 L
.38734 .65385 L
.38462 .65182 L
.36538 .63554 L
.36442 .63462 L
.34675 .61538 L
.34615 .61465 L
.3329 .59615 L
.32692 .58619 L
.3221 .57692 L
.3139 .55769 L
.30806 .53846 L
.30769 .53757 L
.3044 .51923 L
.30285 .5 L
.30342 .48077 L
.30616 .46154 L
.30769 .45405 L
.31121 .44231 L
.31884 .42308 L
.32692 .40788 L
.32945 .40385 L
.34374 .38462 L
.34615 .38186 L
.36303 .36538 L
.36538 .36341 L
.38462 .34957 L
.39028 .34615 L
.40385 .33906 L
.42308 .3312 L
.43679 .32692 L
F
0 g
.44231 .32557 m
.46154 .32193 L
.48077 .32012 L
.5 .32007 L
.51923 .32172 L
.53846 .32509 L
.54636 .32692 L
.55769 .33025 L
.57692 .33732 L
.59553 .34615 L
.59615 .34649 L
.61538 .35809 L
.62559 .36538 L
.63462 .37263 L
.64765 .38462 L
.65385 .39106 L
.66472 .40385 L
.67308 .41527 L
.67811 .42308 L
.68852 .44231 L
.69231 .45074 L
.69636 .46154 L
.70189 .48077 L
.70525 .5 L
.7065 .51923 L
.70564 .53846 L
.70259 .55769 L
.6972 .57692 L
.69231 .5896 L
.68921 .59615 L
.67816 .61538 L
.67308 .62264 L
.66331 .63462 L
.65385 .64443 L
.6432 .65385 L
.63462 .66042 L
.61538 .67254 L
.61441 .67308 L
.59615 .68171 L
.57692 .68846 L
.56187 .69231 L
.55769 .69309 L
.53846 .69582 L
.51923 .69676 L
.5 .69598 L
.48077 .69348 L
.47412 .69231 L
.46154 .68924 L
.44231 .68316 L
.42308 .67509 L
Mistroke
.41893 .67308 L
.40385 .66478 L
.38734 .65385 L
.38462 .65182 L
.36538 .63554 L
.36442 .63462 L
.34675 .61538 L
.34615 .61465 L
.3329 .59615 L
.32692 .58619 L
.3221 .57692 L
.3139 .55769 L
.30806 .53846 L
.30769 .53757 L
.3044 .51923 L
.30285 .5 L
.30342 .48077 L
.30616 .46154 L
.30769 .45405 L
.31121 .44231 L
.31884 .42308 L
.32692 .40788 L
.32945 .40385 L
.34374 .38462 L
.34615 .38186 L
.36303 .36538 L
.36538 .36341 L
.38462 .34957 L
.39028 .34615 L
.40385 .33906 L
.42308 .3312 L
.43679 .32692 L
.44231 .32557 L
Mfstroke
.7 g
.42308 .36117 m
.44231 .35416 L
.46154 .34964 L
.48077 .34731 L
.5 .34703 L
.51923 .34876 L
.53846 .3525 L
.55769 .35837 L
.57454 .36538 L
.57692 .36656 L
.59615 .37742 L
.60657 .38462 L
.61538 .39158 L
.62863 .40385 L
.63462 .41024 L
.645 .42308 L
.65385 .43625 L
.65732 .44231 L
.66639 .46154 L
.67265 .48077 L
.67308 .48247 L
.67634 .5 L
.67757 .51923 L
.67633 .53846 L
.67308 .55703 L
.67249 .55769 L
.6658 .57692 L
.65578 .59615 L
.65385 .59922 L
.64156 .61538 L
.63462 .62282 L
.62131 .63462 L
.61538 .63905 L
.59615 .65079 L
.59003 .65385 L
.57692 .65923 L
.55769 .66498 L
.53846 .66842 L
.51923 .66973 L
.5 .66902 L
.48077 .66631 L
.46154 .66154 L
.44231 .65457 L
.44061 .65385 L
.42308 .64513 L
.40643 .63462 L
.40385 .63275 L
.38462 .6166 L
.38337 .61538 L
.36633 .59615 L
.36538 .59492 L
.3535 .57692 L
.34615 .5627 L
.34401 .55769 L
.33738 .53846 L
.33333 .51923 L
.33177 .5 L
.33267 .48077 L
.33614 .46154 L
.34242 .44231 L
.34615 .43375 L
.35196 .42308 L
.36538 .40405 L
.36556 .40385 L
.38462 .38481 L
.38485 .38462 L
.40385 .37109 L
.41406 .36538 L
F
0 g
.42308 .36117 m
.44231 .35416 L
.46154 .34964 L
.48077 .34731 L
.5 .34703 L
.51923 .34876 L
.53846 .3525 L
.55769 .35837 L
.57454 .36538 L
.57692 .36656 L
.59615 .37742 L
.60657 .38462 L
.61538 .39158 L
.62863 .40385 L
.63462 .41024 L
.645 .42308 L
.65385 .43625 L
.65732 .44231 L
.66639 .46154 L
.67265 .48077 L
.67308 .48247 L
.67634 .5 L
.67757 .51923 L
.67633 .53846 L
.67308 .55703 L
.67249 .55769 L
.6658 .57692 L
.65578 .59615 L
.65385 .59922 L
.64156 .61538 L
.63462 .62282 L
.62131 .63462 L
.61538 .63905 L
.59615 .65079 L
.59003 .65385 L
.57692 .65923 L
.55769 .66498 L
.53846 .66842 L
.51923 .66973 L
.5 .66902 L
.48077 .66631 L
.46154 .66154 L
.44231 .65457 L
.44061 .65385 L
.42308 .64513 L
.40643 .63462 L
.40385 .63275 L
.38462 .6166 L
.38337 .61538 L
.36633 .59615 L
Mistroke
.36538 .59492 L
.3535 .57692 L
.34615 .5627 L
.34401 .55769 L
.33738 .53846 L
.33333 .51923 L
.33177 .5 L
.33267 .48077 L
.33614 .46154 L
.34242 .44231 L
.34615 .43375 L
.35196 .42308 L
.36538 .40405 L
.36556 .40385 L
.38462 .38481 L
.38485 .38462 L
.40385 .37109 L
.41406 .36538 L
.42308 .36117 L
Mfstroke
.8 g
.44231 .38414 m
.46154 .37824 L
.48077 .37514 L
.5 .37456 L
.51923 .37639 L
.53846 .38068 L
.55065 .38462 L
.55769 .38759 L
.57692 .39753 L
.58656 .40385 L
.59615 .41125 L
.60879 .42308 L
.61538 .43041 L
.62433 .44231 L
.63462 .46008 L
.6353 .46154 L
.64265 .48077 L
.64683 .5 L
.64803 .51923 L
.64623 .53846 L
.64121 .55769 L
.63462 .57322 L
.63248 .57692 L
.619 .59615 L
.61538 .60021 L
.59832 .61538 L
.59615 .61695 L
.57692 .62826 L
.56142 .63462 L
.55769 .63576 L
.53846 .64025 L
.51923 .6421 L
.5 .6415 L
.48077 .63848 L
.46591 .63462 L
.46154 .63294 L
.44231 .62462 L
.42658 .61538 L
.42308 .61295 L
.40385 .59686 L
.40314 .59615 L
.38684 .57692 L
.38462 .57378 L
.3753 .55769 L
.36749 .53846 L
.36538 .53451 L
.36289 .51923 L
.36129 .5 L
.36268 .48077 L
.36538 .46783 L
.36724 .46154 L
.37542 .44231 L
.38462 .42762 L
.38818 .42308 L
.40385 .40698 L
.40764 .40385 L
.42308 .39334 L
.44107 .38462 L
F
0 g
.44231 .38414 m
.46154 .37824 L
.48077 .37514 L
.5 .37456 L
.51923 .37639 L
.53846 .38068 L
.55065 .38462 L
.55769 .38759 L
.57692 .39753 L
.58656 .40385 L
.59615 .41125 L
.60879 .42308 L
.61538 .43041 L
.62433 .44231 L
.63462 .46008 L
.6353 .46154 L
.64265 .48077 L
.64683 .5 L
.64803 .51923 L
.64623 .53846 L
.64121 .55769 L
.63462 .57322 L
.63248 .57692 L
.619 .59615 L
.61538 .60021 L
.59832 .61538 L
.59615 .61695 L
.57692 .62826 L
.56142 .63462 L
.55769 .63576 L
.53846 .64025 L
.51923 .6421 L
.5 .6415 L
.48077 .63848 L
.46591 .63462 L
.46154 .63294 L
.44231 .62462 L
.42658 .61538 L
.42308 .61295 L
.40385 .59686 L
.40314 .59615 L
.38684 .57692 L
.38462 .57378 L
.3753 .55769 L
.36749 .53846 L
.36538 .53451 L
.36289 .51923 L
.36129 .5 L
.36268 .48077 L
.36538 .46783 L
Mistroke
.36724 .46154 L
.37542 .44231 L
.38462 .42762 L
.38818 .42308 L
.40385 .40698 L
.40764 .40385 L
.42308 .39334 L
.44107 .38462 L
.44231 .38414 L
Mfstroke
.9 g
.44231 .41869 m
.46154 .41018 L
.48077 .40573 L
.5 .40462 L
.51923 .40662 L
.53846 .41183 L
.55769 .42071 L
.56174 .42308 L
.57692 .43418 L
.58546 .44231 L
.59615 .45519 L
.60025 .46154 L
.60958 .48077 L
.61458 .5 L
.61538 .50653 L
.61571 .51923 L
.61538 .52413 L
.61296 .53846 L
.6058 .55769 L
.59615 .5731 L
.59288 .57692 L
.57692 .59162 L
.57032 .59615 L
.55769 .60268 L
.53846 .6091 L
.51923 .61188 L
.5 .61146 L
.48077 .60792 L
.46154 .60099 L
.45184 .59615 L
.44231 .59009 L
.42645 .57692 L
.42308 .57351 L
.41072 .55769 L
.40385 .54594 L
.40077 .53846 L
.39519 .51923 L
.39353 .5 L
.39576 .48077 L
.40231 .46154 L
.40385 .45823 L
.4143 .44231 L
.42308 .43278 L
.43517 .42308 L
F
0 g
.44231 .41869 m
.46154 .41018 L
.48077 .40573 L
.5 .40462 L
.51923 .40662 L
.53846 .41183 L
.55769 .42071 L
.56174 .42308 L
.57692 .43418 L
.58546 .44231 L
.59615 .45519 L
.60025 .46154 L
.60958 .48077 L
.61458 .5 L
.61538 .50653 L
.61571 .51923 L
.61538 .52413 L
.61296 .53846 L
.6058 .55769 L
.59615 .5731 L
.59288 .57692 L
.57692 .59162 L
.57032 .59615 L
.55769 .60268 L
.53846 .6091 L
.51923 .61188 L
.5 .61146 L
.48077 .60792 L
.46154 .60099 L
.45184 .59615 L
.44231 .59009 L
.42645 .57692 L
.42308 .57351 L
.41072 .55769 L
.40385 .54594 L
.40077 .53846 L
.39519 .51923 L
.39353 .5 L
.39576 .48077 L
.40231 .46154 L
.40385 .45823 L
.4143 .44231 L
.42308 .43278 L
.43517 .42308 L
.44231 .41869 L
s
1 g
.5 .44212 m
.50516 .44231 L
.51923 .44449 L
.53846 .45215 L
.55183 .46154 L
.55769 .46699 L
.56719 .48077 L
.57436 .5 L
.57532 .51923 L
.57008 .53846 L
.55769 .55613 L
.55584 .55769 L
.53846 .56882 L
.51923 .57404 L
.5 .57407 L
.48077 .56922 L
.46154 .55804 L
.46108 .55769 L
.44377 .53846 L
.44231 .53583 L
.43557 .51923 L
.43375 .5 L
.43825 .48077 L
.44231 .47107 L
.45077 .46154 L
.46154 .45285 L
.48077 .4445 L
.49461 .44231 L
F
0 g
.5 .44212 m
.50516 .44231 L
.51923 .44449 L
.53846 .45215 L
.55183 .46154 L
.55769 .46699 L
.56719 .48077 L
.57436 .5 L
.57532 .51923 L
.57008 .53846 L
.55769 .55613 L
.55584 .55769 L
.53846 .56882 L
.51923 .57404 L
.5 .57407 L
.48077 .56922 L
.46154 .55804 L
.46108 .55769 L
.44377 .53846 L
.44231 .53583 L
.43557 .51923 L
.43375 .5 L
.43825 .48077 L
.44231 .47107 L
.45077 .46154 L
.46154 .45285 L
.48077 .4445 L
.49461 .44231 L
.5 .44212 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.662 .742 .909 r
.39902 .59807 .40512 .60372 .41536 .60067 .40928 .59501 Mtetra
.662 .742 .91 r
.40928 .59501 .41536 .60067 .42565 .59762 .41959 .59195 Mtetra
.661 .743 .91 r
.41959 .59195 .42565 .59762 .43597 .59457 .42994 .58889 Mtetra
.661 .743 .911 r
.42994 .58889 .43597 .59457 .44633 .59151 .44032 .58583 Mtetra
.66 .743 .912 r
.44032 .58583 .44633 .59151 .45673 .58846 .45075 .58278 Mtetra
.659 .744 .913 r
.45075 .58278 .45673 .58846 .46717 .58541 .46122 .57974 Mtetra
.659 .745 .914 r
.46122 .57974 .46717 .58541 .47765 .58236 .47172 .5767 Mtetra
.658 .746 .915 r
.47172 .5767 .47765 .58236 .48818 .57932 .48227 .57368 Mtetra
.656 .747 .917 r
.48227 .57368 .48818 .57932 .49874 .57628 .49286 .57067 Mtetra
.655 .748 .918 r
.49286 .57067 .49874 .57628 .50935 .57326 .50349 .56768 Mtetra
.654 .75 .92 r
.50349 .56768 .50935 .57326 .51999 .57024 .51417 .56471 Mtetra
.653 .752 .923 r
.51417 .56471 .51999 .57024 .53068 .56723 .52489 .56175 Mtetra
.651 .754 .925 r
.52489 .56175 .53068 .56723 .54142 .56423 .53565 .55881 Mtetra
.65 .757 .927 r
.53565 .55881 .54142 .56423 .55219 .56124 .54645 .55588 Mtetra
.649 .759 .93 r
.54645 .55588 .55219 .56124 .56301 .55825 .55731 .55296 Mtetra
.647 .762 .933 r
.55731 .55296 .56301 .55825 .57388 .55527 .5682 .55005 Mtetra
.646 .766 .936 r
.5682 .55005 .57388 .55527 .58479 .55228 .57914 .54713 Mtetra
.645 .769 .938 r
.57914 .54713 .58479 .55228 .59574 .54928 .59013 .54421 Mtetra
.645 .773 .941 r
.59013 .54421 .59574 .54928 .60674 .54626 .60116 .54127 Mtetra
.645 .776 .943 r
.60116 .54127 .60674 .54626 .61778 .54322 .61224 .5383 Mtetra
.645 .78 .946 r
.61224 .5383 .61778 .54322 .62887 .54015 .62337 .5353 Mtetra
.646 .784 .948 r
.62337 .5353 .62887 .54015 .64001 .53705 .63454 .53225 Mtetra
.647 .787 .949 r
.63454 .53225 .64001 .53705 .65119 .5339 .64575 .52915 Mtetra
.648 .79 .95 r
.64575 .52915 .65119 .5339 .66241 .53071 .65702 .52598 Mtetra
.65 .793 .951 r
.65702 .52598 .66241 .53071 .67368 .52746 .66832 .52274 Mtetra
.652 .795 .951 r
.66832 .52274 .67368 .52746 .68499 .52415 .67967 .51943 Mtetra
.655 .797 .95 r
.67967 .51943 .68499 .52415 .69634 .52078 .69106 .51604 Mtetra
.657 .798 .95 r
.69106 .51604 .69634 .52078 .70774 .51735 .70249 .51257 Mtetra
.66 .798 .948 r
.70249 .51257 .70774 .51735 .71918 .51385 .71397 .50902 Mtetra
.663 .798 .947 r
.71397 .50902 .71918 .51385 .73066 .5103 .72549 .5054 Mtetra
.666 .797 .945 r
.72549 .5054 .73066 .5103 .74219 .50668 .73705 .5017 Mtetra
.668 .795 .943 r
.73705 .5017 .74219 .50668 .75376 .50302 .74865 .49794 Mtetra
.67 .793 .94 r
.74865 .49794 .75376 .50302 .76537 .49931 .7603 .49412 Mtetra
.672 .79 .937 r
.7603 .49412 .76537 .49931 .77703 .49557 .77198 .49026 Mtetra
.673 .787 .935 r
.77198 .49026 .77703 .49557 .78873 .49179 .78372 .48636 Mtetra
.674 .784 .932 r
.78372 .48636 .78873 .49179 .80047 .48798 .79549 .48243 Mtetra
.674 .78 .929 r
.79549 .48243 .80047 .48798 .81226 .48416 .80731 .47847 Mtetra
.674 .776 .927 r
.80731 .47847 .81226 .48416 .8241 .48032 .81918 .47451 Mtetra
.674 .773 .924 r
.81918 .47451 .8241 .48032 .83599 .47648 .8311 .47055 Mtetra
.674 .769 .922 r
.8311 .47055 .83599 .47648 .84792 .47263 .84306 .46658 Mtetra
.673 .766 .92 r
.84306 .46658 .84792 .47263 .8599 .46879 .85507 .46262 Mtetra
.672 .762 .918 r
.85507 .46262 .8599 .46879 .87194 .46495 .86713 .45868 Mtetra
.672 .759 .916 r
.86713 .45868 .87194 .46495 .88402 .46111 .87925 .45475 Mtetra
.671 .757 .915 r
.87925 .45475 .88402 .46111 .89615 .45729 .89141 .45083 Mtetra
.67 .754 .914 r
.89141 .45083 .89615 .45729 .90834 .45346 .90363 .44692 Mtetra
.669 .752 .913 r
.90363 .44692 .90834 .45346 .92058 .44965 .9159 .44303 Mtetra
.668 .75 .912 r
.9159 .44303 .92058 .44965 .93287 .44584 .92822 .43915 Mtetra
.668 .748 .911 r
.92822 .43915 .93287 .44584 .94521 .44203 .9406 .43528 Mtetra
.667 .747 .91 r
.9406 .43528 .94521 .44203 .95761 .43822 .95303 .43142 Mtetra
.666 .746 .91 r
.95303 .43142 .95761 .43822 .97006 .43442 .96552 .42756 Mtetra
.662 .742 .91 r
.39287 .59238 .39902 .59807 .40928 .59501 .40316 .58932 Mtetra
.661 .742 .91 r
.40316 .58932 .40928 .59501 .41959 .59195 .41349 .58625 Mtetra
.661 .743 .911 r
.41349 .58625 .41959 .59195 .42994 .58889 .42386 .58319 Mtetra
.66 .743 .912 r
.42386 .58319 .42994 .58889 .44032 .58583 .43427 .58014 Mtetra
.659 .744 .913 r
.43427 .58014 .44032 .58583 .45075 .58278 .44472 .5771 Mtetra
.658 .745 .914 r
.44472 .5771 .45075 .58278 .46122 .57974 .45522 .57407 Mtetra
.657 .746 .916 r
.45522 .57407 .46122 .57974 .47172 .5767 .46575 .57106 Mtetra
.655 .747 .917 r
.46575 .57106 .47172 .5767 .48227 .57368 .47632 .56807 Mtetra
.654 .749 .919 r
.47632 .56807 .48227 .57368 .49286 .57067 .48694 .5651 Mtetra
.652 .75 .922 r
.48694 .5651 .49286 .57067 .50349 .56768 .4976 .56216 Mtetra
.65 .753 .924 r
.4976 .56216 .50349 .56768 .51417 .56471 .5083 .55925 Mtetra
.648 .755 .927 r
.5083 .55925 .51417 .56471 .52489 .56175 .51905 .55637 Mtetra
.646 .758 .93 r
.51905 .55637 .52489 .56175 .53565 .55881 .52984 .5535 Mtetra
.644 .761 .934 r
.52984 .5535 .53565 .55881 .54645 .55588 .54067 .55067 Mtetra
.643 .765 .937 r
.54067 .55067 .54645 .55588 .55731 .55296 .55156 .54784 Mtetra
.641 .769 .941 r
.55156 .54784 .55731 .55296 .5682 .55005 .56248 .54503 Mtetra
.639 .773 .944 r
.56248 .54503 .5682 .55005 .57914 .54713 .57346 .54222 Mtetra
.638 .777 .948 r
.57346 .54222 .57914 .54713 .59013 .54421 .58448 .5394 Mtetra
.637 .782 .951 r
.58448 .5394 .59013 .54421 .60116 .54127 .59555 .53657 Mtetra
.636 .787 .954 r
.59555 .53657 .60116 .54127 .61224 .5383 .60667 .5337 Mtetra
.636 .792 .957 r
.60667 .5337 .61224 .5383 .62337 .5353 .61783 .53078 Mtetra
.637 .797 .959 r
.61783 .53078 .62337 .5353 .63454 .53225 .62904 .52781 Mtetra
.638 .801 .961 r
.62904 .52781 .63454 .53225 .64575 .52915 .64029 .52477 Mtetra
.64 .805 .962 r
.64029 .52477 .64575 .52915 .65702 .52598 .65159 .52165 Mtetra
.643 .809 .963 r
.65159 .52165 .65702 .52598 .66832 .52274 .66294 .51844 Mtetra
.646 .811 .963 r
.66294 .51844 .66832 .52274 .67967 .51943 .67432 .51513 Mtetra
.65 .814 .962 r
.67432 .51513 .67967 .51943 .69106 .51604 .68575 .51172 Mtetra
.653 .815 .961 r
.68575 .51172 .69106 .51604 .70249 .51257 .69723 .50821 Mtetra
.657 .815 .959 r
.69723 .50821 .70249 .51257 .71397 .50902 .70874 .5046 Mtetra
.661 .815 .957 r
.70874 .5046 .71397 .50902 .72549 .5054 .72029 .50089 Mtetra
.665 .814 .955 r
.72029 .50089 .72549 .5054 .73705 .5017 .73189 .49709 Mtetra
.669 .811 .952 r
.73189 .49709 .73705 .5017 .74865 .49794 .74353 .4932 Mtetra
.672 .808 .948 r
.74353 .4932 .74865 .49794 .7603 .49412 .7552 .48925 Mtetra
.674 .805 .945 r
.7552 .48925 .7603 .49412 .77198 .49026 .76692 .48524 Mtetra
.676 .801 .942 r
.76692 .48524 .77198 .49026 .78372 .48636 .77869 .48119 Mtetra
.677 .796 .938 r
.77869 .48119 .78372 .48636 .79549 .48243 .79049 .4771 Mtetra
.678 .792 .935 r
.79049 .4771 .79549 .48243 .80731 .47847 .80234 .47299 Mtetra
.678 .787 .932 r
.80234 .47299 .80731 .47847 .81918 .47451 .81424 .46887 Mtetra
.678 .782 .929 r
.81424 .46887 .81918 .47451 .8311 .47055 .82618 .46476 Mtetra
.677 .777 .926 r
.82618 .46476 .8311 .47055 .84306 .46658 .83817 .46065 Mtetra
.676 .773 .923 r
.83817 .46065 .84306 .46658 .85507 .46262 .85021 .45655 Mtetra
.676 .769 .921 r
.85021 .45655 .85507 .46262 .86713 .45868 .8623 .45248 Mtetra
.674 .765 .919 r
.8623 .45248 .86713 .45868 .87925 .45475 .87445 .44843 Mtetra
.673 .761 .917 r
.87445 .44843 .87925 .45475 .89141 .45083 .88664 .4444 Mtetra
.672 .758 .915 r
.88664 .4444 .89141 .45083 .90363 .44692 .89889 .4404 Mtetra
.671 .755 .914 r
.89889 .4404 .90363 .44692 .9159 .44303 .91119 .43642 Mtetra
.67 .753 .913 r
.91119 .43642 .9159 .44303 .92822 .43915 .92355 .43246 Mtetra
.669 .75 .912 r
.92355 .43246 .92822 .43915 .9406 .43528 .93596 .42851 Mtetra
.668 .749 .911 r
.93596 .42851 .9406 .43528 .95303 .43142 .94843 .42458 Mtetra
.667 .747 .91 r
.94843 .42458 .95303 .43142 .96552 .42756 .96095 .42067 Mtetra
.661 .742 .91 r
.38668 .58667 .39287 .59238 .40316 .58932 .39699 .5836 Mtetra
.66 .743 .911 r
.39699 .5836 .40316 .58932 .41349 .58625 .40735 .58053 Mtetra
.66 .743 .912 r
.40735 .58053 .41349 .58625 .42386 .58319 .41774 .57748 Mtetra
.659 .744 .913 r
.41774 .57748 .42386 .58319 .43427 .58014 .42818 .57444 Mtetra
.657 .745 .914 r
.42818 .57444 .43427 .58014 .44472 .5771 .43865 .57141 Mtetra
.656 .746 .916 r
.43865 .57141 .44472 .5771 .45522 .57407 .44917 .56841 Mtetra
.654 .747 .918 r
.44917 .56841 .45522 .57407 .46575 .57106 .45973 .56544 Mtetra
.652 .749 .92 r
.45973 .56544 .46575 .57106 .47632 .56807 .47033 .5625 Mtetra
.65 .751 .923 r
.47033 .5625 .47632 .56807 .48694 .5651 .48097 .5596 Mtetra
.648 .753 .926 r
.48097 .5596 .48694 .5651 .4976 .56216 .49166 .55673 Mtetra
.645 .756 .929 r
.49166 .55673 .4976 .56216 .5083 .55925 .50239 .55391 Mtetra
.643 .759 .933 r
.50239 .55391 .5083 .55925 .51905 .55637 .51316 .55112 Mtetra
.64 .763 .937 r
.51316 .55112 .51905 .55637 .52984 .5535 .52398 .54837 Mtetra
.637 .767 .941 r
.52398 .54837 .52984 .5535 .54067 .55067 .53485 .54565 Mtetra
.634 .771 .946 r
.53485 .54565 .54067 .55067 .55156 .54784 .54576 .54296 Mtetra
.631 .776 .95 r
.54576 .54296 .55156 .54784 .56248 .54503 .55673 .54028 Mtetra
.629 .782 .955 r
.55673 .54028 .56248 .54503 .57346 .54222 .56773 .53761 Mtetra
.626 .787 .959 r
.56773 .53761 .57346 .54222 .58448 .5394 .57879 .53494 Mtetra
.624 .793 .963 r
.57879 .53494 .58448 .5394 .59555 .53657 .5899 .53224 Mtetra
.623 .8 .967 r
.5899 .53224 .59555 .53657 .60667 .5337 .60105 .5295 Mtetra
.623 .806 .97 r
.60105 .5295 .60667 .5337 .61783 .53078 .61226 .5267 Mtetra
.623 .812 .973 r
.61226 .5267 .61783 .53078 .62904 .52781 .62351 .52383 Mtetra
.625 .818 .974 r
.62351 .52383 .62904 .52781 .64029 .52477 .6348 .52088 Mtetra
.627 .823 .976 r
.6348 .52088 .64029 .52477 .65159 .52165 .64614 .51782 Mtetra
.631 .827 .976 r
.64614 .51782 .65159 .52165 .66294 .51844 .65753 .51464 Mtetra
.635 .831 .976 r
.65753 .51464 .66294 .51844 .67432 .51513 .66896 .51134 Mtetra
.641 .834 .975 r
.66896 .51134 .67432 .51513 .68575 .51172 .68043 .50791 Mtetra
.646 .836 .973 r
.68043 .50791 .68575 .51172 .69723 .50821 .69194 .50435 Mtetra
.652 .837 .971 r
.69194 .50435 .69723 .50821 .70874 .5046 .70349 .50066 Mtetra
.658 .836 .968 r
.70349 .50066 .70874 .5046 .72029 .50089 .71509 .49684 Mtetra
.664 .834 .965 r
.71509 .49684 .72029 .50089 .73189 .49709 .72672 .49292 Mtetra
.669 .831 .962 r
.72672 .49292 .73189 .49709 .74353 .4932 .73839 .48889 Mtetra
.673 .828 .958 r
.73839 .48889 .74353 .4932 .7552 .48925 .7501 .48477 Mtetra
.677 .823 .954 r
.7501 .48477 .7552 .48925 .76692 .48524 .76185 .48058 Mtetra
.679 .818 .949 r
.76185 .48058 .76692 .48524 .77869 .48119 .77364 .47634 Mtetra
.681 .812 .945 r
.77364 .47634 .77869 .48119 .79049 .4771 .78547 .47206 Mtetra
.682 .806 .941 r
.78547 .47206 .79049 .4771 .80234 .47299 .79735 .46776 Mtetra
.683 .799 .937 r
.79735 .46776 .80234 .47299 .81424 .46887 .80928 .46345 Mtetra
.682 .793 .933 r
.80928 .46345 .81424 .46887 .82618 .46476 .82125 .45915 Mtetra
.682 .787 .93 r
.82125 .45915 .82618 .46476 .83817 .46065 .83326 .45486 Mtetra
.681 .781 .926 r
.83326 .45486 .83817 .46065 .85021 .45655 .84533 .4506 Mtetra
.679 .776 .923 r
.84533 .4506 .85021 .45655 .8623 .45248 .85745 .44637 Mtetra
.678 .771 .921 r
.85745 .44637 .8623 .45248 .87445 .44843 .86962 .44218 Mtetra
.676 .766 .919 r
.86962 .44218 .87445 .44843 .88664 .4444 .88184 .43802 Mtetra
.675 .762 .917 r
.88184 .43802 .88664 .4444 .89889 .4404 .89412 .4339 Mtetra
.673 .759 .915 r
.89412 .4339 .89889 .4404 .91119 .43642 .90646 .42982 Mtetra
.672 .756 .914 r
.90646 .42982 .91119 .43642 .92355 .43246 .91884 .42576 Mtetra
.67 .753 .912 r
.91884 .42576 .92355 .43246 .93596 .42851 .93129 .42173 Mtetra
.669 .751 .911 r
.93129 .42173 .93596 .42851 .94843 .42458 .94379 .41773 Mtetra
.668 .749 .911 r
.94379 .41773 .94843 .42458 .96095 .42067 .95635 .41374 Mtetra
.66 .743 .911 r
.38044 .58093 .38668 .58667 .39699 .5836 .39078 .57786 Mtetra
.659 .743 .912 r
.39078 .57786 .39699 .5836 .40735 .58053 .40116 .5748 Mtetra
.658 .744 .913 r
.40116 .5748 .40735 .58053 .41774 .57748 .41158 .57176 Mtetra
.657 .745 .915 r
.41158 .57176 .41774 .57748 .42818 .57444 .42204 .56874 Mtetra
.655 .746 .916 r
.42204 .56874 .42818 .57444 .43865 .57141 .43254 .56574 Mtetra
.653 .747 .919 r
.43254 .56574 .43865 .57141 .44917 .56841 .44308 .56279 Mtetra
.651 .749 .921 r
.44308 .56279 .44917 .56841 .45973 .56544 .45366 .55987 Mtetra
.649 .751 .924 r
.45366 .55987 .45973 .56544 .47033 .5625 .46429 .557 Mtetra
.646 .753 .927 r
.46429 .557 .47033 .5625 .48097 .5596 .47496 .55418 Mtetra
.642 .756 .931 r
.47496 .55418 .48097 .5596 .49166 .55673 .48567 .55141 Mtetra
.639 .759 .936 r
.48567 .55141 .49166 .55673 .50239 .55391 .49643 .5487 Mtetra
.635 .763 .94 r
.49643 .5487 .50239 .55391 .51316 .55112 .50723 .54604 Mtetra
.631 .768 .945 r
.50723 .54604 .51316 .55112 .52398 .54837 .51808 .54344 Mtetra
.626 .773 .951 r
.51808 .54344 .52398 .54837 .53485 .54565 .52898 .54088 Mtetra
.622 .779 .956 r
.52898 .54088 .53485 .54565 .54576 .54296 .53993 .53835 Mtetra
.617 .785 .962 r
.53993 .53835 .54576 .54296 .55673 .54028 .55092 .53586 Mtetra
.613 .792 .967 r
.55092 .53586 .55673 .54028 .56773 .53761 .56197 .53337 Mtetra
.609 .799 .972 r
.56197 .53337 .56773 .53761 .57879 .53494 .57306 .53088 Mtetra
.606 .806 .977 r
.57306 .53088 .57879 .53494 .5899 .53224 .58421 .52836 Mtetra
.603 .814 .981 r
.58421 .52836 .5899 .53224 .60105 .5295 .5954 .52579 Mtetra
.602 .821 .984 r
.5954 .52579 .60105 .5295 .61226 .5267 .60665 .52315 Mtetra
.602 .829 .986 r
.60665 .52315 .61226 .5267 .62351 .52383 .61794 .52041 Mtetra
.603 .836 .988 r
.61794 .52041 .62351 .52383 .6348 .52088 .62928 .51757 Mtetra
.607 .843 .989 r
.62928 .51757 .6348 .52088 .64614 .51782 .64067 .51459 Mtetra
.611 .848 .989 r
.64067 .51459 .64614 .51782 .65753 .51464 .6521 .51146 Mtetra
.618 .853 .988 r
.6521 .51146 .65753 .51464 .66896 .51134 .66357 .50817 Mtetra
.625 .857 .986 r
.66357 .50817 .66896 .51134 .68043 .50791 .67508 .50472 Mtetra
.634 .86 .985 r
.67508 .50472 .68043 .50791 .69194 .50435 .68664 .5011 Mtetra
.643 .861 .982 r
.68664 .5011 .69194 .50435 .70349 .50066 .69823 .49731 Mtetra
.652 .861 .979 r
.69823 .49731 .70349 .50066 .71509 .49684 .70986 .49337 Mtetra
.66 .859 .975 r
.70986 .49337 .71509 .49684 .72672 .49292 .72153 .48929 Mtetra
.668 .855 .971 r
.72153 .48929 .72672 .49292 .73839 .48889 .73324 .48508 Mtetra
.674 .851 .967 r
.73324 .48508 .73839 .48889 .7501 .48477 .74498 .48075 Mtetra
.679 .845 .962 r
.74498 .48075 .7501 .48477 .76185 .48058 .75676 .47635 Mtetra
.683 .838 .957 r
.75676 .47635 .76185 .48058 .77364 .47634 .76858 .47187 Mtetra
.686 .83 .952 r
.76858 .47187 .77364 .47634 .78547 .47206 .78044 .46736 Mtetra
.688 .822 .947 r
.78044 .46736 .78547 .47206 .79735 .46776 .79235 .46282 Mtetra
.688 .814 .943 r
.79235 .46282 .79735 .46776 .80928 .46345 .8043 .45828 Mtetra
.688 .806 .938 r
.8043 .45828 .80928 .46345 .82125 .45915 .81629 .45376 Mtetra
.687 .799 .934 r
.81629 .45376 .82125 .45915 .83326 .45486 .82834 .44926 Mtetra
.686 .791 .93 r
.82834 .44926 .83326 .45486 .84533 .4506 .84043 .4448 Mtetra
.684 .785 .927 r
.84043 .4448 .84533 .4506 .85745 .44637 .85257 .44038 Mtetra
.682 .778 .923 r
.85257 .44038 .85745 .44637 .86962 .44218 .86477 .43602 Mtetra
.68 .773 .921 r
.86477 .43602 .86962 .44218 .88184 .43802 .87702 .43171 Mtetra
.678 .767 .918 r
.87702 .43171 .88184 .43802 .89412 .4339 .88933 .42745 Mtetra
.676 .763 .916 r
.88933 .42745 .89412 .4339 .90646 .42982 .90169 .42324 Mtetra
.674 .759 .915 r
.90169 .42324 .90646 .42982 .91884 .42576 .91411 .41907 Mtetra
.673 .756 .913 r
.91411 .41907 .91884 .42576 .93129 .42173 .92659 .41495 Mtetra
.671 .753 .912 r
.92659 .41495 .93129 .42173 .94379 .41773 .93912 .41086 Mtetra
.67 .75 .911 r
.93912 .41086 .94379 .41773 .95635 .41374 .95171 .4068 Mtetra
.659 .743 .912 r
.37416 .57517 .38044 .58093 .39078 .57786 .38452 .5721 Mtetra
.658 .744 .913 r
.38452 .5721 .39078 .57786 .40116 .5748 .39492 .56906 Mtetra
.657 .744 .915 r
.39492 .56906 .40116 .5748 .41158 .57176 .40537 .56603 Mtetra
.655 .745 .917 r
.40537 .56603 .41158 .57176 .42204 .56874 .41585 .56305 Mtetra
.653 .747 .919 r
.41585 .56305 .42204 .56874 .43254 .56574 .42638 .5601 Mtetra
.65 .748 .922 r
.42638 .5601 .43254 .56574 .44308 .56279 .43694 .5572 Mtetra
.647 .75 .925 r
.43694 .5572 .44308 .56279 .45366 .55987 .44755 .55436 Mtetra
.644 .753 .928 r
.44755 .55436 .45366 .55987 .46429 .557 .4582 .55158 Mtetra
.64 .756 .933 r
.4582 .55158 .46429 .557 .47496 .55418 .46889 .54887 Mtetra
.635 .759 .938 r
.46889 .54887 .47496 .55418 .48567 .55141 .47963 .54623 Mtetra
.63 .764 .943 r
.47963 .54623 .48567 .55141 .49643 .5487 .49042 .54366 Mtetra
.624 .768 .949 r
.49042 .54366 .49643 .5487 .50723 .54604 .50125 .54118 Mtetra
.618 .774 .955 r
.50125 .54118 .50723 .54604 .51808 .54344 .51213 .53876 Mtetra
.612 .78 .962 r
.51213 .53876 .51808 .54344 .52898 .54088 .52306 .5364 Mtetra
.605 .787 .968 r
.52306 .5364 .52898 .54088 .53993 .53835 .53404 .5341 Mtetra
.597 .794 .975 r
.53404 .5341 .53993 .53835 .55092 .53586 .54507 .53183 Mtetra
.59 .802 .981 r
.54507 .53183 .55092 .53586 .56197 .53337 .55615 .52957 Mtetra
.583 .811 .986 r
.55615 .52957 .56197 .53337 .57306 .53088 .56729 .52731 Mtetra
.577 .819 .99 r
.56729 .52731 .57306 .53088 .58421 .52836 .57847 .52502 Mtetra
.572 .828 .994 r
.57847 .52502 .58421 .52836 .5954 .52579 .58971 .52266 Mtetra
.568 .836 .996 r
.58971 .52266 .5954 .52579 .60665 .52315 .601 .52021 Mtetra
.567 .845 .997 r
.601 .52021 .60665 .52315 .61794 .52041 .61234 .51765 Mtetra
.568 .853 .997 r
.61234 .51765 .61794 .52041 .62928 .51757 .62373 .51494 Mtetra
.572 .861 .996 r
.62373 .51494 .62928 .51757 .64067 .51459 .63516 .51207 Mtetra
.578 .868 .995 r
.63516 .51207 .64067 .51459 .6521 .51146 .64664 .509 Mtetra
.587 .874 .994 r
.64664 .509 .6521 .51146 .66357 .50817 .65816 .50573 Mtetra
.599 .88 .992 r
.65816 .50573 .66357 .50817 .67508 .50472 .66972 .50226 Mtetra
.611 .884 .99 r
.66972 .50226 .67508 .50472 .68664 .5011 .68132 .49856 Mtetra
.625 .886 .988 r
.68132 .49856 .68664 .5011 .69823 .49731 .69296 .49466 Mtetra
.639 .887 .986 r
.69296 .49466 .69823 .49731 .70986 .49337 .70463 .49057 Mtetra
.652 .885 .983 r
.70463 .49057 .70986 .49337 .72153 .48929 .71634 .48629 Mtetra
.663 .882 .979 r
.71634 .48629 .72153 .48929 .73324 .48508 .72808 .48186 Mtetra
.673 .877 .975 r
.72808 .48186 .73324 .48508 .74498 .48075 .73985 .47729 Mtetra
.681 .87 .97 r
.73985 .47729 .74498 .48075 .75676 .47635 .75167 .47261 Mtetra
.688 .861 .965 r
.75167 .47261 .75676 .47635 .76858 .47187 .76352 .46786 Mtetra
.692 .852 .959 r
.76352 .46786 .76858 .47187 .78044 .46736 .7754 .46306 Mtetra
.694 .842 .954 r
.7754 .46306 .78044 .46736 .79235 .46282 .78733 .45824 Mtetra
.695 .832 .948 r
.78733 .45824 .79235 .46282 .8043 .45828 .79931 .45342 Mtetra
.695 .822 .943 r
.79931 .45342 .8043 .45828 .81629 .45376 .81132 .44862 Mtetra
.694 .812 .938 r
.81132 .44862 .81629 .45376 .82834 .44926 .82339 .44387 Mtetra
.692 .803 .934 r
.82339 .44387 .82834 .44926 .84043 .4448 .83551 .43917 Mtetra
.69 .795 .93 r
.83551 .43917 .84043 .4448 .85257 .44038 .84767 .43453 Mtetra
.688 .787 .926 r
.84767 .43453 .85257 .44038 .86477 .43602 .85989 .42996 Mtetra
.685 .78 .923 r
.85989 .42996 .86477 .43602 .87702 .43171 .87217 .42547 Mtetra
.682 .773 .92 r
.87217 .42547 .87702 .43171 .88933 .42745 .8845 .42104 Mtetra
.68 .768 .918 r
.8845 .42104 .88933 .42745 .90169 .42324 .89689 .41669 Mtetra
.677 .763 .916 r
.89689 .41669 .90169 .42324 .91411 .41907 .90934 .4124 Mtetra
.675 .759 .914 r
.90934 .4124 .91411 .41907 .92659 .41495 .92185 .40816 Mtetra
.673 .755 .913 r
.92185 .40816 .92659 .41495 .93912 .41086 .93442 .40397 Mtetra
.671 .753 .912 r
.93442 .40397 .93912 .41086 .95171 .4068 .94704 .39983 Mtetra
.658 .743 .913 r
.36783 .56939 .37416 .57517 .38452 .5721 .37822 .56633 Mtetra
.656 .744 .915 r
.37822 .56633 .38452 .5721 .39492 .56906 .38864 .5633 Mtetra
.654 .745 .916 r
.38864 .5633 .39492 .56906 .40537 .56603 .39911 .56031 Mtetra
.652 .746 .919 r
.39911 .56031 .40537 .56603 .41585 .56305 .40962 .55737 Mtetra
.649 .748 .922 r
.40962 .55737 .41585 .56305 .42638 .5601 .42016 .55448 Mtetra
.646 .75 .925 r
.42016 .55448 .42638 .5601 .43694 .5572 .43075 .55166 Mtetra
.642 .752 .929 r
.43075 .55166 .43694 .5572 .44755 .55436 .44139 .54892 Mtetra
.637 .755 .934 r
.44139 .54892 .44755 .55436 .4582 .55158 .45206 .54626 Mtetra
.632 .759 .939 r
.45206 .54626 .4582 .55158 .46889 .54887 .46278 .54369 Mtetra
.625 .763 .945 r
.46278 .54369 .46889 .54887 .47963 .54623 .47355 .54121 Mtetra
.618 .768 .952 r
.47355 .54121 .47963 .54623 .49042 .54366 .48436 .53884 Mtetra
.61 .774 .959 r
.48436 .53884 .49042 .54366 .50125 .54118 .49522 .53656 Mtetra
.601 .78 .966 r
.49522 .53656 .50125 .54118 .51213 .53876 .50613 .53438 Mtetra
.591 .787 .974 r
.50613 .53438 .51213 .53876 .52306 .5364 .51709 .53228 Mtetra
.58 .795 .981 r
.51709 .53228 .52306 .5364 .53404 .5341 .5281 .53024 Mtetra
.568 .803 .988 r
.5281 .53024 .53404 .5341 .54507 .53183 .53917 .52826 Mtetra
.556 .811 .993 r
.53917 .52826 .54507 .53183 .55615 .52957 .55029 .52629 Mtetra
.543 .82 .997 r
.55029 .52629 .55615 .52957 .56729 .52731 .56147 .52432 Mtetra
.532 .828 .999 r
.56147 .52432 .56729 .52731 .57847 .52502 .5727 .5223 Mtetra
.522 .837 .999 r
.5727 .5223 .57847 .52502 .58971 .52266 .58398 .52021 Mtetra
.514 .845 .998 r
.58398 .52021 .58971 .52266 .601 .52021 .59532 .51801 Mtetra
.509 .853 .995 r
.59532 .51801 .601 .52021 .61234 .51765 .60671 .51566 Mtetra
.509 .861 .991 r
.60671 .51566 .61234 .51765 .62373 .51494 .61815 .51312 Mtetra
.513 .869 .987 r
.61815 .51312 .62373 .51494 .63516 .51207 .62963 .51037 Mtetra
.522 .877 .984 r
.62963 .51037 .63516 .51207 .64664 .509 .64116 .50738 Mtetra
.535 .886 .982 r
.64116 .50738 .64664 .509 .65816 .50573 .65273 .50414 Mtetra
.552 .894 .981 r
.65273 .50414 .65816 .50573 .66972 .50226 .66434 .50063 Mtetra
.572 .902 .981 r
.66434 .50063 .66972 .50226 .68132 .49856 .67599 .49685 Mtetra
.593 .907 .982 r
.67599 .49685 .68132 .49856 .69296 .49466 .68767 .49282 Mtetra
.615 .911 .982 r
.68767 .49282 .69296 .49466 .70463 .49057 .69938 .48853 Mtetra
.635 .911 .981 r
.69938 .48853 .70463 .49057 .71634 .48629 .71113 .48402 Mtetra
.654 .909 .98 r
.71113 .48402 .71634 .48629 .72808 .48186 .72291 .47932 Mtetra
.669 .904 .978 r
.72291 .47932 .72808 .48186 .73985 .47729 .73472 .47445 Mtetra
.682 .897 .974 r
.73472 .47445 .73985 .47729 .75167 .47261 .74656 .46946 Mtetra
.691 .887 .97 r
.74656 .46946 .75167 .47261 .76352 .46786 .75844 .46437 Mtetra
.698 .876 .965 r
.75844 .46437 .76352 .46786 .7754 .46306 .77035 .45922 Mtetra
.702 .865 .959 r
.77035 .45922 .7754 .46306 .78733 .45824 .78231 .45406 Mtetra
.704 .852 .953 r
.78231 .45406 .78733 .45824 .79931 .45342 .7943 .4489 Mtetra
.704 .84 .948 r
.7943 .4489 .79931 .45342 .81132 .44862 .80634 .44378 Mtetra
.702 .828 .942 r
.80634 .44378 .81132 .44862 .82339 .44387 .81843 .43872 Mtetra
.7 .817 .937 r
.81843 .43872 .82339 .44387 .83551 .43917 .83056 .43373 Mtetra
.697 .806 .933 r
.83056 .43373 .83551 .43917 .84767 .43453 .84275 .42884 Mtetra
.694 .797 .928 r
.84275 .42884 .84767 .43453 .85989 .42996 .855 .42403 Mtetra
.691 .788 .925 r
.855 .42403 .85989 .42996 .87217 .42547 .8673 .41932 Mtetra
.687 .78 .922 r
.8673 .41932 .87217 .42547 .8845 .42104 .87965 .41471 Mtetra
.684 .773 .919 r
.87965 .41471 .8845 .42104 .89689 .41669 .89207 .41018 Mtetra
.681 .768 .917 r
.89207 .41018 .89689 .41669 .90934 .4124 .90455 .40574 Mtetra
.678 .763 .915 r
.90455 .40574 .90934 .4124 .92185 .40816 .91709 .40138 Mtetra
.675 .758 .913 r
.91709 .40138 .92185 .40816 .93442 .40397 .92968 .39708 Mtetra
.673 .755 .912 r
.92968 .39708 .93442 .40397 .94704 .39983 .94234 .39283 Mtetra
.656 .744 .914 r
.36145 .56359 .36783 .56939 .37822 .56633 .37186 .56055 Mtetra
.654 .745 .916 r
.37186 .56055 .37822 .56633 .38864 .5633 .38231 .55755 Mtetra
.652 .746 .919 r
.38231 .55755 .38864 .5633 .39911 .56031 .3928 .55461 Mtetra
.649 .747 .921 r
.3928 .55461 .39911 .56031 .40962 .55737 .40333 .55172 Mtetra
.645 .749 .925 r
.40333 .55172 .40962 .55737 .42016 .55448 .4139 .54892 Mtetra
.64 .751 .929 r
.4139 .54892 .42016 .55448 .43075 .55166 .42452 .54619 Mtetra
.635 .754 .934 r
.42452 .54619 .43075 .55166 .44139 .54892 .43517 .54357 Mtetra
.629 .758 .94 r
.43517 .54357 .44139 .54892 .45206 .54626 .44587 .54106 Mtetra
.621 .762 .946 r
.44587 .54106 .45206 .54626 .46278 .54369 .45662 .53866 Mtetra
.612 .767 .954 r
.45662 .53866 .46278 .54369 .47355 .54121 .46741 .5364 Mtetra
.602 .772 .962 r
.46741 .5364 .47355 .54121 .48436 .53884 .47825 .53426 Mtetra
.59 .779 .97 r
.47825 .53426 .48436 .53884 .49522 .53656 .48913 .53224 Mtetra
.576 .786 .978 r
.48913 .53224 .49522 .53656 .50613 .53438 .50007 .53035 Mtetra
.561 .793 .986 r
.50007 .53035 .50613 .53438 .51709 .53228 .51107 .52856 Mtetra
.543 .801 .993 r
.51107 .52856 .51709 .53228 .5281 .53024 .52212 .52686 Mtetra
.524 .808 .998 r
.52212 .52686 .5281 .53024 .53917 .52826 .53322 .52522 Mtetra
.503 .815 1 r
.53322 .52522 .53917 .52826 .55029 .52629 .54438 .5236 Mtetra
.482 .821 .999 r
.54438 .5236 .55029 .52629 .56147 .52432 .5556 .52198 Mtetra
.461 .826 .994 r
.5556 .52198 .56147 .52432 .5727 .5223 .56688 .52031 Mtetra
.442 .83 .986 r
.56688 .52031 .5727 .5223 .58398 .52021 .57821 .51854 Mtetra
.427 .834 .975 r
.57821 .51854 .58398 .52021 .59532 .51801 .5896 .51663 Mtetra
.418 .838 .963 r
.5896 .51663 .59532 .51801 .60671 .51566 .60104 .51454 Mtetra
.415 .843 .952 r
.60104 .51454 .60671 .51566 .61815 .51312 .61253 .51221 Mtetra
.419 .85 .943 r
.61253 .51221 .61815 .51312 .62963 .51037 .62407 .50961 Mtetra
.431 .86 .938 r
.62407 .50961 .62963 .51037 .64116 .50738 .63565 .50672 Mtetra
.451 .872 .936 r
.63565 .50672 .64116 .50738 .65273 .50414 .64728 .5035 Mtetra
.477 .886 .938 r
.64728 .5035 .65273 .50414 .66434 .50063 .65894 .49995 Mtetra
.507 .9 .943 r
.65894 .49995 .66434 .50063 .67599 .49685 .67064 .49607 Mtetra
.54 .912 .95 r
.67064 .49607 .67599 .49685 .68767 .49282 .68237 .49187 Mtetra
.574 .923 .957 r
.68237 .49187 .68767 .49282 .69938 .48853 .69413 .48736 Mtetra
.606 .93 .964 r
.69413 .48736 .69938 .48853 .71113 .48402 .70592 .48257 Mtetra
.635 .932 .969 r
.70592 .48257 .71113 .48402 .72291 .47932 .71773 .47754 Mtetra
.66 .93 .971 r
.71773 .47754 .72291 .47932 .73472 .47445 .72958 .47232 Mtetra
.679 .924 .972 r
.72958 .47232 .73472 .47445 .74656 .46946 .74145 .46693 Mtetra
.694 .914 .97 r
.74145 .46693 .74656 .46946 .75844 .46437 .75336 .46145 Mtetra
.704 .902 .967 r
.75336 .46145 .75844 .46437 .77035 .45922 .76529 .45589 Mtetra
.71 .889 .962 r
.76529 .45589 .77035 .45922 .78231 .45406 .77727 .45032 Mtetra
.713 .874 .957 r
.77727 .45032 .78231 .45406 .7943 .4489 .78929 .44477 Mtetra
.714 .86 .951 r
.78929 .44477 .7943 .4489 .80634 .44378 .80134 .43927 Mtetra
.712 .845 .946 r
.80134 .43927 .80634 .44378 .81843 .43872 .81345 .43385 Mtetra
.71 .832 .94 r
.81345 .43385 .81843 .43872 .83056 .43373 .8256 .42853 Mtetra
.706 .819 .935 r
.8256 .42853 .83056 .43373 .84275 .42884 .83781 .42332 Mtetra
.702 .807 .931 r
.83781 .42332 .84275 .42884 .855 .42403 .85008 .41824 Mtetra
.697 .797 .927 r
.85008 .41824 .855 .42403 .8673 .41932 .8624 .41328 Mtetra
.693 .788 .923 r
.8624 .41328 .8673 .41932 .87965 .41471 .87478 .40844 Mtetra
.689 .78 .92 r
.87478 .40844 .87965 .41471 .89207 .41018 .88722 .40372 Mtetra
.685 .773 .918 r
.88722 .40372 .89207 .41018 .90455 .40574 .89972 .39911 Mtetra
.682 .767 .916 r
.89972 .39911 .90455 .40574 .91709 .40138 .91229 .3946 Mtetra
.678 .762 .914 r
.91229 .3946 .91709 .40138 .92968 .39708 .92492 .39018 Mtetra
.676 .757 .913 r
.92492 .39018 .92968 .39708 .94234 .39283 .93761 .38582 Mtetra
.654 .744 .916 r
.35503 .55777 .36145 .56359 .37186 .56055 .36546 .55476 Mtetra
.652 .745 .918 r
.36546 .55476 .37186 .56055 .38231 .55755 .37593 .5518 Mtetra
.648 .747 .921 r
.37593 .5518 .38231 .55755 .3928 .55461 .38645 .54892 Mtetra
.644 .748 .925 r
.38645 .54892 .3928 .55461 .40333 .55172 .397 .54611 Mtetra
.64 .75 .929 r
.397 .54611 .40333 .55172 .4139 .54892 .40759 .5434 Mtetra
.634 .753 .934 r
.40759 .5434 .4139 .54892 .42452 .54619 .41823 .5408 Mtetra
.626 .756 .94 r
.41823 .5408 .42452 .54619 .43517 .54357 .42891 .53833 Mtetra
.618 .76 .947 r
.42891 .53833 .43517 .54357 .44587 .54106 .43963 .536 Mtetra
.607 .765 .955 r
.43963 .536 .44587 .54106 .45662 .53866 .4504 .53382 Mtetra
.595 .77 .963 r
.4504 .53382 .45662 .53866 .46741 .5364 .46121 .53181 Mtetra
.58 .776 .972 r
.46121 .53181 .46741 .5364 .47825 .53426 .47208 .52995 Mtetra
.563 .782 .981 r
.47208 .52995 .47825 .53426 .48913 .53224 .48299 .52825 Mtetra
.542 .789 .989 r
.48299 .52825 .48913 .53224 .50007 .53035 .49396 .52671 Mtetra
.517 .795 .996 r
.49396 .52671 .50007 .53035 .51107 .52856 .50499 .5253 Mtetra
.489 .8 .999 r
.50499 .5253 .51107 .52856 .52212 .52686 .51607 .52399 Mtetra
.458 .803 .998 r
.51607 .52399 .52212 .52686 .53322 .52522 .52721 .52277 Mtetra
.423 .804 .991 r
.52721 .52277 .53322 .52522 .54438 .5236 .53842 .52158 Mtetra
.388 .802 .978 r
.53842 .52158 .54438 .5236 .5556 .52198 .54968 .52038 Mtetra
.353 .797 .957 r
.54968 .52038 .5556 .52198 .56688 .52031 .561 .51912 Mtetra
.322 .79 .932 r
.561 .51912 .56688 .52031 .57821 .51854 .57239 .51774 Mtetra
.298 .783 .905 r
.57239 .51774 .57821 .51854 .5896 .51663 .58383 .51618 Mtetra
.282 .779 .879 r
.58383 .51618 .5896 .51663 .60104 .51454 .59533 .51438 Mtetra
.277 .779 .857 r
.59533 .51438 .60104 .51454 .61253 .51221 .60688 .5123 Mtetra
.283 .784 .841 r
.60688 .5123 .61253 .51221 .62407 .50961 .61848 .50988 Mtetra
.301 .796 .834 r
.61848 .50988 .62407 .50961 .63565 .50672 .63012 .5071 Mtetra
.329 .814 .835 r
.63012 .5071 .63565 .50672 .64728 .5035 .6418 .50391 Mtetra
.366 .836 .844 r
.6418 .50391 .64728 .5035 .65894 .49995 .65353 .50032 Mtetra
.411 .862 .859 r
.65353 .50032 .65894 .49995 .67064 .49607 .66528 .49631 Mtetra
.46 .888 .879 r
.66528 .49631 .67064 .49607 .68237 .49187 .67706 .4919 Mtetra
.511 .911 .9 r
.67706 .4919 .68237 .49187 .69413 .48736 .68887 .48712 Mtetra
.559 .93 .92 r
.68887 .48712 .69413 .48736 .70592 .48257 .7007 .48201 Mtetra
.604 .943 .937 r
.7007 .48201 .70592 .48257 .71773 .47754 .71255 .47659 Mtetra
.641 .948 .95 r
.71255 .47659 .71773 .47754 .72958 .47232 .72443 .47094 Mtetra
.671 .947 .958 r
.72443 .47094 .72958 .47232 .74145 .46693 .73633 .46511 Mtetra
.694 .94 .963 r
.73633 .46511 .74145 .46693 .75336 .46145 .74827 .45915 Mtetra
.71 .928 .963 r
.74827 .45915 .75336 .46145 .76529 .45589 .76023 .45312 Mtetra
.719 .914 .961 r
.76023 .45312 .76529 .45589 .77727 .45032 .77222 .44707 Mtetra
.724 .897 .958 r
.77222 .44707 .77727 .45032 .78929 .44477 .78426 .44105 Mtetra
.725 .881 .953 r
.78426 .44105 .78929 .44477 .80134 .43927 .79633 .43511 Mtetra
.724 .864 .948 r
.79633 .43511 .80134 .43927 .81345 .43385 .80845 .42927 Mtetra
.72 .848 .942 r
.80845 .42927 .81345 .43385 .8256 .42853 .82063 .42356 Mtetra
.716 .833 .937 r
.82063 .42356 .8256 .42853 .83781 .42332 .83285 .418 Mtetra
.711 .819 .932 r
.83285 .418 .83781 .42332 .85008 .41824 .84513 .41259 Mtetra
.705 .807 .928 r
.84513 .41259 .85008 .41824 .8624 .41328 .85747 .40734 Mtetra
.7 .796 .924 r
.85747 .40734 .8624 .41328 .87478 .40844 .86987 .40226 Mtetra
.695 .786 .921 r
.86987 .40226 .87478 .40844 .88722 .40372 .88234 .39732 Mtetra
.69 .778 .918 r
.88234 .39732 .88722 .40372 .89972 .39911 .89487 .39251 Mtetra
.686 .771 .916 r
.89487 .39251 .89972 .39911 .91229 .3946 .90746 .38784 Mtetra
.682 .765 .914 r
.90746 .38784 .91229 .3946 .92492 .39018 .92012 .38327 Mtetra
.678 .76 .913 r
.92012 .38327 .92492 .39018 .93761 .38582 .93284 .3788 Mtetra
.652 .745 .917 r
.34856 .55194 .35503 .55777 .36546 .55476 .35901 .54897 Mtetra
.649 .746 .92 r
.35901 .54897 .36546 .55476 .37593 .5518 .36951 .54606 Mtetra
.645 .747 .924 r
.36951 .54606 .37593 .5518 .38645 .54892 .38004 .54325 Mtetra
.639 .749 .928 r
.38004 .54325 .38645 .54892 .397 .54611 .39061 .54054 Mtetra
.633 .752 .933 r
.39061 .54054 .397 .54611 .40759 .5434 .40123 .53795 Mtetra
.625 .754 .939 r
.40123 .53795 .40759 .5434 .41823 .5408 .41189 .5355 Mtetra
.616 .758 .947 r
.41189 .5355 .41823 .5408 .42891 .53833 .42259 .53322 Mtetra
.604 .762 .955 r
.42259 .53322 .42891 .53833 .43963 .536 .43333 .53111 Mtetra
.59 .767 .964 r
.43333 .53111 .43963 .536 .4504 .53382 .44412 .52919 Mtetra
.572 .772 .973 r
.44412 .52919 .4504 .53382 .46121 .53181 .45496 .52747 Mtetra
.551 .778 .983 r
.45496 .52747 .46121 .53181 .47208 .52995 .46585 .52595 Mtetra
.525 .783 .991 r
.46585 .52595 .47208 .52995 .48299 .52825 .47679 .52463 Mtetra
.493 .787 .997 r
.47679 .52463 .48299 .52825 .49396 .52671 .48779 .5235 Mtetra
.456 .789 .999 r
.48779 .5235 .49396 .52671 .50499 .5253 .49885 .52253 Mtetra
.411 .786 .993 r
.49885 .52253 .50499 .5253 .51607 .52399 .50997 .5217 Mtetra
.362 .779 .978 r
.50997 .5217 .51607 .52399 .52721 .52277 .52115 .52097 Mtetra
.308 .765 .951 r
.52115 .52097 .52721 .52277 .53842 .52158 .53239 .52028 Mtetra
.253 .746 .914 r
.53239 .52028 .53842 .52158 .54968 .52038 .5437 .51957 Mtetra
.203 .723 .868 r
.5437 .51957 .54968 .52038 .561 .51912 .55507 .51879 Mtetra
.16 .699 .819 r
.55507 .51879 .561 .51912 .57239 .51774 .56651 .51786 Mtetra
.129 .678 .771 r
.56651 .51786 .57239 .51774 .58383 .51618 .57801 .51671 Mtetra
.112 .664 .73 r
.57801 .51671 .58383 .51618 .59533 .51438 .58957 .51527 Mtetra
.108 .659 .699 r
.58957 .51527 .59533 .51438 .60688 .5123 .60118 .51347 Mtetra
0 0 0 r
.60118 .51347 .60688 .5123 .61848 .50988 .61285 .51127 Mtetra
.61285 .51127 .61848 .50988 .63012 .5071 .62455 .5086 Mtetra
.62455 .5086 .63012 .5071 .6418 .50391 .6363 .50545 Mtetra
.231 .74 .7 r
.6363 .50545 .6418 .50391 .65353 .50032 .64808 .5018 Mtetra
.29 .781 .728 r
.64808 .5018 .65353 .50032 .66528 .49631 .65989 .49764 Mtetra
.356 .824 .764 r
.65989 .49764 .66528 .49631 .67706 .4919 .67173 .49299 Mtetra
.425 .867 .804 r
.67173 .49299 .67706 .4919 .68887 .48712 .68359 .48789 Mtetra
.494 .905 .843 r
.68359 .48789 .68887 .48712 .7007 .48201 .69546 .48239 Mtetra
.558 .934 .879 r
.69546 .48239 .7007 .48201 .71255 .47659 .70736 .47652 Mtetra
.613 .953 .908 r
.70736 .47652 .71255 .47659 .72443 .47094 .71927 .47038 Mtetra
.657 .962 .93 r
.71927 .47038 .72443 .47094 .73633 .46511 .73121 .46401 Mtetra
.691 .96 .944 r
.73121 .46401 .73633 .46511 .74827 .45915 .74317 .4575 Mtetra
.714 .952 .952 r
.74317 .4575 .74827 .45915 .76023 .45312 .75515 .45092 Mtetra
.728 .938 .955 r
.75515 .45092 .76023 .45312 .77222 .44707 .76717 .44432 Mtetra
.736 .92 .954 r
.76717 .44432 .77222 .44707 .78426 .44105 .77922 .43777 Mtetra
.738 .902 .952 r
.77922 .43777 .78426 .44105 .79633 .43511 .79131 .43131 Mtetra
.737 .883 .947 r
.79131 .43131 .79633 .43511 .80845 .42927 .80344 .42499 Mtetra
.733 .864 .943 r
.80344 .42499 .80845 .42927 .82063 .42356 .81563 .41884 Mtetra
.727 .847 .938 r
.81563 .41884 .82063 .42356 .83285 .418 .82787 .41287 Mtetra
.721 .831 .933 r
.82787 .41287 .83285 .418 .84513 .41259 .84016 .4071 Mtetra
.714 .817 .929 r
.84016 .4071 .84513 .41259 .85747 .40734 .85252 .40153 Mtetra
.708 .804 .925 r
.85252 .40153 .85747 .40734 .86987 .40226 .86494 .39615 Mtetra
.701 .793 .922 r
.86494 .39615 .86987 .40226 .88234 .39732 .87743 .39096 Mtetra
.696 .784 .919 r
.87743 .39096 .88234 .39732 .89487 .39251 .88998 .38595 Mtetra
.69 .776 .917 r
.88998 .38595 .89487 .39251 .90746 .38784 .9026 .38108 Mtetra
.686 .769 .915 r
.9026 .38108 .90746 .38784 .92012 .38327 .91528 .37636 Mtetra
.681 .763 .913 r
.91528 .37636 .92012 .38327 .93284 .3788 .92804 .37175 Mtetra
.649 .745 .919 r
.34203 .5461 .34856 .55194 .35901 .54897 .35251 .54317 Mtetra
.645 .746 .923 r
.35251 .54317 .35901 .54897 .36951 .54606 .36303 .54034 Mtetra
.64 .748 .927 r
.36303 .54034 .36951 .54606 .38004 .54325 .37358 .53761 Mtetra
.633 .75 .932 r
.37358 .53761 .38004 .54325 .39061 .54054 .38418 .53501 Mtetra
.625 .752 .938 r
.38418 .53501 .39061 .54054 .40123 .53795 .39481 .53257 Mtetra
.615 .756 .945 r
.39481 .53257 .40123 .53795 .41189 .5355 .40549 .5303 Mtetra
.602 .759 .954 r
.40549 .5303 .41189 .5355 .42259 .53322 .41621 .52823 Mtetra
.586 .763 .963 r
.41621 .52823 .42259 .53322 .43333 .53111 .42697 .52638 Mtetra
.567 .768 .973 r
.42697 .52638 .43333 .53111 .44412 .52919 .43779 .52476 Mtetra
.542 .772 .983 r
.43779 .52476 .44412 .52919 .45496 .52747 .44865 .52339 Mtetra
.512 .776 .992 r
.44865 .52339 .45496 .52747 .46585 .52595 .45956 .52227 Mtetra
.473 .777 .997 r
.45956 .52227 .46585 .52595 .47679 .52463 .47053 .52139 Mtetra
.426 .775 .997 r
.47053 .52139 .47679 .52463 .48779 .5235 .48155 .52074 Mtetra
.369 .766 .986 r
.48155 .52074 .48779 .5235 .49885 .52253 .49264 .5203 Mtetra
.303 .749 .961 r
.49264 .5203 .49885 .52253 .50997 .5217 .50379 .52002 Mtetra
.23 .721 .92 r
.50379 .52002 .50997 .5217 .52115 .52097 .51501 .51985 Mtetra
.155 .684 .863 r
.51501 .51985 .52115 .52097 .53239 .52028 .5263 .51974 Mtetra
.084 .641 .794 r
.5263 .51974 .53239 .52028 .5437 .51957 .53766 .51961 Mtetra
.025 .598 .72 r
.53766 .51961 .5437 .51957 .55507 .51879 .54909 .51938 Mtetra
.02 0 0 r
.54909 .51938 .55507 .51879 .56651 .51786 .56058 .51897 Mtetra
.048 0 0 r
.56058 .51897 .56651 .51786 .57801 .51671 .57214 .51829 Mtetra
.06 0 0 r
.57214 .51829 .57801 .51671 .58957 .51527 .58376 .51725 Mtetra
.057 0 0 r
.58376 .51725 .58957 .51527 .60118 .51347 .59544 .51578 Mtetra
.039 0 0 r
.59544 .51578 .60118 .51347 .61285 .51127 .60717 .51381 Mtetra
.007 0 0 r
.60717 .51381 .61285 .51127 .62455 .5086 .61895 .51128 Mtetra
0 0 0 r
.61895 .51128 .62455 .5086 .6363 .50545 .63076 .50816 Mtetra
.63076 .50816 .6363 .50545 .64808 .5018 .64261 .50443 Mtetra
.64261 .50443 .64808 .5018 .65989 .49764 .65449 .5001 Mtetra
.65449 .5001 .65989 .49764 .67173 .49299 .66638 .49517 Mtetra
.33 .794 .68 r
.66638 .49517 .67173 .49299 .68359 .48789 .67829 .4897 Mtetra
.417 .853 .74 r
.67829 .4897 .68359 .48789 .69546 .48239 .69022 .48374 Mtetra
.501 .904 .797 r
.69022 .48374 .69546 .48239 .70736 .47652 .70215 .47735 Mtetra
.575 .942 .847 r
.70215 .47735 .70736 .47652 .71927 .47038 .71411 .47064 Mtetra
.637 .964 .886 r
.71411 .47064 .71927 .47038 .73121 .46401 .72607 .46366 Mtetra
.684 .973 .914 r
.72607 .46366 .73121 .46401 .74317 .4575 .73806 .45652 Mtetra
.717 .97 .932 r
.73806 .45652 .74317 .4575 .75515 .45092 .75006 .4493 Mtetra
.737 .958 .942 r
.75006 .4493 .75515 .45092 .76717 .44432 .76209 .44208 Mtetra
.748 .942 .947 r
.76209 .44208 .76717 .44432 .77922 .43777 .77416 .43492 Mtetra
.752 .922 .947 r
.77416 .43492 .77922 .43777 .79131 .43131 .78626 .42788 Mtetra
.751 .901 .945 r
.78626 .42788 .79131 .43131 .80344 .42499 .79841 .42102 Mtetra
.747 .881 .941 r
.79841 .42102 .80344 .42499 .81563 .41884 .81061 .41436 Mtetra
.74 .861 .937 r
.81061 .41436 .81563 .41884 .82787 .41287 .82286 .40794 Mtetra
.733 .844 .933 r
.82286 .40794 .82787 .41287 .84016 .4071 .83517 .40176 Mtetra
.725 .827 .929 r
.83517 .40176 .84016 .4071 .85252 .40153 .84754 .39582 Mtetra
.717 .813 .925 r
.84754 .39582 .85252 .40153 .86494 .39615 .85998 .39013 Mtetra
.709 .8 .922 r
.85998 .39013 .86494 .39615 .87743 .39096 .87249 .38466 Mtetra
.702 .79 .919 r
.87249 .38466 .87743 .39096 .88998 .38595 .88506 .3794 Mtetra
.695 .78 .917 r
.88506 .3794 .88998 .38595 .9026 .38108 .8977 .37434 Mtetra
.69 .773 .915 r
.8977 .37434 .9026 .38108 .91528 .37636 .91042 .36944 Mtetra
.685 .766 .913 r
.91042 .36944 .91528 .37636 .92804 .37175 .9232 .36468 Mtetra
.646 .745 .922 r
.33546 .54024 .34203 .5461 .35251 .54317 .34596 .53738 Mtetra
.641 .747 .926 r
.34596 .53738 .35251 .54317 .36303 .54034 .3565 .53462 Mtetra
.634 .748 .93 r
.3565 .53462 .36303 .54034 .37358 .53761 .36707 .532 Mtetra
.626 .75 .936 r
.36707 .532 .37358 .53761 .38418 .53501 .37769 .52954 Mtetra
.615 .753 .944 r
.37769 .52954 .38418 .53501 .39481 .53257 .38834 .52726 Mtetra
.602 .756 .952 r
.38834 .52726 .39481 .53257 .40549 .5303 .39904 .5252 Mtetra
.586 .76 .961 r
.39904 .5252 .40549 .5303 .41621 .52823 .40977 .52339 Mtetra
.565 .763 .971 r
.40977 .52339 .41621 .52823 .42697 .52638 .42056 .52184 Mtetra
.538 .766 .982 r
.42056 .52184 .42697 .52638 .43779 .52476 .43139 .52057 Mtetra
.504 .768 .991 r
.43139 .52057 .43779 .52476 .44865 .52339 .44227 .5196 Mtetra
.46 .767 .996 r
.44227 .5196 .44865 .52339 .45956 .52227 .4532 .51893 Mtetra
.404 .761 .994 r
.4532 .51893 .45956 .52227 .47053 .52139 .4642 .51855 Mtetra
.336 .747 .98 r
.4642 .51855 .47053 .52139 .48155 .52074 .47525 .51846 Mtetra
.254 .719 .947 r
.47525 .51846 .48155 .52074 .49264 .5203 .48637 .5186 Mtetra
.162 .678 .892 r
.48637 .5186 .49264 .5203 .50379 .52002 .49755 .51895 Mtetra
.068 .623 .815 r
.49755 .51895 .50379 .52002 .51501 .51985 .50881 .51943 Mtetra
0 .56 .724 r
.50881 .51943 .51501 .51985 .5263 .51974 .52014 .51998 Mtetra
.093 0 0 r
.52014 .51998 .5263 .51974 .53766 .51961 .53155 .5205 Mtetra
.147 0 0 r
.53155 .5205 .53766 .51961 .54909 .51938 .54303 .5209 Mtetra
.183 0 0 r
.54303 .5209 .54909 .51938 .56058 .51897 .55458 .52107 Mtetra
.201 0 0 r
.55458 .52107 .56058 .51897 .57214 .51829 .56621 .52092 Mtetra
.204 0 0 r
.56621 .52092 .57214 .51829 .58376 .51725 .5779 .52034 Mtetra
.192 0 0 r
.5779 .52034 .58376 .51725 .59544 .51578 .58965 .51924 Mtetra
.167 0 0 r
.58965 .51924 .59544 .51578 .60717 .51381 .60145 .51753 Mtetra
.13 0 0 r
.60145 .51753 .60717 .51381 .61895 .51128 .6133 .51515 Mtetra
.08 0 0 r
.6133 .51515 .61895 .51128 .63076 .50816 .62519 .51206 Mtetra
.018 0 0 r
.62519 .51206 .63076 .50816 .64261 .50443 .6371 .50824 Mtetra
0 0 0 r
.6371 .50824 .64261 .50443 .65449 .5001 .64904 .50368 Mtetra
.64904 .50368 .65449 .5001 .66638 .49517 .661 .49843 Mtetra
.661 .49843 .66638 .49517 .67829 .4897 .67297 .49253 Mtetra
.342 .787 .628 r
.67297 .49253 .67829 .4897 .69022 .48374 .68495 .48605 Mtetra
.443 .858 .704 r
.68495 .48605 .69022 .48374 .70215 .47735 .69693 .47907 Mtetra
.536 .916 .773 r
.69693 .47907 .70215 .47735 .71411 .47064 .70892 .4717 Mtetra
.615 .956 .83 r
.70892 .4717 .71411 .47064 .72607 .46366 .72092 .46404 Mtetra
.676 .977 .874 r
.72092 .46404 .72607 .46366 .73806 .45652 .73293 .45619 Mtetra
.719 .982 .905 r
.73293 .45619 .73806 .45652 .75006 .4493 .74495 .44826 Mtetra
.747 .975 .923 r
.74495 .44826 .75006 .4493 .76209 .44208 .757 .44033 Mtetra
.762 .96 .934 r
.757 .44033 .76209 .44208 .77416 .43492 .76908 .43248 Mtetra
.767 .94 .938 r
.76908 .43248 .77416 .43492 .78626 .42788 .7812 .4248 Mtetra
.767 .918 .939 r
.7812 .4248 .78626 .42788 .79841 .42102 .79336 .41733 Mtetra
.762 .896 .937 r
.79336 .41733 .79841 .42102 .81061 .41436 .80556 .41012 Mtetra
.754 .875 .934 r
.80556 .41012 .81061 .41436 .82286 .40794 .81783 .40319 Mtetra
.745 .855 .931 r
.81783 .40319 .82286 .40794 .83517 .40176 .83015 .39656 Mtetra
.736 .837 .927 r
.83015 .39656 .83517 .40176 .84754 .39582 .84254 .39022 Mtetra
.726 .821 .924 r
.84254 .39022 .84754 .39582 .85998 .39013 .85499 .38417 Mtetra
.717 .807 .921 r
.85499 .38417 .85998 .39013 .87249 .38466 .86751 .3784 Mtetra
.709 .795 .918 r
.86751 .3784 .87249 .38466 .88506 .3794 .88011 .37288 Mtetra
.701 .785 .916 r
.88011 .37288 .88506 .3794 .8977 .37434 .89278 .36759 Mtetra
.694 .776 .914 r
.89278 .36759 .8977 .37434 .91042 .36944 .90551 .36251 Mtetra
.689 .769 .913 r
.90551 .36251 .91042 .36944 .9232 .36468 .91832 .35759 Mtetra
.642 .745 .924 r
.32884 .53438 .33546 .54024 .34596 .53738 .33936 .53158 Mtetra
.636 .747 .929 r
.33936 .53158 .34596 .53738 .3565 .53462 .34991 .52892 Mtetra
.628 .748 .934 r
.34991 .52892 .3565 .53462 .36707 .532 .36051 .52642 Mtetra
.617 .751 .941 r
.36051 .52642 .36707 .532 .37769 .52954 .37114 .52411 Mtetra
.604 .753 .949 r
.37114 .52411 .37769 .52954 .38834 .52726 .38181 .52203 Mtetra
.587 .756 .958 r
.38181 .52203 .38834 .52726 .39904 .5252 .39252 .52021 Mtetra
.565 .758 .969 r
.39252 .52021 .39904 .5252 .40977 .52339 .40328 .51868 Mtetra
.537 .761 .979 r
.40328 .51868 .40977 .52339 .42056 .52184 .41408 .51747 Mtetra
.501 .761 .989 r
.41408 .51747 .42056 .52184 .43139 .52057 .42493 .5166 Mtetra
.454 .759 .995 r
.42493 .5166 .43139 .52057 .44227 .5196 .43583 .51608 Mtetra
.393 .749 .993 r
.43583 .51608 .44227 .5196 .4532 .51893 .44678 .51592 Mtetra
.315 .73 .977 r
.44678 .51592 .4532 .51893 .4642 .51855 .4578 .51611 Mtetra
.221 .695 .939 r
.4578 .51611 .4642 .51855 .47525 .51846 .46887 .51663 Mtetra
.113 .641 .873 r
.46887 .51663 .47525 .51846 .48637 .5186 .48002 .51745 Mtetra
.002 .571 .781 r
.48002 .51745 .48637 .5186 .49755 .51895 .49124 .51849 Mtetra
.1 0 0 r
.49124 .51849 .49755 .51895 .50881 .51943 .50254 .5197 Mtetra
.185 0 0 r
.50254 .5197 .50881 .51943 .52014 .51998 .51391 .52098 Mtetra
.247 0 0 r
.51391 .52098 .52014 .51998 .53155 .5205 .52537 .52223 Mtetra
.288 0 0 r
.52537 .52223 .53155 .5205 .54303 .5209 .5369 .52333 Mtetra
.31 0 0 r
.5369 .52333 .54303 .5209 .55458 .52107 .54852 .52416 Mtetra
.316 0 0 r
.54852 .52416 .55458 .52107 .56621 .52092 .56021 .52459 Mtetra
.309 0 0 r
.56021 .52459 .56621 .52092 .5779 .52034 .57197 .52452 Mtetra
.29 0 0 r
.57197 .52452 .5779 .52034 .58965 .51924 .58379 .52381 Mtetra
.26 0 0 r
.58379 .52381 .58965 .51924 .60145 .51753 .59567 .52239 Mtetra
.219 0 0 r
.59567 .52239 .60145 .51753 .6133 .51515 .6076 .52016 Mtetra
.166 0 0 r
.6076 .52016 .6133 .51515 .62519 .51206 .61956 .51709 Mtetra
.101 0 0 r
.61956 .51709 .62519 .51206 .6371 .50824 .63155 .51315 Mtetra
.023 0 0 r
.63155 .51315 .6371 .50824 .64904 .50368 .64356 .50835 Mtetra
0 0 0 r
.64356 .50835 .64904 .50368 .661 .49843 .65559 .50273 Mtetra
.65559 .50273 .661 .49843 .67297 .49253 .66762 .49634 Mtetra
.66762 .49634 .67297 .49253 .68495 .48605 .67965 .48927 Mtetra
.396 .811 .615 r
.67965 .48927 .68495 .48605 .69693 .47907 .69168 .48163 Mtetra
.503 .885 .699 r
.69168 .48163 .69693 .47907 .70892 .4717 .7037 .47353 Mtetra
.597 .941 .772 r
.7037 .47353 .70892 .4717 .72092 .46404 .71574 .4651 Mtetra
.671 .975 .83 r
.71574 .4651 .72092 .46404 .73293 .45619 .72777 .45646 Mtetra
.724 .988 .872 r
.72777 .45646 .73293 .45619 .74495 .44826 .73982 .44773 Mtetra
.758 .986 .9 r
.73982 .44773 .74495 .44826 .757 .44033 .75189 .43902 Mtetra
.777 .974 .917 r
.75189 .43902 .757 .44033 .76908 .43248 .76398 .43043 Mtetra
.784 .955 .926 r
.76398 .43043 .76908 .43248 .7812 .4248 .77611 .42203 Mtetra
.783 .932 .93 r
.77611 .42203 .7812 .4248 .79336 .41733 .78828 .4139 Mtetra
.778 .909 .931 r
.78828 .4139 .79336 .41733 .80556 .41012 .80049 .40608 Mtetra
.769 .887 .929 r
.80049 .40608 .80556 .41012 .81783 .40319 .81276 .3986 Mtetra
.759 .866 .927 r
.81276 .3986 .81783 .40319 .83015 .39656 .8251 .39147 Mtetra
.747 .846 .925 r
.8251 .39147 .83015 .39656 .84254 .39022 .8375 .3847 Mtetra
.736 .829 .922 r
.8375 .3847 .84254 .39022 .85499 .38417 .84997 .37827 Mtetra
.726 .814 .919 r
.84997 .37827 .85499 .38417 .86751 .3784 .86251 .37217 Mtetra
.716 .801 .917 r
.86251 .37217 .86751 .3784 .88011 .37288 .87512 .36637 Mtetra
.707 .789 .915 r
.87512 .36637 .88011 .37288 .89278 .36759 .88781 .36085 Mtetra
.699 .78 .914 r
.88781 .36085 .89278 .36759 .90551 .36251 .90058 .35556 Mtetra
.693 .772 .912 r
.90058 .35556 .90551 .36251 .91832 .35759 .91341 .35047 Mtetra
.638 .745 .926 r
.32216 .52851 .32884 .53438 .33936 .53158 .3327 .52579 Mtetra
.63 .747 .932 r
.3327 .52579 .33936 .53158 .34991 .52892 .34328 .52323 Mtetra
.62 .748 .938 r
.34328 .52323 .34991 .52892 .36051 .52642 .35389 .52086 Mtetra
.607 .75 .946 r
.35389 .52086 .36051 .52642 .37114 .52411 .36454 .51873 Mtetra
.591 .752 .955 r
.36454 .51873 .37114 .52411 .38181 .52203 .37522 .51687 Mtetra
.569 .754 .965 r
.37522 .51687 .38181 .52203 .39252 .52021 .38595 .51531 Mtetra
.541 .755 .976 r
.38595 .51531 .39252 .52021 .40328 .51868 .39672 .5141 Mtetra
.504 .755 .986 r
.39672 .5141 .40328 .51868 .41408 .51747 .40754 .51327 Mtetra
.456 .751 .993 r
.40754 .51327 .41408 .51747 .42493 .5166 .4184 .51283 Mtetra
.392 .74 .992 r
.4184 .51283 .42493 .5166 .43583 .51608 .42932 .51282 Mtetra
.31 .718 .977 r
.42932 .51282 .43583 .51608 .44678 .51592 .44029 .51322 Mtetra
.207 .678 .938 r
.44029 .51322 .44678 .51592 .4578 .51611 .45132 .51404 Mtetra
.087 .617 .868 r
.45132 .51404 .4578 .51611 .46887 .51663 .46242 .51525 Mtetra
0 .535 .767 r
.46242 .51525 .46887 .51663 .48002 .51745 .4736 .51679 Mtetra
.155 0 0 r
.4736 .51679 .48002 .51745 .49124 .51849 .48485 .51861 Mtetra
.25 0 0 r
.48485 .51861 .49124 .51849 .50254 .5197 .49618 .52061 Mtetra
.32 0 0 r
.49618 .52061 .50254 .5197 .51391 .52098 .5076 .5227 Mtetra
.366 0 0 r
.5076 .5227 .51391 .52098 .52537 .52223 .5191 .52474 Mtetra
.391 0 0 r
.5191 .52474 .52537 .52223 .5369 .52333 .53069 .52661 Mtetra
.401 0 0 r
.53069 .52661 .5369 .52333 .54852 .52416 .54237 .52815 Mtetra
.398 0 0 r
.54237 .52815 .54852 .52416 .56021 .52459 .55413 .52923 Mtetra
.383 0 0 r
.55413 .52923 .56021 .52459 .57197 .52452 .56596 .52969 Mtetra
.359 0 0 r
.56596 .52969 .57197 .52452 .58379 .52381 .57786 .52942 Mtetra
.324 0 0 r
.57786 .52942 .58379 .52381 .59567 .52239 .58982 .52829 Mtetra
.28 0 0 r
.58982 .52829 .59567 .52239 .6076 .52016 .60183 .52623 Mtetra
.224 0 0 r
.60183 .52623 .6076 .52016 .61956 .51709 .61387 .52317 Mtetra
.157 0 0 r
.61387 .52317 .61956 .51709 .63155 .51315 .62595 .51909 Mtetra
.076 0 0 r
.62595 .51909 .63155 .51315 .64356 .50835 .63803 .514 Mtetra
0 0 0 r
.63803 .514 .64356 .50835 .65559 .50273 .65012 .50795 Mtetra
.65012 .50795 .65559 .50273 .66762 .49634 .66222 .50101 Mtetra
.66222 .50101 .66762 .49634 .67965 .48927 .6743 .49329 Mtetra
.6743 .49329 .67965 .48927 .69168 .48163 .68638 .48492 Mtetra
.486 .86 .637 r
.68638 .48492 .69168 .48163 .7037 .47353 .69845 .47602 Mtetra
.59 .927 .721 r
.69845 .47602 .7037 .47353 .71574 .4651 .71052 .46674 Mtetra
.673 .97 .789 r
.71052 .46674 .71574 .4651 .72777 .45646 .72259 .45724 Mtetra
.733 .991 .84 r
.72259 .45724 .72777 .45646 .73982 .44773 .73466 .44764 Mtetra
.772 .994 .876 r
.73466 .44764 .73982 .44773 .75189 .43902 .74674 .43809 Mtetra
.793 .983 .898 r
.74674 .43809 .75189 .43902 .76398 .43043 .75885 .42868 Mtetra
.801 .965 .912 r
.75885 .42868 .76398 .43043 .77611 .42203 .77098 .41952 Mtetra
.801 .943 .919 r
.77098 .41952 .77611 .42203 .78828 .4139 .78316 .41067 Mtetra
.794 .92 .922 r
.78316 .41067 .78828 .4139 .80049 .40608 .79538 .40219 Mtetra
.784 .896 .923 r
.79538 .40219 .80049 .40608 .81276 .3986 .80767 .39412 Mtetra
.772 .874 .922 r
.80767 .39412 .81276 .3986 .8251 .39147 .82001 .38647 Mtetra
.76 .854 .921 r
.82001 .38647 .8251 .39147 .8375 .3847 .83242 .37923 Mtetra
.747 .836 .919 r
.83242 .37923 .8375 .3847 .84997 .37827 .8449 .3724 Mtetra
.735 .819 .917 r
.8449 .3724 .84997 .37827 .86251 .37217 .85746 .36595 Mtetra
.724 .805 .915 r
.85746 .36595 .86251 .37217 .87512 .36637 .8701 .35986 Mtetra
.714 .793 .914 r
.8701 .35986 .87512 .36637 .88781 .36085 .88281 .35408 Mtetra
.705 .783 .913 r
.88281 .35408 .88781 .36085 .90058 .35556 .8956 .34858 Mtetra
.697 .774 .911 r
.8956 .34858 .90058 .35556 .91341 .35047 .90846 .34331 Mtetra
.633 .745 .929 r
.31544 .52262 .32216 .52851 .3327 .52579 .32599 .51999 Mtetra
.624 .746 .935 r
.32599 .51999 .3327 .52579 .34328 .52323 .33658 .51755 Mtetra
.612 .748 .942 r
.33658 .51755 .34328 .52323 .35389 .52086 .34721 .51533 Mtetra
.596 .749 .95 r
.34721 .51533 .35389 .52086 .36454 .51873 .35788 .51339 Mtetra
.575 .75 .96 r
.35788 .51339 .36454 .51873 .37522 .51687 .36858 .51177 Mtetra
.548 .751 .971 r
.36858 .51177 .37522 .51687 .38595 .51531 .37932 .5105 Mtetra
.513 .75 .981 r
.37932 .5105 .38595 .51531 .39672 .5141 .3901 .50964 Mtetra
.465 .745 .99 r
.3901 .50964 .39672 .5141 .40754 .51327 .40093 .50921 Mtetra
.402 .734 .991 r
.40093 .50921 .40754 .51327 .4184 .51283 .41181 .50926 Mtetra
.319 .712 .98 r
.41181 .50926 .4184 .51283 .42932 .51282 .42274 .50978 Mtetra
.212 .671 .946 r
.42274 .50978 .42932 .51282 .44029 .51322 .43372 .5108 Mtetra
.085 .607 .878 r
.43372 .5108 .44029 .51322 .45132 .51404 .44477 .5123 Mtetra
0 .519 .774 r
.44477 .5123 .45132 .51404 .46242 .51525 .45589 .51424 Mtetra
.183 0 0 r
.45589 .51424 .46242 .51525 .4736 .51679 .46709 .51658 Mtetra
.29 0 0 r
.46709 .51658 .4736 .51679 .48485 .51861 .47837 .51923 Mtetra
.369 0 0 r
.47837 .51923 .48485 .51861 .49618 .52061 .48974 .52209 Mtetra
.421 0 0 r
.48974 .52209 .49618 .52061 .5076 .5227 .5012 .52504 Mtetra
.451 0 0 r
.5012 .52504 .5076 .5227 .5191 .52474 .51275 .52794 Mtetra
.465 0 0 r
.51275 .52794 .5191 .52474 .53069 .52661 .5244 .53063 Mtetra
.5244 .53063 .53069 .52661 .54237 .52815 .53614 .53293 Mtetra
.455 0 0 r
.53614 .53293 .54237 .52815 .55413 .52923 .54797 .53469 Mtetra
.435 0 0 r
.54797 .53469 .55413 .52923 .56596 .52969 .55987 .53573 Mtetra
.406 0 0 r
.55987 .53573 .56596 .52969 .57786 .52942 .57186 .53591 Mtetra
.368 0 0 r
.57186 .53591 .57786 .52942 .58982 .52829 .5839 .53509 Mtetra
.321 0 0 r
.5839 .53509 .58982 .52829 .60183 .52623 .59599 .53318 Mtetra
.262 0 0 r
.59599 .53318 .60183 .52623 .61387 .52317 .60812 .53012 Mtetra
.191 0 0 r
.60812 .53012 .61387 .52317 .62595 .51909 .62027 .52587 Mtetra
.106 0 0 r
.62027 .52587 .62595 .51909 .63803 .514 .63244 .52046 Mtetra
.006 0 0 r
.63244 .52046 .63803 .514 .65012 .50795 .6446 .51394 Mtetra
0 0 0 r
.6446 .51394 .65012 .50795 .66222 .50101 .65676 .5064 Mtetra
.65676 .5064 .66222 .50101 .6743 .49329 .66891 .49797 Mtetra
.66891 .49797 .6743 .49329 .68638 .48492 .68104 .48879 Mtetra
.489 .848 .597 r
.68104 .48879 .68638 .48492 .69845 .47602 .69316 .47902 Mtetra
.599 .921 .685 r
.69316 .47902 .69845 .47602 .71052 .46674 .70526 .46884 Mtetra
.687 .969 .759 r
.70526 .46884 .71052 .46674 .72259 .45724 .71735 .4584 Mtetra
.75 .993 .814 r
.71735 .4584 .72259 .45724 .73466 .44764 .72945 .44788 Mtetra
.79 .998 .853 r
.72945 .44788 .73466 .44764 .74674 .43809 .74155 .43742 Mtetra
.812 .989 .88 r
.74155 .43742 .74674 .43809 .75885 .42868 .75367 .42715 Mtetra
.82 .971 .896 r
.75367 .42715 .75885 .42868 .77098 .41952 .76582 .41717 Mtetra
.819 .95 .906 r
.76582 .41717 .77098 .41952 .78316 .41067 .778 .40757 Mtetra
.811 .926 .911 r
.778 .40757 .78316 .41067 .79538 .40219 .79024 .39841 Mtetra
.799 .903 .914 r
.79024 .39841 .79538 .40219 .80767 .39412 .80253 .38971 Mtetra
.786 .88 .915 r
.80253 .38971 .80767 .39412 .82001 .38647 .81488 .3815 Mtetra
.772 .859 .915 r
.81488 .3815 .82001 .38647 .83242 .37923 .8273 .37378 Mtetra
.757 .841 .915 r
.8273 .37378 .83242 .37923 .8449 .3724 .8398 .36653 Mtetra
.744 .824 .914 r
.8398 .36653 .8449 .3724 .85746 .36595 .85237 .35972 Mtetra
.731 .809 .913 r
.85237 .35972 .85746 .36595 .8701 .35986 .86503 .35331 Mtetra
.72 .796 .912 r
.86503 .35331 .8701 .35986 .88281 .35408 .87776 .34727 Mtetra
.71 .786 .911 r
.87776 .34727 .88281 .35408 .8956 .34858 .89058 .34155 Mtetra
.701 .777 .91 r
.89058 .34155 .8956 .34858 .90846 .34331 .90347 .33611 Mtetra
.628 .745 .931 r
.30865 .51671 .31544 .52262 .32599 .51999 .31923 .51418 Mtetra
.617 .745 .938 r
.31923 .51418 .32599 .51999 .33658 .51755 .32984 .51186 Mtetra
.602 .746 .946 r
.32984 .51186 .33658 .51755 .34721 .51533 .34048 .50981 Mtetra
.583 .747 .955 r
.34048 .50981 .34721 .51533 .35788 .51339 .35116 .50808 Mtetra
.558 .747 .965 r
.35116 .50808 .35788 .51339 .36858 .51177 .36188 .50671 Mtetra
.525 .746 .976 r
.36188 .50671 .36858 .51177 .37932 .5105 .37263 .50575 Mtetra
.48 .741 .985 r
.37263 .50575 .37932 .5105 .3901 .50964 .38342 .50526 Mtetra
.42 .731 .99 r
.38342 .50526 .3901 .50964 .40093 .50921 .39426 .50527 Mtetra
.34 .71 .984 r
.39426 .50527 .40093 .50921 .41181 .50926 .40514 .50582 Mtetra
.236 .672 .957 r
.40514 .50582 .41181 .50926 .42274 .50978 .41608 .50693 Mtetra
.106 .609 .899 r
.41608 .50693 .42274 .50978 .43372 .5108 .42708 .5086 Mtetra
0 .52 .8 r
.42708 .5086 .43372 .5108 .44477 .5123 .43815 .51082 Mtetra
.183 0 0 r
.43815 .51082 .44477 .5123 .45589 .51424 .44929 .51354 Mtetra
.305 0 0 r
.44929 .51354 .45589 .51424 .46709 .51658 .46051 .51671 Mtetra
.396 0 0 r
.46051 .51671 .46709 .51658 .47837 .51923 .47181 .52024 Mtetra
.457 0 0 r
.47181 .52024 .47837 .51923 .48974 .52209 .48321 .52401 Mtetra
.494 0 0 r
.48321 .52401 .48974 .52209 .5012 .52504 .49471 .52788 Mtetra
.513 0 0 r
.49471 .52788 .5012 .52504 .51275 .52794 .50631 .53167 Mtetra
.518 0 0 r
.50631 .53167 .51275 .52794 .5244 .53063 .51801 .53522 Mtetra
.512 .006 0 r
.51801 .53522 .5244 .53063 .53614 .53293 .52982 .53832 Mtetra
.496 .004 .017 r
.52982 .53832 .53614 .53293 .54797 .53469 .54171 .54079 Mtetra
.472 0 .03 r
.54171 .54079 .54797 .53469 .55987 .53573 .5537 .54243 Mtetra
.439 0 .033 r
.5537 .54243 .55987 .53573 .57186 .53591 .56576 .54307 Mtetra
.398 0 .025 r
.56576 .54307 .57186 .53591 .5839 .53509 .57789 .54256 Mtetra
.346 0 .006 r
.57789 .54256 .5839 .53509 .59599 .53318 .59007 .5408 Mtetra
.282 0 0 r
.59007 .5408 .59599 .53318 .60812 .53012 .60228 .53771 Mtetra
.206 0 0 r
.60228 .53771 .60812 .53012 .62027 .52587 .61452 .53327 Mtetra
.114 0 0 r
.61452 .53327 .62027 .52587 .63244 .52046 .62677 .5275 Mtetra
.006 0 0 r
.62677 .5275 .63244 .52046 .6446 .51394 .63901 .52047 Mtetra
0 0 0 r
.63901 .52047 .6446 .51394 .65676 .5064 .65124 .51228 Mtetra
.65124 .51228 .65676 .5064 .66891 .49797 .66345 .50308 Mtetra
.66345 .50308 .66891 .49797 .68104 .48879 .67563 .49304 Mtetra
.516 .854 .581 r
.67563 .49304 .68104 .48879 .69316 .47902 .6878 .48235 Mtetra
.628 .927 .669 r
.6878 .48235 .69316 .47902 .70526 .46884 .69994 .47121 Mtetra
.715 .973 .742 r
.69994 .47121 .70526 .46884 .71735 .4584 .71206 .45979 Mtetra
.776 .996 .797 r
.71206 .45979 .71735 .4584 .72945 .44788 .72418 .4483 Mtetra
.814 .999 .836 r
.72418 .4483 .72945 .44788 .74155 .43742 .7363 .4369 Mtetra
.833 .99 .863 r
.7363 .4369 .74155 .43742 .75367 .42715 .74844 .42573 Mtetra
.839 .973 .881 r
.74844 .42573 .75367 .42715 .76582 .41717 .7606 .4149 Mtetra
.836 .952 .892 r
.7606 .4149 .76582 .41717 .778 .40757 .7728 .40451 Mtetra
.827 .929 .9 r
.7728 .40451 .778 .40757 .79024 .39841 .78504 .39463 Mtetra
.814 .906 .904 r
.78504 .39463 .79024 .39841 .80253 .38971 .79734 .3853 Mtetra
.799 .883 .907 r
.79734 .3853 .80253 .38971 .81488 .3815 .8097 .37652 Mtetra
.783 .863 .908 r
.8097 .37652 .81488 .3815 .8273 .37378 .82214 .3683 Mtetra
.768 .844 .909 r
.82214 .3683 .8273 .37378 .8398 .36653 .83465 .36062 Mtetra
.753 .827 .909 r
.83465 .36062 .8398 .36653 .85237 .35972 .84724 .35344 Mtetra
.739 .812 .909 r
.84724 .35344 .85237 .35972 .86503 .35331 .85992 .34672 Mtetra
.726 .799 .909 r
.85992 .34672 .86503 .35331 .87776 .34727 .87268 .34041 Mtetra
.715 .788 .909 r
.87268 .34041 .87776 .34727 .89058 .34155 .88552 .33447 Mtetra
.705 .778 .909 r
.88552 .33447 .89058 .34155 .90347 .33611 .89844 .32884 Mtetra
.622 .744 .934 r
.30182 .51078 .30865 .51671 .31923 .51418 .31241 .50835 Mtetra
.609 .744 .941 r
.31241 .50835 .31923 .51418 .32984 .51186 .32304 .50616 Mtetra
.592 .744 .949 r
.32304 .50616 .32984 .51186 .34048 .50981 .33369 .50429 Mtetra
.569 .744 .959 r
.33369 .50429 .34048 .50981 .35116 .50808 .34439 .50277 Mtetra
.539 .742 .97 r
.34439 .50277 .35116 .50808 .36188 .50671 .35511 .50167 Mtetra
.499 .738 .98 r
.35511 .50167 .36188 .50671 .37263 .50575 .36587 .50104 Mtetra
.445 .729 .987 r
.36587 .50104 .37263 .50575 .38342 .50526 .37668 .50094 Mtetra
.371 .711 .986 r
.37668 .50094 .38342 .50526 .39426 .50527 .38752 .5014 Mtetra
.273 .678 .97 r
.38752 .5014 .39426 .50527 .40514 .50582 .39842 .50248 Mtetra
.148 .622 .925 r
.39842 .50248 .40514 .50582 .41608 .50693 .40936 .50419 Mtetra
0 .538 .841 r
.40936 .50419 .41608 .50693 .42708 .5086 .42037 .50653 Mtetra
0 .43 .717 r
.42037 .50653 .42708 .5086 .43815 .51082 .43145 .5095 Mtetra
.292 0 0 r
.43145 .5095 .43815 .51082 .44929 .51354 .4426 .51303 Mtetra
.4 0 0 r
.4426 .51303 .44929 .51354 .46051 .51671 .45384 .51707 Mtetra
.475 0 0 r
.45384 .51707 .46051 .51671 .47181 .52024 .46517 .52151 Mtetra
.522 0 0 r
.46517 .52151 .47181 .52024 .48321 .52401 .4766 .52622 Mtetra
.548 .004 0 r
.4766 .52622 .48321 .52401 .49471 .52788 .48813 .53102 Mtetra
.558 .034 0 r
.48813 .53102 .49471 .52788 .50631 .53167 .49978 .53574 Mtetra
.557 .049 .003 r
.49978 .53574 .50631 .53167 .51801 .53522 .51153 .54017 Mtetra
.546 .052 .034 r
.51153 .54017 .51801 .53522 .52982 .53832 .5234 .54409 Mtetra
.527 .044 .053 r
.5234 .54409 .52982 .53832 .54171 .54079 .53536 .54728 Mtetra
.499 .025 .061 r
.53536 .54728 .54171 .54079 .5537 .54243 .54742 .54952 Mtetra
.462 0 .059 r
.54742 .54952 .5537 .54243 .56576 .54307 .55956 .55062 Mtetra
.416 0 .047 r
.55956 .55062 .56576 .54307 .57789 .54256 .57178 .55042 Mtetra
.359 0 .024 r
.57178 .55042 .57789 .54256 .59007 .5408 .58404 .54879 Mtetra
.289 0 0 r
.58404 .54879 .59007 .5408 .60228 .53771 .59635 .54566 Mtetra
.204 0 0 r
.59635 .54566 .60228 .53771 .61452 .53327 .60867 .54099 Mtetra
.102 0 0 r
.60867 .54099 .61452 .53327 .62677 .5275 .621 .53483 Mtetra
0 0 0 r
.621 .53483 .62677 .5275 .63901 .52047 .63333 .52724 Mtetra
.63333 .52724 .63901 .52047 .65124 .51228 .64563 .51837 Mtetra
.64563 .51837 .65124 .51228 .66345 .50308 .6579 .50836 Mtetra
.6579 .50836 .66345 .50308 .67563 .49304 .67015 .49743 Mtetra
.568 .879 .591 r
.67015 .49743 .67563 .49304 .6878 .48235 .68236 .48578 Mtetra
.675 .943 .674 r
.68236 .48578 .6878 .48235 .69994 .47121 .69454 .47363 Mtetra
.755 .982 .739 r
.69454 .47363 .69994 .47121 .71206 .45979 .7067 .46121 Mtetra
.808 .998 .788 r
.7067 .46121 .71206 .45979 .72418 .4483 .71885 .44873 Mtetra
.84 .998 .824 r
.71885 .44873 .72418 .4483 .7363 .4369 .73099 .43635 Mtetra
.855 .987 .849 r
.73099 .43635 .7363 .4369 .74844 .42573 .74315 .42426 Mtetra
.858 .97 .866 r
.74315 .42426 .74844 .42573 .7606 .4149 .75532 .41257 Mtetra
.852 .949 .879 r
.75532 .41257 .7606 .4149 .7728 .40451 .76753 .40139 Mtetra
.841 .927 .887 r
.76753 .40139 .7728 .40451 .78504 .39463 .77978 .39079 Mtetra
.827 .905 .893 r
.77978 .39079 .78504 .39463 .79734 .3853 .7921 .38081 Mtetra
.811 .884 .898 r
.7921 .38081 .79734 .3853 .8097 .37652 .80447 .37147 Mtetra
.794 .863 .901 r
.80447 .37147 .8097 .37652 .82214 .3683 .81692 .36275 Mtetra
.777 .845 .903 r
.81692 .36275 .82214 .3683 .83465 .36062 .82945 .35463 Mtetra
.761 .828 .904 r
.82945 .35463 .83465 .36062 .84724 .35344 .84206 .34708 Mtetra
.746 .813 .905 r
.84206 .34708 .84724 .35344 .85992 .34672 .85476 .34005 Mtetra
.732 .8 .906 r
.85476 .34005 .85992 .34672 .87268 .34041 .86754 .33348 Mtetra
.72 .789 .906 r
.86754 .33348 .87268 .34041 .88552 .33447 .88041 .32731 Mtetra
.709 .779 .907 r
.88041 .32731 .88552 .33447 .89844 .32884 .89336 .3215 Mtetra
.617 .742 .936 r
.29493 .50482 .30182 .51078 .31241 .50835 .30554 .50249 Mtetra
.601 .742 .943 r
.30554 .50249 .31241 .50835 .32304 .50616 .31618 .50044 Mtetra
.581 .742 .952 r
.31618 .50044 .32304 .50616 .33369 .50429 .32685 .49874 Mtetra
.555 .74 .962 r
.32685 .49874 .33369 .50429 .34439 .50277 .33755 .49745 Mtetra
.519 .736 .973 r
.33755 .49745 .34439 .50277 .35511 .50167 .34829 .49662 Mtetra
.472 .728 .982 r
.34829 .49662 .35511 .50167 .36587 .50104 .35906 .49632 Mtetra
.407 .714 .986 r
.35906 .49632 .36587 .50104 .37668 .50094 .36987 .49661 Mtetra
.32 .687 .979 r
.36987 .49661 .37668 .50094 .38752 .5014 .38072 .49755 Mtetra
.205 .64 .949 r
.38072 .49755 .38752 .5014 .39842 .50248 .39162 .49916 Mtetra
.062 .566 .885 r
.39162 .49916 .39842 .50248 .40936 .50419 .40257 .50148 Mtetra
0 .464 .779 r
.40257 .50148 .40936 .50419 .42037 .50653 .41359 .50451 Mtetra
.25 0 0 r
.41359 .50451 .42037 .50653 .43145 .5095 .42467 .50823 Mtetra
.378 0 0 r
.42467 .50823 .43145 .5095 .4426 .51303 .43583 .51259 Mtetra
.471 0 0 r
.43583 .51259 .4426 .51303 .45384 .51707 .44709 .5175 Mtetra
.533 0 0 r
.44709 .5175 .45384 .51707 .46517 .52151 .45844 .52286 Mtetra
.57 .016 0 r
.45844 .52286 .46517 .52151 .4766 .52622 .4699 .5285 Mtetra
.588 .055 0 r
.4699 .5285 .4766 .52622 .48813 .53102 .48147 .53426 Mtetra
.593 .077 0 r
.48147 .53426 .48813 .53102 .49978 .53574 .49315 .5399 Mtetra
.587 .087 .032 r
.49315 .5399 .49978 .53574 .51153 .54017 .50496 .54522 Mtetra
.573 .084 .057 r
.50496 .54522 .51153 .54017 .5234 .54409 .51688 .54995 Mtetra
.55 .071 .071 r
.51688 .54995 .5234 .54409 .53536 .54728 .52891 .55385 Mtetra
.518 .046 .074 r
.52891 .55385 .53536 .54728 .54742 .54952 .54104 .55668 Mtetra
.477 .011 .067 r
.54104 .55668 .54742 .54952 .55956 .55062 .55327 .55823 Mtetra
.426 0 .05 r
.55327 .55823 .55956 .55062 .57178 .55042 .56556 .55831 Mtetra
.361 0 .021 r
.56556 .55831 .57178 .55042 .58404 .54879 .57792 .55679 Mtetra
.281 0 0 r
.57792 .55679 .58404 .54879 .59635 .54566 .59031 .55359 Mtetra
.183 0 0 r
.59031 .55359 .59635 .54566 .60867 .54099 .60273 .54867 Mtetra
.066 0 0 r
.60273 .54867 .60867 .54099 .621 .53483 .61514 .54209 Mtetra
0 0 0 r
.61514 .54209 .621 .53483 .63333 .52724 .62754 .53392 Mtetra
.62754 .53392 .63333 .52724 .64563 .51837 .63992 .52433 Mtetra
.63992 .52433 .64563 .51837 .6579 .50836 .65226 .5135 Mtetra
.519 .839 .537 r
.65226 .5135 .6579 .50836 .67015 .49743 .66457 .50164 Mtetra
.642 .916 .624 r
.66457 .50164 .67015 .49743 .68236 .48578 .67683 .48902 Mtetra
.736 .966 .694 r
.67683 .48902 .68236 .48578 .69454 .47363 .68906 .47587 Mtetra
.803 .991 .748 r
.68906 .47587 .69454 .47363 .7067 .46121 .70126 .46243 Mtetra
.844 .998 .788 r
.70126 .46243 .7067 .46121 .71885 .44873 .71343 .44894 Mtetra
.867 .993 .817 r
.71343 .44894 .71885 .44873 .73099 .43635 .7256 .4356 Mtetra
.876 .98 .838 r
.7256 .4356 .73099 .43635 .74315 .42426 .73778 .42259 Mtetra
.875 .962 .853 r
.73778 .42259 .74315 .42426 .75532 .41257 .74997 .41005 Mtetra
.867 .942 .865 r
.74997 .41005 .75532 .41257 .76753 .40139 .7622 .39809 Mtetra
.854 .921 .875 r
.7622 .39809 .76753 .40139 .77978 .39079 .77447 .38678 Mtetra
.838 .9 .882 r
.77447 .38678 .77978 .39079 .7921 .38081 .78679 .37616 Mtetra
.821 .88 .888 r
.78679 .37616 .7921 .38081 .80447 .37147 .79918 .36626 Mtetra
.803 .861 .892 r
.79918 .36626 .80447 .37147 .81692 .36275 .81165 .35705 Mtetra
.785 .844 .896 r
.81165 .35705 .81692 .36275 .82945 .35463 .8242 .34851 Mtetra
.768 .827 .898 r
.8242 .34851 .82945 .35463 .84206 .34708 .83683 .3406 Mtetra
.752 .813 .9 r
.83683 .3406 .84206 .34708 .85476 .34005 .84955 .33327 Mtetra
.738 .8 .902 r
.84955 .33327 .85476 .34005 .86754 .33348 .86236 .32644 Mtetra
.724 .789 .903 r
.86236 .32644 .86754 .33348 .88041 .32731 .87525 .32006 Mtetra
.713 .78 .904 r
.87525 .32006 .88041 .32731 .89336 .3215 .88824 .31407 Mtetra
.611 .741 .938 r
.28799 .49881 .29493 .50482 .30554 .50249 .29862 .49658 Mtetra
.593 .74 .946 r
.29862 .49658 .30554 .50249 .31618 .50044 .30927 .49467 Mtetra
.571 .738 .955 r
.30927 .49467 .31618 .50044 .32685 .49874 .31995 .49315 Mtetra
.54 .735 .965 r
.31995 .49315 .32685 .49874 .33755 .49745 .33067 .49208 Mtetra
.499 .728 .975 r
.33067 .49208 .33755 .49745 .34829 .49662 .34141 .49152 Mtetra
.444 .717 .982 r
.34141 .49152 .34829 .49662 .35906 .49632 .35219 .49156 Mtetra
.369 .695 .983 r
.35219 .49156 .35906 .49632 .36987 .49661 .363 .49224 Mtetra
.269 .659 .968 r
.363 .49224 .36987 .49661 .38072 .49755 .37386 .49364 Mtetra
.14 .599 .926 r
.37386 .49364 .38072 .49755 .39162 .49916 .38476 .49578 Mtetra
0 .51 .845 r
.38476 .49578 .39162 .49916 .40257 .50148 .39571 .49871 Mtetra
0 .396 .724 r
.39571 .49871 .40257 .50148 .41359 .50451 .40673 .50242 Mtetra
.326 0 0 r
.40673 .50242 .41359 .50451 .42467 .50823 .41782 .50688 Mtetra
.442 0 0 r
.41782 .50688 .42467 .50823 .43583 .51259 .42899 .51205 Mtetra
.524 0 0 r
.42899 .51205 .43583 .51259 .44709 .5175 .44026 .51782 Mtetra
.575 .01 0 r
.44026 .51782 .44709 .5175 .45844 .52286 .45163 .52408 Mtetra
.605 .059 0 r
.45163 .52408 .45844 .52286 .4699 .5285 .46311 .53064 Mtetra
.618 .091 0 r
.46311 .53064 .4699 .5285 .48147 .53426 .47471 .53732 Mtetra
.62 .108 .01 r
.47471 .53732 .48147 .53426 .49315 .5399 .48643 .54387 Mtetra
.611 .112 .042 r
.48643 .54387 .49315 .5399 .50496 .54522 .49828 .55004 Mtetra
.594 .104 .062 r
.49828 .55004 .50496 .54522 .51688 .54995 .51026 .55555 Mtetra
.568 .085 .071 r
.51026 .55555 .51688 .54995 .52891 .55385 .52235 .56014 Mtetra
.532 .055 .069 r
.52235 .56014 .52891 .55385 .54104 .55668 .53456 .56353 Mtetra
.486 .013 .057 r
.53456 .56353 .54104 .55668 .55327 .55823 .54686 .56549 Mtetra
.426 0 .032 r
.54686 .56549 .55327 .55823 .56556 .55831 .55924 .56583 Mtetra
.351 0 0 r
.55924 .56583 .56556 .55831 .57792 .55679 .57168 .56439 Mtetra
.257 0 0 r
.57168 .56439 .57792 .55679 .59031 .55359 .58416 .56109 Mtetra
.14 0 0 r
.58416 .56109 .59031 .55359 .60273 .54867 .59666 .5559 Mtetra
.001 0 0 r
.59666 .5559 .60273 .54867 .61514 .54209 .60917 .54887 Mtetra
0 0 0 r
.60917 .54887 .61514 .54209 .62754 .53392 .62165 .54011 Mtetra
.62165 .54011 .62754 .53392 .63992 .52433 .6341 .52979 Mtetra
.485 .816 .516 r
.6341 .52979 .63992 .52433 .65226 .5135 .64652 .51813 Mtetra
.622 .902 .603 r
.64652 .51813 .65226 .5135 .66457 .50164 .65888 .50536 Mtetra
.728 .958 .673 r
.65888 .50536 .66457 .50164 .67683 .48902 .6712 .49177 Mtetra
.802 .986 .725 r
.6712 .49177 .67683 .48902 .68906 .47587 .68348 .47763 Mtetra
.85 .996 .763 r
.68348 .47763 .68906 .47587 .70126 .46243 .69571 .46319 Mtetra
.878 .993 .791 r
.69571 .46319 .70126 .46243 .71343 .44894 .70793 .44873 Mtetra
.891 .982 .812 r
.70793 .44873 .71343 .44894 .7256 .4356 .72012 .43445 Mtetra
.893 .966 .828 r
.72012 .43445 .7256 .4356 .73778 .42259 .73232 .42056 Mtetra
.888 .949 .842 r
.73232 .42056 .73778 .42259 .74997 .41005 .74454 .40719 Mtetra
.878 .93 .853 r
.74454 .40719 .74997 .41005 .7622 .39809 .75678 .39448 Mtetra
.864 .911 .862 r
.75678 .39448 .7622 .39809 .77447 .38678 .76907 .38249 Mtetra
.847 .892 .87 r
.76907 .38249 .77447 .38678 .78679 .37616 .78142 .37127 Mtetra
.829 .874 .877 r
.78142 .37127 .78679 .37616 .79918 .36626 .79383 .36083 Mtetra
.811 .856 .883 r
.79383 .36083 .79918 .36626 .81165 .35705 .80631 .35116 Mtetra
.792 .84 .888 r
.80631 .35116 .81165 .35705 .8242 .34851 .81888 .34222 Mtetra
.774 .825 .892 r
.81888 .34222 .8242 .34851 .83683 .3406 .83154 .33397 Mtetra
.758 .811 .895 r
.83154 .33397 .83683 .3406 .84955 .33327 .84428 .32635 Mtetra
.742 .799 .898 r
.84428 .32635 .84955 .33327 .86236 .32644 .85712 .31928 Mtetra
.728 .788 .9 r
.85712 .31928 .86236 .32644 .87525 .32006 .87005 .3127 Mtetra
.716 .779 .902 r
.87005 .3127 .87525 .32006 .88824 .31407 .88307 .30654 Mtetra
.605 .739 .939 r
.281 .49274 .28799 .49881 .29862 .49658 .29164 .49062 Mtetra
.586 .737 .948 r
.29164 .49062 .29862 .49658 .30927 .49467 .3023 .48885 Mtetra
.56 .734 .957 r
.3023 .48885 .30927 .49467 .31995 .49315 .313 .48749 Mtetra
.526 .729 .967 r
.313 .48749 .31995 .49315 .33067 .49208 .32372 .48664 Mtetra
.48 .72 .976 r
.32372 .48664 .33067 .49208 .34141 .49152 .33448 .48635 Mtetra
.418 .703 .981 r
.33448 .48635 .34141 .49152 .35219 .49156 .34526 .4867 Mtetra
.334 .676 .977 r
.34526 .4867 .35219 .49156 .363 .49224 .35608 .48776 Mtetra
.223 .63 .955 r
.35608 .48776 .363 .49224 .37386 .49364 .36693 .4896 Mtetra
.083 .558 .903 r
.36693 .4896 .37386 .49364 .38476 .49578 .37784 .49226 Mtetra
0 .459 .81 r
.37784 .49226 .38476 .49578 .39571 .49871 .38879 .49576 Mtetra
0 .339 .681 r
.38879 .49576 .39571 .49871 .40673 .50242 .39981 .50012 Mtetra
.38 0 0 r
.39981 .50012 .40673 .50242 .41782 .50688 .4109 .5053 Mtetra
.487 0 0 r
.4109 .5053 .41782 .50688 .42899 .51205 .42208 .51123 Mtetra
.56 0 0 r
.42208 .51123 .42899 .51205 .44026 .51782 .43335 .51783 Mtetra
.606 .045 0 r
.43335 .51783 .44026 .51782 .45163 .52408 .44474 .52494 Mtetra
.631 .089 0 r
.44474 .52494 .45163 .52408 .46311 .53064 .45623 .53238 Mtetra
.642 .115 0 r
.45623 .53238 .46311 .53064 .47471 .53732 .46786 .53993 Mtetra
.641 .127 .008 r
.46786 .53993 .47471 .53732 .48643 .54387 .47962 .54733 Mtetra
.63 .126 .034 r
.47962 .54733 .48643 .54387 .49828 .55004 .49151 .5543 Mtetra
.61 .114 .049 r
.49151 .5543 .49828 .55004 .51026 .55555 .50354 .56054 Mtetra
.581 .089 .052 r
.50354 .56054 .51026 .55555 .52235 .56014 .51569 .56575 Mtetra
.54 .051 .044 r
.51569 .56575 .52235 .56014 .53456 .56353 .52797 .56965 Mtetra
.487 0 .023 r
.52797 .56965 .53456 .56353 .54686 .56549 .54034 .57199 Mtetra
.416 0 0 r
.54034 .57199 .54686 .56549 .55924 .56583 .5528 .57253 Mtetra
.325 0 0 r
.5528 .57253 .55924 .56583 .57168 .56439 .56533 .57113 Mtetra
.208 0 0 r
.56533 .57113 .57168 .56439 .58416 .56109 .57789 .5677 Mtetra
.063 0 0 r
.57789 .5677 .58416 .56109 .59666 .5559 .59048 .56222 Mtetra
0 0 0 r
.59048 .56222 .59666 .5559 .60917 .54887 .60307 .55474 Mtetra
.60307 .55474 .60917 .54887 .62165 .54011 .61563 .54539 Mtetra
.469 .816 .532 r
.61563 .54539 .62165 .54011 .6341 .52979 .62816 .53436 Mtetra
.619 .907 .618 r
.62816 .53436 .6341 .52979 .64652 .51813 .64064 .52188 Mtetra
.733 .961 .681 r
.64064 .52188 .64652 .51813 .65888 .50536 .65308 .50824 Mtetra
.812 .988 .725 r
.65308 .50824 .65888 .50536 .6712 .49177 .66545 .49372 Mtetra
.861 .994 .756 r
.66545 .49372 .6712 .49177 .68348 .47763 .67778 .47862 Mtetra
.89 .99 .778 r
.67778 .47862 .68348 .47763 .69571 .46319 .69006 .46325 Mtetra
.905 .978 .794 r
.69006 .46325 .69571 .46319 .70793 .44873 .70231 .44786 Mtetra
.909 .964 .808 r
.70231 .44786 .70793 .44873 .72012 .43445 .71454 .4327 Mtetra
.905 .948 .82 r
.71454 .4327 .72012 .43445 .73232 .42056 .72677 .41797 Mtetra
.897 .931 .831 r
.72677 .41797 .73232 .42056 .74454 .40719 .73901 .40384 Mtetra
.885 .914 .841 r
.73901 .40384 .74454 .40719 .75678 .39448 .75128 .39043 Mtetra
.87 .897 .85 r
.75128 .39043 .75678 .39448 .76907 .38249 .7636 .37781 Mtetra
.853 .881 .859 r
.7636 .37781 .76907 .38249 .78142 .37127 .77596 .36603 Mtetra
.835 .865 .867 r
.77596 .36603 .78142 .37127 .79383 .36083 .7884 .3551 Mtetra
.816 .849 .874 r
.7884 .3551 .79383 .36083 .80631 .35116 .80091 .345 Mtetra
.797 .834 .88 r
.80091 .345 .80631 .35116 .81888 .34222 .81351 .3357 Mtetra
.779 .821 .885 r
.81351 .3357 .81888 .34222 .83154 .33397 .82619 .32714 Mtetra
.762 .808 .89 r
.82619 .32714 .83154 .33397 .84428 .32635 .83896 .31925 Mtetra
.746 .797 .894 r
.83896 .31925 .84428 .32635 .85712 .31928 .85183 .31196 Mtetra
.732 .787 .897 r
.85183 .31196 .85712 .31928 .87005 .3127 .86479 .3052 Mtetra
.719 .778 .899 r
.86479 .3052 .87005 .3127 .88307 .30654 .87784 .29888 Mtetra
.599 .737 .941 r
.27395 .48661 .281 .49274 .29164 .49062 .2846 .48458 Mtetra
.578 .734 .949 r
.2846 .48458 .29164 .49062 .3023 .48885 .29529 .48294 Mtetra
.55 .729 .958 r
.29529 .48294 .3023 .48885 .313 .48749 .30599 .48174 Mtetra
.513 .722 .967 r
.30599 .48174 .313 .48749 .32372 .48664 .31673 .48109 Mtetra
.462 .71 .975 r
.31673 .48109 .32372 .48664 .33448 .48635 .32749 .48104 Mtetra
.394 .689 .979 r
.32749 .48104 .33448 .48635 .34526 .4867 .33827 .48169 Mtetra
.303 .656 .971 r
.33827 .48169 .34526 .4867 .35608 .48776 .34909 .48311 Mtetra
.185 .602 .943 r
.34909 .48311 .35608 .48776 .36693 .4896 .35995 .48536 Mtetra
.039 .523 .883 r
.35995 .48536 .36693 .4896 .37784 .49226 .37086 .48849 Mtetra
0 .417 .785 r
.37086 .48849 .37784 .49226 .38879 .49576 .38181 .49253 Mtetra
0 .296 .655 r
.38181 .49253 .38879 .49576 .39981 .50012 .39283 .49749 Mtetra
.415 0 0 r
.39283 .49749 .39981 .50012 .4109 .5053 .40392 .50332 Mtetra
.515 0 0 r
.40392 .50332 .4109 .5053 .42208 .51123 .4151 .50997 Mtetra
.584 .008 0 r
.4151 .50997 .42208 .51123 .43335 .51783 .42638 .51731 Mtetra
.626 .067 0 r
.42638 .51731 .43335 .51783 .44474 .52494 .43777 .5252 Mtetra
.65 .106 0 r
.43777 .5252 .44474 .52494 .45623 .53238 .44929 .53343 Mtetra
.659 .128 0 r
.44929 .53343 .45623 .53238 .46786 .53993 .46094 .54177 Mtetra
.657 .136 0 r
.46094 .54177 .46786 .53993 .47962 .54733 .47272 .54994 Mtetra
.644 .13 .007 r
.47272 .54994 .47962 .54733 .49151 .5543 .48465 .55762 Mtetra
.622 .112 .015 r
.48465 .55762 .49151 .5543 .50354 .56054 .49673 .56451 Mtetra
.589 .08 .01 r
.49673 .56451 .50354 .56054 .51569 .56575 .50893 .57028 Mtetra
.541 .032 0 r
.50893 .57028 .51569 .56575 .52797 .56965 .52127 .57462 Mtetra
.477 0 0 r
.52127 .57462 .52797 .56965 .54034 .57199 .53371 .57725 Mtetra
.389 0 0 r
.53371 .57725 .54034 .57199 .5528 .57253 .54625 .57796 Mtetra
.272 0 0 r
.54625 .57796 .5528 .57253 .56533 .57113 .55885 .57656 Mtetra
.12 0 0 r
.55885 .57656 .56533 .57113 .57789 .5677 .5715 .57298 Mtetra
0 0 0 r
.5715 .57298 .57789 .5677 .59048 .56222 .58417 .56719 Mtetra
.58417 .56719 .59048 .56222 .60307 .55474 .59684 .55926 Mtetra
.472 .839 .593 r
.59684 .55926 .60307 .55474 .61563 .54539 .60948 .54934 Mtetra
.635 .929 .67 r
.60948 .54934 .61563 .54539 .62816 .53436 .62209 .53762 Mtetra
.753 .977 .72 r
.62209 .53762 .62816 .53436 .64064 .52188 .63464 .52438 Mtetra
.83 .994 .75 r
.63464 .52438 .64064 .52188 .65308 .50824 .64714 .50991 Mtetra
.876 .993 .768 r
.64714 .50991 .65308 .50824 .66545 .49372 .65958 .49453 Mtetra
.903 .984 .779 r
.65958 .49453 .66545 .49372 .67778 .47862 .67196 .47856 Mtetra
.916 .97 .787 r
.67196 .47856 .67778 .47862 .69006 .46325 .68429 .46232 Mtetra
.92 .955 .795 r
.68429 .46232 .69006 .46325 .70231 .44786 .69658 .4461 Mtetra
.918 .939 .803 r
.69658 .4461 .70231 .44786 .71454 .4327 .70885 .43014 Mtetra
.911 .924 .811 r
.70885 .43014 .71454 .4327 .72677 .41797 .72112 .41467 Mtetra
.901 .909 .82 r
.72112 .41467 .72677 .41797 .73901 .40384 .73339 .39985 Mtetra
.887 .894 .829 r
.73339 .39985 .73901 .40384 .75128 .39043 .74569 .38581 Mtetra
.872 .88 .838 r
.74569 .38581 .75128 .39043 .7636 .37781 .75803 .37264 Mtetra
.855 .866 .848 r
.75803 .37264 .7636 .37781 .77596 .36603 .77043 .36036 Mtetra
.837 .853 .856 r
.77043 .36036 .77596 .36603 .7884 .3551 .78289 .349 Mtetra
.819 .84 .865 r
.78289 .349 .7884 .3551 .80091 .345 .79543 .33854 Mtetra
.8 .827 .872 r
.79543 .33854 .80091 .345 .81351 .3357 .80806 .32892 Mtetra
.782 .815 .879 r
.80806 .32892 .81351 .3357 .82619 .32714 .82077 .32008 Mtetra
.765 .804 .884 r
.82077 .32008 .82619 .32714 .83896 .31925 .83358 .31196 Mtetra
.749 .794 .889 r
.83358 .31196 .83896 .31925 .85183 .31196 .84648 .30448 Mtetra
.734 .785 .893 r
.84648 .30448 .85183 .31196 .86479 .3052 .85948 .29755 Mtetra
.721 .776 .896 r
.85948 .29755 .86479 .3052 .87784 .29888 .87257 .2911 Mtetra
.594 .734 .941 r
.26685 .48041 .27395 .48661 .2846 .48458 .27752 .47846 Mtetra
.572 .73 .949 r
.27752 .47846 .2846 .48458 .29529 .48294 .28821 .47692 Mtetra
.541 .724 .958 r
.28821 .47692 .29529 .48294 .30599 .48174 .29893 .47587 Mtetra
.501 .715 .967 r
.29893 .47587 .30599 .48174 .31673 .48109 .30968 .4754 Mtetra
.447 .7 .974 r
.30968 .4754 .31673 .48109 .32749 .48104 .32044 .47557 Mtetra
.375 .675 .975 r
.32044 .47557 .32749 .48104 .33827 .48169 .33124 .47649 Mtetra
.279 .637 .965 r
.33124 .47649 .33827 .48169 .34909 .48311 .34206 .47822 Mtetra
.157 .578 .933 r
.34206 .47822 .34909 .48311 .35995 .48536 .35292 .48083 Mtetra
.01 .494 .87 r
.35292 .48083 .35995 .48536 .37086 .48849 .36382 .48439 Mtetra
0 .387 .772 r
.36382 .48439 .37086 .48849 .38181 .49253 .37478 .4889 Mtetra
0 .268 .647 r
.37478 .4889 .38181 .49253 .39283 .49749 .3858 .49438 Mtetra
.431 0 0 r
.3858 .49438 .39283 .49749 .40392 .50332 .39689 .50079 Mtetra
.528 0 0 r
.39689 .50079 .40392 .50332 .4151 .50997 .40807 .50806 Mtetra
.594 .02 0 r
.40807 .50806 .4151 .50997 .42638 .51731 .41935 .51606 Mtetra
.636 .075 0 r
.41935 .51606 .42638 .51731 .43777 .5252 .43075 .52462 Mtetra
.659 .11 0 r
.43075 .52462 .43777 .5252 .44929 .53343 .44228 .53354 Mtetra
.668 .129 0 r
.44228 .53354 .44929 .53343 .46094 .54177 .45394 .54256 Mtetra
.666 .132 0 r
.45394 .54256 .46094 .54177 .47272 .54994 .46575 .55138 Mtetra
.652 .122 0 r
.46575 .55138 .47272 .54994 .48465 .55762 .47772 .55967 Mtetra
.626 .096 0 r
.47772 .55967 .48465 .55762 .49673 .56451 .48983 .56709 Mtetra
.587 .053 0 r
.48983 .56709 .49673 .56451 .50893 .57028 .50208 .57331 Mtetra
.53 0 0 r
.50208 .57331 .50893 .57028 .52127 .57462 .51447 .57799 Mtetra
.448 0 0 r
.51447 .57799 .52127 .57462 .53371 .57725 .52698 .58085 Mtetra
.332 0 0 r
.52698 .58085 .53371 .57725 .54625 .57796 .53958 .58165 Mtetra
.172 0 0 r
.53958 .58165 .54625 .57796 .55885 .57656 .55226 .58021 Mtetra
0 0 0 r
.55226 .58021 .55885 .57656 .5715 .57298 .56498 .57645 Mtetra
.56498 .57645 .5715 .57298 .58417 .56719 .57773 .57035 Mtetra
.491 .88 .699 r
.57773 .57035 .58417 .56719 .59684 .55926 .59048 .56199 Mtetra
.663 .962 .76 r
.59048 .56199 .59684 .55926 .60948 .54934 .6032 .55153 Mtetra
.779 .995 .787 r
.6032 .55153 .60948 .54934 .62209 .53762 .61588 .53919 Mtetra
.85 .998 .794 r
.61588 .53919 .62209 .53762 .63464 .52438 .6285 .52526 Mtetra
.89 .988 .794 r
.6285 .52526 .63464 .52438 .64714 .50991 .64107 .51005 Mtetra
.913 .972 .791 r
.64107 .51005 .64714 .50991 .65958 .49453 .65356 .49391 Mtetra
.923 .955 .789 r
.65356 .49391 .65958 .49453 .67196 .47856 .666 .47718 Mtetra
.926 .938 .789 r
.666 .47718 .67196 .47856 .68429 .46232 .67839 .46019 Mtetra
.924 .923 .791 r
.67839 .46019 .68429 .46232 .69658 .4461 .69073 .44324 Mtetra
.919 .909 .796 r
.69073 .44324 .69658 .4461 .70885 .43014 .70304 .4266 Mtetra
.91 .896 .802 r
.70304 .4266 .70885 .43014 .72112 .41467 .71535 .41049 Mtetra
.899 .884 .809 r
.71535 .41049 .72112 .41467 .73339 .39985 .72766 .39509 Mtetra
.886 .872 .818 r
.72766 .39509 .73339 .39985 .74569 .38581 .74 .38053 Mtetra
.871 .861 .827 r
.74 .38053 .74569 .38581 .75803 .37264 .75238 .36688 Mtetra
.855 .85 .837 r
.75238 .36688 .75803 .37264 .77043 .36036 .76481 .3542 Mtetra
.838 .839 .847 r
.76481 .3542 .77043 .36036 .78289 .349 .77731 .34248 Mtetra
.82 .829 .856 r
.77731 .34248 .78289 .349 .79543 .33854 .78988 .3317 Mtetra
.802 .818 .864 r
.78988 .3317 .79543 .33854 .80806 .32892 .80254 .32181 Mtetra
.784 .808 .872 r
.80254 .32181 .80806 .32892 .82077 .32008 .81529 .31276 Mtetra
.767 .799 .879 r
.81529 .31276 .82077 .32008 .83358 .31196 .82813 .30445 Mtetra
.75 .79 .885 r
.82813 .30445 .83358 .31196 .84648 .30448 .84107 .2968 Mtetra
.736 .781 .889 r
.84107 .2968 .84648 .30448 .85948 .29755 .85411 .28974 Mtetra
.722 .774 .893 r
.85411 .28974 .85948 .29755 .87257 .2911 .86724 .28317 Mtetra
.59 .731 .942 r
.2597 .4741 .26685 .48041 .27752 .47846 .27038 .47223 Mtetra
.566 .726 .949 r
.27038 .47223 .27752 .47846 .28821 .47692 .28109 .47078 Mtetra
.534 .719 .958 r
.28109 .47078 .28821 .47692 .29893 .47587 .29182 .46986 Mtetra
.492 .708 .966 r
.29182 .46986 .29893 .47587 .30968 .4754 .30258 .46953 Mtetra
.436 .69 .972 r
.30258 .46953 .30968 .4754 .32044 .47557 .31335 .46989 Mtetra
.362 .663 .971 r
.31335 .46989 .32044 .47557 .33124 .47649 .32415 .47103 Mtetra
.264 .62 .959 r
.32415 .47103 .33124 .47649 .34206 .47822 .33498 .47302 Mtetra
.142 .559 .926 r
.33498 .47302 .34206 .47822 .35292 .48083 .34584 .47595 Mtetra
0 .474 .865 r
.34584 .47595 .35292 .48083 .36382 .48439 .35675 .47985 Mtetra
0 .369 .772 r
.35675 .47985 .36382 .48439 .37478 .4889 .3677 .48476 Mtetra
0 .255 .656 r
.3677 .48476 .37478 .4889 .3858 .49438 .37872 .49068 Mtetra
.428 0 0 r
.37872 .49068 .3858 .49438 .39689 .50079 .38981 .49756 Mtetra
.523 0 0 r
.38981 .49756 .39689 .50079 .40807 .50806 .40099 .50533 Mtetra
.589 .017 0 r
.40099 .50533 .40807 .50806 .41935 .51606 .41227 .51387 Mtetra
.632 .068 0 r
.41227 .51387 .41935 .51606 .43075 .52462 .42368 .52298 Mtetra
.656 .1 0 r
.42368 .52298 .43075 .52462 .44228 .53354 .43521 .53245 Mtetra
.666 .115 0 r
.43521 .53245 .44228 .53354 .45394 .54256 .44689 .542 Mtetra
.663 .114 0 r
.44689 .542 .45394 .54256 .46575 .55138 .45872 .55133 Mtetra
.647 .096 0 r
.45872 .55133 .46575 .55138 .47772 .55967 .47071 .56008 Mtetra
.616 .06 0 r
.47071 .56008 .47772 .55967 .48983 .56709 .48286 .56791 Mtetra
.567 .001 0 r
.48286 .56791 .48983 .56709 .50208 .57331 .49515 .57446 Mtetra
.491 0 0 r
.49515 .57446 .50208 .57331 .51447 .57799 .50759 .57938 Mtetra
.378 0 0 r
.50759 .57938 .51447 .57799 .52698 .58085 .52015 .58237 Mtetra
.213 0 0 r
.52015 .58237 .52698 .58085 .53958 .58165 .53281 .58319 Mtetra
0 0 0 r
.53281 .58319 .53958 .58165 .55226 .58021 .54555 .58167 Mtetra
.273 .773 .748 r
.54555 .58167 .55226 .58021 .56498 .57645 .55835 .57771 Mtetra
.513 .913 .836 r
.55835 .57771 .56498 .57645 .57773 .57035 .57117 .5713 Mtetra
.688 .98 .868 r
.57117 .5713 .57773 .57035 .59048 .56199 .58398 .56254 Mtetra
.796 .996 .863 r
.58398 .56254 .59048 .56199 .6032 .55153 .59678 .5516 Mtetra
.859 .987 .846 r
.59678 .5516 .6032 .55153 .61588 .53919 .60953 .53872 Mtetra
.894 .968 .826 r
.60953 .53872 .61588 .53919 .6285 .52526 .62222 .52419 Mtetra
.912 .949 .809 r
.62222 .52419 .6285 .52526 .64107 .51005 .63485 .50836 Mtetra
.921 .93 .797 r
.63485 .50836 .64107 .51005 .65356 .49391 .64741 .49159 Mtetra
.924 .914 .789 r
.64741 .49159 .65356 .49391 .666 .47718 .65991 .47423 Mtetra
.923 .899 .785 r
.65991 .47423 .666 .47718 .67839 .46019 .67235 .45663 Mtetra
.919 .887 .785 r
.67235 .45663 .67839 .46019 .69073 .44324 .68475 .43909 Mtetra
.912 .876 .787 r
.68475 .43909 .69073 .44324 .70304 .4266 .69711 .42191 Mtetra
.904 .866 .792 r
.69711 .42191 .70304 .4266 .71535 .41049 .70947 .4053 Mtetra
.893 .857 .799 r
.70947 .4053 .71535 .41049 .72766 .39509 .72182 .38944 Mtetra
.881 .849 .808 r
.72182 .38944 .72766 .39509 .74 .38053 .7342 .37447 Mtetra
.867 .841 .817 r
.7342 .37447 .74 .38053 .75238 .36688 .74662 .36046 Mtetra
.852 .833 .827 r
.74662 .36046 .75238 .36688 .76481 .3542 .75909 .34746 Mtetra
.836 .825 .838 r
.75909 .34746 .76481 .3542 .77731 .34248 .77163 .33547 Mtetra
.819 .817 .848 r
.77163 .33547 .77731 .34248 .78988 .3317 .78425 .32446 Mtetra
.801 .808 .857 r
.78425 .32446 .78988 .3317 .80254 .32181 .79695 .31437 Mtetra
.784 .8 .866 r
.79695 .31437 .80254 .32181 .81529 .31276 .80974 .30514 Mtetra
.767 .792 .874 r
.80974 .30514 .81529 .31276 .82813 .30445 .82262 .29668 Mtetra
.751 .785 .88 r
.82262 .29668 .82813 .30445 .84107 .2968 .8356 .28892 Mtetra
.736 .778 .886 r
.8356 .28892 .84107 .2968 .85411 .28974 .84868 .28175 Mtetra
.723 .771 .891 r
.84868 .28175 .85411 .28974 .86724 .28317 .86185 .27509 Mtetra
.587 .728 .941 r
.25249 .4677 .2597 .4741 .27038 .47223 .2632 .46588 Mtetra
.562 .723 .949 r
.2632 .46588 .27038 .47223 .28109 .47078 .27392 .4645 Mtetra
.529 .714 .957 r
.27392 .4645 .28109 .47078 .29182 .46986 .28467 .46367 Mtetra
.486 .701 .964 r
.28467 .46367 .29182 .46986 .30258 .46953 .29543 .46346 Mtetra
.429 .681 .969 r
.29543 .46346 .30258 .46953 .31335 .46989 .30622 .46396 Mtetra
.354 .652 .967 r
.30622 .46396 .31335 .46989 .32415 .47103 .31702 .46527 Mtetra
.259 .608 .955 r
.31702 .46527 .32415 .47103 .33498 .47302 .32786 .46747 Mtetra
.14 .545 .923 r
.32786 .46747 .33498 .47302 .34584 .47595 .33872 .47062 Mtetra
.002 .463 .867 r
.33872 .47062 .34584 .47595 .35675 .47985 .34963 .47479 Mtetra
0 .364 .783 r
.34963 .47479 .35675 .47985 .3677 .48476 .36058 .48 Mtetra
0 .257 .681 r
.36058 .48 .3677 .48476 .37872 .49068 .3716 .48625 Mtetra
.404 0 0 r
.3716 .48625 .37872 .49068 .38981 .49756 .38269 .49349 Mtetra
.497 0 0 r
.38269 .49349 .38981 .49756 .40099 .50533 .39387 .50164 Mtetra
.564 0 0 r
.39387 .50164 .40099 .50533 .41227 .51387 .40515 .51056 Mtetra
.608 .045 0 r
.40515 .51056 .41227 .51387 .42368 .52298 .41656 .52006 Mtetra
.634 .074 0 r
.41656 .52006 .42368 .52298 .43521 .53245 .4281 .52992 Mtetra
.643 .084 0 r
.4281 .52992 .43521 .53245 .44689 .542 .43979 .53985 Mtetra
.638 .076 0 r
.43979 .53985 .44689 .542 .45872 .55133 .45164 .54952 Mtetra
.616 .048 0 r
.45164 .54952 .45872 .55133 .47071 .56008 .46365 .55858 Mtetra
.574 0 0 r
.46365 .55858 .47071 .56008 .48286 .56791 .47582 .56666 Mtetra
.505 0 0 r
.47582 .56666 .48286 .56791 .49515 .57446 .48815 .5734 Mtetra
.395 0 0 r
.48815 .5734 .49515 .57446 .50759 .57938 .50063 .57843 Mtetra
.228 0 0 r
.50063 .57843 .50759 .57938 .52015 .58237 .51324 .58146 Mtetra
.004 .577 .762 r
.51324 .58146 .52015 .58237 .53281 .58319 .52595 .58223 Mtetra
.273 .769 .893 r
.52595 .58223 .53281 .58319 .54555 .58167 .53875 .58058 Mtetra
.514 .897 .955 r
.53875 .58058 .54555 .58167 .55835 .57771 .5516 .5764 Mtetra
.683 .951 .955 r
.5516 .5764 .55835 .57771 .57117 .5713 .56448 .56971 Mtetra
.786 .959 .923 r
.56448 .56971 .57117 .5713 .58398 .56254 .57737 .5606 Mtetra
.845 .947 .886 r
.57737 .5606 .58398 .56254 .59678 .5516 .59023 .54925 Mtetra
.878 .928 .852 r
.59023 .54925 .59678 .5516 .60953 .53872 .60305 .53592 Mtetra
.897 .91 .825 r
.60305 .53592 .60953 .53872 .62222 .52419 .61581 .52092 Mtetra
.907 .893 .805 r
.61581 .52092 .62222 .52419 .63485 .50836 .6285 .50461 Mtetra
.911 .879 .791 r
.6285 .50461 .63485 .50836 .64741 .49159 .64113 .48736 Mtetra
.912 .867 .781 r
.64113 .48736 .64741 .49159 .65991 .47423 .65368 .46953 Mtetra
.91 .858 .777 r
.65368 .46953 .65991 .47423 .67235 .45663 .66618 .45148 Mtetra
.907 .849 .776 r
.66618 .45148 .67235 .45663 .68475 .43909 .67864 .43353 Mtetra
.901 .842 .778 r
.67864 .43353 .68475 .43909 .69711 .42191 .69106 .41596 Mtetra
.893 .836 .782 r
.69106 .41596 .69711 .42191 .70947 .4053 .70346 .399 Mtetra
.884 .831 .789 r
.70346 .399 .70947 .4053 .72182 .38944 .71587 .38283 Mtetra
.873 .825 .798 r
.71587 .38283 .72182 .38944 .7342 .37447 .7283 .36758 Mtetra
.861 .82 .808 r
.7283 .36758 .7342 .37447 .74662 .36046 .74077 .35333 Mtetra
.847 .815 .819 r
.74077 .35333 .74662 .36046 .75909 .34746 .75329 .34012 Mtetra
.832 .81 .829 r
.75329 .34012 .75909 .34746 .77163 .33547 .76587 .32794 Mtetra
.815 .804 .84 r
.76587 .32794 .77163 .33547 .78425 .32446 .77853 .31677 Mtetra
.799 .798 .851 r
.77853 .31677 .78425 .32446 .79695 .31437 .79128 .30655 Mtetra
.782 .792 .86 r
.79128 .30655 .79695 .31437 .80974 .30514 .80411 .29721 Mtetra
.766 .785 .869 r
.80411 .29721 .80974 .30514 .82262 .29668 .81704 .28866 Mtetra
.75 .779 .876 r
.81704 .28866 .82262 .29668 .8356 .28892 .83007 .28081 Mtetra
.736 .773 .883 r
.83007 .28081 .8356 .28892 .84868 .28175 .84319 .27357 Mtetra
.723 .768 .888 r
.84319 .27357 .84868 .28175 .86185 .27509 .85641 .26685 Mtetra
.585 .726 .94 r
.24524 .46118 .25249 .4677 .2632 .46588 .25596 .45939 Mtetra
.559 .719 .947 r
.25596 .45939 .2632 .46588 .27392 .4645 .2667 .45806 Mtetra
.526 .709 .955 r
.2667 .45806 .27392 .4645 .28467 .46367 .27746 .45729 Mtetra
.483 .695 .961 r
.27746 .45729 .28467 .46367 .29543 .46346 .28824 .45715 Mtetra
.427 .674 .965 r
.28824 .45715 .29543 .46346 .30622 .46396 .29904 .45775 Mtetra
.354 .643 .964 r
.29904 .45775 .30622 .46396 .31702 .46527 .30985 .45917 Mtetra
.262 .599 .951 r
.30985 .45917 .31702 .46527 .32786 .46747 .32069 .4615 Mtetra
.15 .538 .923 r
.32069 .4615 .32786 .46747 .33872 .47062 .33156 .46481 Mtetra
.021 .461 .874 r
.33156 .46481 .33872 .47062 .34963 .47479 .34247 .46916 Mtetra
0 .369 .803 r
.34247 .46916 .34963 .47479 .36058 .48 .35343 .47456 Mtetra
0 .272 .716 r
.35343 .47456 .36058 .48 .3716 .48625 .36445 .48101 Mtetra
0 .179 .624 r
.36445 .48101 .3716 .48625 .38269 .49349 .37554 .48846 Mtetra
.449 0 0 r
.37554 .48846 .38269 .49349 .39387 .50164 .38672 .49684 Mtetra
.515 0 0 r
.38672 .49684 .39387 .50164 .40515 .51056 .39801 .50598 Mtetra
.558 .004 0 r
.39801 .50598 .40515 .51056 .41656 .52006 .40942 .51572 Mtetra
.582 .027 0 r
.40942 .51572 .41656 .52006 .4281 .52992 .42097 .52579 Mtetra
.587 .031 0 r
.42097 .52579 .4281 .52992 .43979 .53985 .43267 .53591 Mtetra
.573 .013 0 r
.43267 .53591 .43979 .53985 .45164 .54952 .44453 .54574 Mtetra
.537 0 0 r
.44453 .54574 .45164 .54952 .46365 .55858 .45655 .55493 Mtetra
.471 0 0 r
.45655 .55493 .46365 .55858 .47582 .56666 .46875 .5631 Mtetra
.364 0 0 r
.46875 .5631 .47582 .56666 .48815 .5734 .4811 .56987 Mtetra
0 .36 .722 r
.4811 .56987 .48815 .5734 .50063 .57843 .49361 .57489 Mtetra
.015 .535 .86 r
.49361 .57489 .50063 .57843 .51324 .58146 .50625 .57785 Mtetra
.26 .698 .962 r
.50625 .57785 .51324 .58146 .52595 .58223 .51901 .5785 Mtetra
.479 .81 1 r
.51901 .5785 .52595 .58223 .53875 .58058 .53185 .57667 Mtetra
.637 .864 .984 r
.53185 .57667 .53875 .58058 .5516 .5764 .54476 .57227 Mtetra
.739 .88 .945 r
.54476 .57227 .5516 .5764 .56448 .56971 .5577 .56532 Mtetra
.802 .877 .902 r
.5577 .56532 .56448 .56971 .57737 .5606 .57064 .55591 Mtetra
.84 .867 .863 r
.57064 .55591 .57737 .5606 .59023 .54925 .58356 .54425 Mtetra
.863 .856 .832 r
.58356 .54425 .59023 .54925 .60305 .53592 .59644 .5306 Mtetra
.878 .845 .808 r
.59644 .5306 .60305 .53592 .61581 .52092 .60926 .51527 Mtetra
.887 .836 .791 r
.60926 .51527 .61581 .52092 .6285 .50461 .62202 .49864 Mtetra
.891 .828 .778 r
.62202 .49864 .6285 .50461 .64113 .48736 .63471 .48108 Mtetra
.893 .822 .77 r
.63471 .48108 .64113 .48736 .65368 .46953 .64733 .46296 Mtetra
.893 .817 .766 r
.64733 .46296 .65368 .46953 .66618 .45148 .65989 .44464 Mtetra
.89 .813 .766 r
.65989 .44464 .66618 .45148 .67864 .43353 .6724 .42645 Mtetra
.886 .81 .768 r
.6724 .42645 .67864 .43353 .69106 .41596 .68488 .40867 Mtetra
.88 .807 .773 r
.68488 .40867 .69106 .41596 .70346 .399 .69735 .39152 Mtetra
.872 .805 .781 r
.69735 .39152 .70346 .399 .71587 .38283 .70981 .37519 Mtetra
.863 .802 .789 r
.70981 .37519 .71587 .38283 .7283 .36758 .7223 .3598 Mtetra
.852 .8 .8 r
.7223 .3598 .7283 .36758 .74077 .35333 .73482 .34544 Mtetra
.839 .797 .811 r
.73482 .34544 .74077 .35333 .75329 .34012 .74739 .33213 Mtetra
.826 .794 .822 r
.74739 .33213 .75329 .34012 .76587 .32794 .76003 .31987 Mtetra
.811 .791 .834 r
.76003 .31987 .76587 .32794 .77853 .31677 .77274 .30864 Mtetra
.795 .787 .845 r
.77274 .30864 .77853 .31677 .79128 .30655 .78554 .29836 Mtetra
.78 .783 .855 r
.78554 .29836 .79128 .30655 .80411 .29721 .79842 .28897 Mtetra
.764 .778 .865 r
.79842 .28897 .80411 .29721 .81704 .28866 .8114 .28037 Mtetra
.749 .773 .873 r
.8114 .28037 .81704 .28866 .83007 .28081 .82447 .27248 Mtetra
.735 .769 .88 r
.82447 .27248 .83007 .28081 .84319 .27357 .83764 .2652 Mtetra
.722 .764 .886 r
.83764 .2652 .84319 .27357 .85641 .26685 .85091 .25845 Mtetra
.584 .723 .939 r
.23793 .45454 .24524 .46118 .25596 .45939 .24867 .45276 Mtetra
.559 .715 .946 r
.24867 .45276 .25596 .45939 .2667 .45806 .25943 .45145 Mtetra
.526 .705 .952 r
.25943 .45145 .2667 .45806 .27746 .45729 .27021 .4507 Mtetra
.484 .689 .958 r
.27021 .4507 .27746 .45729 .28824 .45715 .281 .45059 Mtetra
.429 .667 .961 r
.281 .45059 .28824 .45715 .29904 .45775 .29181 .45123 Mtetra
.36 .636 .96 r
.29181 .45123 .29904 .45775 .30985 .45917 .30264 .4527 Mtetra
.274 .594 .949 r
.30264 .4527 .30985 .45917 .32069 .4615 .31349 .45509 Mtetra
.171 .537 .925 r
.31349 .45509 .32069 .4615 .33156 .46481 .32437 .45847 Mtetra
.054 .466 .884 r
.32437 .45847 .33156 .46481 .34247 .46916 .33529 .46288 Mtetra
0 .383 .827 r
.33529 .46288 .34247 .46916 .35343 .47456 .34625 .46835 Mtetra
0 .297 .757 r
.34625 .46835 .35343 .47456 .36445 .48101 .35728 .47488 Mtetra
0 .215 .684 r
.35728 .47488 .36445 .48101 .37554 .48846 .36837 .48241 Mtetra
0 .144 .615 r
.36837 .48241 .37554 .48846 .38672 .49684 .37956 .49084 Mtetra
0 .09 .56 r
.37956 .49084 .38672 .49684 .39801 .50598 .39085 .50005 Mtetra
.474 0 0 r
.39085 .50005 .39801 .50598 .40942 .51572 .40226 .50982 Mtetra
.49 0 0 r
.40226 .50982 .40942 .51572 .42097 .52579 .41382 .51991 Mtetra
.484 0 0 r
.41382 .51991 .42097 .52579 .43267 .53591 .42552 .53003 Mtetra
.453 0 0 r
.42552 .53003 .43267 .53591 .44453 .54574 .43739 .53984 Mtetra
0 .133 .6 r
.43739 .53984 .44453 .54574 .45655 .55493 .44943 .54898 Mtetra
0 .22 .683 r
.44943 .54898 .45655 .55493 .46875 .5631 .46164 .55706 Mtetra
0 .337 .783 r
.46164 .55706 .46875 .5631 .4811 .56987 .47402 .56372 Mtetra
.039 .47 .881 r
.47402 .56372 .4811 .56987 .49361 .57489 .48655 .56859 Mtetra
.241 .595 .95 r
.48655 .56859 .49361 .57489 .50625 .57785 .49922 .57138 Mtetra
.425 .69 .974 r
.49922 .57138 .50625 .57785 .51901 .5785 .51201 .57184 Mtetra
.569 .748 .961 r
.51201 .57184 .51901 .5785 .53185 .57667 .52489 .5698 Mtetra
.67 .777 .93 r
.52489 .5698 .53185 .57667 .54476 .57227 .53783 .56518 Mtetra
.739 .789 .893 r
.53783 .56518 .54476 .57227 .5577 .56532 .55082 .558 Mtetra
.785 .793 .859 r
.55082 .558 .5577 .56532 .57064 .55591 .56381 .54837 Mtetra
.816 .792 .829 r
.56381 .54837 .57064 .55591 .58356 .54425 .57678 .5365 Mtetra
.837 .789 .806 r
.57678 .5365 .58356 .54425 .59644 .5306 .58971 .52265 Mtetra
.852 .786 .787 r
.58971 .52265 .59644 .5306 .60926 .51527 .60259 .50715 Mtetra
.861 .784 .774 r
.60259 .50715 .60926 .51527 .62202 .49864 .61541 .49037 Mtetra
.868 .782 .764 r
.61541 .49037 .62202 .49864 .63471 .48108 .62816 .47268 Mtetra
.871 .78 .758 r
.62816 .47268 .63471 .48108 .64733 .46296 .64084 .45446 Mtetra
.872 .78 .756 r
.64084 .45446 .64733 .46296 .65989 .44464 .65347 .43607 Mtetra
.872 .779 .757 r
.65347 .43607 .65989 .44464 .6724 .42645 .66604 .41783 Mtetra
.869 .779 .76 r
.66604 .41783 .6724 .42645 .68488 .40867 .67859 .40001 Mtetra
.865 .78 .765 r
.67859 .40001 .68488 .40867 .69735 .39152 .69111 .38285 Mtetra
.859 .78 .773 r
.69111 .38285 .69735 .39152 .70981 .37519 .70364 .36652 Mtetra
.851 .781 .782 r
.70364 .36652 .70981 .37519 .7223 .3598 .71619 .35114 Mtetra
.842 .781 .793 r
.71619 .35114 .7223 .3598 .73482 .34544 .72877 .33679 Mtetra
.831 .78 .804 r
.72877 .33679 .73482 .34544 .74739 .33213 .7414 .3235 Mtetra
.818 .78 .816 r
.7414 .3235 .74739 .33213 .76003 .31987 .7541 .31126 Mtetra
.805 .778 .828 r
.7541 .31126 .76003 .31987 .77274 .30864 .76687 .30004 Mtetra
.79 .776 .84 r
.76687 .30004 .77274 .30864 .78554 .29836 .77972 .28978 Mtetra
.776 .774 .851 r
.77972 .28978 .78554 .29836 .79842 .28897 .79266 .2804 Mtetra
.761 .771 .861 r
.79266 .2804 .79842 .28897 .8114 .28037 .80569 .27181 Mtetra
.747 .767 .87 r
.80569 .27181 .8114 .28037 .82447 .27248 .81882 .26393 Mtetra
.733 .764 .878 r
.81882 .26393 .82447 .27248 .83764 .2652 .83204 .25664 Mtetra
.721 .761 .884 r
.83204 .25664 .83764 .2652 .85091 .25845 .84535 .24988 Mtetra
.584 .721 .937 r
.23058 .44778 .23793 .45454 .24867 .45276 .24134 .44598 Mtetra
.559 .713 .943 r
.24134 .44598 .24867 .45276 .25943 .45145 .25212 .44465 Mtetra
.528 .701 .949 r
.25212 .44465 .25943 .45145 .27021 .4507 .26292 .44389 Mtetra
.487 .685 .954 r
.26292 .44389 .27021 .4507 .281 .45059 .27373 .44377 Mtetra
.436 .663 .957 r
.27373 .44377 .281 .45059 .29181 .45123 .28455 .44439 Mtetra
.371 .632 .955 r
.28455 .44439 .29181 .45123 .30264 .4527 .2954 .44585 Mtetra
.293 .592 .946 r
.2954 .44585 .30264 .4527 .31349 .45509 .30626 .44821 Mtetra
.2 .539 .927 r
.30626 .44821 .31349 .45509 .32437 .45847 .31716 .45156 Mtetra
.098 .476 .894 r
.31716 .45156 .32437 .45847 .33529 .46288 .32809 .45593 Mtetra
0 .403 .85 r
.32809 .45593 .33529 .46288 .34625 .46835 .33906 .46136 Mtetra
0 .329 .797 r
.33906 .46136 .34625 .46835 .35728 .47488 .35009 .46782 Mtetra
0 .258 .741 r
.35009 .46782 .35728 .47488 .36837 .48241 .36119 .47527 Mtetra
0 .198 .691 r
.36119 .47527 .36837 .48241 .37956 .49084 .37239 .48361 Mtetra
0 .153 .652 r
.37239 .48361 .37956 .49084 .39085 .50005 .38368 .4927 Mtetra
0 .126 .63 r
.38368 .4927 .39085 .50005 .40226 .50982 .39511 .50233 Mtetra
0 .119 .626 r
.39511 .50233 .40226 .50982 .41382 .51991 .40666 .51225 Mtetra
0 .135 .644 r
.40666 .51225 .41382 .51991 .42552 .53003 .41838 .52218 Mtetra
0 .173 .682 r
.41838 .52218 .42552 .53003 .43739 .53984 .43025 .53177 Mtetra
0 .235 .737 r
.43025 .53177 .43739 .53984 .44943 .54898 .4423 .54067 Mtetra
0 .318 .802 r
.4423 .54067 .44943 .54898 .46164 .55706 .45452 .5485 Mtetra
.07 .412 .862 r
.45452 .5485 .46164 .55706 .47402 .56372 .46691 .55489 Mtetra
.227 .504 .905 r
.46691 .55489 .47402 .56372 .48655 .56859 .47946 .55949 Mtetra
.376 .582 .922 r
.47946 .55949 .48655 .56859 .49922 .57138 .49215 .56201 Mtetra
.501 .639 .916 r
.49215 .56201 .49922 .57138 .51201 .57184 .50496 .56221 Mtetra
.598 .677 .896 r
.50496 .56221 .51201 .57184 .52489 .5698 .51786 .55992 Mtetra
.671 .701 .87 r
.51786 .55992 .52489 .5698 .53783 .56518 .53084 .55509 Mtetra
.723 .716 .843 r
.53084 .55509 .53783 .56518 .55082 .558 .54386 .54773 Mtetra
.762 .725 .818 r
.54386 .54773 .55082 .558 .56381 .54837 .55689 .53797 Mtetra
.789 .73 .797 r
.55689 .53797 .56381 .54837 .57678 .5365 .56991 .52599 Mtetra
.81 .734 .78 r
.56991 .52599 .57678 .5365 .58971 .52265 .58289 .51209 Mtetra
.825 .737 .767 r
.58289 .51209 .58971 .52265 .60259 .50715 .59582 .49658 Mtetra
.836 .739 .757 r
.59582 .49658 .60259 .50715 .61541 .49037 .60869 .47982 Mtetra
.844 .742 .751 r
.60869 .47982 .61541 .49037 .62816 .47268 .6215 .46219 Mtetra
.849 .744 .747 r
.6215 .46219 .62816 .47268 .64084 .45446 .63425 .44407 Mtetra
.852 .747 .746 r
.63425 .44407 .64084 .45446 .65347 .43607 .64693 .42579 Mtetra
.853 .749 .748 r
.64693 .42579 .65347 .43607 .66604 .41783 .65958 .40769 Mtetra
.852 .752 .752 r
.65958 .40769 .66604 .41783 .67859 .40001 .67219 .39002 Mtetra
.849 .755 .758 r
.67219 .39002 .67859 .40001 .69111 .38285 .68478 .37301 Mtetra
.845 .758 .766 r
.68478 .37301 .69111 .38285 .70364 .36652 .69737 .35683 Mtetra
.839 .76 .776 r
.69737 .35683 .70364 .36652 .71619 .35114 .70999 .34161 Mtetra
.831 .763 .787 r
.70999 .34161 .71619 .35114 .72877 .33679 .72263 .3274 Mtetra
.821 .765 .799 r
.72263 .3274 .72877 .33679 .7414 .3235 .73533 .31424 Mtetra
.81 .766 .812 r
.73533 .31424 .7414 .3235 .7541 .31126 .74809 .30212 Mtetra
.798 .766 .824 r
.74809 .30212 .7541 .31126 .76687 .30004 .76092 .29101 Mtetra
.785 .766 .836 r
.76092 .29101 .76687 .30004 .77972 .28978 .77383 .28084 Mtetra
.771 .765 .848 r
.77383 .28084 .77972 .28978 .79266 .2804 .78683 .27153 Mtetra
.757 .764 .858 r
.78683 .27153 .79266 .2804 .80569 .27181 .79992 .263 Mtetra
.743 .762 .868 r
.79992 .263 .80569 .27181 .81882 .26393 .8131 .25515 Mtetra
.73 .759 .876 r
.8131 .25515 .81882 .26393 .83204 .25664 .82637 .2479 Mtetra
.719 .757 .883 r
.82637 .2479 .83204 .25664 .84535 .24988 .83974 .24115 Mtetra
.585 .719 .935 r
.22317 .44088 .23058 .44778 .24134 .44598 .23395 .43904 Mtetra
.562 .71 .941 r
.23395 .43904 .24134 .44598 .25212 .44465 .24476 .43767 Mtetra
.531 .698 .946 r
.24476 .43767 .25212 .44465 .26292 .44389 .25558 .43685 Mtetra
.493 .682 .95 r
.25558 .43685 .26292 .44389 .27373 .44377 .26641 .43667 Mtetra
.445 .66 .952 r
.26641 .43667 .27373 .44377 .28455 .44439 .27726 .43723 Mtetra
.387 .631 .951 r
.27726 .43723 .28455 .44439 .2954 .44585 .28812 .43859 Mtetra
.317 .593 .943 r
.28812 .43859 .2954 .44585 .30626 .44821 .29901 .44086 Mtetra
.236 .545 .928 r
.29901 .44086 .30626 .44821 .31716 .45156 .30992 .44408 Mtetra
.147 .489 .903 r
.30992 .44408 .31716 .45156 .32809 .45593 .32086 .44832 Mtetra
.056 .427 .869 r
.32086 .44832 .32809 .45593 .33906 .46136 .33185 .45357 Mtetra
0 .363 .83 r
.33185 .45357 .33906 .46136 .35009 .46782 .34289 .45984 Mtetra
0 .303 .79 r
.34289 .45984 .35009 .46782 .36119 .47527 .35401 .46706 Mtetra
0 .254 .754 r
.35401 .46706 .36119 .47527 .37239 .48361 .36521 .47514 Mtetra
0 .218 .729 r
.36521 .47514 .37239 .48361 .38368 .4927 .37652 .48393 Mtetra
0 .2 .716 r
.37652 .48393 .38368 .4927 .39511 .50233 .38795 .49324 Mtetra
0 .2 .719 r
.38795 .49324 .39511 .50233 .40666 .51225 .39952 .50281 Mtetra
0 .219 .737 r
.39952 .50281 .40666 .51225 .41838 .52218 .41124 .51235 Mtetra
0 .257 .767 r
.41124 .51235 .41838 .52218 .43025 .53177 .42312 .52155 Mtetra
0 .311 .803 r
.42312 .52155 .43025 .53177 .4423 .54067 .43518 .53003 Mtetra
.103 .375 .837 r
.43518 .53003 .4423 .54067 .45452 .5485 .4474 .53745 Mtetra
.223 .442 .862 r
.4474 .53745 .45452 .5485 .46691 .55489 .4598 .54343 Mtetra
.342 .503 .873 r
.4598 .54343 .46691 .55489 .47946 .55949 .47235 .54764 Mtetra
.447 .554 .871 r
.47235 .54764 .47946 .55949 .49215 .56201 .48505 .54981 Mtetra
.536 .594 .859 r
.48505 .54981 .49215 .56201 .50496 .56221 .49788 .54969 Mtetra
.607 .623 .841 r
.49788 .54969 .50496 .56221 .51786 .55992 .5108 .54715 Mtetra
.663 .645 .822 r
.5108 .54715 .51786 .55992 .53084 .55509 .5238 .54212 Mtetra
.706 .661 .803 r
.5238 .54212 .53084 .55509 .54386 .54773 .53684 .53463 Mtetra
.739 .673 .786 r
.53684 .53463 .54386 .54773 .55689 .53797 .5499 .52481 Mtetra
.765 .682 .771 r
.5499 .52481 .55689 .53797 .56991 .52599 .56296 .51285 Mtetra
.785 .69 .759 r
.56296 .51285 .56991 .52599 .58289 .51209 .57598 .49902 Mtetra
.801 .696 .75 r
.57598 .49902 .58289 .51209 .59582 .49658 .58896 .48366 Mtetra
.813 .702 .743 r
.58896 .48366 .59582 .49658 .60869 .47982 .60188 .4671 Mtetra
.821 .708 .739 r
.60188 .4671 .60869 .47982 .6215 .46219 .61474 .44972 Mtetra
.828 .713 .738 r
.61474 .44972 .6215 .46219 .63425 .44407 .62755 .43187 Mtetra
.832 .718 .738 r
.62755 .43187 .63425 .44407 .64693 .42579 .6403 .4139 Mtetra
.835 .723 .741 r
.6403 .4139 .64693 .42579 .65958 .40769 .65301 .39611 Mtetra
.835 .728 .746 r
.65301 .39611 .65958 .40769 .67219 .39002 .66568 .37877 Mtetra
.834 .733 .753 r
.66568 .37877 .67219 .39002 .68478 .37301 .67835 .36207 Mtetra
.831 .738 .761 r
.67835 .36207 .68478 .37301 .69737 .35683 .69101 .3462 Mtetra
.826 .742 .772 r
.69101 .3462 .69737 .35683 .70999 .34161 .70369 .33126 Mtetra
.819 .746 .783 r
.70369 .33126 .70999 .34161 .72263 .3274 .71641 .31732 Mtetra
.811 .75 .795 r
.71641 .31732 .72263 .3274 .73533 .31424 .72917 .3044 Mtetra
.801 .753 .808 r
.72917 .3044 .73533 .31424 .74809 .30212 .742 .29249 Mtetra
.79 .755 .821 r
.742 .29249 .74809 .30212 .76092 .29101 .75489 .28156 Mtetra
.778 .757 .834 r
.75489 .28156 .76092 .29101 .77383 .28084 .76787 .27155 Mtetra
.765 .757 .845 r
.76787 .27155 .77383 .28084 .78683 .27153 .78093 .26237 Mtetra
.752 .757 .856 r
.78093 .26237 .78683 .27153 .79992 .263 .79408 .25394 Mtetra
.739 .756 .866 r
.79408 .25394 .79992 .263 .8131 .25515 .80732 .24618 Mtetra
.727 .755 .874 r
.80732 .24618 .8131 .25515 .82637 .2479 .82065 .23898 Mtetra
.716 .753 .881 r
.82065 .23898 .82637 .2479 .83974 .24115 .83408 .23228 Mtetra
.588 .717 .933 r
.21571 .43385 .22317 .44088 .23395 .43904 .22652 .43195 Mtetra
.565 .708 .938 r
.22652 .43195 .23395 .43904 .24476 .43767 .23735 .4305 Mtetra
.537 .696 .942 r
.23735 .4305 .24476 .43767 .25558 .43685 .2482 .4296 Mtetra
.502 .68 .946 r
.2482 .4296 .25558 .43685 .26641 .43667 .25905 .42931 Mtetra
.458 .659 .947 r
.25905 .42931 .26641 .43667 .27726 .43723 .26992 .42974 Mtetra
.406 .631 .946 r
.26992 .42974 .27726 .43723 .28812 .43859 .28081 .43095 Mtetra
.344 .596 .94 r
.28081 .43095 .28812 .43859 .29901 .44086 .29172 .43304 Mtetra
.275 .553 .927 r
.29172 .43304 .29901 .44086 .30992 .44408 .30265 .43606 Mtetra
.2 .504 .908 r
.30265 .43606 .30992 .44408 .32086 .44832 .31362 .44004 Mtetra
.124 .45 .883 r
.31362 .44004 .32086 .44832 .33185 .45357 .32463 .44501 Mtetra
.054 .397 .854 r
.32463 .44501 .33185 .45357 .34289 .45984 .33569 .45095 Mtetra
0 .347 .825 r
.33569 .45095 .34289 .45984 .35401 .46706 .34683 .45781 Mtetra
0 .307 .799 r
.34683 .45781 .35401 .46706 .36521 .47514 .35805 .46548 Mtetra
0 .279 .781 r
.35805 .46548 .36521 .47514 .37652 .48393 .36937 .47381 Mtetra
0 .266 .773 r
.36937 .47381 .37652 .48393 .38795 .49324 .38081 .48262 Mtetra
0 .268 .775 r
.38081 .48262 .38795 .49324 .39952 .50281 .39239 .49167 Mtetra
0 .286 .786 r
.39239 .49167 .39952 .50281 .41124 .51235 .40412 .50066 Mtetra
.056 .318 .801 r
.40412 .50066 .41124 .51235 .42312 .52155 .41601 .50929 Mtetra
.138 .359 .817 r
.41601 .50929 .42312 .52155 .43518 .53003 .42807 .5172 Mtetra
.229 .405 .83 r
.42807 .5172 .43518 .53003 .4474 .53745 .4403 .52406 Mtetra
.322 .451 .836 r
.4403 .52406 .4474 .53745 .4598 .54343 .4527 .52951 Mtetra
.409 .493 .834 r
.4527 .52951 .4598 .54343 .47235 .54764 .46525 .53323 Mtetra
.487 .53 .827 r
.46525 .53323 .47235 .54764 .48505 .54981 .47796 .53497 Mtetra
.554 .56 .815 r
.47796 .53497 .48505 .54981 .49788 .54969 .49079 .5345 Mtetra
.609 .585 .801 r
.49079 .5345 .49788 .54969 .5108 .54715 .50372 .53168 Mtetra
.655 .605 .787 r
.50372 .53168 .5108 .54715 .5238 .54212 .51673 .52648 Mtetra
.691 .621 .773 r
.51673 .52648 .5238 .54212 .53684 .53463 .52979 .51892 Mtetra
.721 .634 .761 r
.52979 .51892 .53684 .53463 .5499 .52481 .54287 .50912 Mtetra
.744 .646 .751 r
.54287 .50912 .5499 .52481 .56296 .51285 .55595 .49728 Mtetra
.764 .655 .742 r
.55595 .49728 .56296 .51285 .57598 .49902 .569 .48367 Mtetra
.779 .664 .736 r
.569 .48367 .57598 .49902 .58896 .48366 .58202 .4686 Mtetra
.792 .672 .732 r
.58202 .4686 .58896 .48366 .60188 .4671 .59499 .4524 Mtetra
.801 .679 .73 r
.59499 .4524 .60188 .4671 .61474 .44972 .6079 .43544 Mtetra
.809 .687 .73 r
.6079 .43544 .61474 .44972 .62755 .43187 .62076 .41804 Mtetra
.814 .694 .732 r
.62076 .41804 .62755 .43187 .6403 .4139 .63358 .40055 Mtetra
.818 .7 .736 r
.63358 .40055 .6403 .4139 .65301 .39611 .64635 .38324 Mtetra
.819 .707 .741 r
.64635 .38324 .65301 .39611 .66568 .37877 .65909 .36637 Mtetra
.819 .714 .749 r
.65909 .36637 .66568 .37877 .67835 .36207 .67183 .35015 Mtetra
.817 .72 .758 r
.67183 .35015 .67835 .36207 .69101 .3462 .68456 .33471 Mtetra
.813 .726 .769 r
.68456 .33471 .69101 .3462 .70369 .33126 .69732 .32018 Mtetra
.808 .732 .78 r
.69732 .32018 .70369 .33126 .71641 .31732 .71011 .30661 Mtetra
.801 .737 .793 r
.71011 .30661 .71641 .31732 .72917 .3044 .72294 .29403 Mtetra
.792 .741 .806 r
.72294 .29403 .72917 .3044 .742 .29249 .73584 .28242 Mtetra
.782 .745 .819 r
.73584 .28242 .742 .29249 .75489 .28156 .7488 .27174 Mtetra
.771 .748 .832 r
.7488 .27174 .75489 .28156 .76787 .27155 .76184 .26194 Mtetra
.759 .75 .844 r
.76184 .26194 .76787 .27155 .78093 .26237 .77497 .25294 Mtetra
.747 .751 .855 r
.77497 .25294 .78093 .26237 .79408 .25394 .78818 .24466 Mtetra
.735 .751 .865 r
.78818 .24466 .79408 .25394 .80732 .24618 .80148 .23701 Mtetra
.724 .751 .874 r
.80148 .23701 .80732 .24618 .82065 .23898 .81487 .2299 Mtetra
.713 .75 .881 r
.81487 .2299 .82065 .23898 .83408 .23228 .82835 .22326 Mtetra
.591 .716 .93 r
.20821 .4267 .21571 .43385 .22652 .43195 .21904 .42471 Mtetra
.57 .707 .934 r
.21904 .42471 .22652 .43195 .23735 .4305 .2299 .42316 Mtetra
.544 .695 .938 r
.2299 .42316 .23735 .4305 .2482 .4296 .24077 .42212 Mtetra
.512 .679 .941 r
.24077 .42212 .2482 .4296 .25905 .42931 .25166 .42169 Mtetra
.473 .659 .942 r
.25166 .42169 .25905 .42931 .26992 .42974 .26256 .42194 Mtetra
.427 .633 .941 r
.26256 .42194 .26992 .42974 .28081 .43095 .27347 .42294 Mtetra
.373 .601 .936 r
.27347 .42294 .28081 .43095 .29172 .43304 .28441 .42478 Mtetra
.314 .562 .926 r
.28441 .42478 .29172 .43304 .30265 .43606 .29537 .4275 Mtetra
.252 .519 .91 r
.29537 .4275 .30265 .43606 .31362 .44004 .30636 .43115 Mtetra
.19 .473 .891 r
.30636 .43115 .31362 .44004 .32463 .44501 .3174 .43573 Mtetra
.134 .428 .869 r
.3174 .43573 .32463 .44501 .33569 .45095 .32849 .44123 Mtetra
.089 .387 .846 r
.32849 .44123 .33569 .45095 .34683 .45781 .33964 .44759 Mtetra
.058 .353 .827 r
.33964 .44759 .34683 .45781 .35805 .46548 .35089 .45471 Mtetra
.045 .33 .812 r
.35089 .45471 .35805 .46548 .36937 .47381 .36223 .46245 Mtetra
.05 .32 .804 r
.36223 .46245 .36937 .47381 .38081 .48262 .37369 .47061 Mtetra
.075 .322 .801 r
.37369 .47061 .38081 .48262 .39239 .49167 .38528 .47898 Mtetra
.118 .335 .803 r
.38528 .47898 .39239 .49167 .40412 .50066 .39702 .48727 Mtetra
.175 .359 .807 r
.39702 .48727 .40412 .50066 .41601 .50929 .40892 .49518 Mtetra
.243 .388 .81 r
.40892 .49518 .41601 .50929 .42807 .5172 .42098 .50239 Mtetra
.314 .421 .811 r
.42098 .50239 .42807 .5172 .4403 .52406 .43321 .50857 Mtetra
.385 .454 .809 r
.43321 .50857 .4403 .52406 .4527 .52951 .44561 .51338 Mtetra
.452 .485 .802 r
.44561 .51338 .4527 .52951 .46525 .53323 .45817 .51654 Mtetra
.512 .513 .794 r
.45817 .51654 .46525 .53323 .47796 .53497 .47087 .51778 Mtetra
.565 .537 .783 r
.47087 .51778 .47796 .53497 .49079 .5345 .4837 .51693 Mtetra
.609 .558 .772 r
.4837 .51693 .49079 .5345 .50372 .53168 .49663 .51384 Mtetra
.647 .576 .761 r
.49663 .51384 .50372 .53168 .51673 .52648 .50964 .50849 Mtetra
.679 .592 .751 r
.50964 .50849 .51673 .52648 .52979 .51892 .52271 .50091 Mtetra
.705 .606 .743 r
.52271 .50091 .52979 .51892 .54287 .50912 .5358 .49122 Mtetra
.727 .618 .735 r
.5358 .49122 .54287 .50912 .55595 .49728 .5489 .47961 Mtetra
.746 .628 .73 r
.5489 .47961 .55595 .49728 .569 .48367 .56198 .46633 Mtetra
.761 .638 .726 r
.56198 .46633 .569 .48367 .58202 .4686 .57503 .45169 Mtetra
.773 .648 .723 r
.57503 .45169 .58202 .4686 .59499 .4524 .58803 .436 Mtetra
.783 .657 .723 r
.58803 .436 .59499 .4524 .6079 .43544 .60099 .41959 Mtetra
.791 .665 .724 r
.60099 .41959 .6079 .43544 .62076 .41804 .61391 .4028 Mtetra
.797 .673 .727 r
.61391 .4028 .62076 .41804 .63358 .40055 .62678 .38593 Mtetra
.802 .682 .732 r
.62678 .38593 .63358 .40055 .64635 .38324 .63962 .36925 Mtetra
.804 .69 .738 r
.63962 .36925 .64635 .38324 .65909 .36637 .65243 .353 Mtetra
.805 .697 .746 r
.65243 .353 .65909 .36637 .67183 .35015 .66523 .33737 Mtetra
.804 .705 .756 r
.66523 .33737 .67183 .35015 .68456 .33471 .67804 .32249 Mtetra
.801 .713 .767 r
.67804 .32249 .68456 .33471 .69732 .32018 .69087 .30847 Mtetra
.797 .719 .779 r
.69087 .30847 .69732 .32018 .71011 .30661 .70373 .29537 Mtetra
.79 .726 .792 r
.70373 .29537 .71011 .30661 .72294 .29403 .71664 .2832 Mtetra
.783 .731 .805 r
.71664 .2832 .72294 .29403 .73584 .28242 .72961 .27195 Mtetra
.774 .736 .819 r
.72961 .27195 .73584 .28242 .7488 .27174 .74264 .26159 Mtetra
.763 .74 .832 r
.74264 .26159 .7488 .27174 .76184 .26194 .75575 .25206 Mtetra
.752 .743 .844 r
.75575 .25206 .76184 .26194 .77497 .25294 .76895 .24328 Mtetra
.741 .745 .855 r
.76895 .24328 .77497 .25294 .78818 .24466 .78222 .23517 Mtetra
.73 .746 .865 r
.78222 .23517 .78818 .24466 .80148 .23701 .79559 .22767 Mtetra
.72 .747 .873 r
.79559 .22767 .80148 .23701 .81487 .2299 .80904 .22067 Mtetra
.71 .747 .881 r
.80904 .22067 .81487 .2299 .82835 .22326 .82258 .21411 Mtetra
.595 .715 .928 r
.20065 .41942 .20821 .4267 .21904 .42471 .21151 .41732 Mtetra
.576 .706 .931 r
.21151 .41732 .21904 .42471 .2299 .42316 .2224 .41564 Mtetra
.552 .695 .934 r
.2224 .41564 .2299 .42316 .24077 .42212 .2333 .41445 Mtetra
.523 .679 .936 r
.2333 .41445 .24077 .42212 .25166 .42169 .24422 .41383 Mtetra
.489 .66 .937 r
.24422 .41383 .25166 .42169 .26256 .42194 .25515 .41386 Mtetra
.448 .636 .936 r
.25515 .41386 .26256 .42194 .27347 .42294 .2661 .4146 Mtetra
.403 .606 .931 r
.2661 .4146 .27347 .42294 .28441 .42478 .27707 .41612 Mtetra
.353 .572 .922 r
.27707 .41612 .28441 .42478 .29537 .4275 .28806 .41848 Mtetra
.302 .534 .91 r
.28806 .41848 .29537 .4275 .30636 .43115 .29909 .4217 Mtetra
.252 .495 .894 r
.29909 .4217 .30636 .43115 .3174 .43573 .31015 .4258 Mtetra
.208 .456 .876 r
.31015 .4258 .3174 .43573 .32849 .44123 .32127 .43076 Mtetra
.174 .421 .857 r
.32127 .43076 .32849 .44123 .33964 .44759 .33246 .43651 Mtetra
.152 .392 .841 r
.33246 .43651 .33964 .44759 .35089 .45471 .34373 .44296 Mtetra
.145 .372 .827 r
.34373 .44296 .35089 .45471 .36223 .46245 .3551 .44998 Mtetra
.154 .362 .816 r
.3551 .44998 .36223 .46245 .37369 .47061 .36658 .45738 Mtetra
.178 .362 .809 r
.36658 .45738 .37369 .47061 .38528 .47898 .37819 .46494 Mtetra
.216 .371 .805 r
.37819 .46494 .38528 .47898 .39702 .48727 .38994 .47241 Mtetra
.263 .387 .801 r
.38994 .47241 .39702 .48727 .40892 .49518 .40185 .47949 Mtetra
.317 .408 .798 r
.40185 .47949 .40892 .49518 .42098 .50239 .41392 .48588 Mtetra
.373 .432 .793 r
.41392 .48588 .42098 .50239 .43321 .50857 .42615 .49128 Mtetra
.429 .456 .786 r
.42615 .49128 .43321 .50857 .44561 .51338 .43855 .49538 Mtetra
.481 .479 .778 r
.43855 .49538 .44561 .51338 .45817 .51654 .4511 .4979 Mtetra
.529 .502 .77 r
.4511 .4979 .45817 .51654 .47087 .51778 .4638 .49862 Mtetra
.572 .522 .761 r
.4638 .49862 .47087 .51778 .4837 .51693 .47662 .49737 Mtetra
.609 .54 .752 r
.47662 .49737 .4837 .51693 .49663 .51384 .48954 .49402 Mtetra
.641 .556 .743 r
.48954 .49402 .49663 .51384 .50964 .50849 .50255 .48855 Mtetra
.669 .571 .736 r
.50255 .48855 .50964 .50849 .52271 .50091 .51561 .481 Mtetra
.693 .584 .729 r
.51561 .481 .52271 .50091 .5358 .49122 .52871 .47149 Mtetra
.713 .596 .724 r
.52871 .47149 .5358 .49122 .5489 .47961 .54182 .46019 Mtetra
.73 .608 .721 r
.54182 .46019 .5489 .47961 .56198 .46633 .55491 .44736 Mtetra
.745 .618 .718 r
.55491 .44736 .56198 .46633 .57503 .45169 .56799 .43326 Mtetra
.757 .628 .717 r
.56799 .43326 .57503 .45169 .58803 .436 .58103 .41819 Mtetra
.768 .638 .718 r
.58103 .41819 .58803 .436 .60099 .41959 .59403 .40248 Mtetra
.776 .648 .72 r
.59403 .40248 .60099 .41959 .61391 .4028 .607 .38641 Mtetra
.782 .657 .724 r
.607 .38641 .61391 .4028 .62678 .38593 .61992 .37029 Mtetra
.787 .666 .73 r
.61992 .37029 .62678 .38593 .63962 .36925 .63282 .35436 Mtetra
.79 .675 .737 r
.63282 .35436 .63962 .36925 .65243 .353 .6457 .33883 Mtetra
.792 .684 .746 r
.6457 .33883 .65243 .353 .66523 .33737 .65857 .32389 Mtetra
.791 .693 .756 r
.65857 .32389 .66523 .33737 .67804 .32249 .67146 .30966 Mtetra
.789 .701 .767 r
.67146 .30966 .67804 .32249 .69087 .30847 .68436 .29625 Mtetra
.786 .709 .779 r
.68436 .29625 .69087 .30847 .70373 .29537 .6973 .28368 Mtetra
.78 .716 .792 r
.6973 .28368 .70373 .29537 .71664 .2832 .71028 .272 Mtetra
.773 .723 .806 r
.71028 .272 .71664 .2832 .72961 .27195 .72332 .26117 Mtetra
.765 .729 .819 r
.72332 .26117 .72961 .27195 .74264 .26159 .73643 .25117 Mtetra
.756 .734 .832 r
.73643 .25117 .74264 .26159 .75575 .25206 .74961 .24194 Mtetra
.746 .737 .844 r
.74961 .24194 .75575 .25206 .76895 .24328 .76287 .23342 Mtetra
.735 .74 .855 r
.76287 .23342 .76895 .24328 .78222 .23517 .77621 .22552 Mtetra
.725 .742 .865 r
.77621 .22552 .78222 .23517 .79559 .22767 .78964 .21818 Mtetra
.715 .743 .874 r
.78964 .21818 .79559 .22767 .80904 .22067 .80315 .21131 Mtetra
.706 .744 .881 r
.80315 .21131 .80904 .22067 .82258 .21411 .81675 .20484 Mtetra
.6 .715 .925 r
.19304 .41203 .20065 .41942 .21151 .41732 .20393 .4098 Mtetra
.582 .706 .928 r
.20393 .4098 .21151 .41732 .2224 .41564 .21485 .40797 Mtetra
.561 .695 .93 r
.21485 .40797 .2224 .41564 .2333 .41445 .22579 .4066 Mtetra
.535 .68 .932 r
.22579 .4066 .2333 .41445 .24422 .41383 .23674 .40576 Mtetra
.505 .662 .932 r
.23674 .40576 .24422 .41383 .25515 .41386 .24771 .40552 Mtetra
.47 .64 .93 r
.24771 .40552 .25515 .41386 .2661 .4146 .25869 .40595 Mtetra
.431 .613 .926 r
.25869 .40595 .2661 .4146 .27707 .41612 .2697 .40711 Mtetra
.39 .583 .918 r
.2697 .40711 .27707 .41612 .28806 .41848 .28073 .40904 Mtetra
.348 .549 .907 r
.28073 .40904 .28806 .41848 .29909 .4217 .29179 .41178 Mtetra
.308 .514 .894 r
.29179 .41178 .29909 .4217 .31015 .4258 .3029 .41532 Mtetra
.273 .48 .878 r
.3029 .41532 .31015 .4258 .32127 .43076 .31406 .41965 Mtetra
.247 .45 .862 r
.31406 .41965 .32127 .43076 .33246 .43651 .32528 .42471 Mtetra
.231 .425 .846 r
.32528 .42471 .33246 .43651 .34373 .44296 .33658 .4304 Mtetra
.228 .407 .832 r
.33658 .4304 .34373 .44296 .3551 .44998 .34798 .4366 Mtetra
.238 .396 .82 r
.34798 .4366 .3551 .44998 .36658 .45738 .35949 .44313 Mtetra
.259 .394 .809 r
.35949 .44313 .36658 .45738 .37819 .46494 .37112 .44979 Mtetra
.29 .399 .801 r
.37112 .44979 .37819 .46494 .38994 .47241 .38289 .45633 Mtetra
.329 .409 .793 r
.38289 .45633 .38994 .47241 .40185 .47949 .39481 .4625 Mtetra
.372 .424 .785 r
.39481 .4625 .40185 .47949 .41392 .48588 .40689 .468 Mtetra
.416 .441 .778 r
.40689 .468 .41392 .48588 .42615 .49128 .41912 .47255 Mtetra
.461 .459 .77 r
.41912 .47255 .42615 .49128 .43855 .49538 .43151 .47588 Mtetra
.503 .477 .761 r
.43151 .47588 .43855 .49538 .4511 .4979 .44406 .47774 Mtetra
.542 .495 .753 r
.44406 .47774 .4511 .4979 .4638 .49862 .45674 .47791 Mtetra
.577 .512 .745 r
.45674 .47791 .4638 .49862 .47662 .49737 .46955 .47625 Mtetra
.609 .528 .738 r
.46955 .47625 .47662 .49737 .48954 .49402 .48246 .47266 Mtetra
.637 .542 .731 r
.48246 .47266 .48954 .49402 .50255 .48855 .49546 .4671 Mtetra
.661 .556 .725 r
.49546 .4671 .50255 .48855 .51561 .481 .50852 .45963 Mtetra
.683 .569 .72 r
.50852 .45963 .51561 .481 .52871 .47149 .52161 .45036 Mtetra
.702 .581 .717 r
.52161 .45036 .52871 .47149 .54182 .46019 .53472 .43945 Mtetra
.718 .592 .714 r
.53472 .43945 .54182 .46019 .55491 .44736 .54783 .42714 Mtetra
.732 .603 .713 r
.54783 .42714 .55491 .44736 .56799 .43326 .56093 .41367 Mtetra
.744 .614 .714 r
.56093 .41367 .56799 .43326 .58103 .41819 .574 .39933 Mtetra
.754 .624 .716 r
.574 .39933 .58103 .41819 .59403 .40248 .58703 .3844 Mtetra
.762 .634 .719 r
.58703 .3844 .59403 .40248 .607 .38641 .60004 .36916 Mtetra
.769 .644 .723 r
.60004 .36916 .607 .38641 .61992 .37029 .61302 .35388 Mtetra
.774 .654 .73 r
.61302 .35388 .61992 .37029 .63282 .35436 .62598 .33878 Mtetra
.777 .663 .737 r
.62598 .33878 .63282 .35436 .6457 .33883 .63892 .32406 Mtetra
.779 .673 .746 r
.63892 .32406 .6457 .33883 .65857 .32389 .65186 .30989 Mtetra
.779 .683 .757 r
.65186 .30989 .65857 .32389 .67146 .30966 .66481 .29639 Mtetra
.778 .692 .769 r
.66481 .29639 .67146 .30966 .68436 .29625 .67779 .28363 Mtetra
.775 .7 .781 r
.67779 .28363 .68436 .29625 .6973 .28368 .6908 .27167 Mtetra
.77 .709 .794 r
.6908 .27167 .6973 .28368 .71028 .272 .70386 .26051 Mtetra
.764 .716 .808 r
.70386 .26051 .71028 .272 .72332 .26117 .71697 .25015 Mtetra
.756 .723 .821 r
.71697 .25015 .72332 .26117 .73643 .25117 .73015 .24054 Mtetra
.748 .728 .834 r
.73015 .24054 .73643 .25117 .74961 .24194 .7434 .23165 Mtetra
.739 .733 .846 r
.7434 .23165 .74961 .24194 .76287 .23342 .75673 .2234 Mtetra
.729 .736 .857 r
.75673 .2234 .76287 .23342 .77621 .22552 .77014 .21573 Mtetra
.72 .739 .866 r
.77014 .21573 .77621 .22552 .78964 .21818 .78363 .20856 Mtetra
.711 .74 .875 r
.78363 .20856 .78964 .21818 .80315 .21131 .79721 .20183 Mtetra
.702 .742 .882 r
.79721 .20183 .80315 .21131 .81675 .20484 .81087 .19547 Mtetra
.605 .715 .922 r
.18537 .40453 .19304 .41203 .20393 .4098 .1963 .40216 Mtetra
.589 .707 .925 r
.1963 .40216 .20393 .4098 .21485 .40797 .20725 .40016 Mtetra
.57 .696 .926 r
.20725 .40016 .21485 .40797 .22579 .4066 .21823 .39859 Mtetra
.548 .682 .927 r
.21823 .39859 .22579 .4066 .23674 .40576 .22922 .3975 Mtetra
.521 .665 .927 r
.22922 .3975 .23674 .40576 .24771 .40552 .24022 .39697 Mtetra
.491 .645 .925 r
.24022 .39697 .24771 .40552 .25869 .40595 .25125 .39705 Mtetra
.458 .621 .921 r
.25125 .39705 .25869 .40595 .2697 .40711 .2623 .3978 Mtetra
.424 .593 .914 r
.2623 .3978 .2697 .40711 .28073 .40904 .27337 .39926 Mtetra
.389 .563 .904 r
.27337 .39926 .28073 .40904 .29179 .41178 .28448 .40146 Mtetra
.357 .533 .892 r
.28448 .40146 .29179 .41178 .3029 .41532 .29562 .40439 Mtetra
.329 .503 .877 r
.29562 .40439 .3029 .41532 .31406 .41965 .30682 .40803 Mtetra
.309 .475 .862 r
.30682 .40803 .31406 .41965 .32528 .42471 .31809 .41233 Mtetra
.297 .452 .847 r
.31809 .41233 .32528 .42471 .33658 .4304 .32943 .41719 Mtetra
.296 .435 .832 r
.32943 .41719 .33658 .4304 .34798 .4366 .34086 .42251 Mtetra
.304 .425 .819 r
.34086 .42251 .34798 .4366 .35949 .44313 .3524 .4281 Mtetra
.322 .42 .807 r
.3524 .4281 .35949 .44313 .37112 .44979 .36406 .43379 Mtetra
.348 .421 .796 r
.36406 .43379 .37112 .44979 .38289 .45633 .37585 .43935 Mtetra
.379 .427 .786 r
.37585 .43935 .38289 .45633 .39481 .4625 .38779 .44454 Mtetra
.413 .437 .776 r
.38779 .44454 .39481 .4625 .40689 .468 .39987 .4491 Mtetra
.449 .449 .767 r
.39987 .4491 .40689 .468 .41912 .47255 .41211 .45277 Mtetra
.485 .463 .758 r
.41211 .45277 .41912 .47255 .43151 .47588 .4245 .4553 Mtetra
.519 .477 .75 r
.4245 .4553 .43151 .47588 .44406 .47774 .43704 .45647 Mtetra
.552 .492 .742 r
.43704 .45647 .44406 .47774 .45674 .47791 .44971 .4561 Mtetra
.582 .506 .735 r
.44971 .4561 .45674 .47791 .46955 .47625 .4625 .45404 Mtetra
.609 .52 .728 r
.4625 .45404 .46955 .47625 .48246 .47266 .4754 .45022 Mtetra
.633 .533 .723 r
.4754 .45022 .48246 .47266 .49546 .4671 .48838 .44461 Mtetra
.655 .546 .718 r
.48838 .44461 .49546 .4671 .50852 .45963 .50142 .43726 Mtetra
.675 .558 .715 r
.50142 .43726 .50852 .45963 .52161 .45036 .51451 .42828 Mtetra
.692 .57 .712 r
.51451 .42828 .52161 .45036 .53472 .43945 .52762 .41782 Mtetra
.707 .581 .711 r
.52762 .41782 .53472 .43945 .54783 .42714 .54073 .40609 Mtetra
.72 .592 .711 r
.54073 .40609 .54783 .42714 .56093 .41367 .55384 .39332 Mtetra
.732 .602 .712 r
.55384 .39332 .56093 .41367 .574 .39933 .56694 .37976 Mtetra
.742 .613 .715 r
.56694 .37976 .574 .39933 .58703 .3844 .58001 .36569 Mtetra
.75 .623 .719 r
.58001 .36569 .58703 .3844 .60004 .36916 .59305 .35134 Mtetra
.757 .634 .724 r
.59305 .35134 .60004 .36916 .61302 .35388 .60608 .33695 Mtetra
.762 .644 .731 r
.60608 .33695 .61302 .35388 .62598 .33878 .61909 .32275 Mtetra
.766 .654 .739 r
.61909 .32275 .62598 .33878 .63892 .32406 .6321 .3089 Mtetra
.768 .665 .749 r
.6321 .3089 .63892 .32406 .65186 .30989 .6451 .29555 Mtetra
.768 .675 .76 r
.6451 .29555 .65186 .30989 .66481 .29639 .65813 .28281 Mtetra
.767 .685 .771 r
.65813 .28281 .66481 .29639 .67779 .28363 .67117 .27075 Mtetra
.765 .694 .784 r
.67117 .27075 .67779 .28363 .6908 .27167 .68426 .25942 Mtetra
.76 .703 .797 r
.68426 .25942 .6908 .27167 .70386 .26051 .69739 .24882 Mtetra
.755 .711 .811 r
.69739 .24882 .70386 .26051 .71697 .25015 .71058 .23895 Mtetra
.748 .718 .824 r
.71058 .23895 .71697 .25015 .73015 .24054 .72383 .22976 Mtetra
.74 .724 .836 r
.72383 .22976 .73015 .24054 .7434 .23165 .73715 .22122 Mtetra
.732 .729 .848 r
.73715 .22122 .7434 .23165 .75673 .2234 .75055 .21326 Mtetra
.723 .733 .859 r
.75055 .21326 .75673 .2234 .77014 .21573 .76402 .20583 Mtetra
.714 .736 .868 r
.76402 .20583 .77014 .21573 .78363 .20856 .77758 .19885 Mtetra
.706 .738 .876 r
.77758 .19885 .78363 .20856 .79721 .20183 .79121 .19226 Mtetra
.699 .74 .883 r
.79121 .19226 .79721 .20183 .81087 .19547 .80494 .186 Mtetra
.611 .716 .92 r
.17765 .39694 .18537 .40453 .1963 .40216 .18862 .39442 Mtetra
.596 .708 .922 r
.18862 .39442 .1963 .40216 .20725 .40016 .19961 .39224 Mtetra
.58 .698 .923 r
.19961 .39224 .20725 .40016 .21823 .39859 .21061 .39044 Mtetra
.56 .685 .923 r
.21061 .39044 .21823 .39859 .22922 .3975 .22164 .38909 Mtetra
.537 .669 .922 r
.22164 .38909 .22922 .3975 .24022 .39697 .23269 .38824 Mtetra
.511 .65 .92 r
.23269 .38824 .24022 .39697 .25125 .39705 .24376 .38795 Mtetra
.484 .628 .916 r
.24376 .38795 .25125 .39705 .2623 .3978 .25486 .38826 Mtetra
.455 .604 .909 r
.25486 .38826 .2623 .3978 .27337 .39926 .26598 .38922 Mtetra
.426 .577 .9 r
.26598 .38922 .27337 .39926 .28448 .40146 .27713 .39084 Mtetra
.4 .55 .889 r
.27713 .39084 .28448 .40146 .29562 .40439 .28833 .39312 Mtetra
.378 .523 .876 r
.28833 .39312 .29562 .40439 .30682 .40803 .29957 .39603 Mtetra
.361 .498 .861 r
.29957 .39603 .30682 .40803 .31809 .41233 .31088 .39953 Mtetra
.352 .477 .846 r
.31088 .39953 .31809 .41233 .32943 .41719 .32227 .40353 Mtetra
.351 .46 .831 r
.32227 .40353 .32943 .41719 .34086 .42251 .33374 .40791 Mtetra
.358 .449 .817 r
.33374 .40791 .34086 .42251 .3524 .4281 .34532 .41253 Mtetra
.373 .443 .804 r
.34532 .41253 .3524 .4281 .36406 .43379 .35701 .41722 Mtetra
.393 .441 .792 r
.35701 .41722 .36406 .43379 .37585 .43935 .36882 .42177 Mtetra
.418 .444 .78 r
.36882 .42177 .37585 .43935 .38779 .44454 .38078 .42595 Mtetra
.446 .45 .77 r
.38078 .42595 .38779 .44454 .39987 .4491 .39287 .42955 Mtetra
.475 .459 .76 r
.39287 .42955 .39987 .4491 .41211 .45277 .40512 .43232 Mtetra
.504 .469 .751 r
.40512 .43232 .41211 .45277 .4245 .4553 .4175 .43405 Mtetra
.533 .48 .743 r
.4175 .43405 .4245 .4553 .43704 .45647 .43003 .43454 Mtetra
.56 .492 .735 r
.43003 .43454 .43704 .45647 .44971 .4561 .44269 .43363 Mtetra
.586 .504 .729 r
.44269 .43363 .44971 .4561 .4625 .45404 .45547 .43119 Mtetra
.61 .516 .723 r
.45547 .43119 .4625 .45404 .4754 .45022 .46835 .42717 Mtetra
.631 .528 .719 r
.46835 .42717 .4754 .45022 .48838 .44461 .48131 .42153 Mtetra
.651 .54 .715 r
.48131 .42153 .48838 .44461 .50142 .43726 .49434 .41434 Mtetra
.669 .551 .712 r
.49434 .41434 .50142 .43726 .51451 .42828 .50741 .40568 Mtetra
.684 .562 .711 r
.50741 .40568 .51451 .42828 .52762 .41782 .52052 .39571 Mtetra
.698 .573 .71 r
.52052 .39571 .52762 .41782 .54073 .40609 .53363 .3846 Mtetra
.711 .584 .711 r
.53363 .3846 .54073 .40609 .55384 .39332 .54675 .37256 Mtetra
.722 .595 .713 r
.54675 .37256 .55384 .39332 .56694 .37976 .55986 .35984 Mtetra
.731 .605 .716 r
.55986 .35984 .56694 .37976 .58001 .36569 .57296 .34665 Mtetra
.739 .616 .721 r
.57296 .34665 .58001 .36569 .59305 .35134 .58604 .33322 Mtetra
.746 .627 .727 r
.58604 .33322 .59305 .35134 .60608 .33695 .59911 .31978 Mtetra
.751 .637 .734 r
.59911 .31978 .60608 .33695 .61909 .32275 .61218 .30649 Mtetra
.755 .648 .743 r
.61218 .30649 .61909 .32275 .6321 .3089 .62524 .29353 Mtetra
.757 .659 .753 r
.62524 .29353 .6321 .3089 .6451 .29555 .63831 .28103 Mtetra
.758 .669 .764 r
.63831 .28103 .6451 .29555 .65813 .28281 .6514 .26908 Mtetra
.757 .679 .776 r
.6514 .26908 .65813 .28281 .67117 .27075 .66452 .25774 Mtetra
.755 .689 .788 r
.66452 .25774 .67117 .27075 .68426 .25942 .67767 .24705 Mtetra
.751 .698 .802 r
.67767 .24705 .68426 .25942 .69739 .24882 .69087 .23702 Mtetra
.746 .707 .815 r
.69087 .23702 .69739 .24882 .71058 .23895 .70413 .22764 Mtetra
.74 .714 .827 r
.70413 .22764 .71058 .23895 .72383 .22976 .71745 .21888 Mtetra
.733 .721 .84 r
.71745 .21888 .72383 .22976 .73715 .22122 .73085 .2107 Mtetra
.725 .726 .851 r
.73085 .2107 .73715 .22122 .75055 .21326 .74431 .20303 Mtetra
.717 .73 .861 r
.74431 .20303 .75055 .21326 .76402 .20583 .75785 .19584 Mtetra
.709 .734 .87 r
.75785 .19584 .76402 .20583 .77758 .19885 .77147 .18905 Mtetra
.702 .736 .878 r
.77147 .18905 .77758 .19885 .79121 .19226 .78517 .1826 Mtetra
.695 .738 .884 r
.78517 .1826 .79121 .19226 .80494 .186 .79895 .17645 Mtetra
.616 .717 .918 r
.16987 .38926 .17765 .39694 .18862 .39442 .18087 .38659 Mtetra
.604 .709 .919 r
.18087 .38659 .18862 .39442 .19961 .39224 .1919 .38421 Mtetra
.589 .7 .919 r
.1919 .38421 .19961 .39224 .21061 .39044 .20295 .38218 Mtetra
.572 .688 .919 r
.20295 .38218 .21061 .39044 .22164 .38909 .21402 .38055 Mtetra
.552 .673 .918 r
.21402 .38055 .22164 .38909 .23269 .38824 .22512 .37937 Mtetra
.53 .656 .916 r
.22512 .37937 .23269 .38824 .24376 .38795 .23623 .3787 Mtetra
.507 .637 .912 r
.23623 .3787 .24376 .38795 .25486 .38826 .24737 .37856 Mtetra
.483 .614 .905 r
.24737 .37856 .25486 .38826 .26598 .38922 .25854 .379 Mtetra
.459 .591 .897 r
.25854 .379 .26598 .38922 .27713 .39084 .26975 .38002 Mtetra
.438 .566 .886 r
.26975 .38002 .27713 .39084 .28833 .39312 .281 .38163 Mtetra
.419 .542 .873 r
.281 .38163 .28833 .39312 .29957 .39603 .2923 .38379 Mtetra
.406 .519 .86 r
.2923 .38379 .29957 .39603 .31088 .39953 .30365 .38647 Mtetra
.399 .499 .845 r
.30365 .38647 .31088 .39953 .32227 .40353 .31509 .38959 Mtetra
.398 .483 .831 r
.31509 .38959 .32227 .40353 .33374 .40791 .32661 .39303 Mtetra
.403 .471 .816 r
.32661 .39303 .33374 .40791 .34532 .41253 .33822 .39666 Mtetra
.414 .463 .802 r
.33822 .39666 .34532 .41253 .35701 .41722 .34995 .40034 Mtetra
.43 .46 .79 r
.34995 .40034 .35701 .41722 .36882 .42177 .36179 .40387 Mtetra
.45 .46 .778 r
.36179 .40387 .36882 .42177 .38078 .42595 .37377 .40706 Mtetra
.473 .463 .767 r
.37377 .40706 .38078 .42595 .39287 .42955 .38588 .4097 Mtetra
.497 .469 .757 r
.38588 .4097 .39287 .42955 .40512 .43232 .39813 .41159 Mtetra
.521 .476 .748 r
.39813 .41159 .40512 .43232 .4175 .43405 .41051 .41253 Mtetra
.545 .485 .739 r
.41051 .41253 .4175 .43405 .43003 .43454 .42303 .41236 Mtetra
.568 .495 .732 r
.42303 .41236 .43003 .43454 .44269 .43363 .43568 .41093 Mtetra
.59 .505 .726 r
.43568 .41093 .44269 .43363 .45547 .43119 .44844 .40814 Mtetra
.611 .515 .721 r
.44844 .40814 .45547 .43119 .46835 .42717 .4613 .40393 Mtetra
.63 .526 .717 r
.4613 .40393 .46835 .42717 .48131 .42153 .47424 .3983 Mtetra
.648 .537 .714 r
.47424 .3983 .48131 .42153 .49434 .41434 .48726 .39129 Mtetra
.664 .547 .712 r
.48726 .39129 .49434 .41434 .50741 .40568 .50032 .38298 Mtetra
.678 .558 .712 r
.50032 .38298 .50741 .40568 .52052 .39571 .51341 .37351 Mtetra
.691 .568 .712 r
.51341 .37351 .52052 .39571 .53363 .3846 .52653 .36304 Mtetra
.703 .579 .713 r
.52653 .36304 .53363 .3846 .54675 .37256 .53965 .35176 Mtetra
.713 .59 .716 r
.53965 .35176 .54675 .37256 .55986 .35984 .55278 .33987 Mtetra
.722 .6 .72 r
.55278 .33987 .55986 .35984 .57296 .34665 .5659 .32757 Mtetra
.73 .611 .725 r
.5659 .32757 .57296 .34665 .58604 .33322 .57901 .31508 Mtetra
.737 .622 .731 r
.57901 .31508 .58604 .33322 .59911 .31978 .59212 .30257 Mtetra
.742 .633 .739 r
.59212 .30257 .59911 .31978 .61218 .30649 .60524 .29021 Mtetra
.745 .644 .748 r
.60524 .29021 .61218 .30649 .62524 .29353 .61835 .27815 Mtetra
.748 .655 .758 r
.61835 .27815 .62524 .29353 .63831 .28103 .63148 .26649 Mtetra
.748 .666 .769 r
.63148 .26649 .63831 .28103 .6514 .26908 .64464 .25532 Mtetra
.748 .676 .781 r
.64464 .25532 .6514 .26908 .66452 .25774 .65782 .24469 Mtetra
.746 .686 .794 r
.65782 .24469 .66452 .25774 .67767 .24705 .67104 .23465 Mtetra
.742 .696 .807 r
.67104 .23465 .67767 .24705 .69087 .23702 .68432 .22518 Mtetra
.737 .704 .82 r
.68432 .22518 .69087 .23702 .70413 .22764 .69764 .2163 Mtetra
.732 .712 .832 r
.69764 .2163 .70413 .22764 .71745 .21888 .71104 .20796 Mtetra
.725 .718 .844 r
.71104 .20796 .71745 .21888 .73085 .2107 .72449 .20012 Mtetra
.718 .724 .855 r
.72449 .20012 .73085 .2107 .74431 .20303 .73803 .19275 Mtetra
.711 .729 .864 r
.73803 .19275 .74431 .20303 .75785 .19584 .75163 .18579 Mtetra
.704 .732 .873 r
.75163 .18579 .75785 .19584 .77147 .18905 .76532 .17918 Mtetra
.697 .735 .88 r
.76532 .17918 .77147 .18905 .78517 .1826 .77908 .17288 Mtetra
.691 .737 .886 r
.77908 .17288 .78517 .1826 .79895 .17645 .79292 .16684 Mtetra
.621 .718 .916 r
.16204 .38152 .16987 .38926 .18087 .38659 .17308 .37868 Mtetra
.61 .711 .916 r
.17308 .37868 .18087 .38659 .1919 .38421 .18414 .3761 Mtetra
.598 .702 .917 r
.18414 .3761 .1919 .38421 .20295 .38218 .19523 .37384 Mtetra
.583 .691 .916 r
.19523 .37384 .20295 .38218 .21402 .38055 .20635 .37193 Mtetra
.566 .678 .915 r
.20635 .37193 .21402 .38055 .22512 .37937 .21749 .37042 Mtetra
.548 .663 .912 r
.21749 .37042 .22512 .37937 .23623 .3787 .22865 .36935 Mtetra
.528 .645 .908 r
.22865 .36935 .23623 .3787 .24737 .37856 .23985 .36876 Mtetra
.508 .625 .902 r
.23985 .36876 .24737 .37856 .25854 .379 .25107 .36867 Mtetra
.489 .604 .894 r
.25107 .36867 .25854 .379 .26975 .38002 .26233 .36909 Mtetra
.471 .581 .884 r
.26233 .36909 .26975 .38002 .281 .38163 .27363 .37002 Mtetra
.455 .559 .872 r
.27363 .37002 .281 .38163 .2923 .38379 .28498 .37145 Mtetra
.444 .538 .859 r
.28498 .37145 .2923 .38379 .30365 .38647 .2964 .37331 Mtetra
.438 .52 .845 r
.2964 .37331 .30365 .38647 .31509 .38959 .30788 .37554 Mtetra
.436 .504 .83 r
.30788 .37554 .31509 .38959 .32661 .39303 .31944 .37805 Mtetra
.44 .492 .816 r
.31944 .37805 .32661 .39303 .33822 .39666 .3311 .38072 Mtetra
.449 .483 .802 r
.3311 .38072 .33822 .39666 .34995 .40034 .34287 .3834 Mtetra
.462 .478 .789 r
.34287 .3834 .34995 .40034 .36179 .40387 .35475 .38593 Mtetra
.477 .476 .777 r
.35475 .38593 .36179 .40387 .37377 .40706 .36674 .38814 Mtetra
.496 .477 .766 r
.36674 .38814 .37377 .40706 .38588 .4097 .37887 .38986 Mtetra
.515 .48 .756 r
.37887 .38986 .38588 .4097 .39813 .41159 .39113 .3909 Mtetra
.536 .486 .747 r
.39113 .3909 .39813 .41159 .41051 .41253 .40352 .39109 Mtetra
.556 .492 .739 r
.40352 .39109 .41051 .41253 .42303 .41236 .41604 .39029 Mtetra
.576 .5 .733 r
.41604 .39029 .42303 .41236 .43568 .41093 .42867 .38838 Mtetra
.595 .509 .727 r
.42867 .38838 .43568 .41093 .44844 .40814 .44142 .38527 Mtetra
.613 .518 .722 r
.44142 .38527 .44844 .40814 .4613 .40393 .45426 .38091 Mtetra
.63 .527 .719 r
.45426 .38091 .4613 .40393 .47424 .3983 .46718 .3753 Mtetra
.646 .537 .716 r
.46718 .3753 .47424 .3983 .48726 .39129 .48017 .36848 Mtetra
.66 .547 .715 r
.48017 .36848 .48726 .39129 .50032 .38298 .49322 .36053 Mtetra
.673 .557 .715 r
.49322 .36053 .50032 .38298 .51341 .37351 .50631 .35157 Mtetra
.685 .567 .715 r
.50631 .35157 .51341 .37351 .52653 .36304 .51942 .34173 Mtetra
.696 .577 .717 r
.51942 .34173 .52653 .36304 .53965 .35176 .53255 .33119 Mtetra
.706 .588 .721 r
.53255 .33119 .53965 .35176 .55278 .33987 .54568 .32013 Mtetra
.715 .598 .725 r
.54568 .32013 .55278 .33987 .5659 .32757 .55883 .30872 Mtetra
.722 .609 .731 r
.55883 .30872 .5659 .32757 .57901 .31508 .57197 .29714 Mtetra
.728 .62 .738 r
.57197 .29714 .57901 .31508 .59212 .30257 .58512 .28555 Mtetra
.733 .631 .746 r
.58512 .28555 .59212 .30257 .60524 .29021 .59827 .27409 Mtetra
.736 .642 .755 r
.59827 .27409 .60524 .29021 .61835 .27815 .61144 .26289 Mtetra
.739 .653 .765 r
.61144 .26289 .61835 .27815 .63148 .26649 .62463 .25206 Mtetra
.739 .664 .776 r
.62463 .25206 .63148 .26649 .64464 .25532 .63784 .24165 Mtetra
.739 .675 .788 r
.63784 .24165 .64464 .25532 .65782 .24469 .65109 .23172 Mtetra
.737 .685 .801 r
.65109 .23172 .65782 .24469 .67104 .23465 .66438 .22229 Mtetra
.734 .694 .813 r
.66438 .22229 .67104 .23465 .68432 .22518 .67772 .21338 Mtetra
.729 .703 .826 r
.67772 .21338 .68432 .22518 .69764 .2163 .69112 .20497 Mtetra
.724 .711 .837 r
.69112 .20497 .69764 .2163 .71104 .20796 .70457 .19703 Mtetra
.718 .717 .849 r
.70457 .19703 .71104 .20796 .72449 .20012 .7181 .18954 Mtetra
.712 .723 .859 r
.7181 .18954 .72449 .20012 .73803 .19275 .7317 .18244 Mtetra
.705 .728 .868 r
.7317 .18244 .73803 .19275 .75163 .18579 .74537 .17571 Mtetra
.699 .731 .876 r
.74537 .17571 .75163 .18579 .76532 .17918 .75911 .16928 Mtetra
.693 .734 .882 r
.75911 .16928 .76532 .17918 .77908 .17288 .77293 .16311 Mtetra
.688 .736 .888 r
.77293 .16311 .77908 .17288 .79292 .16684 .78683 .15716 Mtetra
.626 .72 .914 r
.15414 .37371 .16204 .38152 .17308 .37868 .16522 .37071 Mtetra
.617 .713 .914 r
.16522 .37071 .17308 .37868 .18414 .3761 .17632 .36794 Mtetra
.606 .705 .914 r
.17632 .36794 .18414 .3761 .19523 .37384 .18746 .36544 Mtetra
.594 .695 .913 r
.18746 .36544 .19523 .37384 .20635 .37193 .19862 .36325 Mtetra
.579 .683 .912 r
.19862 .36325 .20635 .37193 .21749 .37042 .2098 .3614 Mtetra
.564 .669 .909 r
.2098 .3614 .21749 .37042 .22865 .36935 .22102 .35995 Mtetra
.547 .653 .905 r
.22102 .35995 .22865 .36935 .23985 .36876 .23226 .3589 Mtetra
.531 .636 .899 r
.23226 .3589 .23985 .36876 .25107 .36867 .24354 .35829 Mtetra
.514 .616 .891 r
.24354 .35829 .25107 .36867 .26233 .36909 .25486 .35813 Mtetra
.499 .596 .882 r
.25486 .35813 .26233 .36909 .27363 .37002 .26622 .35841 Mtetra
.486 .576 .871 r
.26622 .35841 .27363 .37002 .28498 .37145 .27762 .3591 Mtetra
.477 .557 .859 r
.27762 .3591 .28498 .37145 .2964 .37331 .28909 .36017 Mtetra
.471 .539 .845 r
.28909 .36017 .2964 .37331 .30788 .37554 .30063 .36155 Mtetra
.469 .524 .832 r
.30063 .36155 .30788 .37554 .31944 .37805 .31225 .36316 Mtetra
.472 .512 .818 r
.31225 .36316 .31944 .37805 .3311 .38072 .32395 .36489 Mtetra
.478 .502 .804 r
.32395 .36489 .3311 .38072 .34287 .3834 .33576 .36661 Mtetra
.488 .496 .792 r
.33576 .36661 .34287 .3834 .35475 .38593 .34767 .36819 Mtetra
.501 .493 .78 r
.34767 .36819 .35475 .38593 .36674 .38814 .3597 .36948 Mtetra
.516 .492 .768 r
.3597 .36948 .36674 .38814 .37887 .38986 .37184 .37032 Mtetra
.532 .493 .759 r
.37184 .37032 .37887 .38986 .39113 .3909 .38412 .37055 Mtetra
.549 .497 .75 r
.38412 .37055 .39113 .3909 .40352 .39109 .39651 .37004 Mtetra
.566 .501 .742 r
.39651 .37004 .40352 .39109 .41604 .39029 .40902 .36866 Mtetra
.583 .508 .736 r
.40902 .36866 .41604 .39029 .42867 .38838 .42165 .3663 Mtetra
.599 .515 .73 r
.42165 .3663 .42867 .38838 .44142 .38527 .43438 .3629 Mtetra
.615 .522 .726 r
.43438 .3629 .44142 .38527 .45426 .38091 .4472 .35841 Mtetra
.63 .531 .723 r
.4472 .35841 .45426 .38091 .46718 .3753 .46011 .35284 Mtetra
.644 .539 .721 r
.46011 .35284 .46718 .3753 .48017 .36848 .47309 .34622 Mtetra
.658 .549 .72 r
.47309 .34622 .48017 .36848 .49322 .36053 .48612 .33863 Mtetra
.67 .558 .72 r
.48612 .33863 .49322 .36053 .50631 .35157 .4992 .33016 Mtetra
.681 .568 .721 r
.4992 .33016 .50631 .35157 .51942 .34173 .5123 .32095 Mtetra
.691 .578 .724 r
.5123 .32095 .51942 .34173 .53255 .33119 .52543 .31113 Mtetra
.7 .588 .727 r
.52543 .31113 .53255 .33119 .54568 .32013 .53858 .30086 Mtetra
.708 .599 .732 r
.53858 .30086 .54568 .32013 .55883 .30872 .55174 .29029 Mtetra
.715 .61 .738 r
.55174 .29029 .55883 .30872 .57197 .29714 .56491 .27958 Mtetra
.72 .621 .745 r
.56491 .27958 .57197 .29714 .58512 .28555 .5781 .26887 Mtetra
.725 .632 .754 r
.5781 .26887 .58512 .28555 .59827 .27409 .59129 .25827 Mtetra
.728 .643 .763 r
.59129 .25827 .59827 .27409 .61144 .26289 .60451 .2479 Mtetra
.73 .654 .773 r
.60451 .2479 .61144 .26289 .62463 .25206 .61775 .23785 Mtetra
.731 .665 .785 r
.61775 .23785 .62463 .25206 .63784 .24165 .63102 .22816 Mtetra
.73 .675 .796 r
.63102 .22816 .63784 .24165 .65109 .23172 .64433 .21889 Mtetra
.729 .685 .808 r
.64433 .21889 .65109 .23172 .66438 .22229 .65768 .21005 Mtetra
.726 .695 .82 r
.65768 .21005 .66438 .22229 .67772 .21338 .67108 .20166 Mtetra
.722 .703 .832 r
.67108 .20166 .67772 .21338 .69112 .20497 .68455 .19369 Mtetra
.717 .711 .843 r
.68455 .19369 .69112 .20497 .70457 .19703 .69807 .18614 Mtetra
.711 .717 .854 r
.69807 .18614 .70457 .19703 .7181 .18954 .71166 .17896 Mtetra
.706 .723 .863 r
.71166 .17896 .7181 .18954 .7317 .18244 .72532 .17213 Mtetra
.7 .727 .871 r
.72532 .17213 .7317 .18244 .74537 .17571 .73905 .1656 Mtetra
.694 .731 .879 r
.73905 .1656 .74537 .17571 .75911 .16928 .75286 .15933 Mtetra
.689 .734 .885 r
.75286 .15933 .75911 .16928 .77293 .16311 .76674 .15329 Mtetra
.684 .736 .89 r
.76674 .15329 .77293 .16311 .78683 .15716 .7807 .14743 Mtetra
.631 .721 .912 r
.14618 .36585 .15414 .37371 .16522 .37071 .15729 .36269 Mtetra
.623 .716 .912 r
.15729 .36269 .16522 .37071 .17632 .36794 .16844 .35973 Mtetra
.614 .708 .912 r
.16844 .35973 .17632 .36794 .18746 .36544 .17962 .357 Mtetra
.603 .699 .911 r
.17962 .357 .18746 .36544 .19862 .36325 .19082 .35453 Mtetra
.591 .689 .909 r
.19082 .35453 .19862 .36325 .2098 .3614 .20206 .35237 Mtetra
.578 .676 .907 r
.20206 .35237 .2098 .3614 .22102 .35995 .21333 .35053 Mtetra
.565 .662 .903 r
.21333 .35053 .22102 .35995 .23226 .3589 .22462 .34905 Mtetra
.551 .646 .897 r
.22462 .34905 .23226 .3589 .24354 .35829 .23596 .34795 Mtetra
.537 .629 .89 r
.23596 .34795 .24354 .35829 .25486 .35813 .24733 .34722 Mtetra
.524 .611 .881 r
.24733 .34722 .25486 .35813 .26622 .35841 .25875 .34687 Mtetra
.514 .593 .871 r
.25875 .34687 .26622 .35841 .27762 .3591 .27021 .34686 Mtetra
.505 .575 .859 r
.27021 .34686 .27762 .3591 .28909 .36017 .28174 .34717 Mtetra
.5 .558 .847 r
.28174 .34717 .28909 .36017 .30063 .36155 .29333 .34774 Mtetra
.498 .544 .834 r
.29333 .34774 .30063 .36155 .31225 .36316 .305 .34849 Mtetra
.499 .531 .821 r
.305 .34849 .31225 .36316 .32395 .36489 .31675 .34934 Mtetra
.504 .522 .808 r
.31675 .34934 .32395 .36489 .33576 .36661 .3286 .35016 Mtetra
.512 .514 .795 r
.3286 .35016 .33576 .36661 .34767 .36819 .34055 .35085 Mtetra
.522 .51 .784 r
.34055 .35085 .34767 .36819 .3597 .36948 .35261 .35128 Mtetra
.534 .507 .773 r
.35261 .35128 .3597 .36948 .37184 .37032 .36478 .3513 Mtetra
.547 .507 .763 r
.36478 .3513 .37184 .37032 .38412 .37055 .37706 .35079 Mtetra
.561 .509 .755 r
.37706 .35079 .38412 .37055 .39651 .37004 .38947 .34963 Mtetra
.575 .512 .747 r
.38947 .34963 .39651 .37004 .40902 .36866 .40198 .34771 Mtetra
.59 .517 .741 r
.40198 .34771 .40902 .36866 .42165 .3663 .4146 .34495 Mtetra
.604 .523 .736 r
.4146 .34495 .42165 .3663 .43438 .3629 .42732 .34129 Mtetra
.618 .529 .732 r
.42732 .34129 .43438 .3629 .4472 .35841 .44013 .3367 Mtetra
.632 .537 .729 r
.44013 .3367 .4472 .35841 .46011 .35284 .45303 .33118 Mtetra
.644 .545 .727 r
.45303 .33118 .46011 .35284 .47309 .34622 .46599 .32476 Mtetra
.656 .553 .727 r
.46599 .32476 .47309 .34622 .48612 .33863 .47901 .31751 Mtetra
.667 .562 .727 r
.47901 .31751 .48612 .33863 .4992 .33016 .49207 .30952 Mtetra
.677 .571 .729 r
.49207 .30952 .4992 .33016 .5123 .32095 .50518 .30089 Mtetra
.687 .581 .732 r
.50518 .30089 .5123 .32095 .52543 .31113 .51831 .29175 Mtetra
.695 .591 .736 r
.51831 .29175 .52543 .31113 .53858 .30086 .53147 .28223 Mtetra
.702 .602 .741 r
.53147 .28223 .53858 .30086 .55174 .29029 .54465 .27246 Mtetra
.709 .612 .747 r
.54465 .27246 .55174 .29029 .56491 .27958 .55784 .26256 Mtetra
.714 .623 .755 r
.55784 .26256 .56491 .27958 .5781 .26887 .57106 .25267 Mtetra
.718 .634 .763 r
.57106 .25267 .5781 .26887 .59129 .25827 .58429 .24287 Mtetra
.721 .645 .773 r
.58429 .24287 .59129 .25827 .60451 .2479 .59755 .23328 Mtetra
.723 .656 .783 r
.59755 .23328 .60451 .2479 .61775 .23785 .61084 .22394 Mtetra
.723 .667 .794 r
.61084 .22394 .61775 .23785 .63102 .22816 .62417 .21493 Mtetra
.723 .677 .805 r
.62417 .21493 .63102 .22816 .64433 .21889 .63753 .20627 Mtetra
.721 .687 .817 r
.63753 .20627 .64433 .21889 .65768 .21005 .65095 .19797 Mtetra
.718 .696 .828 r
.65095 .19797 .65768 .21005 .67108 .20166 .66441 .19006 Mtetra
.714 .704 .839 r
.66441 .19006 .67108 .20166 .68455 .19369 .67794 .18251 Mtetra
.71 .711 .85 r
.67794 .18251 .68455 .19369 .69807 .18614 .69152 .1753 Mtetra
.705 .718 .859 r
.69152 .1753 .69807 .18614 .71166 .17896 .70518 .16842 Mtetra
.7 .723 .868 r
.70518 .16842 .71166 .17896 .72532 .17213 .7189 .16182 Mtetra
.695 .727 .875 r
.7189 .16182 .72532 .17213 .73905 .1656 .73269 .15549 Mtetra
.69 .731 .882 r
.73269 .15549 .73905 .1656 .75286 .15933 .74656 .14937 Mtetra
.685 .734 .887 r
.74656 .14937 .75286 .15933 .76674 .15329 .7605 .14343 Mtetra
.681 .736 .892 r
.7605 .14343 .76674 .15329 .7807 .14743 .77452 .13765 Mtetra
.636 .723 .911 r
.13815 .35795 .14618 .36585 .15729 .36269 .14931 .35463 Mtetra
.629 .718 .911 r
.14931 .35463 .15729 .36269 .16844 .35973 .1605 .35148 Mtetra
.621 .711 .91 r
.1605 .35148 .16844 .35973 .17962 .357 .17172 .34853 Mtetra
.612 .703 .909 r
.17172 .34853 .17962 .357 .19082 .35453 .18297 .34581 Mtetra
.602 .694 .907 r
.18297 .34581 .19082 .35453 .20206 .35237 .19425 .34334 Mtetra
.591 .683 .905 r
.19425 .34334 .20206 .35237 .21333 .35053 .20557 .34115 Mtetra
.58 .67 .901 r
.20557 .34115 .21333 .35053 .22462 .34905 .21692 .33925 Mtetra
.568 .656 .896 r
.21692 .33925 .22462 .34905 .23596 .34795 .22831 .33767 Mtetra
.557 .641 .889 r
.22831 .33767 .23596 .34795 .24733 .34722 .23974 .33641 Mtetra
.546 .625 .881 r
.23974 .33641 .24733 .34722 .25875 .34687 .25121 .33547 Mtetra
.537 .608 .872 r
.25121 .33547 .25875 .34687 .27021 .34686 .26274 .33481 Mtetra
.53 .592 .861 r
.26274 .33481 .27021 .34686 .28174 .34717 .27432 .33441 Mtetra
.525 .577 .85 r
.27432 .33441 .28174 .34717 .29333 .34774 .28597 .33422 Mtetra
.523 .563 .838 r
.28597 .33422 .29333 .34774 .305 .34849 .29769 .33418 Mtetra
.523 .551 .825 r
.29769 .33418 .305 .34849 .31675 .34934 .3095 .33421 Mtetra
.527 .541 .813 r
.3095 .33421 .31675 .34934 .3286 .35016 .32139 .3342 Mtetra
.532 .533 .801 r
.32139 .3342 .3286 .35016 .34055 .35085 .33338 .33407 Mtetra
.54 .527 .79 r
.33338 .33407 .34055 .35085 .35261 .35128 .34547 .3337 Mtetra
.55 .524 .779 r
.34547 .3337 .35261 .35128 .36478 .3513 .35766 .33297 Mtetra
.561 .523 .77 r
.35766 .33297 .36478 .3513 .37706 .35079 .36997 .33179 Mtetra
.572 .523 .762 r
.36997 .33179 .37706 .35079 .38947 .34963 .38238 .33004 Mtetra
.585 .525 .755 r
.38238 .33004 .38947 .34963 .40198 .34771 .3949 .32764 Mtetra
.597 .529 .748 r
.3949 .32764 .40198 .34771 .4146 .34495 .40752 .32452 Mtetra
.609 .533 .744 r
.40752 .32452 .4146 .34495 .42732 .34129 .42023 .32064 Mtetra
.622 .539 .74 r
.42023 .32064 .42732 .34129 .44013 .3367 .43303 .31596 Mtetra
.633 .545 .737 r
.43303 .31596 .44013 .3367 .45303 .33118 .44591 .3105 Mtetra
.645 .552 .736 r
.44591 .3105 .45303 .33118 .46599 .32476 .45886 .30428 Mtetra
.655 .56 .735 r
.45886 .30428 .46599 .32476 .47901 .31751 .47187 .29736 Mtetra
.665 .569 .736 r
.47187 .29736 .47901 .31751 .49207 .30952 .48493 .28981 Mtetra
.675 .577 .738 r
.48493 .28981 .49207 .30952 .50518 .30089 .49803 .28172 Mtetra
.683 .587 .741 r
.49803 .28172 .50518 .30089 .51831 .29175 .51117 .27321 Mtetra
.691 .596 .746 r
.51117 .27321 .51831 .29175 .53147 .28223 .52434 .26437 Mtetra
.697 .607 .751 r
.52434 .26437 .53147 .28223 .54465 .27246 .53753 .25532 Mtetra
.703 .617 .758 r
.53753 .25532 .54465 .27246 .55784 .26256 .55075 .24618 Mtetra
.708 .628 .765 r
.55075 .24618 .55784 .26256 .57106 .25267 .564 .23703 Mtetra
.712 .638 .774 r
.564 .23703 .57106 .25267 .58429 .24287 .57727 .22797 Mtetra
.714 .649 .783 r
.57727 .22797 .58429 .24287 .59755 .23328 .59057 .21908 Mtetra
.716 .66 .793 r
.59057 .21908 .59755 .23328 .61084 .22394 .60391 .21041 Mtetra
.716 .67 .804 r
.60391 .21041 .61084 .22394 .62417 .21493 .61729 .202 Mtetra
.715 .68 .815 r
.61729 .202 .62417 .21493 .63753 .20627 .63071 .19389 Mtetra
.713 .69 .826 r
.63071 .19389 .63753 .20627 .65095 .19797 .64418 .1861 Mtetra
.711 .698 .836 r
.64418 .1861 .65095 .19797 .66441 .19006 .6577 .17861 Mtetra
.707 .706 .846 r
.6577 .17861 .66441 .19006 .67794 .18251 .67129 .17144 Mtetra
.703 .713 .856 r
.67129 .17144 .67794 .18251 .69152 .1753 .68493 .16455 Mtetra
.699 .719 .865 r
.68493 .16455 .69152 .1753 .70518 .16842 .69865 .15792 Mtetra
.694 .724 .872 r
.69865 .15792 .70518 .16842 .7189 .16182 .71243 .15154 Mtetra
.69 .728 .879 r
.71243 .15154 .7189 .16182 .73269 .15549 .72628 .14537 Mtetra
.686 .731 .885 r
.72628 .14537 .73269 .15549 .74656 .14937 .74021 .13938 Mtetra
.682 .734 .89 r
.74021 .13938 .74656 .14937 .7605 .14343 .75421 .13354 Mtetra
.678 .736 .894 r
.75421 .13354 .7605 .14343 .77452 .13765 .76828 .12782 Mtetra
.64 .725 .91 r
.13006 .35001 .13815 .35795 .14931 .35463 .14126 .34654 Mtetra
.634 .72 .91 r
.14126 .34654 .14931 .35463 .1605 .35148 .15248 .34322 Mtetra
.628 .715 .909 r
.15248 .34322 .1605 .35148 .17172 .34853 .16375 .34006 Mtetra
.62 .708 .908 r
.16375 .34006 .17172 .34853 .18297 .34581 .17504 .33709 Mtetra
.612 .699 .906 r
.17504 .33709 .18297 .34581 .19425 .34334 .18638 .33433 Mtetra
.603 .69 .903 r
.18638 .33433 .19425 .34334 .20557 .34115 .19774 .33181 Mtetra
.593 .678 .9 r
.19774 .33181 .20557 .34115 .21692 .33925 .20915 .32953 Mtetra
.584 .666 .895 r
.20915 .32953 .21692 .33925 .22831 .33767 .22059 .32751 Mtetra
.574 .652 .889 r
.22059 .32751 .22831 .33767 .23974 .33641 .23208 .32576 Mtetra
.565 .638 .882 r
.23208 .32576 .23974 .33641 .25121 .33547 .24361 .32426 Mtetra
.558 .623 .873 r
.24361 .32426 .25121 .33547 .26274 .33481 .2552 .323 Mtetra
.551 .609 .864 r
.2552 .323 .26274 .33481 .27432 .33441 .26684 .32196 Mtetra
.547 .595 .853 r
.26684 .32196 .27432 .33441 .28597 .33422 .27854 .32107 Mtetra
.545 .582 .842 r
.27854 .32107 .28597 .33422 .29769 .33418 .29032 .32031 Mtetra
.545 .57 .831 r
.29032 .32031 .29769 .33418 .3095 .33421 .30217 .31958 Mtetra
.547 .56 .819 r
.30217 .31958 .3095 .33421 .32139 .3342 .31411 .31883 Mtetra
.551 .552 .808 r
.31411 .31883 .32139 .3342 .33338 .33407 .32614 .31795 Mtetra
.557 .546 .798 r
.32614 .31795 .33338 .33407 .34547 .3337 .33826 .31686 Mtetra
.565 .542 .788 r
.33826 .31686 .34547 .3337 .35766 .33297 .35049 .31546 Mtetra
.574 .539 .779 r
.35049 .31546 .35766 .33297 .36997 .33179 .36281 .31367 Mtetra
.583 .539 .771 r
.36281 .31367 .36997 .33179 .38238 .33004 .37524 .3114 Mtetra
.594 .54 .764 r
.37524 .3114 .38238 .33004 .3949 .32764 .38776 .30857 Mtetra
.604 .542 .758 r
.38776 .30857 .3949 .32764 .40752 .32452 .40038 .30514 Mtetra
.615 .546 .753 r
.40038 .30514 .40752 .32452 .42023 .32064 .41309 .30106 Mtetra
.625 .55 .75 r
.41309 .30106 .42023 .32064 .43303 .31596 .42589 .29632 Mtetra
.636 .556 .747 r
.42589 .29632 .43303 .31596 .44591 .3105 .43876 .29092 Mtetra
.646 .562 .746 r
.43876 .29092 .44591 .3105 .45886 .30428 .4517 .28488 Mtetra
.655 .569 .746 r
.4517 .28488 .45886 .30428 .47187 .29736 .46471 .27826 Mtetra
.664 .577 .747 r
.46471 .27826 .47187 .29736 .48493 .28981 .47776 .27111 Mtetra
.673 .586 .75 r
.47776 .27111 .48493 .28981 .49803 .28172 .49086 .26352 Mtetra
.68 .594 .753 r
.49086 .26352 .49803 .28172 .51117 .27321 .50401 .25557 Mtetra
.687 .604 .757 r
.50401 .25557 .51117 .27321 .52434 .26437 .51718 .24735 Mtetra
.693 .614 .763 r
.51718 .24735 .52434 .26437 .53753 .25532 .5304 .23896 Mtetra
.698 .624 .77 r
.5304 .23896 .53753 .25532 .55075 .24618 .54364 .23049 Mtetra
.702 .634 .777 r
.54364 .23049 .55075 .24618 .564 .23703 .55691 .22201 Mtetra
.706 .644 .786 r
.55691 .22201 .564 .23703 .57727 .22797 .57022 .21361 Mtetra
.708 .655 .795 r
.57022 .21361 .57727 .22797 .59057 .21908 .58356 .20535 Mtetra
.709 .665 .804 r
.58356 .20535 .59057 .21908 .60391 .21041 .59695 .19727 Mtetra
.709 .675 .814 r
.59695 .19727 .60391 .21041 .61729 .202 .61037 .18941 Mtetra
.708 .684 .825 r
.61037 .18941 .61729 .202 .63071 .19389 .62385 .18179 Mtetra
.707 .693 .835 r
.62385 .18179 .63071 .19389 .64418 .1861 .63737 .17444 Mtetra
.704 .701 .845 r
.63737 .17444 .64418 .1861 .6577 .17861 .65096 .16734 Mtetra
.701 .708 .854 r
.65096 .16734 .6577 .17861 .67129 .17144 .6646 .16049 Mtetra
.697 .715 .862 r
.6646 .16049 .67129 .17144 .68493 .16455 .6783 .15388 Mtetra
.693 .72 .87 r
.6783 .15388 .68493 .16455 .69865 .15792 .69207 .14748 Mtetra
.69 .725 .877 r
.69207 .14748 .69865 .15792 .71243 .15154 .70591 .14128 Mtetra
.686 .729 .883 r
.70591 .14128 .71243 .15154 .72628 .14537 .71982 .13526 Mtetra
.682 .732 .888 r
.71982 .13526 .72628 .14537 .74021 .13938 .73381 .12937 Mtetra
.679 .734 .892 r
.73381 .12937 .74021 .13938 .75421 .13354 .74786 .12361 Mtetra
.676 .736 .896 r
.74786 .12361 .75421 .13354 .76828 .12782 .76199 .11795 Mtetra
.644 .727 .909 r
.1219 .34203 .13006 .35001 .14126 .34654 .13313 .33843 Mtetra
.639 .723 .909 r
.13313 .33843 .14126 .34654 .15248 .34322 .1444 .33495 Mtetra
.634 .718 .908 r
.1444 .33495 .15248 .34322 .16375 .34006 .15571 .3316 Mtetra
.627 .712 .907 r
.15571 .3316 .16375 .34006 .17504 .33709 .16705 .3284 Mtetra
.621 .704 .905 r
.16705 .3284 .17504 .33709 .18638 .33433 .17843 .32537 Mtetra
.613 .696 .903 r
.17843 .32537 .18638 .33433 .19774 .33181 .18985 .32254 Mtetra
.605 .686 .899 r
.18985 .32254 .19774 .33181 .20915 .32953 .2013 .31991 Mtetra
.597 .675 .895 r
.2013 .31991 .20915 .32953 .22059 .32751 .2128 .31749 Mtetra
.589 .664 .89 r
.2128 .31749 .22059 .32751 .23208 .32576 .22434 .31529 Mtetra
.582 .651 .883 r
.22434 .31529 .23208 .32576 .24361 .32426 .23593 .31329 Mtetra
.576 .638 .876 r
.23593 .31329 .24361 .32426 .2552 .323 .24758 .31149 Mtetra
.57 .625 .867 r
.24758 .31149 .2552 .323 .26684 .32196 .25927 .30985 Mtetra
.566 .612 .858 r
.25927 .30985 .26684 .32196 .27854 .32107 .27104 .30834 Mtetra
.564 .6 .848 r
.27104 .30834 .27854 .32107 .29032 .32031 .28287 .30692 Mtetra
.564 .589 .837 r
.28287 .30692 .29032 .32031 .30217 .31958 .29477 .30553 Mtetra
.565 .579 .827 r
.29477 .30553 .30217 .31958 .31411 .31883 .30675 .3041 Mtetra
.568 .571 .816 r
.30675 .3041 .31411 .31883 .32614 .31795 .31882 .30256 Mtetra
.573 .565 .806 r
.31882 .30256 .32614 .31795 .33826 .31686 .33098 .30083 Mtetra
.579 .56 .797 r
.33098 .30083 .33826 .31686 .35049 .31546 .34323 .29884 Mtetra
.586 .557 .789 r
.34323 .29884 .35049 .31546 .36281 .31367 .35558 .29651 Mtetra
.594 .555 .781 r
.35558 .29651 .36281 .31367 .37524 .3114 .36802 .29378 Mtetra
.602 .556 .775 r
.36802 .29378 .37524 .3114 .38776 .30857 .38056 .29058 Mtetra
.611 .557 .769 r
.38056 .29058 .38776 .30857 .40038 .30514 .39319 .28688 Mtetra
.62 .56 .765 r
.39319 .28688 .40038 .30514 .41309 .30106 .4059 .28263 Mtetra
.63 .564 .761 r
.4059 .28263 .41309 .30106 .42589 .29632 .41869 .27784 Mtetra
.639 .568 .759 r
.41869 .27784 .42589 .29632 .43876 .29092 .43156 .27249 Mtetra
.647 .574 .758 r
.43156 .27249 .43876 .29092 .4517 .28488 .4445 .26662 Mtetra
.656 .581 .759 r
.4445 .26662 .4517 .28488 .46471 .27826 .4575 .26027 Mtetra
.664 .588 .76 r
.4575 .26027 .46471 .27826 .47776 .27111 .47056 .25349 Mtetra
.671 .596 .762 r
.47056 .25349 .47776 .27111 .49086 .26352 .48366 .24633 Mtetra
.678 .604 .766 r
.48366 .24633 .49086 .26352 .50401 .25557 .49681 .23888 Mtetra
.684 .613 .77 r
.49681 .23888 .50401 .25557 .51718 .24735 .51 .23121 Mtetra
.689 .622 .776 r
.51 .23121 .51718 .24735 .5304 .23896 .52323 .2234 Mtetra
.694 .632 .782 r
.52323 .2234 .5304 .23896 .54364 .23049 .5365 .21552 Mtetra
.698 .642 .79 r
.5365 .21552 .54364 .23049 .55691 .22201 .5498 .20764 Mtetra
.7 .652 .798 r
.5498 .20764 .55691 .22201 .57022 .21361 .56314 .19982 Mtetra
.702 .661 .807 r
.56314 .19982 .57022 .21361 .58356 .20535 .57653 .1921 Mtetra
.703 .671 .816 r
.57653 .1921 .58356 .20535 .59695 .19727 .58995 .18454 Mtetra
.703 .68 .825 r
.58995 .18454 .59695 .19727 .61037 .18941 .60343 .17716 Mtetra
.702 .689 .835 r
.60343 .17716 .61037 .18941 .62385 .18179 .61695 .16997 Mtetra
.7 .697 .844 r
.61695 .16997 .62385 .18179 .63737 .17444 .63053 .163 Mtetra
.698 .705 .853 r
.63053 .163 .63737 .17444 .65096 .16734 .64417 .15623 Mtetra
.695 .711 .861 r
.64417 .15623 .65096 .16734 .6646 .16049 .65786 .14967 Mtetra
.692 .717 .869 r
.65786 .14967 .6646 .16049 .6783 .15388 .67162 .14329 Mtetra
.689 .722 .875 r
.67162 .14329 .6783 .15388 .69207 .14748 .68545 .1371 Mtetra
.685 .726 .881 r
.68545 .1371 .69207 .14748 .70591 .14128 .69935 .13105 Mtetra
.682 .73 .887 r
.69935 .13105 .70591 .14128 .71982 .13526 .71332 .12515 Mtetra
.679 .733 .891 r
.71332 .12515 .71982 .13526 .73381 .12937 .72735 .11935 Mtetra
.676 .735 .895 r
.72735 .11935 .73381 .12937 .74786 .12361 .74146 .11366 Mtetra
.674 .736 .898 r
.74146 .11366 .74786 .12361 .76199 .11795 .75565 .10803 Mtetra
.647 .729 .908 r
.11368 .33403 .1219 .34203 .13313 .33843 .12494 .3303 Mtetra
.643 .725 .908 r
.12494 .3303 .13313 .33843 .1444 .33495 .13625 .32666 Mtetra
.639 .721 .907 r
.13625 .32666 .1444 .33495 .15571 .3316 .1476 .32314 Mtetra
.634 .716 .906 r
.1476 .32314 .15571 .3316 .16705 .3284 .15898 .31973 Mtetra
.628 .709 .905 r
.15898 .31973 .16705 .3284 .17843 .32537 .17041 .31646 Mtetra
.622 .702 .902 r
.17041 .31646 .17843 .32537 .18985 .32254 .18188 .31335 Mtetra
.616 .694 .899 r
.18188 .31335 .18985 .32254 .2013 .31991 .19338 .3104 Mtetra
.609 .684 .896 r
.19338 .3104 .2013 .31991 .2128 .31749 .20494 .30762 Mtetra
.603 .674 .891 r
.20494 .30762 .2128 .31749 .22434 .31529 .21653 .30501 Mtetra
.597 .663 .885 r
.21653 .30501 .22434 .31529 .23593 .31329 .22818 .30257 Mtetra
.591 .652 .878 r
.22818 .30257 .23593 .31329 .24758 .31149 .23987 .30028 Mtetra
.586 .64 .871 r
.23987 .30028 .24758 .31149 .25927 .30985 .25163 .29812 Mtetra
.583 .628 .862 r
.25163 .29812 .25927 .30985 .27104 .30834 .26344 .29606 Mtetra
.581 .617 .853 r
.26344 .29606 .27104 .30834 .28287 .30692 .27533 .29406 Mtetra
.58 .607 .844 r
.27533 .29406 .28287 .30692 .29477 .30553 .28728 .29207 Mtetra
.581 .598 .835 r
.28728 .29207 .29477 .30553 .30675 .3041 .29931 .29005 Mtetra
.583 .59 .825 r
.29931 .29005 .30675 .3041 .31882 .30256 .31142 .28792 Mtetra
.587 .584 .816 r
.31142 .28792 .31882 .30256 .33098 .30083 .32362 .28564 Mtetra
.591 .579 .808 r
.32362 .28564 .33098 .30083 .34323 .29884 .3359 .28313 Mtetra
.597 .575 .8 r
.3359 .28313 .34323 .29884 .35558 .29651 .34827 .28033 Mtetra
.604 .573 .793 r
.34827 .28033 .35558 .29651 .36802 .29378 .36073 .2772 Mtetra
.611 .573 .787 r
.36073 .2772 .36802 .29378 .38056 .29058 .37329 .27368 Mtetra
.618 .573 .781 r
.37329 .27368 .38056 .29058 .39319 .28688 .38592 .26974 Mtetra
.626 .575 .777 r
.38592 .26974 .39319 .28688 .4059 .28263 .39864 .26536 Mtetra
.634 .578 .774 r
.39864 .26536 .4059 .28263 .41869 .27784 .41144 .26052 Mtetra
.642 .583 .773 r
.41144 .26052 .41869 .27784 .43156 .27249 .42431 .25523 Mtetra
.65 .588 .772 r
.42431 .25523 .43156 .27249 .4445 .26662 .43725 .24951 Mtetra
.657 .593 .772 r
.43725 .24951 .4445 .26662 .4575 .26027 .45025 .24339 Mtetra
.664 .6 .774 r
.45025 .24339 .4575 .26027 .47056 .25349 .46331 .23692 Mtetra
.67 .607 .776 r
.46331 .23692 .47056 .25349 .48366 .24633 .47642 .23015 Mtetra
.676 .615 .78 r
.47642 .23015 .48366 .24633 .49681 .23888 .48958 .22314 Mtetra
.682 .624 .784 r
.48958 .22314 .49681 .23888 .51 .23121 .50278 .21595 Mtetra
.686 .632 .79 r
.50278 .21595 .51 .23121 .52323 .2234 .51603 .20864 Mtetra
.69 .641 .796 r
.51603 .20864 .52323 .2234 .5365 .21552 .52932 .20127 Mtetra
.693 .651 .803 r
.52932 .20127 .5365 .21552 .5498 .20764 .54265 .1939 Mtetra
.695 .66 .811 r
.54265 .1939 .5498 .20764 .56314 .19982 .55603 .18657 Mtetra
.697 .669 .819 r
.55603 .18657 .56314 .19982 .57653 .1921 .56945 .17934 Mtetra
.697 .678 .828 r
.56945 .17934 .57653 .1921 .58995 .18454 .58292 .17222 Mtetra
.697 .687 .836 r
.58292 .17222 .58995 .18454 .60343 .17716 .59644 .16524 Mtetra
.696 .695 .845 r
.59644 .16524 .60343 .17716 .61695 .16997 .61002 .15843 Mtetra
.695 .702 .853 r
.61002 .15843 .61695 .16997 .63053 .163 .62364 .15178 Mtetra
.692 .709 .861 r
.62364 .15178 .63053 .163 .64417 .15623 .63733 .14529 Mtetra
.69 .715 .868 r
.63733 .14529 .64417 .15623 .65786 .14967 .65108 .13897 Mtetra
.687 .72 .874 r
.65108 .13897 .65786 .14967 .67162 .14329 .6649 .13279 Mtetra
.684 .724 .88 r
.6649 .13279 .67162 .14329 .68545 .1371 .67878 .12676 Mtetra
.681 .728 .885 r
.67878 .12676 .68545 .1371 .69935 .13105 .69273 .12084 Mtetra
.678 .731 .89 r
.69273 .12084 .69935 .13105 .71332 .12515 .70676 .11503 Mtetra
.676 .733 .894 r
.70676 .11503 .71332 .12515 .72735 .11935 .72085 .10931 Mtetra
.674 .735 .897 r
.72085 .10931 .72735 .11935 .74146 .11366 .73501 .10366 Mtetra
.672 .737 .899 r
.73501 .10366 .74146 .11366 .75565 .10803 .74925 .09807 Mtetra
.65 .731 .908 r
.10538 .326 .11368 .33403 .12494 .3303 .11668 .32215 Mtetra
.647 .727 .908 r
.11668 .32215 .12494 .3303 .13625 .32666 .12803 .31838 Mtetra
.643 .724 .907 r
.12803 .31838 .13625 .32666 .1476 .32314 .13941 .31469 Mtetra
.639 .719 .906 r
.13941 .31469 .1476 .32314 .15898 .31973 .15084 .31109 Mtetra
.635 .714 .904 r
.15084 .31109 .15898 .31973 .17041 .31646 .16231 .30761 Mtetra
.63 .708 .902 r
.16231 .30761 .17041 .31646 .18188 .31335 .17383 .30425 Mtetra
.624 .701 .9 r
.17383 .30425 .18188 .31335 .19338 .3104 .18538 .30101 Mtetra
.619 .693 .896 r
.18538 .30101 .19338 .3104 .20494 .30762 .19699 .29791 Mtetra
.614 .684 .892 r
.19699 .29791 .20494 .30762 .21653 .30501 .20864 .29495 Mtetra
.609 .674 .887 r
.20864 .29495 .21653 .30501 .22818 .30257 .22033 .29211 Mtetra
.604 .664 .881 r
.22033 .29211 .22818 .30257 .23987 .30028 .23209 .28939 Mtetra
.601 .654 .875 r
.23209 .28939 .23987 .30028 .25163 .29812 .24389 .28677 Mtetra
.598 .644 .867 r
.24389 .28677 .25163 .29812 .26344 .29606 .25576 .28422 Mtetra
.596 .634 .86 r
.25576 .28422 .26344 .29606 .27533 .29406 .2677 .28171 Mtetra
.595 .625 .851 r
.2677 .28171 .27533 .29406 .28728 .29207 .2797 .27921 Mtetra
.595 .616 .843 r
.2797 .27921 .28728 .29207 .29931 .29005 .29178 .27667 Mtetra
.597 .609 .835 r
.29178 .27667 .29931 .29005 .31142 .28792 .30393 .27404 Mtetra
.599 .603 .826 r
.30393 .27404 .31142 .28792 .32362 .28564 .31616 .27127 Mtetra
.603 .598 .819 r
.31616 .27127 .32362 .28564 .3359 .28313 .32848 .26831 Mtetra
.608 .594 .811 r
.32848 .26831 .3359 .28313 .34827 .28033 .34088 .26512 Mtetra
.613 .592 .805 r
.34088 .26512 .34827 .28033 .36073 .2772 .35336 .26164 Mtetra
.619 .59 .799 r
.35336 .26164 .36073 .2772 .37329 .27368 .36593 .25785 Mtetra
.625 .591 .795 r
.36593 .25785 .37329 .27368 .38592 .26974 .37858 .25371 Mtetra
.632 .592 .791 r
.37858 .25371 .38592 .26974 .39864 .26536 .39131 .2492 Mtetra
.638 .595 .788 r
.39131 .2492 .39864 .26536 .41144 .26052 .40411 .24433 Mtetra
.645 .598 .787 r
.40411 .24433 .41144 .26052 .42431 .25523 .41699 .23909 Mtetra
.652 .602 .786 r
.41699 .23909 .42431 .25523 .43725 .24951 .42993 .2335 Mtetra
.658 .608 .787 r
.42993 .2335 .43725 .24951 .45025 .24339 .44294 .22759 Mtetra
.664 .614 .788 r
.44294 .22759 .45025 .24339 .46331 .23692 .45601 .22139 Mtetra
.67 .62 .791 r
.45601 .22139 .46331 .23692 .47642 .23015 .46913 .21494 Mtetra
.675 .628 .794 r
.46913 .21494 .47642 .23015 .48958 .22314 .4823 .2083 Mtetra
.679 .635 .799 r
.4823 .2083 .48958 .22314 .50278 .21595 .49552 .20151 Mtetra
.683 .644 .804 r
.49552 .20151 .50278 .21595 .51603 .20864 .50879 .19463 Mtetra
.687 .652 .81 r
.50879 .19463 .51603 .20864 .52932 .20127 .52211 .18769 Mtetra
.689 .66 .817 r
.52211 .18769 .52932 .20127 .54265 .1939 .53547 .18076 Mtetra
.691 .669 .824 r
.53547 .18076 .54265 .1939 .55603 .18657 .54888 .17385 Mtetra
.692 .677 .831 r
.54888 .17385 .55603 .18657 .56945 .17934 .56234 .16702 Mtetra
.692 .685 .839 r
.56234 .16702 .56945 .17934 .58292 .17222 .57585 .16028 Mtetra
.692 .693 .847 r
.57585 .16028 .58292 .17222 .59644 .16524 .58942 .15364 Mtetra
.691 .7 .854 r
.58942 .15364 .59644 .16524 .61002 .15843 .60304 .14714 Mtetra
.689 .707 .861 r
.60304 .14714 .61002 .15843 .62364 .15178 .61671 .14076 Mtetra
.687 .713 .868 r
.61671 .14076 .62364 .15178 .63733 .14529 .63045 .13451 Mtetra
.685 .718 .874 r
.63045 .13451 .63733 .14529 .65108 .13897 .64426 .12838 Mtetra
.683 .723 .88 r
.64426 .12838 .65108 .13897 .6649 .13279 .65813 .12237 Mtetra
.68 .726 .885 r
.65813 .12237 .6649 .13279 .67878 .12676 .67206 .11646 Mtetra
.678 .73 .889 r
.67206 .11646 .67878 .12676 .69273 .12084 .68607 .11065 Mtetra
.676 .732 .893 r
.68607 .11065 .69273 .12084 .70676 .11503 .70014 .10491 Mtetra
.673 .734 .896 r
.70014 .10491 .70676 .11503 .72085 .10931 .71429 .09924 Mtetra
.672 .736 .899 r
.71429 .09924 .72085 .10931 .73501 .10366 .72851 .09362 Mtetra
.67 .737 .901 r
.72851 .09362 .73501 .10366 .74925 .09807 .7428 .08804 Mtetra
.653 .732 .908 r
.09701 .31793 .10538 .326 .11668 .32215 .10834 .31398 Mtetra
.65 .73 .907 r
.10834 .31398 .11668 .32215 .12803 .31838 .11973 .31008 Mtetra
.647 .726 .907 r
.11973 .31008 .12803 .31838 .13941 .31469 .13116 .30625 Mtetra
.644 .723 .906 r
.13116 .30625 .13941 .31469 .15084 .31109 .14263 .30249 Mtetra
.64 .718 .904 r
.14263 .30249 .15084 .31109 .16231 .30761 .15414 .29881 Mtetra
.636 .713 .902 r
.15414 .29881 .16231 .30761 .17383 .30425 .1657 .29523 Mtetra
.632 .707 .9 r
.1657 .29523 .17383 .30425 .18538 .30101 .1773 .29174 Mtetra
.628 .7 .897 r
.1773 .29174 .18538 .30101 .19699 .29791 .18896 .28836 Mtetra
.624 .693 .894 r
.18896 .28836 .19699 .29791 .20864 .29495 .20066 .28508 Mtetra
.619 .685 .889 r
.20066 .28508 .20864 .29495 .22033 .29211 .21241 .2819 Mtetra
.616 .676 .884 r
.21241 .2819 .22033 .29211 .23209 .28939 .22421 .2788 Mtetra
.613 .667 .879 r
.22421 .2788 .23209 .28939 .24389 .28677 .23607 .27578 Mtetra
.61 .659 .873 r
.23607 .27578 .24389 .28677 .25576 .28422 .24799 .27281 Mtetra
.608 .65 .866 r
.24799 .27281 .25576 .28422 .2677 .28171 .25997 .26987 Mtetra
.607 .642 .859 r
.25997 .26987 .2677 .28171 .2797 .27921 .27202 .26692 Mtetra
.608 .634 .851 r
.27202 .26692 .2797 .27921 .29178 .27667 .28414 .26394 Mtetra
.609 .627 .844 r
.28414 .26394 .29178 .27667 .30393 .27404 .29634 .26087 Mtetra
.611 .621 .837 r
.29634 .26087 .30393 .27404 .31616 .27127 .30861 .25769 Mtetra
.614 .616 .83 r
.30861 .25769 .31616 .27127 .32848 .26831 .32096 .25435 Mtetra
.617 .613 .824 r
.32096 .25435 .32848 .26831 .34088 .26512 .33339 .25082 Mtetra
.622 .61 .818 r
.33339 .25082 .34088 .26512 .35336 .26164 .3459 .24705 Mtetra
.626 .609 .813 r
.3459 .24705 .35336 .26164 .36593 .25785 .35849 .24302 Mtetra
.632 .608 .809 r
.35849 .24302 .36593 .25785 .37858 .25371 .37115 .23871 Mtetra
.637 .609 .805 r
.37115 .23871 .37858 .25371 .39131 .2492 .3839 .23411 Mtetra
.643 .611 .803 r
.3839 .23411 .39131 .2492 .40411 .24433 .39671 .2292 Mtetra
.648 .614 .802 r
.39671 .2292 .40411 .24433 .41699 .23909 .4096 .224 Mtetra
.654 .618 .801 r
.4096 .224 .41699 .23909 .42993 .2335 .42255 .21852 Mtetra
.659 .623 .802 r
.42255 .21852 .42993 .2335 .44294 .22759 .43557 .21278 Mtetra
.665 .628 .803 r
.43557 .21278 .44294 .22759 .45601 .22139 .44865 .2068 Mtetra
.669 .634 .806 r
.44865 .2068 .45601 .22139 .46913 .21494 .46178 .20063 Mtetra
.674 .641 .809 r
.46178 .20063 .46913 .21494 .4823 .2083 .47497 .1943 Mtetra
.677 .648 .813 r
.47497 .1943 .4823 .2083 .49552 .20151 .48821 .18785 Mtetra
.681 .655 .818 r
.48821 .18785 .49552 .20151 .50879 .19463 .5015 .18132 Mtetra
.683 .663 .824 r
.5015 .18132 .50879 .19463 .52211 .18769 .51485 .17475 Mtetra
.685 .671 .83 r
.51485 .17475 .52211 .18769 .53547 .18076 .52824 .16817 Mtetra
.687 .678 .836 r
.52824 .16817 .53547 .18076 .54888 .17385 .54169 .16162 Mtetra
.687 .686 .843 r
.54169 .16162 .54888 .17385 .56234 .16702 .55518 .15511 Mtetra
.688 .693 .85 r
.55518 .15511 .56234 .16702 .57585 .16028 .56873 .14868 Mtetra
.687 .7 .856 r
.56873 .14868 .57585 .16028 .58942 .15364 .58234 .14233 Mtetra
.686 .706 .863 r
.58234 .14233 .58942 .15364 .60304 .14714 .59601 .13607 Mtetra
.685 .712 .869 r
.59601 .13607 .60304 .14714 .61671 .14076 .60974 .12991 Mtetra
.683 .717 .875 r
.60974 .12991 .61671 .14076 .63045 .13451 .62353 .12385 Mtetra
.681 .721 .88 r
.62353 .12385 .63045 .13451 .64426 .12838 .63738 .11788 Mtetra
.679 .725 .885 r
.63738 .11788 .64426 .12838 .65813 .12237 .6513 .112 Mtetra
.677 .729 .889 r
.6513 .112 .65813 .12237 .67206 .11646 .66529 .1062 Mtetra
.675 .731 .893 r
.66529 .1062 .67206 .11646 .68607 .11065 .67935 .10046 Mtetra
.673 .734 .896 r
.67935 .10046 .68607 .11065 .70014 .10491 .69348 .09478 Mtetra
.671 .735 .898 r
.69348 .09478 .70014 .10491 .71429 .09924 .70768 .08914 Mtetra
.67 .737 .9 r
.70768 .08914 .71429 .09924 .72851 .09362 .72195 .08354 Mtetra
.669 .738 .902 r
.72195 .08354 .72851 .09362 .7428 .08804 .7363 .07797 Mtetra
.655 .734 .907 r
.08856 .30984 .09701 .31793 .10834 .31398 .09994 .30579 Mtetra
.653 .731 .907 r
.09994 .30579 .10834 .31398 .11973 .31008 .11136 .30178 Mtetra
.65 .729 .906 r
.11136 .30178 .11973 .31008 .13116 .30625 .12282 .29782 Mtetra
.648 .726 .906 r
.12282 .29782 .13116 .30625 .14263 .30249 .13433 .29391 Mtetra
.645 .722 .904 r
.13433 .29391 .14263 .30249 .15414 .29881 .14589 .29006 Mtetra
.642 .718 .903 r
.14589 .29006 .15414 .29881 .1657 .29523 .15749 .28628 Mtetra
.638 .713 .901 r
.15749 .28628 .1657 .29523 .1773 .29174 .16914 .28258 Mtetra
.635 .707 .898 r
.16914 .28258 .1773 .29174 .18896 .28836 .18084 .27895 Mtetra
.632 .701 .895 r
.18084 .27895 .18896 .28836 .20066 .28508 .19259 .2754 Mtetra
.628 .694 .892 r
.19259 .2754 .20066 .28508 .21241 .2819 .20439 .27192 Mtetra
.625 .687 .888 r
.20439 .27192 .21241 .2819 .22421 .2788 .21624 .2685 Mtetra
.623 .679 .883 r
.21624 .2685 .22421 .2788 .23607 .27578 .22815 .26514 Mtetra
.621 .672 .877 r
.22815 .26514 .23607 .27578 .24799 .27281 .24012 .26181 Mtetra
.619 .664 .872 r
.24012 .26181 .24799 .27281 .25997 .26987 .25215 .2585 Mtetra
.618 .657 .866 r
.25215 .2585 .25997 .26987 .27202 .26692 .26425 .25517 Mtetra
.618 .65 .859 r
.26425 .25517 .27202 .26692 .28414 .26394 .27641 .25181 Mtetra
.619 .644 .853 r
.27641 .25181 .28414 .26394 .29634 .26087 .28865 .24838 Mtetra
.621 .639 .847 r
.28865 .24838 .29634 .26087 .30861 .25769 .30096 .24485 Mtetra
.623 .634 .841 r
.30096 .24485 .30861 .25769 .32096 .25435 .31334 .24118 Mtetra
.626 .631 .835 r
.31334 .24118 .32096 .25435 .33339 .25082 .3258 .23736 Mtetra
.629 .628 .83 r
.3258 .23736 .33339 .25082 .3459 .24705 .33834 .23334 Mtetra
.633 .627 .826 r
.33834 .23334 .3459 .24705 .35849 .24302 .35095 .22912 Mtetra
.638 .626 .822 r
.35095 .22912 .35849 .24302 .37115 .23871 .36364 .22466 Mtetra
.642 .627 .819 r
.36364 .22466 .37115 .23871 .3839 .23411 .3764 .21997 Mtetra
.647 .628 .817 r
.3764 .21997 .3839 .23411 .39671 .2292 .38923 .21504 Mtetra
.652 .631 .816 r
.38923 .21504 .39671 .2292 .4096 .224 .40213 .20987 Mtetra
.656 .634 .816 r
.40213 .20987 .4096 .224 .42255 .21852 .4151 .20448 Mtetra
.661 .638 .817 r
.4151 .20448 .42255 .21852 .43557 .21278 .42813 .19887 Mtetra
.665 .643 .818 r
.42813 .19887 .43557 .21278 .44865 .2068 .44122 .19308 Mtetra
.669 .648 .821 r
.44122 .19308 .44865 .2068 .46178 .20063 .45438 .18713 Mtetra
.673 .654 .824 r
.45438 .18713 .46178 .20063 .47497 .1943 .46758 .18106 Mtetra
.676 .661 .827 r
.46758 .18106 .47497 .1943 .48821 .18785 .48085 .17488 Mtetra
.678 .667 .832 r
.48085 .17488 .48821 .18785 .5015 .18132 .49416 .16864 Mtetra
.68 .674 .837 r
.49416 .16864 .5015 .18132 .51485 .17475 .50754 .16237 Mtetra
.682 .681 .842 r
.50754 .16237 .51485 .17475 .52824 .16817 .52096 .15608 Mtetra
.683 .687 .848 r
.52096 .15608 .52824 .16817 .54169 .16162 .53444 .14981 Mtetra
.683 .694 .854 r
.53444 .14981 .54169 .16162 .55518 .15511 .54798 .14358 Mtetra
.683 .7 .86 r
.54798 .14358 .55518 .15511 .56873 .14868 .56157 .13739 Mtetra
.683 .706 .865 r
.56157 .13739 .56873 .14868 .58234 .14233 .57522 .13127 Mtetra
.682 .711 .871 r
.57522 .13127 .58234 .14233 .59601 .13607 .58893 .12521 Mtetra
.68 .716 .876 r
.58893 .12521 .59601 .13607 .60974 .12991 .60271 .11922 Mtetra
.679 .721 .881 r
.60271 .11922 .60974 .12991 .62353 .12385 .61655 .11331 Mtetra
.677 .725 .885 r
.61655 .11331 .62353 .12385 .63738 .11788 .63045 .10746 Mtetra
.676 .728 .889 r
.63045 .10746 .63738 .11788 .6513 .112 .64442 .10168 Mtetra
.674 .731 .893 r
.64442 .10168 .6513 .112 .66529 .1062 .65846 .09595 Mtetra
.672 .733 .895 r
.65846 .09595 .66529 .1062 .67935 .10046 .67257 .09026 Mtetra
.671 .735 .898 r
.67257 .09026 .67935 .10046 .69348 .09478 .68675 .08462 Mtetra
.67 .736 .9 r
.68675 .08462 .69348 .09478 .70768 .08914 .701 .079 Mtetra
.668 .738 .902 r
.701 .079 .70768 .08914 .72195 .08354 .71533 .07341 Mtetra
.667 .738 .903 r
.71533 .07341 .72195 .08354 .7363 .07797 .72973 .06782 Mtetra
.657 .735 .907 r
.08004 .30171 .08856 .30984 .09994 .30579 .09145 .29758 Mtetra
.655 .733 .907 r
.09145 .29758 .09994 .30579 .11136 .30178 .10291 .29346 Mtetra
.653 .731 .906 r
.10291 .29346 .11136 .30178 .12282 .29782 .11441 .28939 Mtetra
.651 .728 .906 r
.11441 .28939 .12282 .29782 .13433 .29391 .12596 .28535 Mtetra
.649 .725 .905 r
.12596 .28535 .13433 .29391 .14589 .29006 .13756 .28135 Mtetra
.646 .722 .903 r
.13756 .28135 .14589 .29006 .15749 .28628 .1492 .2774 Mtetra
.644 .718 .902 r
.1492 .2774 .15749 .28628 .16914 .28258 .1609 .27351 Mtetra
.641 .713 .9 r
.1609 .27351 .16914 .28258 .18084 .27895 .17264 .26967 Mtetra
.638 .708 .897 r
.17264 .26967 .18084 .27895 .19259 .2754 .18443 .26589 Mtetra
.636 .702 .894 r
.18443 .26589 .19259 .2754 .20439 .27192 .19628 .26215 Mtetra
.633 .696 .891 r
.19628 .26215 .20439 .27192 .21624 .2685 .20818 .25846 Mtetra
.631 .69 .887 r
.20818 .25846 .21624 .2685 .22815 .26514 .22014 .25481 Mtetra
.63 .684 .882 r
.22014 .25481 .22815 .26514 .24012 .26181 .23216 .25117 Mtetra
.628 .677 .877 r
.23216 .25117 .24012 .26181 .25215 .2585 .24423 .24755 Mtetra
.628 .671 .872 r
.24423 .24755 .25215 .2585 .26425 .25517 .25638 .2439 Mtetra
.628 .665 .867 r
.25638 .2439 .26425 .25517 .27641 .25181 .26858 .24022 Mtetra
.628 .66 .862 r
.26858 .24022 .27641 .25181 .28865 .24838 .28086 .23648 Mtetra
.629 .655 .857 r
.28086 .23648 .28865 .24838 .30096 .24485 .29321 .23266 Mtetra
.631 .651 .852 r
.29321 .23266 .30096 .24485 .31334 .24118 .30563 .22872 Mtetra
.633 .648 .847 r
.30563 .22872 .31334 .24118 .3258 .23736 .31812 .22465 Mtetra
.636 .646 .843 r
.31812 .22465 .3258 .23736 .33834 .23334 .33068 .22043 Mtetra
.639 .644 .839 r
.33068 .22043 .33834 .23334 .35095 .22912 .34332 .21604 Mtetra
.643 .643 .836 r
.34332 .21604 .35095 .22912 .36364 .22466 .35603 .21146 Mtetra
.647 .644 .833 r
.35603 .21146 .36364 .22466 .3764 .21997 .36881 .2067 Mtetra
.65 .645 .832 r
.36881 .2067 .3764 .21997 .38923 .21504 .38166 .20174 Mtetra
.654 .647 .831 r
.38166 .20174 .38923 .21504 .40213 .20987 .39458 .19659 Mtetra
.658 .65 .83 r
.39458 .19659 .40213 .20987 .4151 .20448 .40757 .19126 Mtetra
.662 .653 .831 r
.40757 .19126 .4151 .20448 .42813 .19887 .42062 .18577 Mtetra
.665 .658 .833 r
.42062 .18577 .42813 .19887 .44122 .19308 .43373 .18013 Mtetra
.669 .662 .835 r
.43373 .18013 .44122 .19308 .45438 .18713 .4469 .17436 Mtetra
.671 .667 .837 r
.4469 .17436 .45438 .18713 .46758 .18106 .46013 .16848 Mtetra
.674 .673 .841 r
.46013 .16848 .46758 .18106 .48085 .17488 .47342 .16253 Mtetra
.676 .679 .845 r
.47342 .16253 .48085 .17488 .49416 .16864 .48677 .15652 Mtetra
.678 .684 .849 r
.48677 .15652 .49416 .16864 .50754 .16237 .50017 .15048 Mtetra
.679 .69 .854 r
.50017 .15048 .50754 .16237 .52096 .15608 .51363 .14442 Mtetra
.679 .696 .859 r
.51363 .14442 .52096 .15608 .53444 .14981 .52714 .13838 Mtetra
.68 .702 .864 r
.52714 .13838 .53444 .14981 .54798 .14358 .54072 .13235 Mtetra
.679 .707 .869 r
.54072 .13235 .54798 .14358 .56157 .13739 .55435 .12636 Mtetra
.679 .712 .873 r
.55435 .12636 .56157 .13739 .57522 .13127 .56805 .12041 Mtetra
.678 .717 .878 r
.56805 .12041 .57522 .13127 .58893 .12521 .5818 .11451 Mtetra
.677 .721 .882 r
.5818 .11451 .58893 .12521 .60271 .11922 .59562 .10866 Mtetra
.676 .724 .886 r
.59562 .10866 .60271 .11922 .61655 .11331 .60951 .10285 Mtetra
.674 .727 .89 r
.60951 .10285 .61655 .11331 .63045 .10746 .62346 .0971 Mtetra
.673 .73 .893 r
.62346 .0971 .63045 .10746 .64442 .10168 .63749 .09138 Mtetra
.672 .732 .896 r
.63749 .09138 .64442 .10168 .65846 .09595 .65158 .0857 Mtetra
.67 .734 .898 r
.65158 .0857 .65846 .09595 .67257 .09026 .66574 .08005 Mtetra
.669 .736 .9 r
.66574 .08005 .67257 .09026 .68675 .08462 .67997 .07443 Mtetra
.668 .737 .902 r
.67997 .07443 .68675 .08462 .701 .079 .69427 .06881 Mtetra
.667 .738 .903 r
.69427 .06881 .701 .079 .71533 .07341 .70865 .06321 Mtetra
.667 .739 .904 r
.70865 .06321 .71533 .07341 .72973 .06782 .7231 .05762 Mtetra
.658 .736 .907 r
.07145 .29355 .08004 .30171 .09145 .29758 .08289 .28933 Mtetra
.657 .735 .907 r
.08289 .28933 .09145 .29758 .10291 .29346 .09438 .28513 Mtetra
.655 .733 .906 r
.09438 .28513 .10291 .29346 .11441 .28939 .10592 .28095 Mtetra
.654 .731 .906 r
.10592 .28095 .11441 .28939 .12596 .28535 .11751 .27679 Mtetra
.652 .728 .905 r
.11751 .27679 .12596 .28535 .13756 .28135 .12915 .27267 Mtetra
.65 .725 .904 r
.12915 .27267 .13756 .28135 .1492 .2774 .14083 .26858 Mtetra
.648 .722 .902 r
.14083 .26858 .1492 .2774 .1609 .27351 .15257 .26452 Mtetra
.646 .718 .901 r
.15257 .26452 .1609 .27351 .17264 .26967 .16435 .2605 Mtetra
.644 .714 .899 r
.16435 .2605 .17264 .26967 .18443 .26589 .17619 .25652 Mtetra
.642 .71 .896 r
.17619 .25652 .18443 .26589 .19628 .26215 .18808 .25257 Mtetra
.64 .705 .893 r
.18808 .25257 .19628 .26215 .20818 .25846 .20003 .24865 Mtetra
.638 .7 .89 r
.20003 .24865 .20818 .25846 .22014 .25481 .21203 .24475 Mtetra
.637 .694 .887 r
.21203 .24475 .22014 .25481 .23216 .25117 .2241 .24086 Mtetra
.636 .689 .883 r
.2241 .24086 .23216 .25117 .24423 .24755 .23622 .23696 Mtetra
.635 .684 .878 r
.23622 .23696 .24423 .24755 .25638 .2439 .2484 .23305 Mtetra
.635 .679 .874 r
.2484 .23305 .25638 .2439 .26858 .24022 .26065 .22911 Mtetra
.636 .674 .87 r
.26065 .22911 .26858 .24022 .28086 .23648 .27297 .22511 Mtetra
.637 .67 .865 r
.27297 .22511 .28086 .23648 .29321 .23266 .28535 .22104 Mtetra
.638 .667 .861 r
.28535 .22104 .29321 .23266 .30563 .22872 .29781 .21688 Mtetra
.64 .664 .857 r
.29781 .21688 .30563 .22872 .31812 .22465 .31033 .21261 Mtetra
.642 .662 .854 r
.31033 .21261 .31812 .22465 .33068 .22043 .32293 .20821 Mtetra
.645 .66 .851 r
.32293 .20821 .33068 .22043 .34332 .21604 .33559 .20368 Mtetra
.647 .66 .848 r
.33559 .20368 .34332 .21604 .35603 .21146 .34833 .199 Mtetra
.65 .66 .846 r
.34833 .199 .35603 .21146 .36881 .2067 .36114 .19417 Mtetra
.653 .661 .845 r
.36114 .19417 .36881 .2067 .38166 .20174 .37401 .18919 Mtetra
.657 .662 .844 r
.37401 .18919 .38166 .20174 .39458 .19659 .38695 .18405 Mtetra
.66 .665 .844 r
.38695 .18405 .39458 .19659 .40757 .19126 .39996 .17877 Mtetra
.663 .668 .845 r
.39996 .17877 .40757 .19126 .42062 .18577 .41303 .17336 Mtetra
.666 .671 .846 r
.41303 .17336 .42062 .18577 .43373 .18013 .42617 .16783 Mtetra
.668 .675 .848 r
.42617 .16783 .43373 .18013 .4469 .17436 .43936 .16219 Mtetra
.67 .68 .85 r
.43936 .16219 .4469 .17436 .46013 .16848 .45262 .15648 Mtetra
.672 .684 .853 r
.45262 .15648 .46013 .16848 .47342 .16253 .46593 .15069 Mtetra
.674 .689 .856 r
.46593 .15069 .47342 .16253 .48677 .15652 .47931 .14486 Mtetra
.675 .694 .86 r
.47931 .14486 .48677 .15652 .50017 .15048 .49274 .139 Mtetra
.676 .699 .864 r
.49274 .139 .50017 .15048 .51363 .14442 .50624 .13312 Mtetra
.676 .704 .868 r
.50624 .13312 .51363 .14442 .52714 .13838 .51979 .12725 Mtetra
.676 .709 .872 r
.51979 .12725 .52714 .13838 .54072 .13235 .5334 .12139 Mtetra
.676 .713 .876 r
.5334 .12139 .54072 .13235 .55435 .12636 .54708 .11554 Mtetra
.676 .717 .88 r
.54708 .11554 .55435 .12636 .56805 .12041 .56082 .10973 Mtetra
.675 .721 .884 r
.56082 .10973 .56805 .12041 .5818 .11451 .57462 .10394 Mtetra
.674 .724 .887 r
.57462 .10394 .5818 .11451 .59562 .10866 .58849 .09818 Mtetra
.673 .727 .891 r
.58849 .09818 .59562 .10866 .60951 .10285 .60242 .09246 Mtetra
.672 .73 .894 r
.60242 .09246 .60951 .10285 .62346 .0971 .61642 .08676 Mtetra
.671 .732 .896 r
.61642 .08676 .62346 .0971 .63749 .09138 .63049 .08109 Mtetra
.67 .734 .898 r
.63049 .08109 .63749 .09138 .65158 .0857 .64463 .07545 Mtetra
.669 .736 .9 r
.64463 .07545 .65158 .0857 .66574 .08005 .65884 .06981 Mtetra
.668 .737 .902 r
.65884 .06981 .66574 .08005 .67997 .07443 .67313 .06419 Mtetra
.667 .738 .903 r
.67313 .06419 .67997 .07443 .69427 .06881 .68748 .05857 Mtetra
.666 .739 .904 r
.68748 .05857 .69427 .06881 .70865 .06321 .70192 .05296 Mtetra
.666 .739 .905 r
.70192 .05296 .70865 .06321 .7231 .05762 .71642 .04733 Mtetra
.659 .737 .907 r
.06278 .28534 .07145 .29355 .08289 .28933 .07426 .28105 Mtetra
.658 .736 .907 r
.07426 .28105 .08289 .28933 .09438 .28513 .08578 .27677 Mtetra
.657 .735 .907 r
.08578 .27677 .09438 .28513 .10592 .28095 .09736 .2725 Mtetra
.656 .733 .906 r
.09736 .2725 .10592 .28095 .11751 .27679 .10898 .26824 Mtetra
.655 .731 .905 r
.10898 .26824 .11751 .27679 .12915 .27267 .12065 .264 Mtetra
.653 .729 .904 r
.12065 .264 .12915 .27267 .14083 .26858 .13238 .25979 Mtetra
.652 .726 .903 r
.13238 .25979 .14083 .26858 .15257 .26452 .14415 .25559 Mtetra
.65 .723 .902 r
.14415 .25559 .15257 .26452 .16435 .2605 .15598 .25142 Mtetra
.648 .719 .9 r
.15598 .25142 .16435 .2605 .17619 .25652 .16786 .24726 Mtetra
.647 .716 .898 r
.16786 .24726 .17619 .25652 .18808 .25257 .1798 .24313 Mtetra
.645 .712 .896 r
.1798 .24313 .18808 .25257 .20003 .24865 .19179 .23902 Mtetra
.644 .708 .893 r
.19179 .23902 .20003 .24865 .21203 .24475 .20383 .23491 Mtetra
.643 .704 .89 r
.20383 .23491 .21203 .24475 .2241 .24086 .21594 .23081 Mtetra
.642 .699 .887 r
.21594 .23081 .2241 .24086 .23622 .23696 .2281 .2267 Mtetra
.642 .695 .884 r
.2281 .2267 .23622 .23696 .2484 .23305 .24033 .22256 Mtetra
.642 .691 .88 r
.24033 .22256 .2484 .23305 .26065 .22911 .25262 .2184 Mtetra
.642 .687 .877 r
.25262 .2184 .26065 .22911 .27297 .22511 .26498 .21419 Mtetra
.643 .684 .873 r
.26498 .21419 .27297 .22511 .28535 .22104 .2774 .20991 Mtetra
.644 .681 .87 r
.2774 .20991 .28535 .22104 .29781 .21688 .28989 .20556 Mtetra
.645 .678 .867 r
.28989 .20556 .29781 .21688 .31033 .21261 .30245 .20112 Mtetra
.647 .676 .864 r
.30245 .20112 .31033 .21261 .32293 .20821 .31508 .19658 Mtetra
.649 .675 .861 r
.31508 .19658 .32293 .20821 .33559 .20368 .32777 .19193 Mtetra
.651 .675 .859 r
.32777 .19193 .33559 .20368 .34833 .199 .34054 .18716 Mtetra
.654 .675 .858 r
.34054 .18716 .34833 .199 .36114 .19417 .35337 .18227 Mtetra
.656 .675 .857 r
.35337 .18227 .36114 .19417 .37401 .18919 .36627 .17726 Mtetra
.658 .677 .856 r
.36627 .17726 .37401 .18919 .38695 .18405 .37924 .17213 Mtetra
.661 .679 .856 r
.37924 .17213 .38695 .18405 .39996 .17877 .39227 .16688 Mtetra
.663 .681 .857 r
.39227 .16688 .39996 .17877 .41303 .17336 .40537 .16153 Mtetra
.666 .684 .858 r
.40537 .16153 .41303 .17336 .42617 .16783 .41853 .15608 Mtetra
.668 .687 .859 r
.41853 .15608 .42617 .16783 .43936 .16219 .43175 .15055 Mtetra
.669 .691 .862 r
.43175 .15055 .43936 .16219 .45262 .15648 .44503 .14495 Mtetra
.671 .695 .864 r
.44503 .14495 .45262 .15648 .46593 .15069 .45838 .13929 Mtetra
.672 .699 .867 r
.45838 .13929 .46593 .15069 .47931 .14486 .47179 .13359 Mtetra
.673 .703 .87 r
.47179 .13359 .47931 .14486 .49274 .139 .48525 .12786 Mtetra
.673 .707 .873 r
.48525 .12786 .49274 .139 .50624 .13312 .49878 .12212 Mtetra
.674 .711 .876 r
.49878 .12212 .50624 .13312 .51979 .12725 .51237 .11637 Mtetra
.674 .715 .88 r
.51237 .11637 .51979 .12725 .5334 .12139 .52603 .11063 Mtetra
.673 .719 .883 r
.52603 .11063 .5334 .12139 .54708 .11554 .53974 .10489 Mtetra
.673 .722 .886 r
.53974 .10489 .54708 .11554 .56082 .10973 .55353 .09917 Mtetra
.672 .725 .889 r
.55353 .09917 .56082 .10973 .57462 .10394 .56737 .09346 Mtetra
.672 .728 .892 r
.56737 .09346 .57462 .10394 .58849 .09818 .58129 .08777 Mtetra
.671 .73 .894 r
.58129 .08777 .58849 .09818 .60242 .09246 .59527 .0821 Mtetra
.67 .732 .897 r
.59527 .0821 .60242 .09246 .61642 .08676 .60932 .07644 Mtetra
.669 .734 .899 r
.60932 .07644 .61642 .08676 .63049 .08109 .62344 .0708 Mtetra
.668 .736 .9 r
.62344 .0708 .63049 .08109 .64463 .07545 .63763 .06516 Mtetra
.667 .737 .902 r
.63763 .06516 .64463 .07545 .65884 .06981 .65189 .05953 Mtetra
.667 .738 .903 r
.65189 .05953 .65884 .06981 .67313 .06419 .66623 .0539 Mtetra
.666 .739 .904 r
.66623 .0539 .67313 .06419 .68748 .05857 .68063 .04827 Mtetra
.666 .739 .905 r
.68063 .04827 .68748 .05857 .70192 .05296 .69512 .04263 Mtetra
.665 .74 .906 r
.69512 .04263 .70192 .05296 .71642 .04733 .70967 .03698 Mtetra
.66 .738 .907 r
.05404 .27709 .06278 .28534 .07426 .28105 .06555 .27274 Mtetra
.66 .737 .907 r
.06555 .27274 .07426 .28105 .08578 .27677 .0771 .26838 Mtetra
.659 .736 .907 r
.0771 .26838 .08578 .27677 .09736 .2725 .08871 .26403 Mtetra
.658 .735 .906 r
.08871 .26403 .09736 .2725 .10898 .26824 .10037 .25969 Mtetra
.657 .733 .906 r
.10037 .25969 .10898 .26824 .12065 .264 .11208 .25535 Mtetra
.656 .731 .905 r
.11208 .25535 .12065 .264 .13238 .25979 .12384 .25102 Mtetra
.654 .729 .904 r
.12384 .25102 .13238 .25979 .14415 .25559 .13566 .2467 Mtetra
.653 .727 .903 r
.13566 .2467 .14415 .25559 .15598 .25142 .14752 .2424 Mtetra
.652 .724 .902 r
.14752 .2424 .15598 .25142 .16786 .24726 .15944 .2381 Mtetra
.651 .721 .9 r
.15944 .2381 .16786 .24726 .1798 .24313 .17142 .23382 Mtetra
.65 .718 .898 r
.17142 .23382 .1798 .24313 .19179 .23902 .18345 .22954 Mtetra
.649 .715 .896 r
.18345 .22954 .19179 .23902 .20383 .23491 .19554 .22526 Mtetra
.648 .711 .894 r
.19554 .22526 .20383 .23491 .21594 .23081 .20769 .22098 Mtetra
.647 .708 .891 r
.20769 .22098 .21594 .23081 .2281 .2267 .2199 .21669 Mtetra
.647 .705 .889 r
.2199 .21669 .2281 .2267 .24033 .22256 .23216 .21237 Mtetra
.647 .701 .886 r
.23216 .21237 .24033 .22256 .25262 .2184 .24449 .20802 Mtetra
.647 .698 .883 r
.24449 .20802 .25262 .2184 .26498 .21419 .25689 .20363 Mtetra
.648 .695 .88 r
.25689 .20363 .26498 .21419 .2774 .20991 .26935 .19919 Mtetra
.649 .693 .878 r
.26935 .19919 .2774 .20991 .28989 .20556 .28188 .19468 Mtetra
.65 .691 .875 r
.28188 .19468 .28989 .20556 .30245 .20112 .29447 .1901 Mtetra
.651 .689 .873 r
.29447 .1901 .30245 .20112 .31508 .19658 .30713 .18544 Mtetra
.653 .688 .871 r
.30713 .18544 .31508 .19658 .32777 .19193 .31986 .18069 Mtetra
.654 .688 .869 r
.31986 .18069 .32777 .19193 .34054 .18716 .33265 .17584 Mtetra
.656 .688 .868 r
.33265 .17584 .34054 .18716 .35337 .18227 .34551 .1709 Mtetra
.658 .688 .867 r
.34551 .1709 .35337 .18227 .36627 .17726 .35844 .16586 Mtetra
.66 .689 .867 r
.35844 .16586 .36627 .17726 .37924 .17213 .37144 .16072 Mtetra
.662 .691 .867 r
.37144 .16072 .37924 .17213 .39227 .16688 .3845 .15549 Mtetra
.664 .693 .867 r
.3845 .15549 .39227 .16688 .40537 .16153 .39762 .15017 Mtetra
.665 .695 .868 r
.39762 .15017 .40537 .16153 .41853 .15608 .41081 .14478 Mtetra
.667 .698 .87 r
.41081 .14478 .41853 .15608 .43175 .15055 .42406 .13932 Mtetra
.668 .701 .871 r
.42406 .13932 .43175 .15055 .44503 .14495 .43738 .1338 Mtetra
.669 .704 .873 r
.43738 .1338 .44503 .14495 .45838 .13929 .45075 .12823 Mtetra
.67 .708 .876 r
.45075 .12823 .45838 .13929 .47179 .13359 .4642 .12263 Mtetra
.671 .711 .878 r
.4642 .12263 .47179 .13359 .48525 .12786 .4777 .117 Mtetra
.671 .714 .881 r
.4777 .117 .48525 .12786 .49878 .12212 .49126 .11135 Mtetra
.671 .717 .883 r
.49126 .11135 .49878 .12212 .51237 .11637 .50489 .10569 Mtetra
.671 .721 .886 r
.50489 .10569 .51237 .11637 .52603 .11063 .51859 .10003 Mtetra
.671 .723 .889 r
.51859 .10003 .52603 .11063 .53974 .10489 .53235 .09436 Mtetra
.671 .726 .891 r
.53235 .09436 .53974 .10489 .55353 .09917 .54617 .0887 Mtetra
.67 .729 .893 r
.54617 .0887 .55353 .09917 .56737 .09346 .56006 .08305 Mtetra
.67 .731 .896 r
.56006 .08305 .56737 .09346 .58129 .08777 .57402 .0774 Mtetra
.669 .733 .898 r
.57402 .0774 .58129 .08777 .59527 .0821 .58805 .07176 Mtetra
.668 .734 .899 r
.58805 .07176 .59527 .0821 .60932 .07644 .60215 .06612 Mtetra
.668 .736 .901 r
.60215 .06612 .60932 .07644 .62344 .0708 .61632 .06048 Mtetra
.667 .737 .902 r
.61632 .06048 .62344 .0708 .63763 .06516 .63056 .05484 Mtetra
.666 .738 .903 r
.63056 .05484 .63763 .06516 .65189 .05953 .64487 .0492 Mtetra
.666 .739 .904 r
.64487 .0492 .65189 .05953 .66623 .0539 .65926 .04355 Mtetra
.665 .739 .905 r
.65926 .04355 .66623 .0539 .68063 .04827 .67372 .03789 Mtetra
.665 .74 .906 r
.67372 .03789 .68063 .04827 .69512 .04263 .68825 .03222 Mtetra
.68825 .03222 .69512 .04263 .70967 .03698 .70286 .02653 Mtetra
.661 .739 .907 r
.04522 .26879 .05404 .27709 .06555 .27274 .05676 .26438 Mtetra
.661 .738 .907 r
.05676 .26438 .06555 .27274 .0771 .26838 .06835 .25996 Mtetra
.66 .737 .907 r
.06835 .25996 .0771 .26838 .08871 .26403 .07999 .25553 Mtetra
.659 .736 .907 r
.07999 .25553 .08871 .26403 .10037 .25969 .09168 .25111 Mtetra
.658 .735 .906 r
.09168 .25111 .10037 .25969 .11208 .25535 .10343 .24668 Mtetra
.658 .733 .906 r
.10343 .24668 .11208 .25535 .12384 .25102 .11522 .24226 Mtetra
.657 .732 .905 r
.11522 .24226 .12384 .25102 .13566 .2467 .12708 .23784 Mtetra
.656 .73 .904 r
.12708 .23784 .13566 .2467 .14752 .2424 .13898 .23342 Mtetra
.655 .728 .903 r
.13898 .23342 .14752 .2424 .15944 .2381 .15094 .22901 Mtetra
.654 .726 .902 r
.15094 .22901 .15944 .2381 .17142 .23382 .16296 .2246 Mtetra
.653 .723 .9 r
.16296 .2246 .17142 .23382 .18345 .22954 .17503 .22018 Mtetra
.652 .721 .899 r
.17503 .22018 .18345 .22954 .19554 .22526 .18716 .21576 Mtetra
.652 .718 .897 r
.18716 .21576 .19554 .22526 .20769 .22098 .19934 .21133 Mtetra
.651 .715 .895 r
.19934 .21133 .20769 .22098 .2199 .21669 .21159 .20688 Mtetra
.651 .713 .893 r
.21159 .20688 .2199 .21669 .23216 .21237 .2239 .20241 Mtetra
.651 .71 .891 r
.2239 .20241 .23216 .21237 .24449 .20802 .23627 .19791 Mtetra
.651 .707 .888 r
.23627 .19791 .24449 .20802 .25689 .20363 .2487 .19338 Mtetra
.652 .705 .886 r
.2487 .19338 .25689 .20363 .26935 .19919 .2612 .18879 Mtetra
.652 .703 .884 r
.2612 .18879 .26935 .19919 .28188 .19468 .27376 .18415 Mtetra
.653 .702 .882 r
.27376 .18415 .28188 .19468 .29447 .1901 .28639 .17946 Mtetra
.654 .7 .88 r
.28639 .17946 .29447 .1901 .30713 .18544 .29909 .17469 Mtetra
.655 .699 .879 r
.29909 .17469 .30713 .18544 .31986 .18069 .31185 .16985 Mtetra
.657 .699 .878 r
.31185 .16985 .31986 .18069 .33265 .17584 .32467 .16493 Mtetra
.658 .699 .877 r
.32467 .16493 .33265 .17584 .34551 .1709 .33757 .15994 Mtetra
.66 .699 .876 r
.33757 .15994 .34551 .1709 .35844 .16586 .35053 .15486 Mtetra
.661 .7 .876 r
.35053 .15486 .35844 .16586 .37144 .16072 .36355 .14971 Mtetra
.662 .702 .876 r
.36355 .14971 .37144 .16072 .3845 .15549 .37664 .14449 Mtetra
.664 .703 .876 r
.37664 .14449 .3845 .15549 .39762 .15017 .3898 .13919 Mtetra
.665 .705 .877 r
.3898 .13919 .39762 .15017 .41081 .14478 .40302 .13383 Mtetra
.666 .707 .878 r
.40302 .13383 .41081 .14478 .42406 .13932 .4163 .12842 Mtetra
.667 .71 .88 r
.4163 .12842 .42406 .13932 .43738 .1338 .42965 .12295 Mtetra
.668 .712 .881 r
.42965 .12295 .43738 .1338 .45075 .12823 .44306 .11744 Mtetra
.669 .715 .883 r
.44306 .11744 .45075 .12823 .4642 .12263 .45653 .1119 Mtetra
.669 .718 .885 r
.45653 .1119 .4642 .12263 .4777 .117 .47008 .10634 Mtetra
.669 .72 .887 r
.47008 .10634 .4777 .117 .49126 .11135 .48368 .10075 Mtetra
.669 .723 .889 r
.48368 .10075 .49126 .11135 .50489 .10569 .49735 .09515 Mtetra
.669 .725 .891 r
.49735 .09515 .50489 .10569 .51859 .10003 .51108 .08954 Mtetra
.669 .727 .893 r
.51108 .08954 .51859 .10003 .53235 .09436 .52489 .08392 Mtetra
.669 .729 .895 r
.52489 .08392 .53235 .09436 .54617 .0887 .53876 .07829 Mtetra
.668 .731 .897 r
.53876 .07829 .54617 .0887 .56006 .08305 .55269 .07267 Mtetra
.668 .733 .899 r
.55269 .07267 .56006 .08305 .57402 .0774 .5667 .06704 Mtetra
.667 .735 .9 r
.5667 .06704 .57402 .0774 .58805 .07176 .58077 .06141 Mtetra
.667 .736 .901 r
.58077 .06141 .58805 .07176 .60215 .06612 .59492 .05577 Mtetra
.667 .737 .903 r
.59492 .05577 .60215 .06612 .61632 .06048 .60914 .05013 Mtetra
.666 .738 .904 r
.60914 .05013 .61632 .06048 .63056 .05484 .62343 .04447 Mtetra
.666 .739 .904 r
.62343 .04447 .63056 .05484 .64487 .0492 .63779 .03881 Mtetra
.665 .739 .905 r
.63779 .03881 .64487 .0492 .65926 .04355 .65223 .03313 Mtetra
.665 .74 .906 r
.65223 .03313 .65926 .04355 .67372 .03789 .66674 .02744 Mtetra
.66674 .02744 .67372 .03789 .68825 .03222 .68133 .02173 Mtetra
.664 .74 .907 r
.68133 .02173 .68825 .03222 .70286 .02653 .69599 .01601 Mtetra
.662 .739 .907 r
.03632 .26044 .04522 .26879 .05676 .26438 .04789 .25597 Mtetra
.661 .739 .907 r
.04789 .25597 .05676 .26438 .06835 .25996 .05951 .25149 Mtetra
.661 .738 .907 r
.05951 .25149 .06835 .25996 .07999 .25553 .07118 .247 Mtetra
.66 .737 .907 r
.07118 .247 .07999 .25553 .09168 .25111 .08291 .2425 Mtetra
.66 .736 .906 r
.08291 .2425 .09168 .25111 .10343 .24668 .09469 .238 Mtetra
.659 .735 .906 r
.09469 .238 .10343 .24668 .11522 .24226 .10652 .2335 Mtetra
.658 .734 .905 r
.10652 .2335 .11522 .24226 .12708 .23784 .11841 .22899 Mtetra
.658 .733 .905 r
.11841 .22899 .12708 .23784 .13898 .23342 .13035 .22447 Mtetra
.657 .731 .904 r
.13035 .22447 .13898 .23342 .15094 .22901 .14235 .21996 Mtetra
.656 .729 .903 r
.14235 .21996 .15094 .22901 .16296 .2246 .1544 .21543 Mtetra
.656 .727 .902 r
.1544 .21543 .16296 .2246 .17503 .22018 .16652 .2109 Mtetra
.655 .725 .901 r
.16652 .2109 .17503 .22018 .18716 .21576 .17868 .20636 Mtetra
.655 .723 .899 r
.17868 .20636 .18716 .21576 .19934 .21133 .19091 .2018 Mtetra
.655 .721 .898 r
.19091 .2018 .19934 .21133 .21159 .20688 .2032 .19723 Mtetra
.654 .719 .896 r
.2032 .19723 .21159 .20688 .2239 .20241 .21554 .19263 Mtetra
.654 .717 .894 r
.21554 .19263 .2239 .20241 .23627 .19791 .22795 .18801 Mtetra
.654 .715 .893 r
.22795 .18801 .23627 .19791 .2487 .19338 .24042 .18335 Mtetra
.655 .713 .891 r
.24042 .18335 .2487 .19338 .2612 .18879 .25296 .17865 Mtetra
.655 .712 .89 r
.25296 .17865 .2612 .18879 .27376 .18415 .26556 .1739 Mtetra
.656 .711 .888 r
.26556 .1739 .27376 .18415 .28639 .17946 .27822 .1691 Mtetra
.657 .71 .887 r
.27822 .1691 .28639 .17946 .29909 .17469 .29095 .16424 Mtetra
.658 .709 .885 r
.29095 .16424 .29909 .17469 .31185 .16985 .30374 .15933 Mtetra
.659 .709 .885 r
.30374 .15933 .31185 .16985 .32467 .16493 .3166 .15435 Mtetra
.66 .709 .884 r
.3166 .15435 .32467 .16493 .33757 .15994 .32953 .14931 Mtetra
.661 .709 .883 r
.32953 .14931 .33757 .15994 .35053 .15486 .34252 .1442 Mtetra
.662 .71 .883 r
.34252 .1442 .35053 .15486 .36355 .14971 .35558 .13903 Mtetra
.663 .711 .883 r
.35558 .13903 .36355 .14971 .37664 .14449 .3687 .13379 Mtetra
.664 .712 .884 r
.3687 .13379 .37664 .14449 .3898 .13919 .38189 .1285 Mtetra
.665 .713 .884 r
.38189 .1285 .3898 .13919 .40302 .13383 .39514 .12316 Mtetra
.666 .715 .885 r
.39514 .12316 .40302 .13383 .4163 .12842 .40846 .11777 Mtetra
.666 .717 .886 r
.40846 .11777 .4163 .12842 .42965 .12295 .42184 .11233 Mtetra
.667 .719 .888 r
.42184 .11233 .42965 .12295 .44306 .11744 .43529 .10686 Mtetra
.667 .721 .889 r
.43529 .10686 .44306 .11744 .45653 .1119 .4488 .10135 Mtetra
.668 .723 .891 r
.4488 .10135 .45653 .1119 .47008 .10634 .46238 .09582 Mtetra
.668 .725 .892 r
.46238 .09582 .47008 .10634 .48368 .10075 .47603 .09027 Mtetra
.668 .727 .894 r
.47603 .09027 .48368 .10075 .49735 .09515 .48974 .0847 Mtetra
.668 .729 .895 r
.48974 .0847 .49735 .09515 .51108 .08954 .50351 .07912 Mtetra
.668 .731 .897 r
.50351 .07912 .51108 .08954 .52489 .08392 .51736 .07352 Mtetra
.667 .732 .898 r
.51736 .07352 .52489 .08392 .53876 .07829 .53127 .06791 Mtetra
.667 .734 .9 r
.53127 .06791 .53876 .07829 .55269 .07267 .54526 .0623 Mtetra
.667 .735 .901 r
.54526 .0623 .55269 .07267 .5667 .06704 .55931 .05667 Mtetra
.666 .736 .902 r
.55931 .05667 .5667 .06704 .58077 .06141 .57343 .05103 Mtetra
.666 .737 .903 r
.57343 .05103 .58077 .06141 .59492 .05577 .58763 .04538 Mtetra
.666 .738 .904 r
.58763 .04538 .59492 .05577 .60914 .05013 .60189 .03972 Mtetra
.665 .739 .905 r
.60189 .03972 .60914 .05013 .62343 .04447 .61623 .03404 Mtetra
.61623 .03404 .62343 .04447 .63779 .03881 .63065 .02835 Mtetra
.665 .74 .906 r
.63065 .02835 .63779 .03881 .65223 .03313 .64513 .02264 Mtetra
.64513 .02264 .65223 .03313 .66674 .02744 .6597 .01691 Mtetra
.664 .74 .907 r
.6597 .01691 .66674 .02744 .68133 .02173 .67433 .01116 Mtetra
.664 .741 .907 r
.67433 .01116 .68133 .02173 .69599 .01601 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 0 1 r
.005 w
.4484 .34124 m
.4742 .33428 L
.5 .33107 L
.5258 .33132 L
.5516 .33494 L
.5774 .34207 L
.58609 .3452 L
.6032 .35304 L
.629 .36869 L
.63219 .371 L
.6548 .3905 L
.66078 .3968 L
.68057 .4226 L
.6806 .42265 L
.69438 .4484 L
.7033 .4742 L
.7064 .48856 L
.70797 .5 L
.70858 .5258 L
.7064 .54477 L
.70505 .5516 L
.69703 .5774 L
.68359 .6032 L
.6806 .60775 L
.663 .629 L
.6548 .6368 L
.63031 .6548 L
.629 .65558 L
.6032 .66823 L
.5774 .67618 L
.5516 .68026 L
.5472 .6806 L
.5258 .68085 L
.52108 .6806 L
.5 .67809 L
.4742 .67189 L
.4484 .66191 L
.43439 .6548 L
.4226 .64756 L
.39849 .629 L
.3968 .62747 L
.37444 .6032 L
.371 .59871 L
.3576 .5774 L
.34616 .5516 L
.3452 .5501 L
.33921 .5258 L
.3364 .5 L
.33767 .4742 L
.34321 .4484 L
Mistroke
.3452 .4417 L
.35355 .4226 L
.36998 .3968 L
.371 .39549 L
.39514 .371 L
.3968 .36966 L
.4226 .35256 L
.43775 .3452 L
.4484 .34124 L
Mfstroke
.4484 .33578 m
.4742 .32974 L
.5 .32735 L
.5258 .32835 L
.5516 .3327 L
.5774 .34061 L
.58877 .3452 L
.6032 .35245 L
.629 .36917 L
.63138 .371 L
.6548 .39251 L
.65864 .3968 L
.67765 .4226 L
.6806 .42736 L
.69083 .4484 L
.69927 .4742 L
.70346 .5 L
.7036 .5258 L
.69957 .5516 L
.69093 .5774 L
.6806 .59744 L
.67673 .6032 L
.65491 .629 L
.6548 .62911 L
.629 .64941 L
.62011 .6548 L
.6032 .66297 L
.5774 .67171 L
.5516 .67647 L
.5258 .67771 L
.5 .6756 L
.4742 .67009 L
.4484 .66093 L
.43527 .6548 L
.4226 .6476 L
.39691 .629 L
.3968 .6289 L
.37157 .6032 L
.371 .60251 L
.35381 .5774 L
.3452 .56069 L
.34164 .5516 L
.33404 .5258 L
.33063 .5 L
.33129 .4742 L
.33619 .4484 L
.3452 .42374 L
.34584 .4226 L
.36127 .3968 L
.371 .38475 L
Mistroke
.38494 .371 L
.3968 .36152 L
.4226 .34604 L
.42422 .3452 L
.4484 .33578 L
Mfstroke
.4484 .34317 m
.4742 .34063 L
.5 .34149 L
.52364 .3452 L
.5258 .34568 L
.5516 .35329 L
.5774 .36481 L
.58839 .371 L
.6032 .38093 L
.6223 .3968 L
.629 .40336 L
.64539 .4226 L
.6548 .43623 L
.66162 .4484 L
.67265 .4742 L
.67918 .5 L
.6806 .5101 L
.68157 .5258 L
.6806 .54575 L
.67984 .5516 L
.67373 .5774 L
.66253 .6032 L
.6548 .61605 L
.64487 .629 L
.629 .64534 L
.61737 .6548 L
.6032 .66417 L
.5774 .67673 L
.56749 .6806 L
.5516 .68465 L
.5258 .68873 L
.5 .68933 L
.4742 .6866 L
.44865 .6806 L
.4484 .68048 L
.4226 .67076 L
.3968 .65673 L
.3938 .6548 L
.371 .63736 L
.3621 .629 L
.3452 .60986 L
.34032 .6032 L
.325 .5774 L
.3194 .56555 L
.31475 .5516 L
.30889 .5258 L
.30716 .5 L
.30959 .4742 L
.31651 .4484 L
.3194 .44058 L
Mistroke
.32862 .4226 L
.3452 .39949 L
.34762 .3968 L
.371 .37556 L
.37737 .371 L
.3968 .35972 L
.4226 .34933 L
.43561 .3452 L
.4484 .34317 L
Mfstroke
.4742 .34309 m
.5 .34334 L
.51619 .3452 L
.5258 .34691 L
.5516 .35389 L
.5774 .36467 L
.58927 .371 L
.6032 .37989 L
.62445 .3968 L
.629 .40105 L
.64823 .4226 L
.6548 .43152 L
.66495 .4484 L
.67632 .4742 L
.6806 .48502 L
.68318 .5 L
.68588 .5258 L
.68445 .5516 L
.6806 .57068 L
.67865 .5774 L
.66789 .6032 L
.6548 .62396 L
.65076 .629 L
.629 .65097 L
.62423 .6548 L
.6032 .66864 L
.5774 .68034 L
.57683 .6806 L
.5516 .68763 L
.5258 .69114 L
.5 .69121 L
.4742 .68796 L
.4484 .68128 L
.44626 .6806 L
.4226 .67093 L
.3968 .65613 L
.39483 .6548 L
.371 .63568 L
.3642 .629 L
.3452 .60627 L
.34308 .6032 L
.32824 .5774 L
.3194 .5551 L
.31844 .5516 L
.31297 .5258 L
.31163 .5 L
.31447 .4742 L
.3194 .4528 L
.32183 .4484 L
.3345 .4226 L
Mistroke
.3452 .40715 L
.35423 .3968 L
.371 .38133 L
.38541 .371 L
.3968 .36438 L
.4226 .35311 L
.4484 .34625 L
.45445 .3452 L
.4742 .34309 L
Mfstroke
.3968 .34425 m
.4226 .33417 L
.4484 .32827 L
.4742 .32599 L
.5 .32707 L
.5258 .33148 L
.5516 .3394 L
.56565 .3452 L
.5774 .35121 L
.6032 .36781 L
.60734 .371 L
.629 .39089 L
.63431 .3968 L
.65318 .4226 L
.6548 .42517 L
.6663 .4484 L
.67467 .4742 L
.67879 .5 L
.67884 .5258 L
.67468 .5516 L
.66584 .5774 L
.6548 .59816 L
.65131 .6032 L
.629 .62892 L
.62891 .629 L
.6032 .6487 L
.59272 .6548 L
.5774 .66187 L
.5516 .67032 L
.5258 .67483 L
.5 .67585 L
.4742 .67356 L
.4484 .66789 L
.4226 .65859 L
.41424 .6548 L
.3968 .64518 L
.37403 .629 L
.371 .62647 L
.34779 .6032 L
.3452 .60012 L
.32937 .5774 L
.3194 .55839 L
.31666 .5516 L
.30858 .5258 L
.30474 .5 L
.30499 .4742 L
.30948 .4484 L
.31872 .4226 L
.3194 .42109 L
.33368 .3968 L
Mistroke
.3452 .38244 L
.35673 .371 L
.371 .35951 L
.39483 .3452 L
.3968 .34425 L
Mfstroke
0 g
.03 w
.52259 .50591 Mdot
.51723 .50252 Mdot
.49438 .51501 Mdot
.49875 .51718 Mdot
.49185 .50093 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .714 .757 r
.5 .5 m
.5 .5 .34314 0 365.73 arc
F
1 g
.5 .5 m
.5 .5 .11765 0 365.73 arc
F
0 g
.5 Mabswid
.5 .44098 m
.50526 .44118 L
.51961 .4434 L
.53922 .45121 L
.55285 .46078 L
.55882 .46634 L
.5685 .48039 L
.57581 .5 L
.5768 .51961 L
.57145 .53922 L
.55882 .55723 L
.55694 .55882 L
.53922 .57017 L
.51961 .57549 L
.5 .57552 L
.48039 .57057 L
.46078 .55918 L
.46032 .55882 L
.44267 .53922 L
.44118 .53653 L
.43431 .51961 L
.43245 .5 L
.43704 .48039 L
.44118 .4705 L
.4498 .46078 L
.46078 .45192 L
.48039 .44341 L
.49451 .44118 L
.5 .44098 L
s
.44118 .4171 m
.46078 .40842 L
.48039 .40388 L
.5 .40275 L
.51961 .40479 L
.53922 .4101 L
.55882 .41915 L
.56296 .42157 L
.57843 .43289 L
.58714 .44118 L
.59804 .45432 L
.60221 .46078 L
.61173 .48039 L
.61682 .5 L
.61765 .50666 L
.61798 .51961 L
.61765 .52461 L
.61517 .53922 L
.60788 .55882 L
.59804 .57453 L
.5947 .57843 L
.57843 .59341 L
.5717 .59804 L
.55882 .6047 L
.53922 .61124 L
.51961 .61407 L
.5 .61365 L
.48039 .61003 L
.46078 .60298 L
.45089 .59804 L
.44118 .59186 L
.42501 .57843 L
.42157 .57495 L
.40897 .55882 L
.40196 .54684 L
.39882 .53922 L
.39314 .51961 L
.39144 .5 L
.39371 .48039 L
.4004 .46078 L
.40196 .45741 L
.41262 .44118 L
.42157 .43146 L
.4339 .42157 L
.44118 .4171 L
s
.44118 .38187 m
.46078 .37586 L
.48039 .37269 L
.5 .3721 L
.51961 .37397 L
.53922 .37834 L
.55164 .38235 L
.55882 .38539 L
.57843 .39552 L
.58826 .40196 L
.59804 .40951 L
.61093 .42157 L
.61765 .42904 L
.62677 .44118 L
.63725 .45929 L
.63795 .46078 L
.64545 .48039 L
.64971 .5 L
.65093 .51961 L
.64909 .53922 L
.64398 .55882 L
.63725 .57466 L
.63508 .57843 L
.62133 .59804 L
.61765 .60217 L
.60025 .61765 L
.59804 .61924 L
.57843 .63078 L
.56263 .63725 L
.55882 .63842 L
.53922 .643 L
.51961 .64489 L
.5 .64427 L
.48039 .64119 L
.46524 .63725 L
.46078 .63554 L
.44118 .62706 L
.42514 .61765 L
.42157 .61517 L
.40196 .59876 L
.40124 .59804 L
.38462 .57843 L
.38235 .57522 L
.37286 .55882 L
.36489 .53922 L
.36275 .53519 L
.3602 .51961 L
.35857 .5 L
.35999 .48039 L
.36275 .4672 L
Mistroke
.36464 .46078 L
.37298 .44118 L
.38235 .4262 L
.38599 .42157 L
.40196 .40515 L
.40583 .40196 L
.42157 .39125 L
.43991 .38235 L
.44118 .38187 L
Mfstroke
.42157 .35844 m
.44118 .35131 L
.46078 .34669 L
.48039 .34431 L
.5 .34404 L
.51961 .34579 L
.53922 .34961 L
.55882 .35559 L
.576 .36275 L
.57843 .36394 L
.59804 .37502 L
.60866 .38235 L
.61765 .38946 L
.63115 .40196 L
.63725 .40848 L
.64785 .42157 L
.65686 .435 L
.6604 .44118 L
.66965 .46078 L
.67604 .48039 L
.67647 .48213 L
.6798 .5 L
.68105 .51961 L
.67978 .53922 L
.67647 .55815 L
.67587 .55882 L
.66906 .57843 L
.65884 .59804 L
.65686 .60116 L
.64434 .61765 L
.63725 .62523 L
.62369 .63725 L
.61765 .64178 L
.59804 .65375 L
.59179 .65686 L
.57843 .66235 L
.55882 .66822 L
.53922 .67172 L
.51961 .67306 L
.5 .67233 L
.48039 .66957 L
.46078 .66471 L
.44118 .6576 L
.43944 .65686 L
.42157 .64798 L
.40459 .63725 L
.40196 .63536 L
.38235 .61888 L
.38108 .61765 L
.36371 .59804 L
Mistroke
.36275 .59678 L
.35063 .57843 L
.34314 .56393 L
.34096 .55882 L
.33419 .53922 L
.33006 .51961 L
.32847 .5 L
.32938 .48039 L
.33293 .46078 L
.33933 .44118 L
.34314 .43245 L
.34905 .42157 L
.36275 .40217 L
.36292 .40196 L
.38235 .38255 L
.38259 .38235 L
.40196 .36857 L
.41237 .36275 L
.42157 .35844 L
Mfstroke
.44118 .32215 m
.46078 .31844 L
.48039 .3166 L
.5 .31654 L
.51961 .31822 L
.53922 .32166 L
.54727 .32353 L
.55882 .32692 L
.57843 .33413 L
.5974 .34314 L
.59804 .34348 L
.61765 .3553 L
.62805 .36275 L
.63725 .37013 L
.65055 .38235 L
.65686 .38892 L
.66795 .40196 L
.67647 .41361 L
.6816 .42157 L
.69221 .44118 L
.69608 .44977 L
.70021 .46078 L
.70585 .48039 L
.70927 .5 L
.71055 .51961 L
.70967 .53922 L
.70656 .55882 L
.70107 .57843 L
.69608 .59135 L
.69292 .59804 L
.68165 .61765 L
.67647 .62504 L
.66651 .63725 L
.65686 .64726 L
.64601 .65686 L
.63725 .66357 L
.61765 .67593 L
.61666 .67647 L
.59804 .68528 L
.57843 .69215 L
.56308 .69608 L
.55882 .69688 L
.53922 .69966 L
.51961 .70062 L
.5 .69982 L
.48039 .69728 L
.47362 .69608 L
.46078 .69295 L
.44118 .68675 L
.42157 .67852 L
Mistroke
.41734 .67647 L
.40196 .66801 L
.38513 .65686 L
.38235 .6548 L
.36275 .6382 L
.36176 .63725 L
.34375 .61765 L
.34314 .61689 L
.32962 .59804 L
.32353 .58788 L
.31861 .57843 L
.31026 .55882 L
.30429 .53922 L
.30392 .53831 L
.30056 .51961 L
.29899 .5 L
.29956 .48039 L
.30236 .46078 L
.30392 .45315 L
.30751 .44118 L
.31529 .42157 L
.32353 .40607 L
.3261 .40196 L
.34068 .38235 L
.34314 .37954 L
.36035 .36275 L
.36275 .36074 L
.38235 .34663 L
.38813 .34314 L
.40196 .33591 L
.42157 .32789 L
.43555 .32353 L
.44118 .32215 L
Mfstroke
.40196 .30389 m
.42157 .29731 L
.44118 .29257 L
.46078 .28954 L
.48039 .2881 L
.5 .28821 L
.51961 .28983 L
.53922 .29299 L
.55882 .29771 L
.57802 .30392 L
.57843 .30407 L
.59804 .31222 L
.61765 .32232 L
.61975 .32353 L
.63725 .33467 L
.64876 .34314 L
.65686 .34972 L
.67111 .36275 L
.67647 .3682 L
.68896 .38235 L
.69608 .39148 L
.70341 .40196 L
.71506 .42157 L
.71569 .42274 L
.72431 .44118 L
.73139 .46078 L
.73529 .47486 L
.73646 .48039 L
.73962 .5 L
.74091 .51961 L
.74033 .53922 L
.73783 .55882 L
.73529 .57152 L
.73331 .57843 L
.72659 .59804 L
.71743 .61765 L
.71569 .62084 L
.70541 .63725 L
.69608 .64963 L
.68987 .65686 L
.67647 .67044 L
.66964 .67647 L
.65686 .68645 L
.64229 .69608 L
.63725 .69902 L
.61765 .7089 L
.60052 .71569 L
.59804 .71653 L
.57843 .72219 L
.55882 .72608 L
Mistroke
.53922 .72832 L
.51961 .729 L
.5 .72814 L
.48039 .72576 L
.46078 .72184 L
.44118 .71632 L
.43923 .71569 L
.42157 .70909 L
.40196 .70002 L
.39457 .69608 L
.38235 .68885 L
.36436 .67647 L
.36275 .67525 L
.34314 .65864 L
.34126 .65686 L
.32353 .63806 L
.32285 .63725 L
.30796 .61765 L
.30392 .61155 L
.29593 .59804 L
.28635 .57843 L
.28431 .57363 L
.27897 .55882 L
.27361 .53922 L
.27018 .51961 L
.26862 .5 L
.26893 .48039 L
.27116 .46078 L
.2754 .44118 L
.28181 .42157 L
.28431 .41532 L
.29062 .40196 L
.30224 .38235 L
.30392 .37989 L
.31727 .36275 L
.32353 .35586 L
.33678 .34314 L
.34314 .33778 L
.36275 .32367 L
.36297 .32353 L
.38235 .31257 L
.40188 .30392 L
.40196 .30389 L
Mfstroke
.44118 .26088 m
.46078 .2584 L
.48039 .2573 L
.5 .25754 L
.51961 .25912 L
.53922 .26203 L
.5524 .26471 L
.55882 .26631 L
.57843 .27201 L
.59804 .27921 L
.60988 .28431 L
.61765 .28802 L
.63725 .29862 L
.64592 .30392 L
.65686 .31124 L
.67316 .32353 L
.67647 .32625 L
.695 .34314 L
.69608 .34421 L
.71296 .36275 L
.71569 .36606 L
.72787 .38235 L
.73529 .39365 L
.74024 .40196 L
.7504 .42157 L
.7549 .43174 L
.75858 .44118 L
.76492 .46078 L
.76953 .48039 L
.77248 .5 L
.77378 .51961 L
.77345 .53922 L
.77144 .55882 L
.76769 .57843 L
.76209 .59804 L
.7549 .61672 L
.75449 .61765 L
.74463 .63725 L
.73529 .65238 L
.73219 .65686 L
.7166 .67647 L
.71569 .6775 L
.69699 .69608 L
.69608 .69688 L
.67647 .71237 L
.67168 .71569 L
.65686 .72491 L
.63725 .73507 L
.63677 .73529 L
.61765 .74319 L
Mistroke
.59804 .74953 L
.57843 .75425 L
.57545 .7549 L
.55882 .75747 L
.53922 .75927 L
.51961 .7597 L
.5 .7588 L
.48039 .75656 L
.47 .7549 L
.46078 .75297 L
.44118 .74799 L
.42157 .74156 L
.40582 .73529 L
.40196 .73359 L
.38235 .72391 L
.36805 .71569 L
.36275 .71236 L
.34314 .69861 L
.33986 .69608 L
.32353 .68225 L
.31737 .67647 L
.30392 .66256 L
.29892 .65686 L
.28431 .63826 L
.2836 .63725 L
.27088 .61765 L
.26471 .60659 L
.26041 .59804 L
.25195 .57843 L
.24534 .55882 L
.2451 .55802 L
.24048 .53922 L
.23729 .51961 L
.23575 .5 L
.23585 .48039 L
.23762 .46078 L
.24112 .44118 L
.2451 .42576 L
.24645 .42157 L
.25378 .40196 L
.26331 .38235 L
.26471 .37983 L
.27539 .36275 L
.28431 .35065 L
.29052 .34314 L
.30392 .32886 L
.30954 .32353 L
.32353 .31166 L
.33396 .30392 L
.34314 .2978 L
Mistroke
.36275 .28655 L
.36719 .28431 L
.38235 .27749 L
.40196 .27031 L
.42157 .26482 L
.42202 .26471 L
.44118 .26088 L
Mfstroke
.44118 .22468 m
.46078 .22267 L
.48039 .22186 L
.5 .22222 L
.51961 .22375 L
.53372 .22549 L
.53922 .22646 L
.55882 .23036 L
.57843 .23548 L
.59804 .24187 L
.60668 .2451 L
.61765 .24961 L
.63725 .25881 L
.64835 .26471 L
.65686 .26961 L
.67647 .28218 L
.67952 .28431 L
.69608 .29682 L
.7046 .30392 L
.71569 .31392 L
.72545 .32353 L
.73529 .33409 L
.74306 .34314 L
.7549 .35839 L
.75802 .36275 L
.77072 .38235 L
.77451 .38888 L
.78144 .40196 L
.79037 .42157 L
.79412 .43109 L
.79763 .44118 L
.80333 .46078 L
.80754 .48039 L
.8103 .5 L
.81162 .51961 L
.8115 .53922 L
.80992 .55882 L
.80684 .57843 L
.80219 .59804 L
.79586 .61765 L
.79412 .62229 L
.78772 .63725 L
.77756 .65686 L
.77451 .66206 L
.76511 .67647 L
.7549 .69009 L
.74995 .69608 L
.73529 .71192 L
.73144 .71569 L
.71569 .72962 L
Mistroke
.70852 .73529 L
.69608 .74425 L
.67913 .7549 L
.67647 .75642 L
.65686 .76653 L
.63815 .77451 L
.63725 .77485 L
.61765 .78157 L
.59804 .78684 L
.57843 .79076 L
.55882 .79341 L
.55099 .79412 L
.53922 .79482 L
.51961 .79505 L
.50023 .79412 L
.5 .7941 L
.48039 .79198 L
.46078 .78868 L
.44118 .78418 L
.42157 .77843 L
.41018 .77451 L
.40196 .77138 L
.38235 .76292 L
.36633 .7549 L
.36275 .75295 L
.34314 .7413 L
.33407 .73529 L
.32353 .72775 L
.30827 .71569 L
.30392 .71198 L
.28688 .69608 L
.28431 .69348 L
.26884 .67647 L
.26471 .67149 L
.25352 .65686 L
.2451 .64457 L
.24049 .63725 L
.22948 .61765 L
.22549 .60961 L
.22029 .59804 L
.21278 .57843 L
.20684 .55882 L
.20588 .55526 L
.20241 .53922 L
.19944 .51961 L
.19791 .5 L
.19781 .48039 L
.19917 .46078 L
.20203 .44118 L
.20588 .42365 L
Mistroke
.20646 .42157 L
.21255 .40196 L
.22044 .38235 L
.22549 .37177 L
.23031 .36275 L
.24244 .34314 L
.2451 .33932 L
.25723 .32353 L
.26471 .31491 L
.27526 .30392 L
.28431 .29542 L
.29752 .28431 L
.30392 .27942 L
.32353 .26614 L
.32588 .26471 L
.34314 .25509 L
.36275 .24594 L
.36475 .2451 L
.38235 .23847 L
.40196 .23251 L
.42157 .22794 L
.43519 .22549 L
.44118 .22468 L
Mfstroke
.40196 .18533 m
.42157 .18162 L
.44118 .17901 L
.46078 .17745 L
.48039 .17691 L
.5 .1774 L
.51961 .17889 L
.53922 .18139 L
.55882 .18491 L
.56526 .18627 L
.57843 .18948 L
.59804 .19514 L
.61765 .2019 L
.62786 .20588 L
.63725 .20986 L
.65686 .21909 L
.66905 .22549 L
.67647 .22967 L
.69608 .24177 L
.70105 .2451 L
.71569 .25557 L
.72739 .26471 L
.73529 .27131 L
.7497 .28431 L
.7549 .28935 L
.76888 .30392 L
.77451 .31025 L
.78551 .32353 L
.79412 .33487 L
.79996 .34314 L
.81251 .36275 L
.81373 .3648 L
.82333 .38235 L
.8326 .40196 L
.83333 .40365 L
.84039 .42157 L
.84681 .44118 L
.85192 .46078 L
.85294 .46525 L
.85574 .48039 L
.8583 .5 L
.85963 .51961 L
.85972 .53922 L
.85855 .55882 L
.85611 .57843 L
.85294 .59547 L
.85234 .59804 L
.84717 .61765 L
.84053 .63725 L
.83333 .65465 L
Mistroke
.83232 .65686 L
.82235 .67647 L
.81373 .69104 L
.81046 .69608 L
.79635 .71569 L
.79412 .71851 L
.77962 .73529 L
.77451 .74067 L
.75967 .7549 L
.7549 .7591 L
.73553 .77451 L
.73529 .77468 L
.71569 .78795 L
.70541 .79412 L
.69608 .79927 L
.67647 .8089 L
.66528 .81373 L
.65686 .81703 L
.63725 .82377 L
.61765 .82926 L
.59926 .83333 L
.59804 .83356 L
.57843 .83673 L
.55882 .83882 L
.53922 .83986 L
.51961 .83988 L
.5 .8389 L
.48039 .8369 L
.46078 .83389 L
.45769 .83333 L
.44118 .82984 L
.42157 .82472 L
.40196 .81851 L
.38881 .81373 L
.38235 .81116 L
.36275 .80257 L
.3458 .79412 L
.34314 .79269 L
.32353 .78136 L
.31279 .77451 L
.30392 .76846 L
.28576 .7549 L
.28431 .75375 L
.26471 .73694 L
.26293 .73529 L
.2451 .71759 L
.24332 .71569 L
.22633 .69608 L
.22549 .69504 L
.21156 .67647 L
Mistroke
.20588 .66814 L
.19874 .65686 L
.18764 .63725 L
.18627 .63463 L
.17815 .61765 L
.17011 .59804 L
.16667 .58841 L
.16348 .57843 L
.15818 .55882 L
.15415 .53922 L
.15138 .51961 L
.14986 .5 L
.14958 .48039 L
.15056 .46078 L
.15282 .44118 L
.1564 .42157 L
.16136 .40196 L
.16667 .38542 L
.16778 .38235 L
.17579 .36275 L
.1855 .34314 L
.18627 .34171 L
.19713 .32353 L
.20588 .31071 L
.21094 .30392 L
.22549 .28632 L
.2273 .28431 L
.2451 .26628 L
.24679 .26471 L
.26471 .24944 L
.27032 .2451 L
.28431 .23513 L
.29952 .22549 L
.30392 .22292 L
.32353 .21251 L
.33791 .20588 L
.34314 .20368 L
.36275 .1963 L
.38235 .1902 L
.39772 .18627 L
.40196 .18533 L
Mfstroke
.44118 .10703 m
.46078 .10598 L
.48039 .10576 L
.5 .10637 L
.51961 .1078 L
.52006 .10784 L
.53922 .11009 L
.55882 .11322 L
.57843 .11719 L
.59804 .12202 L
.61682 .12745 L
.61765 .12771 L
.63725 .13439 L
.65686 .142 L
.66871 .14706 L
.67647 .15061 L
.69608 .16033 L
.70783 .16667 L
.71569 .17118 L
.73529 .18329 L
.73983 .18627 L
.7549 .19679 L
.76703 .20588 L
.77451 .21182 L
.79065 .22549 L
.79412 .2286 L
.81141 .2451 L
.81373 .24744 L
.8298 .26471 L
.83333 .26874 L
.84616 .28431 L
.85294 .29314 L
.86074 .30392 L
.87255 .32163 L
.87373 .32353 L
.88525 .34314 L
.89216 .35614 L
.89543 .36275 L
.90434 .38235 L
.91176 .40108 L
.91208 .40196 L
.91865 .42157 L
.92414 .44118 L
.92859 .46078 L
.93137 .47624 L
.93198 .48039 L
.93433 .5 L
.93567 .51961 L
.93599 .53922 L
.93528 .55882 L
Mistroke
.93354 .57843 L
.93137 .59443 L
.93073 .59804 L
.9268 .61765 L
.92173 .63725 L
.91548 .65686 L
.91176 .66701 L
.90795 .67647 L
.89906 .69608 L
.89216 .70949 L
.8887 .71569 L
.87672 .73529 L
.87255 .74153 L
.86293 .7549 L
.85294 .76757 L
.84707 .77451 L
.83333 .7895 L
.82879 .79412 L
.81373 .80834 L
.80758 .81373 L
.79412 .82472 L
.78265 .83333 L
.77451 .83904 L
.7549 .85162 L
.75269 .85294 L
.73529 .86263 L
.71569 .8723 L
.71514 .87255 L
.69608 .88067 L
.67647 .88791 L
.66337 .89216 L
.65686 .89407 L
.63725 .89919 L
.61765 .90337 L
.59804 .90663 L
.57843 .90899 L
.55882 .91048 L
.53922 .91112 L
.51961 .91092 L
.5 .90988 L
.48039 .908 L
.46078 .90528 L
.44118 .90173 L
.42157 .89733 L
.40225 .89216 L
.40196 .89207 L
.38235 .88585 L
.36275 .87872 L
.34757 .87255 L
.34314 .87061 L
Mistroke
.32353 .86143 L
.30713 .85294 L
.30392 .85118 L
.28431 .83969 L
.27428 .83333 L
.26471 .82691 L
.24646 .81373 L
.2451 .81269 L
.22549 .79682 L
.22236 .79412 L
.20588 .77907 L
.20119 .77451 L
.18627 .7591 L
.18244 .7549 L
.16667 .73642 L
.16576 .73529 L
.15091 .71569 L
.14706 .71023 L
.13768 .69608 L
.12745 .6792 L
.1259 .67647 L
.11551 .65686 L
.10784 .64062 L
.10637 .63725 L
.09846 .61765 L
.09166 .59804 L
.08824 .58673 L
.08598 .57843 L
.08139 .55882 L
.07782 .53922 L
.07529 .51961 L
.07377 .5 L
.07329 .48039 L
.07383 .46078 L
.07542 .44118 L
.07808 .42157 L
.08183 .40196 L
.0867 .38235 L
.08824 .37699 L
.0928 .36275 L
.10015 .34314 L
.10784 .32561 L
.10884 .32353 L
.11901 .30392 L
.12745 .28955 L
.13076 .28431 L
.14431 .26471 L
.14706 .26104 L
.1599 .2451 L
.16667 .23737 L
Mistroke
.17785 .22549 L
.18627 .2172 L
.19866 .20588 L
.20588 .19974 L
.22306 .18627 L
.22549 .1845 L
.2451 .17114 L
.25227 .16667 L
.26471 .15942 L
.28431 .14913 L
.28859 .14706 L
.30392 .14017 L
.32353 .13239 L
.33769 .12745 L
.34314 .12572 L
.36275 .12011 L
.38235 .11547 L
.40196 .11176 L
.42157 .10895 L
.43099 .10784 L
.44118 .10703 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo08_ooooo0P000012ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<0
0000ooooooooool0R?ooool300000003ooooo`00003ooooo047ooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`26ooooo`8000000oooool00onY_NP000000000
0011ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0Pooo
ool3000000;ooooo1?nY_NP00`00003ooooo00000010ooooo`002Oooool01000003ooooooooooooo
oom900000003o`00000000000000064000001?ooool00`00003oooooooooo`20ooooo`<000000_oo
ool2ojZmi`GoZKgX00<00000ooooo`000000@?ooool000Wooooo00@00000ooooooooooooooooA`00
000I01TI6Dd000001?ooool00`00003oooooooooo`1nooooo`8000000oooool5ojZmi`08ojVmj?nZ
_NOoZ[gWojVmj000003oZKgXooooo`00000oooooo`002Oooool01000003ooooooooooooooom00000
02@06ATIB@000004ooooo`0300000?oooooooooo07_ooooo0`000002ooooo`coZ[gW00D00000ojZm
iooooooooooo0000000nooooo`002Oooool01000003ooooooooooooooolj00000003o`0000000000
000002X06ATI100000000ol0000000000000000o000000Cooooo00<00000ooooooooool0NOooool2
000000?ooooo3_nZ_NL01@00003oZ[gWojZmioooool0000003kooooo0009ooooo`0400000?oooooo
ooooooooocT00000<P0I6AU2000000Cooooo00<00000ooooooooool0M_ooool3000000;ooooo00?o
Z[cWojZmionZ_NL03_nZ_NL01P00003oZ[gWojZmionZ_NOooooo000003gooooo0009ooooo`040000
0?ooooooooooooooocH00000>00I6ATo000000Cooooo00<00000ooooooooool0M?ooool2000000;o
oooo1OnZ_>L2ojZmi`03ojZlionZ_NOoZ[gW00[oZ[gW00<00000ojZmionZ_NL00_nZ_NL00`00003o
ooooooooo`0kooooo`002Oooool01000003ooooooooooooooole000003d06ATI>`000004ooooo`03
00000?oooooooooo077ooooo0`000002ooooo`03ojZli_nZ_>OoZ[cW00SoZ[cW0_nZ_NL00onZ_>Oo
Z[gWojZmi`06ojZmi`0300000?nZ_NOoZ[gW00;oZ[gW00?ooooo00000?ooool0>oooool000Wooooo
00@00000oooooooooooooooo<00000000ol0000000000000001101TI6CT000001?ooool00`00003o
ooooooooo`1^ooooo`<000000_ooool5ojZliP;oZ[cW00?oZ[cVojZlionZ_>L00onZ_>L00onZ_>Ko
Z[cWojZli`02ojZli`;oZ[gW00?oZ[cWojZmionZ_NL00_nZ_NL00`00003oZ[gWojZmi`03ojZmi`03
ooooo`00003ooooo03[ooooo0009ooooo`0400000?ooooooooooooooobl00000A`0I6ATg000000Co
oooo00<00000ooooooooool0K?ooool2000000?ooooo00?oZ[_VojZli_nZ_>H02?nZ_>H2ojZli`04
oj^li_nZ_>KoZ[cVojZliP;oZ[cW00?oZ[cVojZlionZ_>L00_nZ_>L01OnZ_NOoZ[cWojZlionZ_NL0
000000GoZ[gW00<00000ooooooooool0>Oooool000Wooooo00@00000oooooooooooooooo;P00001;
01TI6C@000001?ooool00`00003oooooooooo`1Yooooo`<000000_ooool00onZ^nGoZ[_VojZkiP02
ojZkiP;oZ[cV00?oZk_VojZli_nZ_>H00onZ_>H00on[^nKoZkcVoj^liP02oj^liP03ojZli_n[_>Ko
ZkcV00?oZ[cV0_nZ_>L00on[_>KoZ[cWojZli`02ojZli`0300000?nZ_>OoZ[cW00;oZ[gW00?oZ[cW
ooooo`000000>_ooool000Wooooo00@00000oooooooooooooooo;000001?01TI6C8000001?ooool0
0`00003oooooooooo`1Wooooo`8000000oooool01?n[^nGoZ[_UojZkiOnZ^nD2ojZkiP03oj^kiOn[
^nKoZk_V00;oZk_V00?oZ[cVoj^kiOn[^nD00on[^nH2oj^liP03oj^ki_n[_>KoZkcV00;oZkcV00?o
Z[cVoj^li_n[_>H00on[_>H2ojZli`03oj^liP00003oZ[cW00;oZkcV0onZ_>L00oooool00000oooo
o`0hooooo`002Oooool01000003ooooooooooooooolZ000005<06ATI<0000004ooooo`0300000?oo
oooooooo06Cooooo0`000002ooooo`03oj^jiOn[^nGoZk_U00;oZk_U00?oZ[_Uoj^jiOn[^^D00on[
^nD2oj^kiPGoZk_U00?oZk_Voj^kiOn[^nD00on[^nH2oj^liP03oj^kiOn[_>KoZkcV00OoZkcV00<0
0000oj^li_n[_>H00_n[_>H01?nZ_>OoZkcVooooo`00000iooooo`002Oooool01000003ooooooooo
oooooolY000002D06ATI2`00000V01TI6Bh000001?ooool00`00003oooooooooo`1Rooooo`800000
0oooool01?n[^^CoZk[Uoj^jiOn[^^D2oj^ki@03oj^ji?n[^^GoZk[U00;oZk[U00?oZk_Uoj^ji?n[
^^@01On[^nD00on[^^CoZk_Uoj^ki@02oj^ki@03oj^ki_n[^nGoZk_U00?oZk_U00KoZkcVoj^kiOn[
^nGoZk_Uoj^li_n[_>D2oj^liP0300000?n[_>KoZkcV00GoZkcV00?ooooo00000?ooool0=oooool0
00Wooooo00@00000oooooooooooooooo:000000O01TI6@L000002`0c<c<7000002006ATI00?o0000
000000000000:P000004ooooo`0300000?oooooooooo05oooooo0`000002ooooo`;oZkWT0on[^^@0
0on[^^GoZkWToj^ii003oj^ji0;oZk[U00?oZkWToj^ji?n[^^@00_n[^^@00on[^nGo[;[Toj^ji003
oj^ji0;oZk_U00?o[;[Toj^kiOn[^nD00on[^nD2ojbki@;oZk_U00Oo[;_Uoj^liOn[_>GoZkcUoj^l
iP00003oZkcU00OoZkcV00?ooooo00000?ooool0=_ooool000Wooooo00@00000oooooooooooooooo
9@0000000ol00000000001TI6@0K01TI6@0400000?l0003o0000000001T0<c<c00<00000o`000000
00001000000J01TI6B`000001?ooool00`00003oooooooooo`1Mooooo`8000000oooool5oj^ii003
oj^ji?n[^N?oZkWT00?oZkWT00?oZk[Toj^ihon[^N<00on[^N@2oj^ji004ojbihon/^^Co[;[Tojbj
i0;oZk[T1On/^^@00on[^nGo[;[Tojbji007ojbki@04oj^liOn/^nGo[;_U000000;oZkcU0_n[_>H0
0on/_>KoZkcVoj^liP02oj^liP0300000?oooooooooo03Gooooo0009ooooo`0400000?oooooooooo
ooooob@00000700I6AT3000002@0<c<c0`00000I01TI6BX000001?ooool00`00003oooooooooo`1J
ooooo`<000000_ooool2ojZhh`GoZkWT00CoZkSSoj^ihon[^N?oZkWS0_n[^N@00on[^>;oZkWSoj^i
h`02oj^ih`03oj^ii?n/^>;o[;WS00?o[;WS00?o[;[Tojbihon/^N<01On/^^@00on/^^?o[;[Tojbj
i002ojbji003ojbkiOn/^nCo[;_T00;o[;_U00Oo[;_TojbkiOn/^nGo[;_U00000?n[_>Go[;_U00Co
[;cV0_n[_>H00on/_>Kooooo0000000fooooo`002Oooool01000003ooooooooooooooolS000001X0
6ATI0`00000Z03<c<`030000000I6AT06ATI01L06ATI:@000004ooooo`0300000?oooooooooo05Oo
oooo0`000003ooooo`GoZ[SS00?oZkWToj^gh_n[^><00on[^><00on[^N?oZkORoj^ghP03oj^hhP;o
ZkWS1?n/^>82ojbih`03ojbhh_n/^N?o[;WS00;o[;WS00?o[;[Tojfih_n]^N800on/^^<2ojbji0;o
[K[S00?o[;_Tojfjhon]^^<00on/^n@2ojbki@0400000?n/^nGo[;_Uojbki@;o[;cV00?o[;cUojbl
i_n/_>H00_n/_>H00oooool00000ooooo`0dooooo`002Oooool01000003ooooooooooooooolQ0000
0003o`00000I6AT06ATI01D06ATI00@00000o`00000000000000;P0c<c<4000001L06ATI00?o0000
00000000000090000004ooooo`0300000?oooooooooo05Gooooo0P000003ooooo`;oZ[OR1OnZ^><4
oj^ghP;oZkSS00?oZkKQoj^gh_n[]n800_n[]n800on[^>;o[;OQojbgh@04ojbhhP;o[KOQ0on/^>82
ojbih`03ojfhhOn]^N;o[KWR00;o[KWR00?o[;[Sojfih_n]^N800_n]^^<00on]^N;o[K[Sojfjh`02
ojfjh`07ojbki?n]^^?o[K_Tojfki000003o[K_Tojbki@02ojfki0?o[;cU0_n/_>H2ojbli@030000
0?oooooooooo03?ooooo0009ooooo`0400000?ooooooooooooooob4000005`0I6AT00`000000<c<c
03<c<`0d03<c<`8000005P0I6ATV000000Cooooo00<00000ooooooooool0D_ooool3000000?ooooo
1OnZ]n800onZ^>?oZkKQoj^fh@04oj^ghP;oZkKP0on[]^42oj^ghP03ojbfh?n/]n7o[;OQ00;o[;OQ
00?o[;SRojffh?n]]n400on]]n400on/^>;o[KOPojfgh003ojfhh@;o[KWR00Go[KSQojfih_n]^N;o
[KWRojjhh@03ojfihP;o[K[S00Oo[[WRojfjhon]^^?o[K[Sojfki000003o[K_S00Co[K_T00?o[;cU
ojfliOn]_>D00_n/_>D00on]_>Gooooo0000000dooooo`002Oooool01000003ooooooooooooooolP
000001H06ATI0P00000i03<c<`030000000I6AT06ATI01@06ATI9@000004ooooo`0300000?oooooo
oooo053ooooo0P000003ooooo`;oZ[KR1OnZ]n800onZ]N7oZkKQoj^fh@02oj^fh@03oj^gh_n[]N3o
ZkKP00?oZkKP00?oZkKQojbdgon/]=l00on/]^02ojbgh@04ojfegon]]^3o[KKPojffh0;o[KOQ00?o
[KKOojfgh?n]]n000_n]]n000on]^>7o[[OPojfhh@03ojfhh@06ojfih_n^^>7o[[SQojjhhOn]^N;o
[[WQ1?n^^N801?n]^^?o[[[RojjjhP000002ojfkh`?o[K_T1on]_>D00`00003oooooooooo`0boooo
o`002Oooool01000003ooooooooooooooolO000001D06ATI0P00000H03<c<`/000006@0c<c<20000
01D06ATI90000004ooooo`0300000?oooooooooo04gooooo0`000003ooooo`;oZKKR0onZ]^800onZ
]n;oZ[CPojZdh003ojZeh@;oZkKQ00CoZkCOoj^eh?n[]N3oZkGP0_n[]^000on//mko[;COojbdg`02
ojbdg`03ojbfh?n]]=ko[KGO00?o[KGO00?o[KKPojfdg_n]]=h00on]]]l2ojfgh004ojjfg_n^]n3o
[[OPojjgh0;o[KSQ0_n^]ml2ojjhh@04ojnggon^^N7o[[WQojjih@;o[[WR00Oo[kWQojjjh_n^^^;o
[[[R00000?n]^n?o[[[S00Co[K_T00?o[KcUojfki?n]^n@00_n]_>D00on]_>Cooooo0000000coooo
o`002Oooool01000003ooooooooooooooolN000001@06ATI00<00000o`00000c<c<04P0c<c<40000
00;o000000<0000004a<C01<C4`02@1<C4`300000004o`00000000000000000001@0<c<c0P00000D
01TI6@03o`00000000000000020000001?ooool00`00003oooooooooo`1;ooooo`8000001?ooool5
ojVfhP03ojZfh_nZ]>3oZ[CP00?oZ[CP00?oZ[GQoj^cg_n[/mh00on[]=l00on[]N3o[;;Mojbbg@03
ojbcgP;o[;CO00Co[K;Mojfdg_n]]=ko[KCN0_n]]Ml00on^/mgo[KCNojfdgP02ojfdgP03ojffgon^
]=go[[KN00?o[[KN00?o[[OPojnfg_n_]]h00on^]ml4ojngg`03ojjihOn_^=oo[kSO00?o[kWQ0_n^
^^801000003o[[[Sojjjhon^^^<2ojfki0;o[[_S00?o[K_Tojjkhon^^n<00on]_>@00oooool00000
ooooo`0aooooo`002Oooool01000003ooooooooooooooolM000001@06ATI00<0000003<c<`0c<c<0
400c<c<3000001T0C4a<1000000B03<c<`800000500I6ATQ000000Cooooo00<00000ooooooooool0
B?ooool3000000?ooooo0_nY]N85ojVfhP03ojVch?nZ]>3oZ[CP00?oZ[CP00?oZ[;Noj^cg_n[/mh0
0_n[/mh00on[]=ooZk7Mojbbg@03ojbbg@03ojbcg_n//Mco[;7L00?o[K;M00?o[KCNojfbfon]/]/0
0on^/md2ojfdgP04ojjcg?n^]=go[[CMojjdg@;o[[KN00?o[kCLojnfg_n_]]h00_n_]]h00on^]moo
[kKNojnfgP02ojngg`03ok2gg_n_^=oo[kSO00;o[kSO00Oo[kWQok2hgon_^N7o[kWQ00000?n_^N7o
[[[S00;o[k[R0_n^^n<00on_^n;o[[_Sojjkh`02ojjkh`04ojfli?n^_>Cooooo000003;ooooo0009
ooooo`0400000?oooooooooooooooa`000004`0I6AT200000100<c<c0`00000P04a<C0<000004@0c
<c<00`0000006ATI01TI6@0B01TI6B0000001?ooool00`00003oooooooooo`15ooooo`<000001?oo
ool5ojVehP03ojVfh_nY/n3oZK?P00?oZK?P00?oZ[CPojZag_nZ/Mh00onZ/]h2oj^cgP04oj^`g?n[
/MgoZk7Moj^ag@;o[;;M00?o[;3Kojbag?n//M`00_n//M`00on]/]go[K3Jojfbf`03ojfbf`03ojjc
gOn^/M[o[[?L00?o[[?L00?o[[CMojncfon_/m/00on_]=`2ojnfgP05ok2dg?n_]]ko[kKNojnfg_na
]M`00on`]mh2ojnhg`07ok6gg_n`^=oo/;SOok2hgon_^N400000ok2ih003ojnjhP04ok2jhOn_^n;o
[k_RojnkhP;o[[_S00Ko[k_Sojjli?n^_>Co[[cTooooo`00000aooooo`002Oooool01000003ooooo
oooooooooolJ00000003o`00000I6AT06ATI01406ATI00<0000003<c<`0c<c<0300c<c<01000003o
000000000000000V04a<C00400000?l000000000000000h0<c<c00?o00000000000000004P0I6AT0
0ol0000000000000000L000000Cooooo00<00000ooooooooool0@oooool2000000Gooooo00?oZ;GR
ojVeh_nY]N800onY]N86ojVch003ojVagOnZ/MkoZ[7N00;oZ[7N00?oZ[;Noj^_fon[/=`00on[/=`0
0on[/Mgo[:oJojb`f`03ojb`f`;o[;7L00Co[JoIojf`f_n]/=[o[K3J0_n]/]/01?n^[mWo[[7Jojja
f_n^/MX2ojjcg003ok2afOn_/m_o[k?K00;o[k?K00?o[kCLok2cf_n`]=`00on`]=`01_n_]]ko/KGL
ok6eg?na]Mco/;ONok6fg0Co/KON00Co/;SOok6hg_n`^N0000000_n`^N001_n_^^;o/;[Qok2jhOn`
^^7o[k_Rok2kh@Co[k_S00Go[[cTojnlhooooooooooo0000000`ooooo`002Oooool01000003ooooo
oooooooooolK000001806ATI00?o000003<c<`0c<c<0300c<c<00`000000C4a<04a<C00/04a<C080
00003`0c<c<00`0000006ATI01TI6@0?01TI6Al000001?ooool00`00003oooooooooo`10ooooo`<0
00001?ooool5ojRehP03ojVeh_nX/^3oZ;;P00GoZK?P00CoZK3MojVagOnY/MgoZK7M0_nZ/Mh01?nZ
[m_oZjoKoj^_fon[[m/2oj^`g004oj^^fOn/[m[o[:oJojb_fP?o[;3K1?n][mT00on]/=[o[ZkGojj_
f@03ojj_f@03ojjaf_n_[mOo[joG00?o/;7I0_n_/m/01?na/MSo/;?Jok2cf_n`/mX2ok2dg005ok6c
f_na]Mco/KGLok6eg?nb]=X00ona]]`2ok6ggP06ok:gg?na^=ko/KSNok6hgP00003o/;WP0_na^Ml2
ok2jh@04ok6jgon`^n7o/;_Qok2kh@;o[k_S00Ko/;_Rojnlhon__>?o[kcSooooo`00000`ooooo`00
2Oooool01000003ooooooooooooooolJ000001806ATI00<0000003<c<`0c<c<02`0c<c<2000001H0
C4a<1000000G04a<C08000003P0c<c<00`0000006ATI01TI6@0?01TI6Ah000001?ooool00`00003o
ooooooooo`0nooooo`8000001Oooool6ojRehPGoZ;;P00?oZK?PojR`gOnX/=d00onY/=d00onY/Mgo
ZJkKojV^f`03ojZ_f`03oj^_fon[[=WoZjkI00?oZjkI0on/[mX00on//=_o[JgHojf]f002ojf_f@04
ojj/e_n^[]Oo[ZkGojj^e`?o[ZoI1?n_[mL00on`/MWo/JoFok6af003ok6af003ok2cf_nb/MSo/[7H
00?o/K?J00Ko/KGLok:df_nb]=[o/[CJok6fg?nc]MX4ok:gg003ok6hg_nb^=d0000000?o/KWO1?na
^]l00on`^n7o/K_Qok2khP03ok2khP05ojnlhon`_>?o/;cSooooo`000000;oooool000Wooooo00@0
0000oooooooooooooooo6@00000B01TI6@030000000c<c<0<c<c00/0<c<c00<0000004a<C01<C4`0
3`1<C4`7000000@0IVIV2P00000?04a<C08000003@0c<c<00`0000006ATI01TI6@0?01TI6Ad00000
1?ooool00`00003oooooooooo`0kooooo`<000001Oooool00onX]N?oZ;GRojRehP03ojRehPKoZ;;P
1OnX/=d00onY/=goZJgKojV^f`03ojV^f`03ojZ_fonZZmSoZjcI00;oZjcI0on[[]T2ojb_fP05ojb/
eon][MSo[JgHojf]f?n][mT00on^[=H3ojj^e`03ojj_fOn_[MKo[jgF00;o[joG00Co/JgDok6_e_na
[mKo/JoF0_na/MP00onb[mKo/[7Hok:af002ok:af003ok6cf_nc/]So/[CJ00;o/[CJ00Co];?Hok>e
f_nc]M[o/kGJ0_nb]m`01_nc]]_o/[SMok:hg@00003o/[SMok6ig`;o/kWN0_na^]l01?nc^]ko/K_Q
ok6khOna^n42ok2khP;o/K_Q00Go/;cSok2lh_n`_>;ooooo0000000^ooooo`002Oooool01000003o
oooooooooooooolG00000003o`00000I6AT06ATI00l06ATI00?o00000000000c<c<02P0c<c<00`00
003o00000000000>04a<C0@000005@1VIVH01?l00000000000000000000=04a<C003o`00000c<c<0
<c<c00/0<c<c00?o000001TI6@0I6AT03`0I6AT00ol0000000000000000I000000Cooooo00<00000
ooooooooool0>Oooool2000000Gooooo0_nW]^<3ojReh`03ojReh_nW/^7oYk;Q00GoZ;;P00?oYk3N
ojR`gOnX/=d00onX/=d01?nX[M_oZJgKojV]fonY[M/2ojV^f`04ojV[f?nZZmSoZZ_HojZ[f0?oZjcI
00?oZjkIoj^Ze_n[Z]H00on/[=L00on][MSo[J[DojfZe003ojj/eP;o[ZkG00Go[j_Dojn]e_n_[MKo
[jgFojn_e`03ok6]e0;o/JoF1?nb[mH2ok:af005ok>`eOnc/]So/k;Hok>bf?nb]=X00ond/mP00onc
]M[o];CHokBdf003ok>ff`06ok:hg@00003o];OKokBgfonc^Mko];WL1?nc^]h00ona^n7o/[_Pok6k
h@02ok6kh@03ok:lhOn`_>;o/;cR00;o/;cR00<00000ooooooooool0;?ooool000Wooooo00@00000
oooooooooooooooo6000000@01TI6@030000000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`0301<
C4`3000001d0IVIV0`00000;04a<C0800000300c<c<2000001006ATI6`000004ooooo`0300000?oo
oooooooo03Kooooo0`000003ooooo`03ojNfi?nW]^?oYkKS00CoYkKS00?oZ;GSojNchOnW/n400onW
/^400onX/^3oYk3NojN`gP03ojN`gP03ojR`gOnW[=_oYjcK00?oZ:gK00?oZJgKojRZf?nYZmP00onY
ZmP2ojZ[f0;oZjcI00?oZjWEoj^Ze_n[Z]H00_n[Z]H00on/[=Oo[JWCojfZe003ojfZe003ojj/e_n^
ZM;o[j_D00?o[j_D00?o[jgFok2[d_n`Zm800ona[M@00ona[mKo/ZgCok:]d`03ok:_ePCo/k3E00?o
/k;HokBaeOnd/MD00ond/mP4okBdf006ok>ffone]]Wo];OK00000?nd]m_o][OJ0ond^M`2ok>jgP05
okBjg_nb^n3o/[_Pok:kh?na^n400onb_>42ok2lhP03ok6lh_ooool0000002gooooo0009ooooo`04
00000?oooooooooooooooaL00000400I6AT00`000000<c<c03<c<`0:03<c<`030000001<C4`0C4a<
00X0C4a<0`00000S06IVIP<000002P1<C4`2000000`0<c<c00<0000001TI6@0I6AT03P0I6ATJ0000
00Cooooo00<00000ooooooooool0<oooool3000000Cooooo00CoYkOTojNfi?nW]^CoYkKT0_nW]^<0
0onV/n;oYk?QojNch@04ojNch@03ojNbhOnW/=koYk3N00CoYk3N1OnW[=/00onX[M_oZ:WHojRZf002
ojRZf0?oZJ_H00?oZZ_HojZXeOnZZ=D00on[ZMD2oj^ZeP04ojbWd_n]ZM?o[JWCojfYd`;o[J[D00Co
[ZOAojjYd_n^ZM;o[ZWB0_n_Zm@00on`Z=7o/:_Bok2[dP02ok2[dP03ok6]e?nbZm7o/ZgC00?o/ZgC
00?o/ZoFok>^donc[]<00_nc/=D00one[m?o];7EokBae@02okBae@03okBcf?nf/]Ko][;F00;o];CH
00Go][CFokFffOne]]Wo]KKI00000003okJgfP03okBig?nf^M_o][WK00?o];[N00Ko/[_PokBkgond
^moo];_Ook:lhOnc_>04ok6lhP0300000?oooooooooo02_ooooo0009ooooo`0400000?oooooooooo
oooooaH00000400I6AT00`000000<c<c03<c<`0903<c<`0300000?l00000C4a<00X0C4a<0P00000Y
06IVIP03o`00001<C4`0C4a<00T0C4a<0P00000;03<c<`03o`00000I6AT06ATI00h06ATI6@000004
ooooo`0300000?oooooooooo037ooooo0P000004ooooo`GoYkOT00?oYkKTojJdh_nV]>800onV/n84
ojNch@03ojJ`gonW/=koYk3N00?oYk3N00?oYZcKojN/fonW[=/00onW[=/01?nWZMSoZ:WHojRYf?nX
ZMP3ojRZf003ojV[f?nYYmCoZZSE00?oZZSE00?oZjWEoj^Ud_n[YM800on/Ym800on]ZM?o[JG@ojjW
d@03ojjWd@03ojjYd_n_Y/oo/:SA00?o/:SA0_n`Zm801?naZ<oo/Z_Aok:[dOnbZm42ok:]d`04ok>[
d?nc[]?o/jkCok>^d`Co]JoC0_nd/MD01Onf/=?o][;FokJbe_nf/]Ko];CH00?o][CF00Ko]KKIokNf
eonf]mX00000okJgf_ng]mT4okJif`03okBjg_nf^]go];_O00;o];_O00Co]K_Nok>lh?nc_>3o/kcP
0_na_>82ok:mhP0300000?oooooooooo02[ooooo0009ooooo`0400000?oooooooooooooooa@00000
00?o000001TI6@0I6AT03`0I6AT00ol00000<c<c03<c<`0803<c<`030000001<C4`0C4a<00T0C4a<
00<00000o`00001VIVH03P1VIVH?000000h0IVIV0P00000;04a<C0030000000c<c<0<c<c00T0<c<c
00<0000001TI6@0I6AT03@0I6ATI000000Cooooo00<00000ooooooooool0;_ooool3000000Cooooo
0_nW^>D4ojNgi003ojJdhonV]>;oY[CR00;oY[CR00?oY[?RojJah?nV/=l01OnV/=l00onW/=koYZcL
ojJ/g003ojJ/f`03ojN/fonVZ=SoYjWH00?oYjWH0_nXZMP2ojRZf004ojRVe?nYYmCoZJODojVWe0;o
ZZSE00?oZZCAoj^Ud_n[YM800_n[YM800on/Ym;o[:C?ojfUd002ojfUd0?o[ZOA0on_Y/l3ok2Xd@Co
/JS?00?o/Z_Aok>Yc_ncZLh00oncZm000onc[]?o]Jc@okF/d003okF_d`Co][3C00?o][;FokNbdonf
]=H00_nf]=H01Onh/mCo]kKGokNfeong]]L0000000?o]kOI0_nf^M/01Ong^M[o][[MokJjgOnf^]go
];_O00?o]K_N00?o/kcPokBlh?nb_N800_nb_N800onc_N7ooooo0000000[ooooo`002Oooool01000
003ooooooooooooooolE000001006ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<C009
04a<C0030000001VIVH0IVIV00`0IVIV0`00000?07moO`<000003@1VIVH2000000X0C4a<00<00000
03<c<`0c<c<0200c<c<00`0000006ATI01TI6@0>01TI6AP000001?ooool00`00003oooooooooo`0/
ooooo`8000001Oooool5ojNhi@03ojNgi?nV]NCoY[CS00;oY[CS0_nV]>801?nU/N7oY[7PojJah?nV
/N04ojJ`g`03ojF]gOnV[=coYZcL00;oYZcL00?oYZcKojFXfOnVZ=P00_nVZ=P3ojNYf003ojRYf?nW
YMCoYjGD00?oZ:KD00?oZJODojVSdOnZY=400onZY=42oj^UdP04oj^Rc_n/Y<oo[:C?ojbTc`?o[JG@
00?o[ZOAojjTcOn^Y<d00on_Y/l00on`Z=7o/JK=ok6Vc@02ok6Xc`03ok>Vc?ncZLko/jW>00;o/jW>
00?o/j_@okFZcOne[=000one[=000one[m?o]jk@okN^d002okJ`d`05okR_dOng/]?o]k;CokNbdonf
]=H00onh/m@00ong]]Oo^KKF00000003okNgf@Co]kWJ00?o][[MokNjg?ng^]`00_ne^mh01Onf_=ko
];cPokBlh?nd_>3o/[gR00?o/kgQ00<00000ooooooooool0:Oooool000Wooooo00@00000oooooooo
oooooooo5000000@01TI6@030000000c<c<0<c<c00T0<c<c00<0000004a<C01<C4`01`1<C4`20000
00/0IVIV1000000E07moO`@000002`1VIVH00ol00000C4a<04a<C00804a<C0030000000c<c<0<c<c
00P0<c<c00<0000001TI6@0I6AT03@0I6ATH000000Cooooo00<00000ooooooooool0:Oooool30000
00;ooooo1OnW^NH4ojNhi@05ojJfi?nV]NCoY[GTojJei?nV]><00_nU/^83ojFah@03ojJah?nT[]ko
Y:kN00GoYJgM0_nV[=`4ojFXf@?oYZSH00?oYjWHojJUe?nWYM@00onWYM@00onXY]CoYj;@ojVSd@02
ojVSd@?oZZCA00CoZjGBoj^Rc_n[X/koZj;>0_n/Y<l2ojfUd004ojfRc?n^Y<go[ZC=ojjTc@;o[jK?
00Go/:C;ok6VcOnaY/go/JK=ok6Xc`03ok>Vc0;o/jW>00Co]JO;okFZcOneZ/go]J[=0_ne[=001?ng
Zlgo]jk@okN^d?ng[]04okR_d@03okNbdoni/M7o^K7A00?o^;?D0_ni]]H00`00003o^KKFokNgf@02
okVgf0;o]kWJ00Co^KWIokNjg?ng^]co]k[L1?nf_=h00ond_>3o][gOokJmg`02ok>mh@03okBnhOoo
ool0000002[ooooo0009ooooo`0400000?oooooooooooooooa@000003`0I6AT00`000000<c<c03<c
<`0903<c<`030000001<C4`0C4a<00H0C4a<0P00000:06IVIP0300000?l00000000001d0Ogmo0`00
000906IVIP8000002@1<C4`00`000000<c<c03<c<`0803<c<`03o`00000I6AT06ATI00d06ATI5`00
0004ooooo`0300000?oooooooooo02Oooooo0P000003ooooo`;oYk[V1?nW^NH5ojJgi@;oY[KT00?o
Y[GTojFch_nU/n800onU/^800onU/N7oY:oOojB_g`03ojB^gP?oYJgM0_nTZMX4ojFXf@04ojBTe_nU
Y=GoYJCEojFTe@?oYZGD0_nWYM@01?nVXM3oYj;@ojNRd?nWX]03ojVSd@03ojZTdOnZX<goZZ3=00?o
Zj;>00?o[:C?ojbPbon/X</00on]X/`00on^Y<go[j7:ok2Tb`03ok2Tb`03ok6VcOnbY<[o/ZC:00?o
/jK<00Co/jW>okFWboneYl_o]JO;0_neZ/d4okN[c@03okN^d?ni[Lko^Jg>00?o^:oA1?ni/M401_nh
/mCo^[?CokZcdoni]]H00000ok^fe0?o^KOH1?ni^MT00ong^]co^K_KokVkf`02okJlgP04okRmgOnf
_Moo][gOokJmg`Co];kQ00?ooooo00000?ooool0:?ooool000Wooooo00@00000oooooooooooooooo
5000000>01TI6@03o`00000c<c<0<c<c00T0<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV
06IVIP0706IVIP<000008`1oOgl3000000P0IVIV0P00000804a<C0030000000c<c<0<c<c00P0<c<c
00<0000001TI6@0I6AT0300I6ATG000000Cooooo00<00000ooooooooool09?ooool3000000?ooooo
00?oYk[WojNji_nW^^H00_nW^^H00onW^NKoY[SVojJgi@04ojJgi@04ojFei?nU]>?oYKCSojFdh`?o
YK?R00?oYK;RojB_h?nT[ml00onT[ml00onT[]koXj[Loj>Yf`02oj>Yf`?oY:WJ00?oYJSIoj>Te_nT
Y=H00_nTY=H3ojFTe@03ojJUe?nUX=7oYZ7@00?oYZ7@0_nWX]02ojVSd@03ojROcOnZX<goZZ3=00;o
ZZ3=00?oZj;>oj^Nb_n/X</00on/X</00on]X/co[Yo8ojnQbP02ojnQbP?o/:C;1?nbY<X00oncY/co
]:C9okFWb`03okFWb`03okFZcOngZ<_o]jS;00?o]j_=1?ni[Lh00onh[m7o^Zo>okZ_cP02okVad@06
ok^ad?nj/m?o^[?CokZcdonk]]@000000_nk]]@00oni]mSo^kSGok^he`02okVif@04ok^jfOni^m_o
^K_KokVkf`Co^;gM00?o][gOokNngong_]l00_nd_^400one_n7ooooo0000000Yooooo`002Oooool0
1000003ooooooooooooooolC000000l06ATI00<0000003<c<`0c<c<01`0c<c<2000000P0C4a<00<0
000006IVIP1VIVH01P1VIVH2000000d0Ogmo3`00000=07moO`030000001VIVH0IVIV00L0IVIV00<0
000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0803<c<`030000000I6AT06ATI00`06ATI5P00
0004ooooo`0300000?oooooooooo02;ooooo0P000004ooooo`04ojRkionW^^OoYk[WojNji`;oYk[V
00CoYkWVojJhi_nV^>KoY[SV0_nV]nD01OnU]^CoYKGTojFei?nU]NCoYKCS00;oY;7R0_nT/>43ojB_
h0;oY:oO00CoXj_Moj>Zg?nSZ]coXj[L0onSZM/00onTZM[oXZGGoj>TeP02oj>TeP?oY:CF00?oYJCE
ojBPdOnUX=400_nUX=43ojJQd003ojNRd?nWW/goYik=00?oZ9o=0_nZX<d01?nYWLWoZik:oj^Nb_n[
W/X2ojbPb`04ojfMaon^WlSo[Yo8ojjOb0?o[j7:00?o/:C;ok6Qb?naXLP00_nbY<X01?ncX/Ko]:C9
okBTbOndY<T2okFWb`03okJVb?ngZ<_o]jS;00;o]jS;00?o]j_=okVZboniZ//00_ni[Lh01?nj[<_o
^Zo>okZ_c_nj[lh4ok^ad006okZcdonl]=7o_;CA00000?nk]]Co_KKC0onk^=L01Onm^MKo^k[Iok^j
fOnk^]Wo^K_K00;o^[cK0_nh_Md2okVmg@03okNngonh_moo]KoQ00?o]KoQ00?ooooo00000?ooool0
9oooool000Wooooo00@00000oooooooooooooooo4P00000?01TI6@030000000c<c<0<c<c00L0<c<c
00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00T0Ogmo
00@00000o`000?l0000000003`2IVIT4000000X0Ogmo00?o00000000000000001`1VIVH00ol00000
C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT0300I6AT00ol00000
00000000000B000000Cooooo00<00000ooooooooool07oooool3000000Cooooo1?nX^nL00onW^^Oo
YkWVojNiiP03ojNiiP03ojJhi_nV]nGoY[OU00?oYKKT00?oYKGTojBbhonT/^<00onT/N82ojB`h@03
ojB_h?nR[=koXZcN00?oXj_M00?oXj[Loj6Vf_nRYMP00_nRYMP3oj:Ue`?oXjCF00?oY:CFoj>Pd_nT
X=400_nTX=43ojFPd@03ojJQd?nUWLgoYik=00?oYik=00?oZ9o=ojRKbOnYWLT00onYWLT2oj^NbP04
ojbPbon]WLOo[Ig7ojfMa`;o[Yo80_n_XLX01On`WlKo/J78ok6Qb?naXLSo/ZC:00?o/j;60_ndY<T4
okJVb0;o]jS;00Co^JO8okVZboniZ/_o^J[;1?nj[</00onj[lko_:o=okb_c@02ok^ad005okfbc_nl
]=7o_;CAokbdd@0000000onm]]<01Onk^=Oo_KWFokfie_nm^MKo^k[I00;o_K_H00?o^[cKokbmf_nl
_MX00oni_Md3okRog`;o]KoQ0_nf_n400oooool00000ooooo`0Vooooo`002Oooool01000003ooooo
oooooooooolA00000003o`00000I6AT06ATI00d06ATI00<0000003<c<`0c<c<01`0c<c<00`000000
C4a<04a<C00604a<C003o`00001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl3000001L0
VIVI0`00000:07moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000
<c<c03<c<`0803<c<`030000000I6AT06ATI00`06ATI50000004ooooo`0300000?oooooooooo01co
oooo0`000002ooooo`;oZ;cW1?nX^nL5ojNji`03ojNii_nV^>KoY[SV00GoY[OU00?oYKKTojBdhonT
]><00onT/^<00onT/N;oXZoPoj:]g`02oj:]g`?oXZcN00?oXj_Moj6WfonQY]X00_nQY]X3oj:Uf003
oj:UeonQX=CoXZ3C00;oXZ3C0onSX=800onTX=7oXi_>ojBLc@02ojBLc@?oYIg=0_nWW/d01?nVV/Wo
Z9_9ojRKbOnXVlT3ojVMb@03oj^Nb_n[VlKo[Ig700?o[Ig700?o[Yo8ojnLaOn`WlH00on`WlH00ona
XLSo/Yo5ok>RaP03ok>RaP03okBTbOnfXlKo]Z?600?o]ZK81?niYlP00oniZ/_o^j[8ok^Zb002okZ/
b`05okf/bOnl[lgo_:o=okb_cOnk/M000onm//h01_nl]=7o_[C@00000?nn]=3o_KKCokngdP?o_KWF
00Co_k[Eokfkf?nm^mSo_K_H1?nl_MX01?ni_Mgo^[kMokZngOnh_ml2okW0g`;o][oQ00?o]l3Qoooo
o`0000009oooool000Wooooo00@00000oooooooooooooooo4P00000>01TI6@030000000c<c<0<c<c
00L0<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo
00H0Ogmo0P00000M09VIV@8000002@1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<
00H0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0<01TI6A<000001?ooool00`00
003oooooooooo`0Jooooo`8000000oooool5ojRli`?oZ;_W1?nW^^L00onV^NKoY[SVojJhiP02ojJh
iP03ojJgiOnU]^GoY;GT00;oY;GT0onT]><00onT/^?oX[3Roj:_h002oj:_h0?oXZgO00?oXZcNoj2X
g?nQYm/00_nQYm/3oj6VfP03oj:Uf?nPXMGoXJ3D00;oXJ3D0onRX=<00onSX=;oXI_?oj>KcP02oj>K
cP?oY9c=00?oYIg=ojFIbOnVV/T00onVV/T2ojRKb@;oZIg900CoZIW6oj^Ka_n[VlKoZi_60on]WLL3
ojnLa@?o/9o60onbWlD3ok>RaPCo]Z?600?o]ZK8okRUaOnhYLD00_niYlP01OnjYlGo^j[8ok^Zb?nk
Z/So^Zc;00?o_Jc900?o_:o=okj_bonn[l/00onm//h2okjdd00300000?o1]/oo_kOB00;o_kOB00Go
_KWFoknjeOno^]Go_k[Eokfkf002okjlf0;o_;gJ0_nm_]X00onj_]go_<3MokW0g`02okW0g`06ok[1
gong`>7o]l3QokO0hOooool000009_ooool000Wooooo00@00000oooooooooooooooo4@00000>01TI
6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0606IV
IP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT07`2IVIT2000000P0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI
6@0I6AT0300I6ATC000000Cooooo00<00000ooooooooool05oooool3000000?ooooo0_nX_>P4ojRl
i`GoZ;_W0_nW^^L3ojJiiP;oY[SV00GoYKOUojFfiOnU]^GoYKKUojBei002oj>ch`;oXk7S0onR/>80
0onR[n3oX:_Ooj2[g`02oj2Zg@?oX:SL00?oXJOKoijSf?nOX]L00_nOX]L3oj2Qe@?oXJ3D00?oXZ3C
oj2Kd?nQVll00_nQVll3oj>KcP03ojBLcOnSV<WoYIW900;oYIW90onVV/T00onXVlWoZ9O5ojVIaP03
ojVIaP?oZi_600?o[Ig7ojfJa?n]V/@00on_W<D00on`WlKo/Ig3ok6M``03ok:Oa@03ok>Ra_neX<?o
]J3300;o]Z?600Go]j;3okRUaOnhYLGo^:G5okVWb003okZWa@;o^j[800Co_JW6okf/bOnm[<Wo_Jc9
1?nn[l/00onm//ko`;;=ol2bc@02000000;o`KK?00?o_kOBol6id_no^]D00_no^]D01?o1^mCo_[cH
okjlf?nn_=P3okfnfP05oko0f_nl`=go_<3Mokc0gOni`=l00onj`Ml01Ong`>7o^<7RokS1h_ooool0
000002Gooooo0009ooooo`0400000?oooooooooooooooa4000003P0I6AT00ol00000<c<c03<c<`07
03<c<`03o`00001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`00003o000007moO`05
07moO`0300000?l00000000000X0VIVI3`00000;09VIV@8000001`1oOgl00ol00000IVIV06IVIP05
06IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0<
01TI6A8000001?ooool00`00003oooooooooo`0Fooooo`0300000?l0003ooooo00;ooooo0_nY_>P3
ojRlj0?oZ;cW1?nX^nL4ojNji`03ojJii_nU^>KoYKSV00?oYKOU00?oYKKUoj>di?nS]>@00onS/n<2
oj>ah`03oj:`h_nP[N3oX:gP00?oX:_O0_nPZ]d00onPZ=coWZCJoijTfP02oijSf0?oWj;G00?oX:7E
oifLd_nOW=400_nOW=43oj2Kd0?oXI_?00?oXi_>oj6Gb_nSV<T00_nSV<T3ojFIb@03ojJJbOnVU/Go
Z9O500;oZ9O50onYVLH2oj^KaP04oj^H`on]V/Co[I[4ojfJa0;o[ic500Co[i[1ok6M`onaWL?o/Ig3
0_nbWlD01OncWL;o]J33okFP`oneX<?o]Z?600?o]j;30_nhYLD4okZWa@05ok^Zb?nmZLKo_JW6okfY
a_nm[<T00_no[LL2okj_b`08ol6`b@000000000000000?o1]/l00000ol6fcoo3]lh3ol6idP05oknj
eOo1^mCo`K_Dol6ke?nn_=P00_o0_]P01Onm_][o_l3Joko0f_no`=[o_<3M00;o_L7M0_nj`Ml01_nj
`^3o^<7RokS1h_nh`N;ooooo000002Gooooo0009ooooo`0400000?oooooooooooooooa4000003P0I
6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00@0C4a<00?o000006IVIP1VIVH01@1V
IVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00P0VIVI0`00000?0;>c/`<000002P2I
VIT00`000000Ogmo07moO`0507moO`8000001P1VIVH00`000000C4a<04a<C00604a<C0030000000c
<c<0<c<c00H0<c<c00<0000001TI6@0I6AT0300I6ATB000000Cooooo00<00000ooooooooool05_oo
ool00`00003oZKgXojVmj002ojVmj003ojVlj?nX_>SoZ;cX00?oZ;cX00?oZ;cWojRkionX^nL00onW
^nL00onW^^OoY[WWojJii`03ojJiiP;oYKSV00?oYKOUojBeiOnT]ND00onS]>@00onS/n?oXK3Soj6_
h@02oj6_h@?oX:gP00CoX:_OoijXgOnNY]_oWZKK1?nNY=X2oijSf003oinReonMWMCoWIcB00;oWIcB
0onOW=42oj2Kd0;oXI_?00CoWiO;oj6Gb_nQUl[oXIO:0_nSV<T2ojFIb@04ojBEaOnVU/GoYYK5ojJF
a@?oZ9O500?oZIW6ojVF`_n[V<<00on[V<<2ojfJa0Co[i[10_naWL<4ok>M`P;o]J331?ngX/<00onh
YLGo^ZC3okZT``03okZWa@?o_JW600Co_j[4okn]aono[LOo_jg70`0000001_o1/<Wo`;;=ol:cc?o2
/lco`KK?000000;o`kO>00?o`KWBol>jdOo3^]400_o1^m@01?o3_MCo`;kHol2nf?o0_]P3oko0fP04
ol31fonm`Mgo_L7Mokg1g@Co^/;P00Go^<7RokS2h_nh`^;ooooo0000000Tooooo`002Oooool01000
003oooooooooooooool@000000h06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C005
04a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@06
09VIV@<000005@2c/k<4000000L0VIVI0P00000707moO`030000001VIVH0IVIV00@0IVIV00<00000
04a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0603<c<`030000000I6AT06ATI00`06ATI00?o0000
0000000000003P000004ooooo`0300000?oooooooooo01Kooooo00@00000ojVmj?nY_NSoZKgX0_nY
_>P4ojRlj0;oZ;cW0onX^nL00onW^nOoYk[WojJii`03ojJii`03ojJii_nU]nKoY;KV00;oY;KV0onT
]ND00onS]>CoX[;Toj6`h`02oj6`h`03oj6_hOnN[>3oWZcP00;oWZWO0onNZ=d2oijVf`;oWZCJ00?o
Vj3HoibNe_nLW]H00onMWM@3oifLdP04oinLdOnLUlkoWYO<oijGc0CoWiO;0_nQUlX00onSV<WoXY?6
ojBEa@03ojBEa@;oYYK50_nXUlD01?nWU<;oZIK2ojVF`_nYU/83oj^H``03ojfJa?n^V<3o[i[100?o
[i[100?o/Ig3ok:K`?nbVl000oncWL800oneX<?o]Yo1okJO`@03okNR``Co^ZC300Co^ZO5okfW`onm
Yl?o_JW60_noZ/@3000000?o`K3900So`k78ol:cc?o2/lco`[?<olFeboo3]lh00000ol>gcP?o`k[A
1?o3_M@01?o0_]So`[oHol:of?no`=X3ol31f`03okg1gOnn`mko_/?N00;o^/;P0_nk`n001?nh`^;o
^<?RokS3hP00000Tooooo`002Oooool01000003oooooooooooooool?000000h06ATI00<0000003<c
<`0c<c<01`0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV00?o000007mo
O`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@800000702c/k<2000000L0VIVI0P00000607mo
O`03o`00001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c
<`03o`00000I6AT06ATI00`06ATI40000004ooooo`0300000?oooooooooo01Kooooo00<00000ojVm
j?nY_NP00_nY_NP2ojVlj0CoZ;cX0_nX_>L00onX^nOoYk_WojNki`02ojNji`;oY[WW00GoYKSVojFg
i_nU]nKoYKOVojBfiP02oj>ei@?oX[?T0_nR/^@00onQ/>?oWjgRoin]hP03oij/h0;oWZWO00?oWZSM
oi^TfonKX]T00_nKX]T3oi^Pf0;oW9kF0_nMWM@2oifLdP04oi^HconLUlkoW9O>oibGcP;oWYO<0onO
Ul/00onQUl[oX9?6oj:CaP02oj:CaP?oY9G500?oYYK5ojFB`_nWU<800onWU<82ojVF`P;oZiS300Co
[9JoojjH`?n^V<3o[YS00_n_V/400on`V;ko/Y_0ok:K`002ok:K`003ok>M`_neW;oo]Yo100?o]Yo1
00?o]j;3okVQ`OniXL400_njY<<01?nlY<7o_JO3okfW`onmYl<300000005oknZa?no[LOo`Jg6ol6]
a_o1/<T00oo3/LP02?o2/lcoaKG;olFeboo5]L_o`kO>00000?o5^Lko`k[A0_o6_=42ol>me0;oaKoD
00?o`[oHol?1f?o3`MP00_o0`M/2ol73f`03okk3g_noa=ko_lCN00;o^l?P00Ko_<CQokS3h_nh`n;o
^<?Rooooo`00000Sooooo`002Oooool01000003oooooooooooooool?000000h06ATI00<0000003<c
<`0c<c<01`0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV00<0000007mo
O`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c01h0/k>c0P00000709VI
V@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6AT@000000Cooooo00<00000oooo
ooooool05Oooool01@00003oooooooooooooooooZKgX00OoZ;cX1?nW^nL2ojJji`?oY[WW0_nU^>H0
0onU]nKoY;KVojBfiP03oj>ei@03oj:ci?nP/NCoWjoS00;oWjoS0onO[N801?nN[>3oW:SOoi^VgOnK
Y]d3oi^Tf`?oVj;I0_nKX=P00onLW]KoVI[CoiZId@02oiZId@?oViS?0_nLUlh3oijGc003oinGbonN
T/OoX9?600;oX9?60onRTlH00onTULGoXi72ojFB`P02ojFB`P?oYiC200?oZIK2ojVC_on/U[l00on/
U[l2ojjH`004ojnJ`On`V;ko/9Rnok2H_P;o/Y_000Co/iZmokFL_oneW;oo]Ibo0_nfWl401OnhW[ko
^J71okVQ`OniXL7o^ZC300;o_:C10`0000001?noYl;o_j[4oknZa?o2Zl<3ol6]aP04olB_aOo3/LSo
`k78ol>ab0?oaKG;00CoakO:olFicP00003oaKW>0oo6_=401?o8_]7oaKoDolFoe?o5_m@3ol?1f0?o
`L?K00Co`/GLoko4g_noa=ko_lCN1?nla>401Onh`n;o^LCSokW4hoooool0000002;ooooo0009oooo
o`0400000?ooooooooooooooo`l000003P0I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0
C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0
VIVI00D0VIVI00<000000;>c/`2c/k<0202c/k<>000000/0/k>c00<0000009VIV@2IVIT0102IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`0
0`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00`06ATI40000004ooooo`0300000?oooooo
oooo01Gooooo00@00000oooooooooooooooo2OnX_>P3ojNki`?oY[[W00?oY[WWojFhionT]nH00onT
]nH2ojBfiP03oj>eiOnQ/nGoX;7T00;oX;7T0onO[n<00onO[N;oW:[QoibXg`02oibXg`;oVjKM0onK
Y=/01?nKX]WoV9gGoiRKeOnHVmD3oiVJd`?oVYWA0_nKV<l00onLUlkoVY;;oibBb@02oibBb@?oWY;7
0_nPTlH2oj:CaP03oj6@`_nSTL;oXi7200?oYI;20onWU<83ojVC_`?o[9Jo00?o[YS0ojjF_On`V;h0
0on`V;h00onbVl3o/iZmok>J_@03okFL_`04okJO`OnhW[ko^9jnokRN_P;o^J710`0000001OnlY<7o
_jO2oknW`_noYl;o_j[400?o`Z_300Go`Jg6olB_aOo4[lGoa:o5ol>ab002olJca`08olFeboo7]l[o
akO:olNgb_o5^Lh00000olRkc_o6_=43olRnd@04olFoe?o7`MGoal7Eol?1f0;oaL?I00Go`L?Kol;5
g?o2aMco`/GLoko4gP02oko5g`;o_<CQ0_nlaN801?nia>?o^LGTokW5i000000Rooooo`002Oooool0
1000003oooooooooooooool?000000d06ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<
C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VI
V@0509VIV@030000002c/k<0/k>c00L0/k>c0P00000>0<c<c0<000002@2c/k<00`000000VIVI09VI
V@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6AT?000000Cooooo00<0
0000ooooooooool05Oooool00`00003oooooooooo`02ooooo`OoZ;cX1OnW^nL00onV^^OoY[WWojFh
i`02ojFhi`;oY;OV00CoXkKVoj:diOnR]>GoX[CU0_nQ/nD00onP/NCoWZoSoij_h`03oif]hP;oW:[Q
0_nLZ=l00onKY]goV:;LoiRRg002oiROf@?oV9gG0_nHVmD3oiVJd`04oiZIdOnGU<koV9?<oiRCc0?o
VY;;0onLT/T2oijBa`03oj2Ca_nNSl?oXI3200;oXI320onSTL83ojFB`P03ojND`_nWTKkoZI>o00;o
ZI>o0on/U[l3ojjF_@?o/9Rn1?ncV[d2okFL_`?o^9jn0`0000001OnkXKko_:C1okbT`OnlY<7o_ZBo
00;o_jO21?o2Zl<4olB_a@?oa[?71?o7]lX2olRkcP0500000?o8_]7ob;kAolRndOo:`M800oo7`MD3
olG3f@03olK6fOo2aMco`/GL00;o`lOM00?o_lGOoko7h?noan000_nlaN801_nlan;o^LGTokW5i?ni
aNCooooo0000027ooooo0009ooooo`0400000?ooooooooooooooo`d0000000?o000001TI6@0I6AT0
2`0I6AT00ol00000000003<c<`0703<c<`030000001<C4`0C4a<00D0C4a<00?o000006IVIP1VIVH0
0`1VIVH00ol00000Ogmo07moO`0407moO`03o`00002IVIT0VIVI00@0VIVI0P0000080;>c/`030000
0?l00000c<c<0180c<c<00?o00000000000000001`2c/k<00ol00000VIVI09VIV@0409VIV@03o`00
001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C003o`00
000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02`0I6AT?000000Cooooo00<00000ooooooooool0
5Oooool00`00003oooooooooo`04ooooo`KoZ;cX0_nW^nL3ojJji`;oY[WW00?oYKSWojBgionT]nL0
0onS]^H00onR]>GoX;?Uoj2ci@03oinai0;oWZoS00?oWJgRoiZYhOnIYml00_nIYml2oiVTg@?oV:;L
0_nHWmT2oiRMe`03oiRKeOnEUm?oUYG@00;oUYG@0onGU<h2oiRCc0?oVY;;0_nLT/T00onNT/OoW8k4
oij?``02oij?``?oXI320_nSTL82ojFB`P04ojF?__nWTKkoYi6nojNA_P?oZI>o00?o[9JoojbC_?n^
U[d00on^U[d00on`V;ko/INlok>J_@03ok>J_@03okFL_ongW;`000000080000000?o^Yjlok^Q__nk
XKh00_nkXKh01?nlY<7o_ZBookjT_onoYl82ol6X`0?o`Z_300?oa:c2olB_aOo4[lD00_o7/L@2olJc
a`03olVeaoo7]l[oakO:00;ob[W:00Cob;_>olZmcP00003ob;kA0oo:`M801?o7`MGob<CFolS4e_o5
`mT2olK6f@?o`lOM00Coa<SNoko7h?noan3o_lOP1?nlan801OniaNCo^<KTokS6i?ooool00000023o
oooo0009ooooo`0400000?ooooooooooooooo`h000003@0I6AT00`000000<c<c03<c<`0703<c<`03
0000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`03
0000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<3000001P0c<c<00<000000;>c/`2c
/k<01@2c/k<2000000D0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP03
0000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@l0
00001?ooool00`00003oooooooooo`0Eooooo`0300000?oooooooooo00Cooooo1OnX_>P01OnW^nSo
Yk_WojNkionW^nOoY[[W00;oYKWW0onU^>L2ojBgi`03oj>fi_nQ]>KoXKCV00?oX;?U00CoWk7Toif_
i?nK[>?oVjcS0onJZN43oiVWg`;oVJCM00CoV:;LoiBMf_nDVmSoU9_H0onDVMD2oiFGd`?oUYG@0_nG
U<h2oiRCc0;oVY;;00?oV8k7oiZ>a_nJS/H00onLS/@2oij?``?oXI3200?oXi72oj:>_onUSkh00onU
Skh2ojNA_P;oZI>o00CoZY6lojbC_?n/Tkco[9>l0_n^U[d01?n_U;_o/INlok6G_?naUk`2ok>J_@05
okFI^`0000000000okNL_?nhW[h00onjW[`2ok^Q_P04okfR_OnnY;oo_ZBookjT_`Co`JS000Co`Z_3
olB/`_o4[<;oa:o50oo7/L@01?o6/lOobKG7olVeaoo7]lX3olZibP;ob[g>00@00000ol[1d_o:`M;o
b/7B0_o<a=801?o8a=Kob/KGol[6eoo6a]T2olO8fP05ol?7gOo4b=koa<SNolC8g_noan000_o0b>42
okc7hP;o_<OS00Co^<KTokS6iOnha^D000008?ooool000Wooooo00@00000oooooooooooooooo3@00
000=01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c
/`050;>c/`030000003<c<`0c<c<01X0c<c<0P0000070;>c/`030000002IVIT0VIVI00<0VIVI00<0
000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0;01TI6@h000001?ooool00`00003ooooooooo
o`0Eooooo`0300000?oooooooooo00Gooooo1?nX_>P2ojNkj003ojNkionV^^OoY[[W00?oYKWW00?o
YKSWoj>gionR]^H00_nR]^H3oj6diP03oj2ciOnN/NGoWJoT00;oWJoT0_nK[><00onJZN7oUjKPoiNV
h002oiJSgP;oUJ3L0onDWMX2oiBKf0?oU9WE0_nEUm<2oiJEd004oiNDc_nDSlcoUXk9oiJ>b@CoV8k7
0_nJS/H2oib>a0?oWXo300?oXI32oin<_onRS[l00_nRS[l3ojF?_P03ojNA__nWSkcoZY6l00?oZY6l
0_n/Tk`01?n^U[go[iBkojnD^on_U;/2ok6G_0<0000000?o]IVkokNL_?ngW;`01?njW[`01?nkXKko
_J:mokfR_OnmX[d2okjT_`04ol6U__o1Z<3o`JS0olBZ_`?oa:c20oo7/L@01?o9/lCobKG7olVeaoo9
]LL3olZibP;ocKc;00Cob[g>olg0cP00003ob/7B0_o<a=801?o>am?ob/KGol[6eoo:a]L3olO8fP;o
b<[L00Coa<SNolC:goo4b]oo`<SQ0_nob^82okc7h`06ok_8i?nha^Go^<KUokS7i_ooool000007ooo
ool000Wooooo00@00000oooooooooooooooo3@00000=01TI6@030000000c<c<0<c<c00L0<c<c00<0
000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo00<0
000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00T0c<c<1ol0
000=0<c<c08000001P2c/k<00ol00000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00@0Ogmo00<0
000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00?o
00000000000I6AT02`0I6AT>000000Cooooo00<00000ooooooooool05?ooool00`00003ooooooooo
o`08ooooo`03ojRlj?nW^nSoYk_X00?oYk_X0_nV^^L00onU^NOoY;WWojBii`02oj>gi`03oj:fi_nQ
]NKoXKGV00?oWk?V0_nN/ND00onM[nCoVZcToiZ/i002oiRYhP?oUjKP0_nFXmh2oiFPg0;oU9gJ00?o
U9_Hoi2Fe_n@U=<00_n@U=<2oi6Bd0;oTY3>0onDSl`2oiJ>b@?oV8k70_nJS/H00onLS/CoVX[2oif;
`002oif;`0?oWhbo0onRS[l00onUSkkoYHflojN?_002ojN?_0?oZY6l00?o[9>lojfB^_n_U;/00_n_
U;/3000000Co]IVk00?o]iblokRK^onhVk/00onjW[`4okfR_@04okjT_oo1YKko`JFnol6X`0?oa:Zo
00Coa:c2olN^`Oo7[/7oak740oo9/l@01?o9]LOoc;S7olbhaoo:^LX3olflb`?ocL3>00<00000olc4
d_o>am<00_o>am<01?o:a]OoblWHol_9f?o7b=X2olS:g004olS<gOo4b]ooa<[OolC:g`?o_l[R0onk
b>@4okS7iP03ooooo`00003ooooo01gooooo0009ooooo`0400000?ooooooooooooooo`d000003@0I
6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0307moO`03o`00002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c
/k<00ol00000c<c<0<c<c0070<c<c0?o00001`3Vi^H4o`0000/0c<c<00<000000;>c/`2c/k<0102c
/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1V
IVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02P0I
6AT>000000Cooooo00<00000ooooooooool05?ooool00`00003oooooooooo`09ooooo`CoYk_X00Go
Y[[XojFij?nU^NSoYKWXojBii`02oj>hi`?oX[KW0_nQ]NH00onO/nKoWK7Voi^_i@02oi^_i@?oVZcT
0_nHZN801?nGY^3oTj?Poi6OgOnAWmd2oi2Lf`?oT9WI0_n@U]H3oi2Dd`;oTI;@0_nBT<h2oiB?c0?o
UXk900CoV8k7oiF9aOnHR/?oV8[30onJR/83oif;`0;oWhbo0_nRS[l00onRRkcoYHflojF=_003ojN?
_0?oZY6l0_n]T[X300000004ojnD^oncU[[o/iJjok>F^P?o]IVk1?nhVk/00onjW[co_9nkokbO^`02
okfR_@04ol2S^oo1YKko`JFnol6U_PCoa:Zo0oo7[/401?o:/L7obK?4olVca?o9/l@3olbha`06oljk
aoo=_<_ocKc;olflboo?_l_ocL3>0_o?a<l01P00003oc/OColk7doo>am?ocl[Eol_9f0;oc<cI00Go
b<[LolS<gOo8c=gob<cMolC:g`02olC<h@04oko:h_nobn?o_l_Sok_8i0;o^lWU0_nhanH2okO7iP03
00000?oooooooooo01cooooo0009ooooo`0400000?ooooooooooooooo`d000003@0I6AT00`000000
<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000
Ogmo07moO`0407moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000
c<c<0<c<c0060<c<c0;o00003P3Vi^H3o`0000P0c<c<00<000000;>c/`2c/k<0102c/k<00`000000
VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000
C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT=000000Co
oooo00<00000ooooooooool05?ooool00`00003oooooooooo`0:ooooo`?oYk_X0_nV^^P00onU^NSo
Y;WXojBij003oj>hi`03oj:fionP]NOoWk?V00;oWk?V0_nM/NH3oi^_i@04oiZ/i?nFZN?oU:KRoiBV
hP?oTj?P0_nAWmd2oi2Lf`?oT9WI0_n@U]H2oi2Dd`;oTI;@00CoTY3>ohj;c?n@R/WoT8[90onBRLL2
oiF9a@?oV8[30_nJR/83oif;`003oin<_onORKgoXX^l00;oXX^l0onUSK`3ojN?_004ojZA_0000000
0000000000;o[I:j00?o[iBkok2C^OncU[X00oncU[X00oneVK_o]iViokNI^@02okRK^`05okZL^Onl
Wk_o_9nkokbO^onmX[d00oo0Xk/2ol6U_P05olBW_Oo4Z[ooa:ZoolBZ_oo7[;h00_o7[/42olZa`@04
olVca?o=]/CocKK4olbha`?oc[_700?ocKc;olnoboo?_l/00oo?a<l00`00003odLO@olk7d`02olo:
e@?oc<cI00?ocLkKolS<gOo8c=d00_o8c]l01?o4c>7o`lgRol?=h_nobn<2okk<i003ok_9iOnjbNKo
^/WV00;o]lOV0_nfanL00`00003oooooooooo`0Kooooo`002Oooool01000003oooooooooooooool=
000000d06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0
IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0
/k>c00<0/k>c00<000000<c<c03<c<`01P3<c<`00ol00000i^KV0>KViP0A0>KViP;o00001`3<c<`0
0`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl0
0`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01`0c<c<0
0`0000006ATI01TI6@0:01TI6@d000001?ooool00`00003oooooooooo`0Dooooo`0300000?oooooo
oooo00_ooooo00?oYk_XojJkj?nV^nP00onU^^P2ojBij003oj>hionR]nOoX;GW00;oX;GW00?oWk?V
oibbionL/^L00_nJ[nH3oiR/i@;oUZWS0_nDY^82oi>Sh004oi6OgOn=VmgoS9SJohbHfP?oRiCG0_n;
TM@2ohb?d@;oSHg>0on>Rl`2oi2:b@?oTXW70_nERLD2oiR:``?oVX[200?oWH_0oi^8__nORKd00_nO
RKd3oj:;_0;oYHfl00CoYhnl00000000000000000_nZSkX2ojfB^P04ojjA^?n`TkWo/9>iok2C^@;o
/iJj00Go]9JhokNI^OngVKWo]iViokRK^`03okZL^@;o_9nk1?o0Xk/01Oo1YKkoa:NmolBW_Oo4Ykgo
a:Zo00;oajbn00Coajk1olZa`Oo:/L7ob[710oo=]/@3oljka`;odKk800Cocko;om;3c?oB`lcoclC?
0_oAam000`00003odl_Bolo:e@02om3=e`03olc<fOo=c]_ocLkK00?ob<kO00?ob=3Qol?=h_o3cN80
0_o3c^<01?nnc>Co_LcUokg<iOnjbNH2okW9i`;o]/OW00?o]LOXooooo`0000007?ooool000Wooooo
00@00000oooooooooooooooo3@00000=01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`0101<C4`00ol00000000006IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00D0c<c<0_l0000F0>KViP03
o`00003<c<`0c<c<00D0c<c<00?o00000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@03
0000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00ol00000C4a<04a<C00404a<C003
o`00000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT<000000Cooooo00<00000oooooooo
ool05?ooool00`00003oooooooooo`0<ooooo`?oY[_X00?oYK[XojBij?nS^>P00_nS^>P2oj:gi`03
oj2eionN]>OoW[CW00?oW;;W0_nJ[nH01?nH[>GoUJ[Uoi:VhonBY^<2oi2Sh@?oSYoO0_n=Vmd2ohbH
fP?oRiCG0_n;TM@2ohb?d@;oSHg>0on>Rl`2oi2:b@;oTXW70_nERLD00onHR/?oUHK1oiR7_`02oiR7
_`;oVhRn0onORKd3oj:;_0<000000onWSKX2ojZ?^P03ojfB^_n^TKSo[Y6h00?o/9>i00?o/iJjokBF
^?ndU[P00ongVKT4okZL^@03okbO^onnX;[o_Z2j00?o`:>k0oo4Ykd01?o6ZKcoajbnolN/__o7[;h3
olZa`@;ocKC10_o=]/@00oo@^LCoc[_7om6nb002om6nb0?od/?<00Goe<O=om77d?oCbm;odl_B0000
0003om3=e`05om7AfOo=c]_ocM7MolgAgOo8c]l00_o8d>43ol?>h`;o`/oU00Go_LcUokc<i_nlc>Ko
^LWWokS9i`04okG7j00300000?oooooooooo01[ooooo0009ooooo`0400000?ooooooooooooooo`d0
00003@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1V
IVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c
/k<00`2c/k<00`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV01L0i^KV00?o00000<c<c03<
c<`01@3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1o
Ogl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01@0c<c<00`0000006ATI01TI6@0;01TI6@`000001?ooool00`00003oooooooooo`0Dooooo`03
00000?oooooooooo00gooooo00?oY[_XojFjj?nU^^P00_nT^NP00onS^>SoX[OXoj:gj003oj2fj0;o
W[CW00?oW;;WoiZ`ionG[NH00_nG[NH2oiFZi@;oTZKS0_n@Xn43ohjOg`;oSI_M0_n<V=X2oh^De`;o
Ri7D0_n<Sm42ohf=cP;oSX_<00?oRXK:ohb6aon<Q/L00_n?QLD2oi:5``?oUHK10_nHQkl3oi^8_P;o
WhVm0`000003ojB;^P?oYhfj00?oZXnjoj^>^?n^TKP00on^TKP2ok2C^@Co]9Jh0_ngVKT01?nhVKSo
^YbiokZL^OnjW;T4okjP^P04ol2S^oo3Y;_o`jBkolBW_@?oaZVl00CoajbnolZ___o:[kkob[710oo=
]<400oo=]/Cod;W4om2ia003om6nb0;oe<?900?od/?<omC7cOoDald00ooCbm800`00003oe<oDom3=
e`02om7Af@05om7Dfoo=dMgoc=?OolcCgoo8d>400_o7d^801?o3c^?o`/oUol;?iOo0d>H3okc<iP?o
^<WW0_neanP00ondanSooooo0000000Kooooo`002Oooool01000003oooooooooooooool<000000d0
6ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0
IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0
/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP0I0>KViP;o00001P3<c<`00`000000
/k>c0;>c/`030;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000
IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`000000
6ATI01TI6@0;01TI6@/000001?ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00oo
oooo00?oYK[XojBjj?nT^^P00onS^NP2oj:gj003oj2fj?nN]NSoW;;W00;oW;;W0_nJ/>L00onG[NKo
U:_VoiB[iP02oi6Wi@;oSZCS0_n;Wn42ohVKg`;oQiOL0_n6TmT2ohF@eP;oQHgC0_n6R]02ohR8c@?o
RXK:0_n<Q/L2ohn5a@?oTXG30_nEQ/43oiR7_`05oi^8_P000000000000000?nNQk/00_nQRKX3ojB;
^P?oYhfj0on[S[P3ojjA^003ok2C^OnbTkOo/Y>g00?o]9Jh00?o]iViokRI^?nhVKP00onjW;T4okjP
^P?o`jBk1?o6ZK`3olZ__P04oljb__o=]<7ocKC1olfd`@?od;W400?odkg5om6nb?oD`lT00_oD`lT3
omC7c@07omK<cooCbm;oe<oDomC?e000003oe]?Fom7Af@02om7Df`?oc=?O00Goc=GQolOBh_o6dnCo
a]?Tol;?i@03ol3@iP04okc<i_nkc>Oo^lcWokS9i`;o]lWX00Co]<OXok?6j?nca^P000006oooool0
00Wooooo00@00000oooooooooooooooo3000000=01TI6@030000000c<c<0<c<c00H0<c<c00<00000
04a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<00000
09VIV@2IVIT00`2IVIT00ol00000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00@0c<c<00?o0000
0>KViP3Vi^H0203Vi^H:o`0000X0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`03
0;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;
01TI6@/000001?ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo017ooooo0_nT^^P0
0onS^NSoX[SXoj2gj002oj2gj0;oW[GX00?oW;;WoiZaj?nJ/NP00_nG[^L3oiB[iP;oTJOU0_n>Y><2
oh^Oh@;oRI_O0_n7Um`2ohJCf@;oQI3F0_n5SM<2ohJ:d0;oR8S=0on:Q/X2ohb6a`;oShG50_nBQL<3
oiF6`@04oiR7_`0000000000oiZ5_0?oWXNk0onQRKX3ojB;^P03ojN=^_nXS;SoZhjh00;oZhjh0on^
TKP3ok:C]`?o]9Jh1?nhVKP00onjW;Wo_IfhokfM^002okjP^P;o`J:i0_o3Y;/01Oo6Yk[oaZVlolJY
_?o6ZKcobZbl00;obZnn0_o>/[h01?o=]<7odKS2om6h`_o@^L@2om>ma@06omK2a_oD`lWoe<?9omC3
bOoGal_oe<O=0_oFc<l01ooHd=7oe<oDomKCe_oFdmH00000omKFf?oAe=/00_oAemd01Oo<dmooc=GQ
olcEhOo:en?oa]?T00;oa=?U0_o0d>H2okk@i`04ok_<ionic>So^LcXokO9j0;o]LWY00Co/lKXok;6
jOooool000006_ooool000Wooooo00@00000oooooooooooooooo3000000=01TI6@030000000c<c<0
<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00@0c<c<00?o00000>KViP3Vi^H01`3Vi^H00ol00000oooo0?ooo`080?ooo`03o`00003Vi^H0
i^KV00P0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0
VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0
C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@/000001?ooool0
0`00003oooooooooo`0Cooooo`0300000?oooooooooo017ooooo0onS^NP2oj:hj003oj2gj?nN]^So
W[KX00?oW;?X0_nJ/NP2oiN^i`04oiB[i_n@ZNOoSJGUohfUi@;oRJ7S0_n6W>42oh>GgP;oPI?K0_mo
S]P2ogn;e@;oOhOB0_n1QLh3oh>3b`;oRXK:0_n<Q/L2ohn5a@03oi:5`on?P/7oTh>o00<0000000Co
UhBmoiZ5_?nJQKcoVXFl0onNQk/2oj69^P;oY8^j00CoY8VhojR<^?nXS;SoZ8bh0on[S[P00on^TKSo
[i6gok:C]`03ok:C]`03okBF^?nfUkOo]YNg00;o^9Vh00Go^iZgokfM^?nmWKSo_IfhokjP^P03ol6R
^@05ol>T^oo6Yk[oaZNjolJW^_o6ZK`00_o:[;`01?o:[kkoc[:noljb__o>/[h3om6h`P?odkg50_oF
`/H01OoD`lWoelO;omO7booJc<coe/c?00;of=3A00Oof]GComKCe_oFe]Soe]KH00000?oFf]_odMOM
00;od=WO00Goc=GQol[Ghoo:en?ob=SUolCCi@02ol;Ci`;o_]3W0_nmcnP01?nic>So^<_YokS;jOne
bNT2okC8j@;o//KY00?ooooo00000?ooool06?ooool000Wooooo00@00000oooooooooooooooo3000
000=01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c
/`020;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KViP3Vi^H01`3Vi^H00ol00000oooo0?oo
o`0:0?ooo`;o00002@3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0
000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0
000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI2`00
0004ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool04_ooool00onS^NSoX[WYoj6g
j@02oj6gj@?oW[KX00CoW;?XoiZbjOnG/>SoUk3X0onC[NP2oi2Yi`;oSJGU0_n9XN<2ohJLh@;oPiON
0_n1Tm/2ogn>f0;oOh_E0_moQm82oh65cP;oPh?;0_n5P/P2ohR1a@;oS8730`000002oi>3_`?oUhBm
0_nJQK`3oij7^`03oj69^_nQQkWoY8Vh00;oY8Vh0onXS;P2oj^>^004ojb>]on_TKOo[i6gojnA]`;o
/Y>g00Go/iBfokJG]onfUkOo]YNgokRI^003ok^J]`;o_Ifh1?o1X[T4olJW^P?obZbl0oo>/[h2om6f
_`;odKS200Coe;c2om>maOoF`/Koe/;60_oIalP01OoGal_of/c<om[<c?oLdLkof=3A00;of]GC00Co
f]WFomKFf?oFf]/000000_oEgMd01?o@fMoocm_RoloKh_o:en<2olSHi@04olKHioo2dnOo`=?Xol3C
j0;o_LoX00?o^loYokS;jOnhbnT00_nfbnT00ondb>Wo//OYok75j@02ok75j@0300000?oooooooooo
01Oooooo0009ooooo`0400000?ooooooooooooooo``000003@0I6AT00`000000<c<c03<c<`0503<c
<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307mo
O`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<
c003o`00003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool03@3oool00ol00000i^KV0>KViP060>KV
iP03o`00003<c<`0c<c<00@0c<c<00?o00000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VI
V@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT;000000Cooooo00<00000oooo
ooooool04oooool00`00003oooooooooo`0Cooooo`;oX[WY00?oXKOYoingjOnO]nT00onM]NT2oiZb
j@;oUk3X00CoTjgXoi2[j?n<YnOoS:OW0_n7X^H2oh>Mi0?oOiSQ0_mlTmh00omjS]_oN8WHogR9f003
ogn;e@;oOhOB0_n1QLh2oh>3b`;oQH;80`0000000on<PL?oSh;1ohn2`@03oi>3_`;oUhBm0onJQK`0
0onNQk_oWHFioj67^@02oj67^@?oY8Vh0_nXS;P3ojb>]`?o[i6g00?o/Y>gok>D]_ncU;H00onfUkL4
ok^J]`03okfM^?noWkSo_inh00?o`J:i00?oa:BiolJW^_o6YkX00_o9Z[X2olZ/_003olf`_?o>/[ko
dKJo00;odKJo00GodKS2omBl`_oD_<;of<;4omK2aP03omW7b0?of/c<00?og=7>omgGdOoJeM<00_oJ
fMH01?oJgMWoe][KomGMg@000002omCOh004oloKh_o=g>CocMcTolSHi@;oa]SW00Goa=SXol3Cj?nn
d^Wo_];Yok_?j@02okW>jP;o]/_Y00Go]<WZok;7jOnbanWo//OYok75j@02ok34j@0300000?oooooo
oooo01Kooooo0009ooooo`0400000?ooooooooooooooo``000003@0I6AT00`000000<c<c03<c<`05
03<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`02
07moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c004
0<c<c003o`00003Vi^H0i^KV00D0i^KV0_l0000A0?ooo`03o`00003Vi^H0i^KV00H0i^KV00?o0000
0<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<00000
07moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<00000
03<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@/000001?ooool00`00003oooooooooo`0C
ooooo`0300000?oooooooooo01Cooooo0onQ^>T2oingj@03oifejOnK]>WoV;7Y00;oV;7Y0_nD[^T2
oi2[j0;oS:OW0_n7X^H2oh>Mi0?oOiSQ0_mlTmh00omjS]_oN8WHogR9f002ogR6e0;oN8?A0_mjP<d0
1?mlO/X00000000000000002ohR1a@?oS8730_n?P/42oi>3_`03oiN4_OnEP[coVH>j00;oVH>j0_nM
QKT3oj67^@?oY8Vh00?oZ8bhojR<]onXS;L00on/S[L2ojnA]`Co/iBf0_nfUkL01?nhV;Ko^iZgok^J
]onkV[L4oknO^004ol6R^Oo4Y;Woa:BiolJW^P?obJZj00?obZblolf`_?o=/;`01?oA][l3omBl`P04
omS2a?oIalSofLO8omW7b0;og<g900Cof/c<omcAc_oLdLkogMOA0ooJfMH01OoJgMWof^7KomGMgOoD
gn00000000;od^7S00CocMcTol_Li_o;g>Koa]SW0_o4f>P01_o1en[o_];YokcAj_nldN[o^LkZokO=
jPCo]<WZ00Co//OYok76jOnaa^Wo/<CY0_n_a>T00`00003oooooooooo`0Eooooo`002Oooool01000
003oooooooooooooool<000000d06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C004
04a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@03
09VIV@030000002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP04
0>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H01@3Vi^H00ol00000c<c<0<c<c003
0<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`02
07moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`06
03<c<`030000000I6AT06ATI00X06ATI2`000004ooooo`0300000?oooooooooo01;ooooo00<00000
ooooooooool05_ooool00onQ^>WoX;SYoiffj@02oiffj@;oVkCY00?oV;7YoiF`j_nE/>X00_n@[NX2
ohbYj@;oQjGX0_n2WnH2ogfJi0;oN9CR0_mdSml2og69f`;oN8WH0_mhQ]@01OmhPm40000000000000
003oO7k:00;oP7k70_n4OL@3ohQn`P;oS7no0_n@P;d3oiF2_0;oVH>j0onMQKT3oj67^@03ojB9^?nU
RKOoZ8bg00;oZ8bg0on/S[L00on_TKOo/96fok2A]P03ok>D]P03okJG]onhV;Ko^9Rf00?o^iZg1?no
WkP3olBT^@CobJZj0oo=/;`00ooA];godKJoom6f_`02omFk`005omBl`_oH`/Cof<;4om_7aOoIalP0
0ooLcLT01ooOdlcog=7>omgGdOoMem7og]cCom[Ie_oJgMT00_oJhM/01?oHi=koe=oPom;Qh`000002
oloRi@04ol_Li_o8g>Sob=cXolCHj0;o`MOZ0onldNX3okO=jP;o]<WZ00?o/lSZok76jOnaa^T00_n`
aNX00on_a>Wo[/?Y0000000Gooooo`002Oooool01000003oooooooooooooool<000000`06ATI00<0
000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0
000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<0
00000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP050>KViP03o`00003oool0oooo01<0oooo00?o
00000>KViP3Vi^H01@3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0
000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`03o`00001VIVH0IVIV00<0IVIV00<0
000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI00?o
00000000000000001`000004ooooo`0300000?oooooooooo01;ooooo00<00000ooooooooool05ooo
ool2oj2hj@03oiffjOnL]^[oW;KZ00?oVK?Z0_nE/>X2oi2]jP;oS:WY0_n7YNP2oh:OiP;oOI[T0_mh
U>82ogB?g`03og69fom`QMSoL8GH00<0000000?oN8?AogZ0cOmjP<d00_mlO/X2oh1na`;oQ7g40_n8
O/82ohao_`;oT82m0onEP[`3oiV3^P;oWHFi0_nQQkT00onQQ[SoYHVgojF9]`04ojR<]`03ojb>]on]
S[Ko/96f00;o/96f0oncU;H4okRH]P03ok^J]onmW;Oo_Ibg00;o_inh0_o3X[P2olBT^@03olRX^Oo9
Z[[obJZj00;ocJjk00CocK2lom6d_OoA];godKJo0ooE^l001?oI`L;of<;4om_7aOoKalD2omo>a`05
omc=bOoOdlcogm?<on7Ic_oMem400_oNg=<00ooOhMKog^GIom[Qf`02omSTgP05omKVhOoBhN<00000
oloRiOo<h^P00_o8g>P2olGKjP04ol7Gj_noe^_o_mK[okcAjP;o^M3[00Co]lgZokG;jonebn_o/lSZ
0_naanX2ok35jP05ojo4j_n^`nWo[/?Yojk3j@0000005_ooool000Wooooo00@00000oooooooooooo
oooo3000000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000
/k>c0;>c/`030;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000
oooo0?ooo`0E0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000
/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000
IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`000000
6ATI01TI6@0:01TI6@X000001?ooool00`00003oooooooooo`0Booooo`0300000?oooooooooo01So
oooo0onN]nX2oibfjP04oiVcj_nF/n_oT[3[oi:`j`?oSJc[0_n7YnX2oh6Sj@03og^MiomeUnGoMIOU
00;oL93R0_m[R]l300000004og25f?m_PMCoL7g@og1md0;oLW_=0_mfN/T2oh1na`;oQ7g40on8O/82
ohao_`;oT82m0onEP[`2oiV3^P03oif5^OnLQ;SoXHJh00;oXHJh0onURKL2ojR<]`03ojV<]_n]S[Ko
[Hjf00Co/96f00?o/iBfokJE]_nfUKH00_nhV;H01OnkV[Ko_IbgokfL]onmW;Oo_inh00?o`j:h00Co
a:BiolRX^Oo8Z;WobJZj0oo=[[/3om6d_@05omFj__oE^l3oeK_0omFk`?oI`L800ooKalD2omo>a`?o
gm?<00?ohMW>on;OdOoNg=<00_oOhMH00ooNiMWogNWLomSTgP02omKVh@05om?Wi?o?h^D00000olcR
j?o9hNX00_o5fnX2ol;Jj`04okoFjonle>co_=C/okW@j`;o]lk[00Co]L_[ok?:joncb^_o/LOZ0_n`
a^X00on_a>[o[/?Yojg2j@03ojg2j@0300000?oooooooooo01?ooooo0009ooooo`0400000?oooooo
ooooooooo``00000300I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0
000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<0
00000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00@0i^KV00?o
00000?ooo`3oool05@3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<00<0c<c<00<0
00000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0
000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0
000001TI6@0I6AT02P0I6AT:000000Cooooo00<00000ooooooooool04_ooool00`00003ooooooooo
o`0Iooooo`03oijgj_nM]n_oWKO[00;oV[G[0_nF/n/2oi:`j`04ohf/jon9ZncoPZK[oh:Vj`;oNj3Z
0_mdV^P2ogFGi@03og2@hP000000000000;oIhCL0_mVOmP2ofn1e0;oL7g@00?oLW_=ogIjbOmfN/T0
0_mjNLH3ogija0;oR7k20_n<Okl2oi20_@;oUH:l00?oTgnkoiR2^_nHP[X00_nLQ;P4oj66^0;oYHVg
00?oZ8bgojV<]_nYS;H00on]S[H2ok2A]P05ok:B]OnfUKKo]YFfokJE]_nhV;H00onkV[H2okfL]`Co
`j:h0oo8Z;T4olf^^`03om6c_?oA];godKBm00;oeKZn00GoeK_0omW1`_oI`L;ogLO3om_7a@02omo>
a`;oh]C900Oogm?<on7Ic_oQfLkoh]oAon?Te?oOhMKog^GI00;ogNWL00Oof^_OomKVhOoCinCodnOT
om3Wioo<h^P0000000;oaMo/0_o2f^/00onof>co_=C/okcDk002okWBk004okO>jonec>co]Lc/ok?:
j`;o//S[00?o/<KZojo5j_n^`nT00_n^`nT2ojg2j@03ojg1j@00003ooooo01Cooooo0009ooooo`04
00000?ooooooooooooooo``00000300I6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<
00@0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI
0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV
00D0i^KV00?o00000?ooo`3oool05P3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<
00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo
0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c
00H0<c<c00<0000001TI6@0I6AT02P0I6AT:000000Cooooo00<00000ooooooooool04_ooool00`00
003oooooooooo`0Jooooo`03oifgjonL]n_oW;O[00;oV;G/0_nD/^`2ohn_k0;oRJ_/0_n2Y^/2og^P
jP05ogBJj0000000000000000?mVS><00_mPQN02ofN4g003ofIof?mUNmCoIG_D00;oIgS@0_mbNld2
ogIjb@;oNWW60_mnN/@2oh=j`@;oRGbo0_n>OKd3oi=o^`;oV8:j0onLQ;P3oj66^003ojF9]onURKKo
ZHbf00?oZHbf0_n]S[H00on`TKKo/Y:eok:B]@03okJE]PCo^iZf00?o_Ibgol6O]oo1WkL00_o3X[P2
olJU^0;ob:Ri00?oc:bjolf^^oo=[[/00_oA/k`01_oA];goeKZnomFj__oE^[kof/30omW1`P;ogLO3
00CohLk5omo>aooRe<Woh]C90_oTfl`01ooQfLkoh]oAon?Te?oSi=Coh^WGon3^f_oMjM`00_oJjml0
0ooGkN?odnOTom3Wi`02olcWj@05olSUk000003o`]g]ol;MkOnof>`00_nle^d2okWBk0;o]m3/00Co
]Lc/ok?;k?ncbnco//S[0_n`an/2ojo5jP03ojk3jOn]`nWo[L?Y00;o[L7Y00?o[<7Y00000?ooool0
4oooool000Wooooo00@00000oooooooooooooooo3000000<01TI6@030000000c<c<0<c<c00H0<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo
00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<
00?o00000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0F0?ooo`03o`00003Vi^H0i^KV00@0i^KV
00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI00<0VIVI
00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@X000001?ooool00`00003ooooo
ooooo`0Booooo`0300000?oooooooooo01cooooo0_nL]n/2oiRek004oiBbk?nA/^goS:k]ohb^k@?o
QJ[]0`000002ofbGj@03of>@iomVS>?oIXcS00;oH8GP00?oG7oLoeYjf?mJN]P00_mUNm@00omWN=3o
JGK=ofUfc@02ogIjb@;oNWW60omnN/@00on3N/7oRGboohUl_`03ohim_@?oTgnk0_nHP[X2oib4^0;o
XHJh00?oXHJgojF9]_nURKH01?nYS;H2ojf>]PCo/Y:e0_nfUKH4ok^J]P?o`Ing00Go`j:holJU^?o6
YKSoaZFholRX^@03olb/^P03olf^^ooA/kcodK>l00?oeKZn0_oJ`<03omg7``03on7>aOoTe/Soh]C9
00;oi=_<0_oVh/l02?oVj=7ohnCDon;YeooRjMOoh>kJomgagOoJjmooengS0_oCkNH01_o?kNWoc>OY
olSUk?o8iN`00000ol;Mk@;o_][^00?o_=K]okWCkOnidnd00_ngd>`00onecNco/l_/ok?;k002ok79
j`03ok37jon_aN_o[/CZ00;o[/CZ00Ko[L?Yojc2jOn/`^Wo[<7Yoj_0j@00000Dooooo`002Oooool0
1000003oooooooooooooool<000000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<
C00404a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VI
V@0209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KV
iP050>KViP03o`00003oool0oooo01H0oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<
c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07mo
O`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0603<c<`030000000I6AT06ATI00X06ATI2P000004ooooo`0300000?oooooooooo01;ooooo00<0
0000ooooooooool07?ooool3oiZgk0;oU[C/0_nA/^d01?n<[^d00000000000000002ogRSkP;oMIk[
0_m/UnT00omST>OoFhSToe^8i002oeB0h004oeaog?mJN]SoFGGDoeUee0;oIgS@00?oJGK=ofieb_m^
MLX00omcMLL2ogija0;oPg[10_n9O;l2ohim_@?oTgnk0_nHP[X00onLQ;SoW8>hoj66]`02oj66]`?o
YHVf0onYS;H00on]S[Ko[hnfok:B]@03ok:B]@03okJE]_nhUkKo^9Nf00;o^iZf00Co_Yffol6O]oo1
WkOo`Ing1?o6YKP4olb/^P?odK>l00?oeKVmomFj__oJ`<000_oJ`<001ooNal;ogLO3on7>aOoQc/Go
i=K8onOMb_oTfl`00_oVh/l2onKXd@03onG^e?oRjMOoh>kJ00;ogO7M00Cof_;QomKci?oCkNKocngY
0_o;jn`01Oo8iNcoa>?]ol7Ok`00003o_][^00;o^mS^00Co^M?]okKAkOnfdNgo]Lg/0_ncbn`2ok79
j`05ok37jon_aN_o[lG[ojo5jon^a>X00_n]`nX00on/`^Wo[<7Yojc1j@02oj_0j@0300000?oooooo
oooo017ooooo0009ooooo`0400000?ooooooooooooooo``00000300I6AT00`000000<c<c03<c<`06
03<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`03
07moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c003
0<c<c003o`00003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool05P3oool00ol00000i^KV0>KViP04
0>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@03
09VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C003
04a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT:000000Cooooo00<00000
ooooooooool04Oooool00`00003oooooooooo`0Nooooo`04oiZgk?nI]ncoU;C]oiBdk@<000000_n8
[^h2oh6YkP;oN:?^0_m^W>d00omSUN_oFHcXoeV<j002oe^8i005oeB0h?m?NMcoCgWLoeYjf?mIMM@0
0_mKL]42ofUfc@;oKWG:0_mcMLL2ogUfa0;oOgS10_n9O;l3ohim_@04oi=o^onAO[_oUh6ioiN1^@?o
W8>h0onQQ[L2ojF9]P;oZHbf00CoZhffojn?]_n_SkKo[hnf0_nbT[D01OndU;Ko^9NfokRG]_nhUkKo
^iZf00?o_Yff0_o1WkL01Oo4XkOoaZFholJU^?o6YKSobZZi00;oc:bj0_o@/K/01?oA/kcoeKVmomFi
_OoJ_kl2om[0`0;og/O200Ooh/o4on7>aOoTe/Soi=K8onOMb_oXiLgoi^;?00?oi^SA00GoiNkDon?b
eooOm][ogO7Mom[bh@02omKci003om7cioo=lN_obn_/00;oanS^00Go`nG_ol7Okonmg>l00000ok_H
kP02okSDkP04okKAkOndc^go]<k]ok?;k0;o/LW/00?o/<O[ojo5jon^a>X00on^a>X01On]`n[o[<;Y
ojc2jOn/`NWoZl3Y00?oZkoY00<00000ooooooooool04?ooool000Wooooo00@00000oooooooooooo
oooo3000000=01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000
/k>c0;>c/`030;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000
oooo0?ooo`0F0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000
/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000
IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`000000
6ATI01TI6@0;01TI6@T000001?ooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo01oo
oooo0`000002oi>dkP?oSK7_0_n5[Nl2ogfXk`;oIi_^0_mJT^`2oeV<j004odj3i?m5N^3oAG[Podmi
g0;oC7?H00?oFGGDoe]bdOmOLLd00_mOLLd2ofiebP;oLgG700?oNGK4ogmh`OmoN<400_n5NKl3oh]l
_@;oTGjk0_nGPKT3oib3^0?oXHJg00?oYHVfojJ:]on[SKH00_n[SKH3ojn?]P04ok:B]OndU;Ko]9Bf
okBD]P;o^9Nf1?nnWKH01Oo1WkOoa:>golBS]oo4XkOoaZFh00;obZZi00Coc:bjom2a^oo@/K_od;6k
0ooE^Kd2omZo_`06om[0`?oNal;og/O2on;?a?oVelOoi=K80_oWgLX02?oXiLgojNc?onW/cooVj=7o
iNkDon?beooOm][ofoSM0_oFnN400ooFlnCodO?Wolgaj`02olS^kP08olOXk_o3iNoo_n7`okoQl?nm
g>oo^]S`00000?nhe>h2okKAkP04okC>kOnbc>go//c]ok79k0;o[lO/0_n_aN/2ojk4jP03ojg3j_n/
`^Wo[<;Y00;o[<7Y0_n[`>T2oj^oj@0300000?oooooooooo013ooooo0009ooooo`0400000?oooooo
ooooooooo``000003@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0
000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<0
00000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00@0i^KV00?o
00000?ooo`3oool05P3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<00<0c<c<00<0
00000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0
000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0
000001TI6@0I6AT02`0I6AT9000000Cooooo00<00000ooooooooool04Oooool00`00003ooooooooo
o`0Looooo`<000000_ooool2oiRgk@;oTkC^00CoSK7_oh^al?n3[O3oPjg`0_miZ?400om]X_3oIi_^
ofNKkP02oeZBk004odf8j?m0O^Co@7kTodEjh0;o?g?L00CoC7?Hod]_e?m;KmCoFg;A0_mOLLd2ofA`
bP;oJg770_miM/@2ogmh`@;oQGVo0_n;O;d3oi5n^`;oUh6i0onLPkP00onQQ[OoXHNhojJ:]`02ojJ:
]`?oZhff0_n_SkH4okBD]P03okRG]_nkV[Ko^iZf00?o_Yff1?o4XkL3olZZ^@06oln_^_o@/K_od;6k
om2a^ooD]kcoeKVm0ooJ_kl01ooOal7og/O2on;?a?oRclCoi]O7onWPbOoWgLX00_oXiLd01_oYk<oo
io;AonObdOoSl]OogoKJom_hg@;oe_WQ00?odOSUolggjOo8m>d00_o8k^h01Oo4jo3o`>KaokoQl?no
hO3o^mga00;o^]S`00<00000okOEkonfdNh00_ncc^h01?nbc>go/<W/ok39k?n_an`2ojk5j`;o[/C[
00?o[L?Zojc2j_n/`^X00_n/`NT4oj_0j@03oj^ojOnZ_nP00000017ooooo0009ooooo`0400000?oo
ooooooooooooo``000003@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<
00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI
00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00@0i^KV
00?o00000?ooo`3oool05P3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<00<0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo
00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c
00<0000001TI6@0I6AT02`0I6AT9000000Cooooo00<00000ooooooooool04Oooool00`00003ooooo
ooooo`0Iooooo`<000001Oooool3oiNgkP;oTKC_0_n;/O02oh>]l0;oNJSa0_m]X_02oenIk`03oe2?
kOm0Q>So@7kT00;o=GCP00Co?g?Loc]/f?lkK=SoBfoD0_m=K=42oemac@03ofA`b_m[LLOoJg7700;o
LW?50_moN<42ohEi_`?oRgbm0_nAO[/2oiN1^@;oW8>h00?oW8Bioj67^?nQQkP00onVR[L3oj^=]P03
ojn?]_naTKKo/I6f00?o]9Bf0onkV[H3okjM]P03ol6P]oo4XkOoa:>g00;ob:Ri0_o:Z[T2oln_^P03
om2a^ooD]kcoe;Nl00?of[no0_oOal42on;?a0;oi]O700CojN39on_XbooXiLgojNc?0_oWl]402?oT
mm?oh?[Fom[lfOoEoMcocogQom7hiOo=mnWob?C]0_o4l?001Oo4jo3o`>KaokcRl_nlh_;o^mga00;o
^=Wa0_ngeNl00`00003o/lk^ok?>kP02ok7<k@05ok39k?n_anco[lO/ojk5jon]a>/00on]`nX00on/
`^[o[<7Yojc1j@04oj_0j@05oj^ojOnZ_nSoZ[oXojZnj00000004?ooool000Wooooo00@00000oooo
oooooooooooo3@00000<01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`0
0`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KViP3Vi^H0103Vi^H0
0ol00000oooo0?ooo`0D0?ooo`03o`00003Vi^H0i^KV00D0i^KV00?o00000<c<c03<c<`00`3<c<`0
0`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl0
0`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<0
0`0000006ATI01TI6@0;01TI6@T000001?ooool00`00003oooooooooo`0Aooooo`0300000?oooooo
oooo01Kooooo0`000009ooooo`03oiNgk_nF]nkoT;G`00;oT;G`0_n9/_42oh2^lP;oMJSb0_mWXO80
1_mHV?3oAXg]odJ=kOm0Q>So<7WTocEdh0;o;6_K00Co>fcHocYXe?ljJ=CoCFcA0_mBJlh2ofA`bP03
of]aaombLlGoLW?500;oNGG20on1N<02oh]l_@;oTGjk00?oUh6ioiJ1^_nLQ;T00_nLQ;T3oj67^0?o
YXZg00?oZhffojb>]onaTKH00_naTKH3okBD]PCo^iZf00Co_Yffol6P]oo1X;Ooa:>g0oo8Z;T01?o:
Z[Wocjnjoln_^_o?[kX3omBg_003omZo__oJ_kooglO100;oglO100?ohm34on;?a?oVelL00_oYh<T0
2Oo[j<_ojo3=onSfc_oWl]7oi?OCon3je_oJo=WoeOgLolomh@02ol_ki@04olKij_o3mNooa?3`ol3/
lP;o_>Kc00Co_>;bokWMl_nigO;o^=Wa0_nee?000onddNoo//k^00000002ok7<k@03ok39kOn_anco
[lO/00;o[/G[0_n]a>/01On]`n[o[<;Zojc2j_n/`NWoZl3Y00CoZkoY0_nZ_nP2ojZnj00300000?oo
oooooooo00kooooo0009ooooo`0400000?ooooooooooooooo`d00000300I6AT00`000000<c<c03<c
<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0307moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`00003o00000<c<
c0040<c<c003o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool0503oool00ol00000i^KV0>KV
iP050>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VI
V@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02`0I6AT9000000Cooooo00<0
0000ooooooooool04Oooool00`00003oooooooooo`0Dooooo`8000003Oooool2oiJgkP03oi2el?n?
]O3oSkG`00?oQk;b0_mn[_<2of>Ql`;oDIOa0_m6SNd01?lcPNSo<7WTob9]g_l/Jm/2obITe`04ocYX
e?llIM7o?6GAoe9[cP;oFF_;0_m[LLL2og9ca@;oNGG20_n1N<02ohQj_P;oSgfl0onFPKX3oib4^@;o
XHNh0_nVR[L00onWRkOo[8jgojb>]`04ok6A]P03okBD]_ngUkKo]iNf00;o^iZf00Co_Yjgol6P]oo1
X;Oo`J2g1?o8Z;T3oln_^P;odkJl00?oe;NlomZo__oJ_kh00ooOal42on?@a003onSIa_oVelOojN39
00;ojnS;00_ojo3=onSfc_oTnloogOkAomOod_o@omKob_oJolGnh?o;nnGoa_WZol?ek`02okoalP06
okc[m?nli_?o^N7cokWQlonigO;o]]Sb0_ncdo42ok?Ak`04ok;>k_n`bnh00000ok39k@;o[/O/0_n^
aN/01On]a>_o[<?Zojc3j_n/`n[o[<;Z00;oZl7Y0_n[`>T3oj^oj@05ojZoj?ooooooooooooooo`00
00004?ooool000Wooooo00@00000oooooooooooooooo3@00000<01TI6@030000000c<c<0<c<c00H0
<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0
Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00<0
c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0D0?ooo`03o`00003Vi^H0i^KV00D0
i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI00<0
VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0;01TI6@T000001?ooool00`00003o
ooooooooo`0@ooooo`0300000?oooooooooo01;ooooo0`00000Aooooo`;oUKS_0_n?]O001On7/_;o
Qk?bogb_m?ml[oCoKjWd00;oHj7c0_mAUo402_llRngo9GgWobEmiolOLn;o8VgNoaISf?lVI=Oo9EoC
ocYXe?llIM42od9Tc`03oeU[bomQKLWoHFg900;oLW?50_miML83oh5h`003ohQj__n?OKcoSgfl00?o
UX6j0onLQ;T2oj67^003ojJ:]onWRkOoYh^g00?o[8jg0_naTKH01OncU;Oo]iNfokNG]_ngUkKo^iZf
00?o_Yjg0_o1X;L01_o5YKWob:RiolRX^Oo8Z;WocJfjoln_^P?odkJl0ooJ_kh2omo7`@?ohm3400ko
j=W6on_Sb?o/k<[ojnS;on_`cOoXm/koi?_?omgndOoGom;od?oFol[of_o5o^3o`_cVokoik0;o_?Ga
00Ko_o7bokc[m?niiOGo^NGeokWQlonfg?<2okCGlP03ok?ClOnaco3o/Lo`00;o/Lg_00Co/<_^0000
0?n_b>go[/O/0_n]aN/2ojg4j`;o[<?Z0_n/`^X00on[`NWoZl3Yoj_0j@03oj^oj@Gooooo00<00000
ooooooooool03_ooool000Wooooo00@00000oooooooooooooooo3@00000<01TI6@030000000c<c<0
<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00<0c<c<00?o00000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0B0?ooo`03o`00003Vi^H0
i^KV00H0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0
VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0
C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0;01TI6@T000001?ooool0
0`00003oooooooooo`0@ooooo`0300000?oooooooooo00oooooo0`00000Eooooo`;oUKS_0_n?]_42
ohNclP;oO:od0_m_ZO@2oejQm0;oBiOb00Oo9GgWo`i]g_l>KMko3FGJoaISf?l>F]?o9EoC00;o?6GA
00Co@VC?odYVcOmIJl_oHFg90_mYKlH3og9ba0;oPGS00_n8N[h2ohmm_0?oUX6j0_nLQ;T00onQQkSo
XXRiojN;]`03ojN;]`;o[8jg00Co/I6fok>D]oncU;Oo/iBg0_ngUkH4okjN]`05ol6P]oo5YKWoaJFi
olFU^Oo8Z;T00_o=[KX4om>f_004omVn_ooJ_kkoglO1omo7`@;oi=7401;ohm34onSIa_oXfLKojn?8
onc/b_o[m<_oio[;on3nb_oHolWoc_o9olKnc?noo]3o^ogGokWlgonhnnOo]oS^okcelOnjl?@2okSY
mP05okWUmOnfgoCo]=[cokCJlondeo800_nad_400onaco3o[lc_ojo<k`02ojo:kP04ojo8k@00003o
[LK/ojg5j`;o[<?[1?n/`^X00on[`NWoZl3Yoj_0j@0:ooooo`0300000?oooooooooo00gooooo0009
ooooo`0400000?ooooooooooooooo`d000003@0I6AT00`000000<c<c03<c<`0503<c<`030000001<
C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002I
VIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0020<c<c003o`00003V
i^H0i^KV00H0i^KV00?o00000?ooo`3oool04@3oool00ol00000i^KV0>KViP050>KViP03o`00003<
c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001o
Ogl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c
<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT9000000Cooooo00<00000ooooooooool04?oo
ool00`00003oooooooooo`0<ooooo`<000006?ooool3oiFil0;oSkOb0_n6]?<2og^`m@;oKJ[f0_mL
X_D01?m6V?;o:hW/ob^9k?l>KMh2o`1Le004o`1Hdol>F]?o2eC?obMLd0;o@VC?00?oBVK=of5]bOmQ
KLT00_mYKlH2og9ba0;oO7K20_n4N[l2ohmm_0;oUX6j00?oU86loi^5^_nKQKX00onRR;T3ojN;]`03
ojb>]on^TKSo/iBg00?o/iBg00?o]iNfokZK^?njVkP00onnW[L4olFU^@?ocJfj00?od[Fmom>f_?oC
][`00_oI_[l3omo7`@;oi=7400?oj=_6onSIa_o[hlP00_o/k<X03?o[m<_oio[;on3nb_oHolWoa_k<
okond?nkoMOo^OcOokSkiongn>ko]_?cokG]mP;o^>Wf00Co]N?fok?MmOndf_?o]=[c0_nae?801?na
d_7o/<k`ok3>l?n_c>l2ojk9kP;o[/O]00Go[LK/00000?n]a>_o[<?[ojc2jP03oj_1jP03oj_1jOoo
oooooooo00_ooooo00<00000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo3@00
000=01TI6@030000000c<c<0<c<c00H0<c<c00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c
/`030;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H01P3Vi^H3o`0000h0oooo0_l0
00080>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00304a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT9000000Cooooo00<0
0000ooooooooool04?ooool00`00003oooooooooo`09ooooo`<000007?ooool4oiFil0;oSkSb0_n6
]O@00omk/OKoKJcgoff/m`02oeZTmP06od>Ilol[RNco:hW/o`egh_l0G=Co04g:0_l0C/`01?l;E<oo
9ec@obeLcom:I/d2oeAXb`;oJFo60_mbL/@2ogaf`P;oQ7Zo0_n=OKd3oiB1_0;oVhFj0onRR;T3ojN;
]`?o[Y6h0oncU;L4okZK^003okjN]oo2XkWo`Z>i00;oaJFi0_o:[;/01?o=[K[od[Fmom:e_OoC][`3
omVn_`04omk7`_oOal7oi=74onCAa0;oj=_600cok>K8ong`bOo/k<[ojoC;onOjbooPo/[of?o9okOi
_On_n<;oZoWDojgjgon`mO42ok7`mP05okG]m_ndi_Oo/^3gok;PmoncgOD00_naeo@2ok7DlP04ok3@
lOn`c_3o/<k`ojk;kP;o[/W^00Go[LK]ojg5k?n]aNco[LG/00000002ojc3j`;o[<;Z00?oZl7Zoooo
ooooool03Oooool00`00003oooooooooo`0=ooooo`002Oooool01000003oooooooooooooool=0000
00d06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV
00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@03o`00002c/k<0/k>c
0080/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP080>KViP03o`00003oool0oooo
00T0oooo0_l0000:0>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`00
0000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`00
0000C4a<04a<C00304a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT90000
00Cooooo00<00000ooooooooool04?ooool00`00003oooooooooo`06ooooo`<000008Oooool00onE
^O3oU[[`ohnilP02ohnilP;oQkKd0_ml/oH2off^n0;oFZKg0_lVRN`01Ol5M]oo06;Co`1=b_l0C/co
04O700;o357=0_lgG/h01?mDJ<_oGfc8oem/b?mOK<P2og9ba0;oO7K200CoQ7Zoohem_On=OKgoSGfm
0onDPK`2oi^5^P?oXXRi00?oYh^gojV>^On^TKP00on^TKP00oncU;Oo]YRiokZK^003okZK^0?o`Z>i
00GoaJFiolZ/^oo:[;_obZbkolf]^P02om:e_@03omRm`?oI_[oofKjo00;og/O200Coi=;5onCAa?oX
flKoj=_60_o/i/P02Oo]l<Woj_S9on?maooIo/?ocOfookOi_On_n<;oXoKRojSfkP02oj_bm@05ok7`
m_najOSo/>?hok3Sn?nbh?L00_naf_D01?naeoCo/=;bok3Bl_n`d?42ojk<k`03ojk;k_n]b>go[LS]
00?o[LK]00Co[LG/ojc4jon/a>/000004oooool00`00003oooooooooo`0=ooooo`002Oooool01000
003oooooooooooooool>000000d06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C003
04a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@02
09VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP08
0>KViP?o00001P3oool2o`0000/0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`03
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00ol00000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:
01TI6@X000001?ooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo00?ooooo0`00000U
ooooo`;oU[[`00?oSkWboi2il_n@^O800_n8^?D2ogfem`;oKk3h0_mLZOP02Om3W_Go8h_/ob>;k?l0
G/go04c1o`11`Ol0AlOo357=oa=Bc@02ocMNcP03oeAXbomOK<SoGfc800;oJW370_mlM/82ohAj_`;o
SGfm0onDPK`2oi^5^P;oXXRi00CoXhZkojV>^OnYS[WoZHji0_n^TKP01?naUK[o]YRiokJH^OnfV;T2
okZK^004okjP^_o2XkWo`Z>iol:S^@CobZbk0ooB]Kd2omRm`006omVn_ooNal;og/O2onCBaOoYgLOo
j=_60_o/i/P2ong`b@06on[hbOoSoLOocOfooiW[[onClMSoW??X0_nTl_<01_n[l_Go[NchojkUnOn^
iOWo/>?hok3Lm`;o[]Kd0_n_e?<01?n`d_;o[/k`ojk>l?n^c>l2ojg9kP03ojg8kOn/aNco[<G/00;o
[<C/0_n/a>/2ooooo`0300000?oooooooooo013ooooo00<00000ooooooooool03Oooool000Wooooo
00@00000oooooooooooooooo3P00000=01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<
C4`0101<C4`00`000000IVIV06IVIP0206IVIP0300000?l00000Ogmo00<0Ogmo00<0000009VIV@2I
VIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KViP3V
i^H02P3Vi^H6o`0000/0i^KV0_l000050<c<c00300000?l00000/k>c00<0/k>c00<0000009VIV@2I
VIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI2P000004ooooo`03
00000?oooooooooo00oooooo00@00000oooooooooooooooo0`00000Yooooo`;oUk_a00?oT;Wboi:j
l_nB^_800_n:^OD2oh2gm`;oL[?i0_mO[?T01_m7XoOo98o]obB?kOl0NMgo04Fgo`0g^P;o04C500Co
4e;=ocMNc_m3Hlgo@f?=0_mOK<P00omZL<OoMWG5ogIea@02oh1j`P?oSGfm00CoU86loi>3__nKQkco
VhNl0onSR[/3ojV>^@03ojjA^?naUK[o/IFj00?o]YRi00Co^Y^hokjP^_nnX;[o_Z2j0_o2XkT01_o7
ZKcobZbkolZ/^oo:[;_od;>nom:e_@?of;g000Gog/S3omk7`_oTd/Goi=;5onWMa`02oncYb@07oncd
bOo]l<Woj_S9on?maonPkJ_oP>:bohk_h@02oi[ak`03ojCblonXk_SoZnOj00;o[>3i00Co[]khojgH
m_n]f?Ko[]Kd0_n]dO800on^co7o[L_`ojg;l002ojg:k`04ojg9k_n/a^go[<K]ojc5k0Sooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`0=ooooo`002Oooool01000003ooooooooooooo
ool>000000d06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c
/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`00ol00000i^KV0>KViP0I0>KViP03o`00003<
c<`0c<c<00D0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001o
Ogl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c
<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT:000000Cooooo00<00000ooooooooool03ooo
ool4000002kooooo00CoV;_`oi:jl_nC^o;oTk_b0on<^_D2oh>hm`;oM[Gi00WoI;3jodfWn?lXTnko
:9?^o`9ng_l0G/Go03Njo`14aOl0A<H00_lNELd00om3HlgoDFS<oe5Xc002ofY`a`03ogIeaOn0N/;o
P7[200?oRWk00_nCPkh3oi^7_0?oXhZk0_nYS[T4ok6E^P;o]YRi1?nnX;X01Oo2XkWoajVlolNY_?o7
ZKcobZbk00;od;>n0ooH_L02omk8``05onCCaooTd/GojMg7onWMaoo/jLT00_o/m<T01OoLo/7ocObi
ohCJU?mafkCoSnk[00;oVnkf00GoX^khojOXn_nYhO[oZN7jojcPn@02ojcIm`04ojgHm_n]d_Co[M;d
ojgAlP;o[Lga00?o[L_`ojc8k_n/b>h00_n/and00on/a^goooooooooo`08ooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool03Oooool000Wooooo00@00000oooooooooooooooo3`00000<
01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`03
0;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H05`3Vi^H00ol00000c<c<0<c<c005
0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`04
07moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`05
03<c<`030000000I6AT06ATI00/06ATI2P000004ooooo`0300000?oooooooooo00oooooo00<00000
o`000?ooool0<?ooool2oiVll0;oTk_b00?oS;[eohnkm?n?^o@00_n6^_L2ogZhn@;oJk?k0_mE[OX0
2Ol9QN;o06?5o`11Yol0<kOo04C6oaiEcOl/Flko@f?=oe5Xc002oem^b`;oMWG50_n0N/83ohYn`0;o
Th>n0_nKQk`3oj>:^`03ojV>^On[T[coZi:l00?o/IFj00?o]YRiokZN_?njW[`00onnX;X3olNY_006
olfb_oo@/kkod;>nom2c__oF_L7of;g00ooNb<<01?oTdlOojN7:onWMaoo/jLT2oncdb@04omcn`Oo=
o;WoQ=ZDoh;YiP;oT^cd00GoVnkfoj;YnonVh__oY^;kojWQnP02oj_Jn004ojcImon/doGo[=?eojgB
m0;o[<ka00Co[Lgaojc9kon/bNoo[<S^3oooool00`00003oooooooooo`0?ooooo`0300000?oooooo
oooo00cooooo0009ooooo`0400000?ooooooooooooooo`l00000300I6AT00`000000<c<c03<c<`07
03<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`02
07moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c005
0<c<c0;o00005P3Vi^H00ol00000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00<0/k>c00<00000
09VIV@2IVIT00`2IVIT00ol00000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<00000
04a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`03o`00000I6AT06ATI00/06ATI00?o0000
0000000000001`000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool0;oooool2
oiZml0;oU[cb00?oSk_doi:lm?nB_?@00_n:_?L2ognjn@;oLKOk0_mN/O/2odBXm`05ob>IkOl0<kSo
04W9oaiEcOl/Flh00_mAJ<`00omOK/_oKGC9ofedb@03oh1j`P;oRWk00_nCPkh3oi^7_003oj>:^onT
S[koZi:l00;oZi:l0onaUKX4okZN_004okjP^_o3Ykgo`jNmolNY_0?ocK:o00?od;>nomJm`OoF_L40
0_oLb<H02_oNb<?oi=?7onCCaooYhL[ojnk<onWhb_o/m<Wocobiok[e[?n:jO<2oiOXn`05oigYnonS
hocoY]cjojKLn_nXfoT00_nYeOL2oj_DmP05oj_?lon/c_;o[<kbojc>l_n/c_400_n/b^l00on/bNoo
ooooooooo`0@ooooo`0300000?oooooooooo00kooooo00<00000ooooooooool03?ooool000Wooooo
00@00000oooooooooooooooo3`00000=01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<
C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT00`2IVIT00`000000/k>c0;>c/`040;>c/`8000001`3<c<`2o`000180i^KV0_l000080<c<c003
o`00002c/k<0/k>c00<0/k>c00<00000o`00002IVIT0102IVIT00`000000Ogmo07moO`0307moO`03
0000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`03
0000000I6AT06ATI00/06ATI2P000004ooooo`0300000?oooooooooo01;ooooo00?o0000oooooooo
ool0;oooool2oibml0;oUkgb00?oT[cdoiBmlonD_O<00_n>_OH2ohBln@;oN;[k0_mX]_`2oe6_nP04
ocBSl_l0<kSo04W9obaKcP;o?V??0_mOK//01?m]M<WoNg[7og]jaomkN/L2ohN0a@;oTXG20onKR/03
ojB>_P?oZi:l00?o/IFjokBK__ndVkh00_njW[`01?nnYL3o`jNmol>W_Oo3Ykd4olfb_`?oe[g10_oL
b<H02OoSe/[oi=?7onWQb_oYhL[ojnk<onWhb_oPo/Cocobioi;Vn`02oicRo@04oioRo?nTg?_oY=ck
ojKLnP;oZ=Kg00CoZMGgoj[@m?nZd?CoZloc0_n[bo400on[bo3oooooooooo`0Fooooo`0300000?oo
oooooooo00gooooo00<00000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo3`00
000=01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00ol00000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c
/`050;>c/`030000003<c<`0c<c<00H0c<c<0ol0000<0>KViP?o0000203<c<`2000000H0/k>c00<0
000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0
000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI2P00
0004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool0;oooool3oifmk`03oiVmlOnD
_O?oUkkb00;oUkkb0_nA__D00on9_OSoOkcjognlnP02og6jo0;oG[Kl00GoAJghogT00?l>DLgo3U7=
ociSc`02oe1[c`;oKGC90_mkN/L2ohN0a@?oTXG20onKR/02ojB>_P;oZi:l00Go[IO0okBK__ndVkko
]9^nokZN_003okjU`0;o`jNm00?ob;32olfb_oo=/[l00_oC_<@00ooF_L7og<S6omc8aP02on?FbP07
onSTc_oYhL[ojnk<onWhb_oPo/CocobioiWQo@02oioKo004oj;Lo?nUe_WoYMKiojKFn0;oZ=3e0_nY
d?@01?nZd?CoZ/caoj[<lOn[bo4Jooooo`0300000?oooooooooo00gooooo00<00000ooooooooool0
3?ooool000Wooooo00@00000oooooooooooooooo4000000=01TI6@030000000c<c<0<c<c00H0<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo
00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00P0c<c<
0ol000060>KViP?o00002P3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI
00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@/000001?ooool00`00003ooooo
ooooo`0Dooooo`;o0000<?ooool00onM_NooWkk_oinnk`02oi^nl003oiNnl_nJ__;oV[kb00;oUKod
0_n>_oL00on6__WoS<3hohc0n002oh>on`;oMkkm0_l>DLd00olnHlooD6_?of9dc`02of9dc`;oNg[7
0_n7P<D2oi:5`P?oVh[000?oY8jnojFC`_n]Ul000on]Ul02okBK_PCo_ZG000Co`jNmolR``_o8/<;o
cK:o0ooC_<@01?oJbLWog<S6on?Fb_oSe/X2onSTcP04onWbcooSo<_oe?jook_f[P;oW][l00CoWm_l
ojCEnOnTeOWoYMKi0_nWd?H01?nXd?GoZ<cbojS<l_nYc?8Oooooo`0300000?oooooooooo00cooooo
00<00000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo4000000=01TI6@030000
000c<c<0<c<c00L0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP03o`00
001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`050;>c/`800000
2`3<c<`6o`0000`0c<c<00?o00000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000
001oOgl0Ogmo00<0Ogmo00?o000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C003o`00
000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT;000000Cooooo00<00000ooooooooool0
5_ooool00ol0003oooooooooo`0^ooooo`03oinnkonP_^koX;k^00;oWKk`00?oV[kboibolOnL_o40
0_nH_o<2oi>om@03ohc0n?nA`OOoTL7g00;oR/7i0_n1`O`2o`11a0;oD6_?0_mRM<l2og=lc@;oQh35
0onBQL800onKR/3oVhk5ojFC`P02ojFC`P?o[IO000?o]9^nokRR`_nhX/800_nnYL001Oo3[/Gob;32
olR``_o8/<;ock_700?odkc400?of/W9on3Hc_oSe/X00ooXi<h00ooYl/oohoc;omCn_`02oj7Cn@04
oj;DnOnUcoKoYLofojK@mP;oYlcc0_nXc?<00onXc?;oooooooooo`0Pooooo`0300000?oooooooooo
00_ooooo00<00000ooooooooool03?ooool000Wooooo00@00000oooooooooooooooo4000000=01TI
6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00ol0000000000;>c/`060;>c
/`030000003<c<`0c<c<01T0c<c<0P0000070;>c/`030000002IVIT0VIVI00@0VIVI00<0000007mo
O`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c
<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@/000001?ooool00`00003oooooooooo`0Goooo
o`03o`000?oooooooooo02kooooo00?oX;k^oj:nkOnR_^d00_nO_^l00onL_o7oW[o`oijol002oi^o
lP;oUl3d00?oTL7goiK1mOnF`OD00_n@`_P2ohW2nP04o`11a?l0Clgo>VODocYWe0;oHWC?00?oLgc=
oh>3bon3Pl/00on@RLP3oi^>a@;oYI?20_n]Ul001On`W/Go^:;2okRR`_nhX/;o_ZG000?o`jk500Go
b;32olnkaoo?^lOock_7om>la002om[9b@09on3Hc_oUj=?oiNSConSTc_oYl/oohoc;omCn_onPd_Wo
XM?i00;oY<of00CoYLofojK;lonVbo?oYlcc9oooool00`00003oooooooooo`0:ooooo`0300000?oo
oooooooo00cooooo0009ooooo`0400000?oooooooooooooooa4000003@0I6AT00`000000<c<c03<c
<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<2000001L0c<c<0P00
00070;>c/`8000001P2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00<0IVIV00<0
000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI2`00
0004ooooo`0300000?oooooooooo01Sooooo00?o0000ooooooooool0;_ooool00onR_^goXkk]oj>n
k@02oj6okP03oijol?nP_nooX;o_00;oWL3`0_nJ`?800onF`OGoV/7coi[1l`02oiK2mP05oi33n?nF
`oKo02b^o`1?cOljIm@00_mBLmH2og=lc@;oPh?;0on@RLP2oi^>a@03ojFC`_nWV/Wo/9k500?o/9k5
0_nhX/801?nm[<Wo`jk5ol>^aOo3[/D3olnka`;oe/W>00?of/W9on3Hc_oPf<h00_oUj=<01OoTmm?o
fOo;ol3j^?nScOKoXlkf00;oYL[c0onVbo<Yooooo`0300000?oooooooooo00_ooooo00<00000oooo
ooooool02oooool000Wooooo00@00000oooooooooooooooo4@00000>01TI6@030000000c<c<0<c<c
00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo
00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`060;>c/`8000004`3<c<`20000
00P0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI
00/06ATI30000004ooooo`0300000?oooooooooo01Wooooo0_l0000`ooooo`03oj>nkOnT_^coY;k/
00;oX[o]00?oX;o_oj:ok_nR_nh00_nP_nl00onM`?7oWl3`oio0l002oig1l@04oi[2m?nF`oKoV/?d
o`0l_0;o6UoF00?oDW?FofQneOmXO]D00_n3Pl/3oi29b003oi^>aOnKULgoYi[900;oYi[90on`W/D0
1OnhX/;o_Jc9okf/bOnm[<Wo`jk500;obK[<00Kock_7omK9c_oFbLkoe/W>omcKe?oPf<h2onGXd`04
onCgdooIol_o`?ZhojG8lP;oYLWb00?oYL[cooooooooool0;?ooool00`00003oooooooooo`0:oooo
o`0300000?oooooooooo00_ooooo0009ooooo`0400000?oooooooooooooooa8000003@0I6AT00ol0
0000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`00
0000Ogmo07moO`0407moO`8000001P2IVIT00ol0000000000;>c/`070;>c/`<00000303<c<`30000
0003o`00002c/k<0/k>c00L0/k>c00?o000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0703<c
<`030000000I6AT06ATI00/06ATI30000004ooooo`0300000?oooooooooo01_ooooo00?o0000oooo
ooooool0;_ooool00onT_^coYKk/ojFnk002ojBok@03oj:ok_nS_ngoXko]00;oX[o^00?oWl3`oj;0
k_nR`>h00_nO`O02oig2lP03oi[3m?l0?;co6UoF00;o>G7L00?oJ7kEogb7domlQm<00on=Sm03oi^E
c@?oYi[900?o/9k5okBYcOnm[<T00_nm[<T01Oo3^M7obK[<olVjc?o9^/cod<[D00?oe/W>00Oog=_D
on3]f_oUj=?oi?OColOnbOnUao;oYLSb03?ooooo00<00000ooooooooool02Oooool00`00003ooooo
ooooo`0;ooooo`002Oooool01000003ooooooooooooooolB000000d06ATI00<0000003<c<`0c<c<0
1`0c<c<00ol00000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0
1@1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00P0/k>c3000000;0;>c/`800000
1`2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0
101<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00/06ATI30000004ooooo`030000
0?oooooooooo01cooooo00?o0000ooooooooool0;_ooool00onU_^coY[k[ojJnj`02ojFnk003oj>o
kOnU_ncoYKo/00;oXko]00?oX/3^oj>okOnS_nd00_nR`>l01_nP`O3oX/7_oj;1kol08YWo057=ocUa
g0;oEh3O0_mlQm<3ohf?d0;oViG=0_nWV/T01OnYYM;o]:W=okBYcOndZLgo_Jc900?o`kWA00KobK[<
om3:e?o@b]Cod<[DomK9c_oLfm@2on3]fP03om_lf?o7o/Wooooo03Kooooo00<00000ooooooooool0
2?ooool00`00003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooolC000000d06ATI
00<0000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV
00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@<000007@2c/k<00`000000VIVI
09VIV@0509VIV@8000001P1oOgl00ol00000IVIV06IVIP0506IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0;01TI6@d000001?ooool00`00003ooooo
ooooo`0Mooooo`03o`000?oooooooooo02kooooo00?oY[k[ojJnj_nV_^X00_nV_^/00onU_ncoYKo[
ojFoj`02ojBok003oj>okOnU_ncoYKo/00;oXl3]00KoX/7_ojC0kOnT`>goXl7_o`0h[_liLM`2oeN0
g`;oLXgN0_n=Sm000onKULgoVioGoi^Oe`03ojVUdP;o]:W=00Co^KOGol>idOo3^M7o`kWA0oo@b]@2
omOMg004omSbh_oPkM[ofocHolOnbCSooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`0;ooooo`002Oooool01000003ooooooooooooooolC000000h06ATI00<0000003<c<`0c<c<01`0c
<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1o
Ogl2000000P0VIVI0P00000H0;>c/`80000000?o000009VIV@2IVIT01@2IVIT00ol00000Ogmo07mo
O`0507moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00ol00000<c<c03<c
<`0603<c<`0300000?l000006ATI00`06ATI3@000004ooooo`0300000?oooooooooo01kooooo0_l0
000_ooooo`03ojJnj_nW_^[oY[k[00;oY[k[00?oYKo[ojJnjonV_^/00_nV_n/00onU_ncoY[o/ojJo
k002ojFok005ojC0kOnU_ncoYKo/ojC0kOl0>:h00omGP=l00ombSMkoRISKohVHf`04oi^Oe`;oZJGB
00Go]:W=okVgeoni]mOo^KOGol>id@02olS;f`03om3:e?oGgMcoemgL00;of?;R00?obokLoooooooo
ool0>Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00_ooooo0009ooooo`040000
0?oooooooooooooooa<000003P0I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00H0
C4a<00?o000006IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0607moO`030000002IVIT0VIVI00L0
VIVI0P00000C0;>c/`<00000202IVIT2000000P0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000
C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6AT=000000Co
oooo00<00000ooooooooool08?ooool00ol0003oooooooooo`0]ooooo`;oYkkZ00GoY[k[ojNnj_nW
_^[oY[k[ojNnjP03ojJnj`03ojJok?nW_n_oYko[00;oY[o/00?oYKo/ojJojonV_n/00_nV`>`01?l0
E/So>X7Wof2Dk?mPU>`2ohVHf`;oVioG00CoVJgUoj^cg_n[/mkoZk?N0_ni]mL2okg9i004olS;foo=
h>KocN3VomOMg0;of?;R00?obokLooooooooool0>oooool00`00003oooooooooo`07ooooo`030000
0?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooooa@000003P0I6AT00`000000<c<c
03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo
07moO`0607moO`8000002@2IVIT3000000`0/k>c1000000:09VIV@030000001oOgl0Ogmo00L0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c
00<0000001TI6@0I6AT02`0I6AT>000000Cooooo00<00000ooooooooool08Oooool00ol0003ooooo
ooooo`0^ooooo`03ojNnjOnW_^[oYkkZ00?oYkkZ00GoY[k[ojNnj_nW_^[oYko[ojNnjP03ojNoj`03
ojJojonW_n_oYko[00;oY[o[00CoG@00o`UhhOmPU>coH9C/0_n0XnX3oiV]i@03oj^cg_n[a^koZlK^
00?o_LWT00Ko_N7aolgPi_o9mNcobOG/ok3jg_mmhK8oooooo`0300000?oooooooooo00Kooooo00<0
0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo5000000>01TI6@030000000c
<c<0<c<c00P0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001o
Ogl0Ogmo00L0Ogmo00<0000009VIV@2IVIT02@2IVIT<000000d0VIVI00<0000007moO`1oOgl01`1o
Ogl00ol00000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01`0c
<c<00`0000006ATI01TI6@0<01TI6@h000001?ooool00`00003oooooooooo`0Rooooo`03o`000?oo
oooooooo02kooooo0_nX_^T01OnW_^[oZ;kYojRnjOnX_^[oYkkZ00;oZ;kZ0_nW_^X01?nW_n_oYkkZ
ojNnj_nW_n/2ojRnjP;oYkoZ00CoYko[o`1L^?lmV??o?ISc0_m//?T00onI[NGoTKofoi6omP03oj_6
kP06okg9i?nmhO7o[_?dojkcm?n3jMKo0000@Oooool00`00003oooooooooo`06ooooo`0300000?oo
oooooooo00[ooooo0009ooooo`0400000?oooooooooooooooaD000003P0I6AT00`000000<c<c03<c
<`0803<c<`03o`00001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH2000000P0Ogmo00<0
0000o`00000000007`2IVIT2000000P0Ogmo0P00000606IVIP8000001`1<C4`00`000000<c<c03<c
<`0803<c<`030000000I6AT06ATI00`06ATI3P000004ooooo`0300000?oooooooooo02?ooooo00?o
0000ooooooooool0;_ooool7ojRnj@05ojRnj_nX_^WoZ;kYojRnjOnW_^X00_nX_^T00onX_^[oZ;kY
ojRnj@02ojRnjP04ojNoj_ooooooooooo`>8g0;oK;3i00?oTKofog[?oomjcol00_nSgO/2oh?Um003
ojkcm?oooooooooo04?ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0:ooooo`00
2Oooool01000003ooooooooooooooolE000000l06ATI00<0000003<c<`0c<c<01`0c<c<00`000000
C4a<04a<C00604a<C003o`0000000000IVIV00H0IVIV0P00000907moO`030000002IVIT0VIVI01T0
VIVI0`00000907moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01`1<C4`00`000000
<c<c03<c<`0703<c<`030000000I6AT06ATI00d06ATI3P000004ooooo`0300000?oooooooooo02Co
oooo0_l0000_oooooa3oZ;kY2_ooool2odG4i4[ooooo00<00000ooooooooool01?ooool00`00003o
ooooooooo`0:ooooo`002Oooool01000003ooooooooooooooolF000000l06ATI00<0000003<c<`0c
<c<01`0c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00H0IVIV0P00000807moO`<0
00005P2IVIT2000000X0Ogmo0P00000706IVIP030000001<C4`0C4a<00L0C4a<00?o000003<c<`0c
<c<01`0c<c<00ol000006ATI01TI6@0=01TI6@l000001?ooool00`00003oooooooooo`0Vooooo`03
o`000?oooooooooo02gooooo0_nY_NP00onX_^WoZKgXojVmj002ojVnj@03ojRnjOnY_^WoZKkY00?o
Z;kYF?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo00[ooooo0009ooooo`040000
0?oooooooooooooooaL000003`0I6AT00`000000<c<c03<c<`0703<c<`0300000?l00000C4a<00L0
C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0807moO`@0000000?o000000000000
00002@2IVIT300000003o`0000000000000000/0Ogmo00?o000006IVIP1VIVH01P1VIVH00`000000
C4a<04a<C00704a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT03@0I6AT@000000Co
oooo00<00000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`GoZKgX0_nY_^P00onY_^Wo
ooooooooo`1Kooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02_ooool000Wooooo
00@00000oooooooooooooooo5`00000?01TI6@030000000c<c<0<c<c00T0<c<c00<0000004a<C01<
C4`01P1<C4`00ol00000000006IVIP0706IVIP03o`0000000000Ogmo00h0Ogmo2@00000?07moO`80
0000201VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I
6AT03@0I6AT@000000Cooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`0]ooooo`?o
ZKgXH_ooool00`00003oooooooooo`03ooooo`0300000?oooooooooo00Wooooo0009ooooo`040000
0?oooooooooooooooaP000003`0I6AT00`000000<c<c03<c<`0903<c<`030000001<C4`0C4a<00L0
C4a<00<0000006IVIP1VIVH01`1VIVH2000002<0Ogmo0P00000906IVIP030000001<C4`0C4a<00L0
C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0=01TI6A4000001?ooool00`00003o
ooooooooo`0Yooooo`;o0000;Oooool00ol0003oooooooooo`1Sooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo6@00000?01TI6@03
0000000c<c<0<c<c00T0<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0806IVIP<0
00007P1oOgl2000000X0IVIV00?o000004a<C01<C4`01`1<C4`00ol00000<c<c03<c<`0903<c<`03
0000000I6AT06ATI00d06ATI00?o00000000000000003P000004ooooo`0300000?oooooooooo02_o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Sooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool02Oooool000Wooooo00@00000oooooooooooooooo6@0000000ol00000
6ATI01TI6@0=01TI6@030000000c<c<0<c<c00P0<c<c00?o00000000001<C4`0201<C4`00ol00000
00000000000:06IVIP<000005`1oOgl4000000X0IVIV0P00000904a<C0030000000c<c<0<c<c00T0
<c<c00<0000001TI6@0I6AT03@0I6ATB000000Cooooo00<00000ooooooooool0;?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00D00000oooooooooooooooo0000000;oooo
o`002Oooool01000003ooooooooooooooolJ000001006ATI00<0000003<c<`0c<c<02@0c<c<00`00
0000C4a<04a<C00904a<C08000002`1VIVH400000100Ogmo0`00000;06IVIP<000002P1<C4`00`00
0000<c<c03<c<`0903<c<`030000000I6AT06ATI00h06ATI4P000004ooooo`0300000?oooooooooo
02gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Uooooo`0400000?oooooooooo
000000_ooooo0009ooooo`0400000?oooooooooooooooa/00000400I6AT00`000000<c<c03<c<`09
03<c<`8000002`1<C4`00`000000IVIV06IVIP0<06IVIQ0000003@1VIVH00`000000C4a<04a<C009
04a<C08000002`0c<c<00`0000006ATI01TI6@0>01TI6A<000001?ooool00`00003oooooooooo`0^
ooooo`;o0000:?ooool00ol0003oooooooooo`1Vooooo`0300000?ooool0000000_ooooo0009oooo
o`0400000?oooooooooooooooa`00000400I6AT00`00003o000003<c<`0:03<c<`8000002P1<C4`0
1000003o000000000000000U06IVIP8000002`1<C4`00`000000<c<c03<c<`0:03<c<`03o`00000I
6AT06ATI00h06ATI00?o00000000000000004@000004ooooo`0300000?oooooooooo033ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1Vooooo`0300000?ooool0000000_ooooo0009
ooooo`0400000?oooooooooooooooa`000004P0I6AT00`000000<c<c03<c<`0:03<c<`800000301<
C4`300000200IVIV0P00000<04a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT03P0I
6ATE000000Cooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo06Oooooo00<00000ooooo`0000002_ooool000Wooooo00@00000oooooooooooooooo7@00
000B01TI6@030000000c<c<0<c<c00/0<c<c00<0000004a<C01<C4`0301<C4`3000001/0IVIV0P00
000<04a<C0800000300c<c<00`0000006ATI01TI6@0?01TI6AD000001?ooool00`00003ooooooooo
o`0booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0J?ooool2000000[ooooo0009
ooooo`0400000?oooooooooooooooah000004P0I6AT00`000000<c<c03<c<`0;03<c<`030000001<
C4`0C4a<00h0C4a<0P00000E06IVIP@000003@1<C4`00`000000<c<c03<c<`0;03<c<`030000000I
6AT06ATI00l06ATI5P000004ooooo`0300000?oooooooooo03?ooooo0_l0000Sooooo`03o`000?oo
oooooooo06Oooooo0_l000000`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooo
oolO00000003o`00000I6AT06ATI00l06ATI00?o00000000000c<c<02`0c<c<00ol0000000000000
000?04a<C003o`0000000000000000D000000`1VIVH:000000l0C4a<0P00000<03<c<`8000004P0I
6ATF000000Cooooo00<00000ooooooooool0=Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo06?ooooo1?l0000=ooooo`002Oooool01000003ooooooooooooooolQ000001806ATI00<0
000003<c<`0c<c<0300c<c<2000001D0C4a<0`00000G04a<C08000003@0c<c<00`0000006ATI01TI
6@0A01TI6AL000001?ooool00`00003oooooooooo`0fooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0H?ooool3o`00017ooooo0009ooooo`0400000?ooooooooooooooob8000004P0I
6AT00`000000<c<c03<c<`0=03<c<`030000001<C4`0C4a<02X0C4a<0P00000>03<c<`030000000I
6AT06ATI01406ATI00?o00000000000000005@000004ooooo`0300000?oooooooooo03Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`Co00005?ooool000Wooooo00@00000
oooooooooooooooo8`00000B01TI6@03o`0000000000<c<c00d0<c<c1000000T04a<C0@000003`0c
<c<00`0000006ATI01TI6@0A01TI6AT000001?ooool00`00003oooooooooo`0hooooo`;o00007_oo
ool00ol0003oooooooooo`1Hooooo`Co00006?ooool000Wooooo00@00000oooooooooooooooo8P00
00000ol000006ATI01TI6@0B01TI6@800000400c<c<3000001h0C4a<0`00000B03<c<`030000000I
6AT06ATI01806ATI6@000004ooooo`0300000?oooooooooo03[ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Dooooo`Co00007?ooool000Wooooo00@00000oooooooooooooooo9000
000E01TI6@8000004@0c<c<3000001L0C4a<1000000D03<c<`030000000I6AT06ATI01806ATI6P00
0004ooooo`0300000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`1Aooooo`?o00008?ooool000Wooooo00@00000oooooooooooooooo9@00000F01TI6@030000000c
<c<0<c<c0140<c<c1`00000;04a<C003o`00000000000000008000005P0c<c<2000001@06ATI00?o
000000000000000060000004ooooo`0300000?oooooooooo03cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1=ooooo`Co00008oooool000Wooooo00@00000oooooooooooooooo9P00
00000ol000006ATI01TI6@0B01TI6@03o`0000000000000001P0<c<c00<00000o`00000000002000
000I03<c<`800000500I6ATM000000Cooooo00<00000ooooooooool0?Oooool2o`0001Wooooo00?o
0000ooooooooool0BOooool4o`0002Oooooo0009ooooo`0400000?ooooooooooooooobP000005P0I
6AT2000003P0<c<c0P00000E01TI6Ah000001?ooool00`00003oooooooooo`0oooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0002_ooooo0009ooooo`0400000?oooooo
ooooooooobT000005`0I6AT2000003<0<c<c0`00000F01TI6@03o`0000000000000001`000001?oo
ool00`00003oooooooooo`10ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@ooo
ool3o`0002oooooo0009ooooo`0400000?ooooooooooooooobX0000000?o00000000000I6AT05@0I
6AT00`00003o00000000000^03<c<`800000600I6ATP000000Cooooo00<00000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03oooooo1?l0000booooo`002Oooool0
1000003oooooooooooooool]000001P06ATI0`00000Y03<c<`8000006@0I6ATQ000000Cooooo00<0
0000ooooooooool0@_ooool2o`0001?ooooo00?o0000ooooooooool0>oooool4o`0003Kooooo0009
ooooo`0400000?ooooooooooooooobh000006P0I6AT400000240<c<c1000000J01TI6B8000001?oo
ool00`00003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=ooo
ool4o`0003[ooooo0009ooooo`0400000?ooooooooooooooobh000007P0I6AT3000001/0<c<c0`00
000M01TI6B<000001?ooool00`00003oooooooooo`15ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0<oooool4o`0003kooooo0009ooooo`0400000?oooooooooooooooc0000007`0I
6AT00`00003o000000000004000000d0<c<c1`00000N01TI6BD000001?ooool00`00003ooooooooo
o`16ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool3o`0004;ooooo0009
ooooo`0400000?oooooooooooooooc800000900I6AT=000002<06ATI9`000004ooooo`0300000?oo
oooooooo04Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOoo
ool000Wooooo00@00000oooooooooooooooo=000001A01TI6BP000001?ooool00`00003ooooooooo
o`18ooooo`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000BOooool000Wooooo00@00000
oooooooooooooooo=P00001<01TI6@80000000?o00000000000000009P000004ooooo`0300000?oo
oooooooo04[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`Co0000COoo
ool000Wooooo00@00000oooooooooooooooo=`00001:01TI6B`000001?ooool00`00003ooooooooo
o`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo0009
ooooo`0400000?ooooooooooooooocX00000A@0I6AT^000000Cooooo00<00000ooooooooool0C?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0001Dooooo`002Oooool0
1000003oooooooooooooooll000004406ATI00?o0000000000000000;@000004ooooo`0300000?oo
oooooooo04gooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0001Hooooo`002Oooool0
1000003ooooooooooooooolk00000003o`0000000000000003d06ATI<P000004ooooo`0300000?oo
oooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?oo
ool000Wooooo00@00000oooooooooooooooo@@00000g01TI6CD000001?ooool00`00003ooooooooo
o`1@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool3o`00063ooooo0009
ooooo`0400000?ooooooooooooooodD00000<00I6ATh000000Cooooo00<00000ooooooooool0DOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0001Sooooo`002Oooool0
1000003ooooooooooooooom8000002T06ATI0P0000000ol0000000000000000g000000Cooooo00<0
0000ooooooooool0D_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0006Oooooo0009
ooooo`0400000?oooooooooooooood`000008@0I6AU0000000Cooooo00<00000ooooooooool0E?oo
ool01?l0003oooooooooool00008ooooo`Co0000Joooool000Wooooo00@00000oooooooooooooooo
D`00000G01TI6D<000001?ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo000000Gooooo
0ol0001_ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
E_ooool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo05Oooooo0_l0001fooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooo
ooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0
coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo
0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@0
0000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00<00000ooooooooool0/_oo
ool00`00003oooooooooo`3?ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo]P00003Aooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAoooo
o`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf0000017ooooo]_l0000:
ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool0Coooool;000005Sooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo2`00000;
ooooo`P00000D?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2boooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool3000001kooooo1`000019oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooooooo
ool03oooool00ol0003oooooooooo`0mooooo`@00000:?ooool3000004Kooooo00?o0000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo03Wooooo00@00000o`00000000000000;oooool4000004;ooooo00?o0000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo03Oooooo0P00000gooooo`800000@?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0=Ooo
ool2000003_ooooo0P00000nooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo0;;ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0cooooo`800000?oooool2
000003cooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo02oooooo00@00000o`00000000000000@oooool0
0ol0000000000000000iooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`0300000?oooooooooo
04Sooooo0P00000gooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;o
oooo00<00000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`800000COooool2000003Go
oooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0C?oooolI0?nf`Dgooooo
00<00000ooooooooool03oooool00ol0003oooooooooo`0Zooooo`8000008?oooolI0?nf`ASooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`19oooooal0okK1B_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00<0
0000ooooooooool07OoooolO0?nf`AKooooo0P00000booooo`03o`000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo04Kooooo9@3o]/57ooooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0:?ooool00`00003oooooooooo`0Kooooo`T0okK12`00000A0?nf`AGooooo0P00000`
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04?ooooo:`3o]/54oooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool09oooool00`00003oooooooooo`0Ioooo
o`D0okK11`00000;0?nf`@P00000303o]/4Dooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0@?oooola0?nf`D7ooooo00<00000oooooooo
ool03oooool00ol0003oooooooooo`0Tooooo`0300000?l00000000001Wooooo103o]/401000003o
0000o`000000000J0?nf`@03o`0000000000000000@00000203o]/4Booooo`800000;Oooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0mooooocL0okK1?_ooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00<00000ooooooooool05oooool40?nf`@<0
00009@3o]/42000000T0okK14Oooool00`00003oooooooooo`0Zooooo`03o`000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo03[ooooo>`3o]/4mooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool08_ooool00`00003oooooooooo`0Eooooo`<0okK11000000Z0?nf`@800000
203o]/4Aooooo`800000:_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`0iooooocd0okK1??ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool05Oooool0103o]/7o000000000000000`0?nf`@80000000?o00000?nf`@3o]/40
103o]/4Booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0=ooooom20?nf`CWooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`0Pooooo`0300000?oooooooooo01Cooooo0P3o]/400`000000okK10?nf`@0d0?nf`@8000001`3o
]/4@ooooo`0300000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0=Ooooom60?nf`COooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0O
ooooo`0300000?oooooooooo01?ooooo00@0okK10000000000000000>@3o]/42000000L0okK13ooo
ool00`00003oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo03CoooooB03o]/4fooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool07_ooool0
0`00003oooooooooo`0Cooooo`8000006@3o]/4;000001X0okK10P0000060?nf`@oooooo00<00000
ooooooooool09?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0coooo
odX0okK1=Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00<00000oooo
ooooool04_ooool00`00003o00000?nf`@0C0?nf`@@000000_l000000`000000okK10?nf`@090?nf
`@@0000000Co00000000000000000000503o]/400ol00000okK10?nf`@040?nf`@oooooo00?o0000
00000?ooool08oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0boooo
od`0okK1=?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00<00000oooo
ooooool04_ooool00`000000okK10?nf`@0@0?nf`@@000006P3o]/4300000180okK10P0000050?nf
`A3ooooo00<00000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`0`oooooe00okK1<_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01_o
oooo00<00000ooooooooool04Oooool200000100okK10`00000Q0?nf`@@00000403o]/42000000D0
okK13oooool00`00003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo02ooooooDP3o]/4aooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Aooooo`030000003o]/40okK100h0okK10P00000X0?nf`@@00000
3P3o]/400ol0000000000?nf`@030?nf`@oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0^oooooe@0okK1<?ooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo00<00000ooooooooool04?ooool00ol00000okK10?nf
`@0=0?nf`@80000000?o00000?nf`@3o]/40:`3o]/42000000h0okK100<000000?nf`@3o]/400P3o
]/4>ooooo`0300000?oooooooooo01oooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0;OoooomF0?nf`Boooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0I
ooooo`0300000?oooooooooo013ooooo00<000000?nf`@3o]/402`3o]/4300000380okK100<00000
0?nf`@3o]/40303o]/42000000<0okK13_ooool00`00003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo02coooooF03o]/4^ooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool06?ooool00`00003oooooooooo`0@ooooo`030000003o]/40okK1
00/0okK100<000000?nf`@3o]/403`3o]/4C00000180okK10P00000>0?nf`@040000003o]/40okK1
0?nf`@kooooo00<00000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0[oooooeX0okK1;Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool03oooool00ol0000000000?nf`@0;0?nf`@8000003`3o]/430000
01<0okK10`0000001?l00000000000000000000=0?nf`@8000003@3o]/401?l00000okK10?nf`@3o
]/4>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0:_oooomK0?nf`Bgooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0G
ooooo`0300000?oooooooooo00oooooo00<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0;
0?nf`@@000007@3o]/43000000`0okK10P00000<0?nf`@030000003o]/40okK100oooooo00<00000
ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Zoooo
oe`0okK1;?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00<00000oooo
ooooool03oooool00`00003ooooo0?nf`@0:0?nf`@030000003o]/40okK100T0okK10`00000T0?nf
`@030000003o]/40okK100/0okK100<000000?nf`@3o]/402P3o]/400`000000okK10?nf`@0>oooo
o`0300000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0:OoooomN0?nf`B_ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03
00000?oooooooooo00kooooo00<00000ooooo`3o]/402P3o]/400`000000okK10?nf`@090?nf`@03
0000003o]/40okK102H0okK10P00000<0?nf`@03o`00003o]/40okK100X0okK100<000000?nf`@3o
]/403_ooool00`00003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo02SoooooH03o]/4Zooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
5Oooool00`00003oooooooooo`0>ooooo`0300000?ooool0okK100T0okK100<00000o`00003o]/40
2@3o]/4200000180okK12000000A0?nf`@@000002@3o]/42000000/0okK100?o00000000003o]/40
3_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo02OoooooHP3o]/4Yooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0>ooooo`0300000?ooool0okK100T0okK100<000000?nf`@3o]/40203o
]/42000000d0okK11`0000080?nf`@P000003@3o]/400`000000okK10?nf`@080?nf`@030000003o
]/40okK100T0okK100<000000?nf`@3o]/403_ooool00`00003oooooooooo`0Hooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo02KoooooH`3o]/4Yooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool05?ooool00`00003oooooooooo`0=ooooo`0300000?ooool0
okK100T0okK100<000000?nf`@3o]/401`3o]/42000000`0okK10`00000G0?nf`@<000002`3o]/42
000000T0okK100?o00000?nf`@3o]/402@3o]/400`000000okK1ooooo`0>ooooo`0300000?oooooo
oooo01Oooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool09_oooomT0?nf
`BSooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`0300000?oooooooooo
00gooooo00<00000ooooooooool02@3o]/400ol00000okK10?nf`@070?nf`@030000003o]/40okK1
00T0okK100<00000o`00000000007@3o]/43000000X0okK10P0000080?nf`@030000003o]/40okK1
00T0okK100?o00000?nf`Oooool03_ooool00`00003oooooooooo`0Fooooo`03o`000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo02GoooooIP3o]/4Wooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool04oooool00`00003oooooooooo`0<ooooo`03o`000?oooooooooo00T0
okK100<000000?nf`@3o]/401`3o]/400ol00000okK10?nf`@080?nf`@8000008`3o]/400`000000
okK10?nf`@090?nf`@030000003o]/40okK100H0okK100<000000?nf`@3o]/402@3o]/400`000000
okK1ooooo`0=ooooo`0300000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo
00<00000ooooooooool09?oooomW0?nf`BOooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`0Booooo`0300000?oooooooooo00gooooo00<00000ooooo`3o]/40203o]/400`000000okK1
0?nf`@070?nf`@030000003o]/40okK100L0okK10P00000?0?nf`@P000003`3o]/43000000T0okK1
00<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@080?nf`@030000003o]/7ooooo00kooooo
00<00000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`0TooooofP0okK19_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00<0
0000ooooooooool03?ooool00`00003oooooooooo`090?nf`@030000003o]/40okK100H0okK100<0
00000?nf`@3o]/401`3o]/400`000000okK10?nf`@0:0?nf`@03o`0000000000000000800000203o
]/4500000003o`00003o]/40okK100X0okK100<00000o`00003o]/401`3o]/400`000000okK10?nf
`@060?nf`@030000003o]/40okK100P0okK100<000000?nf`Oooool03_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02?ooooo;P3o]/4:
0000oc40okK19_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00<00000
ooooooooool03Oooool00`00003ooooo0?nf`@070?nf`@800000203o]/400`000000okK10?nf`@06
0?nf`@800000203o]/4400000003o`00003o]/40okK10140okK1100000090?nf`@800000203o]/42
000000L0okK100<000000?nf`@3o]/40203o]/400`00003oooooooooo`0=ooooo`0300000?oooooo
oooo01Cooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool08ooooolY0?nf
`AL0003o:P3o]/4Uooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00`00
003oooooooooo`0=ooooo`0300000?ooool0okK100H0okK100<000000?nf`@3o]/401`3o]/400ol0
0000okK10?nf`@050?nf`@8000002@3o]/400`000000okK10?nf`@0J0?nf`@8000002@3o]/400`00
0000okK10?nf`@070?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/40203o]/400`00
003oooooooooo`0<ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool08_oooolU0?nf`@D0003o00<0okK10000o`000?l01P000?l90?nf`@L0
003o:@3o]/4Tooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003o
ooooooooo`0=ooooo`0300000?ooool0okK100H0okK100<000000?nf`@3o]/401`3o]/400`000000
okK10?nf`@050?nf`@030000003o]/40okK100L0okK10P00000O0?nf`@<000001`3o]/42000000P0
okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@080?nf`@03o`000?oooooooooo00co
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0Qooooob@0okK100?o003o0000o`3o]/400`3o]/440000o`;o003o0`000?l7o`00o`H0okK1
0P000?l00`3o]/40003o0000o`020000obH0okK19?ooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo00oooooo00<00000ooooooooool03Oooool00`00003ooooo0?nf`@070?nf`@03o`00
003o]/40okK100H0okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@060?nf`@800000
3@3o]/48000000l0okK10P0000070?nf`@8000001`3o]/400`000000okK10?nf`@050?nf`@030000
003o]/40okK100P0okK100<00000ooooooooool03?ooool00`00003oooooooooo`0Booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo027ooooo8P3o]/400`000?oo003o0?nf
`@020?nf`@H0003o00?o003o0000o`000?l02@3o]/46o`00o`<0okK10P000?l20?nf`@<0003o9@3o
]/4Sooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool03oooool00`00003ooooooooo
o`0=ooooo`0300000?ooool0okK100L0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK100D0okK100<00000o`00003o]/402`3o]/43000000P0okK12000
00090?nf`@8000001`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100H0okK100<0
00000?nf`@3o]/401`3o]/400`00003oooooooooo`0<ooooo`0300000?oooooooooo01;ooooo00?o
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool08?oooolQ0?nf`@80003o0`3o]/46
0000oa@0okK10ol00?l20?nf`@80003o0`3o]/420000ob<0okK18oooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool03?ooool00`00003ooooo0?nf`@07
0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@05
0?nf`@030000003o]/40okK100P0okK11000000C0?nf`@8000002@3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@07
0?nf`@0300000?oooooooooo00cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0Pooooob00okK100@0003o0?nf`@3o]/40okK110000?lK
0?nf`@;o003o0P3o]/420000o`<0okK10P000?lR0?nf`B;ooooo00<00000ooooooooool03oooool0
0ol0003oooooooooo`0>ooooo`0300000?oooooooooo00gooooo00<00000ooooo`3o]/401`3o]/40
0`000000okK10?nf`@050?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/40
0`000000okK10?nf`@070?nf`@03o`0000000000okK101P0okK100<000000?nf`@3o]/401`3o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/401P3o]/40
0ol00000okK10?nf`@060?nf`@0300000?oooooooooo00cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Oooooob00okK100<0003o0?nf
`@3o]/401@000?lN0?nf`@?o003o00<0okK10000o`3o]/400`3o]/400`000?l0okK10?nf`@0P0?nf
`B7ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`0300000?oooooooooo
00cooooo00<00000ooooo`3o]/401`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/401@3o]/400ol00000okK10?nf`@060?nf`@0300000?l00000okK1
01/0okK100?o00000000000000001`3o]/400ol00000okK10?nf`@040?nf`@03o`00003o]/40okK1
00D0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@070?nf`@0300000?oooooooooo
00cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`0Nooooob00okK100<0003o0?nf`@3o]/400`000?l00`3o]/40003o0?nf`@0P0?nf`@;o
003o00<0okK1o`00o`000?l00`3o]/400`000?l0okK10?nf`@0O0?nf`B7ooooo00<00000oooooooo
ool03oooool00ol0003oooooooooo`0>ooooo`0300000?oooooooooo00cooooo00<000000?nf`@3o
]/401P3o]/400ol00000okK10?nf`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@050?nf`@8000003`3o]/44000000h0okK100<000000?nf`@3o
]/401@3o]/42000000D0okK10P0000060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/401`3o]/400`00003oooooooooo`0<ooooo`0300000?oooooooooo013ooooo00?o0000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool07_oooolO0?nf`@040000o`3o]/40okK1o`00o`80
003o00<0okK10000o`3o]/408`3o]/401?l00?l0okK10?nf`@000?l30?nf`@030000o`3o]/40okK1
01l0okK18?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00<00000oooo
ooooool03?ooool00`00003ooooo0?nf`@070?nf`@030000003o]/40okK100D0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK10P00000:0?nf
`@L00000103o]/44000000/0okK10P0000070?nf`@030000003o]/40okK100@0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100L0okK100<00000oooo
ooooool03?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo01gooooo7`3o]/400`000?l0okK10?nf`@030000o`030?nf`@000?l0okK102D0
okK10_l00?l00`3o]/40003o0?nf`@020?nf`@030000o`3o]/40okK101h0okK18?ooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00`00003o
oooo0?nf`@070?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401`3o]/400`00003o
00000000000?0?nf`@<0000000?o00000?nf`@3o]/401`3o]/400`000000okK10?nf`@050?nf`@03
o`00003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@03
o`00003o]/40okK100L0okK100<00000ooooooooool03?ooool00`00003oooooooooo`0>ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01gooooo7P3o]/400`000?l0okK1
0?nf`@030000o`030?nf`@000?l0okK10100okK11`3ooolA0?nf`@03o`00o`3o]/40003o00<0okK1
00<0003o0?nf`@3o]/407@3o]/4Pooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
3Oooool00`00003oooooooooo`0;ooooo`03o`000?ooool0okK100L0okK100<000000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40
103o]/400`000000okK10?nf`@050?nf`@800000203o]/470?ooo`L0okK10P0000080?nf`@030000
003o]/40okK100D0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK100D0okK100<000000?nf`@3o]/401P3o]/400`00003oooooooooo`0<ooooo`030000
0?oooooooooo00kooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool07Ooo
oolM0?nf`@030000o`3o]/40okK100<0003o00<0okK10000o`3o]/403@3o]/4?0?ooo`h0okK100?o
003o0?nf`Ol00?l00`3o]/400ol00?l0003o0?nf`@0M0?nf`Aoooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`0=ooooo`0300000?oooooooooo00_ooooo00<00000ooooo`3o]/401`3o
]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK10P0000060?nf`@l0oooo1@3o
]/42000000L0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o
]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@070?nf`@0300000?oo
oooooooo00_ooooo00<00000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0Loooooad0okK100<0003o0?nf`@3o]/400`000?l00`3o]/40003o0?nf`@0<
0?nf`A<0oooo3@3o]/400ol00?l0okK10000o`030?nf`@80003o7@3o]/4Oooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool03?ooool00`00003oooooooooo`0;ooooo`0300000?ooool0
okK100L0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100@0okK14`3oool50?nf`@03o`00003o]/40okK100D0okK100<000000?nf`@3o]/40103o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/40
0`000000okK10?nf`@060?nf`@0300000?oooooooooo00cooooo00<00000ooooooooool03Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Loooooad0okK100<0003o0?nf
`@3o]/400`000?l00`3o]/40003o0?nf`@0:0?nf`AL0oooo303o]/400ol00?l0003o0?nf`@020?nf
`@80003o7@3o]/4Oooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool03?ooool00`00
003oooooooooo`0;ooooo`0300000?ooool0okK100L0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@040?nf`@030000003o]/40okK100<0okK11P3oool<o`0000D0oooo103o]/420000
00H0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK1
00@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@060?nf`@03ooooo`00003ooooo
00cooooo00<00000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`0Loooooa`0okK100<0003o0?nf`@3o]/400`000?l00`3o]/40003o0?nf`@0:0?nf`AX0
oooo2P3o]/400ol00?l0okK10000o`030?nf`@80003o7@3o]/4Nooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool03?ooool00`00003oooooooooo`0;ooooo`0300000?ooool0okK100L0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0
okK100?o00000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0
okK1103oool3o`0000`0oooo0ol000040?ooo`@0okK10P0000050?nf`@030000003o]/40okK100<0
okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/401`3o]/400`00003oooooooooo`0;ooooo`0300000?oooooooooo00go
oooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool06ooooolM0?nf`@040000
o`3o]/40003o0?nf`@<0003o2`3o]/4L0?ooo`X0okK100?o003o0?nf`@000?l00`3o]/420000oa`0
okK17_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00<00000oooooooo
ool02oooool00`00003ooooo0?nf`@070?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@030?nf`@@0oooo00?o00000?ooo`3oool0403oool00ol00000
oooo0?ooo`020?ooo`D0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@03
o`00003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@03
0000003o]/40okK100H0okK100?ooooo00000?ooool03?ooool00`00003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01_ooooo703o]/400`000?l0okK1
0?nf`@020000o`030?nf`@000?l0003o00X0okK17P3oool:0?nf`@03o`00o`000?l0okK100<0okK1
00<0003oo`00o`3o]/406P3o]/4Nooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
2oooool00`00003oooooooooo`0;ooooo`0300000?ooool0okK100H0okK100<000000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK10P3oool3o`0001@0oooo
0ol000020?ooo`D0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK100<0okK100?o00000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK100D0okK100?ooooo00000?ooool03?ooool00`00003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01_ooooo703o]/401Ol00?l0okK10000
o`000?l0okK10080003o2P3o]/4P0?ooo`X0okK100?o003o0000o`3o]/400`3o]/400`000?l0okK1
0?nf`@0I0?nf`Akooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`030000
0?oooooooooo00_ooooo00<00000ooooo`3o]/401P3o]/400ol00000okK10?nf`@040?nf`@03o`00
003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK100<0okK100?o00000?nf`@3o]/400`3o]/420?ooo`03o`00003oool0oooo01P0oooo
00?o00000?ooo`3oool0103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK1
00<000000?nf`@3o]/401@3o]/400oooool00000ooooo`0<ooooo`0300000?oooooooooo00cooooo
00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool06ooooolL0?nf`@050000o`3o
]/40003oo`00o`3o]/400P000?l:0?nf`B00oooo2P3o]/400ol00?l0003o0?nf`@030?nf`@030000
o`3o]/40okK101T0okK17_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo
00<00000ooooooooool02oooool00`00003ooooo0?nf`@060?nf`@030000003o]/40okK100@0okK1
00<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030?ooool00000oooo01/0oooo
00?o00000?ooo`3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100@0okK1
00<000000?nf`@3o]/40103o]/400oooool00000ooooo`0<ooooo`0300000?oooooooooo00cooooo
00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool06ooooolK0?nf`@050000o`3o
]/40003oo`00o`3o]/400P000?l90?nf`B<0oooo2P3o]/400ol00?l0003o0?nf`@030?nf`@030000
o`3o]/40okK101P0okK17_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo
00<00000ooooooooool02oooool00`00003ooooo0?nf`@060?nf`@030000003o]/40okK100@0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@<0oooo00?o00000?ooo`3oool0
6P3oool00ol00000oooo0?ooo`040?nf`@030000003o]/40okK100@0okK100?o00000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40
103o]/400`000000okK10?nf`@040?nf`@;ooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01_ooooo6`3o
]/420000o`03o`00o`3o]/40okK10080003o203o]/4U0?ooo`X0okK100?o003o0000o`3o]/400P3o
]/420000oaX0okK17Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00<0
0000ooooooooool02oooool00`00003ooooo0?nf`@060?nf`@030000003o]/40okK100@0okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<0
00000?nf`@3o]/40103o]/4010000000okK10?nf`@3o]/430?ooo`03o`00003oool0oooo00P0oooo
2_l0000:0?ooo`03o`00003oool0oooo00@0okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@030?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK100D0okK100?ooooo00000?ooool03?ooool00`00003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01[ooooo6`3o
]/400`000?oo003oo`00o`020?nf`@030000ool00?l0okK100P0okK19@3oool;0?nf`@03o`00o`00
0?l0okK10080okK10P000?lI0?nf`Agooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`0;ooooo`0300000?oooooooooo00_ooooo00<000000?nf`@3o]/401P3o]/400`000000okK10?nf
`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK100@0okK100@000000?nf`@3o]/40okK10`3oool00ol00000oooo
0?ooo`060?ooo`;o00002P3oool2o`0000T0oooo00?o00000?ooo`3o]/400`3o]/400`000000okK1
0?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400oooool00000
ooooo`0<ooooo`0300000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool06_oooolK0?nf`@030000ool00?oo003o0080okK10P000?l80?nf`BL0oooo2P3o
]/400ol00?l0003o0?nf`@020?nf`@80003o6@3o]/4Mooooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool00`00003oooooooooo`0;ooooo`0300000?ooool0okK100H0okK100<0
00000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@040000003o]/40okK10?nf`@<0oooo
00?o00000?ooo`3oool01@3oool2o`0000h0oooo0_l000080?ooo`03o`00003oool0okK100<0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK1
0_ooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool06_oooolK0?nf`@030000ool00?oo003o0080okK10P00
0?l80?nf`BL0oooo2`3o]/4010000?l0okK10?nf`@3o]/420000oaT0okK17Oooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool02oooool00`00003ooooo
0?nf`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@030?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@020?nf`@030?ooool0003o000000L0oooo00?o00000?ooo`3oool0403oool00ol00000oooo
0?ooo`060?ooo`03o`00003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK100@0okK10_ooool00ol0003oooooooooo`0;ooooo`030000
0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool06_oo
oolJ0?nf`@050000ool00?l0okK1o`00o`3o]/400P000?l80?nf`BT0oooo2P3o]/400ol00?l0003o
0?nf`@020?nf`@80003o603o]/4Mooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
2_ooool00`00003oooooooooo`0;ooooo`0300000?ooool0okK100H0okK100<000000?nf`@3o]/40
103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@030?nf`@040000003o]/40okK10?nf`@80oooo00?o00000?ooo`3o
ool01P3oool00ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3o
]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/40103o]/42ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`0JoooooaX0okK100<0003oo`00ool00?l0
0P3o]/420000o`P0okK1:@3oool:0?nf`@03o`00o`000?l0okK10080okK10P000?lH0?nf`Agooooo
00<00000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00_ooooo
00<00000ooooo`3o]/401P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK1
00@000000?nf`@3o]/40okK10P3oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0oooo0180
oooo00?o00000?ooo`3oool01P3oool00ol00000okK10?nf`@030?nf`@030000003o]/40okK10080
okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@;ooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo01[ooooo6P3o]/400`000?oo003oo`00o`020?nf`@80003o203o]/4Y0?ooo`/0okK1
00@0003o0?nf`@3o]/40okK10P000?lH0?nf`Agooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`0:ooooo`0300000?oooooooooo00_ooooo00<00000ooooo`3o]/401P3o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@030?nf`@030000003o]/40okK100<0okK100H000000?nf`@3o]/40okK10?ooool00008
0?ooo`03o`00003oool0oooo01<0oooo00?o00000?ooo`3oool01@3oool00ol00000okK10?nf`@03
0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@02
0?nf`@03o`00003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@03
0?nf`@?ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo01[ooooo6P3o]/400`000?oo003oo`00o`020?nf
`@80003o203o]/4Y0?ooo`/0okK100@0003o0?nf`@3o]/40okK10P000?lH0?nf`Agooooo00<00000
ooooooooool03oooool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00_ooooo00<00000
ooooo`3o]/401P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/400P3o]/400`3ooooo00000?ooo`060?ooo`03o`00003oool0oooo01D0oooo00?o0000
0?ooo`3oool01@3oool00ol00000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@?ooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
01[ooooo6P3o]/400`000?oo003oo`00o`020?nf`@80003o1`3o]/4[0?ooo`X0okK100L0003oo`00
o`3o]/40okK10000o`3o]/40003o01L0okK17Oooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo00[ooooo00<00000ooooooooool02oooool00`00003ooooo0?nf`@060?nf`@030000003o
]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o
]/40okK100<0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf`@3o]/420?ooo`03o`00
003oool0oooo00D0oooo00?o00000?ooo`3oool05@3oool00ol00000oooo0?ooo`050?ooo`03o`00
003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000
003o]/40okK100<0okK10oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool06_oooolJ0?nf`@030000ool0
0?l0okK10080okK10P000?l70?nf`A<0oooo0`000000103oool0000000000000000A0?ooo`/0okK1
00@0003o0?nf`@3o]/40okK10P000?lG0?nf`Agooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`0:ooooo`0300000?oooooooooo00_ooooo00<00000ooooo`3o]/401P3o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000
okK10?nf`@030?nf`@030000003o]/40okK10080okK100@000000?nf`@3o]/40okK10P3oool00ol0
0000oooo0?ooo`050?ooo`03o`00003oool0oooo01D0oooo00?o00000?ooo`3oool01@3oool00ol0
0000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`00
0000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@030?nf`@?ooooo00<00000ooooooooool02oooool00`00003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Wooooo6`3o]/400`000?oo
003o0?nf`@020?nf`@80003o1`3o]/4B0?ooo`T00000403oool;0?nf`@040000ool00?l0okK10?nf
`@80003o5`3o]/4Mooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00`00
003oooooooooo`0;ooooo`030000003o]/40okK100H0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/400`00
0000okK10?nf`@030?nf`@040000003o]/40okK10?nf`@80oooo00?o00000?ooo`3oool0103oool0
0ol00000oooo0?ooo`0G0?ooo`03o`00003oool0oooo00D0oooo00?o00000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/43
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0Ioooooa/0okK100<0003oo`00o`3o]/400P3o]/420000
o`L0okK14P3oool:000000l0oooo2`3o]/4010000?oo003o0?nf`@3o]/420000oaL0okK17Oooool0
0`00003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00<00000ooooooooool02oooool0
0`000000okK10?nf`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/40
10000000okK10?nf`@3o]/420?ooo`03o`00003oool0oooo00@0oooo00?o00000?ooo`3oool05`3o
ool00ol00000oooo0?ooo`050?ooo`03o`00003o]/40okK100<0okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK10oooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool06OoooolK0?nf`@030000ool00?l0okK10080okK10P000?l70?nf`A80oooo2P00000?
0?ooo`/0okK100@0003oo`00o`3o]/40okK10P000?lG0?nf`Agooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`0:ooooo`0300000?oooooooooo00_ooooo00<000000?nf`@3o]/401P3o
]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o
]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100@000000?nf`@3o]/40okK1
0P3oool00ol00000oooo0?ooo`040?ooo`03o`00003oool0oooo01L0oooo00?o00000?ooo`3oool0
1@3oool00ol00000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
103o]/400`000000okK10?nf`@020?nf`@?ooooo00<00000ooooooooool02oooool00`00003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Wooooo6`3o
]/400`000?oo003o0?nf`@020?nf`@80003o1`3o]/4B0?ooo`X000003`3oool;0?nf`@040000ool0
0?l0okK10?nf`@80003o5`3o]/4Mooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
2oooool00`00003oooooooooo`0:ooooo`030000003o]/40okK100H0okK100<000000?nf`@3o]/40
103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK10?nf`@80oooo00?o00000?ooo`3o
ool01@3oool00ol00000oooo0?ooo`0F0?ooo`03o`00003oool0oooo00D0oooo00?o00000?nf`@3o
]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/400P3o]/43ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Joooooa/0okK100@0003oo`00o`3o]/40
okK10P000?l70?nf`A80oooo2@00000@0?ooo`/0okK100@0003oo`00o`3o]/40okK10P000?lG0?nf
`Agooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`0300000?oooooooooo
00[ooooo00<00000ooooo`3o]/401P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK1
00<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK1
0080okK100@000000?nf`@3o]/40okK10P3oool00ol00000oooo0?ooo`050?ooo`03o`00003oool0
oooo01H0oooo00?o00000?ooo`3oool01@3oool00ol00000okK10?nf`@030?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@?ooooo00<00000
ooooooooool02oooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo01[ooooo6`3o]/4010000?oo003o0?nf`@3o]/420000o`L0okK14`3oool5
000001<0oooo2`3o]/4010000?oo003o0?nf`@3o]/420000oaL0okK17Oooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo00_ooooo00<00000ooooooooool02_ooool00`00003ooooo0?nf
`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf
`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/4010000000okK10?nf
`@3o]/420?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3oool05P3oool00ol00000oooo
0?ooo`050?ooo`03o`00003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK10080okK10oooool00`00003oooooooooo`0;ooooo`030000
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool06_oo
oolK0?nf`@040000ool00?l0okK10?nf`@80003o203o]/4C0?ooo`<000004`3oool<0?nf`@040000
ool00?l0okK10?nf`@80003o5`3o]/4Mooooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool02oooool00`00003oooooooooo`0:ooooo`0300000?ooool0okK100H0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400P3o]/400`000000okK10?nf`@030?nf`@060000003o]/40okK10?nf`@3ooooo0000203oool0
0ol00000oooo0?ooo`0E0?ooo`03o`00003oool0oooo00@0oooo00<0okK1o`00003o]/40103o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/43
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0Joooooa/0okK100<0003oo`00o`3o]/400P3o]/420000
o`L0okK1:@3oool<0?nf`@040000ool00?l0okK10?nf`@80003o5`3o]/4Mooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool02oooool00`00003oooooooooo`0;ooooo`030000003o]/40
okK100H0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@040000003o]/40
okK10?nf`@80oooo00?o00000?ooo`3oool01@3oool00ol00000oooo0?ooo`0D0?ooo`03o`00003o
ool0oooo00D0oooo00?o00000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK10080okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o
]/40okK100@0okK100<000000?nf`@3o]/400P3o]/43ooooo`0300000?oooooooooo00_ooooo00<0
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0J
oooooa`0okK100@0003oo`00o`3o]/40okK10P000?l70?nf`BT0oooo2`3o]/400`000?oo003oo`00
o`020?nf`@80003o5`3o]/4Mooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool02ooo
ool00`00003oooooooooo`0;ooooo`030000003o]/40okK100H0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100?o00000?nf`@3o]/400`3o
]/400`000000okK10?nf`@020?nf`@04o`00003o]/40okK10?nf`@80oooo00?o00000?ooo`3oool0
1@3oool00ol00000oooo0?ooo`0D0?ooo`03o`00003oool0oooo00D0oooo00?o00000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK100<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40
0P3o]/43ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Joooooa`0okK100@0003oo`00o`3o]/40okK1
0P000?l70?nf`BT0oooo2`3o]/400`000?oo003oo`00o`020?nf`@030000ool00?l0okK101H0okK1
7Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00<00000ooooooooool0
2oooool00`000000okK10?nf`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40
0`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/4010000000okK10?nf`@3o]/430?ooo`03o`00003oool0oooo00D0oooo00?o00000?ooo`3o
ool04`3oool00ol00000oooo0?ooo`050?ooo`03o`00003o]/40okK100<0okK100<000000?nf`@3o
]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o
]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK10oooool00`00003o
ooooooooo`0;ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool000Wooooo
00<00000ooooooooool06_oooolL0?nf`@030000ool00?l0okK10080okK10P000?l70?nf`BL0oooo
303o]/400`000?oo003oo`00o`020?nf`@80003o5`3o]/4Mooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool03?ooool00`00003oooooooooo`0;ooooo`030000003o]/40okK100D0okK1
00<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK1
00<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@040000003o]/40okK10?nf`@80
oooo00?o00000?ooo`3oool01P3oool00ol00000oooo0?ooo`0A0?ooo`03o`00003oool0oooo00D0
oooo00?o00000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0
okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0
okK100<000000?nf`@3o]/400`3o]/43ooooo`0300000?oooooooooo00_ooooo00<00000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Joooooa`0okK1
0_l00?l40?nf`@03o`00o`3o]/40okK100D0okK19`3oool<0?nf`@030000ool00?oo003o0080okK1
0P000?lG0?nf`Agooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`030000
0?oooooooooo00_ooooo00<000000?nf`@3o]/401@3o]/400`00003o00000?nf`@040?nf`@030000
003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@030?nf`@030000
003o]/40okK10080okK100@000000?nf`@3o]/40okK10`3oool00ol00000oooo0?ooo`060?ooo`;o
00003`3oool2o`0000P0oooo00?o00000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@03
0000003o]/40okK100<0okK100<000000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@03
0000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/43ooooo`0300000?oooooooooo00_o
oooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0Joooooad0okK100<0003o0?nf`@3o]/400P3o]/420000o`L0okK19@3oool<0?nf`@030000
o`3o]/7o003o0080okK10P000?lH0?nf`Agooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`0<ooooo`0300000?oooooooooo00_ooooo00<000000?nf`@3o]/401P3o]/400`000000okK1
0?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/400`000000okK1
0?nf`@030?nf`@03o`00003o]/40okK10080okK100<000000?nf`@3o]/400P3o]/420?ooo`03o`00
003oool0oooo00P0oooo0_l0000<0?ooo`03o`00003oool0oooo00L0oooo00<0okK1o`00003o]/40
103o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
0P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40
0`3o]/43ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Koooooa`0okK100?o003o0000o`3o]/400P3o
]/420000o`T0okK18`3oool<0?nf`@030000ool00?oo003o0080okK10P000?lH0?nf`Agooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`0300000?oooooooooo00_ooooo00<0
00000?nf`@3o]/401P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@020?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/400`3o]/400`3ooooo00000?ooo`0:0?ooo`?o00001P3oool3o`0000X0oooo00?o
00000?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/400P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<0
00000?nf`@3o]/400`3o]/43ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Koooooad0okK100<0003o
0?nf`@3o]/400P3o]/400`000?l0okK10?nf`@070?nf`B80oooo3@3o]/400`000?oo003oo`00o`02
0?nf`@80003o5`3o]/4Nooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool03Oooool0
0`00003oooooooooo`0;ooooo`030000003o]/40okK100H0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK10080okK10P3oool00ol00000oooo0?ooo`0;
0?ooo`Ko0000303oool00ol00000okK10?nf`@040?nf`@03o`00003o]/40okK100<0okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/40103o]/400`000000okK10?nf`@020?nf`@Cooooo00<00000ooooooooool02oooool0
0`00003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
01_ooooo7@3o]/400ol00?l0003o0?nf`@020?nf`@80003o2@3o]/4P0?ooo`d0okK100D0003o0?nf
`Ol00?oo003o0?nf`@020000oaP0okK17_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo00<00000ooooooooool02oooool00`000000okK10?nf`@060?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/400`3o]/400ol00000okK10?nf`@030?nf`@030000003o]/40
okK10080okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@020?nf`@80oooo0_l0000L
0?ooo`;o00001P3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<00000
0?nf`@3o]/400P3o]/44ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Koooooad0okK100?o003o0000
o`3o]/400P3o]/420000o`X0okK17P3oool>0?nf`@050000o`3o]/7o003oo`00o`3o]/400P000?lH
0?nf`Akooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo00<000000?nf`@3o]/401P3o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/40103o]/400ol00000okK10?nf`@020?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/400P3o]/430?ooo`03o`00003oool0oooo01P0oooo00?o0000
0?nf`@3o]/401@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<00000
0?nf`@3o]/400P3o]/44ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Koooooah0okK100?o003o0000
o`3o]/400P3o]/420000o`X0okK1703oool>0?nf`@050000o`3o]/7o003oo`00o`3o]/400P000?lI
0?nf`Akooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`0300000?oooooo
oooo00_ooooo00<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40
okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@030?nf`@030000003o]/40
okK100@0okK100<000000?nf`@3o]/400P3o]/430?ooo`;o00005P3oool2o`0000L0okK100<00000
0?nf`@3o]/40103o]/400`000000okK10?nf`@030?nf`@03o`00003o]/40okK100<0okK100<00000
0?nf`@3o]/400`3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK10oooool0
0`00003oooooooooo`0;ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool07?oooolN0?nf`@03o`00o`000?l0okK10080okK10P000?l:0?nf
`AT0oooo3`3o]/400ol00?l0okK10?nf`@03o`00o`030?nf`@000?l0okK101P0okK17_ooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00<00000ooooooooool02oooool00ol0
0000okK10?nf`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/40103o]/400`00
0000okK10?nf`@020?nf`@@0oooo00?o00000?ooo`3oool04@3oool2o`0000P0okK100?o00000?nf
`@3o]/40103o]/400ol00000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf
`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100<0okK10oooool00`00
003oooooooooo`0;ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool07?oooolO0?nf`@03o`00o`000?l0okK10080okK100<0003oo`00o`3o
]/402P3o]/4E0?oooa40okK100L0003o0?nf`Ol00?oo003o0000o`3o]/7o003o01T0okK17oooool0
0`00003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00<00000ooooooooool02oooool0
0`000000okK10?nf`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/40
0`000000okK10?nf`@030?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/401@3o]/40
0`000000okK10?nf`@030?nf`@<0oooo0ol0000>0?ooo`;o00002P3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/400`3o]/400`000000okK10?nf`@04
0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400P3o]/44ooooo`0300000?oooooo
oooo00_ooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0Looooob00okK100?o003o0000o`3o]/400P3o]/400`000?l0okK10?nf`@0;0?nf
`A40oooo4`3o]/4010000?oo003o0?nf`Ol00?l20000oaX0okK17oooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo00kooooo00<00000ooooooooool02oooool00`000000okK10?nf`@07
0?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@03
0?nf`@030000003o]/40okK100<0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@04
0?nf`@@0oooo1?l000090?ooo`03o`00003o]/40okK100T0okK100<000000?nf`@3o]/401@3o]/40
0`000000okK10?nf`@020?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/40
0`000000okK10?nf`@040?nf`@030000003o]/40okK10080okK11?ooool00`00003oooooooooo`0;
ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool07OoooolO0?nf`@03o`00o`3o]/40003o00<0okK100<0003o0?nf`@3o]/40303o]/4=0?oo
oa@0okK100L0003oo`00o`3o]/7o003o0000o`3o]/40003o01X0okK17oooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo00oooooo00<00000ooooooooool02oooool00`000000okK10?nf
`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf
`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf
`@050?nf`@H0oooo2Ol0000;0?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400`3o
]/400`000000okK10?nf`@030?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o
]/400`000000okK10?nf`@030?nf`@?ooooo00<00000ooooooooool03?ooool00`00003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01gooooo803o]/40
0ol00?l0okK10000o`030?nf`@030000o`3o]/40okK100l0okK11@3ooolG0?nf`@070000o`3o]/7o
003oo`00o`000?l0okK10000o`0J0?nf`B3ooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`0300000?oooooooooo00_ooooo00<000000?nf`@3o]/401`3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK100@0okK100?o00000?nf`@3o]/400`3o]/400`000000okK1
0?nf`@040?nf`@8000001P3o]/400ol000000000000000080?nf`@D0oooo3P3o]/4200000003o`00
003o]/40okK100@0okK10P0000050?nf`@03o`00003o]/40okK100<0okK100<00000o`00003o]/40
103o]/400`00003o00000?nf`@050?nf`@03o`00003o]/40okK10080okK11?ooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool07OoooolQ0?nf`@03o`00o`3o]/40003o00<0okK100<0003o0?nf`@3o]/40:@3o
]/401`000?l0okK1o`00ool00?l0003o0?nf`@000?l06`3o]/4Pooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool03oooool00`00003oooooooooo`0;ooooo`030000003o]/40okK100L0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@060?nf`@800000603o]/400`000000
okK10?nf`@060?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/40103o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400P3o]/44ooooo`03
00000?oooooooooo00cooooo00<00000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0Nooooob40okK100Co003o0?nf`Ol00?l0003o0P3o]/420000obL0
okK10P000?l20?nf`@?o003o00<0003o0?nf`@3o]/406P3o]/4Pooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool04?ooool00`00003oooooooooo`0;ooooo`030000003o]/40okK100L0
okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0
okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK101<0
okK10P0000080?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400`3o]/400`000000
okK10?nf`@040?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/400`3o]/43ooooo`03
00000?oooooooooo00cooooo00<00000ooooooooool02oooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0Nooooob80okK10_l00?l00`3o]/40003o0?nf`@020?nf`@030000
o`3o]/40okK10280okK10P000?l30?nf`@;o003o00<0003o0?nf`@3o]/406`3o]/4Qooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00`00003oooooooooo`0;ooooo`030?nf
`@000000okK100P0okK100<000000?nf`@3o]/40103o]/400`000000okK10?nf`@040?nf`@030000
0?l00000okK100@0okK100<000000?nf`@3o]/401@3o]/42000000P0okK100@00000o`0000000000
00003`3o]/400ol0000000000?nf`@080?nf`@03o`00003o]/40okK100D0okK100<000000?nf`@3o
]/40103o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o
]/400`3o]/44ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool02oooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Oooooob<0okK100?o003o0?nf`@000?l0
0`3o]/400`000?l0okK10?nf`@0P0?nf`@030000o`3o]/40okK10080okK10_l00?lO0?nf`B7ooooo
00<00000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo
00<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@040?nf`@03o`00003o]/40okK100D0okK1
00<000000?nf`@3o]/40103o]/400ol0000000000?nf`@060?nf`@030000003o]/40okK100T0okK1
0`0000060?nf`@H000002@3o]/42000000L0okK100<000000?nf`@3o]/401@3o]/400`000000okK1
0?nf`@040?nf`@030000003o]/40okK100@0okK100<000000?nf`@3o]/400`3o]/44ooooo`030000
0?oooooooooo00cooooo00<00000ooooooooool02oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`0Pooooob<0okK100?o003o0?nf`@000?l00P000?l0103o]/40003o0000
o`000?lM0?nf`@80003o0`3o]/43o`00oal0okK18_ooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo017ooooo00<00000ooooooooool03?ooool00`000000okK10?nf`@060?nf`@030000
003o]/40okK100D0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@050?nf`@030000
003o]/40okK100D0okK10P00000<0?nf`@H000003@3o]/42000000P0okK100<000000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@040?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o]/40
0P3o]/44ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool02oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Pooooob@0okK100Go003o0?nf`@3o]/40okK1
0000o`030?nf`@030000o`3o]/40okK101P0okK10P000?l30?nf`@Co003o7`3o]/4Sooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool04_ooool00`00003oooooooooo`0;ooooo`030000
003o]/40okK100L0okK100<000000?nf`@3o]/401@3o]/400`000000okK10?nf`@050?nf`@030000
003o]/40okK100D0okK100<000000?nf`@3o]/401P3o]/42000001`0okK100?o00000?nf`@3o]/40
1`3o]/400`000000okK10?nf`@050?nf`@03o`00003o]/40okK100@0okK100?o00000?nf`@3o]/40
1@3o]/400`000000okK10?nf`@020?nf`@Gooooo00?o0000ooooooooool03?ooool00`00003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo027ooooo903o
]/42o`00o`80okK100Go003o0000o`3o]/40okK10000o`0H0?nf`@030000o`3o]/40okK10080okK1
0_l00?l00`3o]/40003o0000o`0O0?nf`B?ooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`0Booooo`0300000?oooooooooo00cooooo00<000000?nf`@3o]/401`3o]/400`000000okK1
0?nf`@050?nf`@030000003o]/40okK100D0okK10P0000060?nf`@03o`0000000000okK100L0okK1
0`00000G0?nf`@800000203o]/42000000H0okK10P0000060?nf`@030000003o]/40okK100H0okK1
00?o00000?nf`@3o]/400P3o]/45ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0
3?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0QooooobH0okK10_l0
0?l20?nf`@L0003o4@3o]/430000o`<0okK10ol00?l20000ob00okK19?ooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo01;ooooo00<00000ooooooooool03?ooool00`000000okK10?nf
`@070?nf`@030000003o]/40okK100H0okK100?o00000?nf`@3o]/401P3o]/400`000000okK10?nf
`@050?nf`@030000003o]/40okK100P0okK10`00000A0?nf`@<00000203o]/42000000L0okK100<0
00000?nf`@3o]/401P3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK10080okK11_oo
ool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00cooooo00?o0000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool08OoooolX0?nf`@;o003o0`3o]/480000o`T0okK110000?l3
0?nf`@Go003o8`3o]/4Tooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool04oooool0
0`00003oooooooooo`0;ooooo`030?nf`@000000okK100P0okK100<000000?nf`@3o]/401P3o]/40
0`000000okK10?nf`@060?nf`@030000003o]/40okK100D0okK10`00000:0?nf`@@000002P3o]/43
000000X0okK100<000000?nf`@3o]/401P3o]/400ol00000okK10?nf`@060?nf`@030000003o]/40
okK100D0okK100<000000?nf`@3o]/400`3o]/45ooooo`0300000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Roooo
obT0okK10ol00?l40?nf`A<0003o1?l00?lU0?nf`BCooooo00<00000ooooooooool03oooool00ol0
003oooooooooo`0Dooooo`0300000?oooooooooo00_ooooo00<0okK1o`00003o]/40203o]/400`00
003o00000?nf`@060?nf`@8000001`3o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK1
00/0okK12P00000;0?nf`@800000203o]/400`000000okK10?nf`@060?nf`@03o`00003o]/40okK1
00D0okK100<000000?nf`@3o]/40103o]/44ooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool03_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Sooooob/0
okK11?l00?l40?nf`@/0003o00?o003o0000ool00?l00_l00?lW0?nf`BGooooo00<00000oooooooo
ool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00<000000?nf`@3o
]/40203o]/400`000000okK10?nf`@070?nf`@030000003o]/40okK100D0okK100<000000?nf`@3o
]/401P3o]/400ol0000000000000000N0?nf`@8000002@3o]/400`000000okK10?nf`@060?nf`@03
0000003o]/40okK100H0okK100<000000?nf`@3o]/400`3o]/45ooooo`0300000?oooooooooo00co
oooo00<00000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0Sooooobl0okK11?l00?l90?nf`@Co003o:@3o]/4Vooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool05?ooool00`00003oooooooooo`0<ooooo`030?nf`@000000okK100T0okK1
00<000000?nf`@3o]/401`3o]/400`000000okK10?nf`@050?nf`@030000003o]/40okK100P0okK1
1000000H0?nf`@8000002@3o]/42000000P0okK100<000000?nf`@3o]/401P3o]/400`000000okK1
0?nf`@030?nf`@Gooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02Cooooo<P3o]/49o`00obd0okK19_oo
ool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00<00000ooooooooool03?oo
ool00`3o]/4000000?nf`@090?nf`@030000003o]/40okK100L0okK100<000000?nf`@3o]/401@3o
]/42000000`0okK10`00000B0?nf`@<000002P3o]/400`000000okK10?nf`@070?nf`@030000003o
]/40okK100L0okK100?o00000?nf`@3o]/400`3o]/44ooooo`03o`000?oooooooooo00gooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0T
ooooofL0okK19oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00<00000
ooooooooool02oooool20?nf`@030000003o]/40okK100P0okK100?o00000?nf`@3o]/401`3o]/42
000000L0okK10P00000=0?nf`@0400000?l000000000000000X0okK10P0000000ol0000000000?nf
`@090?nf`@80000000?o00000?nf`@3o]/401P3o]/42000000T0okK100<000000?nf`@3o]/400`3o
]/45ooooo`0300000?oooooooooo00gooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0UooooofH0okK19oooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo01Kooooo00<00000ooooooooool03?ooool00`3o]/4000000?nf`@0:
0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/401P3o]/43000000h0okK12P00000=
0?nf`@030000003o]/40okK100P0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@04
0?nf`@Gooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo02KoooooI03o]/4Xooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool05oooool00`00003oooooooooo`0<ooooo`030?nf`@000000okK1
00X0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@080?nf`@8000008@3o]/420000
00X0okK100<000000?nf`@3o]/40203o]/400`000000okK10?nf`@040?nf`@Gooooo00<00000oooo
ooooool03?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo02OoooooHP3o]/4Yooooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool06?ooool00`00003oooooooooo`0<ooooo`030?nf`@000000okK100X0okK100<000000?nf`@3o
]/40203o]/400`000000okK10?nf`@090?nf`@030000003o]/40okK101d0okK100<000000?nf`@3o
]/402@3o]/400ol00000okK10?nf`@080?nf`@03o`00003o]/40okK100@0okK11Oooool00`00003o
ooooooooo`0=ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0:?oooomP0?nf`B[ooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00gooooo00<0okK10000000000002P3o]/400ol000000000
0?nf`@080?nf`@03o`0000000000okK100T0okK100@00000o`00000000000000603o]/4200000003
o`00003o]/40okK100P0okK10P0000090?nf`@8000001P3o]/45ooooo`0300000?oooooooooo00ko
oooo00<00000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0Xoooooel0okK1:oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo
00<00000ooooooooool03?ooool30?nf`@030000003o]/40okK100T0okK100<000000?nf`@3o]/40
203o]/42000000`0okK11`00000:0?nf`@L000002`3o]/42000000X0okK100<000000?nf`@3o]/40
1@3o]/45ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool04Oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Yoooooeh0okK1:oooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo01[ooooo00<00000ooooooooool03?ooool30?nf`@030000003o
]/40okK100T0okK100<000000?nf`@3o]/402@3o]/4200000140okK12P00000@0?nf`@8000002`3o
]/400ol00000okK10?nf`@060?nf`@Cooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`0Booooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02[oooooG03o]/4/
ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool06oooool00`00003oooooooooo`0<
ooooo`<0okK100<000000?nf`@3o]/402@3o]/400ol0000000000?nf`@0:0?nf`@<000009P3o]/42
000000`0okK100<000000?nf`@3o]/401P3o]/44ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0[oooo
oeX0okK1;Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00<00000oooo
ooooool03Oooool30?nf`@030000003o]/40okK100X0okK10P00000<0?nf`@<00000803o]/430000
00d0okK100<000000?nf`@3o]/401P3o]/44ooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0/oooooeP0
okK1;_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00<00000oooooooo
ool03Oooool30?nf`@030000003o]/40okK100/0okK10P00000=0?nf`@@000006P3o]/42000000h0
okK10P0000080?nf`@Cooooo00<00000ooooooooool04?ooool00`00003oooooooooo`0Dooooo`03
o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02goooooE@3o]/4`ooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool07Oooool00`00003oooooooooo`0=ooooo`<0okK1
00<000000?nf`@3o]/40303o]/400`000000okK10?nf`@0>0?nf`@800000503o]/401?l000000000
00000000000?0?nf`@030000003o]/40okK100H0okK11Oooool00`00003oooooooooo`0@ooooo`03
00000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
;_oooomC0?nf`C7ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`030000
0?l0003ooooo00gooooo0`3o]/400ol0000000000?nf`@0;0?nf`@03o`000000000000000100okK1
5000000@0?nf`@80000000?o00000?nf`@3o]/401P3o]/44ooooo`8000004_ooool00`00003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo033oooooD03o
]/4booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool07oooool00`00003ooooooooo
o`0>ooooo`<0okK100<000000?nf`@3o]/40303o]/4200000340okK100<000000?nf`@3o]/40203o
]/44ooooo`0300000?oooooooooo017ooooo00<00000ooooooooool05oooool00ol0003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`0aooooodh0okK1<oooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo023ooooo00<00000ooooooooool03_ooool30?nf`@8000003P3o]/42
000002`0okK10`00000:0?nf`@Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo03;oooooC03o]/4doooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool08Oooool00`00003oooooooooo`0>oooo
o`@0okK10P00000>0?nf`@0300000?l00000000002H0okK10`00000<0?nf`@?ooooo0P00000Coooo
o`0300000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0<ooooom:0?nf`CGooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00kooooo1@3o]/42000000l0okK10`00000O0?nf`@@000003P3o]/43ooooo`03
00000?oooooooooo01?ooooo00<00000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0eooooodH0okK1=oooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo02?ooooo00<00000ooooooooool03oooool50?nf`@030000003o]/40okK100l0okK1
1000000H0?nf`@<00000403o]/44ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0
6_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0foooood@0okK1>?oo
ool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00<00000ooooooooool03ooo
ool50?nf`@030000003o]/40okK10180okK11`00000=0?nf`@@000004P3o]/44ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0hoooood00okK1>_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooo
oooo02Gooooo00<00000o`000?ooool04?ooool40?nf`@03o`0000000000000001P0okK100<00000
o`0000000000200000000ol0000000000?nf`@0C0?nf`@Cooooo0P00000Dooooo`8000007_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0joooooc`0okK1??ooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00<00000ooooooooool04?ooool50?nf
`@800000=@3o]/43ooooo`<000005Oooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo03_ooooo>P3o]/4mooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool0:?ooool00`00003oooooooooo`0@ooooo`H0okK100<000000?nf`@3o
]/40<@3o]/401?ooool0000000000000000Gooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0?_oooole0?nf`Coooooo00<00000oooooooo
ool03oooool00ol0003oooooooooo`0Yooooo`0300000?l0003ooooo01;ooooo103o]/401000003o
000000000000000]0?nf`@;ooooo00?o0000ooooooooool05oooool00`00003oooooooooo`0Poooo
o`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo047ooooo;`3o]/52ooooo`03
00000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00`00003oooooooooo`0Cooooo`D0
okK10`00000W0?nf`@;ooooo0`00000Iooooo`0300000?oooooooooo027ooooo00?o0000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0A?oooolY0?nf`DGooooo00<00000ooooooooool0
3oooool00ol0003oooooooooo`0/ooooo`0300000?oooooooooo01Gooooo1@3o]/4300000240okK1
0_ooool3000001_ooooo00<00000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`17ooooob<0okK1B?ooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo02gooooo0P00000Hooooo`D0okK11000000J0?nf`@03ooooo`0000000000008000007Ooo
ool00`00003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo04[ooooo7@3o]/5;ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0;oooool0
0`00003oooooooooo`0Hooooo`H0okK11`00000=0?nf`@L000007oooool2000002Kooooo00?o0000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0COoooolG0?nf`Dkooooo00<00000oooo
ooooool03oooool00ol0003oooooooooo`0`ooooo`03o`000000003ooooo01[ooooo2P3o]/4=0000
02Cooooo0P00000Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05Ko
oooo103o]/5Hooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool2000002;o
oooo103o]/4]ooooo`0300000?oooooooooo02Sooooo00?o0000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo
00<00000o`0000000000COooool200000003o`000?oooooooooo02Wooooo00?o0000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Oooooo00<00000ooooooooool0BOooool00`00003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool0
0ol0003oooooooooo`0hooooo`<00000A_ooool2000002oooooo00?o0000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo
03_ooooo00<00000ooooooooool0@Oooool20000037ooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo03co
oooo00?o0000000000000000?_ooool2000003?ooooo00?o0000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo
0`00000hooooo`<00000=Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0@_ooool3000003?ooooo0P00
000hooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000
ooooooooool03oooool00ol0003oooooooooo`15ooooo`@00000;?ooool00ol0000000000000000j
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000oooo
ooooool03oooool00ol0003oooooooooo`19ooooo`<000009_ooool3000003gooooo00?o0000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo04cooooo1000000Kooooo`L00000@?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
D?ooool7000000gooooo1`000017ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`1Gooooo`d00000C_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2b
ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`08ooooo`002Ooooonf0000017ooooo]_l0000:ooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-1.18773, -1.18808, 0.00564516, 0.00564516}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, data1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.425638 0.000327439 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -9 -9 ]
[.7381 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01634 -30 -4.5 ]
[-0.0125 .01634 0 4.5 ]
[-0.0125 .0982 -30 -4.5 ]
[-0.0125 .0982 0 4.5 ]
[-0.0125 .18006 -24 -4.5 ]
[-0.0125 .18006 0 4.5 ]
[-0.0125 .26192 -24 -4.5 ]
[-0.0125 .26192 0 4.5 ]
[-0.0125 .34378 -24 -4.5 ]
[-0.0125 .34378 0 4.5 ]
[-0.0125 .42564 -6 -4.5 ]
[-0.0125 .42564 0 4.5 ]
[-0.0125 .5075 -18 -4.5 ]
[-0.0125 .5075 0 4.5 ]
[-0.0125 .58936 -18 -4.5 ]
[-0.0125 .58936 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
0 .0982 m
1 .0982 L
s
0 .18006 m
1 .18006 L
s
0 .26192 m
1 .26192 L
s
0 .34378 m
1 .34378 L
s
0 .42564 m
1 .42564 L
s
0 .5075 m
1 .5075 L
s
0 .58936 m
1 .58936 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(0.5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1.5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01634 m
.00625 .01634 L
s
[(-1250)] -0.0125 .01634 1 0 Mshowa
0 .0982 m
.00625 .0982 L
s
[(-1000)] -0.0125 .0982 1 0 Mshowa
0 .18006 m
.00625 .18006 L
s
[(-750)] -0.0125 .18006 1 0 Mshowa
0 .26192 m
.00625 .26192 L
s
[(-500)] -0.0125 .26192 1 0 Mshowa
0 .34378 m
.00625 .34378 L
s
[(-250)] -0.0125 .34378 1 0 Mshowa
0 .42564 m
.00625 .42564 L
s
[(0)] -0.0125 .42564 1 0 Mshowa
0 .5075 m
.00625 .5075 L
s
[(250)] -0.0125 .5075 1 0 Mshowa
0 .58936 m
.00625 .58936 L
s
[(500)] -0.0125 .58936 1 0 Mshowa
.125 Mabswid
0 .03271 m
.00375 .03271 L
s
0 .04908 m
.00375 .04908 L
s
0 .06546 m
.00375 .06546 L
s
0 .08183 m
.00375 .08183 L
s
0 .11457 m
.00375 .11457 L
s
0 .13094 m
.00375 .13094 L
s
0 .14732 m
.00375 .14732 L
s
0 .16369 m
.00375 .16369 L
s
0 .19643 m
.00375 .19643 L
s
0 .2128 m
.00375 .2128 L
s
0 .22917 m
.00375 .22917 L
s
0 .24555 m
.00375 .24555 L
s
0 .27829 m
.00375 .27829 L
s
0 .29466 m
.00375 .29466 L
s
0 .31103 m
.00375 .31103 L
s
0 .32741 m
.00375 .32741 L
s
0 .36015 m
.00375 .36015 L
s
0 .37652 m
.00375 .37652 L
s
0 .39289 m
.00375 .39289 L
s
0 .40927 m
.00375 .40927 L
s
0 .44201 m
.00375 .44201 L
s
0 .45838 m
.00375 .45838 L
s
0 .47475 m
.00375 .47475 L
s
0 .49113 m
.00375 .49113 L
s
0 .52387 m
.00375 .52387 L
s
0 .54024 m
.00375 .54024 L
s
0 .55661 m
.00375 .55661 L
s
0 .57299 m
.00375 .57299 L
s
0 .60573 m
.00375 .60573 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01634 m
1 .01634 L
s
.99375 .0982 m
1 .0982 L
s
.99375 .18006 m
1 .18006 L
s
.99375 .26192 m
1 .26192 L
s
.99375 .34378 m
1 .34378 L
s
.99375 .42564 m
1 .42564 L
s
.99375 .5075 m
1 .5075 L
s
.99375 .58936 m
1 .58936 L
s
.125 Mabswid
.99625 .03271 m
1 .03271 L
s
.99625 .04908 m
1 .04908 L
s
.99625 .06546 m
1 .06546 L
s
.99625 .08183 m
1 .08183 L
s
.99625 .11457 m
1 .11457 L
s
.99625 .13094 m
1 .13094 L
s
.99625 .14732 m
1 .14732 L
s
.99625 .16369 m
1 .16369 L
s
.99625 .19643 m
1 .19643 L
s
.99625 .2128 m
1 .2128 L
s
.99625 .22917 m
1 .22917 L
s
.99625 .24555 m
1 .24555 L
s
.99625 .27829 m
1 .27829 L
s
.99625 .29466 m
1 .29466 L
s
.99625 .31103 m
1 .31103 L
s
.99625 .32741 m
1 .32741 L
s
.99625 .36015 m
1 .36015 L
s
.99625 .37652 m
1 .37652 L
s
.99625 .39289 m
1 .39289 L
s
.99625 .40927 m
1 .40927 L
s
.99625 .44201 m
1 .44201 L
s
.99625 .45838 m
1 .45838 L
s
.99625 .47475 m
1 .47475 L
s
.99625 .49113 m
1 .49113 L
s
.99625 .52387 m
1 .52387 L
s
.99625 .54024 m
1 .54024 L
s
.99625 .55661 m
1 .55661 L
s
.99625 .57299 m
1 .57299 L
s
.99625 .60573 m
1 .60573 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.5 .60332 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.5 .60332 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`009_ooool2
o`0003Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000dooooo`?o0000<oooool3
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0003;ooooo1Ol00006ooooo`009Oooool01?l0
003oooooooooool0000booooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00000dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000003;ooooo00Co0000oooooooooooo00001_ooool002Gooooo00Co0000oooooooo
oooo0000<_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01_ooool002Gooooo00Co0000oooooooooooo0000<_ooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool002Gooooo00Co0000
oooooooooooo0000<_ooool01?l0003oooooooooool00007ooooo`Co0000=Oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo00Oooooo1?l0000booooo`05o`000?ooooooooooooooool0
00001_ooool002Gooooo00Co0000oooooooooooo0000<_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo03Gooooo0_l0000dooooo`;o00002Oooool00ol0003oooooooooo`0coooo
o`05o`000?ooooooooooooooool000001_ooool002Kooooo0_l0000dooooo`;o00002?ooool5o`00
03Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`07ooooo`Go0000<_ooool3o`00
00Oooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Qoooo
o`0300000?l0003o00000?[o00000@000001ooooo`001oooool3o`0000;ooooo1Ol00002ooooo`?o
00001?ooool2o`0000Gooooo00<00000ooooooooool00_ooool30?l000[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`03ooooo`4000000Oooool000Sooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`0400000?ooooooooooooooo`D0o`00>Oooool00`0007oooooooooo
o`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo0005
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool01000003oooooooooooooool50?l003Wooooo
00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo
0@000001ooooo`002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`0400000?l0003oooooooooo`D0
o`00>Oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool0?_ooool1o`00004000000Oooool000Sooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooo000000?o00000oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo
00;ooooo0`3o000jooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`00
07ooooooooooo`0oooooo`4000000Oooool000Oooooo0_l00003ooooo`07o`000?oooooooooooooo
ool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01Ooo
ool00`00003oooooooooo`0gooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Ooo
ool00`0007ooooooooooo`0oooooo`4000000Oooool000Sooooo00?o0000ooooooooool00_ooool3
o`0000;ooooo1Ol00003ooooo`;o00001Oooool00`00003oooooooooo`06ooooo`0300000?oooooo
oooo03Kooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooo
oooo03oooooo0@000001ooooo`008Oooool00`00003o0000ooooo`07ooooo`0300000?oooooooooo
03Gooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
03kooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo00Oooooo00<00000oooooooo
ool0=Oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool0?oooool10000007ooooo000Qooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0
=?ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0
?oooool10000007ooooo000Qooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0<ooo
ool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?ooo
ool10000007ooooo000Qooooo`0300000?l0003ooooo00[ooooo00<00000ooooooooool0<_ooool0
0`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?_ooool1
o`00004000000Oooool0027ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0aoooo
o`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0ooooo
o`4000000Oooool0027ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0aooooo`03
0000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`40
00000Oooool0027ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0`ooooo`030000
Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`400000
0Oooool0027ooooo00<00000o`000?ooool03Oooool00`00003oooooooooo`0_ooooo`030000Oooo
oooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0nooooo`7o00000@00
0001ooooo`008Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo02kooooo00<0001o
ooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001
ooooo`008Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02gooooo00<0001ooooo
ooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001oooo
o`008Oooool00`00003oooooooooo`0@ooooo`0300000?oooooooooo02cooooo00<0001ooooooooo
ool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001ooooo`00
8Oooool00`00003o0000ooooo`0@ooooo`0300000?oooooooooo02cooooo00<0001oooooooooool0
>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03kooooo0Ol000010000007ooooo
000Qooooo`0300000?oooooooooo017ooooo00<00000ooooooooool0:oooool00`0007oooooooooo
o`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo0007
ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0B
ooooo`0300000?oooooooooo02[ooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0i
ooooo`030000Oooooooooooo03oooooo0@000001ooooo`002?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0:Oooool00`0007oooooo
ooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo
0005o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Doooo
o`0300000?oooooooooo02Sooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0ioooo
o`030000Oooooooooooo03oooooo0@000001ooooo`002?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`0300000?l00000001o01@0001o00<000000000O`0007l0hP0007l1o`00004000000Ooo
ool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Eooooo`03
00000?oooooooooo02Oooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo03oooooo0@000001ooooo`001oooool2o`0000Cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
ooooooooool05_ooool00`00003oooooooooo`0Vooooo`030000Oooooooooooo03[ooooo00<0001o
ooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool000Sooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Goooo
o`0300000?oooooooooo02Gooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0ioooo
o`030000Oooooooooooo03oooooo0@000001ooooo`008Oooool00`00003o0000ooooo`0Hooooo`03
00000?oooooooooo02Cooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo03kooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo01Sooooo
00<00000ooooooooool09?ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo
00<0001oooooooooool0?oooool10000007ooooo000Qooooo`0300000?oooooooooo01Wooooo00<0
0000ooooooooool08oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool0?oooool10000007ooooo000Qooooo`0300000?oooooooooo01[ooooo00<00000
ooooooooool08_ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool0?oooool10000007ooooo000Qooooo`0300000?l0003ooooo01_ooooo00<00000oooo
ooooool08Oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001ooooo
ooooool0?_ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool07?ooool00`00003o
ooooooooo`0Pooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oo
ooooooooo`0oooooo`4000000Oooool0027ooooo00<00000ooooooooool07?ooool00`00003ooooo
ooooo`0Pooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0oooooo`4000000Oooool0027ooooo00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Oooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooooooo
o`0oooooo`4000000Oooool0027ooooo00<00000o`000?ooool07_ooool00`00003oooooooooo`0N
ooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0n
ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo
01gooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
03oooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo01co
oooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oo
oooo0@000001ooooo`008Oooool00`00003oooooooooo`0Pooooo`0300000?oooooooooo01cooooo
00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo
0@000001ooooo`008Oooool00`00003o0000ooooo`0Qooooo`0300000?oooooooooo01_ooooo00<0
001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03kooooo0Ol0
00010000007ooooo000Qooooo`0300000?oooooooooo02;ooooo00<00000ooooooooool06_ooool0
0`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool1
0000007ooooo000>ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`;o00001Oooool00`00
003oooooooooo`0Sooooo`0300000?oooooooooo01Wooooo00<0001oooooooooool0>_ooool00`00
07ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001ooooo`003_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`0300000?oooooooooo02Cooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0j
ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo0006oooo
o`Go00001?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00`00003o00000000O`0T0000O`030000000007l0001o0=80001o0Ol00001
0000007ooooo000?ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`0300000?oooooooooo02Gooooo00<00000ooooooooool05oooool0
0`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool1
0000007ooooo000@ooooo`03o`000?oooooo000000?o00000oooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo02Kooooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0j
ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo000<oooo
o`07o`000?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool09oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo03[ooooo
00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool000cooooo1Ol0
00000ooooooo0000o`000003o`0000?ooooo0_l00005ooooo`0300000?oooooooooo02Sooooo00<0
0000ooooooooool05?ooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool0?oooool10000007ooooo000Qooooo`0300000?l0003ooooo02Wooooo00<00000
ooooooooool04oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool0?_ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0:Oooool00`00
003oooooooooo`0Cooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`00
07ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000ooooooooool0:_ooool00`00003o
ooooooooo`0Booooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oo
ooooooooo`0oooooo`4000000Oooool0027ooooo00<00000ooooooooool0:oooool00`00003ooooo
ooooo`0Aooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0oooooo`4000000Oooool0027ooooo00<00000o`000?ooool0;?ooool00`00003ooooooooo
o`0@ooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007oooooooooo
o`0nooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0]ooooo`0300000?oooooo
oooo00oooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooo
oooo03oooooo0@000001ooooo`008Oooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo
00oooooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo
03oooooo0@000001ooooo`008Oooool00`00003oooooooooo`0^ooooo`0300000?oooooooooo00ko
oooo00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oo
oooo0@000001ooooo`008Oooool00`00003o0000ooooo`0_ooooo`0300000?oooooooooo00gooooo
00<0001oooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03kooooo
0Ol000010000007ooooo000Qooooo`0300000?oooooooooo033ooooo00<00000ooooooooool03?oo
ool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?ooo
ool10000007ooooo000Qooooo`0300000?oooooooooo037ooooo00<00000ooooooooool02oooool0
0`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool1
0000007ooooo000Qooooo`0300000?oooooooooo037ooooo00<00000ooooooooool02oooool00`00
07ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000
007ooooo000Qooooo`0300000?l0003ooooo03;ooooo00<00000ooooooooool02_ooool00`0007oo
ooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?_ooool1o`000040
00000Oooool0027ooooo00<00000ooooooooool0<oooool00`00003oooooooooo`09ooooo`030000
Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`400000
0Oooool000gooooo0ol00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0=?oo
ool00`00003oooooooooo`08ooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Ooo
ool00`0007ooooooooooo`0oooooo`4000000Oooool000cooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0eooooo`0300000?oooooooooo00Oooooo00<0001oooooooooool0>_ooool00`0007oo
ooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001ooooo`001_ooool5o`0000Gooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00<00000o`00000007l0=@0007l00`000000001o0000O`310000O`7o00000@000001oooo
o`004?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00`00003oooooooooo`0fooooo`0300000?oooooooooo00Kooooo00<0001o
ooooooooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001
ooooo`003?ooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo03Oooooo00<00000ooooooooool01Oooool00`0007oooooooooo
o`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo000<
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo03Sooooo00<00000ooooooooool01?ooool00`0007oooooo
ooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo
000<ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?l0003ooooo03Wooooo00<0
0000ooooooooool00oooool00`0007ooooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool0?_ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0>Oooool0
0`00003oooooooooo`03ooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool0
0`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000ooooooooool0>_ooool00`00
003oooooooooo`02ooooo`030000Oooooooooooo03[ooooo00<0001oooooooooool0>Oooool00`00
07ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000ooooooooool0>oooool01@00003o
ooooooooooooool0001o03cooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0ooooo
o`4000000Oooool0027ooooo00<00000o`000?ooool0??ooool01000003oooooooooo`0007lloooo
o`030000Oooooooooooo03Wooooo00<0001oooooooooool0?_ooool1o`00004000000Oooool0027o
oooo00<00000ooooooooool0?Oooool00`00003ooooo0000O`0looooo`030000Oooooooooooo03Wo
oooo00<0001oooooooooool0?oooool10000007ooooo000Qooooo`0300000?oooooooooo03gooooo
00<00000ooooo`0007l0??ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo
0@000001ooooo`008Oooool00`00003oooooooooo`0nooooo`030000000007oooooo03_ooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000
ooooooooool0?oooool00`00003oooooooooo`0jooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool0?oooool10000007ooooo000Qooooo`0300000?l0003ooooo03oooooo00<0001o0000
0?ooool0>_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03kooooo0Ol000010000
007ooooo000Qooooo`0300000?oooooooooo03oooooo00<0001oooooo`000000>_ooool00`0007oo
ooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001ooooo`008Oooool00`00003ooooo
ooooo`0oooooo`040000Oooooooooooo000003Wooooo00<0001oooooooooool0>Oooool00`0007oo
ooooooooo`0oooooo`4000000Oooool0027ooooo00<00000ooooooooool0?oooool0100007oooooo
ooooo`00000iooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007o
oooo000Qooooo`0300000?l0003ooooo03oooooo00D0001ooooooooooooooooo0000000hooooo`03
0000Oooooooooooo03Wooooo00<0001oooooooooool0?_ooool1o`00004000000Oooool000cooooo
1Ol00002ooooo`?o00001?ooool2o`0000Gooooo00<00000ooooooooool0?oooool00`0007oooooo
ooooo`02ooooo`0300000?oooooooooo03Gooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0oooooo`4000000Oooool000gooooo00Ko0000oooooooooooo0000ooooool00003ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0ooooo
o`030000Oooooooooooo00?ooooo00<00000ooooooooool0=?ooool00`0007ooooooooooo`0ioooo
o`030000Oooooooooooo03oooooo0@000001ooooo`001_ooool5o`0000?ooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000oooo
ooooool0?oooool00`0007ooooooooooo`04ooooo`0300000?oooooooooo03?ooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool000oooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`00
000007l0AP0007l00`000000001o0000O`2`0000O`7o00000@000001ooooo`003?ooool01_l0003o
oooooooooooooooo0000ooooo`Co00000oooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo03oooooo00<0001oooooooooool01Oooool00`00003oooooooooo`0booooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo000<ooooo`07o`000?oooooo
ooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool0?oooool00`0007ooooooooooo`06ooooo`0300000?oooooooooo037ooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool000gooooo0ol00002ooooo`Go0000
0oooool2o`0000Gooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`07ooooo`030000
0?oooooooooo033ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`400000
0Oooool0027ooooo00<00000o`000?ooool0?oooool00`0007ooooooooooo`08ooooo`0300000?oo
oooooooo02oooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0nooooo`7o00000@00
0001ooooo`008Oooool00`00003oooooooooo`0oooooo`030000Oooooooooooo00Sooooo00<00000
ooooooooool0;oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001
ooooo`008Oooool00`00003oooooooooo`0oooooo`030000Oooooooooooo00Wooooo00<00000oooo
ooooool0;_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001oooo
o`008Oooool00`00003oooooooooo`0oooooo`030000Oooooooooooo00[ooooo00<00000oooooooo
ool0;Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001ooooo`00
8Oooool00`00003o0000ooooo`0oooooo`030000Oooooooooooo00_ooooo00<00000ooooooooool0
;?ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03kooooo0Ol000010000007ooooo
000Qooooo`0300000?oooooooooo03oooooo00<0001oooooooooool03?ooool00`00003ooooooooo
o`0[ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo000Q
ooooo`0300000?oooooooooo03oooooo00<0001oooooooooool03?ooool00`00003oooooooooo`0[
ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo000Qoooo
o`0300000?oooooooooo03oooooo00<0001oooooooooool03Oooool00`00003oooooooooo`0Zoooo
o`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo000Qooooo`03
00000?l0003ooooo03oooooo00<0001oooooooooool03_ooool00`00003oooooooooo`0Yooooo`03
0000Oooooooooooo03Wooooo00<0001oooooooooool0?_ooool1o`00004000000Oooool0027ooooo
00<00000ooooooooool0?oooool00`0007ooooooooooo`0?ooooo`0300000?oooooooooo02Sooooo
00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<0
0000ooooooooool0?oooool00`0007ooooooooooo`0@ooooo`0300000?oooooooooo02Oooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000
ooooooooool0?oooool00`0007ooooooooooo`0@ooooo`0300000?oooooooooo02Oooooo00<0001o
ooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000oooo
ooooool0?oooool00`0007ooooooooooo`0Aooooo`0300000?oooooooooo02Kooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000o`000?oo
ool0?oooool00`0007ooooooooooo`0Booooo`0300000?oooooooooo02Gooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0nooooo`7o00000@000001ooooo`006_ooool2o`0000Gooooo
00<00000ooooooooool0?oooool00`0007ooooooooooo`0Cooooo`0300000?oooooooooo02Cooooo
00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool001Wooooo00Co
0000oooooooooooo00001?ooool00`00003oooooooooo`0oooooo`030000Oooooooooooo01Cooooo
00<00000ooooooooool08oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo
0@000001ooooo`006Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo03oooooo
00<0001oooooooooool05?ooool00`00003oooooooooo`0Sooooo`030000Oooooooooooo03Wooooo
00<0001oooooooooool0?oooool10000007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo
00<00000o`00000007l0E`0007l00`000000001o0000O`2O0000O`7o00000@000001ooooo`006Ooo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo03oooooo00<0001oooooooooool0
5_ooool00`00003oooooooooo`0Qooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0
?oooool10000007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
?oooool00`0007ooooooooooo`0Gooooo`0300000?oooooooooo023ooooo00<0001oooooooooool0
>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool001[ooooo0_l00005ooooo`0300000?oo
oooooooo03oooooo00<0001oooooooooool06?ooool00`00003oooooooooo`0Oooooo`030000Oooo
oooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo000Qooooo`0300000?l0003o
oooo03oooooo00<0001oooooooooool06Oooool00`00003oooooooooo`0Nooooo`030000Oooooooo
oooo03Wooooo00<0001oooooooooool0?_ooool1o`00004000000Oooool0027ooooo00<00000oooo
ooooool0?oooool00`0007ooooooooooo`0Iooooo`0300000?oooooooooo01kooooo00<0001ooooo
ooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000oooooooo
ool0?oooool00`0007ooooooooooo`0Jooooo`0300000?oooooooooo01gooooo00<0001ooooooooo
ool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000ooooooooool0
?oooool00`0007ooooooooooo`0Kooooo`0300000?oooooooooo01cooooo00<0001oooooooooool0
>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0027ooooo00<00000o`000?ooool0?ooo
ool00`0007ooooooooooo`0Looooo`0300000?oooooooooo01_ooooo00<0001oooooooooool0>Ooo
ool00`0007ooooooooooo`0nooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0o
ooooo`030000Oooooooooooo01gooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0i
ooooo`030000Oooooooooooo03oooooo0@000001ooooo`008Oooool00`00003oooooooooo`0ooooo
o`030000Oooooooooooo01gooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0ioooo
o`030000Oooooooooooo03oooooo0@000001ooooo`008Oooool00`00003oooooooooo`0oooooo`03
0000Oooooooooooo01kooooo00<00000ooooooooool06Oooool00`0007ooooooooooo`0iooooo`03
0000Oooooooooooo03oooooo0@000001ooooo`008Oooool00`00003o0000ooooo`0oooooo`030000
Oooooooooooo01oooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0iooooo`030000
Oooooooooooo03kooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo03oooooo00<0
001oooooooooool08?ooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool0?oooool10000007ooooo000Qooooo`0300000?oooooooooo03oooooo00<0001o
ooooooooool08Oooool00`00003oooooooooo`0Fooooo`030000Oooooooooooo03Wooooo00<0001o
ooooooooool0?oooool10000007ooooo000Qooooo`0300000?oooooooooo03oooooo00<0001ooooo
ooooool08Oooool00`00003oooooooooo`0Fooooo`030000Oooooooooooo03Wooooo00<0001ooooo
ooooool0?oooool10000007ooooo000Qooooo`0300000?l0003ooooo03oooooo00<0001ooooooooo
ool08_ooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool0?_ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool0?oooool00`0007oooooo
ooooo`0Sooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool0>Oooool00`0007oooooo
ooooo`0oooooo`4000000Oooool000cooooo1Ol00002ooooo`?o00001?ooool2o`0000Gooooo00<0
0000ooooooooool0?oooool00`0007ooooooooooo`0Tooooo`0300000?oooooooooo01?ooooo00<0
001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool000gooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00`00003oooooooooo`0oooooo`030000Oooooooooooo02Gooooo00<00000oooooooo
ool04_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001ooooo`00
3_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00`00003o00000000O`1W0000O`030000000007l0001o08l0001o0Ol000010000007o
oooo000?ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`0300000?oooooooooo03oooooo00<0001oooooooooool09_ooool00`00003o
ooooooooo`0Aooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007o
oooo000<ooooo`06o`000?ooooooooooooooool0003ooooo1?l00003ooooo`04o`000?oooooooooo
o`0000Cooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`0Wooooo`0300000?oooooo
oooo013ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`4000000Oooool0
00cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`0oooooo`030000Oooooooooooo02Sooooo00<00000ooooooooool0
3oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001ooooo`003Ooo
ool3o`0000;ooooo1Ol00003ooooo`;o00001Oooool00`00003oooooooooo`0oooooo`030000Oooo
oooooooo02Wooooo00<00000ooooooooool03_ooool00`0007ooooooooooo`0iooooo`030000Oooo
oooooooo03oooooo0@000001ooooo`008Oooool00`00003o0000ooooo`0oooooo`030000Oooooooo
oooo02Wooooo00<00000ooooooooool03_ooool00`0007ooooooooooo`0iooooo`030000Oooooooo
oooo03kooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo03oooooo00<0001ooooo
ooooool0:_ooool00`00003oooooooooo`0=ooooo`030000Oooooooooooo03Wooooo00<0001ooooo
ooooool0?oooool10000007ooooo000Qooooo`0300000?oooooooooo03oooooo00<0001ooooooooo
ool0:oooool00`00003oooooooooo`0<ooooo`030000Oooooooooooo03Wooooo00<0001ooooooooo
ool0?oooool10000007ooooo000Qooooo`0300000?oooooooooo03oooooo00<0001oooooooooool0
;?ooool00`00003oooooooooo`0;ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0
?oooool10000007ooooo000Qooooo`0300000?l0003ooooo03oooooo00<0001oooooooooool0;Ooo
ool00`00003oooooooooo`0:ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?_oo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`0]
ooooo`0300000?oooooooooo00[ooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0o
ooooo`4000000Oooool0027ooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`0^oooo
o`0300000?oooooooooo00Wooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0ooooo
o`4000000Oooool0027ooooo00<00000ooooooooool0?oooool00`0007ooooooooooo`0_ooooo`03
00000?oooooooooo00Sooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0oooooo`40
00000Oooool0027ooooo00<00000o`000?ooool0?oooool00`0007ooooooooooo`0`ooooo`030000
0?oooooooooo00Oooooo00<0001oooooooooool0>Oooool00`0007ooooooooooo`0nooooo`7o0000
0@000001ooooo`008Oooool00`00003oooooooooo`0oooooo`030000Oooooooooooo037ooooo00<0
0000ooooooooool01_ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@00
0001ooooo`008Oooool00`00003oooooooooo`0oooooo`030000Oooooooooooo03;ooooo00<00000
ooooooooool01Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001
ooooo`008Oooool00`00003oooooooooo`0oooooo`030000Oooooooooooo03;ooooo00<00000oooo
ooooool01Oooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03oooooo0@000001oooo
o`008Oooool00`00003o0000ooooo`0oooooo`030000Oooooooooooo03?ooooo00<00000oooooooo
ool01?ooool00`0007ooooooooooo`0iooooo`030000Oooooooooooo03kooooo0Ol000010000007o
oooo000Qooooo`0300000?oooooooooo03oooooo00<0001oooooooooool0=?ooool00`00003ooooo
ooooo`03ooooo`030000Oooooooooooo03Wooooo00<0001oooooooooool0?oooool10000007ooooo
000=ooooo`?o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo03oooooo00<0
001oooooooooool0=Oooool00`00003oooooooooo`02ooooo`030000Oooooooooooo03Wooooo00<0
001oooooooooool0?oooool10000007ooooo000<ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool0?oooool00`0007ooooooooooo`0fooooo`0500000?ooooooooooooooo`0007l0>oooool00`00
07ooooooooooo`0oooooo`4000000Oooool0013ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`00000007l0N00007l0
0`000000001o0000O`1n0000O`7o00000@000001ooooo`004?ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003ooooooooo
o`0oooooo`030000Oooooooooooo03Oooooo00@00000ooooooooool0001o>oooool00`0007oooooo
ooooo`0oooooo`4000000Oooool000cooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0oooooo`030000Oooooooooooo03So
oooo00@000000?l0003o0000o`00>_ooool00`0007ooooooooooo`0hooooo`<0o`001?ooool10000
007ooooo000<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00004ooooo`0300000?oooooooooo03oooooo00<0001oooooooooool0>?ooool5
0?l003Wooooo00<0001oooooooooool0=oooool50?l000?ooooo0@000001ooooo`003?ooool5o`00
00?ooooo0_l00004ooooo`;o00001Oooool00`00003o0000ooooo`0oooooo`030000Oooooooooooo
03Sooooo1@3o001c000000D0o`000_ooool1o`00004000000Oooool0027ooooo00<00000oooooooo
ool0?oooool00`0007ooooooooooo`0hooooo`D0o`00>Oooool00`0007ooooooooooo`0gooooo`D0
o`000oooool10000007ooooo000Qooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0
>Oooool00`00003oooooooooo`0iooooo`<0o`00>_ooool00`00003oooooooooo`0hooooo`<0o`00
1?ooool10000007ooooo000Qooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00<00000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00?ooooo0@000001ooooo`008Oooooon
0000007ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.324585, -1494.39, \
0.00827746, 12.0378}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsection"],

Cell[BoxData[
    \(\(badInitialization2 = \ em;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation", "Subsection"],

Cell[BoxData[
    \(\(\(AnnularAllPlot[c1, rr1, rr2, #] &\)\  /@ \ 
        badInitialization2;\)\)], "Input"]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{675, 713},
WindowMargins->{{0, Automatic}, {Automatic, 1}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 43, 0, 62, "Title"],
Cell[1800, 53, 275, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2100, 63, 42, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2167, 67, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2245, 71, 36, 0, 43, "Subsubsection"],
Cell[2284, 73, 166, 4, 63, "Input"],
Cell[2453, 79, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2664, 87, 53, 0, 43, "Subsubsection"],
Cell[2720, 89, 207, 4, 63, "Input"],
Cell[2930, 95, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3063, 102, 40, 0, 49, "Subsection"],
Cell[3106, 104, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3206, 110, 36, 0, 49, "Subsection"],
Cell[3245, 112, 130, 2, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3424, 120, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3485, 124, 77, 0, 49, "Subsection"],
Cell[3565, 126, 893, 17, 255, "Input"],
Cell[4461, 145, 857, 17, 255, "Input"],

Cell[CellGroupData[{
Cell[5343, 166, 43, 0, 43, "Subsubsection"],
Cell[5389, 168, 299, 6, 79, "Input"],
Cell[5691, 176, 628, 10, 175, "Input"],
Cell[6322, 188, 296, 5, 95, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6667, 199, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[6744, 203, 50, 0, 43, "Subsubsection"],
Cell[6797, 205, 613, 9, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7447, 219, 65, 0, 43, "Subsubsection"],
Cell[7515, 221, 1145, 19, 223, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8721, 247, 52, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[8798, 251, 44, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8867, 255, 70, 1, 47, "Input"],
Cell[8940, 258, 21391, 327, 296, 893, 69, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30380, 591, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[30465, 595, 55, 0, 43, "Subsubsection"],
Cell[30523, 597, 105, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30665, 605, 39, 0, 43, "Subsubsection"],
Cell[30707, 607, 85, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30829, 613, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[30893, 617, 155, 3, 63, "Input"],
Cell[31051, 622, 65472, 1629, 296, 19537, 1057, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[96596, 2259, 75, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[96696, 2263, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[96790, 2267, 68, 0, 43, "Subsubsection"],
Cell[96861, 2269, 97, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96995, 2277, 57, 0, 43, "Subsubsection"],
Cell[97055, 2279, 83, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[97187, 2286, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[97254, 2290, 81, 1, 47, "Input"],
Cell[97338, 2293, 68, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[97455, 2300, 35, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[97515, 2304, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[97578, 2308, 79, 1, 47, "Input"],
Cell[97660, 2311, 355933, 8613, 408, 225281, 6997, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[453642, 10930, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[453703, 10934, 78, 1, 47, "Input"],
Cell[453784, 10937, 456203, 12155, 408, 268061, 9829, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[910036, 23098, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[910169, 23105, 66, 1, 47, "Input"],
Cell[910238, 23108, 53982, 1071, 186, 5828, 472, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[964281, 24186, 35, 0, 49, "Subsection"],
Cell[964319, 24188, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[964419, 24194, 31, 0, 49, "Subsection"],
Cell[964453, 24196, 110, 2, 47, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[964612, 24204, 93, 3, 39, "Section"],

Cell[CellGroupData[{
Cell[964730, 24211, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[964824, 24215, 68, 0, 43, "Subsubsection"],
Cell[964895, 24217, 97, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[965029, 24225, 55, 0, 43, "Subsubsection"],
Cell[965087, 24227, 130, 3, 47, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[965266, 24236, 42, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[965333, 24240, 80, 1, 47, "Input"],
Cell[965416, 24243, 69, 1, 47, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[965534, 24250, 35, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[965594, 24254, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[965657, 24258, 79, 1, 47, "Input"],
Cell[965739, 24261, 456665, 11647, 408, 259253, 9207, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1422453, 35914, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1422514, 35918, 78, 1, 47, "Input"],
Cell[1422595, 35921, 451754, 11959, 408, 265597, 9658, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1874398, 47886, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1874531, 47893, 66, 1, 47, "Input"],
Cell[1874600, 47896, 43023, 917, 186, 5889, 454, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1917684, 48820, 35, 0, 49, "Subsection"],
Cell[1917722, 48822, 63, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1917822, 48828, 31, 0, 33, "Subsection"],
Cell[1917856, 48830, 110, 2, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1918015, 48838, 74, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[1918114, 48842, 69, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1918208, 48846, 68, 0, 43, "Subsubsection"],
Cell[1918279, 48848, 97, 3, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1918413, 48856, 55, 0, 43, "Subsubsection"],
Cell[1918471, 48858, 130, 3, 47, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1918650, 48867, 42, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1918717, 48871, 80, 1, 47, "Input"],
Cell[1918800, 48874, 70, 1, 47, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1918919, 48881, 35, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1918979, 48885, 38, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1919042, 48889, 79, 1, 47, "Input"],
Cell[1919124, 48892, 441855, 11137, 408, 252049, 8791, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2361028, 60035, 36, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2361089, 60039, 78, 1, 47, "Input"],
Cell[2361170, 60042, 415285, 10484, 408, 246741, 8400, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2776504, 70532, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[2776637, 70539, 66, 1, 47, "Input"],
Cell[2776706, 70542, 36576, 876, 186, 5733, 491, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2813343, 71425, 35, 0, 49, "Subsection"],
Cell[2813381, 71427, 63, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2813481, 71433, 31, 0, 33, "Subsection"],
Cell[2813515, 71435, 110, 2, 47, "Input"]
}, Closed]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

