(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1385652,      35376]*)
(*NotebookOutlinePosition[   1386388,      35402]*)
(*  CellTagsIndexPosition[   1386344,      35398]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Difficult to classify examples: Normal density", "Title"],

Cell[TextData[{
  "This notebook gives difficult-to-classify examples using the Normal \
density, and assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global user definitions", "Section"],

Cell[CellGroupData[{

Cell["Colors representing two classes", "Subsection"],

Cell[CellGroupData[{

Cell["Data colors", "Subsubsection"],

Cell[BoxData[{
    \(\(data1Color = Red;\)\), "\[IndentingNewLine]", 
    \(\(data2Color = Blue;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[{
    \(\(style1\  = \ {data1Color, 
          PointSize[ .02]};\)\), "\[IndentingNewLine]", 
    \(\(style2\  = \ {data2Color, PointSize[ .02]};\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(class1Color\  = \ RGBColor[1, 1,  .5];\)\), "\[IndentingNewLine]", 
    \(\(class2Color\  = \ RGBColor[ .5, 1, 1];\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(classColors\  = \ {class1Color, \ class2Color};\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default plot range", "Subsection"],

Cell[BoxData[
    \(\(pr\  = \ {{0, 1}, {0, 1}};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["No frame ticks", "Subsection"],

Cell[BoxData[{
    \(\(nF = FrameTicks \[Rule] None;\)\), "\[IndentingNewLine]", 
    \(\(FS = Sequence[yS, \ nF];\)\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Difficult to classify example #1 (normal density)", "Section"],

Cell[CellGroupData[{

Cell["Specialized data generation and visualization functions", "Subsection"],

Cell[BoxData[
    \(\(AnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {x1\  - \ r2, \ 
              x1 + \ r2}; \[IndentingNewLine]range2\  = \ {x2\  - \ r2, \ 
              x2\  + \ r2}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  < \ 
                  r2\  && \ tst\  > \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(AntiAnnularRegion[center_, \ r1_, \ r2_, \ n_] := 
        Module[{tst, x1, x2, count, xd, t1, t2, range1, \ 
            range2}, {x1, x2}\  = \ 
            center; \[IndentingNewLine]range1\  = \ {0, \ 
              1}; \[IndentingNewLine]range2\  = \ {0, 
              1}; \[IndentingNewLine]count\  = \ 
            1; \[IndentingNewLine]xd\  = \ 
            Table[0, \ {n}]; \[IndentingNewLine]While[
            count\  <= \ 
              n, {t1, t2}\  = \ {Random[Real, \ range1], \ 
                Random[Real, \ range2]}; 
            If[\((tst\  = 
                      Sqrt[\((t1 - x1)\)^2\  + \ \((t2 - x2)\)^2])\)\  > \ 
                  r2\  || \ tst\  < \ r1, 
              xd[\([\(count++\)]\)]\  = \ {t1, 
                  t2}]\[IndentingNewLine]]; \[IndentingNewLine]xd\
\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Draw annular region in 2d", "Subsubsection"],

Cell[BoxData[
    \(\(DrawAnnularRegion[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {GrayLevel[1. ], 
                  Disk[center, r1]}}], \ AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for annular region", "Subsubsection"],

Cell[BoxData[
    \(\(AnnularAllPlot[center_, \ r1_, \ 
          r2_, \ {\[Mu]_, \[CapitalSigma]_, 
            priors_}] := \[IndentingNewLine]Module[{pr, g1, g2, g3, g4, g5, 
            ga, gb}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g1\  = \ \ DrawAnnularRegion[center, 
              rr1, rr2, \ pr, LightPink, \ nS]; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ 
              nS]; \[IndentingNewLine]g3\  = \ 
            PlotContourPDFOverlay[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nS]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nS]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, 
              nS]; \[IndentingNewLine]ga\  = \ 
            Show[g1, g2]; \[IndentingNewLine]gb\  = \ 
            Show[g1, g3]; \[IndentingNewLine]Show[
            GraphicsArray[{{ga, gb}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Region definitions", "Subsubsection"],

Cell[BoxData[
    \(\(\(\(c1\  = \ { .5,  .5};\) (*\ 
      center\ of\ annular\ region\ *) \[IndentingNewLine]
    \(rr1\  = \  .12;\) (*\ inner\ radius\ *) \[IndentingNewLine]
    \(rr2\  = \  .35;\)\)\( (*\ outer\ radius\ *) \)\)\)], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(DrawAnnularRegion2[center_, r1_, r2_, pr_, \ color_:  LightPink, \ 
          color2_:  White, 
          opt___] := \[IndentingNewLine]Module[{xmin, xmax, ymin, 
            ymax}, \[IndentingNewLine]{xmin, xmax, ymin, ymax} = 
            Flatten[pr] + {\(- .01\),  .01, \(- .01\),  .01}; \
\[IndentingNewLine]Show[\[IndentingNewLine]Graphics[{{color, 
                  Disk[center, \ r2]}, {color2, Disk[center, r1]}}], \ 
            AspectRatio \[Rule] Automatic, \ 
            PlotRange \[Rule] {{xmin, xmax}, {ymin, ymax}}, 
            Frame \[Rule] True, opt]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot\  := 
        Show[Graphics[{class1Color, 
              Rectangle[{0, 0}, {1, 1}]}], \ \ DrawAnnularRegion2[c1, rr1, 
            rr2, \ pr, class2Color, \ class1Color, nS]\ , 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Idealized data classes", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
1 1 .5 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00o`00000P0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00
00<00000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?oo
ool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<00000oooo
ooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool10000007o
oooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo
0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6oooo
o`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC
0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool000030000
0?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3o
oglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3o
ogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
o`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0
000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo
4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?o
ooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo
1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooo
ooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0
oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooon60?ooO`P0OoooQ03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooNP3ooglP07ooogP0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooogD0oomo:@1ooomd0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom`0?ooOc<0OoooK`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
KP3ooglg07ooofd0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooofX0oomo@01o
oomX0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomW0?ooOdD0OoooIP3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooI@3oogm907ooof@0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooof<0oomoC@1ooomR0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomQ0?ooOe40OoooH03oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooG`3oogmF07oooed0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooe`0oomoF`1ooomK0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomJ0?oo
Oel0OoooF@3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooF03oogmS07oooeL0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooeL0oomoI@1ooomF0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooomF0?ooOfL0OoooE@3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooE03oogm[07oooe<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooe80oomoK`1ooomA0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooomA0?ooOg40OoooD03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
D03oogmc07ooodl0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodh0oomoM`1o
oom=0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom=0?ooOgP0OoooC@3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooC@3oogmi07oood`0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooood/0oomoO@1ooom:0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooom:0?ooOgl0OoooB@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooB@3oogn107ooodP0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooodP0oomoP`1ooom70?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom70?oo
OhD0OoooAP3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooAP3oogn707ooodD0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodD0oomoR@1ooom40?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooom40?ooOh/0Oooo@`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo@`3oogn=07oood80oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooood80oomoS`1ooom10?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom10?ooOi00Oooo@@3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
@@3oognA07oood00oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocl0oomoU@1o
ooln0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooooln0?ooOiH0Oooo?P3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo?P3oognG07ooocd0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocd0oomoV@1oooll0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooooll0?ooOi/0Oooo>`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo>`3oognL07oooc/0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc/0oomoW@1ooolj0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolj0?oo
Oih0Oooo>P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo>P3oognO07ooocT0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocT0oomoX@1ooolh0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolh0?ooOj<0Oooo=`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo=`3oognT07ooocL0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooocL0oomoY@1ooolf0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolf0?ooOjH0Oooo=P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=P3oognW07ooocD0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocD0oomoZ01o
oole0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooole0?ooOjT0Oooo=03oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=03oognZ07oooc@0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooooc@0oomoZ`1ooolc0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolc0?ooOj`0Oooo<`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo<`3oogn/07oooc<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc<0oomo[@1ooolb0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolb0?oo
Ojh0Oooo<P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo<P3oogn_07oooc40
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc40oomo/01ooola0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooola0?ooOk40Oooo<03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo<03oognb07oooc00oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc00oomo/`1oool_0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00oooool_0?ooOeD0Oooo2`3oogmD07ooobl0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobl0oomoD@1ooolC0?ooOe40Oooo;P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo;P3oogm?07oooaX0oomoC@1oool^0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00oooool^0?ooOdd0Oooo7@3oogm<07ooobh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobh0oomoC01ooolQ0?ooOdT0Oooo;P3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo;P3oogm:07ooob@0oomoB01oool^0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooool^0?ooOdL0Oooo:03oogm807ooobd0oomo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooobd0oomoA`1ooolZ0?ooOdL0Oooo;@3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo;@3oogm607ooob`0oomoA`1oool/0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00oooool/0?ooOdL0Oooo;@3oogm607ooob`0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooob`0oomoAP1oool_0?ooOdD0Oooo;03oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo;03oogm507oooc40oomoA01oool/0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00oooool/0?ooOd@0Oooo<P3oogm407ooob`0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooob`0oomo@`1ooold0?ooOd@0Oooo:`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm407ooocD0oomo@`1oool[0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd<0Oooo=`3oogm207ooob/0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomo@P1oooli0?ooOd40Oooo
:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm207ooocT0oomo@P1o
oolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd80Oooo>`3oogm1
07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@@1oooll0?oo
Od40Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm107oooc`0
oomo@@1ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd00Oooo
?P3oogm007ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@01o
ooln0?ooOd00Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm0
07oooch0oomo@01ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?oo
Od00Oooo?`3ooglo07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0
oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oolZ0?ooOcl0Oooo@03ooglo07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooobX0oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo:P3ooglo07oood40oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolY0?ooOcl0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobT0oomo?`1ooom20?ooOcl0Oooo:@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo:@3ooglo07oood80oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00ooooolY0?ooOcl0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobT0oomo?`1ooom20?ooOcl0Oooo:@3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo:@3ooglo07oood80oomo?`1ooolY0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolZ0?ooOch0Oooo@P3ooglo07ooobT0oomo1_ooool10000007ooooo
00000`00003oooooooooo`03ooooobX0oomo?`1ooom10?ooOch0Oooo:P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooolZ0?ooOcl0Oooo@03ooglo07ooobX0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooobX0oomo?`1ooom00?ooOcl0Oooo:P3oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?ooooo:P3ooglo07oood00oomo?`1ooolZ0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd00Oooo?`3ooglo07ooobX0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@01oooln0?ooOd00Oooo:P3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm007oooch0oomo@01ooolZ0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooolZ0?ooOd40Oooo?@3oogm007ooobX0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooobX0oomo@@1oooll0?ooOd40Oooo
:P3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:P3oogm107oooc`0oomo@@1o
oolZ0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd40Oooo>P3oogm2
07ooobX0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomo@P1oooli0?oo
Od40Oooo:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo:`3oogm207ooocP0
oomo@P1oool[0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool[0?ooOd<0Oooo
=P3oogm307ooob/0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob/0oomoA01o
oole0?ooOd<0Oooo:`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo;03oogm4
07oooc<0oomoA01oool[0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooool/0?oo
OdD0Oooo<@3oogm407ooob`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooob`0
oomoA@1oool`0?ooOdD0Oooo;03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
;03oogm607ooobh0oomoAP1oool/0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
ool/0?ooOdL0Oooo;03oogm707ooob`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooobd0oomoB01ooolY0?ooOdP0Oooo;03oogl6ooooo`4000000Oooool0000300000?oooooooooo
00?ooooo;@3oogm907ooobL0oomoB01oool]0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00oooool^0?ooOd/0Oooo8`3oogm907ooobd0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooobh0oomoC@1ooolO0?ooOdX0Oooo;P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo;P3oogm>07oooa/0oomoC@1oool^0?ooO`Kooooo0@000001ooooo`0000<00000
ooooooooool00oooool^0?ooOe40Oooo5`3oogm>07ooobh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooobl0oomoD@1ooolC0?ooOe40Oooo;P3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?ooooo;`3oogmF07ooo`T0oomoE@1oool_0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00oooool_0?ooOk@0Oooo;`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo<03oognc07ooobl0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooc00oomo/P1oool`0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooola0?oo
Ok40Oooo<03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo<@3oogn`07oooc40
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc80oomo[`1ooola0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolb0?ooOjh0Oooo<P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo<`3oogn]07oooc80oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc<0oomo[01ooolc0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooold0?ooOj/0Oooo<`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
=03oognZ07oooc@0oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooc@0oomoZP1o
oold0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooole0?ooOjT0Oooo=03oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo=@3oognX07ooocD0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooocH0oomoY`1ooole0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooolf0?ooOjH0Oooo=P3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo=`3oognU07ooocH0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooocP0oomoX`1ooolg0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00oooooli0?oo
Oj40Oooo>03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo>@3oognP07ooocT0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooocX0oomoW`1oooli0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooolj0?ooOih0Oooo>P3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?ooooo>`3oognM07ooocX0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03oooooc`0oomoV`1ooolk0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooolm0?ooOiT0Oooo?03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
?@3oognH07ooocd0oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooch0oomoU`1o
oolm0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom00?ooOi<0Oooo?`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?ooooo@03oognB07oood00oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooood40oomoT@1ooom00?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooom20?ooOhl0Oooo@@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?ooooo@`3oogn=07oood80oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooood@0oomoR`1ooom30?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom50?oo
OhT0OoooA03oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooAP3oogn707ooodD0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodL0oomoQ@1ooom60?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooom80?ooOh<0OoooA`3oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooB@3oogn107ooodP0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooodX0oomoO`1ooom90?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooom<0?ooOg/0OoooB`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
C03oogmj07oood`0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooodd0oomoN@1o
oom<0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom?0?ooOgD0OoooCP3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooD03oogmc07ooodl0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03oooooe40oomoL@1ooom@0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomC0?ooOfd0OoooDP3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooE@3oogmY07oooe@0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
oooooeH0oomoI`1ooomE0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooomG0?oo
OfD0OoooEP3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooF@3oogmQ07oooeP0
oomo1_ooool10000007ooooo00000`00003oooooooooo`03oooooe/0oomoG@1ooomJ0?ooO`Kooooo
0@000001ooooo`0000<00000ooooooooool00ooooomM0?ooOeT0OoooG03oogl6ooooo`4000000Ooo
ool0000300000?oooooooooo00?oooooH03oogmD07oooeh0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooof80oomoC`1ooomQ0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooomT0?ooOd/0OoooH`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
IP3oogm707ooofD0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooofP0oomo@`1o
oomW0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooom[0?ooOch0OoooJ@3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooK`3oogle07ooofh0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooog40oomo<@1ooom`0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooomf0?ooObL0OoooM@3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooN`3ooglN07ooogT0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooohL0oomo1P1ooon50?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?oo
Oa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`40
00000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<0
0000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03
ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?oo
O`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007o
oooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oo
oooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo
0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6oooo
o`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`00
00<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooooooo
o`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC
0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000
007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool000030000
0?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooo
oooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6
ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001oooo
o`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003ooooo
ooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3o
oglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool1
0000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool00003
00000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool0
0ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3o
ogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001
ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003o
ooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?ooooo
o`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_oo
ool10000007ooooo00000`00003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0
000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@000001ooooo`0000<00000oooooooo
ool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00003oooooooooo`03ooooool0oomo
4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo00?oooooo`3ooglC0?ooO`Kooooo0@00
0001ooooo`0000<00000ooooooooool00ooooooo0?ooOa<0oomo1_ooool10000007ooooo00000`00
003oooooooooo`03ooooool0oomo4`3oogl6ooooo`4000000Oooool0000300000?oooooooooo0?oo
oooo7?ooool10000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`0000<0
0000ooooooooool0oooooolLooooo`4000000Oooool0000300000?oooooooooo0?oooooo7?ooool1
0000007ooooo00000`00003oooooooooo`3ooooooacooooo0@000001ooooo`00o`00000P0000007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = AnnularRegion[c1, \ rr1, \ rr2, \ n1];\)\), "\n", 
    \(\(data2\  = AntiAnnularRegion[c1, \ rr1, \ rr2, \ n2];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.37824 .37334 Mdot
.21468 .68695 Mdot
.63484 .35767 Mdot
.49736 .27252 Mdot
.64504 .76281 Mdot
.30177 .38345 Mdot
.28735 .70762 Mdot
.60753 .67032 Mdot
.56189 .82745 Mdot
.63227 .48495 Mdot
.52801 .72765 Mdot
.63694 .52465 Mdot
.73631 .52685 Mdot
.29644 .40899 Mdot
.24813 .60717 Mdot
.38714 .35522 Mdot
.39888 .75838 Mdot
.37663 .49693 Mdot
.65619 .34378 Mdot
.5875 .16884 Mdot
.28505 .45927 Mdot
.7937 .48733 Mdot
.39188 .77556 Mdot
.65412 .2352 Mdot
.30061 .32525 Mdot
.65945 .20966 Mdot
.33983 .42569 Mdot
.42917 .69757 Mdot
.78408 .51045 Mdot
.2094 .3575 Mdot
.28475 .32354 Mdot
.46504 .34552 Mdot
.51449 .70132 Mdot
.60783 .77499 Mdot
.70351 .62299 Mdot
.20092 .57019 Mdot
.28111 .33777 Mdot
.61489 .71576 Mdot
.34017 .67046 Mdot
.21228 .50378 Mdot
.25417 .32647 Mdot
.21257 .63951 Mdot
.44788 .70766 Mdot
.72245 .68843 Mdot
.67839 .2751 Mdot
.70268 .76328 Mdot
.22036 .40248 Mdot
.51938 .24969 Mdot
.50115 .7305 Mdot
.40826 .79266 Mdot
.66416 .24947 Mdot
.78485 .40417 Mdot
.26332 .28593 Mdot
.59767 .81411 Mdot
.54181 .83922 Mdot
.29057 .38194 Mdot
.29482 .4352 Mdot
.72545 .43241 Mdot
.4738 .3426 Mdot
.76507 .34741 Mdot
.53209 .78156 Mdot
.78848 .36346 Mdot
.42563 .6525 Mdot
.67144 .29966 Mdot
.38267 .76905 Mdot
.23064 .32869 Mdot
.684 .77297 Mdot
.21462 .51434 Mdot
.2291 .3089 Mdot
.29269 .32379 Mdot
.54015 .37047 Mdot
.34735 .80347 Mdot
.27139 .56111 Mdot
.51904 .66066 Mdot
.73185 .63519 Mdot
.50181 .36759 Mdot
.44744 .18461 Mdot
.42957 .21556 Mdot
.31162 .70395 Mdot
.73255 .68823 Mdot
.61803 .28398 Mdot
.44523 .23982 Mdot
.72931 .49193 Mdot
.68146 .62971 Mdot
.49475 .2089 Mdot
.33651 .41898 Mdot
.75008 .36028 Mdot
.73569 .32033 Mdot
.17438 .51519 Mdot
.77142 .41985 Mdot
.39949 .38807 Mdot
.48306 .33689 Mdot
.51332 .73928 Mdot
.675 .26644 Mdot
.83149 .53387 Mdot
.49535 .6906 Mdot
.78418 .50958 Mdot
.20536 .34611 Mdot
.57089 .81513 Mdot
.32826 .58392 Mdot
.63715 .58938 Mdot
.65808 .68778 Mdot
.82622 .57821 Mdot
.32256 .4696 Mdot
.48773 .73075 Mdot
.38151 .80315 Mdot
.74245 .40043 Mdot
.33302 .61391 Mdot
.32842 .42844 Mdot
.2128 .68764 Mdot
.41879 .25513 Mdot
.26474 .25166 Mdot
.359 .42167 Mdot
.78532 .6252 Mdot
.71441 .53406 Mdot
.56067 .66518 Mdot
.38452 .20814 Mdot
.64355 .70519 Mdot
.32858 .36363 Mdot
.45817 .17452 Mdot
.25603 .59599 Mdot
.70287 .38851 Mdot
.38476 .21879 Mdot
.29906 .56647 Mdot
.41279 .77144 Mdot
.75768 .5152 Mdot
.61238 .22311 Mdot
.58597 .30843 Mdot
.51082 .18792 Mdot
.32827 .64084 Mdot
.18375 .37314 Mdot
.6141 .44484 Mdot
.27153 .55918 Mdot
.69566 .36455 Mdot
.52191 .29881 Mdot
.66453 .3352 Mdot
.26712 .70687 Mdot
.24023 .49059 Mdot
.46927 .20261 Mdot
.34925 .74708 Mdot
.46755 .66716 Mdot
.66368 .49633 Mdot
.75606 .3522 Mdot
.6458 .48846 Mdot
.6535 .41595 Mdot
.34644 .79597 Mdot
.62561 .28496 Mdot
.33352 .55255 Mdot
.34764 .63395 Mdot
.3655 .42077 Mdot
.21887 .46732 Mdot
.63206 .79329 Mdot
.40851 .20823 Mdot
.35086 .7152 Mdot
.73136 .4971 Mdot
.52272 .2332 Mdot
.5685 .64263 Mdot
.77957 .69248 Mdot
.20906 .55765 Mdot
.70994 .74019 Mdot
.83327 .45911 Mdot
.73347 .74003 Mdot
.7684 .40946 Mdot
.53947 .18169 Mdot
.53625 .78672 Mdot
.51432 .67916 Mdot
.18818 .4516 Mdot
.15827 .5125 Mdot
.32137 .55455 Mdot
.43104 .65765 Mdot
.24288 .64393 Mdot
.73471 .63283 Mdot
.35532 .68925 Mdot
.53465 .20927 Mdot
.38757 .54517 Mdot
.48104 .82539 Mdot
.35625 .25042 Mdot
.19174 .53901 Mdot
.60384 .7245 Mdot
.38234 .61557 Mdot
.71227 .24853 Mdot
.33337 .72714 Mdot
.64186 .67473 Mdot
.28311 .7004 Mdot
.31769 .69248 Mdot
.77 .60683 Mdot
.68119 .37959 Mdot
.3697 .80637 Mdot
.28815 .34332 Mdot
.41902 .25165 Mdot
.65398 .46367 Mdot
.74835 .69236 Mdot
.69443 .78273 Mdot
.69524 .38513 Mdot
.1701 .56001 Mdot
.64354 .59677 Mdot
.65618 .40597 Mdot
.40982 .72234 Mdot
.50461 .18684 Mdot
.29565 .37064 Mdot
.28242 .65377 Mdot
.22714 .49243 Mdot
.48202 .21386 Mdot
.66898 .65102 Mdot
.66678 .70872 Mdot
.6767 .55535 Mdot
.60138 .57124 Mdot
.53791 .34157 Mdot
.57098 .7615 Mdot
.77347 .47394 Mdot
.26136 .66606 Mdot
.27076 .26827 Mdot
.43772 .80048 Mdot
.63001 .50216 Mdot
.60416 .402 Mdot
.45765 .16942 Mdot
.65389 .52949 Mdot
.80009 .58662 Mdot
.69771 .67912 Mdot
.61906 .38949 Mdot
.33821 .43214 Mdot
.57719 .18701 Mdot
.76832 .29151 Mdot
.51094 .81286 Mdot
.46753 .27895 Mdot
.70018 .44024 Mdot
.81976 .3847 Mdot
.656 .69948 Mdot
.17622 .56307 Mdot
.35007 .7747 Mdot
.77436 .56319 Mdot
.72568 .65261 Mdot
.37197 .27401 Mdot
.25441 .73826 Mdot
.73999 .74305 Mdot
.48692 .2859 Mdot
.72063 .33684 Mdot
.36853 .21969 Mdot
.43533 .64706 Mdot
.50411 .24074 Mdot
.29279 .47864 Mdot
.42993 .80406 Mdot
.76396 .3615 Mdot
.33238 .22266 Mdot
.36172 .78697 Mdot
.43553 .32275 Mdot
.71794 .65794 Mdot
.55804 .82905 Mdot
.27957 .33885 Mdot
.6186 .25497 Mdot
.34553 .29405 Mdot
.43105 .62371 Mdot
.2262 .67988 Mdot
.57763 .74864 Mdot
.68826 .42683 Mdot
.74002 .58075 Mdot
.35732 .80611 Mdot
.27828 .48264 Mdot
.77588 .34544 Mdot
.5744 .35405 Mdot
.34197 .36855 Mdot
.31053 .49537 Mdot
.32238 .44896 Mdot
.46541 .2254 Mdot
.42549 .71135 Mdot
.26494 .26243 Mdot
.30408 .38558 Mdot
.25949 .28467 Mdot
.37133 .197 Mdot
.52823 .77375 Mdot
.45174 .76608 Mdot
.18003 .41331 Mdot
.26663 .55439 Mdot
.71264 .76107 Mdot
.4041 .69253 Mdot
.29601 .58697 Mdot
.19338 .45916 Mdot
.54848 .20227 Mdot
.48512 .27211 Mdot
.61561 .35417 Mdot
.36838 .50477 Mdot
.60416 .82615 Mdot
.19271 .45864 Mdot
.52756 .77323 Mdot
.19931 .65799 Mdot
.61674 .47823 Mdot
.27914 .24951 Mdot
.30344 .258 Mdot
.54242 .27499 Mdot
.79337 .57947 Mdot
.42267 .64937 Mdot
.72616 .29108 Mdot
.26628 .65599 Mdot
.79652 .5307 Mdot
.83027 .56334 Mdot
.73807 .57479 Mdot
.6837 .4622 Mdot
.75199 .53668 Mdot
.29814 .34408 Mdot
.35967 .24061 Mdot
.53595 .30785 Mdot
.47665 .79267 Mdot
.31259 .31646 Mdot
.36723 .29354 Mdot
.3592 .6289 Mdot
.38009 .57334 Mdot
.46427 .21097 Mdot
.53954 .268 Mdot
.39826 .76706 Mdot
.21772 .40922 Mdot
.56195 .73378 Mdot
.35158 .5971 Mdot
.23852 .40976 Mdot
.43195 .75575 Mdot
.52624 .73547 Mdot
.77257 .33213 Mdot
.71172 .76605 Mdot
.23844 .66079 Mdot
.41753 .36629 Mdot
.26696 .63703 Mdot
.33587 .79967 Mdot
.67815 .72442 Mdot
.65277 .22106 Mdot
.64446 .73572 Mdot
.72333 .73206 Mdot
.64935 .5872 Mdot
.37306 .32932 Mdot
.29148 .51166 Mdot
.63064 .76956 Mdot
.45163 .81303 Mdot
.642 .74884 Mdot
.54505 .25763 Mdot
.73884 .51356 Mdot
.52264 .34111 Mdot
.70203 .75805 Mdot
.38802 .67258 Mdot
.3635 .79795 Mdot
.47207 .70384 Mdot
.57637 .34714 Mdot
.45 .28731 Mdot
.66571 .33345 Mdot
.3786 .29882 Mdot
.45907 .37864 Mdot
.60197 .28023 Mdot
.81302 .55647 Mdot
.56511 .75749 Mdot
.39351 .3662 Mdot
.41308 .71213 Mdot
.33978 .36016 Mdot
.80621 .58169 Mdot
.51721 .18358 Mdot
.215 .64807 Mdot
.61619 .38776 Mdot
.35829 .3059 Mdot
.6463 .67443 Mdot
.63631 .39155 Mdot
.3801 .52255 Mdot
.41702 .784 Mdot
.55267 .23508 Mdot
.67569 .50113 Mdot
.69319 .34163 Mdot
.49176 .1926 Mdot
.23204 .36795 Mdot
.69859 .64419 Mdot
.66552 .746 Mdot
.47535 .2785 Mdot
.59565 .64107 Mdot
.2152 .33764 Mdot
.19984 .56285 Mdot
.38265 .67965 Mdot
.54845 .28956 Mdot
.67011 .24718 Mdot
.1977 .45915 Mdot
.59493 .72237 Mdot
.34225 .6581 Mdot
.71003 .53646 Mdot
.33376 .3353 Mdot
.6517 .35568 Mdot
.29078 .6156 Mdot
.75849 .39257 Mdot
.69562 .56515 Mdot
.32043 .51334 Mdot
.51023 .75019 Mdot
.64334 .37059 Mdot
.21413 .35853 Mdot
.76649 .58607 Mdot
.33789 .26004 Mdot
.6724 .47143 Mdot
.42253 .71061 Mdot
.25896 .35413 Mdot
.71108 .66029 Mdot
.66635 .62864 Mdot
.65381 .45862 Mdot
.67472 .61374 Mdot
.73046 .71568 Mdot
.26586 .27487 Mdot
.54944 .6125 Mdot
.43659 .64657 Mdot
.28377 .74503 Mdot
.45981 .74029 Mdot
.18167 .54777 Mdot
.31373 .73062 Mdot
.32691 .26927 Mdot
.61573 .55631 Mdot
.38633 .38066 Mdot
.79287 .57723 Mdot
.48992 .68008 Mdot
.75772 .49415 Mdot
.49667 .78216 Mdot
.60086 .60667 Mdot
.32662 .66976 Mdot
.25466 .33468 Mdot
.67443 .32795 Mdot
.48207 .6215 Mdot
.44496 .79043 Mdot
.41577 .67769 Mdot
.49523 .37006 Mdot
.47638 .63577 Mdot
.16217 .53312 Mdot
.56179 .29848 Mdot
.80407 .53495 Mdot
.33888 .76747 Mdot
.70627 .35714 Mdot
.38107 .57877 Mdot
.21949 .64909 Mdot
.48893 .26531 Mdot
.56209 .74592 Mdot
.80934 .43188 Mdot
.71457 .38436 Mdot
.36384 .63111 Mdot
.722 .49597 Mdot
.7567 .59489 Mdot
.80457 .49151 Mdot
.5313 .24459 Mdot
.42823 .16984 Mdot
.72616 .47605 Mdot
.63581 .76525 Mdot
.36803 .43568 Mdot
.71367 .75921 Mdot
.33924 .67149 Mdot
.78167 .54904 Mdot
.75414 .65851 Mdot
.36164 .29837 Mdot
.56897 .37626 Mdot
.46887 .63105 Mdot
.3578 .78372 Mdot
.48727 .18137 Mdot
.45036 .67027 Mdot
.3049 .35302 Mdot
.51183 .27809 Mdot
.45631 .2051 Mdot
.18911 .39614 Mdot
.82574 .46927 Mdot
.46328 .17675 Mdot
.51374 .68136 Mdot
.1917 .35489 Mdot
.61821 .21166 Mdot
.47017 .70177 Mdot
.22951 .40653 Mdot
.23314 .32098 Mdot
.61633 .35829 Mdot
.63373 .73216 Mdot
.58075 .74809 Mdot
.47527 .66879 Mdot
.24202 .6959 Mdot
.7002 .61399 Mdot
.50068 .32501 Mdot
.38689 .75536 Mdot
.42803 .76162 Mdot
.31061 .59125 Mdot
.65484 .56019 Mdot
.26658 .66641 Mdot
.52897 .76146 Mdot
.74425 .62038 Mdot
.6591 .76761 Mdot
.3535 .47868 Mdot
.31529 .59947 Mdot
.80974 .56645 Mdot
.73039 .68098 Mdot
.54629 .3088 Mdot
.21131 .44962 Mdot
.31019 .67238 Mdot
.49423 .7479 Mdot
.61013 .66226 Mdot
.33581 .3053 Mdot
.64352 .25267 Mdot
.373 .34666 Mdot
.44124 .81181 Mdot
.31855 .74018 Mdot
.51413 .3199 Mdot
.6933 .61813 Mdot
.20664 .52232 Mdot
.72977 .54716 Mdot
.21911 .40172 Mdot
.51363 .35736 Mdot
.62101 .43305 Mdot
.35195 .46032 Mdot
.35396 .698 Mdot
.34359 .39252 Mdot
.73681 .4176 Mdot
.6726 .22948 Mdot
.20038 .64261 Mdot
.49428 .21487 Mdot
.25088 .31034 Mdot
.31047 .44237 Mdot
.74207 .69316 Mdot
.79965 .58751 Mdot
.2197 .32677 Mdot
.72588 .38489 Mdot
.17619 .5273 Mdot
.38846 .32688 Mdot
.18245 .40702 Mdot
.62395 .65917 Mdot
.25096 .5316 Mdot
.631 .65567 Mdot
.82711 .50172 Mdot
.23252 .35503 Mdot
.76428 .33181 Mdot
.74495 .64764 Mdot
.80446 .64327 Mdot
.71936 .39749 Mdot
.62527 .70902 Mdot
.65058 .4784 Mdot
.68478 .6198 Mdot
.7008 .27494 Mdot
.78707 .46771 Mdot
.63283 .69743 Mdot
.31535 .74114 Mdot
.45232 .71334 Mdot
.53322 .18898 Mdot
.64487 .3918 Mdot
.69158 .41232 Mdot
.62528 .56906 Mdot
.68135 .25822 Mdot
.21111 .35111 Mdot
.24407 .60379 Mdot
.45437 .7495 Mdot
.70418 .31448 Mdot
.32783 .28236 Mdot
.35719 .64436 Mdot
.47938 .71318 Mdot
.57504 .23216 Mdot
.43435 .38155 Mdot
.64963 .37015 Mdot
.41482 .32593 Mdot
.35211 .46379 Mdot
.55377 .16832 Mdot
.35005 .42763 Mdot
.38281 .7291 Mdot
.71764 .36387 Mdot
.56565 .73263 Mdot
.52239 .74322 Mdot
.3292 .47245 Mdot
.33633 .68918 Mdot
.76165 .29494 Mdot
.39439 .56092 Mdot
.51988 .35391 Mdot
.76471 .58798 Mdot
.75282 .70994 Mdot
.2806 .71786 Mdot
.48882 .29219 Mdot
.39808 .74169 Mdot
.77352 .36251 Mdot
.33278 .43634 Mdot
.44316 .72818 Mdot
.65604 .23929 Mdot
.52159 .29706 Mdot
.65855 .62861 Mdot
.6119 .43026 Mdot
.24694 .65698 Mdot
.77427 .51465 Mdot
.31655 .45133 Mdot
.59835 .23518 Mdot
.71653 .56629 Mdot
.35181 .42609 Mdot
.28377 .36728 Mdot
.29351 .56318 Mdot
.25175 .4403 Mdot
.63521 .20814 Mdot
.70408 .53663 Mdot
.68826 .33199 Mdot
.26259 .45831 Mdot
.81487 .60883 Mdot
.32028 .46243 Mdot
.61993 .3396 Mdot
.74301 .53197 Mdot
.26466 .4807 Mdot
.40372 .78721 Mdot
.29798 .48576 Mdot
.27719 .3362 Mdot
.5004 .83973 Mdot
.46352 .65282 Mdot
.19818 .3962 Mdot
.52152 .74935 Mdot
.58434 .62919 Mdot
.52981 .81457 Mdot
.49229 .68416 Mdot
.37196 .50483 Mdot
.7147 .50824 Mdot
.40804 .69855 Mdot
.42848 .29483 Mdot
.49495 .37932 Mdot
.30217 .32001 Mdot
.80828 .40789 Mdot
.65303 .47898 Mdot
.57646 .76535 Mdot
.43793 .81729 Mdot
.32234 .45986 Mdot
.69568 .76883 Mdot
.31519 .61049 Mdot
.42407 .63086 Mdot
.42867 .66129 Mdot
.77225 .4084 Mdot
.28336 .49814 Mdot
.47347 .17602 Mdot
.38751 .23517 Mdot
.22203 .61844 Mdot
.36948 .69275 Mdot
.72532 .30731 Mdot
.59882 .65231 Mdot
.2092 .65297 Mdot
.28221 .63314 Mdot
.66483 .57466 Mdot
.24667 .58813 Mdot
.59966 .79935 Mdot
.38704 .26347 Mdot
.46664 .19729 Mdot
.44162 .20158 Mdot
.58446 .73312 Mdot
.42532 .39124 Mdot
.37299 .58141 Mdot
.70344 .44767 Mdot
.5513 .16361 Mdot
.61363 .70267 Mdot
.56459 .78706 Mdot
.52636 .65321 Mdot
.27983 .74234 Mdot
.69765 .50797 Mdot
.48152 .7697 Mdot
.25281 .39161 Mdot
.48932 .68158 Mdot
.414 .76848 Mdot
.22168 .42586 Mdot
.79813 .59161 Mdot
.63218 .19091 Mdot
.19113 .63537 Mdot
.49801 .16477 Mdot
.17006 .52709 Mdot
.21835 .48974 Mdot
.26336 .74126 Mdot
.49574 .74421 Mdot
.40338 .23288 Mdot
.46148 .2657 Mdot
.68702 .57837 Mdot
.58052 .68025 Mdot
.53166 .79082 Mdot
.21672 .42471 Mdot
.22705 .68198 Mdot
.31135 .3566 Mdot
.6219 .25709 Mdot
.46747 .62136 Mdot
.27887 .6197 Mdot
.60163 .36301 Mdot
.38816 .33032 Mdot
.76806 .67273 Mdot
.19943 .56658 Mdot
.70821 .40489 Mdot
.55372 .20516 Mdot
.35048 .62751 Mdot
.24311 .42694 Mdot
.35616 .48582 Mdot
.46997 .64481 Mdot
.73888 .28741 Mdot
.19994 .48277 Mdot
.69631 .56397 Mdot
.33487 .23474 Mdot
.72393 .67938 Mdot
.62429 .18644 Mdot
.53031 .20873 Mdot
.45871 .20092 Mdot
.33874 .27368 Mdot
.37074 .80446 Mdot
.24985 .2687 Mdot
.32766 .47855 Mdot
.51588 .71162 Mdot
.3685 .3711 Mdot
.6736 .61159 Mdot
.52686 .61571 Mdot
.53813 .37332 Mdot
.27784 .53345 Mdot
.44514 .26148 Mdot
.20533 .55676 Mdot
.80052 .65422 Mdot
.53259 .68827 Mdot
.54702 .18537 Mdot
.75842 .67153 Mdot
.17702 .41281 Mdot
.42356 .33363 Mdot
.48203 .19635 Mdot
.30259 .64331 Mdot
.35241 .58842 Mdot
.39503 .77733 Mdot
.64929 .49421 Mdot
.75196 .50446 Mdot
.73401 .66582 Mdot
.7318 .24852 Mdot
.40663 .20903 Mdot
.32159 .68888 Mdot
.36974 .27417 Mdot
.38131 .7392 Mdot
.57415 .32313 Mdot
.76861 .36308 Mdot
.76799 .67205 Mdot
.28486 .6101 Mdot
.72137 .55793 Mdot
.40194 .67144 Mdot
.28405 .54457 Mdot
.70176 .40472 Mdot
.35857 .33835 Mdot
.7769 .5758 Mdot
.34191 .47973 Mdot
.74292 .56957 Mdot
.33312 .20925 Mdot
.33569 .3117 Mdot
.77431 .38095 Mdot
.67033 .71421 Mdot
.49841 .65311 Mdot
.54314 .3265 Mdot
.63979 .40526 Mdot
.70603 .67259 Mdot
.84266 .50843 Mdot
.7856 .6388 Mdot
.62999 .20749 Mdot
.69882 .66968 Mdot
.77959 .6129 Mdot
.39331 .44326 Mdot
.56062 .6113 Mdot
.20873 .4551 Mdot
.73462 .67882 Mdot
.26675 .30788 Mdot
.26149 .62819 Mdot
.5031 .66705 Mdot
.40581 .80165 Mdot
.56665 .21101 Mdot
.33021 .61089 Mdot
.48793 .33064 Mdot
.27833 .31265 Mdot
.63334 .39193 Mdot
.22598 .36597 Mdot
.74186 .55625 Mdot
.63723 .77119 Mdot
.38828 .81268 Mdot
.73262 .3369 Mdot
.69494 .69695 Mdot
.21846 .46188 Mdot
.36869 .20424 Mdot
.31974 .74877 Mdot
.52565 .82071 Mdot
.79645 .59823 Mdot
.22069 .4182 Mdot
.50455 .6922 Mdot
.25956 .28349 Mdot
.2236 .43571 Mdot
.69805 .38833 Mdot
.72135 .75911 Mdot
.35257 .78153 Mdot
.49216 .64396 Mdot
.42833 .38262 Mdot
.76692 .53356 Mdot
.70018 .25471 Mdot
.72926 .30419 Mdot
.22137 .6665 Mdot
.67092 .37382 Mdot
.63617 .44074 Mdot
.71239 .75032 Mdot
.56594 .6006 Mdot
.60589 .5989 Mdot
.63794 .36586 Mdot
.3889 .65229 Mdot
.59586 .36841 Mdot
.39993 .56814 Mdot
.72661 .46122 Mdot
.71441 .65188 Mdot
.22809 .36864 Mdot
.70434 .70891 Mdot
.54716 .69859 Mdot
.40779 .39013 Mdot
.75236 .4896 Mdot
.17575 .58098 Mdot
.78535 .49756 Mdot
.42303 .36944 Mdot
.54228 .77256 Mdot
.53955 .75136 Mdot
.66828 .25634 Mdot
.63706 .59325 Mdot
.80708 .39056 Mdot
.33754 .40506 Mdot
.39533 .75064 Mdot
.57469 .29866 Mdot
.35083 .42293 Mdot
.7856 .65176 Mdot
.26093 .52827 Mdot
.38632 .65133 Mdot
.69219 .38873 Mdot
.52807 .37257 Mdot
.57796 .33871 Mdot
.67502 .3945 Mdot
.68712 .37832 Mdot
.49315 .79852 Mdot
.31126 .34596 Mdot
.38908 .42711 Mdot
.76808 .53778 Mdot
.46568 .3039 Mdot
.23275 .30591 Mdot
.49793 .81033 Mdot
.2626 .53682 Mdot
.49466 .77028 Mdot
.41862 .31537 Mdot
.39779 .77255 Mdot
.7686 .35998 Mdot
.24339 .58345 Mdot
.53639 .77601 Mdot
.22757 .62897 Mdot
.28996 .69764 Mdot
.58777 .77258 Mdot
.69532 .22975 Mdot
.68328 .64233 Mdot
.30375 .70946 Mdot
.36151 .54712 Mdot
.78622 .38285 Mdot
.61688 .61768 Mdot
.52377 .61538 Mdot
.30698 .21971 Mdot
.67158 .5425 Mdot
.31995 .55419 Mdot
.61559 .60931 Mdot
.24377 .47369 Mdot
.41094 .21905 Mdot
.30068 .24771 Mdot
.6372 .4445 Mdot
.38495 .18254 Mdot
.2703 .67226 Mdot
.44185 .28662 Mdot
.61113 .54231 Mdot
.37906 .23355 Mdot
.44804 .83126 Mdot
.36114 .51443 Mdot
.35253 .40518 Mdot
.21732 .42359 Mdot
.55847 .80382 Mdot
.6755 .39791 Mdot
.44504 .28842 Mdot
.62412 .76825 Mdot
.53835 .74777 Mdot
.17438 .45774 Mdot
.33408 .39021 Mdot
.66498 .20942 Mdot
.68687 .2905 Mdot
.65829 .80165 Mdot
.70047 .39774 Mdot
.31898 .4931 Mdot
.17352 .57565 Mdot
.35167 .5231 Mdot
.71128 .29313 Mdot
.24517 .43122 Mdot
.56086 .74647 Mdot
.36604 .38024 Mdot
.71064 .30393 Mdot
.69405 .47812 Mdot
.70062 .30245 Mdot
.78714 .58342 Mdot
.67546 .28298 Mdot
.57796 .36005 Mdot
.60617 .77604 Mdot
.66671 .25396 Mdot
.5238 .81031 Mdot
.1758 .48041 Mdot
.60533 .29527 Mdot
.64051 .31621 Mdot
.43371 .34987 Mdot
.4496 .6627 Mdot
.75305 .3827 Mdot
.60083 .67501 Mdot
.73411 .74542 Mdot
.32004 .41049 Mdot
.55784 .27208 Mdot
.31908 .46835 Mdot
.2792 .34244 Mdot
.64415 .19607 Mdot
.35141 .3765 Mdot
.77871 .60986 Mdot
.43054 .29101 Mdot
.38541 .70228 Mdot
.22319 .39079 Mdot
.80295 .64735 Mdot
.31979 .44593 Mdot
.3661 .25958 Mdot
.2752 .58149 Mdot
.73292 .72235 Mdot
.66659 .48842 Mdot
.26436 .72972 Mdot
.7226 .44006 Mdot
.62409 .38427 Mdot
.46116 .78147 Mdot
.62723 .79894 Mdot
.34283 .35684 Mdot
.62881 .19446 Mdot
.52132 .30787 Mdot
.75013 .54915 Mdot
.2829 .32175 Mdot
.57485 .38662 Mdot
.66488 .38341 Mdot
.79076 .43082 Mdot
.47892 .18343 Mdot
.25595 .44359 Mdot
.18274 .54894 Mdot
.39628 .55973 Mdot
.48929 .16744 Mdot
.38078 .65298 Mdot
.36325 .68883 Mdot
.64907 .42322 Mdot
.21946 .43572 Mdot
.28894 .29968 Mdot
.64044 .32705 Mdot
.33998 .20156 Mdot
.30801 .31647 Mdot
.80233 .39172 Mdot
.7879 .47077 Mdot
.45182 .81923 Mdot
.34065 .57277 Mdot
.6926 .42728 Mdot
.30393 .68599 Mdot
.56052 .28446 Mdot
.37741 .23976 Mdot
.35548 .3562 Mdot
.41822 .69118 Mdot
.41072 .72857 Mdot
.26495 .72269 Mdot
.65627 .74659 Mdot
.66682 .30418 Mdot
.80681 .47617 Mdot
.40315 .34857 Mdot
.65765 .58932 Mdot
.60752 .41762 Mdot
.40379 .70389 Mdot
.39632 .82694 Mdot
.68629 .63462 Mdot
.57264 .67962 Mdot
.72262 .31531 Mdot
.20975 .37516 Mdot
.47634 .80987 Mdot
.19662 .42963 Mdot
.45061 .70107 Mdot
.38211 .68344 Mdot
.68623 .44031 Mdot
.34366 .74537 Mdot
.5005 .26762 Mdot
.62102 .79545 Mdot
.75986 .51133 Mdot
.69407 .2845 Mdot
.53461 .67103 Mdot
.5563 .69148 Mdot
.66419 .7851 Mdot
.32054 .67434 Mdot
.80809 .53648 Mdot
.54266 .72203 Mdot
.39798 .73646 Mdot
.54705 .60882 Mdot
.5392 .76462 Mdot
.55447 .30518 Mdot
.21845 .33261 Mdot
.16868 .42629 Mdot
.20997 .58023 Mdot
.61383 .53297 Mdot
.80449 .49605 Mdot
.40421 .23976 Mdot
.52758 .15953 Mdot
.37684 .649 Mdot
.25495 .71795 Mdot
.31525 .47325 Mdot
.24314 .44853 Mdot
.26214 .73616 Mdot
.47244 .7587 Mdot
.30079 .39698 Mdot
.73972 .31408 Mdot
.49321 .63914 Mdot
.80112 .51689 Mdot
.72744 .64227 Mdot
.69584 .62387 Mdot
.41186 .72671 Mdot
.55191 .38375 Mdot
.65533 .22653 Mdot
.28497 .74654 Mdot
.31898 .43053 Mdot
.20261 .44038 Mdot
.24574 .69013 Mdot
.36144 .20472 Mdot
.39192 .29963 Mdot
.79272 .32115 Mdot
.68314 .75901 Mdot
0 0 1 r
.90932 .39857 Mdot
.04954 .77049 Mdot
.73298 .9549 Mdot
.5144 .84403 Mdot
.60762 .0838 Mdot
.22215 .77566 Mdot
.27183 .86024 Mdot
.50039 .98042 Mdot
.37506 .15221 Mdot
.65252 .8304 Mdot
.98778 .97059 Mdot
.90974 .8657 Mdot
.48318 .13637 Mdot
.31192 .7917 Mdot
.0499 .92166 Mdot
.96685 .80013 Mdot
.5397 .93143 Mdot
.08885 .7215 Mdot
.95283 .0617 Mdot
.42652 .88129 Mdot
.95525 .0813 Mdot
.50698 .0254 Mdot
.48187 .93513 Mdot
.20486 .22389 Mdot
.16476 .29243 Mdot
.24419 .78409 Mdot
.6328 .13617 Mdot
.67016 .08428 Mdot
.1195 .72879 Mdot
.70511 .01278 Mdot
.23304 .06785 Mdot
.40767 .49911 Mdot
.022 .46402 Mdot
.25271 .21648 Mdot
.62764 .85549 Mdot
.14501 .54376 Mdot
.10123 .2454 Mdot
.46505 .46928 Mdot
.97193 .50681 Mdot
.5269 .40826 Mdot
.96154 .2945 Mdot
.51471 .93444 Mdot
.71863 .08782 Mdot
.10079 .22253 Mdot
.98976 .96732 Mdot
.14644 .26108 Mdot
.02764 .47032 Mdot
.84979 .38651 Mdot
.93905 .31399 Mdot
.84806 .10126 Mdot
.9867 .4476 Mdot
.84849 .12413 Mdot
.85006 .19632 Mdot
.83066 .64401 Mdot
.47337 .40155 Mdot
.20164 .9575 Mdot
.61378 .02484 Mdot
.52435 .57529 Mdot
.71764 .17966 Mdot
.67421 .94721 Mdot
.85934 .06533 Mdot
.81435 .76069 Mdot
.03848 .41152 Mdot
.3125 .85912 Mdot
.01937 .42797 Mdot
.11338 .41952 Mdot
.15023 .37244 Mdot
.12155 .95112 Mdot
.92865 .2899 Mdot
.21126 .92619 Mdot
.9624 .64778 Mdot
.74315 .16467 Mdot
.245 .05976 Mdot
.95555 .77833 Mdot
.85197 .36862 Mdot
.09501 .25936 Mdot
.96366 .29843 Mdot
.43263 .4937 Mdot
.71656 .13395 Mdot
.48137 .08399 Mdot
.85254 .19188 Mdot
.17053 .20265 Mdot
.19707 .89441 Mdot
.64591 .0524 Mdot
.4985 .13229 Mdot
.77213 .98853 Mdot
.30057 .91434 Mdot
.80947 .65937 Mdot
.05463 .47195 Mdot
.94713 .47729 Mdot
.87429 .27911 Mdot
.66712 .0148 Mdot
.03101 .95259 Mdot
.19833 .25241 Mdot
.27433 .20343 Mdot
.12563 .32993 Mdot
.45505 .53426 Mdot
.0808 .84817 Mdot
.49812 .06677 Mdot
.8212 .06178 Mdot
.79998 .09939 Mdot
.31135 .95157 Mdot
.01166 .67609 Mdot
.88516 .7073 Mdot
.28227 .93841 Mdot
.77435 .88144 Mdot
.51143 .94053 Mdot
.94335 .82946 Mdot
.02136 .73655 Mdot
.15317 .73988 Mdot
.15131 .07359 Mdot
.80525 .07769 Mdot
.04572 .68071 Mdot
.14151 .6331 Mdot
.33758 .16132 Mdot
.81635 .21099 Mdot
.40421 .90258 Mdot
.26085 .17251 Mdot
.11438 .67964 Mdot
.11934 .10873 Mdot
.26341 .92125 Mdot
.56385 .87471 Mdot
.91602 .76973 Mdot
.2163 .14267 Mdot
.10948 .56855 Mdot
.80229 .23028 Mdot
.29489 .11373 Mdot
.55125 .06757 Mdot
.44171 .94904 Mdot
.88118 .80271 Mdot
.62758 .87166 Mdot
.70176 .11173 Mdot
.95619 .42385 Mdot
.60208 .53338 Mdot
.16371 .20338 Mdot
.60266 .14561 Mdot
.13649 .01498 Mdot
.17075 .18677 Mdot
.2455 .20247 Mdot
.2521 .18883 Mdot
.89655 .21907 Mdot
.1322 .5616 Mdot
.97747 .25623 Mdot
.51974 .42579 Mdot
.85079 .25105 Mdot
.61509 .05839 Mdot
.9244 .50328 Mdot
.01678 .72759 Mdot
.11042 .51832 Mdot
.4058 .55927 Mdot
.79634 .83263 Mdot
.2834 .98787 Mdot
.94848 .34496 Mdot
.2356 .05046 Mdot
.38276 .93626 Mdot
.10916 .93858 Mdot
.93083 .05344 Mdot
.31892 .97069 Mdot
.97289 .42151 Mdot
.32744 .18263 Mdot
.2091 .81426 Mdot
.8538 .44756 Mdot
.06455 .29374 Mdot
.91316 .40393 Mdot
.75313 .88194 Mdot
.01584 .5109 Mdot
.26382 .87486 Mdot
.96175 .76747 Mdot
.907 .48353 Mdot
.47725 .04298 Mdot
.18098 .18008 Mdot
.03406 .84329 Mdot
.14512 .36102 Mdot
.83524 .18836 Mdot
.66407 .01809 Mdot
.38113 .10285 Mdot
.83402 .94251 Mdot
.58177 .42006 Mdot
.12023 .51296 Mdot
.05604 .62193 Mdot
.35837 .84107 Mdot
.90111 .27071 Mdot
.25284 .93306 Mdot
.83946 .65423 Mdot
.60923 .46811 Mdot
.59344 .92448 Mdot
.74961 .97216 Mdot
.64632 .94521 Mdot
.68918 .07217 Mdot
.76749 .94581 Mdot
.44614 .1293 Mdot
.91822 .30138 Mdot
.82711 .65139 Mdot
.94288 .33112 Mdot
.92617 .90632 Mdot
.3526 .98824 Mdot
.65361 .92587 Mdot
.86806 .34237 Mdot
.21728 .80637 Mdot
.94004 .05079 Mdot
.38037 .16478 Mdot
.77155 .86885 Mdot
.04989 .29857 Mdot
.11392 .38244 Mdot
.47607 .54949 Mdot
.45876 .09426 Mdot
.02559 .03701 Mdot
.9659 .72864 Mdot
.86178 .356 Mdot
.15833 .66699 Mdot
.33588 .06299 Mdot
.20089 .80875 Mdot
.49607 .60308 Mdot
.1851 .78155 Mdot
.05261 .82927 Mdot
.2094 .06272 Mdot
.26968 .93599 Mdot
.91518 .43518 Mdot
.924 .88281 Mdot
.10285 .90572 Mdot
.89216 .10678 Mdot
.70704 .04379 Mdot
.97634 .63632 Mdot
.26427 .13041 Mdot
.06215 .7437 Mdot
.17122 .21489 Mdot
.83943 .11644 Mdot
.26925 .11792 Mdot
.1422 .08245 Mdot
.46817 .86793 Mdot
.03512 .53998 Mdot
.22215 .29562 Mdot
.83606 .97439 Mdot
.5816 .85378 Mdot
.18366 .89598 Mdot
.20203 .7167 Mdot
.72406 .83896 Mdot
.51172 .55315 Mdot
.73717 .22372 Mdot
.28552 .89385 Mdot
.16537 .36013 Mdot
.11166 .98806 Mdot
.76743 .20852 Mdot
.57521 .48201 Mdot
.96628 .42296 Mdot
.84135 .63324 Mdot
.33943 .0899 Mdot
.64607 .01095 Mdot
.06372 .18624 Mdot
.94225 .18837 Mdot
.74532 .92957 Mdot
.18462 .97005 Mdot
.17069 .76851 Mdot
.59961 .49785 Mdot
.74846 .8548 Mdot
.79175 .1403 Mdot
.15549 .13915 Mdot
.90005 .54897 Mdot
.73917 .77065 Mdot
.62862 .93219 Mdot
.55437 .42511 Mdot
.87036 .0872 Mdot
.60713 .16526 Mdot
.10622 .69462 Mdot
.94215 .66712 Mdot
.0519 .12795 Mdot
.81689 .89308 Mdot
.73874 .91258 Mdot
.93673 .81569 Mdot
.97613 .62777 Mdot
.4852 .5228 Mdot
.09164 .33956 Mdot
.47667 .97021 Mdot
.98166 .45721 Mdot
.96856 .31709 Mdot
.55152 .51189 Mdot
.89745 .09536 Mdot
.17656 .82484 Mdot
.09473 .49507 Mdot
.74183 .0877 Mdot
.76601 .15405 Mdot
.41611 .9714 Mdot
.85479 .46931 Mdot
.59872 .05249 Mdot
.6031 .1494 Mdot
.85147 .07151 Mdot
.59729 .84995 Mdot
.82148 .7057 Mdot
.06049 .78221 Mdot
.1959 .3227 Mdot
.79357 .71812 Mdot
.88516 .53863 Mdot
.0435 .47693 Mdot
.8317 .40696 Mdot
.02002 .69146 Mdot
.51621 .9117 Mdot
.94016 .73037 Mdot
.82224 .91077 Mdot
.1564 .02206 Mdot
.92727 .38195 Mdot
.89357 .89522 Mdot
.8663 .34838 Mdot
.85608 .64712 Mdot
.81047 .27981 Mdot
.51383 .15593 Mdot
.56386 .41575 Mdot
.82356 .30959 Mdot
.95767 .65267 Mdot
.67072 .01194 Mdot
.45365 .50654 Mdot
.19036 .33094 Mdot
.87998 .10059 Mdot
.52244 .57051 Mdot
.79159 .20184 Mdot
.76306 .04892 Mdot
.96412 .71859 Mdot
.92969 .72953 Mdot
.48293 .44645 Mdot
.96221 .08667 Mdot
.51837 .57033 Mdot
.62184 .12318 Mdot
.10921 .54286 Mdot
.16586 .78246 Mdot
.45351 .02361 Mdot
.84116 .18579 Mdot
.48149 .92714 Mdot
.04857 .73167 Mdot
.95332 .36662 Mdot
.33454 .87727 Mdot
.31752 .08523 Mdot
.17848 .10462 Mdot
.01951 .7246 Mdot
.67581 .11197 Mdot
.82485 .91638 Mdot
.84068 .40072 Mdot
.78608 .19451 Mdot
.87756 .0439 Mdot
.55282 .15683 Mdot
.07125 .49098 Mdot
.38414 .06201 Mdot
.06154 .75658 Mdot
.426 .96236 Mdot
.53864 .92826 Mdot
.37622 .96729 Mdot
.97602 .78124 Mdot
.01283 .0381 Mdot
.87732 .07513 Mdot
.76189 .74518 Mdot
.22424 .80669 Mdot
.77607 .95413 Mdot
.89966 .33039 Mdot
.1842 .2349 Mdot
.18117 .20661 Mdot
.44483 .54139 Mdot
.1443 .84834 Mdot
.3726 .11297 Mdot
.58672 .14903 Mdot
.41233 .90433 Mdot
.06227 .6669 Mdot
.29317 .14117 Mdot
.78632 .17594 Mdot
.86011 .92314 Mdot
.04712 .5183 Mdot
.28903 .21463 Mdot
.42897 .91036 Mdot
.6925 .0754 Mdot
.28997 .16127 Mdot
.6678 .96591 Mdot
.05882 .44394 Mdot
.38444 .83454 Mdot
.51452 .9016 Mdot
.60106 .95021 Mdot
.4772 .3931 Mdot
.05804 .47293 Mdot
.32797 .82052 Mdot
.65036 .84481 Mdot
.29035 .09418 Mdot
.27573 .02008 Mdot
.03746 .80657 Mdot
.7514 .10867 Mdot
.4266 .84656 Mdot
.11456 .11098 Mdot
.23577 .24264 Mdot
.48523 .4214 Mdot
.898 .41232 Mdot
.15567 .88328 Mdot
.85552 .79891 Mdot
.9719 .54743 Mdot
.82786 .98254 Mdot
.41107 .14578 Mdot
.9365 .73299 Mdot
.30631 .0446 Mdot
.80273 .09763 Mdot
.5551 .53013 Mdot
.80009 .9116 Mdot
.57339 .97289 Mdot
.96242 .91926 Mdot
.44357 .14488 Mdot
.87372 .21317 Mdot
.95846 .49336 Mdot
.98623 .5643 Mdot
.40214 .16621 Mdot
.98575 .36506 Mdot
.18003 .03255 Mdot
.3093 .07387 Mdot
.72666 .87786 Mdot
.42578 .85089 Mdot
.94851 .4729 Mdot
.10716 .18746 Mdot
.98025 .96973 Mdot
.98421 .41524 Mdot
.94019 .3307 Mdot
.94463 .95584 Mdot
.64514 .89177 Mdot
.22916 .05068 Mdot
.1318 .85342 Mdot
.71007 .85612 Mdot
.81987 .05521 Mdot
.16074 .23172 Mdot
.86543 .08957 Mdot
.2301 .188 Mdot
.11938 .87685 Mdot
.01074 .14712 Mdot
.86914 .28389 Mdot
.10908 .89797 Mdot
.98167 .48866 Mdot
.27941 .85256 Mdot
.83074 .26674 Mdot
.07852 .64649 Mdot
.94934 .75984 Mdot
.5437 .1437 Mdot
.304 .1832 Mdot
.83235 .77931 Mdot
.20472 .27543 Mdot
.84088 .30045 Mdot
.91551 .41306 Mdot
.01994 .04351 Mdot
.93162 .38721 Mdot
.34706 .04567 Mdot
.97247 .61757 Mdot
.43857 .48367 Mdot
.86013 .40519 Mdot
.66521 .13957 Mdot
.22857 .09604 Mdot
.79418 .9732 Mdot
.8717 .06017 Mdot
.38313 .87195 Mdot
.83764 .0764 Mdot
.77691 .18719 Mdot
.18223 .92703 Mdot
.04098 .77347 Mdot
.21377 .1339 Mdot
.4916 .43006 Mdot
.33227 .08353 Mdot
.66989 .07443 Mdot
.29657 .19267 Mdot
.50985 .01529 Mdot
.17229 .3882 Mdot
.19291 .80915 Mdot
.94872 .2641 Mdot
.03142 .32426 Mdot
.02117 .57862 Mdot
.72505 .14139 Mdot
.24392 .05306 Mdot
.225 .13591 Mdot
.73651 .89409 Mdot
.47662 .06634 Mdot
.55341 .09475 Mdot
.8521 .69606 Mdot
.88204 .61187 Mdot
.83048 .3816 Mdot
.87068 .04305 Mdot
.11523 .25002 Mdot
.63656 .98018 Mdot
.88043 .12391 Mdot
.98764 .54525 Mdot
.15372 .22001 Mdot
.52083 .48871 Mdot
.59051 .13506 Mdot
.01253 .68647 Mdot
.12068 .08441 Mdot
.88832 .0574 Mdot
.2402 .05116 Mdot
.78289 .79758 Mdot
.59384 .06118 Mdot
.89265 .68347 Mdot
.59639 .50612 Mdot
.08537 .02721 Mdot
.16803 .34801 Mdot
.08265 .33093 Mdot
.42963 .909 Mdot
.95216 .25632 Mdot
.5315 .86141 Mdot
.72177 .21496 Mdot
.73881 .07363 Mdot
.13773 .16359 Mdot
.83635 .38035 Mdot
.09741 .89728 Mdot
.91958 .55908 Mdot
.42117 .06261 Mdot
.95845 .76907 Mdot
.68959 .83785 Mdot
.03993 .0462 Mdot
.36631 .85872 Mdot
.20082 .1068 Mdot
.85675 .22825 Mdot
.76985 .05399 Mdot
.88849 .44938 Mdot
.09006 .20634 Mdot
.5186 .51248 Mdot
.48847 .47608 Mdot
.98987 .97204 Mdot
.90452 .07976 Mdot
.63337 .12312 Mdot
.7135 .96315 Mdot
.76681 .88507 Mdot
.93384 .91897 Mdot
.86852 .4455 Mdot
.85358 .72243 Mdot
.20947 .70136 Mdot
.90431 .30172 Mdot
.84651 .73387 Mdot
.90463 .31988 Mdot
.93219 .66392 Mdot
.28107 .20657 Mdot
.62613 .85639 Mdot
.42147 .04956 Mdot
.42647 .16483 Mdot
.08649 .81999 Mdot
.51236 .8533 Mdot
.23017 .09592 Mdot
.59792 .54322 Mdot
.06948 .72144 Mdot
.81239 .04457 Mdot
.77482 .94944 Mdot
.19606 .17837 Mdot
.36315 .90969 Mdot
.75979 .02335 Mdot
.28647 .0995 Mdot
.25724 .16024 Mdot
.06611 .01338 Mdot
.70846 .85013 Mdot
.92384 .89089 Mdot
.32421 .06722 Mdot
.57049 .9714 Mdot
.55462 .05368 Mdot
.29383 .8817 Mdot
.30719 .88364 Mdot
.23752 .87813 Mdot
.32501 .02548 Mdot
.80474 .77988 Mdot
.9259 .67859 Mdot
.94336 .67323 Mdot
.71564 .7853 Mdot
.97083 .50872 Mdot
.51473 .05172 Mdot
.84109 .70336 Mdot
.36057 .97109 Mdot
.46007 .92144 Mdot
.80591 .98882 Mdot
.5254 .96457 Mdot
.02047 .92266 Mdot
.30919 .79241 Mdot
.93882 .81152 Mdot
.84354 .50525 Mdot
.52376 .51902 Mdot
.72741 .02148 Mdot
.9117 .02285 Mdot
.03959 .80995 Mdot
.02893 .87749 Mdot
.51341 .88393 Mdot
.85237 .93575 Mdot
.97985 .37472 Mdot
.95074 .89439 Mdot
.92095 .09425 Mdot
.90182 .20696 Mdot
.11726 .13727 Mdot
.20591 .74635 Mdot
.6044 .85901 Mdot
.8182 .12208 Mdot
.85766 .21788 Mdot
.02104 .16558 Mdot
.9269 .13343 Mdot
.03489 .91667 Mdot
.33428 .1956 Mdot
.81917 .18012 Mdot
.73043 .94226 Mdot
.13583 .09305 Mdot
.78977 .04918 Mdot
.85306 .90594 Mdot
.33089 .10844 Mdot
.82798 .97947 Mdot
.98681 .90304 Mdot
.01862 .80915 Mdot
.26619 .95098 Mdot
.52357 .44943 Mdot
.14016 .86773 Mdot
.85653 .20199 Mdot
.07657 .16261 Mdot
.58366 .86856 Mdot
.2137 .24687 Mdot
.26257 .76992 Mdot
.26596 .85707 Mdot
.98996 .89629 Mdot
.83372 .9794 Mdot
.85961 .03837 Mdot
.96739 .78722 Mdot
.90062 .63441 Mdot
.91965 .85014 Mdot
.66688 .09003 Mdot
.33062 .14955 Mdot
.95371 .70111 Mdot
.12979 .7119 Mdot
.1526 .91488 Mdot
.03824 .55018 Mdot
.10879 .69024 Mdot
.53564 .88312 Mdot
.21483 .74337 Mdot
.03117 .39667 Mdot
.25131 .05207 Mdot
.61041 .08942 Mdot
.13132 .33036 Mdot
.07866 .79113 Mdot
.96891 .40568 Mdot
.05022 .25075 Mdot
.73654 .12521 Mdot
.93163 .55071 Mdot
.2107 .23228 Mdot
.50933 .93089 Mdot
.98607 .4791 Mdot
.48797 .54402 Mdot
.86776 .4644 Mdot
.62304 .11628 Mdot
.89798 .5854 Mdot
.81706 .86201 Mdot
.31753 .92132 Mdot
.70122 .87402 Mdot
.94685 .44699 Mdot
.9422 .9129 Mdot
.1531 .25924 Mdot
.3848 .82691 Mdot
.77169 .05432 Mdot
.55794 .95509 Mdot
.08441 .68159 Mdot
.25022 .04357 Mdot
.09292 .02987 Mdot
.93077 .6378 Mdot
.14221 .63914 Mdot
.18395 .84669 Mdot
.71174 .98268 Mdot
.91771 .78421 Mdot
.28046 .0955 Mdot
.97714 .15622 Mdot
.60432 .47351 Mdot
.11078 .09561 Mdot
.91703 .23912 Mdot
.75037 .83209 Mdot
.16941 .7334 Mdot
.50728 .57336 Mdot
.21465 .18166 Mdot
.55633 .4318 Mdot
.9787 .16923 Mdot
.52852 .11668 Mdot
.25894 .90981 Mdot
.8738 .11593 Mdot
.66937 .14027 Mdot
.66895 .92447 Mdot
.08635 .49753 Mdot
.12243 .50248 Mdot
.09785 .33811 Mdot
.65728 .16629 Mdot
.57146 .01305 Mdot
.13857 .05941 Mdot
.55611 .59066 Mdot
.87625 .57 Mdot
.87694 .4602 Mdot
.80039 .95286 Mdot
.10448 .14306 Mdot
.4374 .96697 Mdot
.15068 .62131 Mdot
.30864 .91736 Mdot
.33564 .12084 Mdot
.88298 .06998 Mdot
.44562 .0453 Mdot
.09239 .10731 Mdot
.35095 .89244 Mdot
.90375 .91567 Mdot
.22937 .84183 Mdot
.60491 .9885 Mdot
.88393 .73079 Mdot
.07574 .74726 Mdot
.12401 .22022 Mdot
.41301 .08584 Mdot
.23122 .16005 Mdot
.95758 .05034 Mdot
.14863 .06254 Mdot
.61644 .14809 Mdot
.70289 .22262 Mdot
.10778 .22432 Mdot
.65529 .98757 Mdot
.04185 .46725 Mdot
.04501 .21239 Mdot
.40245 .98458 Mdot
.33231 .97997 Mdot
.84363 .26622 Mdot
.23434 .76545 Mdot
.19815 .26885 Mdot
.20229 .30801 Mdot
.57346 .90699 Mdot
.33741 .84518 Mdot
.91201 .56611 Mdot
.16637 .28081 Mdot
.87681 .36351 Mdot
.90068 .03001 Mdot
.13728 .30028 Mdot
.07487 .27926 Mdot
.57109 .15328 Mdot
.80717 .85704 Mdot
.20109 .08993 Mdot
.89669 .83684 Mdot
.86152 .48165 Mdot
.19417 .09529 Mdot
.73405 .19117 Mdot
.1291 .80622 Mdot
.18984 .79787 Mdot
.54784 .98049 Mdot
.81075 .24828 Mdot
.01338 .38143 Mdot
.60117 .45629 Mdot
.10689 .53478 Mdot
.72984 .96484 Mdot
.90292 .4493 Mdot
.98599 .78348 Mdot
.80596 .9758 Mdot
.26793 .98551 Mdot
.58122 .01285 Mdot
.46567 .4589 Mdot
.8547 .01241 Mdot
.48056 .09664 Mdot
.13466 .03777 Mdot
.13887 .24449 Mdot
.77442 .01408 Mdot
.06498 .26357 Mdot
.79141 .7499 Mdot
.22357 .13809 Mdot
.725 .79226 Mdot
.73321 .05125 Mdot
.47107 .52962 Mdot
.15777 .28053 Mdot
.01832 .63688 Mdot
.1026 .02677 Mdot
.2171 .87717 Mdot
.98372 .74889 Mdot
.17816 .64592 Mdot
.09494 .31335 Mdot
.69729 .12611 Mdot
.69419 .90391 Mdot
.47838 .38987 Mdot
.94342 .60652 Mdot
.18473 .1963 Mdot
.23434 .91392 Mdot
.01637 .54058 Mdot
.1492 .61038 Mdot
.28116 .04957 Mdot
.35022 .15337 Mdot
.1753 .94727 Mdot
.56196 .48486 Mdot
.42256 .86468 Mdot
.84964 .98241 Mdot
.96754 .17781 Mdot
.10928 .41352 Mdot
.22761 .73838 Mdot
.93664 .69861 Mdot
.4556 .51006 Mdot
.15994 .29982 Mdot
.13119 .14631 Mdot
.17542 .93067 Mdot
.27174 .15409 Mdot
.19807 .76266 Mdot
.17227 .73076 Mdot
.96066 .03409 Mdot
.36645 .08694 Mdot
.03382 .32567 Mdot
.90104 .56707 Mdot
.86407 .03566 Mdot
.62074 .02388 Mdot
.28569 .2207 Mdot
.49936 .86777 Mdot
.12008 .28022 Mdot
.23742 .72348 Mdot
.9122 .50776 Mdot
.07495 .98292 Mdot
.94174 .48347 Mdot
.6987 .90578 Mdot
.91773 .1676 Mdot
.06347 .14175 Mdot
.17692 .33444 Mdot
.76797 .91125 Mdot
.73569 .14288 Mdot
.66649 .81528 Mdot
.8566 .4918 Mdot
.86883 .47657 Mdot
.70172 .15193 Mdot
.04477 .4388 Mdot
.04377 .68526 Mdot
.59383 .95187 Mdot
.22864 .23081 Mdot
.83783 .01529 Mdot
.55235 .40573 Mdot
.97142 .51369 Mdot
.67372 .91936 Mdot
.17829 .16364 Mdot
.9622 .77724 Mdot
.14332 .71504 Mdot
.92823 .10179 Mdot
.75625 .91707 Mdot
.34421 .14011 Mdot
.13428 .27179 Mdot
.12537 .89949 Mdot
.56321 .50356 Mdot
.87969 .57439 Mdot
.13693 .58897 Mdot
.90769 .78735 Mdot
.98381 .86412 Mdot
.96965 .69537 Mdot
.23736 .93725 Mdot
.11288 .67527 Mdot
.94667 .16201 Mdot
.07679 .57781 Mdot
.39369 .087 Mdot
.1593 .78065 Mdot
.17984 .09509 Mdot
.17252 .26602 Mdot
.53478 .52022 Mdot
.06944 .58095 Mdot
.0249 .85465 Mdot
.2432 .17199 Mdot
.06842 .70245 Mdot
.98183 .13445 Mdot
.83233 .34399 Mdot
.91882 .21555 Mdot
.75611 .93972 Mdot
.13732 .72868 Mdot
.12222 .86422 Mdot
.06361 .17157 Mdot
.07198 .04693 Mdot
.49316 .08581 Mdot
.55774 .44424 Mdot
.72725 .13629 Mdot
.04058 .75791 Mdot
.31781 .83173 Mdot
.5677 .56133 Mdot
.81721 .85096 Mdot
.40522 .56922 Mdot
.96219 .92989 Mdot
.90225 .49321 Mdot
.41425 .49545 Mdot
.97422 .77989 Mdot
.15404 .59901 Mdot
.66622 .93836 Mdot
.57654 .04748 Mdot
.74953 .18672 Mdot
.44205 .12429 Mdot
.82393 .21022 Mdot
.83991 .42052 Mdot
.12281 .15854 Mdot
.53647 .12086 Mdot
.76167 .20396 Mdot
.77714 .92434 Mdot
.55149 .5586 Mdot
.31331 .85292 Mdot
.98098 .21197 Mdot
.08406 .19462 Mdot
.143 .01668 Mdot
.85447 .92421 Mdot
.81989 .15395 Mdot
.86368 .72204 Mdot
.14975 .27743 Mdot
.52921 .96195 Mdot
.56961 .91494 Mdot
.43641 .90807 Mdot
.4299 .86061 Mdot
.54613 .03225 Mdot
.30578 .83429 Mdot
.14794 .31762 Mdot
.83475 .71536 Mdot
.6693 .91589 Mdot
.41466 .84494 Mdot
.13451 .26176 Mdot
.85678 .62116 Mdot
.57475 .09873 Mdot
.07779 .78663 Mdot
.85253 .48143 Mdot
.92005 .47881 Mdot
.0951 .75365 Mdot
.89742 .85631 Mdot
.67064 .89891 Mdot
.18196 .02604 Mdot
.06298 .50263 Mdot
.11398 .2296 Mdot
.20065 .031 Mdot
.18412 .74099 Mdot
.09883 .97753 Mdot
.41838 .08843 Mdot
.2224 .16035 Mdot
.86265 .43167 Mdot
.58467 .559 Mdot
.53149 .06617 Mdot
.34064 .04498 Mdot
.412 .44485 Mdot
.7165 .796 Mdot
.01919 .43274 Mdot
.89479 .37889 Mdot
.78698 .28219 Mdot
.04194 .93742 Mdot
.21212 .71339 Mdot
.34333 .8913 Mdot
.03016 .4436 Mdot
.12557 .07451 Mdot
.80751 .12072 Mdot
.09343 .12729 Mdot
.92456 .7307 Mdot
.98665 .24955 Mdot
.59438 .11866 Mdot
.97089 .29282 Mdot
.63276 .89505 Mdot
.3764 .8899 Mdot
.94409 .39126 Mdot
.68159 .13695 Mdot
.02933 .65076 Mdot
.68514 .8776 Mdot
.42515 .5419 Mdot
.04183 .53895 Mdot
.07787 .35918 Mdot
.87246 .79396 Mdot
.50898 .57039 Mdot
.4489 .09091 Mdot
.7575 .94415 Mdot
.53556 .52837 Mdot
.08217 .07636 Mdot
.12021 .97667 Mdot
.05015 .5276 Mdot
.64108 .8837 Mdot
.75882 .09954 Mdot
.09871 .79802 Mdot
.31973 .01844 Mdot
.55242 .06448 Mdot
.98846 .10033 Mdot
.48005 .97832 Mdot
.87805 .11386 Mdot
.43971 .46052 Mdot
.61422 .98846 Mdot
.03981 .47728 Mdot
.98169 .57154 Mdot
.16767 .41396 Mdot
.98342 .48102 Mdot
.11518 .37696 Mdot
.2479 .95552 Mdot
.88347 .0103 Mdot
.44927 .39831 Mdot
.27905 .01204 Mdot
.41926 .91123 Mdot
.74394 .80199 Mdot
.75245 .24025 Mdot
.54131 .04823 Mdot
.75922 .74943 Mdot
.85369 .61258 Mdot
.17613 .25875 Mdot
.05769 .87553 Mdot
.97533 .3373 Mdot
.03729 .57726 Mdot
.79189 .81402 Mdot
.85135 .32831 Mdot
.1141 .98079 Mdot
.56298 .86674 Mdot
.06621 .11506 Mdot
.57785 .53924 Mdot
.36174 .95137 Mdot
.89694 .04363 Mdot
.78967 .75558 Mdot
.86946 .45656 Mdot
.98798 .93175 Mdot
.02791 .13805 Mdot
.90401 .14746 Mdot
.13424 .62073 Mdot
.8476 .0422 Mdot
.54659 .09129 Mdot
.19466 .13011 Mdot
.50346 .15542 Mdot
.70017 .9161 Mdot
.58965 .01776 Mdot
.73224 .96575 Mdot
.03895 .22369 Mdot
.83449 .10339 Mdot
.04344 .47109 Mdot
.06152 .31548 Mdot
.01841 .05161 Mdot
.41896 .04366 Mdot
.766 .0942 Mdot
.67692 .0681 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`1;ooooo`?o003oIoooool3o`00o`Co
oooo0ol00?laooooo`?o003o1_ooool3o`00oaoooooo0Ol00001ooooo`0000?o0000ooooooooool0
3_ooool3o`00oa7ooooo0ol00?lUooooo`Go003o?oooool3o`00o`kooooo1_l00?l?ooooo`Go003o
0_ooool5o`00o`Kooooo0ol00?l@ooooo`?o003o4?ooool8o`00o`Cooooo1Ol00?lNooooo`7o0000
0Oooool00003o`000?oooooooooo00gooooo1Ol00?l?ooooo`Ko003o8oooool5o`00o`Sooooo0ol0
0?lcooooo`Go003o3?ooool9o`00o`gooooo1Ol00?l00ooooooo003oo`00o`04o`00o`Gooooo1Ol0
0?l>ooooo`Go003o3_ooool9o`00o`Cooooo1Ol00?lNooooo`7o00000Oooool00003o`000?oooooo
oooo00gooooo1Ol00?l?ooooo`[o003o7oooool5o`00o`Oooooo1Ol00?lbooooo`Go003o3?ooool:
o`00o`cooooo3?l00?l5ooooo`Go003o0_ooool3o`00o`Wooooo1Ol00?l>ooooo`Wo003o1?ooool5
o`00o`Cooooo0ol00?lGooooo`7o00000Oooool00003o`000?oooooooooo00gooooo1Ol00?l?oooo
o`_o003o0oooool3o`00oaOooooo1Ol00?l8ooooo`Ko003o8Oooool3o`00o`gooooo1Ol00?l<oooo
o`[o003o0oooool5o`00o`Gooooo0ol00?l00ooooooo003oo`00o`04o`00o`Kooooo1Ol00?l00ooo
oooo003oo`00o`03o`00o`Gooooo2?l00?l>ooooo`So003o1_ooool3o`00o`Cooooo1Ol00?lFoooo
o`7o00000Oooool00003o`000?oooooooooo00kooooo0ol00?l3ooooo`?o003o0_ooool3o`00o`Ko
oooo2_l00?l2ooooo`Go003o5_ooool5o`00o`Sooooo1ol00?lOooooo`Go003o2oooool5o`00o`ko
oooo2Ol00?l2ooooo`Oo003o2?ooool5o`00o`Sooooo0ol00?l2ooooo`Go003o1?ooool8o`00oa3o
oooo0ol00?lAooooo`Go003o5_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`[o003o
1oooool8o`00o`;ooooo1Ol00?l2ooooo`?o003o4Oooool5o`00o`Wooooo1_l00?lOooooo`Go003o
2oooool5o`00o`Oooooo0ol00?l9ooooo`?o003o0oooool7o`00o`Wooooo0ol00?l>ooooo`Go003o
1?ooool5o`00obGooooo1ol00?lFooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo2_l0
0?l;ooooo`?o003o0oooool5o`00o`03ooooool00?oo003o00?o003o4Oooool3o`00o`_ooooo1Ol0
0?lOooooo`Go003o2oooool5o`00o`Kooooo1Ol00?l>ooooo`Oo003o6oooool3o`00o`Gooooo1Ol0
0?lJooooo`?o003o1oooool7o`00o`_ooooo0ol00?l9ooooo`7o00000Oooool00003o`000?oooooo
003o00;o003o00Coooooo`00ool00?oo003o3Oooool:o`00o`Gooooo0ol00?l9ooooo`Go003o00?o
ooooo`00ool00?l00ol00?lPooooo`?o003o8Oooool3o`00o`gooooo0ol00?l7ooooo`Go003o3ooo
ool5o`00obGooooo0ol00?lJooooo`Go003o1_ooool5o`00o`cooooo1Ol00?l8ooooo`7o00000Ooo
ool00003o`000?l00?oo003o00Oo003o3Oooool8o`00o`Gooooo1Ol00?l8ooooo`Go003o00?ooooo
o`00ool00?l00ol00?l:ooooo`?o003o;Oooool3o`00o`kooooo0ol00?l@ooooo`Go003o:_ooool3
o`00obGooooo2_l00?l5ooooo`Go003o3?ooool5o`00o`Sooooo0Ol00001ooooo`0000?o0000o`00
ool00?l02_l00?l6ooooo`?o003o0oooool3o`00o`Sooooo1Ol00?l9ooooo`?o003o0oooool3o`00
o`[ooooo1Ol00?l<ooooo`?o003o1oooool5o`00oa3ooooo1Ol00?l4ooooo`?o003o1Oooool5o`00
oa3ooooo0ol00?lZooooo`Go003o6_ooool3o`00o`Kooooo3Ol00?l2ooooo`Go003o3Oooool5o`00
o`Sooooo0Ol00001ooooo`0000?o0000o`00ool00?l02ol00?l4ooooo`Go003o3Oooool5o`00oaOo
oooo2_l00?l5ooooo`?o003o0oooool5o`00o`Gooooo1ol00?l?ooooo`Go003o0oooool5o`00o`Co
oooo1Ol00?l?ooooo`?o003o1oooool3o`00ob7ooooo1Ol00?l<ooooo`?o003o1Oooool3o`00o`;o
oooo1Ol00?l5ooooo`ko003o00?oooooo`00ool00?l00ol00?l=ooooo`Co003o2Oooool1o`00007o
oooo00000ol0003oooooo`00o`0;o`00o`Cooooo1Ol00?l>ooooo`?o003o5oooool;o`00o`Cooooo
1Ol00?l2ooooo`Go003o1Oooool7o`00o`oooooo1_l00?l2ooooo`Go003o1?ooool5o`00o`Oooooo
0ol00?l4ooooo`Oo003o0oooool5o`00o`;ooooo0ol00?l;ooooo`?o003o3Oooool5o`00o`Cooooo
0ol00?l4ooooo`Ko003o0_ooool5o`00o`03ooooool00?oo003o00?o003o1Oooool>o`00o`03oooo
ool00?oo003o00?o003o1Oooool6o`00o`03ooooool00?oo003o00?o003o2Oooool1o`00007ooooo
00000ol0003oooooooooo`05o`00o`03ooooool00?oo003o00?o003o1?ooool5o`00obSooooo2ol0
0?l4ooooo`Go003o0_ooool5o`00o`Gooooo1ol00?l@ooooo`Go003o0_ooool5o`00o`Gooooo0ol0
0?l7ooooo`Go003o0oooool8o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Wooooo1Ol0
0?l=ooooo`?o003o1?ooool5o`00o`?ooooo1ol00?l00ooooooo003oo`00o`03o`00o`03ooooool0
0?oo003o00Co003o1Oooool3o`00o`Cooooo2ol00?l5ooooo`go003o2Oooool1o`00007ooooo0000
0ol0003oooooooooo`05o`00o`;ooooo0ol00?l6ooooo`?o003o4?ooool3o`00oaKooooo2ol00?l4
ooooo`Go003o0oooool3o`00o`Oooooo1Ol00?lAooooo`Go003o0oooool3o`00oa3ooooo1Ol00?l3
ooooo`So003o0_ooool5o`00o`03ooooool00?oo003o00?o003o00Coooooo`00ool00?oo003o1Ooo
ool5o`00oaCooooo1Ol00?l3ooooo`go003o0_ooool6o`00o`_ooooo2Ol00?l7ooooo`go003o2Ooo
ool1o`00007ooooo00000ol0003oooooooooo`05o`00oagooooo1ol00?l>ooooo`?o003o0oooool:
o`00o`Gooooo0ol00?l=ooooo`?o003o2_ooool3o`00o`Sooooo0ol00?lGooooo`Go003o1?ooool7
o`00o`?ooooo0ol00?l00ooooooo003oo`00o`09o`00o`Cooooo1Ol00?lDooooo`Go003o1?ooool7
o`00o`04ooooool00?oo003oo`00o`Cooooo1Ol00?l:ooooo`[o003o1oooool<o`00o`[ooooo0Ol0
0001ooooo`0000Co0000oooooooooooooooo0ol00?lNooooo`So003o3?ooool5o`00o`?ooooo2?l0
0?lBooooo`So003o2?ooool5o`00o`Kooooo1Ol00?l<ooooo`?o003o0oooool3o`00o`;ooooo0ol0
0?l2ooooo`?o003o0_ooool5o`00o`Oooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Gooooo0ol0
0?l5ooooo`?o003o3_ooool3o`00o`Oooooo1Ol00?l8ooooo`Ko003o1oooool<o`00o`Sooooo2ol0
0?l:ooooo`7o00000Oooool00003o`000?oooooooooo02;ooooo2?l00?l<ooooo`Go003o0_ooool9
o`00oa7ooooo2Ol00?l8ooooo`Go003o1_ooool5o`00o`_ooooo1Ol00?l00ooooooo003oo`00o`03
o`00o`Gooooo2ol00?l7ooooo`Go003o00?oooooo`00ool00?l00ol00?l<ooooo`Go003o6?ooool3
o`00o`[ooooo1Ol00?l4ooooo`ko003o3oooool5o`00o`[ooooo0Ol00001ooooo`0000?o0000oooo
ooooool07oooool3o`00o`03ooooool00?oo003o00Go003o3?ooool5o`00o`;ooooo2?l00?l?oooo
o`co003o2?ooool5o`00o`Kooooo1Ol00?l;ooooo`Go003o00?oooooo`00ool00?l00ol00?l5oooo
o`_o003o2?ooool3o`00o`?ooooo0ol00?l<ooooo`Wo003o2oooool3o`00oaCooooo1Ol00?l3oooo
o`oo003o3oooool5o`00o`[ooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool3o`00o`So
oooo1Ol00?l3ooooo`Go003o3?ooool3o`00o`?ooooo1Ol00?lAooooo`co003o2_ooool3o`00o`So
oooo0ol00?l<ooooo`Go003o00?oooooo`00ool00?l00ol00?l5ooooo`[o003o7Oooool;o`00o`Wo
oooo1Ol00?l?ooooo`?o003o0_ooool3o`00o`;ooooo4Ol00?l@ooooo`?o003o2oooool1o`00007o
oooo00000ol0003oooooooooo`0Booooo`Go003o1oooool5o`00o`?ooooo1Ol00?lCooooo`?o003o
4_ooool8o`00obWooooo0ol00?l3ooooo`?o003o1oooool3o`00o`;ooooo0ol00?lNooooo`co003o
2?ooool5o`00o`kooooo1Ol00?l5ooooo`[o003o00?oooooo`00ool00?l01Ol00?l2ooooo`?o003o
2oooool3o`00o`_ooooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool5o`00o`Oooooo1Ol0
0?l00ooooooo003oo`00o`05o`00obSooooo1_l00?l2ooooo`?o003o9oooool3o`00ob;ooooo0ol0
0?l=ooooo`Go003o00?oooooo`00ool00?l01?l00?l8ooooo`Go003o3_ooool5o`00o`Gooooo1ol0
0?l4ooooo`Ko003o0_ooool5o`00o`Wooooo1Ol00?l:ooooo`7o00000Oooool00003o`000?oooooo
oooo01;ooooo1Ol00?l6ooooo`Go003o00?oooooo`00ool00?l01Ol00?lZooooo`_o003o1Oooool3
o`00o`Gooooo0ol00?l3ooooo`Co003o3_ooool8o`00oagooooo1Ol00?l<ooooo`Go003o0_ooool5
o`00o`?ooooo0ol00?l3ooooo`Co003o3_ooool5o`00o`Gooooo1Ol00?l5ooooo`Go003o1?ooool5
o`00o`Wooooo1_l00?l9ooooo`7o00000Oooool00003o`000?oooooooooo01?ooooo0ol00?l7oooo
o`Go003o00?oooooo`00ool00?l00ol00?l=ooooo`?o003o7Oooool;o`00o`?ooooo1Ol00?l3oooo
o`Go003o00?oooooo`00ool00?l01?l00?l5ooooo`?o003o1Oooool9o`00o`_ooooo0ol00?l>oooo
o`Go003o3?ooool5o`00o`?ooooo0ol00?l3ooooo`Go003o0_ooool5o`00o`kooooo0ol00?l7oooo
o`?o003o1?ooool6o`00o`Gooooo1Ol00?l9ooooo`Oo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`0Kooooo`go003o1oooool3o`00o`03ooooool00?oo003o00Co003o1?ooool3o`00o`co
oooo1_l00?l3ooooo`co003o0_ooool5o`00o`?ooooo1Ol00?l00ooooooo003oo`00o`04o`00o`Co
oooo1ol00?l2ooooo`Wo003o2_ooool6o`00o`cooooo1Ol00?l<ooooo`Go003o2Oooool5o`00o`;o
oooo1Ol00?l3ooooo`?o003o6?ooool7o`00o`Cooooo1Ol00?l01?oooooo003oo`00ool00?l7oooo
o`Ko003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0Jooooo`go003o1oooool;o`00o`?o
oooo1Ol00?l:ooooo`So003o0oooool3o`00o`;ooooo1_l00?l2ooooo`Go003o0oooool5o`00o`03
ooooool00?oo003o00Co003o1?ooool8o`00o`;ooooo2?l00?l:ooooo`Oo003o0_ooool3o`00o`Ko
oooo1Ol00?l<ooooo`Go003o2Oooool5o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`04o`00o`Ko
oooo0ol00?l>ooooo`Oo003o0oooool5o`00o`03ooooool00?oo003o00?o003o1oooool5o`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool06_ooool5o`00o`;ooooo1Ol00?l8ooooo`_o003o
0oooool5o`00o`[ooooo2?l00?l9ooooo`Go003o0oooool3o`00o`;ooooo1_l00?l3ooooo`Co003o
1Oooool8o`00o`03ooooool00?oo003o00Ko003o2oooool7o`00o`03ooooool00?oo003o00?o003o
1Oooool5o`00o`cooooo1Ol00?l:ooooo`?o003o1?ooool3o`00o`03ooooool00?oo003o00Go003o
1Oooool5o`00o`Wooooo0ol00?l00ooooooo003oo`00o`07o`00o`03ooooool00?oo003o00?o003o
00?oooooo`00ool00?l01?l00?l7ooooo`?o003o1Oooool3o`00o`7ooooo0Ol00001ooooo`0000?o
0000ooooooooool06_ooool5o`00o`;ooooo1Ol00?l8ooooo`[o003o1?ooool5o`00o`[ooooo2?l0
0?l:ooooo`?o003o2?ooool5o`00o`oooooo1ol00?l00ooooooo003oo`00o`03o`00o`oooooo1_l0
0?l00ooooooo003oo`00o`03o`00o`Kooooo0ol00?l>ooooo`?o003o5_ooool7o`00o`Gooooo1Ol0
0?l6ooooo`Oo003o00Goooooo`00ool00?oo003oooooo`0:o`00o`03ooooool00?oo003o00Go003o
3Oooool5o`00o`7o00000Oooool00003o`000?oooooooooo01Kooooo0ol00?l2ooooo`Ko003o00Co
ooooo`00ool00?oo003o2?ooool5o`00o`03ooooool00?oo003o00?o003o1Oooool3o`00o`cooooo
1_l00?l8ooooo`?o003o2oooool5o`00oa;ooooo0ol00?l2ooooo`Go003o4Oooool3o`00o`;ooooo
1Ol00?l_ooooo`Oo003o1_ooool5o`00o`Gooooo2?l00?l5ooooo`Wo003o0oooool6o`00o`gooooo
1Ol00?l1o`00007ooooo00000ol0003oooooooooo`0Eooooo`Go003o0_ooool6o`00o`_ooooo1Ol0
0?l2ooooo`Go003o5?ooool3o`00o`Wooooo1Ol00?l8ooooo`Oo003o6?ooool3o`00oaSooooo0ol0
0?lJooooo`?o003o1Oooool3o`00o`[ooooo1_l00?l9ooooo`?o003o1_ooool8o`00o`Gooooo2?l0
0?l5ooooo`Go003o3Oooool5o`00o`7o00000Oooool00003o`000?oooooooooo00kooooo0ol00?l4
ooooo`Go003o00?oooooo`00ool00?l01Ol00?l;ooooo`Go003o0_ooool5o`00oaOooooo0ol00?l6
ooooo`Go003o1oooool7o`00obOooooo0ol00?lHooooo`?o003o2oooool5o`00o`?ooooo1Ol00?l9
ooooo`Go003o4oooool7o`00o`Gooooo2Ol00?l6ooooo`?o003o3oooool3o`00o`7ooooo0Ol00001
ooooo`0000?o0000ooooooooool03Oooool5o`00o`?ooooo1Ol00?l00ooooooo003oo`00o`05o`00
o`cooooo0ol00?l3ooooo`Go003o4?ooool3o`00o`?ooooo1Ol00?l5ooooo`Go003o1oooool5o`00
obSooooo1Ol00?l?ooooo`?o003o1?ooool5o`00o`[ooooo1Ol00?l3ooooo`Go003o2Oooool5o`00
oaCooooo1Ol00?l5ooooo`[o003o7?ooool1o`00007ooooo00000ol0003oooooooooo`0=ooooo`Go
003o1?ooool3o`00o`;ooooo1_l00?lDooooo`?o003o4?ooool5o`00o`;ooooo1Ol00?l6ooooo`Go
003o1_ooool5o`00obSooooo1_l00?l=ooooo`Go003o0oooool7o`00o`Sooooo1Ol00?l3ooooo`Go
003o2_ooool3o`00o`gooooo1_l00?l2ooooo`Go003o1Oooool9o`00oagooooo0Ol00001ooooo`00
00?o0000ooooooooool03Oooool5o`00o`Cooooo0ol00?l3ooooo`?o003o:Oooool5o`00o`;ooooo
1Ol00?l7ooooo`Go003o1_ooool3o`00oa7ooooo0ol00?lEooooo`Oo003o3?ooool5o`00o`?ooooo
2?l00?l8ooooo`?o003o0oooool5o`00o`Oooooo0ol00?l@ooooo`So003o00?oooooo`00ool00?l0
1Ol00?l3ooooo`Oo003o7oooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`?o003o00Co
ooooo`00ool00?oo003o1?ooool5o`00oaWooooo0ol00?lAooooo`Ko003o0oooool3o`00o`Sooooo
1Ol00?lIooooo`Go003o5Oooool6o`00o`cooooo1Ol00?l3ooooo`So003o3Oooool5o`00o`Oooooo
1Ol00?l?ooooo`So003o0_ooool7o`00o`?ooooo1_l00?lOooooo`7o00000Oooool00003o`000?oo
oooooooo00Wooooo1Ol00?l7ooooo`Go003o6?ooool5o`00o`;ooooo0ol00?l:ooooo`Ko003o3ooo
ool5o`00oaWooooo1_l00?l;ooooo`?o003o1oooool5o`00o`gooooo0ol00?l4ooooo`So003o3Ooo
ool5o`00o`;ooooo0ol00?l2ooooo`Go003o3oooool8o`00o`Cooooo1Ol00?l4ooooo`Go003o2Ooo
ool3o`00o`gooooo0ol00?l3ooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo1Ol00?l7
ooooo`Go003o0oooool3o`00oa;ooooo1Ol00?l00ooooooo003oo`00o`05o`00o`Oooooo1Ol00?lA
ooooo`?o003o6_ooool6o`00o`Oooooo2?l00?l7ooooo`?o003o3Oooool3o`00o`Kooooo1_l00?l;
ooooo`So003o00?oooooo`00ool00?l02Ol00?l@ooooo`Ko003o1Oooool5o`00o`Gooooo0ol00?l9
ooooo`Go003o2oooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool3o`00
o`?ooooo1Ol00?l8ooooo`?o003o0oooool5o`00o`Oooooo0ol00?l7ooooo`Go003o00?oooooo`00
ool00?l01_l00?l6ooooo`Go003o1?ooool3o`00o`cooooo0ol00?lIooooo`Go003o1_ooool9o`00
oaKooooo1Ol00?l7ooooo`Go003o1Oooool<o`00o`;ooooo2_l00?l<ooooo`?o003o3_ooool3o`00
oa;ooooo1Ol00?l;ooooo`Go003o0_ooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`Go
003o0oooool3o`00o`04ooooool00?oo003oo`00o`Sooooo2?l00?l6ooooo`Go003o1oooool3o`00
o`;ooooo2?l00?l7ooooo`?o003o1?ooool5o`00o`[ooooo1Ol00?lIooooo`?o003o1oooool9o`00
o`Wooooo0ol00?l:ooooo`Go003o1oooool5o`00o`Cooooo2_l00?l5ooooo`Wo003o3?ooool5o`00
ob;ooooo1Ol00?l;ooooo`Go003o0_ooool1o`00007ooooo00001Ol0003o003oo`00ool00?oooooo
00Go003o1_ooool5o`00o`Kooooo3?l00?l3ooooo`Go003o3?ooool8o`00o`kooooo1Ol00?l:oooo
o`Go003o3oooool3o`00o`Kooooo1Ol00?l6ooooo`So003o2Oooool5o`00o`Wooooo1ol00?l01Ooo
oooo003oo`00ool00?oooooo00Go003o1?ooool:o`00o`Kooooo2Ol00?l;ooooo`Go003o7Oooool3
o`00o`?ooooo0ol00?l=ooooo`?o003o0oooool1o`00007ooooo000:o`00o`Kooooo1Ol00?l6oooo
o`go003o0_ooool5o`00o`cooooo1ol00?l?ooooo`Go003o1oooool8o`00o`kooooo1Ol00?l5oooo
o`Go003o1oooool3o`00o`gooooo1Ol00?l9ooooo`co003o00Coooooo`00ool00?oo003o1Oooool9
o`00o`Sooooo2?l00?l;ooooo`Go003o7?ooool5o`00oaSooooo0Ol00001ooooo`001Ol00?l01?oo
oooo003oo`00ool00?l7ooooo`Go003o1_ooool5o`00o`?ooooo1Ol00?l3ooooo`?o003o3Oooool6
o`00o`_ooooo0ol00?l3ooooo`?o003o1oooool:o`00o`Cooooo0ol00?l6ooooo`Go003o1Oooool5
o`00oaOooooo1Ol00?l4ooooo`?o003o00?oooooo`00ool00?l02ol00?l:ooooo`Co003o1oooool3
o`00o`?ooooo1ol00?l5ooooo`?o003o1?ooool3o`00o`Gooooo0ol00?lEooooo`Go003o6?ooool1
o`00007ooooo0005o`00o`cooooo0ol00?l8ooooo`?o003o0oooool6o`00oaCooooo0ol00?l<oooo
o`Go003o3?ooool5o`00o`03ooooool00?oo003o00?o003o0_ooool5o`00o`Gooooo1Ol00?l6oooo
o`?o003o3_ooool6o`00o`Gooooo1_l00?l00ooooooo003oo`00o`0@o`00oaCooooo1Ol00?l5oooo
o`?o003o1Oooool5o`00o`[ooooo1Ol00?lDooooo`Go003o4Oooool3o`00o`Cooooo0Ol00001oooo
o`0000Co0000o`00ool00?oo003o7Oooool6o`00oaOooooo1_l00?l4ooooo`So003o00Coooooo`00
ool00?oo003o2?ooool;o`00o`;ooooo1Ol00?l6ooooo`?o003o5oooool8o`00o`?oo`000ooooolF
o`00oaGooooo1Ol00?l=ooooo`Go003o2_ooool5o`00oaGooooo0ol00?l9ooooo`?o003o1Oooool5
o`00o`?ooooo0Ol00001ooooo`0000Co0000oooooooooooooooo0ol00?l=ooooo`?o003o2_ooool8
o`00o`Sooooo0ol00?l9ooooo`So003o0_ooool>o`00o`Sooooo2_l00?l2ooooo`Go003o2oooool3
o`00oa7ooooo00?oo`00o`00ool00?l01_l00?l4ool000;ooooo2_l00?l01Ooooooo003oo`00ool0
0?oooooo00Co003o6?ooool5o`00o`Oooooo0ol00?l3ooooo`Go003o2_ooool5o`00ob3ooooo1Ol0
0?l4ooooo`Go003o0oooool1o`00007ooooo00000ol0003oooooooooo`05o`00o`_ooooo1Ol00?l9
ooooo`Wo003o1_ooool5o`00o`Sooooo2?l00?l2ooooo`So003o00?oooooo`00ool00?l00ol00?l9
ooooo`So003o1?ooool5o`00o`?ooooo0ol00?l3ooooo`Go003o3_ooool3ool000So003o1?oo0000
0oooooooo`00o`00o`04o`00o`04ooooool00?oo003oo`00o`;ooooo0ooo00000ooooooo003oo`00
o`03o`00o`_ooooo0ol00?l:ooooo`?o003o1oooool5o`00o`?ooooo0ol00?l<ooooo`?o003o6Ooo
ool3o`00o`Gooooo1Ol00?l4ooooo`Go003o0oooool1o`00007ooooo00000ol0003oooooooooo`05
o`00o`Wooooo1ol00?l:ooooo`So003o1_ooool5o`00o`Sooooo3ol00?l4ooooo`Go003o2Oooool5
o`00o`Oooooo1Ol00?l2ooooo`Go003o0_ooool5o`00o`Gooooo0ooo0005ooooo`Goo`001_l00?l5
ool00003oooooooo003oo`0000?o003o00?oo`00ooooooooool00oooool5ool000Go003o2_ooool5
o`00oa?ooooo1Ol00?l]ooooo`Go003o1?ooool5o`00o`Cooooo1Ol00?l3ooooo`7o00000Oooool0
0003o`000?oooooooooo00Go003o2?ooool8o`00o`gooooo1Ol00?l6ooooo`Go003o2Oooool?o`00
o`Cooooo0ol00?l;ooooo`?o003o2?ooool5o`00o`;ooooo1Ol00?l2ooooo`Go003o1?ooool8ool0
0003oooooooo003oo`0000Goo`001Oooool3ool000;ooooo1_oo0005ooooo`Goo`001Ol00?l:oooo
o`Go003o4oooool5o`00o`Wooooo0ol00?lQooooo`Go003o1Oooool3o`00o`Gooooo1Ol00?l3oooo
o`7o00000Oooool00004o`000?ooooooooooooooo`?o003o2Oooool7o`00o`oooooo0ol00?l8oooo
o`?o003o0oooool3o`00o`Wooooo2_l00?lNooooo`?o003o0oooool5o`00o`;ooooo00Goo`00o`00
ool00?oo003oool00004ooooo`ooo`003?ooool5ool000Gooooo1Ooo00001?oooooo003oo`00ool0
0?l;ooooo`Go003o3Oooool3o`00o`Cooooo0ol00?l9ooooo`Go003o8?ooool5o`00o`_ooooo1ol0
0?l3ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo1Ol00?lMooooo`?o003o00?ooooo
o`00ool00?l00ol00?l01?oooooo003oo`00ool00?l4ooooo`[o003o2?ooool3o`00o`Cooooo0ol0
0?l>ooooo`?oo`000_ooool3o`00o`?ooooo1Ooo0004ooooo`goo`002oooool3ool00004oooooooo
003oo`00ool000Oooooo0ooo000Aooooo`?o003o3Oooool5o`00o`oooooo1Ol00?l5ooooo`?o003o
6Oooool3o`00o`_ooooo1ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00kooooo0ol0
0?lKoooooa7o003o1?ooool3o`00o`;ooooo0ol00?l8ooooo`Go003o0_ooool5o`00o`cooooo1Ooo
0008ooooo`?oo`000oooool?ool000Gooooo0ooo0002ooooo`Koo`004oooool3ool001Oooooo1Ol0
0?l5ooooo`?o003o1oooool5o`00o`Cooooo1Ol00?l3ooooo`?o003o8?ooool5o`00o`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool5o`00o`Sooooo0ol00?l>oooooaGo003o1?ooool3
o`00o`[ooooo1Ol00?l2ooooo`Go003o3?ooool5ool000gooooo4?oo00000oooooooo`00ool0000>
ool000Gooooo0ooo0009ooooo`Goo`005_ooool5o`00o`Cooooo1Ol00?l4ooooo`Ko003o1Oooool5
o`00o`03ooooool00?oo003o00Co003o6Oooool3o`00o`?ooooo1Ol00?l6ooooo`7o00000Oooool0
0003o`000?oooooooooo00gooooo1Ol00?l7ooooo`Go003o3Oooool8o`00o`05ooooool00?oo003o
o`00ooooool02Ol00?l2ooooo`Go003o2?ooool6o`00o`;ooooo1Ol00?l<ooooo`Goo`003Oooool8
ool00003oooooooo003oo`0001Koo`001?ooool5ool000Sooooo1ooo000Eooooo`?o003o0_ooool8
o`00o`?ooooo1Ol00?l7ooooo`ko003o5_ooool5o`00o`?ooooo0ol00?l7ooooo`7o00000Oooool0
0003o`000?oooooooooo00gooooo1Ol00?l01?oooooo003oo`00ool00?l3ooooo`Go003o3Oooool8
o`00o`Kooooo2?l00?l2ooooo`Go003o1oooool6o`00o`Cooooo1Ol00?l8ooooo`?oo`0000Cooooo
ool00?oo003oo`003_ooool5ool000Cooooo6?oo0004ooooo`Goo`002?ooool:ool001Kooooo2Ol0
0?l3ooooo`Oo003o1_ooool3o`00o`03ooooool00?oo003o00So003o5Oooool5o`00o`gooooo0Ol0
0001ooooo`0000?o0000ooooooooool03_ooool3o`00o`03ooooool00?oo003o00?o003o0_ooool5
o`00o`kooooo2?l00?l8ooooo`Go003o0_ooool5o`00o`Oooooo1Ol00?l6ooooo`Go003o1_ooool5
ool001;ooooo0ooo0002ooooo`?oo`0000?oooooool00?oo00005?oo0005ooooo`Goo`002Oooool:
ool001Gooooo2?l00?l4ooooo`So003o2Oooool:o`00oaGooooo1Ol00?l=ooooo`7o00000Oooool0
0003o`000?oooooooooo01;ooooo1Ol00?l3ooooo`?o003o3Oooool:o`00o`Wooooo0ol00?l2oooo
o`Go003o0oooool3o`00o`;ooooo1Ol00?l6ooooo`Go003o00?oo`00ooooooooool00oooool5ool0
013ooooo0ooo0002oooooa;oo`000oooool3ool000;ooooo0ooo0005ooooo`?oo`002oooool9ool0
01Gooooo1Ol00?l4ooooo`?o003o00?oooooo`00ool00?l01Ol00?l:ooooo`Wo003o5_ooool3o`00
o`kooooo0Ol00001ooooo`0000?o0000ooooooooool04_ooool6o`00oa7ooooo2ol00?l=ooooo`Go
003o0oooool6o`00o`04ooooool00?oo003oo`00o`Oooooo1Ol00?l2ool000;ooooo1ooo000?oooo
oa;oo`003Oooool5ool001;ooooo2Ooo000Fooooo`?o003o1?ooool5o`00o`;ooooo1_l00?l<oooo
o`Oo003o2Oooool3o`00oa[ooooo0Ol00001ooooo`0000?o0000ooooooooool04oooool6o`00oa3o
oooo2_l00?l>ooooo`Go003o0oooool7o`00o`_ooooo0ol00?l3ool00003oooooooo003oo`0000Go
o`0000Coooooool00?oo003oo`000oooool3ool000Kooooo4ooo0007ooooo`koo`003_ooool8ool0
0003oooooooo003oo`0000?oo`006?ooool5o`00o`?ooooo1Ol00?l3ooooo`Ko003o1?ooool6o`00
o`Sooooo1Ol00?lIooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo0ol00?l9ooooo`Go
003o4?ooool:o`00o`kooooo1Ol00?l3ooooo`So003o2Oooool7ool00003oooooooo003oo`0000[o
o`0000?oooooool00?oo00000ooo0005oooooaCoo`001Oooool@ool000_ooooo2?oo0002ooooo`Oo
o`005oooool6o`00o`;ooooo1Ol00?l2ooooo`So003o1?ooool5o`00o`04ooooool00?oo003oo`00
o`Cooooo1Ol00?lCooooo`?o003o0oooool1o`00007ooooo00000ol0003oooooooooo`07ooooo`Go
003o2?ooool5o`00oa7ooooo2Ol00?l?ooooo`Go003o0oooool8o`00o`Sooooo1_oo0002ooooo`co
o`0000?oooooool00?oo00000ooo0002ooooo`?oo`0000?oooooool00?oo00004Ooo0005oooooa3o
o`002_ooool9ool000;ooooo1ooo000<ooooo`?o003o2Oooool5o`00o`?ooooo0ol00?l3ooooo`So
003o1Oooool3o`00o`03ooooool00?oo003o00?o003o0oooool5o`00o`04ooooool00?oo003oo`00
o`kooooo1Ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo1Ol00?l9ooooo`?o
003o1oooool3o`00o`Gooooo0ol00?l00ooooooo003oo`00o`05o`00oa7ooooo1Ol00?l4ooooo`Ko
003o00Coooooool00?oo003oo`001?ooool5ool000Cooooo1Ooo00000oooooooo`00ool00003ool0
0003oooooooo003oo`0000?oo`0000?oooooool00?oo00000ooo0004ooooo`Koo`0000?oooooool0
0?oo00001_oo0005ooooo`Ooo`0000?oooooool00?oo00001_oo000:ooooo`Woo`0000?oooooool0
0?oo00001_oo000;ooooo`Go003o2?ooool5o`00o`Wooooo2?l00?l4ooooo`[o003o0_ooool5o`00
o`03ooooool00?oo003o00?o003o3Oooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000oooooooo
ool01_ooool6o`00o`cooooo1Ol00?l00ooooooo003oo`00o`03o`00o`?ooooo2_l00?l6ooooo`?o
003o2_ooool5o`00o`Cooooo1_l00?l5ool000Cooooo0ooo0006ooooo`[oo`000_ooool:ool000Ko
oooo0ooo0002ooooo`Soo`001_ooool5ool000Kooooo0ooo000:ooooo`Woo`0000?oooooool00?oo
00001_oo0008ooooo`?o003o00?oooooo`00ool00?l00ol00?l01?oooooo003oo`00ool00?l5oooo
o`?o003o2oooool6o`00o`Gooooo2_l00?l00ooooooo003oo`00o`03o`00o`;ooooo1Ol00?l=oooo
o`Go003o0_ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`Ko003o3?ooool<o`00o`?o
oooo2_l00?l5ooooo`Go003o2Oooool5o`00o`Cooooo1Ol00?l00oooooooo`00ool00003ool000?o
oooo1Ooo0005ooooo`[oo`000_ooool:ool000Oooooo0ooo0002ooooo`Ooo`007Oooool6ool000Go
oooo1Ooo000:ooooo`oo003o7Oooool5o`00o`04ooooool00?oo003oo`00o`;ooooo1Ol00?l2oooo
o`Go003o3_ooool3o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool5o`00o`go
oooo3?l00?l3ooooo`Wo003o1_ooool5o`00o`?ooooo0ol00?l4ooooo`?o003o1Oooool5o`00o`03
oooooooo003oo`0000?oo`000oooool5ool000Gooooo2_oo0002ooooo`Goo`0000Coooooool00?oo
003oo`001oooool5ool000Cooooo0ooo000Nooooo`Goo`001_ooool6ool00004oooooooo003oo`00
ool000Cooooo00?oo`00o`00ool00?l00ol00?l01Ooooooo003oo`00ool00?oooooo00Go003o3_oo
ool3o`00o`cooooo1Ol00?l6ooooo`Go003o0oooool3o`00oaGooooo0Ol00001ooooo`0000?o0000
ooooooooool01Oooool5o`00o`gooooo2ol00?l5ooooo`Ko003o0oooool3o`00o`;ooooo1_l00?l0
0ooooooo003oo`00o`03o`00o`cooooo0ol00?l3ooooo`?oo`001?ooool5ool000Kooooo2?oo0002
ooooo`Goo`003?ooool5ool000cooooo0ooo0006ooooo`?oo`000oooool3ool000Cooooo2?oo0007
ooooo`[oo`000_ooool2ool000Go003o1Oooool5o`00o`gooooo1Ol00?l;ooooo`Go003o1oooool3
o`00oacooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool3o`00o`oooooo2?l00?l8oooo
o`Go003o0_ooool5o`00o`;ooooo2ol00?lIooooo`Goo`002?ooool<ool000gooooo1Ooo000;oooo
o`Goo`001?ooool5ool00003oooooooo003oo`0000?oo`000_ooool8ool000Sooooo2_oo0002oooo
o`?oo`000ol00?l7ooooo`?o003o3_ooool5o`00o`_ooooo1Ol00?lVooooo`7o00000Oooool00003
o`000?oooooooooo01_ooooo1Ol00?l8ooooo`Go003o0_ooool5o`00o`?ooooo2_l00?lIooooo`Go
o`000oooool3ool000;ooooo3?oo0008ooooo`?oo`000oooool3ool000Sooooo0ooo00000ooooooo
o`00ool00003ool000Cooooo1Ooo00000oooooooo`00ool00003ool000;ooooo1Ooo000;ooooo`[o
o`000_ooool5ool000cooooo0ol00?l:ooooo`Go003o3?ooool3o`00o`kooooo0ol00?lFooooo`7o
00000Oooool00003o`000?oooooooooo01Sooooo0ol00?l01?oooooo003oo`00ool00?l4ooooo`?o
003o0oooool3o`00o`?ooooo1Ol00?l3ooooo`Go003o00?oooooo`00ool00?l00ol00?lHooooo`Go
o`000_ooool5ool00003oooooooo003oo`0000[oo`001oooool5ool000cooooo3?oo0002ooooo`Go
o`0000?oooooool00?oo00000ooo0002ooooo`Goo`002oooool5ool00004oooooooo003oo`00ool0
00Cooooo0ooo000<ooooo`Go003o2_ooool3o`00oagooooo1Ol00?lEooooo`7o00000Oooool00003
o`000?oooooooooo01Oooooo1Ol00?l6ooooo`Go003o2Oooool3o`00o`Gooooo1?l00?l2ooooo`Go
003o2?ooool3ool000Cooooo0ooo0006ooooo`?oo`000oooool5ool00003oooooooo003oo`0000Co
o`0000?oooooool00?oo00000ooo0007ooooo`Goo`003?ooool5ool00003oooooooo003oo`0000Go
o`000_ooool3ool000?ooooo0ooo0004ooooo`?oo`003?ooool8ool000[ooooo0ooo0002ooooo`?o
o`000_ooool5o`00o`gooooo0ol00?lJooooo`Go003o4?ooool3o`00o`;ooooo0Ol00001ooooo`00
00?o0000ooooooooool02_ooool3o`00o`[ooooo2?l00?l3ooooo`Go003o3Oooool3o`00o`03oooo
ool00?oo003o00?o003o00?oooooo`00ool00?l00ol00?l4ooooo`Soo`000_ooool5ool000_ooooo
1Ooo00000oooooooo`00ool00003ool000;ooooo2?oo0004ooooo`Goo`003?ooool=ool001cooooo
2ooo0008ooooo`[oo`0000?oooooo`00ool00?l00ol00?l<ooooo`Go003o1oooool3o`00o`oooooo
1Ol00?l?ooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`Go003o2Ooo
ool9o`00o`;ooooo1Ol00?l<ooooo`[o003o00?oooooo`00ool00?l00ol00?l3ooooo`Woo`000_oo
ool5ool000[ooooo1Ooo0003ooooo`?oo`001?ooool8ool000Cooooo0ooo000>ooooo`coo`005Ooo
ool3ool000?ooooo3?oo0005ooooo`goo`000_ooool3o`00o`gooooo1Ol00?l6ooooo`Go003o3ooo
ool3o`00o`Oooooo0ol00?l5ooooo`Ko003o0Oooool1o`00007ooooo00000ol0003oooooooooo`09
ooooo`Go003o2Oooool9o`00o`?ooooo0ol00?l01?oooooo003oo`00ool00?l4ooooo`?o003o0_oo
ool:o`00o`;ooooo0ol00?l4ooooo`Woo`000_ooool5ool000[ooooo1ooo000;ooooo`Goo`006?oo
ool8ool00004oooooooo003oo`00ool0017ooooo1Ooo0002ooooo`Goo`0000?oooooool00?oo0000
1ooo00000oooooooo`00ool0000<ool001;ooooo1Ol00?l6ooooo`Go003o6?ooool5o`00o`?ooooo
1ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo1Ol00?l8ooooo`[o003o0_oo
ool9o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`04ooooool00?oo003oo`00o`[ooooo
2?oo0003ooooo`Goo`001_ooool3ool00003oooooooo003oo`0000Koo`000_ooool3ool000Gooooo
1Ooo0004ooooo`?oo`004Oooool5ool000?ooooo1Ooo000@ooooo`Koo`0000?oooooool00?oo0000
0ooo00000oooooooo`00ool0000@ool000;ooooo0ooo000Dooooo`?o003o1oooool5o`00oaSooooo
1Ol00?l3ooooo`Ko003o0_ooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`?o003o00Co
ooooo`00ool00?oo003o1Oooool5o`00o`04ooooool00?oo003oo`00o`;ooooo2_l00?l2ooooo`Go
003o0_ooool3o`00o`oooooo1Ooo0006ooooo`Goo`001Oooool5ool00003oooooooo003oo`0000Go
o`0000?oooooool00?oo00000ooo0004ooooo`Goo`000oooool5ool00004oooooooo003oo`00ool0
00Gooooo0ooo0005ooooo`?oo`001?ooool5ool0013ooooo1_oo0002ooooo`?oo`000_ooool?ool0
02;ooooo2?l00?lIooooo`Go003o0oooool5o`00o`?ooooo0Ol00001ooooo`0000?o0000oooooooo
ool03Oooool5o`00o`Cooooo1Ol00?l6ooooo`[o003o00?oooooo`00ool00?l01?l00?l2ooooo`?o
003o3?ooool9ool000Gooooo1Ooo0003ooooo`Ooo`000oooool5ool00003oooooooo003oo`0000?o
o`001Oooool3ool000Cooooo2_oo0003ooooo`Ooo`002?ooool6ool0017ooooo1Ooo0008ooooo`Wo
o`0000Coooooool00?oo003oo`008_ooool8o`00oaWooooo1Ol00?l5ooooo`?o003o1?ooool1o`00
007ooooo00000ol0003oooooooooo`0=ooooo`Go003o1Oooool3o`00o`Oooooo2Ol00?l2ooooo`Go
003o0_ooool5o`00o`[ooooo2ooo0005ooooo`?oo`000oooool8ool000Cooooo0ooo0002ooooo`Go
o`003?ooool:ool000;ooooo2Ooo0006ooooo`Woo`004?ooool3ool000_ooooo1_oo000Wooooo`So
003o3Oooool3o`00o`Wooooo1Ol00?l<ooooo`7o00000Oooool00003o`000?oooooooooo00gooooo
1Ol00?l?ooooo`So003o0oooool5o`00o`;ooooo1_l00?l9ooooo`_oo`002oooool8ool000Gooooo
1?oo00001?ooooooo`00ool00?oo000>ooooo`?oo`0000?oooooool00?oo00000ooo00000ooooooo
o`00ool00008ool000Kooooo2_oo000Mooooo`Goo`000oooool3ool002;ooooo2?l00?l<ooooo`Go
003o2?ooool5o`00o`cooooo0Ol00001ooooo`0000?o0000ooooooooool03_ooool6o`00o`[ooooo
4_l00?l3ooooo`Oo003o2?ooool;ool000_ooooo2?oo0004ooooo`Koo`005_oooolAool000Cooooo
2_oo0009ooooo`?oo`004_ooool5ool00003oooooooo003oo`0000?oo`007?ooool3o`00o`?ooooo
1_l00?l6ooooo`?o003o1?ooool5o`00o`Wooooo0ol00?l=ooooo`7o00000Oooool00003o`000?oo
oooooooo013ooooo1Ol00?l8oooooa;o003o1Oooool6o`00o`Wooooo2Ooo000=ooooo`Ooo`001?oo
ool6ool001Kooooo4_oo0004ooooo`Woo`002?ooool5ool00004oooooooo003oo`00ool000gooooo
1Ooo00000oooooooo`00ool00003ool001Gooooo0ol00?l3ooooo`Go003o3Oooool5o`00o`?ooooo
1Ol00?lIooooo`7o00000Oooool00003o`000?oooooooooo013ooooo1Ol00?l8oooooa;o003o1_oo
ool5o`00o`_ooooo1ooo000<ooooo`Ooo`001Oooool6ool0013ooooo1Ooo00000oooooooo`00ool0
000@ool000Cooooo2Ooo0008ooooo`_oo`002_ooool<ool000Oooooo0ooo000:ooooo`Go003o0_oo
ool5o`00o`cooooo1_l00?l4ooooo`?o003o6_ooool1o`00007ooooo00000ol0003oooooooooo`0@
ooooo`Go003o2?ooool5o`00o`Cooooo2Ol00?l7ooooo`?o003o3?ooool6ool000gooooo1Ooo0008
ooooo`Coo`003_oooolDool000;ooooo1Ooo0005ooooo`Woo`001oooool<ool000Wooooo2ooo0005
ooooo`Ooo`002Oooool5o`00o`;ooooo1Ol00?l<ooooo`Ko003o3?ooool3o`00oa;ooooo0Ol00001
ooooo`0000?o0000ooooooooool03_ooool6o`00o`[ooooo0ol00?l8ooooo`Go003o5oooool6ool0
00gooooo1Ooo00001?ooooooo`00ool00?oo0004ooooo`?oo`003_ooool:ool00003oooooooo003o
o`0000Soo`000oooool3ool000Oooooo2?oo0008ooooo`?oo`0000?oooooool00?oo00001Ooo0009
ooooo`[oo`0000Goooooool00?oo003oo`00ooooo`08ool000Gooooo0ooo00000ooooooo003oo`00
o`03o`00o`?ooooo0ol00?l=ooooo`Go003o3?ooool5o`00o`Gooooo1_l00?l6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00gooooo1Ol00?lHooooo`Go003o3?ooool3o`00o`Oooooo1_oo000>
ooooo`?oo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00004ool000cooooo2ooo0006
ooooo`Goo`001_ooool3ool000Cooooo2?oo0009ooooo`?oo`0000?oooooool00?oo00001?oo000:
oooooaKoo`000oooool6ool00004ooooool00?oo003oo`00oaGooooo0ol00?l=ooooo`Go003o1?oo
ool8o`00o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool8o`00oa7ooooo0ol00?l3
ooooo`Ko003o2oooool5o`00o`Oooooo1?oo0004ooooo`?oo`003?ooool>ool00004oooooooo003o
o`00ool000Kooooo2_oo0007ooooo`Goo`001Oooool5ool000?ooooo1ooo00001?ooooooo`00ool0
0?oo0005ooooo`Goo`000_ooool3ool000[ooooo2Ooo00000oooooooo`00ool0000:ool000?ooooo
1ooo000@ooooo`?o003o4?ooool3o`00o`03ooooool00?oo003o00Go003o1?ooool8o`00o`Gooooo
0Ol00001ooooo`0000?o0000ooooooooool02Oooool9o`00oa3ooooo1Ol00?l00ooooooo003oo`00
o`05o`00o`_ooooo1Ol00?l>ooooo`Goo`002_oooolDool000Gooooo1Ooo00001?ooooooo`00ool0
0?oo0003ooooo`?oo`000_ooool5ool000Gooooo1Ooo0004ooooo`_oo`001?ooool5ool000kooooo
2?oo00000oooooooo`00ool00005ool00004oooooooo003oo`00ool000Kooooo1ooo000?ooooo`Go
003o3_ooool;o`00o`Gooooo2?l00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00Wooooo
2?l00?lAooooo`Go003o00?oooooo`00ool00?l01?l00?l7ooooo`?o003o0_ooool5o`00o`;oo`00
1oooool3ool000;ooooo1Ooo0009ooooo`Koo`0000?oooooool00?oo00003?oo0006ooooo`?oo`00
1oooool5ool000;ooooo0ooo0006oooooaKoo`000_ooool5ool000gooooo1_oo0003ooooo`goo`00
1Oooool6ool0013ooooo1Ol00?l>ooooo`Wo003o2?ooool6o`00o`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool02Oooool5o`00oaCooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Oooooo1Ol0
0?l2ooooo`?o003o1?oo00001Oooooooo`00ool00?oo003ooooo00Goo`0000?oooooool00?oo0000
0ooo0009ooooo`Goo`0000?oooooool00?oo00000ooo00000oooooooo`00ool00007ool0013ooooo
1Ooo000;oooooaOoo`000_ooool3ool000kooooo1_oo0003ooooo`goo`001_ooool3ool000kooooo
0ol00?l00ooooooo003oo`00o`03o`00o`kooooo2Ol00?l8ooooo`Go003o1oooool1o`00007ooooo
00000ol0003oooooooooo`0:ooooo`Ko003o1oooool3o`00o`Wooooo0ol00?l3ooooo`?o003o2?oo
ool5o`00o`?ooooo5Ooo000:ooooo`Goo`0000?oooooool00?oo00000ooo0002ooooo`?oo`0000Co
ooooool00?oo003oo`001?ooool3ool000[ooooo1Ooo000;ooooo`ooo`0000?oooooool00?oo0000
1Ooo000Cooooo`Goo`001?ooool?ool001Cooooo1Ol00?l01?oooooo003oo`00ool00?l@ooooo`?o
003o00Coooooo`00ool00?oo003o0oooool3o`00o`Cooooo0ol00?l8ooooo`7o00000Oooool00003
o`000?oooooooooo00cooooo1Ol00?l5ooooo`Go003o2oooool3o`00o`_ooooo1Ol00?l3oooooa?o
o`001Oooool4ool000?ooooo1Ooo00000oooooooo`00ool00003ool000cooooo1Ooo000:ooooo`?o
o`003?ooool=ool000Gooooo1Ooo000<ooooo`?oo`001Oooool3ool000Kooooo3ooo000Cooooo`Go
003o7Oooool5o`00o`Cooooo0ol00?l7ooooo`7o00000Oooool00003o`000?oooooooooo00cooooo
1Ol00?l5ooooo`Go003o2_ooool5o`00o`Wooooo1Ol00?l4ooooo`Goo`0000?oooooool00?oo0000
0ooo00000oooooooo`00ool00005ool000?ooooo1ooo0002ooooo`Goo`000_ooool3ool000gooooo
1Ooo00001?ooooooo`00ool00?oo000Dooooo`Goo`0000?oooooool00?oo00001?oo0008ooooo`?o
o`003?ooool5ool000gooooo1Ooo00000oooooooo`00ool00007ool000cooooo0ooo0004ooooo`Go
003o5?ooool3o`00o`Kooooo1Ol00?l3ooooo`Go003o1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`04ooooo`Co003o1?ooool5o`00o`Gooooo1Ol00?l:ooooo`Go003o2?ooool5o`00o`Kooooo
1Ooo00001?ooooooo`00ool00?oo0004ooooo`ooo`000oooool3ool001?ooooo2_oo000?ooooo`So
o`003Oooool3ool000oooooo1Ooo000=ooooo`Goo`0000?oooooool00?oo00001ooo000;ooooo`Go
o`001?ooool3o`00oaCooooo1Ol00?l5ooooo`Go003o0oooool5o`00o`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool6o`00o`Cooooo0ol00?l7ooooo`?o003o2oooool5o`00o`Sooooo
1Ol00?l3ooooo`Soo`000_ooool3ool000Cooooo3_oo000=ooooo`?oo`000_ooool3ool000?ooooo
1Ooo00000oooooooo`00ool00003ool000kooooo2Ooo0004ooooo`?oo`001Oooool5ool000kooooo
1Ooo0006ooooo`?oo`001Oooool3ool000?ooooo1ooo000<ooooo`Goo`003?ooool3o`00o`cooooo
1Ol00?l6ooooo`?o003o1?ooool5o`00o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ool6o`00o`[ooooo0ol00?l9ooooo`Go003o0_ooool3o`00o`Wooooo1Ol00?l2ooooo`Woo`0000?o
ooooool00?oo00000ooo0003ooooo`goo`003Oooool:ool000;ooooo1Ooo00000oooooooo`00ool0
0003ool000_ooooo3?oo0003ooooo`Goo`001?ooool5ool000kooooo1Ooo0005ooooo`Soo`002Ooo
ool5ool000Cooooo1_oo0002ooooo`Goo`002oooool5o`00o`[ooooo1_l00?l6ooooo`Co003o1?oo
ool3o`00o`Oooooo0Ol00001ooooo`0000?o0000ooooooooool00oooool6o`00o`Wooooo1Ol00?l7
ooooo`Oo003o2Oooool8o`00o`?ooooo2?oo0002ooooo`Goo`000oooool;ool000Gooooo0ooo0007
ooooo`[oo`000_ooool:ool000_ooooo3?oo0004ooooo`Goo`001?ooool5ool000kooooo1Ooo0003
ooooo`_oo`002Oooool3ool000Cooooo2?oo0002ooooo`?oo`003?ooool5o`00o`Wooooo1_l00?l6
ooooo`Ko003o3Oooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`Co003o2_ooool8o`00
o`Cooooo1ol00?l8ooooo`Wo003o0oooool8ool000;ooooo1Ooo0002ooooo`_oo`001Oooool5ool0
00?ooooo3Ooo0003ooooo`Ooo`003Oooool8ool000Sooooo1Ooo0005ooooo`Coo`002Oooool3ool0
00;ooooo1Ooo0002ooooo`coo`001Oooool6ool000Gooooo2?oo000Aooooo`Go003o2Oooool5o`00
o`Oooooo1_l00?l5ooooo`?o003o1Oooool1o`00007ooooo00000ol0003oooooooooo`0Booooo`Wo
003o0oooool7o`00o`Sooooo2Ol00?l2ooooo`Soo`000oooool5ool000;ooooo1ooo0009ooooo`Go
o`000_ooool8ool00003oooooooo003oo`0000?oo`001Oooool5ool000[ooooo2?oo0006ooooo`?o
o`000_ooool4ool000Kooooo1Ooo0007ooooo`Goo`000_ooool3ool000?ooooo3?oo0004ooooo`So
o`001?ooool8ool001;ooooo0ol00?l2ooooo`?o003o1Oooool5o`00o`Oooooo1_l00?l4ooooo`Go
003o1?ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`So003o1?ooool5o`00o`Wooooo
2?l00?l00oooooooo`00ool00005ool000Kooooo1Ooo0002ooooo`[oo`0000Coooooool00?oo003o
o`000_ooool5ool000;ooooo2?oo0002ooooo`?oo`001_ooool5ool000Sooooo2Ooo0006ooooo`[o
o`001_ooool5ool000Oooooo1Ooo0006ooooo`Ooo`000oooool5ool000?ooooo2?oo0005ooooo`Oo
o`003Oooool3o`00o`Kooooo1Ol00?l5ooooo`?o003o2Oooool5o`00o`Cooooo1Ol00?l4ooooo`7o
00000Oooool00003o`000?oooooooooo01Gooooo1_l00?l@ooooo`Ko003o1?ooool8ool000Oooooo
0ooo0003ooooo`ooo`000_ooool3ool000?ooooo2Ooo0005ooooo`?oo`000oooool6ool000Gooooo
2_oo0006ooooo`[oo`001_ooool5ool000Oooooo1Ooo0005ooooo`Ooo`001?ooool5ool000?ooooo
2?oo0006ooooo`Ooo`002oooool5o`00o`Gooooo1Ol00?lBooooo`Go003o0oooool5o`00o`Cooooo
0Ol00001ooooo`0000?o0000ooooooooool05_ooool4o`00oa3ooooo1Ol00?l6ooooo`Ooo`002_oo
ool3ool00003oooooooo003oo`0000goo`002Oooool8ool000Cooooo1Ooo0004ooooo`Goo`001?oo
ool9ool000Oooooo2_oo0006ooooo`Goo`001oooool4ool000Kooooo1Ooo0006ooooo`Goo`001?oo
ool6ool000Cooooo2_oo000;ooooo`Go003o1Oooool5o`00oa;ooooo1Ol00?l4ooooo`?o003o1Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Zooooo`Go003o0oooool:ool000;ooooo0ooo0004
ooooo`Goo`0000?oooooool00?oo00003?oo0005ooooo`Koo`0000?oooooool00?oo00001_oo0000
0oooooooo`00ool00003ool000Cooooo1Ooo0004ooooo`Koo`002Oooool5ool000;ooooo0ooo0006
ooooo`Koo`001_ooool5ool00004oooooooo003oo`00ool000;ooooo1Ooo0007ooooo`?oo`0000Co
ooooool00?oo003oo`002_ooool;ool000_ooooo1Ol00?l4ooooo`Ko003o4_ooool5o`00o`cooooo
0Ol00001ooooo`0000?o0000ooooooooool04_ooool3o`00oa3ooooo0ol00?l2ooooo`Go003o0_oo
ool;ool00003oooooooo003oo`0000?oo`000oooool5ool000Oooooo2?oo0004ooooo`Soo`0000?o
ooooool00?oo00002ooo0004ooooo`Goo`001Oooool3ool000[ooooo1_oo000;ooooo`Goo`001ooo
ool?ool000_ooooo1Ooo0008ooooo`_oo`003Oooool3o`00o`Cooooo1ol00?lCooooo`?o003o3Ooo
ool1o`00007ooooo00000ol0003oooooooooo`0Aooooo`Go003o3_ooool5o`00o`03ooooool00?oo
003o00?o003o0_oooolAool000?ooooo1Ooo0008ooooo`Ooo`0000?oooooool00?oo00002Ooo0004
ooooo`Goo`0000Coooooool00?oo003oo`001_ooool3ool001?ooooo1_oo000;ooooo`Koo`000ooo
oolBool000Wooooo2Ooo0005ooooo`_oo`0000Coooooool00?oo003oo`004Oooool9o`00ob7ooooo
0Ol00001ooooo`0000?o0000ooooooooool04Oooool5o`00o`kooooo1Ol00?l00ooooooo003oo`00
o`03o`00o`;ooooo4Ooo0004ooooo`?oo`001?ooool3ool000?ooooo4_oo0004ooooo`Koo`001?oo
ool3ool001Gooooo2?oo000=ooooo`Goo`000_oooolCool000Sooooo2ooo0004oooooa3oo`004?oo
ool:o`00oa;ooooo0ol00?l6ooooo`?o003o0_ooool1o`00007ooooo00000ol0003oooooooooo`0A
ooooo`Go003o3_ooool5o`00o`03ooooool00?oo003o00?o003o0oooool3ool000;ooooo2ooo000:
ooooo`Ooo`000_ooool3ool00003oooooooo003oo`0000Woo`0000Coooooool00?oo003oo`000_oo
ool6ool000;ooooo1_oo000Aooooo`Woo`001?ooool3ool000Oooooo1Ooo00000oooooooo`00ool0
0008ool00003oooooooo003oo`0000Koo`002Oooool;ool000Cooooo4?oo000?ooooo`Go003o00?o
ooooo`00ool00?l00ol00?lAooooo`Go003o1?ooool5o`00o`7ooooo0Ol00001ooooo`0000?o0000
ooooooooool04_ooool3o`00oa3ooooo1?l00?l2ooooo`?o003o0_ooool3ool000Kooooo2Ooo000:
ooooo`Soo`001Oooool8ool000?ooooo3?oo0002ooooo`Ooo`003oooool7ool000Cooooo1ooo0007
ooooo`?oo`0000?oooooool00?oo00002?oo0002ooooo`Woo`000_ooool3ool000?ooooo1Ooo0000
0oooooooo`00ool00003ool000Gooooo3ooo000>ooooo`Go003o0_ooool5o`00oa7ooooo1Ol00?l3
ooooo`Ko003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0Looooo`?o003o1_ooool5o`00
o`Gooooo1Ooo0003ooooo`?oo`0000?oooooool00?oo00001Ooo000:ooooo`Soo`001_ooool9ool0
0003oooooooo003oo`0000[oo`000_ooool7ool000oooooo1ooo0003ooooo`Soo`001?ooool3ool0
00Cooooo1_oo0006ooooo`Woo`0000?oooooool00?oo00002Ooo0003ooooo`?oo`002_ooool6ool0
0004oooooooo003oo`00ool000oooooo1Ol00?l3ooooo`?o003o4_ooool5o`00o`;ooooo1ol00?l1
ooooo`7o00000Oooool00003o`000?oooooo003o00;o003o6Oooool5o`00o`Gooooo1Ol00?l5oooo
o`Goo`000_ooool5ool00003oooooooo003oo`0000?oo`003?ooool7ool000Sooooo4ooo0004oooo
o`Soo`001?ooool3ool000Kooooo1_oo0004ooooo`Soo`000oooool5ool000?ooooo1Ooo0008oooo
o`Soo`0000?oooooool00?oo00001ooo000Eooooo`?oo`003Oooool5o`00o`03ooooool00?oo003o
00?o003o2?ooool3o`00o`Kooooo0ol00?l5ooooo`?o003o0oooool6o`00o`;ooooo0Ol00001oooo
o`0000?o0000o`00ool00?l00ol00?lHooooo`Go003o1Oooool5o`00o`Gooooo1Ooo0002ooooo`Go
o`000_ooool3ool000kooooo1ooo0008oooooa7oo`001oooool7ool000;ooooo1Ooo0005ooooo`Go
o`001Oooool@ool000Cooooo0ooo0005ooooo`?oo`000oooool5ool00003oooooooo003oo`0000[o
o`000_ooool6ool000Gooooo0ooo0002ooooo`Soo`001_ooool2ool000Oo003o00Coooooo`00ool0
0?oo003o2?ooool5o`00o`Cooooo1Ol00?l:ooooo`Go003o0oooool1o`00007ooooo00000ol0003o
003oo`00o`03o`00oaSooooo1Ol00?l6ooooo`?o003o1?ooool3o`00o`?oo`000oooool5ool001?o
oooo2?oo0009oooooa;oo`001?ooool7ool000;ooooo1Ooo0005ooooo`Goo`001_ooool@ool000Wo
oooo1_oo0007oooooaKoo`000oooool5ool00003oooooooo003oo`0000Ooo`001?ooool3ool000[o
003o2Oooool5o`00o`Cooooo1Ol00?l;ooooo`?o003o1?ooool1o`00007ooooo00000ol0003o003o
o`00o`03o`00oaSooooo1Ol00?l<ooooo`Go003o1_ooool3ool00004oooooooo003oo`00ool000Ko
oooo0ooo0007ooooo`Woo`001?ooool=ool00003oooooooo003oo`0000Soo`000_ooool7ool000;o
oooo1Ooo00001Ooooooo003oo`00ool00?oooooo00Goo`003?ooool;ool000Oooooo3?oo0002oooo
oaKoo`000oooool5ool00003oooooooo003oo`0000koo`002ol00?l8ooooo`Go003o1?ooool9o`00
o`kooooo0Ol00001ooooo`0000?o0000ooooool00?l00_l00?lIooooo`Go003o3?ooool5o`00o`Wo
oooo1Ooo0004ooooo`Goo`001oooool8ool000?ooooo2?oo0002ooooo`?oo`000ooooolAool000Co
oooo0ooo00000ooooooo003oo`00o`03o`00o`04oooooooo003oo`00ool000gooooo1Ooo00000ooo
ooooo`00ool00003ool000Oooooo3Ooo00000oooooooo`00ool0000Dool000?ooooo1_oo00000ooo
ooooo`00ool0000>ool000[o003o2Oooool3o`00o`Kooooo2Ol00?l=ooooo`7o00000Oooool00003
o`000?oooooooooo00Cooooo0ol00?lEooooo`?o003o3Oooool5o`00o`03oooooooo003oo`0000?o
o`000oooool5ool000Cooooo1Ooo000:ooooo`Goo`000oooool8ool000_ooooo3?oo0003ooooo`?o
003o1?ooool5o`00oa;ooooo0ooo0002ooooo`Goo`001oooool=ool000;ooooo5?oo0005ooooo`Ko
o`001?ooool<ool000Gooooo1Ol00?l=ooooo`?o003o0_ooool9o`00o`gooooo0Ol00001ooooo`00
00?o0000ooooooooool00oooool5o`00obGooooo0ol00?l00oooooooo`00ool00005ool000;ooooo
1Ooo0004ooooo`Goo`002Oooool5ool000Cooooo2?oo000<ooooo`_oo`000_ooool5o`00o`?ooooo
1Ol00?lHooooo`?oo`001_ooool?ool000Cooooo1Ooo00000oooooooo`00ool00004ool00003oooo
oooo003oo`0000?oo`000_ooool3ool00003oooooooo003oo`0000?oo`001oooool7ool000Gooooo
1_l00?l=ooooo`Go003o0_ooool8o`00o`gooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
ool5o`00obWooooo1ooo00000oooooooo`00ool00004ool000Gooooo0ooo000:ooooo`Goo`001Ooo
ool8ool000gooooo0ooo0002ooooo`?oo`000oooool5o`00o`;ooooo1_l00?lBooooo`?o003o2ooo
ool8ool00003oooooooo003oo`0000Ooo`000_ooool5ool000;ooooo2ooo00000oooooooo`00ool0
0008ool000?ooooo0ooo0002ooooo`Goo`001Oooool5o`00o`;ooooo0ol00?l:ooooo`Go003o1_oo
ool3o`00o`Cooooo0ol00?l7ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1Ol00?lX
ooooo`Soo`0000?oooooool00?oo00002?oo000=ooooo`Koo`001Oooool9ool001Oooooo1Ol00?l2
ooooo`Go003o2oooool3o`00o`Cooooo1Ol00?l:ooooo`Goo`001Oooool9ool00003oooooooo003o
o`0000?oo`000_ooool;ool00003oooooooo003oo`0000?oo`0000?oooooool00?oo00002Ooo0003
ooooo`?oo`001?ooool6o`00o`03ooooool00?oo003o00?o003o2Oooool6o`00o`_ooooo1Ol00?l6
ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo1Ol00?lUooooo`Woo`000_ooool;ool0
00_ooooo1_oo0002ooooo`?oo`0000?oooooool00?oo00001ooo000Hooooo`?o003o0oooool5o`00
o`[ooooo1Ol00?l3ooooo`Go003o2_ooool5ool000Gooooo2Ooo0002ooooo`?oo`000_ooool;ool0
00;ooooo1Ooo0003ooooo`Woo`000_ooool5ool000;ooooo1ol00?l00ooooooo003oo`00o`03o`00
o`Oooooo2?l00?l;ooooo`Go003o1_ooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`Go
003o4Oooool3o`00o`gooooo0ol00?l6ool000Gooooo2ooo000;ooooo`Goo`000_ooool>ool001oo
oooo0ol00?l;ooooo`Go003o0oooool7o`00o`Wooooo0ooo0006ooooo`Woo`001_ooool9ool000Ko
oooo0ooo0004ooooo`Woo`000_ooool5ool000;ooooo1_l00?l2ooooo`Go003o1_ooool:o`00o`[o
oooo1Ol00?l01?oooooo003oo`00ool00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00Go
oooo1Ol00?l@ooooo`Go003o2oooool5o`00o`Goo`001Oooool;ool000_ooooo1Ooo0002ooooo`Go
o`0000Goooooool00?oo003oo`00ooooo`03ool002kooooo1Ol00?l4ooooo`Oo003o00Coooooo`00
ool00?oo003o1Oooool3ool000Kooooo2?oo0006ooooo`Soo`001_ooool3ool000Gooooo2?oo0003
ooooo`Goo`000_ooool5o`00o`Cooooo0ol00?l7ooooo`[o003o2oooool3o`00o`03ooooool00?oo
003o00?o003o0Oooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`Go003o4?ooool6o`00
o`[ooooo1Ol00?l4ool000Oooooo2Ooo000=ooooo`?oo`000ooooolAool001oooooo0ol00?l9oooo
o`?o003o1oooool:o`00o`?ooooo1Ooo0007ooooo`Koo`001_ooool5ool000Sooooo1Ooo0005oooo
o`Goo`001_ooool3ool000Cooooo1Ol00?l=ooooo`[o003o2?ooool<o`00o`7ooooo0Ol00001oooo
o`0000?o0000ooooooooool01_ooool3o`00oa7ooooo1_l00?l:ooooo`Go003o0ooo0007ooooo`Ko
o`000_ooool3ool001?ooooo0ooo00000oooooooo`00ool0000;ool000?ooooo0ooo000Gooooo`Go
003o1_ooool3o`00o`Oooooo3?l00?l3ooooo`Goo`001_ooool7ool000Kooooo1?oo0009ooooo`Go
o`001Oooool5ool000kooooo1Ol00?l=ooooo`?o003o0_ooool3o`00o`Sooooo3Ol00?l1ooooo`7o
00000Oooool00004o`000?ooooooooooooooo`?o003o5oooool5o`00o`_ooooo0ol00?l2ool000Co
oooo0ooo00000oooooooo`00ool00005ool00003oooooooo003oo`0000?oo`004_oooolAool000;o
oooo1Ooo000Fooooo`Ko003o1?ooool5o`00o`Gooooo1ol00?l00ooooooo003oo`00o`03o`00o`?o
oooo1Ooo0006ooooo`Koo`001_ooool6ool000Sooooo1Ooo0005ooooo`Goo`0000Coooooool00?oo
003oo`002_ooool5o`00oagooooo3?l00?l2ooooo`7o00000Oooool00003o`000?oooooooooo00Go
003o5oooool3o`00o`cooooo1Ooo0003ooooo`coo`0000?oooooool00?oo00000ooo000Aoooooa;o
o`000_ooool5ool001Kooooo1ol00?l3ooooo`Go003o1Oooool5o`00o`Cooooo0ol00?l5ooooo`Ko
o`001?ooool5ool000Oooooo1_oo0005ooooo`?oo`0000Coooooool00?oo003oo`001oooool3ool0
0003oooooooo003oo`0000?oo`0000Coooooool00?oo003oo`001Oooool5o`00o`?ooooo0ol00?lG
ooooo`Wo003o1Oooool1o`00007ooooo00000ol0003oooooooooo`05o`00obKooooo1Ooo0003oooo
o`coo`0000?oooooool00?oo00001?oo000:ooooo`?oo`000ooooolBool000;ooooo1Ooo000Goooo
o`Ko003o0oooool5o`00o`Gooooo1_l00?l;ooooo`Ooo`001?ooool3ool000Sooooo1_oo0004oooo
o`Goo`003_ooool:ool000Gooooo0ol00?l3ooooo`Go003o2oooool3o`00o`Wooooo1ol00?l6oooo
o`7o00000Oooool00003o`000?oooooooooo00Go003o0oooool3o`00ob7ooooo0ooo0004ooooo`Go
o`0000?oooooool00?oo00001?oo0002ooooo`Koo`002?ooool5ool000;ooooo4ooo0002ooooo`?o
o`006Oooool5o`00o`Cooooo0ol00?l7ooooo`Go003o2oooool7ool00004oooooooo003oo`00ool0
00_ooooo1ooo0003ooooo`Goo`003_ooool:ool000_ooooo1Ol00?l:ooooo`Go003o5Oooool1o`00
007ooooo00000ol0003oooooooooo`0?o`00obGooooo2ooo0002ooooo`Ooo`001ooooolDool00003
oooooooo003oo`0000?oo`000oooool3ool000;ooooo0ol00?lDooooo`?o003o3oooool5o`00o`co
oooo2ooo0009ooooo`Woo`000_ooool5ool000oooooo0ooo00000oooooooo`00ool00003ool000_o
oooo1Ol00?l:ooooo`Go003o5Oooool1o`00007ooooo00001?l0003oooooooooooooool?o`00obCo
oooo2ooo0003ooooo`Ooo`001_ooool@ool000Gooooo1Ooo0002ooooo`Goo`001Ol00?lAooooo`?o
003o4Oooool5o`00o`_ooooo1_oo00000oooooooo`00ool00003ool000Wooooo2Ooo0002ooooo`Go
o`005?ooool3ool000[ooooo1ol00?l:ooooo`Go003o1Oooool3o`00o`Sooooo0ol00?l2ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooo3Ol00?lQooooo`goo`000oooool8ool000Oooooo
3_oo0007ooooo`?oo`000oooool5ool000Go003o4?ooool5o`00o`Oooooo0ol00?l6ooooo`Go003o
2oooool5ool000;ooooo1Ooo0009ooooo`[oo`0000?oooooool00?oo00000ooo000Pooooo`Wo003o
0_ooool3o`00o`05ooooool00?oo003oo`00ooooool00ol00?l5ooooo`Go003o1_ooool5o`00o`7o
oooo0Ol00001ooooo`0000?o0000ooooooooool00oooool=o`00ob3ooooo3?oo0004ooooo`Woo`00
2_ooool9ool000oooooo1Ooo0005o`00oa3ooooo1Ol00?l6ooooo`Go003o1Oooool5o`00o`_ooooo
1Ooo0002ooooo`Goo`002_ooool3ool00003oooooooo003oo`0000?oo`000_ooool3ool0027ooooo
2Ol00?l00ooooooo003oo`00o`07o`00o`Sooooo1Ol00?l6ooooo`Go003o0Oooool1o`00007ooooo
00000ol0003oooooooooo`04ooooo`?o003o1Oooool3o`00oakooooo3ooo0004ooooo`[oo`002_oo
ool8ool0013ooooo0ooo0002ooooo`?o003o4Oooool5o`00o`Kooooo1Ol00?l6ooooo`?o003o2_oo
ool3o`00o`?oo`001?ooool3ool000;ooooo0ooo000:ooooo`Goo`009_ooool9o`00o`03ooooool0
0?oo003o00Oo003o2?ooool5o`00o`Kooooo1Ol00?l1ooooo`7o00000Oooool00003o`000?oooooo
oooo02cooooo4Ooo0003ooooo`Goo`0000?oooooool00?oo00000ooo0002ooooo`?oo`001Oooool7
ool000Cooooo0ooo000Fooooo`?o003o1Oooool3o`00o`;ooooo0ol00?l7ooooo`Go003o4_ooool5
o`00o`[ooooo1Ooo0004ooooo`?oo`000oooool3ool000Cooooo0ooo000Kooooo`?oo`000oooool3
o`00o`03ooooool00?oo003o00co003o2Oooool3o`00o`Kooooo1Ol00?l2ooooo`7o00000Oooool0
0003o`000?oooooooooo00;ooooo0ol00?lWoooooa;oo`000oooool3ool000;ooooo1Ooo00000ooo
ooooo`00ool00003ool000Gooooo1_oo0003ooooo`Goo`005?ooool5o`00o`?ooooo1Ol00?l<oooo
o`?o003o4oooool5o`00o`[ooooo1Ooo0003ooooo`Goo`002?ooool5ool001Wooooo1Ooo0006oooo
o`Wo003o00Coooooo`00ool00?oo003o4oooool5o`00o`;ooooo0Ol00001ooooo`0000Co0000oooo
oooooooooooo1Ol00?l01?oooooo003oo`00ool00?lRooooo`Goo`0000?oooooool00?oo00002_oo
0008ooooo`Goo`0000?oooooool00?oo00000ooo0005ooooo`Koo`000oooool5ool001Cooooo1Ol0
0?l3ooooo`Go003o8_ooool6o`00o`Wooooo1Ooo0003ooooo`Goo`002?ooool5ool000gooooo0ooo
0008ooooo`Koo`001Oooool8o`00oaWooooo1Ol00?l2ooooo`7o00000Oooool00004o`000?oooooo
ooooooooo`go003o7oooool3ool000;ooooo1_oo00000oooooooo`00ool00003ool000Wooooo0ooo
0002ooooo`Goo`001Oooool7ool000;ooooo1Ooo000Dooooo`Go003o0oooool5o`00ob?ooooo1_l0
0?l8ooooo`Goo`0000?oooooool00?oo00001Ooo0008ooooo`Goo`003?ooool5ool000Kooooo1ooo
0002ooooo`_o003o6_ooool3o`00o`?ooooo0Ol00001ooooo`0000Co0000oooooooooooooooo3_l0
0?lTooooo`Coo`000_ooool5ool000?ooooo0ooo0009ooooo`?oo`001_ooool8ool00003oooooooo
003oo`0000?oo`005Oooool3o`00o`Cooooo1Ol00?l2ooooo`?o003o7oooool5o`00o`Sooooo3?oo
000:ooooo`?oo`002_ooool8ool000;ooooo0ooo00000oooooooo`00ool00004ool000;ooooo2ol0
0?lAooooo`?o003o3Oooool1o`00007ooooo00000ol0003oooooooooo`02ooooo`ko003o:Oooool5
ool000;ooooo1Ooo000:ooooo`?oo`000oooool?ool001cooooo1Ol00?l00ooooooo003oo`00o`03
o`00oagooooo1_l00?l00ooo003oooooooooo`05ooooo`Coo`0000?oooooool00?oo00000ooo0002
ooooo`?oo`001_ooool5ool000Sooooo2Ooo00000oooooooo`00ool00008ool000?ooooo2?l00?l<
ooooo`?o003o1?ooool5o`00o`Oooooo0ol00?l2ooooo`7o00000Oooool00003o`000?oooooooooo
00;ooooo3_l00?lNooooo`?oo`001?ooool3ool000;ooooo0ooo0003ooooo`Goo`000_ooool3ool0
0003oooooooo003oo`0000Koo`000_ooool@ool001_ooooo1Ol00?l00ooooooo003oo`00o`03o`00
oaGooooo0ol00?l5ooooo`Go003o0ooo0005ooooo`_oo`0000?oooooool00?oo00000ooo0005oooo
o`Goo`002?ooool9ool00003oooooooo003oo`0000?oo`0000Coooooool00?oo003oo`001?ooool9
o`00o`[ooooo1Ol00?l3ooooo`Go003o1_ooool5o`00o`7ooooo0Ol00001ooooo`0000?o0000oooo
ooooool00oooool=o`00oagooooo1Ooo0002ooooo`Goo`001oooool5ool00003oooooooo003oo`00
00coo`0000?oooooool00?oo00003_oo000Dooooo`?o003o1Oooool3o`00o`;ooooo1Ol00?lAoooo
o`So003o1?ooool5o`00o`?oo`0000Goooooool00?oo003oo`00ooooo`06ool00004oooooooo003o
o`00ool000;ooooo1Ooo0005ooooo`Goo`002?ooool8ool000;ooooo1Ooo0008ooooo`Wo003o1ooo
ool8o`00o`;ooooo1_l00?l5ooooo`Ko003o0Oooool1o`00007ooooo00000ol0003oooooooooo`06
ooooo`Wo003o7_ooool5ool000;ooooo1Ooo00001?ooooooo`00ool00?oo0004ooooo`?oo`000_oo
ool?ool00003oooooooo003oo`0000goo`004oooool5o`00o`[ooooo0ol00?l7ooooo`?o003o1ooo
ool9o`00o`Gooooo0ol00?lAool000Cooooo1Ooo0006ooooo`?oo`001?ooool3ool000?ooooo0ooo
0003ooooo`?oo`0000Coooooool00?oo003oo`002Oooool9o`00o`Kooooo2Ol00?l00ooooooo003o
o`00o`05o`00o`Gooooo1_l00?l1ooooo`7o00000Oooool00003o`000?oooooooooo00Oooooo1?l0
0?l5ooooo`?o003o6_ooool5ool000;ooooo2ooo00001?ooooooo`00ool00?oo0003ooooo`ooo`00
0_ooool5ool00003oooooooo003oo`0000Koo`004oooool5o`00oa?ooooo1Ol00?l6ooooo`Wo003o
2?ooool3ool00003oooooooo003oo`0000coo`001?ooool3ool000Oooooo0ooo0003ooooo`Goo`00
1oooool7ool000[ooooo2?l00?l7ooooo`So003o0_ooool9o`00o`?ooooo1Ol00?l2ooooo`7o0000
0Oooool00003o`000?oooooooooo00oooooo1Ol00?l2ooooo`?o003o5Oooool3ool000Cooooo0ooo
00000oooooooo`00ool00009ool000?ooooo0ooo00001?ooooooo`00ool00?oo0002ooooo`_oo`00
1Oooool5ool000;ooooo0ooo0008ooooo`?o003o0_ooool6o`00oa?ooooo1Ol00?l6ooooo`So003o
3Oooool8ool00003oooooooo003oo`0000?oo`003?ooool6ool000;ooooo1_oo0006ooooo`Soo`00
2_ooool5o`00o`Sooooo1_l00?l5ooooo`[o003o0_ooool5o`00o`;ooooo0Ol00001ooooo`0000?o
0000ooooooooool03oooool;o`00oaoooooo2ooo0009ooooo`?oo`0000?oooooool00?oo00002?oo
0006ooooo`?oo`000_ooool5ool000Gooooo3?l00?lDooooo`Go003o1oooool3o`00o`Sooooo0ol0
0?l7ooooo`goo`002oooool8ool00003oooooooo003oo`0000Goo`001?ooool9ool000[ooooo1Ol0
0?l8ooooo`Go003o1oooool3o`00o`03ooooool00?oo003o00?o003o0_ooool5o`00o`;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool03Oooool=o`00o`Cooooo0ol00?lGooooo`coo`002?ooool5
ool000;ooooo2?oo000;ooooo`Goo`001?ooool<o`00oaKooooo0ol00?l9ooooo`?o003o1_ooool5
o`00o`Gooooo0ooo00000oooooooo`00ool0000:ool000Wooooo2?oo0002ooooo`Koo`000oooool:
ool000;ooooo0ooo0005ooooo`Go003o2?ooool5o`00o`;ooooo0ol00?l6ooooo`Go003o0oooool3
o`00o`?ooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool>o`00o`?ooooo1Ol00?lEoooo
o`Soo`0000Coooooool00?oo003oo`002Oooool5ool000;ooooo1ooo000;ooooo`Koo`001?ooool<
o`00o`;ooooo0ol00?lLooooo`Go003o1Oooool5o`00o`Cooooo4_oo0008ooooo`Soo`000_ooool6
ool000?ooooo2_oo00000oooooooo`00ool00003ool00005ooooool00?oo003oo`00ooooool00ol0
0?l:ooooo`?o003o0_ooool5o`00o`Kooooo0ol00?l01?oooooo003oo`00ool00?l6ooooo`7o0000
0Oooool00003o`000?oooooooooo00?o003o2Oooool5o`00o`;ooooo1_l00?l4ooooo`Go003o5Ooo
ool5ool0013ooooo1Ooo0003ooooo`?oo`003Oooool6ool000Gooooo1_l00?l2ooooo`?o003o0_oo
ool5o`00oa_ooooo1Ol00?l4ooooo`Ko003o1?ooool5ool00004oooooooo003oo`00ool000;ooooo
1ooo0002ooooo`?oo`000_ooool8ool000;ooooo1_oo0004ooooo`Goo`0000Coooooool00?oo003o
o`000_ooool5ool000Go003o4?ooool7o`00o`Wooooo1Ol00?l5ooooo`7o00000Oooool00003o`00
0?oooooo003o00Co003o2?ooool5o`00o`?ooooo0ol00?l6ooooo`Go003o1oooool3ool000_ooooo
1Ooo000Aooooo`Goo`001Oooool3ool000Wooooo1ooo0006ooooo`?o003o2Oooool6o`00o`kooooo
0ol00?l6ooooo`So003o1?ooool5o`00o`Gooooo1Ooo0008ooooo`Goo`0000?oooooool00?oo0000
2?oo0003ooooo`Woo`000oooool5ool000Oooooo1Ooo0005o`00o`oooooo2?l00?l9ooooo`Go003o
1Oooool1o`00007ooooo00000ol0003oooooo`00o`04o`00o`Wooooo0ol00?l=ooooo`Go003o1_oo
ool8ool000Sooooo1Ooo000Aooooo`Goo`000oooool5ool000Oooooo2?oo000Booooo`Ko003o3Ooo
ool5o`00o`Cooooo2?l00?l5ooooo`Go003o1_ooool3ool000[ooooo0ooo0002ooooo`[oo`000_oo
oolBool00004oooooooo003oo`00ool000Cooooo0ooo00000ooooooo003oo`00o`03o`00o`oooooo
1ol00?l:ooooo`Go003o1Oooool1o`00007ooooo00000ol0003oooooo`00o`04o`00o`Gooooo0ol0
0?l?ooooo`Oo003o1_ooool9ool000Oooooo1Ooo000Aooooo`Goo`000oooool5ool000Oooooo1ooo
000Dooooo`Go003o3Oooool>o`00o`Wooooo0ol00?lIooooo`[oo`000_oooolGool000Oooooo00Go
o`00o`00ool00?oo003oool0000?ooooo`Go003o3?ooool5o`00o`Gooooo0Ol00001ooooo`0000?o
0000ooooooooool00ol00?l5ooooo`Go003o3Oooool8o`00o`Kooooo2Ooo0006ooooo`Koo`004Ooo
ool5ool000?ooooo1Ooo0005ooooo`Ooo`0000Coooooool00?oo003oo`004oooool3o`00o`Gooooo
0ol00?l6ooooo`ko003o5Oooool3ool000kooooo0ooo0002ooooo`?oo`000oooool5ool00003oooo
oooo003oo`0000Woo`0000?oooooool00?oo00000ooo0008ooooo`?oo`004Oooool3o`00o`gooooo
1Ol00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00Sooooo1Ol00?l=ooooo`Oo003o2?oo
ool8ool000Gooooo1_oo000:ooooo`?oo`001_ooool3ool000Gooooo0ooo0005ooooo`Ooo`0000?o
ooooool00?oo00000ooo000Iooooo`Go003o1_ooool<o`00oaGooooo1Ooo000Hooooo`Coo`000_oo
ool9ool000?ooooo1Ooo000]ooooo`?o003o1_ooool1o`00007ooooo00000ol0003oooooooooo`08
ooooo`Ko003o3?ooool5o`00o`cooooo1ooo0004ooooo`Goo`002?ooool7ool001Gooooo1Ooo0003
ooooo`Goo`005_ooool8o`00o`Oooooo2?l00?l01?oooooo003oo`00ool00?lDooooo`Goo`0000Co
ooooool00?oo003oo`004oooool6ool000;ooooo0ooo00001?ooooooo`00ool00?oo0004ooooo`Co
o`00=oooool1o`00007ooooo00000ol0003oooooooooo`09ooooo`Go003o3?ooool4o`00o`cooooo
2?oo0004ooooo`Goo`001oooool8ool00004oooooooo003oo`00ool0017ooooo1Ooo0003ooooo`Go
o`004_ooool<o`00o`Sooooo3?l00?l:ooooo`?o003o0ooo0003ooooo`[oo`003Oooool3ool000;o
oooo1ooo0003ooooo`?oo`001Oooool6ool000Gooooo0ooo000^ooooo`7o00000Oooool00003o`00
0?oooooooooo00Oooooo1ol00?l;ooooo`Go003o2oooool<ool000;ooooo0ooo0008ooooo`goo`00
4Oooool3ool000Gooooo0ooo000Booooo`co003o2oooool:o`00o`Wooooo1Ol00?l3ool000?ooooo
0ooo00000oooooooo`00ool00003ool000[ooooo1ooo00000oooooooo`00ool0000<ool000Cooooo
1ooo0003ooooo`Goo`002oooool3o`00oaoooooo0Ol00001ooooo`0000?o0000ooooooooool00ol0
0?l2ooooo`So003o3?ooool5o`00o`_ooooo3Ooo000<ooooo`goo`009_ooool3o`00o`?ooooo2ol0
0?l?ooooo`?o003o00?oooooo`00ool00?l00ol00?l3ooooo`?o003o0oooool5o`00o`?oo`001ooo
ool5ool00004oooooooo003oo`00ool000Gooooo2?oo0002ooooo`koo`000oooool8ool000;ooooo
1Ooo000:ooooo`Go003o7_ooool1o`00007ooooo00000ol0003oooooo`00o`0;o`00o`kooooo1Ol0
0?l7ooooo`?o003o00?oooooool00?oo00000ooo0003ooooo`Goo`003Oooool=ool001[ooooo0ooo
0007ooooo`Go003o00?oooooo`00ool00?l02Ol00?l2ooooo`?o003o4?ooool3o`00o`?ooooo1Ol0
0?l2ooooo`Go003o0ooo0008ooooo`?oo`0000?oooooool00?oo00000ooo0004ooooo`Soo`001?oo
ool<ool000Cooooo1ooo0002ooooo`Goo`002_ooool5o`00oa[ooooo0ol00?l1ooooo`7o00000Ooo
ool00003o`000?oooooo003o00_o003o3oooool5o`00o`Gooooo1Ol00?l01?ooooooo`00ool00?oo
0002ooooo`Ooo`004?ooool;ool001;ooooo0ooo0003ooooo`Goo`001_ooool5o`00o`03ooooool0
0?oo003o00Go003o1Oooool5o`00oaGooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Coo`003?oo
ool5ool000Cooooo1ooo0002ooooo`?oo`000_ooool<ool000Cooooo1Ooo0003ooooo`?oo`002ooo
ool8o`00oa;ooooo0ol00?l00ooooooo003oo`00o`03o`00o`7o00000Oooool00003o`000?oooooo
003o00[o003o4?ooool5o`00o`Gooooo1Ol00?l5ooooo`Ooo`004_ooool3ool000;ooooo1Ooo000:
ooooo`?oo`001?ooool5ool000;ooooo1Ooo0006ooooo`Go003o00?oooooo`00ool00?l00ol00?l5
ooooo`Oo003o5Oooool5o`00o`03ooooool00?oo003o00?o003o1?oo000<ooooo`Goo`001Oooool5
ool000;ooooo2_oo0002ooooo`Ooo`001?ooool3ool001?ooooo2?l00?l5ooooo`?o003o2?ooool:
o`00o`7o00000Oooool00003o`000?oooooooooo00?o003o0_ooool5o`00oa3ooooo1Ol00?l5oooo
o`Go003o1Oooool6ool001Cooooo0ooo00000oooooooo`00ool00003ool000Kooooo2?oo0003oooo
o`Goo`000_ooool5ool000Oooooo0ol00?l3ooooo`?o003o1Oooool8o`00o`?ooooo0ol00?l@oooo
o`?o003o0_ooool5o`00o`Coo`003Oooool4ool000cooooo2_oo0004ooooo`Goo`007Oooool5o`00
o`Cooooo1Ol00?l7ooooo`[o003o0Ol00001ooooo`0000?o0000ooooooooool01Oooool5o`00oa7o
oooo0ol00?l7ooooo`?o003o1_ooool6ool000;ooooo1?oo000=ooooo`Goo`0000Coooooool00?oo
003oo`001_ooool9ool000?ooooo1Ooo0003ooooo`Koo`000ol00?l@ooooo`Oo003o0oooool5o`00
o`Oooooo0ol00?l7ooooo`?o003o00Goooooo`00ool00?oo003oooooo`05ool000cooooo1Ooo0009
ooooo`coo`001?ooool5ool000Gooooo0ooo000Eooooo`Go003o0_ooool7o`00o`Oooooo1Ol00?l0
1_oooooo003oo`00ool00?ooooooo`00007ooooo00000ol0003oooooooooo`05ooooo`Go003o5ooo
ool3o`00o`Sooooo1ooo0002ooooo`Koo`003?ooool6ool000;ooooo0ooo0004ooooo`Woo`001?oo
ool3ool000Kooooo0ooo0005o`00o`oooooo1Ol00?l5ooooo`Go003o1_ooool5o`00o`05ooooool0
0?oo003oo`00ooooool01Ol00?l4ooooo`Goo`001oooool3ool000;ooooo1Ooo0008ooooo`coo`00
1?ooool5ool000Gooooo1Ooo00001?ooooooo`00ool00?oo000Aooooo`?o003o0_ooool8o`00o`So
oooo0ol00?l6ooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo0ol00?lGooooo`Go003o
1_ooool7ool000;ooooo1ooo000<ooooo`Koo`0000?oooooool00?oo00001?oo0002ooooo`Soo`00
3Oooool4ool000Go003o4?ooool3o`00o`Kooooo1Ol00?l6ooooo`oo003o1?ooool5ool000Kooooo
1Ooo00000oooooooo`00ool00003ool000;ooooo0ooo0003ooooo`Goo`0000?oooooool00?oo0000
0ooo0004ooooo`Goo`001_ooool:ool001Cooooo2?l00?l=ooooo`?o003o0_ooool1o`00007ooooo
00000ol0003oooooooooo`0Kooooo`?o003o0_ooool5o`00o`Kooooo1ooo0002ooooo`Ooo`003Ooo
ool5ool00003oooooooo003oo`0000Goo`000_ooool3ool0017ooooo1?oo0005o`00oaWooooo1_l0
0?l5ooooo`oo003o1Oooool6ool000Cooooo1Ooo0002ooooo`?oo`000_ooool5ool00003oooooooo
003oo`0000Coo`000_ooool3ool000Gooooo1Ooo0006ooooo`[oo`002_ooool3o`00o`Cooooo2Ol0
0?l>ooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0Jooooo`Go003o00?ooooo
o`00ool00?l00ol00?l6ooooo`Ooo`000_ooool6ool000kooooo1Ooo00000oooooooo`00ool00005
ool000Sooooo0ooo0008ooooo`Ooo`001Ol00?lHooooo`So003o1Oooool3o`00o`03ooooool00?oo
003o00?o003o00Coooooo`00ool00?oo003o0_ooool3ool000?ooooo1Ooo0003ooooo`Goo`001ooo
ool5ool00003oooooooo003oo`0000?oo`000_ooool5ool000Cooooo1Ooo0006ooooo`[oo`002Ooo
ool5o`00o`;ooooo2Ol00?l?ooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`06
ooooo`?o003o4Oooool5o`00o`;ooooo0ol00?l8ooooo`Goo`000oooool5ool0013ooooo0ooo0003
ooooo`Koo`001oooool5ool000Kooooo2?oo0005o`00oaSooooo2Ol00?l9ooooo`?o003o1_ooool5
ool000;ooooo1Ooo0004ooooo`Koo`001Oooool5ool00003oooooooo003oo`0000?oo`000_ooool5
ool000Gooooo1?oo0002ooooo`?oo`0000?oooooool00?oo00000ooo00001?ooooooo`00ool00?oo
000:ooooo`Go003o0_ooool8o`00o`oooooo1_l00?l1ooooo`7o00000Oooool00004o`000?oooooo
ooooooooo`?o003o00?oooooo`00ool00?l00ol00?l7ooooo`?o003o1_ooool5o`00o`gooooo1Ooo
0003ooooo`Ooo`005_ooool3ool000Sooooo1Ooo0006ooooo`Goo`0000?oooooool00?oo00001Ol0
0?lHooooo`[o003o4Oooool5ool000;ooooo1Ooo0006ooooo`Goo`000_ooool6ool000?ooooo0ooo
0002ooooo`Koo`001Oooool:ool00005oooooooo003oo`00ool00?ooool00ooo000;ooooo`Ko003o
00?oooooo`00ool00?l01Ol00?l@ooooo`Go003o0_ooool1o`00007ooooo00000ol0003ooooooooo
o`0:o`00o`Gooooo1_l00?l6ooooo`?o003o3_ooool5ool000Cooooo1ooo0005ooooo`?oo`001_oo
ool3ool000cooooo2?oo0005ooooo`Ooo`0000?oooooool00?oo00000ol00?lIooooo`[o003o4Ooo
ool5ool000?ooooo0ooo0007ooooo`Goo`0000?oooooool00?oo00000ooo000:ooooo`Koo`001Ooo
ool<ool000;ooooo1Ooo000;ooooo`Go003o0_ooool3o`00oa?ooooo1Ol00?l2ooooo`7o00000Ooo
ool00003o`000?oooooooooo00[o003o1?ooool7o`00oaOooooo1_oo0005ooooo`Goo`001?ooool5
ool000Cooooo1Ooo0002ooooo`?oo`001Oooool8ool000Gooooo2?oo000Pooooo`?o003o00?ooooo
o`00ool00?l00ol00?lBooooo`?oo`002oooool8ool00003oooooooo003oo`0000?oo`002_ooool6
ool000?ooooo3ooo00000oooooooo`00ool00003ool000_ooooo1Ol00?l01?oooooo003oo`00ool0
0?lEooooo`?o003o0oooool1o`00007ooooo00000ol0003oooooooooo`05o`00o`04ooooool00?oo
003oo`00o`Gooooo1ol00?l>ooooo`?o003o1oooool5ool000Gooooo1Ooo0004ooooo`Goo`001?oo
ool5ool00003oooooooo003oo`0000Koo`0000?oooooool00?oo00000ooo0003ooooo`?oo`000_oo
ool8ool002Gooooo0ol00?l6ooooo`?o003o5?ooool;ool000;ooooo1Ooo000;ooooo`Goo`000_oo
ool@ool00003oooooooo003oo`0000?oo`003?ooool3o`00o`03ooooool00?oo003o00?o003o6_oo
ool1o`00007ooooo00001?l0003oooooooooooooool3o`00o`[ooooo1_l00?l>ooooo`Go003o1_oo
ool5ool000Kooooo0ooo0005ooooo`Koo`000oooool5ool00003oooooooo003oo`0000coo`000_oo
ool5ool00003oooooooo003oo`0000Goo`00;_ooool5o`00oa;ooooo2ooo0004ooooo`?oo`003Ooo
ool3ool000?ooooo1Ooo00000oooooooo`00ool00008ool000;ooooo0ooo000Aooooo`Go003o6_oo
ool1o`00007ooooo00000ol0003oooooooooo`0?ooooo`?o003o4?ooool5o`00o`Oooooo0ooo000@
ooooo`Ooo`000_ooool3ool000;ooooo2Ooo00001?ooooooo`00ool00?oo0003ooooo`Goo`000_oo
ool3ool0037ooooo1Ol00?lBooooo`_oo`006?ooool7ool000;ooooo2?oo000Gooooo`Go003o6_oo
ool1o`00007ooooo00000ol0003oooooooooo`0Rooooo`So003o5oooool8ool000Oooooo2Ooo0006
ooooo`Goo`00=_ooool5o`00o`;oo`002?ooool3ool000Gooooo2ooo000Gooooo`Soo`001?ooool5
ool001Wooooo0ol00?lKooooo`7o00000Oooool00003o`000?oooooooooo02?ooooo2?l00?lFoooo
o`Soo`002oooool6ool000Gooooo1Ooo000Vooooo`?o003o3_ooool3o`00o`Coo`001_ooool5ool0
00Cooooo2_oo000Hooooo`Ooo`001Oooool5ool003Oooooo0Ol00001ooooo`0000?o0000oooooooo
ool09_ooool5o`00oaGooooo2Ooo000<ooooo`Goo`001Oooool5ool002Gooooo1Ol00?l?ooooo`Go
o`001_ooool5ool000Gooooo1_oo000Kooooo`Soo`001?ooool5ool002Kooooo0ol00?l>ooooo`7o
00000Oooool00003o`000?oooooooooo02Kooooo1Ol00?lEooooo`Soo`001Oooool3ool000Gooooo
2?oo0003ooooo`?oo`009_ooool5o`00o`[ooooo0ooo00000oooooooo`00ool00004ool000Gooooo
2?oo0005ooooo`?oo`001Oooool3ool001Gooooo2_oo0002ooooo`?oo`000_ooool3ool0013ooooo
0ol00?l>ooooo`Go003o3Oooool1o`00007ooooo00000ol0003oooooooooo`0Uooooo`Go003o5_oo
ool6ool000Kooooo1_oo0003ooooo`Woo`002oooool3ool001gooooo1Ol00?l4ooooo`?oo`000_oo
ool:ool000Kooooo2Ooo000;ooooo`Goo`001?ooool3ool0013ooooo2?oo0005ooooo`Goo`001ooo
ool3o`00o`Cooooo1Ol00?l=ooooo`Go003o3Oooool1o`00007ooooo00000ol0003oooooooooo`0U
ooooo`Go003o4Oooool3ool000?ooooo1Ooo0006ooooo`Ooo`000_ooool:ool000Wooooo1Ooo000M
ooooo`?o003o1?ooool5ool00003oooooooo003oo`0000Ooo`001oooool9ool000_ooooo1_oo0000
0oooooooo`00ool00004ool000oooooo2?oo0005ooooo`Goo`001_ooool5o`00o`?ooooo1Ol00?l=
ooooo`Go003o1?ooool3o`00o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool02oooool3o`00
oaCooooo2?l00?l@ooooo`Goo`000oooool3ool000Kooooo2?oo0002ooooo`[oo`002Oooool5ool0
01Cooooo0ooo0002ooooo`?oo`002?ooool5ool00003oooooooo003oo`0000Ooo`002?ooool8ool0
00_ooooo3Ooo0009ooooo`?oo`001?ooool7ool000Gooooo1Ooo0006ooooo`Go003o0oooool5o`00
o`kooooo0ol00?l4ooooo`Go003o1Oooool1o`00007ooooo00000ol0003oooooooooo`0:ooooo`Go
003o4_ooool:o`00o`oooooo1Ooo000;ooooo`Woo`000oooool3ool00003oooooooo003oo`0000?o
o`002Oooool5ool000[ooooo0ooo0006ooooo`[oo`001oooool5ool000;ooooo1ooo000<ooooo`Go
o`003?ooool<ool000Sooooo1Ooo0005ooooo`Koo`001Oooool3ool000Oooooo1_l00?l3ooooo`?o
003o5_ooool5o`00o`Gooooo0Ol00001ooooo`0000?o0000ooooooooool02_ooool5o`00oa;ooooo
2_l00?l?ooooo`Koo`001_ooool3ool00003oooooooo003oo`0000Koo`002Oooool3ool000;ooooo
1Ooo0004ooooo`?oo`002_ooool5ool000Gooooo2_oo0008ooooo`?oo`001?ooool3ool000Oooooo
0ooo0005ooooo`Goo`002?oooolAool000Oooooo1Ooo0006ooooo`Koo`003oooool5o`00oacooooo
1Ol00?l5ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo1Ol00?lBooooo`[o003o4?oo
ool6ool000Cooooo2_oo000@ooooo`Soo`003_ooool6ool000Gooooo2_oo000Hooooo`Goo`001Ooo
ool3ool000Sooooo1ooo00000oooooooo`00ool00008ool000Gooooo1ooo0007ooooo`Goo`003ooo
ool5o`00oagooooo1Ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00_ooooo0ol00?lD
ooooo`So003o2?ooool3ool000Oooooo1Ooo0004ooooo`Goo`0000?oooooool00?oo00000ooo000?
ooooo`Woo`003?ooool7ool000Kooooo2?oo000Iooooo`Goo`004?oooolBool000Cooooo1ooo0008
ooooo`Goo`003?ooool3o`00o`04ooooool00?oo003oo`00o`[ooooo0ol00?lAooooo`Go003o1?oo
ool1o`00007ooooo00001?l0003oooooooooooooool3o`00oaoooooo1Ol00?l9ooooo`Goo`000_oo
ool3ool00003oooooooo003oo`0000?oo`001?ooool;ool000kooooo2_oo000<ooooo`Koo`001ooo
ool7ool00004oooooooo003oo`00ool001Kooooo1Ooo000@oooooa7oo`001?ooool6ool000_ooooo
0ooo000<ooooo`Go003o3?ooool5o`00o`Cooooo0ol00?l9ooooo`Go003o1?ooool1o`00007ooooo
00000ol0003oooooooooo`05o`00oakooooo1Ol00?l9ooooo`_oo`0000Coooooool00?oo003oo`00
1_ooool:ool000;ooooo0ooo0004ooooo`?oo`000_ooool:ool000cooooo1Ooo0008ooooo`coo`00
4Oooool3ool000;ooooo1_oo000?ooooo`Goo`0000?oooooool00?oo00001?oo0008ooooo`Koo`00
2_ooool5ool00004oooooooo003oo`00ool000Oooooo1Ol00?l<ooooo`Go003o0oooool5o`00o`So
oooo1Ol00?l4ooooo`7o00000Oooool00003o`000?oooooooooo00Go003o3Oooool3o`00o`kooooo
1Ol00?l6ooooo`?o003o2ooo0005ooooo`?oo`000oooool8ool000;ooooo1Ooo0002ooooo`Goo`00
00?oooooool00?oo00001ooo000>ooooo`Ooo`001_ooool;ool0013ooooo1Ooo0003ooooo`Goo`00
5?ooool9ool000Cooooo1_oo000;ooooo`[oo`001?ooool:o`00o`Wooooo1Ol00?l3ooooo`Go003o
2?ooool5o`00o`Cooooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?l<ooooo`Go003o3Ooo
ool5o`00o`Gooooo1Ol00?l;ool000?ooooo1Ooo0002ooooo`Goo`001Oooool5ool000;ooooo1Ooo
0002ooooo`Ooo`0000Coooooool00?oo003oo`002oooool8ool000Cooooo3?oo000@ooooo`Goo`00
0oooool5ool001Cooooo2_oo0003ooooo`Goo`0000Coooooool00?oo003oo`002?ooool:ool000?o
oooo3?l00?l9ooooo`?o003o1?ooool5o`00o`Gooooo0ol00?l01?oooooo003oo`00ool00?l5oooo
o`7o00000Oooool00004o`000?ooooooooooooooo`Ko003o2_ooool5o`00o`kooooo0ol00?l6oooo
o`Go003o0_ooool:ool000;ooooo1Ooo0003ooooo`?oo`0000Coooooool00?oo003oo`000_ooool5
ool000;ooooo1Ooo0004ooooo`goo`001_ooool9ool000?ooooo1_oo00000oooooooo`00ool00004
ool000Gooooo0ooo0008ooooo`Goo`000oooool5ool0017ooooo6_oo0008ooooo`?oo`0000?ooooo
ool00?oo00000ooo0002ooooo`Ko003o0_ooool5o`00oa7ooooo0ol00?l5ooooo`Go003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`03ooooo`Go003o2Oooool5o`00oaOooooo1Ol00?l3oooo
o`Woo`000_ooool5ool000?ooooo2?oo0002ooooo`?oo`001?ooool3ool000Gooooo3_oo0005oooo
o`Woo`000_ooool7ool00003oooooooo003oo`0000Goo`000oooool5ool000Sooooo0ooo0005oooo
o`Goo`001Oooool3ool000Oooooo2?oo00000oooooooo`00ool0000:ool00003oooooooo003oo`00
00?oo`001oooool:ool00003ooooool00?oo003o00Ko003o00?oooooo`00ool00?l00ol00?lHoooo
o`Ko003o2?ooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`Go003o2_ooool3o`00oaWo
oooo0ol00?l3ooooo`[oo`000_ooool6ool00003oooooooo003oo`0000Ooo`003Oooool3ool000;o
oooo0ooo00000oooooooo`00ool00007ool000Gooooo2?oo0003ooooo`Koo`000oooool6ool000;o
oooo1_oo000@ooooo`Goo`000oooool6ool000Kooooo1Ooo0005ooooo`_oo`0000?oooooool00?oo
00001Ooo0005ooooo`Ooo`000ol00?l00ooooooo003oo`00o`07o`00o`04ooooool00?oo003oo`00
oaWooooo1_l00?l8ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1Ol00?l[ooooo`[o
o`000_ooool7ool00003oooooooo003oo`0000Ooo`003?ooool5ool000Kooooo2?oo0005ooooo`Oo
o`0000?oooooool00?oo00001_oo0005ooooo`Goo`0000?oooooool00?oo00001Ooo000@ooooo`ko
o`001_ooool5ool000Oooooo2Ooo0002ooooo`Ooo`001?ooool6ool000ko003o5oooool3o`00o`?o
oooo1Ol00?l9ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo0ol00?l6ooooo`?o003o
6Oooool3o`00o`Oooooo1ooo00001Oooooooo`00ool00?oo003ooooo013oo`003Oooool5ool000So
oooo1Ooo0007ooooo`ooo`001_ooool;ool000Oooooo0ooo0008ooooo`goo`001oooool3ool000So
oooo2ooo0002ooooo`Goo`001Oooool5ool000Go003o00?oooooo`00ool00?l01_l00?lFooooo`Ko
003o0_ooool3o`00o`[ooooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool5o`00oaOooooo
1Ol00?l6ooooo`Goo`000_oooolBool000gooooo2?oo000>ooooo`?oo`000ooooolBool000Cooooo
2Ooo00001?ooooooo`00ool00?oo0003ooooo`Goo`002Oooool:ool0017ooooo3_oo00000ooooooo
o`00ool00003ool000Wooooo00?oo`00o`00ool00?l00ol00?l5ooooo`?o003o5oooool7o`00o`ko
oooo0Ol00001ooooo`0000?o0000ooooooooool03?ooool5o`00oaOooooo1Ol00?l7ooooo`?oo`00
0oooool5ool00004oooooooo003oo`00ool000;ooooo1ooo0008ooooo`goo`002_ooool8ool000;o
oooo1Ooo00000oooooooo`00ool0000;ool000?ooooo2?oo00000oooooooo`00ool00003ool000;o
oooo1Ooo0008ooooo`Woo`000_ooool5ool000_ooooo2Ooo00000oooooooo`00ool00003ool000;o
oooo1ooo0008ooooo`?o003o8?ooool7o`00o`kooooo0Ol00001ooooo`0000?o0000ooooool00?l0
0_l00?l:ooooo`Go003o2oooool3o`00o`Wooooo1Ol00?l=ooooo`Goo`001_ooool8ool000Kooooo
3_oo0009ooooo`ooo`000_ooool=ool000?ooooo1Ooo0004ooooo`Goo`000_ooool5ool000Oooooo
1ooo0004ooooo`Ooo`002_ooool7ool000?ooooo1Ooo0002ooooo`Soo`00:oooool7o`00o`gooooo
0Ol00001ooooo`0000?o0000o`00ool00?l00ol00?l5ooooo`?o003o0_ooool3o`00o`Cooooo0ol0
0?l4ooooo`Go003o2Oooool3o`00o`oooooo1?oo0007ooooo`Ooo`001_ooool>ool000Sooooo3_oo
0004ooooo`Goo`0000?oooooool00?oo00002?oo00000oooooooo`00ool00004ool000;ooooo1Ooo
0003ooooo`?oo`0000?oooooool00?oo00000ooo0002ooooo`Ooo`001?ooool7ool000[ooooo1ooo
00000oooooooo`00ool00004ool000?ooooo2?oo000Yooooo`?o003o00?oooooo`00ool00?l00ol0
0?l=ooooo`7o00000Oooool00003o`000?l00?oo003o00?o003o1?ooool5o`00o`Oooooo1Ol00?l3
ooooo`Go003o6oooool5ool000Sooooo1Ooo0006ooooo`Woo`0000Coooooool00?oo003oo`002?oo
ool?ool000Gooooo0ooo0005ooooo`Soo`000_ooool5ool000;ooooo0ooo0007ooooo`Ooo`0000?o
ooooool00?oo00001?oo0005ooooo`Ooo`002Oooool@ool000?ooooo1ooo000Oooooo`?o003o1_oo
ool:o`00o`gooooo0Ol00001ooooo`0000?o0000o`00ool00?l00ol00?l4ooooo`Go003o1oooool5
o`00o`?ooooo1Ol00?lHooooo`Soo`002Oooool3ool000Kooooo2Ooo0008ooooo`?oo`000_ooool6
ool000Cooooo1Ooo000@ooooo`Goo`000_ooool5ool00004oooooooo003oo`00ool000Sooooo1ooo
0002ooooo`?oo`002?ooool8ool000Oooooo1ooo00000oooooooo`00ool00006ool000Kooooo0ooo
000Oooooo`Go003o1Oooool5o`00o`04ooooool00?oo003oo`00o`kooooo0Ol00001ooooo`0000?o
0000o`00ool00?l01?l00?l3ooooo`Go003o1oooool5o`00o`?ooooo1Ol00?lGooooo`Woo`000_oo
ool3ool000cooooo1Ooo00000oooooooo`00ool00006ool000;ooooo1_oo00000oooooooo`00ool0
0003ool000Kooooo0ooo000Aoooooa7oo`000oooool3ool00003oooooooo003oo`0000Goo`004Ooo
ool5ool000Kooooo1Ooo0002ooooo`coo`009Oooool5o`00o`Gooooo1Ol00?lBooooo`7o00000Ooo
ool00003o`000?l00?oo003o00Go003o0_ooool5o`00o`Sooooo0ol00?l3ooooo`Go003o6?ooool8
ool000;ooooo1Ooo000;oooooacoo`000_ooool8ool0013ooooo2ooo00000oooooooo`00ool00003
ool000;ooooo1Ooo00000oooooooo`00ool00003ool001;ooooo1Ooo0007ooooo`?oo`000oooool=
ool000Gooooo0ooo000Looooo`Go003o1_ooool3o`00o`Wooooo0ol00?l7ooooo`7o00000Oooool0
0003o`000?l00?oo003o00Go003o0oooool3o`00o`kooooo1_l00?lHooooo`Koo`000oooool6ool0
00Sooooo7_oo0002ooooo`_oo`003oooool8ool000?ooooo3?oo000Booooo`?oo`000oooool5ool0
00Oooooo0ooo0003ooooo`goo`001?ooool5ool0017ooooo0ol00?l8ooooo`?o003o2_ooool3o`00
o`Gooooo1Ol00?l6ooooo`7o00000Oooool00003o`000?oooooo003o00Go003o2_ooool3o`00o`Oo
oooo1_l00?lHooooo`?o003o0_oo0004ooooo`Koo`001_oooolMool00005oooooooo003oo`00ool0
0?ooool03?oo0003ooooo`?oo`000_ooool3ool000?ooooo2_oo0002ooooo`_oo`003?ooool3ool0
00;ooooo1Ooo0002ooooo`Coo`001oooool5ool000?ooooo3?oo0004ooooo`Goo`004?ooool5o`00
oa?ooooo1Ol00?l00ooooooo003oo`00o`06o`00o`Kooooo0Ol00001ooooo`0000Co0000oooooooo
oooooooo0ol00?l:ooooo`Go003o1_ooool5o`00oaSooooo1Ol00?l5ooooo`Goo`001_ooool7ool0
00?ooooo1Ooo0002ooooo`?oo`0000?oooooool00?oo00006?oo0002ooooo`[oo`000oooool:ool0
00Cooooo1ooo000<ooooo`Goo`0000?oooooool00?oo00002Ooo0007ooooo`Goo`002?ooool6ool0
00Gooooo1Ooo0008ooooo`?o003o0_ooool8o`00oa?ooooo3_l00?l6ooooo`7o00000Oooool00003
o`000?oooooooooo00kooooo1Ol00?l7ooooo`?o003o6Oooool5o`00o`Kooooo0ooo0004oooooa7o
o`001oooool8ool00003oooooooo003oo`0000Woo`0000?oooooool00?oo00000ooo0002ooooo`_o
o`001oooool5ool000Cooooo1Ooo000>oooooaCoo`001?ooool6ool000Sooooo0ooo0008ooooo`?o
o`002?ooool>o`00o`Gooooo0ol00?l;ooooo`go003o1oooool1o`00007ooooo00000ol0003ooooo
ooooo`0>ooooo`Go003o3_ooool3o`00oa;ooooo1Ol00?l<oooooa;oo`002?ooool3ool000Gooooo
4?oo0002ooooo`goo`001_ooool5ool000Gooooo0ooo000?oooooaGoo`001?ooool6ool000[ooooo
0ooo000@ooooo`go003o1Oooool5o`00o`_ooooo0ol00?l00ooooooo003oo`00o`03o`00o`[ooooo
0Ol00001ooooo`0000?o0000ooooooooool03oooool3o`00o`kooooo1ol00?l>ooooo`Oo003o2ooo
oolBool000Oooooo0ooo0007ooooo`?oo`0000?oooooool00?oo00002Ooo0002ooooo`Koo`0000?o
ooooool00?oo00001Ooo0005ooooo`Goo`006?oooolDool000Gooooo1Ooo0004ooooo`?oo`000_oo
ool5ool000oooooo2_l00?l8ooooo`Go003o4?ooool3o`00o`_ooooo0Ol00001ooooo`0000?o0000
ooooooooool08?ooool8o`00o`cooooo2?l00?l8oooooaCoo`001oooool5ool000_ooooo2_oo0002
ooooo`Koo`000_ooool6ool000Gooooo1Ooo000Hooooo`Soo`0000Coooooool00?oo003oo`000ooo
ool6ool000Cooooo1Ooo0003ooooo`Goo`0000?oooooool00?oo00000ooo0008ooooo`?o003o1Ooo
ool8o`00o`Wooooo1Ol00?lCooooo`?o003o2?ooool1o`00007ooooo00000ol0003oooooooooo`0?
ooooo`?o003o0oooool3o`00o`Sooooo2?l00?l<ooooo`So003o0oooool3o`00o`03oooooooo003o
o`0000coo`0000Coooooool00?oo003oo`002_ooool5ool000gooooo2?oo0003ooooo`Goo`000ooo
ool5ool000Gooooo1Ooo0004ooooo`?oo`003?ooool3ool000;ooooo1ooo0009ooooo`Goo`001Ooo
ool3ool000Cooooo1Ooo00000oooooooo`00ool00003ool000Oooooo1Ol00?l7ooooo`Go003o00?o
ooooo`00ool00?l01?l00?l3ooooo`?o003o4oooool5o`00o`Oooooo0Ol00001ooooo`0000Co0000
oooooooooooooooo0ol00?l:ooooo`Go003o00?oooooo`00ool00?l00ol00?l8ooooo`Oo003o3?oo
ool7o`00o`?ooooo1Ol00?l=ool000_ooooo0ooo00000oooooooo`00ool00003ool000cooooo2?oo
0005ooooo`?oo`001Oooool3ool000Oooooo0ooo0004ooooo`Goo`002_ooool;ool000_ooooo1_oo
000;ooooo`Goo`000_ooool3ool000Sooooo1Ol00?l7ooooo`go003o6?ooool5o`00o`Oooooo0Ol0
0001ooooo`0000?o0000ooooooooool01Ol00?l9ooooo`Go003o00?oooooo`00ool00?l00ol00?l5
ooooo`?o003o0_ooool4o`00o`Kooooo0ol00?l5ooooo`?o003o1_ooool5o`00o`goo`001Oooool3
ool000;ooooo1Ooo00001?ooooooo`00ool00?oo0006ooooo`?oo`001?ooool5ool000Gooooo0ooo
000:ooooo`?oo`0000Coooooool00?oo003oo`001Oooool8ool000[ooooo2_oo000=ooooo`Koo`00
2_ooool5ool000gooooo1Ol00?l8ooooo`?o003o00?oooooo`00ool00?l01_l00?l2ooooo`?o003o
2?ooool8o`00o`?ooooo1Ol00?l7ooooo`7o00000Oooool00003o`000?oooooo003o00Go003o1?oo
ool3o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Cooooo2_l00?l5ooooo`Go003o3Ooo
ool5o`00o`03oooooooo003oo`0000Goo`0000Coooooool00?oo003oo`001Oooool5ool00003oooo
oooo003oo`0000?oo`002Oooool5ool000?ooooo1Ooo0004ooooo`Goo`002?ooool9ool000?ooooo
2Ooo00000oooooooo`00ool00003ool000;ooooo2Ooo0005ooooo`?oo`002Oooool5ool000Wooooo
1_oo000>ooooo`?o003o3?ooool9o`00o`03ooooool00?oo003o00?o003o1_ooool:o`00o`;ooooo
1Ol00?l7ooooo`7o00000Oooool00003o`000?oooooo003o00Go003o0oooool5o`00o`;ooooo0ol0
0?l3ooooo`?o003o1Oooool:o`00o`Cooooo1_l00?l>ooooo`?o003o1?ooool5ool000Wooooo1Ooo
00000oooooooo`00ool00003ool000Wooooo3Ooo0004ooooo`Goo`002?ooool9ool000?ooooo2?oo
00000oooooooo`00ool0000?ool000Cooooo1ooo0006ooooo`Goo`002?ooool6ool001gooooo2Ol0
0?l2ooooo`Go003o1_ooool:o`00o`;ooooo1Ol00?l7ooooo`7o00000Oooool00003o`000?oooooo
003o00Go003o0oooool5o`00oa3ooooo3Ol00?l00ooooooo003oo`00o`06o`00o`[ooooo0ol00?l4
ooooo`Ooo`002Oooool6ool00004oooooooo003oo`00ool000[ooooo3Ooo0004ooooo`Goo`0000Co
ooooool00?oo003oo`001?oooolAool000Cooooo3?oo00001?ooooooo`00ool00?oo0005ooooo`So
o`001_ooool3ool000Kooooo2_oo000Looooo`Go003o1_ooool5o`00o`Kooooo2_l00?l2ooooo`Go
003o1oooool1o`00007ooooo00000ol0003oooooooooo`05o`00o`?ooooo2?l00?l>ooooo`?o003o
0_oooolAo`00o`Gooooo2?l00?l2ooooo`Soo`0000Coooooool00?oo003oo`001_ooool6ool000go
oooo3?oo0006ooooo`?oo`0000?oooooool00?oo00000ooo0004ooooo`ooo`001Oooool<ool000Wo
oooo2?oo000>ooooo`goo`006_ooool5o`00o`Oooooo0ol00?l8ooooo`So003o1?ooool3o`00o`So
oooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?l4ooooo`_o003o4_ooool5o`00o`03oooo
ool00?oo003o00Ko003o0_ooool;o`00o`;ooooo3Ooo0005ooooo`Koo`000oooool4ool000Kooooo
2Ooo000=ooooo`Goo`001Oooool5ool00003oooooooo003oo`0000Woo`000oooool5ool00003oooo
oooo003oo`0000;oo`002oooool<ool000Wooooo3_oo0002ooooo`?o003o5Oooool3o`00oaOooooo
0ol00?l@ooooo`7o00000Oooool00004o`000?ooooooooooooooo`?o003o2?ooool9o`00oa7ooooo
1Ol00?l4ooooo`Go003o00?oooooo`00ool00?l02_l00?l2ooooo`koo`001?ooool6ool000;ooooo
1_oo0005ooooo`Woo`003Oooool5ool000Gooooo1Ooo00000oooooooo`00ool0000:ool00003oooo
oooo003oo`0000?oo`0000?oooooool00?oo00000ooo000=ooooo`_oo`002?ooool5ool000;ooooo
1ooo00000ooooooo003oo`00o`03o`00o`Cooooo0ol00?ldooooo`?o003o0oooool1o`00007ooooo
00000ol0003oooooooooo`0<ooooo`Wo003o0_ooool3o`00o`gooooo0ol00?l6ooooo`?o003o0_oo
ool;o`00o`Cooooo1_oo00000oooooooo`00ool00004ool000Gooooo1Ooo0002ooooo`Koo`001_oo
ool8ool000cooooo1Ooo0006oooooa;oo`0000?oooooool00?oo00002Ooo000<ooooo`coo`002Ooo
ool5ool00003oooooooo003oo`0000Goo`001_l00?l3ooooo`Go003o<_ooool5o`00o`;ooooo0Ol0
0001ooooo`0000?o0000ooooooooool01oooool3o`00o`?ooooo2?l00?l00ooooooo003oo`00o`03
o`00oa[ooooo1ol00?l@ooooo`Goo`001Oooool5ool000;ooooo1_oo0007ooooo`Ooo`001_ooool3
ool000?ooooo1Ooo00001?ooooooo`00ool00?oo0002oooooa;oo`0000?oooooool00?oo00002Ooo
000<ooooo`coo`001oooool7ool00003oooooooo003oo`0000Coo`0000?oooooo`00ool00?l01?l0
0?l3ooooo`Go003o<_ooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5
o`00o`03ooooool00?oo003o00Ko003o0_ooool5o`00oa_ooooo0ol00?lDooooo`?oo`001_ooool5
ool000?ooooo1?oo0007ooooo`Woo`001?ooool5ool000;ooooo2_oo0002ooooo`?oo`0000?ooooo
ool00?oo00002ooo0002ooooo`Woo`003Oooool;ool000;ooooo0ooo0002ooooo`Woo`0000Cooooo
ool00?oo003oo`000oooool5o`00o`Cooooo1Ol00?l3ooooo`?o003o9?ooool3o`00o`Gooooo1Ol0
0?l2ooooo`7o00000Oooool00003o`000?oooooooooo00Kooooo1Ol00?l00ooooooo003oo`00o`03
o`00o`Gooooo1Ol00?lIooooo`?o003o2?ooool3o`00oaGooooo0ooo000?ooooo`Woo`000oooool6
ool000?ooooo0ooo00000oooooooo`00ool00003ool000Oooooo2ooo0003ooooo`Soo`003_ooool5
ool000Oooooo1Ooo00000oooooooo`00ool00008ool000Oooooo0ol00?l5ooooo`Go003o0_ooool5
o`00ob;ooooo1Ol00?l5ooooo`?o003o0oooool1o`00007ooooo00000ol0003oooooooooo`06oooo
o`Go003o00?oooooo`00ool00?l00ol00?l6ooooo`?o003o4_ooool3o`00o`Cooooo1Ol00?l6oooo
o`Go003o6Oooool3ool000[ooooo4_oo0002ooooo`?oo`000_ooool5ool000_ooooo2?oo0002oooo
o`Woo`002Oooool=ool000?ooooo4?oo000?ooooo`Go003o0_ooool5o`00ob;ooooo1ol00?l9oooo
o`7o00000Oooool00003o`000?oooooooooo00Oooooo2Ol00?lKooooo`Go003o0oooool5o`00o`Ko
oooo1Ol00?l4ooooo`?o003o4Oooool5ool000Sooooo4_oo0002ooooo`Goo`000_ooool5ool00004
oooooooo003oo`00ool000Kooooo2?oo0003ooooo`[oo`001_ooool?ool000;ooooo4?oo00001?oo
oooo003oo`00ool00?l<ooooo`?o003o0oooool5o`00oaWooooo0ol00?l6ooooo`So003o2?ooool1
o`00007ooooo00000ol0003oooooooooo`07ooooo`Oo003o7Oooool5o`00o`?ooooo1Ol00?l3oooo
o`So003o0oooool5o`00oa3ooooo2?oo0005oooooa7oo`000oooool5ool000?ooooo2Ooo0006oooo
o`Soo`001?ooool9ool00003oooooooo003oo`00017oo`000oooool>ool00003ooooool00?oo003o
00?o003o4_ooool3o`00oaWooooo1Ol00?l6ooooo`Oo003o2?ooool1o`00007ooooo00000ol0003o
ooooooooo`06ooooo`So003o7Oooool5o`00o`Cooooo0ol00?l3ooooo`So003o1?ooool5o`00oa3o
oooo2Ooo0004ooooo`koo`001_ooool5ool000?ooooo2Ooo0005ooooo`Woo`001_oooolKool000;o
oooo3Ooo0003ooooo`Go003o5oooool3o`00oaCooooo1Ol00?l7ooooo`Ko003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`06ooooo`[o003o6Oooool6o`00o`04ooooool00?oo003oo`00o`Oo
oooo1Ol00?l7ooooo`Go003o4Oooool8ool000Gooooo3Ooo0007ooooo`Koo`0000?oooooool00?oo
00001ooo0005ooooo`Woo`002?oooolCool000;ooooo0ooo0003ooooo`Soo`0000Coooooool00?oo
003oo`001?ooool5o`00o`oooooo0ol00?l4ooooo`Go003o4oooool5o`00o`Kooooo2_l00?l5oooo
o`7o00000Oooool00003o`000?oooooooooo00Kooooo2ol00?lGooooo`co003o1_ooool5o`00o`;o
oooo0ol00?l3ooooo`?o003o5Oooool6ool000Kooooo1_oo00000oooooooo`00ool00002ool000Wo
oooo1Ooo00001Oooooooo`00ool00?oo003ooooo00Goo`001?ooool8ool000[ooooo0ooo00000ooo
ooooo`00ool00004ool000;ooooo1Ooo0005ooooo`?oo`0000?oooooool00?oo00001_oo0003oooo
o`?o003o0oooool3o`00o`oooooo1Ol00?l3ooooo`Go003o5?ooool3o`00o`Oooooo3Ol00?l2oooo
o`7o00000Oooool00003o`000?oooooooooo00Oooooo0ol00?l2ooooo`Go003o00Coooooo`00ool0
0?oo003o4oooool<o`00o`Oooooo0ol00?l2ooooo`Go003o6_ooool7ool000Kooooo2ooo0008oooo
o`Goo`001Oooool5ool000Gooooo1Ooo0005ooooo`?oo`002Oooool4ool000cooooo1Ooo00000ooo
ooooo`00ool00005ool000;ooooo1Ol00?lDooooo`Go003o0oooool5o`00oa;ooooo1_l00?l6oooo
o`ko003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0<ooooo`[o003o4_ooool<o`00o`co
oooo1Ol00?l?ooooo`Co003o1oooool8ool000Kooooo2_oo0004ooooo`?oo`0000?oooooool00?oo
00001_oo0002ooooo`Goo`001Oooool6ool000?ooooo1Ooo000@ooooo`?oo`001Oooool5ool000?o
oooo1Ooo0002ooooo`Ko003o4oooool5o`00o`Cooooo0ol00?lBooooo`Oo003o1oooool=o`00o`7o
oooo0Ol00001ooooo`0000?o0000ooooooooool03Oooool3o`00o`03ooooool00?oo003o00?o003o
4oooool5o`00o`;ooooo0ol00?l=ooooo`Go003o3_ooool6o`00o`Kooooo2?oo0007ooooo`Woo`00
0oooool5ool00003oooooooo003oo`0000Koo`000_ooool3ool000Kooooo1_oo0003ooooo`Goo`00
3?ooool8ool000Cooooo1Ooo0004ooooo`?oo`000oooool7o`00oa?ooooo0ol00?l@ooooo`?o003o
1oooool7o`00o`[ooooo2_l00?l1ooooo`7o00000Oooool00003o`000?oooooooooo017ooooo1Ol0
0?l2ooooo`?o003o5oooool3o`00o`cooooo0ol00?l?ooooo`Ko003o0oooool;ool000Oooooo2?oo
0003ooooo`Koo`001?ooool5ool00004oooooooo003oo`00ool000Oooooo1_oo0003ooooo`Goo`00
1_ooool3ool000;ooooo2Ooo0005ooooo`?oo`002oooool7o`00o`gooooo0ol00?lBooooo`So003o
1_ooool6o`00o`_ooooo1Ol00?l01?oooooo003oo`00ool00?l2ooooo`7o00000Oooool00003o`00
0?oooooooooo017ooooo1Ol00?l00ooooooo003oo`00o`03o`00oaGooooo1Ol00?lMooooo`Ko003o
0_ooool=ool00004oooooooo003oo`00ool000?ooooo1Ooo0003ooooo`Soo`001?ooool:ool000Ko
oooo1Ooo0003ooooo`Goo`001_ooool5ool00003oooooooo003oo`0000Ooo`000oooool3ool000go
oooo1ol00?l2ooooo`?o003o1oooool5o`00oa3ooooo2ol00?l5ooooo`?o003o3Oooool5o`00o`Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool3o`00o`Wooooo0ol00?l2ooooo`Go003o
1?ooool3o`00o`kooooo1Ol00?l4ooooo`Go003o5Oooool4o`00o`?ooooo4_oo0002ooooo`Goo`00
0_ooool8ool000Kooooo0ooo00000oooooooo`00ool00003ool000Oooooo0ooo0003ooooo`Goo`00
1oooool5ool00003oooooooo003oo`0000Koo`000oooool5ool000cooooo1_l00?l2ooooo`Go003o
1_ooool5o`00oa3ooooo3?l00?lDooooo`Go003o1_ooool1o`00007ooooo00001?l0003ooooooooo
ooooool3o`00o`03ooooool00?oo003o00?o003o3Oooool5o`00o`?ooooo1Ol00?l=ooooo`Oo003o
00?oooooo`00ool00?l01Ol00?lKoooooa;oo`000_ooool5ool000;ooooo1ooo0007ooooo`?oo`00
00?oooooool00?oo00000ooo0005ooooo`?oo`001Oooool5ool000Oooooo1Ooo0002ooooo`Koo`00
1?ooool5ool000gooooo0ol00?l4ooooo`Go003o1_ooool5o`00oa3ooooo3?l00?lDooooo`Go003o
1_ooool1o`00007ooooo00000ol0003oooooooooo`0;o`00o`gooooo0ol00?l4ooooo`Go003o3_oo
ool>o`00oacooooo4_oo00000oooooooo`00ool00003ool000;ooooo2_oo0003ooooo`Goo`0000?o
ooooool00?oo00002ooo0004ooooo`Goo`002?ooool3ool000Gooooo0ooo0005ooooo`Goo`005?oo
ool5o`00o`Oooooo1Ol00?l@ooooo`?o003o0oooool5o`00o`gooooo0ol00?l5ooooo`?o003o1ooo
ool1o`00007ooooo00000ol0003oooooooooo`0;o`00oaCooooo1Ol00?l>ooooo`ko003o7oooool@
ool00004oooooooo003oo`00ool000Cooooo2_oo0002ooooo`Goo`0000?oooooool00?oo00002ooo
0005ooooo`?oo`0000Coooooool00?oo003oo`001?ooool5ool000gooooo0_oo0003o`00oaCooooo
0ol00?l9ooooo`Go003o5_ooool3o`00o`gooooo1Ol00?l>ooooo`7o00000Oooool00003o`000?oo
oooooooo00Go003o00?oooooo`00ool00?l00ol00?l9ooooo`?o003o2Oooool3o`00o`oooooo3Ol0
0?lJooooo`?o003o1_ooool7ool00003oooooooo003oo`0000?oo`002Oooool9ool000;ooooo1Ooo
00000oooooooo`00ool0000<ool000Oooooo1Ooo0003ooooo`Goo`003_ooool5o`00oaoooooo1Ol0
0?lUooooo`Ko003o3_ooool1o`00007ooooo00001?l0003oooooooooooooool3o`00o`?ooooo0ol0
0?l9ooooo`Go003o5_ooool3o`00o`;ooooo2?l00?lMooooo`Go003o3Oooool5ool000Wooooo2Ooo
0003ooooo`?oo`000oooool=ool000Oooooo1Ooo0003ooooo`Goo`003_ooool5o`00oaoooooo1Ol0
0?lUooooo`Ko003o3_ooool1o`00007ooooo00000ol0003oooooooooo`0Cooooo`Go003o5Oooool5
o`00o`Gooooo0ol00?lNooooo`Go003o3Oooool3o`00o`?oo`002?ooool9ool000Cooooo0ooo0006
ooooo`Woo`001Oooool7ool000Cooooo1Ooo000=ooooo`Go003o8?ooool3o`00obKooooo1Ol00?l?
ooooo`7o00000Oooool00003o`000?oooooooooo00[ooooo0ol00?l6ooooo`Go003o5Oooool5o`00
obCooooo1ol00?l<ooooo`Go003o0ooo0008ooooo`Soo`000oooool5ool000Sooooo1Ooo0005oooo
o`Ooo`001_ooool5ool000Wooooo0ol00?l01?oooooo003oo`00ool00?m;ooooo`Go003o3_ooool1
o`00007ooooo00000ol0003oooooooooo`09ooooo`Go003o1_ooool3o`00oaKooooo1Ol00?lQoooo
o`Wo003o3Oooool5o`00o`?oo`002_ooool5ool000Cooooo1Ooo0009ooooo`?oo`001Oooool6ool0
00Sooooo1Ooo0008ooooo`Go003o6?ooool3o`00o`_ooooo0ol00?lVooooo`Go003o3Oooool1o`00
007ooooo00000ol0003oooooooooo`09ooooo`Go003o8?ooool3o`00ob7ooooo2?l00?l?ooooo`Go
003o0ooo000:ooooo`Goo`001?ooool5ool0017ooooo1_oo0008ooooo`Goo`002?ooool5o`00o`Oo
oooo0ol00?l=ooooo`Go003o2Oooool5o`00oaSooooo0ol00?l:ooooo`Go003o3Oooool1o`00007o
oooo00000ol0003oooooooooo`09ooooo`Go003o;oooool3o`00oa;ooooo2?l00?l8ooooo`?o003o
1?ooool5o`00o`;oo`002oooool5ool000Gooooo0ooo0003ooooo`?oo`002Oooool8ool000[ooooo
0ooo0009ooooo`Go003o1_ooool5o`00o`Kooooo0ol00?l3ooooo`Go003o2Oooool5o`00oaOooooo
1Ol00?l9ooooo`Go003o3Oooool1o`00007ooooo00000ol0003oooooooooo`05ooooo`?o003o0_oo
ool3o`00oboooooo1Ol00?lAooooo`Oo003o0oooool3o`00o`;ooooo1Ol00?l3ooooo`Go003o1?oo
ool3o`00o`Oooooo0ooo000;ooooo`Goo`000ol00?l4ooooo`Soo`006?ooool3o`00o`Oooooo1Ol0
0?l5ooooo`Go003o0_ooool5o`00o`Wooooo1Ol00?lGooooo`Go003o2_ooool3o`00o`kooooo0Ol0
0001ooooo`0000?o0000ooooooooool01?ooool5o`00o`Wooooo0ol00?l@ooooo`?o003o2?ooool3
o`00o`Wooooo1Ol00?lBooooo`?o003o1Oooool5o`00o`03ooooool00?oo003o00?o003o1?ooool3
o`00o`Cooooo2?l00?lAooooo`Coo`001Ol00?l3ooooo`Goo`006_ooool5o`00o`Kooooo1Ol00?l5
ooooo`Go003o0oooool3o`00o`_ooooo0ol00?lHooooo`Go003o6oooool1o`00007ooooo00000ol0
003oooooooooo`04ooooo`Go003o2?ooool5o`00o`kooooo1Ol00?l6ooooo`Go003o2?ooool5o`00
o`[ooooo0ol00?l=ooooo`Go003o00?oooooo`00ool00?l00ol00?l;ooooo`Wo003o4?ooool4ool0
00Go003o0oooool5ool000cooooo0ol00?l;ooooo`Go003o1oooool3o`00o`;ooooo0ol00?l00ooo
oooo003oo`00o`03o`00oaOooooo0ol00?lCooooo`?o003o1?ooool3o`00oaGooooo0Ol00001oooo
o`0000?o0000ooooooooool00_ooool7o`00o`Sooooo1Ol00?l;ooooo`So003o1_ooool5o`00o`Wo
oooo0ol00?l:ooooo`Go003o1_ooool3o`00o`?ooooo1Ol00?l2ooooo`?o003o3?ooool9o`00oa7o
oooo0ooo0005o`00o`Cooooo0ooo0008ooooo`?o003o00?oooooo`00ool00?l00ol00?l4ooooo`?o
003o0oooool5o`00o`_ooooo1Ol00?l01?oooooo003oo`00ool00?l4ooooo`?o003o4?ooool5o`00
oa?ooooo0ol00?l2ooooo`Go003o5?ooool1o`00007ooooo00001?l0003oooooooooooooool7o`00
o`Wooooo1Ol00?l:ooooo`Wo003o1_ooool5o`00oaCooooo1ol00?l5ooooo`Go003o0oooool3o`00
o`Gooooo0ol00?l;ooooo`So003o4oooool5o`00o`oooooo2ol00?l2ooooo`Go003o0oooool3o`00
o`cooooo1_l00?l6ooooo`Go003o3Oooool7o`00oa;ooooo1Ol00?l00ooooooo003oo`00o`03o`00
oaCooooo0Ol00001ooooo`0000Co0000oooooooooooooooo1Ol00?l<ooooo`?o003o2oooool8o`00
o`Sooooo0ol00?lDooooo`So003o1Oooool5o`00o`[ooooo1Ol00?l<ooooo`Ko003o4oooool5o`00
o`;ooooo0ol00?l:ooooo`co003o00?oooooo`00ool00?l00ol00?lBooooo`Ko003o1_ooool5o`00
o`cooooo2?l00?lBooooo`Go003o00?oooooo`00ool00?l00ol00?lDooooo`7o00000Oooool00004
o`000?ooooooooooooooo`Go003o6?ooool7o`00ob;ooooo1ol00?l6ooooo`Go003o2_ooool5o`00
o`cooooo1ol00?lBooooo`Go003o00?oooooo`00ool00?l00ol00?l5ooooo`?o003o00?oooooo`00
ool00?l00ol00?l00ooooooo003oo`00o`04o`00o`03ooooool00?oo003o00?o003o4oooool5o`00
o`Kooooo1Ol00?l<ooooo`So003o4_ooool:o`00o`oooooo0ol00?l3ooooo`7o00000Oooool00003
o`000?oooooooooo00;ooooo0ol00?lHooooo`[o003o8?ooool6o`00o`Oooooo1Ol00?l:ooooo`Go
003o2oooool8o`00o`Oooooo0ol00?l6ooooo`Ko003o0_ooool5o`00o`Cooooo1Ol00?l00ooooooo
003oo`00o`02o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`03o`00oaCooooo0ol00?l8ooooo`?o
003o1?ooool3o`00o`Kooooo2?l00?lCooooo`Oo003o4?ooool5o`00o`;ooooo0Ol00001ooooo`00
00?o0000ooooooooool07Oooool5o`00o`03ooooool00?oo003o00?o003o8?ooool5o`00o`Sooooo
0ol00?l<ooooo`?o003o0_ooool3o`00o`Oooooo2?l00?l6ooooo`Go003o1?ooool5o`00o`Cooooo
1Ol00?l4ooooo`Go003o00?oooooo`00ool00?l00ol00?l2ooooo`?o003o0oooool3o`00obKooooo
1Ol00?l6ooooo`Oo003o5Oooool5o`00oa3ooooo1Ol00?l2ooooo`7o00000Oooool00003o`000?oo
oooooooo00cooooo0ol00?l>ooooo`Go003o00?oooooo`00ool00?l00ol00?lBooooo`?o003o2_oo
ool5o`00o`oooooo0ol00?l:ooooo`Go003o1_ooool7o`00o`Oooooo1Ol00?l4ooooo`Go003o1Ooo
ool3o`00o`Gooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Oooooo1Ol00?lAooooo`?o003o4Ooo
ool5o`00o`Wooooo0ol00?lFooooo`Go003o4?ooool5o`00o`;ooooo0Ol00001ooooo`0000?o0000
ooooooooool01?ooool3o`00o`Cooooo1Ol00?l=ooooo`Go003o00?oooooo`00ool00?l00ol00?lA
ooooo`Go003o00Coooooo`00ool00?oo003o1?ooool5o`00o`oooooo1Ol00?l9ooooo`Go003o1ooo
ool3o`00o`[ooooo1Ol00?l4ooooo`Go003o3Oooool5o`00o`03ooooool00?oo003o00?o003o1ooo
ool5o`00o`gooooo2?l00?l4ooooo`?o003o2Oooool5o`00ob?ooooo0ol00?lBooooo`?o003o0ooo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooo`Go003o0oooool5o`00o`gooooo1Ol00?l2
ooooo`?o003o00Coooooo`00ool00?oo003o3_ooool:o`00o`?ooooo1Ol00?l5ooooo`Ko003o1?oo
ool5o`00o`Wooooo1Ol00?l9ooooo`?o003o2Oooool3o`00o`Kooooo0ol00?l01?oooooo003oo`00
ool00?l3ooooo`?o003o1?ooool5o`00o`;ooooo0ol00?l8ooooo`So003o2Oooool9o`00o`?ooooo
1Ol00?l3ooooo`?o003o0oooool3o`00obSooooo0ol00?lDooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo1Ol00?l3ooooo`Go003o3Oooool5o`00o`Gooooo1Ol00?l=ooooo`[o003o0ooo
ool5o`00o`Cooooo2?l00?l3ooooo`Go003o2_ooool3o`00o`Wooooo1Ol00?lDooooo`Go003o00?o
ooooo`00ool00?l00ol00?l3ooooo`Go003o3_ooool8o`00o`Sooooo2Ol00?l3ooooo`Go003o0_oo
ool;o`00obKooooo1Ol00?lCooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo1Ol00?l4
ooooo`?o003o3oooool3o`00o`Kooooo1Ol00?l>ooooo`?o003o00?oooooo`00ool00?l00ol00?l4
ooooo`?o003o1Oooool8o`00o`Cooooo0ol00?l9ooooo`?o003o2oooool5o`00oaCooooo1Ol00?l0
0ooooooo003oo`00o`03o`00o`Cooooo0ol00?lBooooo`Go003o2?ooool8o`00o`Cooooo1Ol00?l2
ooooo`_o003o9_ooool5o`00oa?ooooo0Ol00001ooooo`0000?o0000ooooooooool01?ooool3o`00
ob3ooooo1Ol00?l8ooooo`?o003o2?ooool3o`00o`_ooooo2_l00?l7ooooo`Go003o0oooool5o`00
o`[ooooo1Ol00?lDooooo`Go003o00?oooooo`00ool00?l00ol00?lIooooo`Go003o2Oooool3o`00
o`Wooooo4Ol00?l9ooooo`?o003o6_ooool5o`00o`Cooooo0ol00?l<ooooo`7o00000Oooool00003
o`000?oooooooooo01Oooooo0ol00?l01?oooooo003oo`00ool00?l:ooooo`?o003o1Oooool8o`00
oaCooooo2_l00?l7ooooo`Oo003o0_ooool5o`00o`_ooooo0ol00?lFooooo`?o003o0oooool3o`00
oaWooooo1ol00?lFooooo`ko003o2Oooool5o`00oa;ooooo0ol00?l4ooooo`Go003o0oooool5o`00
o`Oooooo0ol00?l1ooooo`7o00000Oooool00003o`000?oooooooooo01Kooooo3?l00?l=ooooo`Wo
003o5?ooool5o`00o`cooooo1ol00?l2ooooo`Go003o9?ooool3o`00oakooooo2?l00?l4ooooo`?o
003o3oooool5o`00o`Cooooo0ol00?l;ooooo`Go003o4Oooool5o`00o`?ooooo1Ol00?l3ooooo`Go
003o1_ooool5o`00o`7o00000Oooool00003o`000?oooooooooo01Kooooo3Ol00?l<ooooo`Wo003o
5?ooool5o`00o`cooooo1ol00?l3ooooo`?o003o1Oooool6o`00oaWooooo1Ol00?lMooooo`So003o
0oooool5o`00o`;ooooo0ol00?l9ooooo`Go003o4_ooool5o`00oa7ooooo1Ol00?l4ooooo`?o003o
1?ooool5o`00o`Kooooo1Ol00?l1o`00007ooooo00000ol0003oooooooooo`0Fooooo`go003o3?oo
ool8o`00oaKooooo0ol00?l>ooooo`Go003o2oooool8o`00o`;ooooo0ol00?lCooooo`Go003o3Ooo
ool3o`00o`gooooo1ol00?l4ooooo`Go003o00?oooooo`00ool00?l01?l00?l8ooooo`?o003o5?oo
ool3o`00o`Oooooo0ol00?l8ooooo`Go003o1Oooool3o`00o`Cooooo0ol00?l6ooooo`Ko003o0Ol0
0001ooooo`0000?o0000ooooooooool05oooool<o`00o`gooooo0ol00?lCooooo`?o003o6_ooool3
o`00o`Sooooo3_l00?lBooooo`Go003o3?ooool5o`00o`gooooo0ol00?l7ooooo`Go003o00?ooooo
o`00ool00?l01Ol00?l@ooooo`?o003o1_ooool3o`00o`?ooooo0ol00?l5ooooo`Go003o2?ooool3
o`00o`Gooooo1Ol00?l<ooooo`Go003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0Hoooo
o`Go003o0_ooool3o`00o`Gooooo0ol00?lEooooo`?o003o0oooool5o`00o`Sooooo0ol00?l=oooo
o`Go003o1oooool>o`00oa;ooooo1Ol00?l<ooooo`Go003o6?ooool3o`00o`;ooooo1ol00?l7oooo
o`?o003o1Oooool5o`00o`Cooooo1Ol00?l00ooooooo003oo`00o`03o`00o`Cooooo1Ol00?l@oooo
o`So003o2Oooool5o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool01Oooool3o`00oa3o
oooo1Ol00?l9ooooo`Go003o4oooool5o`00o`;ooooo1Ol00?l7ooooo`Ko003o2oooool5o`00o`So
oooo3Ol00?lBooooo`Go003o2oooool6o`00oaOooooo0ol00?l4ooooo`Ko003o1_ooool5o`00o`03
ooooool00?oo003o00Ko003o1?ooool5o`00o`03ooooool00?oo003o00?o003o1?ooool5o`00o`[o
oooo0ol00?l3ooooo`Wo003o2Oooool3o`00o`;ooooo0Ol00001ooooo`0000?o0000ooooooooool0
1?ooool5o`00o`04ooooool00?oo003oo`00o`cooooo0ol00?l:ooooo`Go003o4oooool5o`00o`;o
oooo1Ol00?l7ooooo`So003o2Oooool5o`00o`cooooo2?l00?l4ooooo`?o003o3?ooool5o`00o`_o
oooo1Ol00?lGooooo`Ko003o0oooool5o`00o`Kooooo3_l00?l4ooooo`Go003o00?oooooo`00ool0
0?l01?l00?l4ooooo`?o003o2_ooool5o`00o`?ooooo2?l00?l2ooooo`?o003o2Oooool1o`00007o
oooo00001?l0003oooooooooooooool=o`00oaSooooo1Ol00?lCooooo`Go003o0oooool5o`00o`Ko
oooo2Ol00?l9ooooo`?o003o3_ooool6o`00o`Cooooo1Ol00?l<ooooo`?o003o3?ooool5o`00o`;o
oooo0ol00?l?ooooo`[o003o0_ooool5o`00o`Kooooo3ol00?l4ooooo`?o003o0oooool5o`00o`Co
oooo1Ol00?l8ooooo`Go003o1?ooool7o`00o`03ooooool00?oo003o00?o003o2?ooool1o`00007o
oooo00000ol0003oooooooooo`0>o`00oaWooooo0ol00?l6ooooo`?o003o1Oooool3o`00o`Cooooo
0ol00?l4ooooo`Go003o1oooool8o`00obCooooo1Ol00?l2ooooo`?o003o3_ooool3o`00o`Kooooo
0ol00?l2ooooo`Go003o3Oooool;o`00o`;ooooo1Ol00?l7ooooo`Wo003o00?oooooo`00ool00?l0
0ol00?l9ooooo`Go003o0oooool7o`00o`Oooooo1Ol00?l4ooooo`Ko003o0_ooool5o`00o`Sooooo
0Ol00001ooooo`0000?o0000ooooooooool02?l00?l00ooooooo003oo`00o`03o`00ob3ooooo1_l0
0?l3ooooo`Go003o2?ooool7o`00o`Wooooo1_l00?lTooooo`Go003o00?oooooo`00ool00?l00ol0
0?l4ooooo`?o003o1Oooool5o`00o`[ooooo1Ol00?l7ooooo`?o003o0oooool;o`00o`?ooooo0ol0
0?l9ooooo`Oo003o0_ooool5o`00o`[ooooo0ol00?l4ooooo`Oo003o2?ooool3o`00o`Kooooo0ol0
0?l4ooooo`Go003o1?ooool3o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool01Ol00?l5
ooooo`?o003o8?ooool7o`00o`?ooooo1Ol00?l7ooooo`Wo003o2_ooool3o`00oa3ooooo0ol00?lC
ooooo`?o003o0_ooool5o`00o`?ooooo1_l00?l3ooooo`Go003o2_ooool5o`00o`Kooooo1Ol00?l2
ooooo`[o003o4?ooool5o`00o`Cooooo1Ol00?lAooooo`Oo003o6?ooool5o`00o`?ooooo1Ol00?l1
o`00007ooooo00001?l0003oooooooooooooool3o`00o`?ooooo0ol00?lAooooo`?o003o3oooool7
o`00o`?ooooo1Ol00?l3ooooo`?o003o00?oooooo`00ool00?l02_l00?lIooooo`Go003o5oooool5
o`00o`?ooooo1ol00?l2ooooo`Go003o2oooool3o`00o`Oooooo1Ol00?l3ooooo`Oo003o4_ooool7
o`00o`?ooooo0ol00?lBooooo`Ko003o6Oooool5o`00o`?ooooo1Ol00?l1o`00007ooooo00000ol0
003oooooooooo`06ooooo`Go003o3oooool5o`00o`kooooo1_l00?l5ooooo`?o003o0ooooolBo`00
oaSooooo1Ol00?lGooooo`Go003o0oooool7o`00o`;ooooo1Ol00?lEooooo`Go003o1Oooool5o`00
o`oooooo0ol00?l00ooooooo003oo`00o`05o`00oa;ooooo0ol00?l2ooooo`Go003o6_ooool5o`00
o`?ooooo1Ol00?l1o`00007ooooo00000ol0003oooooooooo`06ooooo`Go003o3oooool5o`00o`oo
oooo0ol00?l=ooooo`Go003o00Goooooo`00ool00?oo003oooooo`08o`00oaSooooo1Ol00?lGoooo
o`Go003o1?ooool6o`00o`?ooooo0ol00?lGooooo`?o003o0_ooool3o`00o`03ooooool00?oo003o
00?o003o3_ooool5o`00o`;ooooo1ol00?l?ooooo`Go003o00?oooooo`00ool00?l00ol00?lKoooo
o`?o003o1Oooool3o`00o`7ooooo0Ol00001ooooo`0000?o0000ooooooooool01_ooool5o`00o`oo
oooo1Ol00?l?ooooo`?o003o3Oooool5o`00o`Kooooo1ol00?lIooooo`?o003o3_ooool3o`00o`So
oooo0ol00?l5ooooo`Go003o5_ooool3o`00o`Wooooo3?l00?l<ooooo`Go003o0_ooool9o`00o`go
oooo1Ol00?l2ooooo`?o003o:?ooool1o`00007ooooo00000ol0003oooooooooo`04ooooo`Ko003o
4Oooool6o`00o`cooooo1Ol00?l=ooooo`?o003o1_ooool3o`00o`04ooooool00?oo003oo`00o`Ko
oooo0ol00?l;ooooo`?o003o4oooool5o`00o`oooooo1Ol00?lDooooo`Ko003o2?ooool5o`00o`03
ooooool00?oo003o00Go003o2oooool5o`00o`?ooooo2Ol00?l4ooooo`?o003o1Oooool5o`00obgo
oooo0Ol00001ooooo`0000?o0000ooooooooool00oooool5o`00oaGooooo1Ol00?l;ooooo`Go003o
0oooool3o`00o`[ooooo0ol00?l2ooooo`Go003o2?ooool5o`00o`Wooooo1Ol00?lBooooo`Go003o
4?ooool3o`00o`[ooooo0ol00?l7ooooo`Oo003o2?ooool5o`00o`?ooooo1Ol00?l<ooooo`?o003o
1?ooool9o`00o`?ooooo1Ol00?l5ooooo`?o003o7Oooool3o`00o`kooooo0Ol00001ooooo`0000?o
0000ooooooooool00oooool5o`00oaGooooo1Ol00?l;ooooo`Go003o0_ooool5o`00o`Sooooo1Ol0
0?l00ooooooo003oo`00o`03o`00o`Sooooo1Ol00?l9ooooo`Go003o4_ooool5o`00oacooooo1Ol0
0?l6ooooo`Oo003o2Oooool3o`00o`Cooooo1Ol00?l;ooooo`Go003o1?ooool9o`00o`;ooooo1Ol0
0?lTooooo`Go003o3Oooool1o`00007ooooo00000ol0003oooooooooo`03ooooo`Go003o5Oooool5
o`00o`cooooo0ol00?l3ooooo`Go003o2?ooool5o`00o`03ooooool00?oo003o00?o003o2?ooool5
o`00o`Wooooo1Ol00?l>ooooo`?o003o0_ooool3o`00oaKooooo0ol00?l4ooooo`Go003o1_ooool6
o`00oa;ooooo0ol00?l8ooooo`?o003o00?oooooo`00ool00?l00ol00?l8ooooo`Go003o0_ooool5
o`00obCooooo1Ol00?l=ooooo`7o00000Oooool00003o`000?oooooooooo00Cooooo0ol00?lGoooo
o`?o003o4oooool5o`00o`Sooooo1Ol00?l2ooooo`?o003o2_ooool3o`00o`_ooooo0ol00?l01?oo
oooo003oo`00ool00?l:ooooo`So003o5_ooool5o`00o`?ooooo1Ol00?l7ooooo`?o003o4_ooool3
o`00o`Wooooo2_l00?l8ooooo`Go003o0oooool3o`00obGooooo1Ol00?l9ooooo`?o003o0Oooool1
o`00007ooooo00000ol0003oooooooooo`0`ooooo`?o003o0_ooool3o`00o`[ooooo0ol00?lBoooo
o`?o003o2Oooool8o`00o`Sooooo2_l00?l7ooooo`?o003o2_ooool6o`00o`Cooooo0ol00?l01?oo
oooo003oo`00ool00?lHooooo`Go003o2?ooool:o`00o`Wooooo0ol00?l]ooooo`?o003o1oooool7
o`00o`7o00000Oooool00003o`000?oooooooooo02oooooo1Ol00?lRooooo`Go003o1oooool9o`00
o`Oooooo2ol00?l6ooooo`Go003o2Oooool6o`00o`Oooooo1Ol00?lGooooo`Go003o2?ooool:o`00
o`04ooooool00?oo003oo`00o`[ooooo0ol00?l9ooooo`?o003o9Oooool8o`00o`7o00000Oooool0
0003o`000?oooooooooo01Sooooo0ol00?l3ooooo`?o003o3_ooool5o`00ob;ooooo1Ol00?l7oooo
o`Wo003o1oooool;o`00o`Kooooo1Ol00?l9ooooo`Go003o2?ooool6o`00oaKooooo1Ol00?l9oooo
o`?o003o00?oooooo`00ool00?l02?l00?l8ooooo`Oo003o1Oooool5o`00obCooooo2?l00?l1o`00
007ooooo00000ol0003oooooooooo`0Gooooo`_o003o3Oooool5o`00ob;ooooo2?l00?l4ooooo`So
003o2?ooool5o`00o`;ooooo0ol00?l7ooooo`Ko003o0_ooool3o`00o`Cooooo0ol00?l3ooooo`?o
003o0oooool6o`00o`kooooo0ol00?l6ooooo`?o003o3oooool3o`00o`03ooooool00?oo003o00?o
003o2?ooool8o`00o`?ooooo1_l00?lTooooo`So003o0Ol00001ooooo`0000?o0000ooooooooool0
4Oooool3o`00o`?ooooo2ol00?l>ooooo`?o003o9?ooool8o`00o`Cooooo0ol00?l9ooooo`?o003o
00Coooooo`00ool00?oo003o3_ooool5o`00o`03ooooool00?oo003o00?o003o2?ooool5o`00o`?o
oooo1Ol00?l=ooooo`Go003o4Oooool3o`00o`Oooooo1Ol00?l8ooooo`So003o0_ooool:o`00ob;o
oooo1ol00?l1o`00007ooooo00000ol0003oooooooooo`0@ooooo`Go003o0_ooool;o`00obKooooo
0ol00?l2ooooo`?o003o2_ooool5o`00o`04ooooool00?oo003oo`00o`_ooooo1Ol00?lAooooo`Go
003o00?oooooo`00ool00?l00ol00?l8ooooo`Go003o1?ooool3o`00o`Kooooo1Ol00?l3ooooo`Go
003o00Coooooo`00ool00?oo003o3?ooool5o`00o`Oooooo0ol00?l4ooooo`?o003o0oooool7o`00
o`;ooooo2ol00?lTooooo`?o003o0Oooool1o`00007ooooo00000ol0003oooooooooo`0@ooooo`Go
003o0oooool9o`00obKooooo2_l00?l9ooooo`[o003o2_ooool5o`00oa;ooooo0ol00?l2ooooo`Go
003o2?ooool5o`00o`cooooo1ol00?l2ooooo`[o003o2oooool5o`00o`gooooo1Ol00?l4ooooo`Go
003o0_ooool;o`00obSooooo0Ol00001ooooo`0000?o0000ooooooooool04?ooool5o`00o`Gooooo
1Ol00?lXooooo`[o003o2_ooool3o`00o`03ooooool00?oo003o00?o003o2_ooool5o`00oaSooooo
0ol00?l:ooooo`?o003o3Oooool7o`00o`?ooooo0ol00?l00ooooooo003oo`00o`03o`00o`_ooooo
1Ol00?l=ooooo`Go003o1?ooool5o`00o`;ooooo1Ol00?l00ooooooo003oo`00o`03o`00obSooooo
0Ol00001ooooo`0000?o0000ooooooooool04Oooool3o`00o`Kooooo1Ol00?lXooooo`[o003o3_oo
ool5o`00o`_ooooo0ol00?lfooooo`Oo003o1oooool5o`00o`cooooo0ol00?l>ooooo`Go003o1?oo
ool5o`00o`?ooooo0ol00?l3ooooo`?o003o:Oooool1o`00007ooooo00000ol0003oooooooooo`0K
ooooo`?o003o:_ooool3o`00o`;ooooo0ol00?l@ooooo`?o003oA_ooool5o`00o`Wooooo0ol00?lO
ooooo`?o003o1_ooool3o`00ocKooooo0Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gaussian probability density functions", "Subsection"],

Cell[CellGroupData[{

Cell["Compute Gaussian pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[data1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[data2, {x, y}];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Gaussian pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.43836 .09274 m
.46302 .09059 L
.48767 .08991 L
.51233 .09069 L
.53698 .09293 L
.53926 .0932 L
.56164 .09673 L
.58629 .10208 L
.61095 .10899 L
.6356 .1175 L
.63652 .11785 L
.66026 .1279 L
.68491 .14014 L
.68927 .1425 L
.70957 .15455 L
.72852 .16716 L
.73422 .17127 L
.75888 .19074 L
.76014 .19181 L
.78353 .21346 L
.78652 .21647 L
.80819 .24021 L
.80895 .24112 L
.82818 .26578 L
.83284 .27233 L
.84472 .29043 L
.8575 .3123 L
.85898 .31509 L
.8711 .33974 L
.88143 .3644 L
.88215 .36629 L
.88989 .38905 L
.89677 .41371 L
.90211 .43836 L
.90595 .46302 L
.9068 .4673 L
.90826 .48767 L
.90912 .51233 L
.90854 .53698 L
.9068 .55901 L
.90651 .56164 L
.90295 .58629 L
.89784 .61095 L
.89116 .6356 L
.88285 .66026 L
.88215 .66213 L
.87262 .68491 L
.8605 .70957 L
.8575 .71511 L
.84614 .73422 L
.83284 .75407 L
.82934 .75888 L
.80961 .78353 L
.80819 .78517 L
.78636 .80819 L
.78353 .81091 L
.75888 .83263 L
.75862 .83284 L
.73422 .85107 L
.72466 .8575 L
.70957 .86679 L
.68491 .88019 L
.68094 .88215 L
.66026 .8914 L
.6356 .90076 L
.61655 .9068 L
.61095 .90835 L
.58629 .91419 L
.56164 .91848 L
.53698 .92125 L
.51233 .92251 L
.48767 .92229 L
.46302 .92058 L
.43836 .91739 L
.41371 .91269 L
.39021 .9068 L
.38905 .90647 L
.3644 .89849 L
.33974 .88884 L
.3248 .88215 L
.31509 .87735 L
.29043 .8638 L
.28009 .8575 L
.26578 .848 L
.24514 .83284 L
.24112 .82965 L
.21647 .80827 L
.21638 .80819 L
.19213 .78353 L
.19181 .78318 L
.17142 .75888 L
.16716 .75333 L
.15361 .73422 L
.1425 .71682 L
.13826 .70957 L
.12512 .68491 L
.11785 .66947 L
.11393 .66026 L
.10459 .6356 L
.09687 .61095 L
.0932 .597 L
.0908 .58629 L
.0863 .56164 L
.08326 .53698 L
.08168 .51233 L
.08155 .48767 L
.08287 .46302 L
.08567 .43836 L
.08995 .41371 L
.0932 .39901 L
.09581 .38905 L
.10337 .3644 L
.11263 .33974 L
.11785 .32757 L
.12378 .31509 L
.13702 .29043 L
.1425 .28124 L
.15258 .26578 L
.16716 .24573 L
.1708 .24112 L
.19181 .2169 L
.19222 .21647 L
.21647 .19283 L
.2176 .19181 L
.24112 .17246 L
.24823 .16716 L
.26578 .15512 L
.28648 .1425 L
.29043 .14031 L
.31509 .12781 L
.33823 .11785 L
.33974 .11727 L
.3644 .10868 L
.38905 .10177 L
.41371 .09646 L
.43435 .0932 L
F
0 g
.43836 .09274 m
.46302 .09059 L
.48767 .08991 L
.51233 .09069 L
.53698 .09293 L
.53926 .0932 L
.56164 .09673 L
.58629 .10208 L
.61095 .10899 L
.6356 .1175 L
.63652 .11785 L
.66026 .1279 L
.68491 .14014 L
.68927 .1425 L
.70957 .15455 L
.72852 .16716 L
.73422 .17127 L
.75888 .19074 L
.76014 .19181 L
.78353 .21346 L
.78652 .21647 L
.80819 .24021 L
.80895 .24112 L
.82818 .26578 L
.83284 .27233 L
.84472 .29043 L
.8575 .3123 L
.85898 .31509 L
.8711 .33974 L
.88143 .3644 L
.88215 .36629 L
.88989 .38905 L
.89677 .41371 L
.90211 .43836 L
.90595 .46302 L
.9068 .4673 L
.90826 .48767 L
.90912 .51233 L
.90854 .53698 L
.9068 .55901 L
.90651 .56164 L
.90295 .58629 L
.89784 .61095 L
.89116 .6356 L
.88285 .66026 L
.88215 .66213 L
.87262 .68491 L
.8605 .70957 L
.8575 .71511 L
.84614 .73422 L
Mistroke
.83284 .75407 L
.82934 .75888 L
.80961 .78353 L
.80819 .78517 L
.78636 .80819 L
.78353 .81091 L
.75888 .83263 L
.75862 .83284 L
.73422 .85107 L
.72466 .8575 L
.70957 .86679 L
.68491 .88019 L
.68094 .88215 L
.66026 .8914 L
.6356 .90076 L
.61655 .9068 L
.61095 .90835 L
.58629 .91419 L
.56164 .91848 L
.53698 .92125 L
.51233 .92251 L
.48767 .92229 L
.46302 .92058 L
.43836 .91739 L
.41371 .91269 L
.39021 .9068 L
.38905 .90647 L
.3644 .89849 L
.33974 .88884 L
.3248 .88215 L
.31509 .87735 L
.29043 .8638 L
.28009 .8575 L
.26578 .848 L
.24514 .83284 L
.24112 .82965 L
.21647 .80827 L
.21638 .80819 L
.19213 .78353 L
.19181 .78318 L
.17142 .75888 L
.16716 .75333 L
.15361 .73422 L
.1425 .71682 L
.13826 .70957 L
.12512 .68491 L
.11785 .66947 L
.11393 .66026 L
.10459 .6356 L
.09687 .61095 L
Mistroke
.0932 .597 L
.0908 .58629 L
.0863 .56164 L
.08326 .53698 L
.08168 .51233 L
.08155 .48767 L
.08287 .46302 L
.08567 .43836 L
.08995 .41371 L
.0932 .39901 L
.09581 .38905 L
.10337 .3644 L
.11263 .33974 L
.11785 .32757 L
.12378 .31509 L
.13702 .29043 L
.1425 .28124 L
.15258 .26578 L
.16716 .24573 L
.1708 .24112 L
.19181 .2169 L
.19222 .21647 L
.21647 .19283 L
.2176 .19181 L
.24112 .17246 L
.24823 .16716 L
.26578 .15512 L
.28648 .1425 L
.29043 .14031 L
.31509 .12781 L
.33823 .11785 L
.33974 .11727 L
.3644 .10868 L
.38905 .10177 L
.41371 .09646 L
.43435 .0932 L
.43836 .09274 L
Mfstroke
.2 g
.43836 .16706 m
.46302 .16431 L
.48767 .16337 L
.51233 .16422 L
.53698 .16685 L
.53922 .16716 L
.56164 .17136 L
.58629 .17777 L
.61095 .18617 L
.62485 .19181 L
.6356 .19673 L
.66026 .20967 L
.67157 .21647 L
.68491 .2253 L
.70599 .24112 L
.70957 .24407 L
.73331 .26578 L
.73422 .26669 L
.75569 .29043 L
.75888 .29434 L
.77427 .31509 L
.78353 .32924 L
.78977 .33974 L
.80262 .3644 L
.80819 .37675 L
.81312 .38905 L
.82148 .41371 L
.8279 .43836 L
.83244 .46302 L
.83284 .46399 L
.83515 .48767 L
.83609 .51233 L
.83528 .53698 L
.83284 .56061 L
.83269 .56164 L
.82824 .58629 L
.82187 .61095 L
.81348 .6356 L
.80819 .64864 L
.80286 .66026 L
.78975 .68491 L
.78353 .69514 L
.77381 .70957 L
.75888 .72902 L
.75447 .73422 L
.73422 .75565 L
.73085 .75888 L
.70957 .77726 L
.70142 .78353 L
.68491 .79502 L
.66298 .80819 L
.66026 .80965 L
.6356 .82156 L
.61095 .83114 L
.60592 .83284 L
.58629 .83851 L
.56164 .84388 L
.53698 .84736 L
.51233 .84901 L
.48767 .84885 L
.46302 .84688 L
.43836 .84311 L
.41371 .83747 L
.39781 .83284 L
.38905 .82986 L
.3644 .82013 L
.33977 .80819 L
.33974 .80817 L
.31509 .7936 L
.30033 .78353 L
.29043 .77611 L
.2699 .75888 L
.26578 .75508 L
.24528 .73422 L
.24112 .72955 L
.22494 .70957 L
.21647 .69782 L
.208 .68491 L
.19388 .66026 L
.19181 .65624 L
.18228 .6356 L
.17287 .61095 L
.16716 .59258 L
.1655 .58629 L
.16009 .56164 L
.15649 .53698 L
.15467 .51233 L
.15462 .48767 L
.15634 .46302 L
.15986 .43836 L
.16524 .41371 L
.16716 .40648 L
.17263 .38905 L
.18214 .3644 L
.19181 .34384 L
.19397 .33974 L
.20847 .31509 L
.21647 .30327 L
.22606 .29043 L
.24112 .27256 L
.24744 .26578 L
.26578 .24804 L
.27375 .24112 L
.29043 .22803 L
.30717 .21647 L
.31509 .21154 L
.33974 .198 L
.3529 .19181 L
.3644 .18702 L
.38905 .17833 L
.41371 .17172 L
.43764 .16716 L
F
0 g
.43836 .16706 m
.46302 .16431 L
.48767 .16337 L
.51233 .16422 L
.53698 .16685 L
.53922 .16716 L
.56164 .17136 L
.58629 .17777 L
.61095 .18617 L
.62485 .19181 L
.6356 .19673 L
.66026 .20967 L
.67157 .21647 L
.68491 .2253 L
.70599 .24112 L
.70957 .24407 L
.73331 .26578 L
.73422 .26669 L
.75569 .29043 L
.75888 .29434 L
.77427 .31509 L
.78353 .32924 L
.78977 .33974 L
.80262 .3644 L
.80819 .37675 L
.81312 .38905 L
.82148 .41371 L
.8279 .43836 L
.83244 .46302 L
.83284 .46399 L
.83515 .48767 L
.83609 .51233 L
.83528 .53698 L
.83284 .56061 L
.83269 .56164 L
.82824 .58629 L
.82187 .61095 L
.81348 .6356 L
.80819 .64864 L
.80286 .66026 L
.78975 .68491 L
.78353 .69514 L
.77381 .70957 L
.75888 .72902 L
.75447 .73422 L
.73422 .75565 L
.73085 .75888 L
.70957 .77726 L
.70142 .78353 L
.68491 .79502 L
Mistroke
.66298 .80819 L
.66026 .80965 L
.6356 .82156 L
.61095 .83114 L
.60592 .83284 L
.58629 .83851 L
.56164 .84388 L
.53698 .84736 L
.51233 .84901 L
.48767 .84885 L
.46302 .84688 L
.43836 .84311 L
.41371 .83747 L
.39781 .83284 L
.38905 .82986 L
.3644 .82013 L
.33977 .80819 L
.33974 .80817 L
.31509 .7936 L
.30033 .78353 L
.29043 .77611 L
.2699 .75888 L
.26578 .75508 L
.24528 .73422 L
.24112 .72955 L
.22494 .70957 L
.21647 .69782 L
.208 .68491 L
.19388 .66026 L
.19181 .65624 L
.18228 .6356 L
.17287 .61095 L
.16716 .59258 L
.1655 .58629 L
.16009 .56164 L
.15649 .53698 L
.15467 .51233 L
.15462 .48767 L
.15634 .46302 L
.15986 .43836 L
.16524 .41371 L
.16716 .40648 L
.17263 .38905 L
.18214 .3644 L
.19181 .34384 L
.19397 .33974 L
.20847 .31509 L
.21647 .30327 L
.22606 .29043 L
.24112 .27256 L
Mistroke
.24744 .26578 L
.26578 .24804 L
.27375 .24112 L
.29043 .22803 L
.30717 .21647 L
.31509 .21154 L
.33974 .198 L
.3529 .19181 L
.3644 .18702 L
.38905 .17833 L
.41371 .17172 L
.43764 .16716 L
.43836 .16706 L
Mfstroke
.3 g
.43836 .21426 m
.46302 .21098 L
.48767 .2098 L
.51233 .21071 L
.53698 .2137 L
.55225 .21647 L
.56164 .21883 L
.58629 .22623 L
.61095 .23603 L
.62176 .24112 L
.6356 .24851 L
.66026 .26405 L
.6627 .26578 L
.68491 .28328 L
.69288 .29043 L
.70957 .3072 L
.71658 .31509 L
.73422 .3377 L
.73565 .33974 L
.75109 .3644 L
.75888 .37915 L
.7635 .38905 L
.77328 .41371 L
.78068 .43836 L
.78353 .45001 L
.78586 .46302 L
.78892 .48767 L
.78994 .51233 L
.78892 .53698 L
.78583 .56164 L
.78353 .57435 L
.78058 .58629 L
.77303 .61095 L
.763 .6356 L
.75888 .64421 L
.75015 .66026 L
.73422 .68465 L
.73403 .68491 L
.71384 .70957 L
.70957 .71414 L
.68828 .73422 L
.68491 .73704 L
.66026 .75526 L
.65465 .75888 L
.6356 .76979 L
.61095 .78127 L
.60532 .78353 L
.58629 .79005 L
.56164 .79642 L
.53698 .80055 L
.51233 .80253 L
.48767 .80243 L
.46302 .80024 L
.43836 .79593 L
.41371 .78943 L
.39642 .78353 L
.38905 .78059 L
.3644 .76917 L
.3461 .75888 L
.33974 .75487 L
.31509 .73715 L
.31147 .73422 L
.29043 .7152 L
.28491 .70957 L
.26578 .68756 L
.26372 .68491 L
.24659 .66026 L
.24112 .65118 L
.23275 .6356 L
.22171 .61095 L
.21647 .59677 L
.21317 .58629 L
.20693 .56164 L
.20284 .53698 L
.20081 .51233 L
.20083 .48767 L
.2029 .46302 L
.20708 .43836 L
.21346 .41371 L
.21647 .40433 L
.22224 .38905 L
.23366 .3644 L
.24112 .35093 L
.2481 .33974 L
.26578 .31556 L
.26616 .31509 L
.28886 .29043 L
.29043 .28893 L
.31509 .26799 L
.31804 .26578 L
.33974 .25129 L
.358 .24112 L
.3644 .23799 L
.38905 .22759 L
.41371 .21975 L
.42661 .21647 L
F
0 g
.43836 .21426 m
.46302 .21098 L
.48767 .2098 L
.51233 .21071 L
.53698 .2137 L
.55225 .21647 L
.56164 .21883 L
.58629 .22623 L
.61095 .23603 L
.62176 .24112 L
.6356 .24851 L
.66026 .26405 L
.6627 .26578 L
.68491 .28328 L
.69288 .29043 L
.70957 .3072 L
.71658 .31509 L
.73422 .3377 L
.73565 .33974 L
.75109 .3644 L
.75888 .37915 L
.7635 .38905 L
.77328 .41371 L
.78068 .43836 L
.78353 .45001 L
.78586 .46302 L
.78892 .48767 L
.78994 .51233 L
.78892 .53698 L
.78583 .56164 L
.78353 .57435 L
.78058 .58629 L
.77303 .61095 L
.763 .6356 L
.75888 .64421 L
.75015 .66026 L
.73422 .68465 L
.73403 .68491 L
.71384 .70957 L
.70957 .71414 L
.68828 .73422 L
.68491 .73704 L
.66026 .75526 L
.65465 .75888 L
.6356 .76979 L
.61095 .78127 L
.60532 .78353 L
.58629 .79005 L
.56164 .79642 L
.53698 .80055 L
Mistroke
.51233 .80253 L
.48767 .80243 L
.46302 .80024 L
.43836 .79593 L
.41371 .78943 L
.39642 .78353 L
.38905 .78059 L
.3644 .76917 L
.3461 .75888 L
.33974 .75487 L
.31509 .73715 L
.31147 .73422 L
.29043 .7152 L
.28491 .70957 L
.26578 .68756 L
.26372 .68491 L
.24659 .66026 L
.24112 .65118 L
.23275 .6356 L
.22171 .61095 L
.21647 .59677 L
.21317 .58629 L
.20693 .56164 L
.20284 .53698 L
.20081 .51233 L
.20083 .48767 L
.2029 .46302 L
.20708 .43836 L
.21346 .41371 L
.21647 .40433 L
.22224 .38905 L
.23366 .3644 L
.24112 .35093 L
.2481 .33974 L
.26578 .31556 L
.26616 .31509 L
.28886 .29043 L
.29043 .28893 L
.31509 .26799 L
.31804 .26578 L
.33974 .25129 L
.358 .24112 L
.3644 .23799 L
.38905 .22759 L
.41371 .21975 L
.42661 .21647 L
.43836 .21426 L
Mfstroke
.4 g
.41371 .25804 m
.43836 .25165 L
.46302 .2478 L
.48767 .24639 L
.51233 .24735 L
.53698 .2507 L
.56164 .25652 L
.58629 .26496 L
.58833 .26578 L
.61095 .27632 L
.63476 .29043 L
.6356 .291 L
.66026 .30972 L
.66634 .31509 L
.68491 .33373 L
.69017 .33974 L
.70878 .3644 L
.70957 .36557 L
.72339 .38905 L
.73422 .41244 L
.73472 .41371 L
.74318 .43836 L
.74905 .46302 L
.75249 .48767 L
.75358 .51233 L
.75234 .53698 L
.74872 .56164 L
.7426 .58629 L
.73422 .60992 L
.73378 .61095 L
.7219 .6356 L
.70957 .65577 L
.70644 .66026 L
.68647 .68491 L
.68491 .68659 L
.66029 .70957 L
.66026 .70959 L
.6356 .7273 L
.62398 .73422 L
.61095 .74097 L
.58629 .7513 L
.56164 .75875 L
.56124 .75888 L
.53698 .76355 L
.51233 .76588 L
.48767 .76583 L
.46302 .76341 L
.43936 .75888 L
.43836 .75857 L
.41371 .75115 L
.38905 .74096 L
.37577 .73422 L
.3644 .72762 L
.33974 .71057 L
.33846 .70957 L
.31509 .6888 L
.31128 .68491 L
.29043 .66043 L
.29031 .66026 L
.27385 .6356 L
.26578 .62096 L
.26097 .61095 L
.25115 .58629 L
.24402 .56164 L
.24112 .54924 L
.2394 .53698 L
.23717 .51233 L
.23726 .48767 L
.23969 .46302 L
.24112 .45321 L
.24457 .43836 L
.25203 .41371 L
.26235 .38905 L
.26578 .38217 L
.27597 .3644 L
.29043 .34369 L
.29357 .33974 L
.31509 .31634 L
.3164 .31509 L
.33974 .29558 L
.34697 .29043 L
.3644 .27954 L
.38905 .26722 L
.39236 .26578 L
F
0 g
.41371 .25804 m
.43836 .25165 L
.46302 .2478 L
.48767 .24639 L
.51233 .24735 L
.53698 .2507 L
.56164 .25652 L
.58629 .26496 L
.58833 .26578 L
.61095 .27632 L
.63476 .29043 L
.6356 .291 L
.66026 .30972 L
.66634 .31509 L
.68491 .33373 L
.69017 .33974 L
.70878 .3644 L
.70957 .36557 L
.72339 .38905 L
.73422 .41244 L
.73472 .41371 L
.74318 .43836 L
.74905 .46302 L
.75249 .48767 L
.75358 .51233 L
.75234 .53698 L
.74872 .56164 L
.7426 .58629 L
.73422 .60992 L
.73378 .61095 L
.7219 .6356 L
.70957 .65577 L
.70644 .66026 L
.68647 .68491 L
.68491 .68659 L
.66029 .70957 L
.66026 .70959 L
.6356 .7273 L
.62398 .73422 L
.61095 .74097 L
.58629 .7513 L
.56164 .75875 L
.56124 .75888 L
.53698 .76355 L
.51233 .76588 L
.48767 .76583 L
.46302 .76341 L
.43936 .75888 L
.43836 .75857 L
.41371 .75115 L
Mistroke
.38905 .74096 L
.37577 .73422 L
.3644 .72762 L
.33974 .71057 L
.33846 .70957 L
.31509 .6888 L
.31128 .68491 L
.29043 .66043 L
.29031 .66026 L
.27385 .6356 L
.26578 .62096 L
.26097 .61095 L
.25115 .58629 L
.24402 .56164 L
.24112 .54924 L
.2394 .53698 L
.23717 .51233 L
.23726 .48767 L
.23969 .46302 L
.24112 .45321 L
.24457 .43836 L
.25203 .41371 L
.26235 .38905 L
.26578 .38217 L
.27597 .3644 L
.29043 .34369 L
.29357 .33974 L
.31509 .31634 L
.3164 .31509 L
.33974 .29558 L
.34697 .29043 L
.3644 .27954 L
.38905 .26722 L
.39236 .26578 L
.41371 .25804 L
Mfstroke
.5 g
.43836 .28433 m
.46302 .27986 L
.48767 .27818 L
.51233 .2792 L
.53698 .28295 L
.56164 .28955 L
.56433 .29043 L
.58629 .29926 L
.61095 .31249 L
.61507 .31509 L
.6356 .33001 L
.64683 .33974 L
.66026 .35321 L
.6699 .3644 L
.68491 .38515 L
.68736 .38905 L
.70057 .41371 L
.70957 .43612 L
.7103 .43836 L
.71696 .46302 L
.72081 .48767 L
.72199 .51233 L
.72051 .53698 L
.71629 .56164 L
.70957 .58525 L
.70917 .58629 L
.6988 .61095 L
.68491 .63517 L
.68462 .6356 L
.66564 .66026 L
.66026 .6661 L
.63987 .68491 L
.6356 .68828 L
.61095 .70479 L
.6023 .70957 L
.58629 .71702 L
.56164 .72571 L
.53698 .7313 L
.51233 .73404 L
.48767 .73406 L
.46302 .73136 L
.43836 .72587 L
.41371 .7174 L
.39645 .70957 L
.38905 .7056 L
.3644 .68985 L
.35788 .68491 L
.33974 .66907 L
.33111 .66026 L
.31509 .64107 L
.31113 .6356 L
.29595 .61095 L
.29043 .60003 L
.28458 .58629 L
.27646 .56164 L
.27124 .53698 L
.26875 .51233 L
.26893 .48767 L
.27179 .46302 L
.27745 .43836 L
.28617 .41371 L
.29043 .40412 L
.29839 .38905 L
.31485 .3644 L
.31509 .36408 L
.33693 .33974 L
.33974 .33709 L
.3644 .31732 L
.36767 .31509 L
.38905 .30258 L
.41371 .29178 L
.41723 .29043 L
F
0 g
.43836 .28433 m
.46302 .27986 L
.48767 .27818 L
.51233 .2792 L
.53698 .28295 L
.56164 .28955 L
.56433 .29043 L
.58629 .29926 L
.61095 .31249 L
.61507 .31509 L
.6356 .33001 L
.64683 .33974 L
.66026 .35321 L
.6699 .3644 L
.68491 .38515 L
.68736 .38905 L
.70057 .41371 L
.70957 .43612 L
.7103 .43836 L
.71696 .46302 L
.72081 .48767 L
.72199 .51233 L
.72051 .53698 L
.71629 .56164 L
.70957 .58525 L
.70917 .58629 L
.6988 .61095 L
.68491 .63517 L
.68462 .6356 L
.66564 .66026 L
.66026 .6661 L
.63987 .68491 L
.6356 .68828 L
.61095 .70479 L
.6023 .70957 L
.58629 .71702 L
.56164 .72571 L
.53698 .7313 L
.51233 .73404 L
.48767 .73406 L
.46302 .73136 L
.43836 .72587 L
.41371 .7174 L
.39645 .70957 L
.38905 .7056 L
.3644 .68985 L
.35788 .68491 L
.33974 .66907 L
.33111 .66026 L
.31509 .64107 L
Mistroke
.31113 .6356 L
.29595 .61095 L
.29043 .60003 L
.28458 .58629 L
.27646 .56164 L
.27124 .53698 L
.26875 .51233 L
.26893 .48767 L
.27179 .46302 L
.27745 .43836 L
.28617 .41371 L
.29043 .40412 L
.29839 .38905 L
.31485 .3644 L
.31509 .36408 L
.33693 .33974 L
.33974 .33709 L
.3644 .31732 L
.36767 .31509 L
.38905 .30258 L
.41371 .29178 L
.41723 .29043 L
.43836 .28433 L
Mfstroke
.6 g
.43836 .31479 m
.46302 .30955 L
.48767 .30754 L
.51233 .30864 L
.53698 .31289 L
.54606 .31509 L
.56164 .32046 L
.58629 .33177 L
.59979 .33974 L
.61095 .34755 L
.63074 .3644 L
.6356 .36927 L
.65241 .38905 L
.66026 .40029 L
.66818 .41371 L
.67952 .43836 L
.68491 .45391 L
.68717 .46302 L
.69153 .48767 L
.69281 .51233 L
.69103 .53698 L
.68608 .56164 L
.68491 .56609 L
.67769 .58629 L
.66529 .61095 L
.66026 .619 L
.64788 .6356 L
.6356 .64904 L
.62331 .66026 L
.61095 .66974 L
.58629 .6845 L
.58551 .68491 L
.56164 .6948 L
.53698 .70136 L
.51233 .7046 L
.48767 .70469 L
.46302 .70167 L
.43836 .69541 L
.41371 .6856 L
.41225 .68491 L
.38905 .67167 L
.37344 .66026 L
.3644 .65249 L
.34787 .6356 L
.33974 .6257 L
.32945 .61095 L
.31606 .58629 L
.31509 .58424 L
.30666 .56164 L
.30072 .53698 L
.29794 .51233 L
.29821 .48767 L
.30158 .46302 L
.30823 .43836 L
.31509 .42079 L
.31857 .41371 L
.33334 .38905 L
.33974 .38047 L
.35401 .3644 L
.3644 .35468 L
.38399 .33974 L
.38905 .33651 L
.41371 .32358 L
.43727 .31509 L
F
0 g
.43836 .31479 m
.46302 .30955 L
.48767 .30754 L
.51233 .30864 L
.53698 .31289 L
.54606 .31509 L
.56164 .32046 L
.58629 .33177 L
.59979 .33974 L
.61095 .34755 L
.63074 .3644 L
.6356 .36927 L
.65241 .38905 L
.66026 .40029 L
.66818 .41371 L
.67952 .43836 L
.68491 .45391 L
.68717 .46302 L
.69153 .48767 L
.69281 .51233 L
.69103 .53698 L
.68608 .56164 L
.68491 .56609 L
.67769 .58629 L
.66529 .61095 L
.66026 .619 L
.64788 .6356 L
.6356 .64904 L
.62331 .66026 L
.61095 .66974 L
.58629 .6845 L
.58551 .68491 L
.56164 .6948 L
.53698 .70136 L
.51233 .7046 L
.48767 .70469 L
.46302 .70167 L
.43836 .69541 L
.41371 .6856 L
.41225 .68491 L
.38905 .67167 L
.37344 .66026 L
.3644 .65249 L
.34787 .6356 L
.33974 .6257 L
.32945 .61095 L
.31606 .58629 L
.31509 .58424 L
.30666 .56164 L
.30072 .53698 L
Mistroke
.29794 .51233 L
.29821 .48767 L
.30158 .46302 L
.30823 .43836 L
.31509 .42079 L
.31857 .41371 L
.33334 .38905 L
.33974 .38047 L
.35401 .3644 L
.3644 .35468 L
.38399 .33974 L
.38905 .33651 L
.41371 .32358 L
.43727 .31509 L
.43836 .31479 L
Mfstroke
.7 g
.46302 .33849 m
.48767 .33605 L
.51233 .33725 L
.52714 .33974 L
.53698 .34214 L
.56164 .35103 L
.58595 .3644 L
.58629 .36463 L
.61095 .38438 L
.61562 .38905 L
.6354 .41371 L
.6356 .41401 L
.64906 .43836 L
.65804 .46302 L
.66026 .4718 L
.66307 .48767 L
.66448 .51233 L
.66231 .53698 L
.66026 .55078 L
.6564 .56164 L
.64625 .58629 L
.6356 .6044 L
.63085 .61095 L
.61095 .63291 L
.60797 .6356 L
.58629 .65166 L
.57083 .66026 L
.56164 .66423 L
.53698 .67211 L
.51233 .67599 L
.48767 .67618 L
.46302 .67273 L
.43836 .66543 L
.42584 .66026 L
.41371 .65378 L
.38905 .63664 L
.38781 .6356 L
.3644 .61155 L
.36392 .61095 L
.3475 .58629 L
.33974 .57058 L
.33636 .56164 L
.32943 .53698 L
.32626 .51233 L
.32667 .48767 L
.33071 .46302 L
.3387 .43836 L
.33974 .43581 L
.35133 .41371 L
.3644 .39555 L
.37011 .38905 L
.38905 .37151 L
.39867 .3644 L
.41371 .35541 L
.43836 .34476 L
.45458 .33974 L
F
0 g
.46302 .33849 m
.48767 .33605 L
.51233 .33725 L
.52714 .33974 L
.53698 .34214 L
.56164 .35103 L
.58595 .3644 L
.58629 .36463 L
.61095 .38438 L
.61562 .38905 L
.6354 .41371 L
.6356 .41401 L
.64906 .43836 L
.65804 .46302 L
.66026 .4718 L
.66307 .48767 L
.66448 .51233 L
.66231 .53698 L
.66026 .55078 L
.6564 .56164 L
.64625 .58629 L
.6356 .6044 L
.63085 .61095 L
.61095 .63291 L
.60797 .6356 L
.58629 .65166 L
.57083 .66026 L
.56164 .66423 L
.53698 .67211 L
.51233 .67599 L
.48767 .67618 L
.46302 .67273 L
.43836 .66543 L
.42584 .66026 L
.41371 .65378 L
.38905 .63664 L
.38781 .6356 L
.3644 .61155 L
.36392 .61095 L
.3475 .58629 L
.33974 .57058 L
.33636 .56164 L
.32943 .53698 L
.32626 .51233 L
.32667 .48767 L
.33071 .46302 L
.3387 .43836 L
.33974 .43581 L
.35133 .41371 L
.3644 .39555 L
Mistroke
.37011 .38905 L
.38905 .37151 L
.39867 .3644 L
.41371 .35541 L
.43836 .34476 L
.45458 .33974 L
.46302 .33849 L
Mfstroke
.8 g
.43836 .37603 m
.46302 .36821 L
.48767 .36516 L
.51233 .36651 L
.53698 .37233 L
.56164 .38325 L
.57128 .38905 L
.58629 .40064 L
.5994 .41371 L
.61095 .42857 L
.61691 .43836 L
.62796 .46302 L
.63397 .48767 L
.63555 .51233 L
.63283 .53698 L
.62547 .56164 L
.61247 .58629 L
.61095 .58858 L
.59158 .61095 L
.58629 .61559 L
.56164 .63202 L
.55516 .6356 L
.53698 .64191 L
.51233 .64675 L
.48767 .64708 L
.46302 .643 L
.44083 .6356 L
.43836 .63415 L
.41371 .61952 L
.40312 .61095 L
.38905 .59648 L
.38124 .58629 L
.36729 .56164 L
.3644 .55617 L
.35892 .53698 L
.35518 .51233 L
.35577 .48767 L
.3608 .46302 L
.3644 .45157 L
.37082 .43836 L
.38742 .41371 L
.38905 .41179 L
.41371 .38971 L
.4146 .38905 L
F
0 g
.43836 .37603 m
.46302 .36821 L
.48767 .36516 L
.51233 .36651 L
.53698 .37233 L
.56164 .38325 L
.57128 .38905 L
.58629 .40064 L
.5994 .41371 L
.61095 .42857 L
.61691 .43836 L
.62796 .46302 L
.63397 .48767 L
.63555 .51233 L
.63283 .53698 L
.62547 .56164 L
.61247 .58629 L
.61095 .58858 L
.59158 .61095 L
.58629 .61559 L
.56164 .63202 L
.55516 .6356 L
.53698 .64191 L
.51233 .64675 L
.48767 .64708 L
.46302 .643 L
.44083 .6356 L
.43836 .63415 L
.41371 .61952 L
.40312 .61095 L
.38905 .59648 L
.38124 .58629 L
.36729 .56164 L
.3644 .55617 L
.35892 .53698 L
.35518 .51233 L
.35577 .48767 L
.3608 .46302 L
.3644 .45157 L
.37082 .43836 L
.38742 .41371 L
.38905 .41179 L
.41371 .38971 L
.4146 .38905 L
.43836 .37603 L
s
.9 g
.43836 .41183 m
.46302 .40103 L
.48767 .3969 L
.51233 .39849 L
.53698 .40602 L
.55223 .41371 L
.56164 .42079 L
.57934 .43836 L
.58629 .44751 L
.59434 .46302 L
.60212 .48767 L
.60403 .51233 L
.60034 .53698 L
.59022 .56164 L
.58629 .56835 L
.57129 .58629 L
.56164 .59442 L
.53698 .60821 L
.52906 .61095 L
.51233 .6147 L
.48767 .61528 L
.46568 .61095 L
.46302 .61012 L
.43836 .59848 L
.42236 .58629 L
.41371 .57737 L
.40245 .56164 L
.39145 .53698 L
.38905 .52773 L
.38677 .51233 L
.38769 .48767 L
.38905 .48044 L
.39439 .46302 L
.40851 .43836 L
.41371 .43201 L
.4352 .41371 L
F
0 g
.43836 .41183 m
.46302 .40103 L
.48767 .3969 L
.51233 .39849 L
.53698 .40602 L
.55223 .41371 L
.56164 .42079 L
.57934 .43836 L
.58629 .44751 L
.59434 .46302 L
.60212 .48767 L
.60403 .51233 L
.60034 .53698 L
.59022 .56164 L
.58629 .56835 L
.57129 .58629 L
.56164 .59442 L
.53698 .60821 L
.52906 .61095 L
.51233 .6147 L
.48767 .61528 L
.46568 .61095 L
.46302 .61012 L
.43836 .59848 L
.42236 .58629 L
.41371 .57737 L
.40245 .56164 L
.39145 .53698 L
.38905 .52773 L
.38677 .51233 L
.38769 .48767 L
.38905 .48044 L
.39439 .46302 L
.40851 .43836 L
.41371 .43201 L
.4352 .41371 L
.43836 .41183 L
s
1 g
.48767 .43663 m
.51018 .43836 L
.51233 .43884 L
.53698 .45048 L
.5498 .46302 L
.56164 .48714 L
.5618 .48767 L
.56463 .51233 L
.56164 .52809 L
.55872 .53698 L
.53894 .56164 L
.53698 .56303 L
.51233 .57475 L
.48767 .57596 L
.46302 .56775 L
.45238 .56164 L
.43836 .54694 L
.4333 .53698 L
.42582 .51233 L
.42757 .48767 L
.43836 .46505 L
.43932 .46302 L
.46302 .4431 L
.4776 .43836 L
F
0 g
.48767 .43663 m
.51018 .43836 L
.51233 .43884 L
.53698 .45048 L
.5498 .46302 L
.56164 .48714 L
.5618 .48767 L
.56463 .51233 L
.56164 .52809 L
.55872 .53698 L
.53894 .56164 L
.53698 .56303 L
.51233 .57475 L
.48767 .57596 L
.46302 .56775 L
.45238 .56164 L
.43836 .54694 L
.4333 .53698 L
.42582 .51233 L
.42757 .48767 L
.43836 .46505 L
.43932 .46302 L
.46302 .4431 L
.4776 .43836 L
.48767 .43663 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.1 g
.01923 .68292 m
.02003 .68491 L
.03071 .70957 L
.04285 .73422 L
.04389 .73619 L
.05655 .75888 L
.06854 .7783 L
.07196 .78353 L
.08925 .80819 L
.0932 .81343 L
.10867 .83284 L
.11785 .84357 L
.13051 .8575 L
.1425 .86985 L
.15522 .88215 L
.16716 .89301 L
.18341 .9068 L
.19181 .91353 L
.21604 .93146 L
.21647 .93176 L
.24112 .94796 L
.25473 .95611 L
.26578 .96234 L
.29043 .97505 L
.30266 .98077 L
.01923 .98077 L
F
0 g
.01923 .68292 m
.02003 .68491 L
.03071 .70957 L
.04285 .73422 L
.04389 .73619 L
.05655 .75888 L
.06854 .7783 L
.07196 .78353 L
.08925 .80819 L
.0932 .81343 L
.10867 .83284 L
.11785 .84357 L
.13051 .8575 L
.1425 .86985 L
.15522 .88215 L
.16716 .89301 L
.18341 .9068 L
.19181 .91353 L
.21604 .93146 L
.21647 .93176 L
.24112 .94796 L
.25473 .95611 L
.26578 .96234 L
.29043 .97505 L
.30266 .98077 L
s
.1 g
.01923 .26907 m
.02058 .26578 L
.0315 .24112 L
.04389 .21662 L
.04397 .21647 L
.05809 .19181 L
.06854 .17533 L
.07405 .16716 L
.09205 .1425 L
.0932 .14103 L
.11238 .11785 L
.11785 .11171 L
.13544 .0932 L
.1425 .08625 L
.16179 .06854 L
.16716 .06391 L
.19181 .04422 L
.19226 .04389 L
.21647 .0268 L
.22823 .01923 L
.01923 .01923 L
F
0 g
.01923 .26907 m
.02058 .26578 L
.0315 .24112 L
.04389 .21662 L
.04397 .21647 L
.05809 .19181 L
.06854 .17533 L
.07405 .16716 L
.09205 .1425 L
.0932 .14103 L
.11238 .11785 L
.11785 .11171 L
.13544 .0932 L
.1425 .08625 L
.16179 .06854 L
.16716 .06391 L
.19181 .04422 L
.19226 .04389 L
.21647 .0268 L
.22823 .01923 L
s
.01923 .84711 m
.0268 .8575 L
.04389 .87939 L
.04615 .88215 L
.06757 .9068 L
.06854 .90787 L
.09138 .93146 L
.0932 .93323 L
.11785 .95598 L
.118 .95611 L
.1425 .97647 L
.14802 .98077 L
.01923 .98077 L
F
.01923 .84711 m
.0268 .8575 L
.04389 .87939 L
.04615 .88215 L
.06757 .9068 L
.06854 .90787 L
.09138 .93146 L
.0932 .93323 L
.11785 .95598 L
.118 .95611 L
.1425 .97647 L
.14802 .98077 L
s
.01923 .10488 m
.028 .0932 L
.04389 .07342 L
.04802 .06854 L
.06854 .04577 L
.07034 .04389 L
.0932 .02122 L
.09533 .01923 L
.01923 .01923 L
F
.01923 .10488 m
.028 .0932 L
.04389 .07342 L
.04802 .06854 L
.06854 .04577 L
.07034 .04389 L
.0932 .02122 L
.09533 .01923 L
s
.3 g
.98077 .53941 m
.97807 .56164 L
.97388 .58629 L
.96835 .61095 L
.96144 .6356 L
.95611 .65183 L
.95308 .66026 L
.94318 .68491 L
.93164 .70957 L
.93146 .70992 L
.91828 .73422 L
.9068 .75298 L
.90294 .75888 L
.88535 .78353 L
.88215 .78768 L
.86517 .80819 L
.8575 .81671 L
.84189 .83284 L
.83284 .84151 L
.81479 .8575 L
.80819 .86293 L
.78353 .88154 L
.78266 .88215 L
.75888 .89772 L
.74335 .9068 L
.73422 .91177 L
.70957 .92389 L
.69197 .93146 L
.68491 .93425 L
.66026 .94296 L
.6356 .95014 L
.61095 .95585 L
.60969 .95611 L
.58629 .96015 L
.56164 .96308 L
.53698 .96467 L
.51233 .96494 L
.48767 .96389 L
.46302 .96152 L
.43836 .9578 L
.42926 .95611 L
.41371 .95272 L
.38905 .94623 L
.3644 .93827 L
.34628 .93146 L
.33974 .92878 L
.31509 .91765 L
.29412 .9068 L
.29043 .90476 L
.26578 .88995 L
.25401 .88215 L
.24112 .87301 L
.2211 .8575 L
.21647 .85366 L
.19321 .83284 L
.19181 .8315 L
.16915 .80819 L
.16716 .80599 L
.14817 .78353 L
.1425 .77627 L
.12979 .75888 L
.11785 .74094 L
.11366 .73422 L
.09952 .70957 L
.0932 .69736 L
.08719 .68491 L
.0765 .66026 L
.06854 .63905 L
.06735 .6356 L
.05966 .61095 L
.05335 .58629 L
.04836 .56164 L
.04466 .53698 L
.04389 .53165 L
.04223 .51233 L
.04104 .48767 L
.04109 .46302 L
.04238 .43836 L
.04389 .42119 L
.04494 .41371 L
.04877 .38905 L
.05392 .3644 L
.06043 .33974 L
.06837 .31509 L
.06854 .3146 L
.07782 .29043 L
.08889 .26578 L
.0932 .2571 L
.10172 .24112 L
.11648 .21647 L
.11785 .21434 L
.13341 .19181 L
.1425 .17983 L
.15282 .16716 L
.16716 .15093 L
.17516 .1425 L
.19181 .12624 L
.2011 .11785 L
.21647 .10491 L
.23165 .0932 L
.24112 .08638 L
.26578 .07026 L
.26862 .06854 L
.29043 .05627 L
.31509 .0442 L
.31578 .04389 L
.33974 .03389 L
.3644 .02522 L
.38469 .01923 L
.98077 .01923 L
F
0 g
.98077 .53941 m
.97807 .56164 L
.97388 .58629 L
.96835 .61095 L
.96144 .6356 L
.95611 .65183 L
.95308 .66026 L
.94318 .68491 L
.93164 .70957 L
.93146 .70992 L
.91828 .73422 L
.9068 .75298 L
.90294 .75888 L
.88535 .78353 L
.88215 .78768 L
.86517 .80819 L
.8575 .81671 L
.84189 .83284 L
.83284 .84151 L
.81479 .8575 L
.80819 .86293 L
.78353 .88154 L
.78266 .88215 L
.75888 .89772 L
.74335 .9068 L
.73422 .91177 L
.70957 .92389 L
.69197 .93146 L
.68491 .93425 L
.66026 .94296 L
.6356 .95014 L
.61095 .95585 L
.60969 .95611 L
.58629 .96015 L
.56164 .96308 L
.53698 .96467 L
.51233 .96494 L
.48767 .96389 L
.46302 .96152 L
.43836 .9578 L
.42926 .95611 L
.41371 .95272 L
.38905 .94623 L
.3644 .93827 L
.34628 .93146 L
.33974 .92878 L
.31509 .91765 L
.29412 .9068 L
.29043 .90476 L
.26578 .88995 L
Mistroke
.25401 .88215 L
.24112 .87301 L
.2211 .8575 L
.21647 .85366 L
.19321 .83284 L
.19181 .8315 L
.16915 .80819 L
.16716 .80599 L
.14817 .78353 L
.1425 .77627 L
.12979 .75888 L
.11785 .74094 L
.11366 .73422 L
.09952 .70957 L
.0932 .69736 L
.08719 .68491 L
.0765 .66026 L
.06854 .63905 L
.06735 .6356 L
.05966 .61095 L
.05335 .58629 L
.04836 .56164 L
.04466 .53698 L
.04389 .53165 L
.04223 .51233 L
.04104 .48767 L
.04109 .46302 L
.04238 .43836 L
.04389 .42119 L
.04494 .41371 L
.04877 .38905 L
.05392 .3644 L
.06043 .33974 L
.06837 .31509 L
.06854 .3146 L
.07782 .29043 L
.08889 .26578 L
.0932 .2571 L
.10172 .24112 L
.11648 .21647 L
.11785 .21434 L
.13341 .19181 L
.1425 .17983 L
.15282 .16716 L
.16716 .15093 L
.17516 .1425 L
.19181 .12624 L
.2011 .11785 L
.21647 .10491 L
.23165 .0932 L
Mistroke
.24112 .08638 L
.26578 .07026 L
.26862 .06854 L
.29043 .05627 L
.31509 .0442 L
.31578 .04389 L
.33974 .03389 L
.3644 .02522 L
.38469 .01923 L
Mfstroke
.4 g
.41371 .0678 m
.43836 .06292 L
.46302 .0596 L
.48767 .0578 L
.51233 .05749 L
.53698 .05866 L
.56164 .06133 L
.58629 .06551 L
.60028 .06854 L
.61095 .07126 L
.6356 .07862 L
.66026 .08768 L
.6733 .0932 L
.68491 .09857 L
.70957 .11142 L
.72059 .11785 L
.73422 .12645 L
.75701 .1425 L
.75888 .14392 L
.78353 .16424 L
.78679 .16716 L
.80819 .18795 L
.81186 .19181 L
.83284 .21592 L
.83328 .21647 L
.85174 .24112 L
.8575 .24962 L
.86767 .26578 L
.88139 .29043 L
.88215 .29191 L
.89314 .31509 L
.90308 .33974 L
.9068 .35023 L
.91134 .3644 L
.91802 .38905 L
.92319 .41371 L
.92691 .43836 L
.92921 .46302 L
.93011 .48767 L
.92961 .51233 L
.9277 .53698 L
.92436 .56164 L
.91956 .58629 L
.91323 .61095 L
.9068 .63131 L
.9053 .6356 L
.89565 .66026 L
.88416 .68491 L
.88215 .68883 L
.87063 .70957 L
.8575 .7303 L
.85481 .73422 L
.83636 .75888 L
.83284 .76318 L
.81478 .78353 L
.80819 .79033 L
.78931 .80819 L
.78353 .81322 L
.75888 .83271 L
.7587 .83284 L
.73422 .84936 L
.72061 .8575 L
.70957 .86357 L
.68491 .8756 L
.66943 .88215 L
.66026 .88566 L
.6356 .89391 L
.61095 .90045 L
.58629 .90537 L
.57802 .9068 L
.56164 .90873 L
.53698 .91058 L
.51233 .91093 L
.48767 .9098 L
.46302 .90718 L
.46022 .9068 L
.43836 .90304 L
.41371 .89734 L
.38905 .89002 L
.36726 .88215 L
.3644 .88101 L
.33974 .87018 L
.31529 .8575 L
.31509 .85738 L
.29043 .84242 L
.2764 .83284 L
.26578 .82502 L
.245 .80819 L
.24112 .8048 L
.21874 .78353 L
.21647 .78119 L
.19637 .75888 L
.19181 .75336 L
.17714 .73422 L
.16716 .71985 L
.16053 .70957 L
.14621 .68491 L
.1425 .67787 L
.13393 .66026 L
.1235 .6356 L
.11785 .62022 L
.11477 .61095 L
.10766 .58629 L
.10206 .56164 L
.09794 .53698 L
.09524 .51233 L
.09396 .48767 L
.09406 .46302 L
.09557 .43836 L
.0985 .41371 L
.10289 .38905 L
.10878 .3644 L
.11626 .33974 L
.11785 .33508 L
.12541 .31509 L
.13637 .29043 L
.1425 .27823 L
.1493 .26578 L
.16444 .24112 L
.16716 .23707 L
.18211 .21647 L
.19181 .20439 L
.20275 .19181 L
.21647 .17737 L
.22702 .16716 L
.24112 .15459 L
.25602 .1425 L
.26578 .13519 L
.29043 .11861 L
.29166 .11785 L
.31509 .10447 L
.33817 .0932 L
.33974 .09249 L
.3644 .08248 L
.38905 .07429 L
.41049 .06854 L
F
0 g
.41371 .0678 m
.43836 .06292 L
.46302 .0596 L
.48767 .0578 L
.51233 .05749 L
.53698 .05866 L
.56164 .06133 L
.58629 .06551 L
.60028 .06854 L
.61095 .07126 L
.6356 .07862 L
.66026 .08768 L
.6733 .0932 L
.68491 .09857 L
.70957 .11142 L
.72059 .11785 L
.73422 .12645 L
.75701 .1425 L
.75888 .14392 L
.78353 .16424 L
.78679 .16716 L
.80819 .18795 L
.81186 .19181 L
.83284 .21592 L
.83328 .21647 L
.85174 .24112 L
.8575 .24962 L
.86767 .26578 L
.88139 .29043 L
.88215 .29191 L
.89314 .31509 L
.90308 .33974 L
.9068 .35023 L
.91134 .3644 L
.91802 .38905 L
.92319 .41371 L
.92691 .43836 L
.92921 .46302 L
.93011 .48767 L
.92961 .51233 L
.9277 .53698 L
.92436 .56164 L
.91956 .58629 L
.91323 .61095 L
.9068 .63131 L
.9053 .6356 L
.89565 .66026 L
.88416 .68491 L
.88215 .68883 L
.87063 .70957 L
Mistroke
.8575 .7303 L
.85481 .73422 L
.83636 .75888 L
.83284 .76318 L
.81478 .78353 L
.80819 .79033 L
.78931 .80819 L
.78353 .81322 L
.75888 .83271 L
.7587 .83284 L
.73422 .84936 L
.72061 .8575 L
.70957 .86357 L
.68491 .8756 L
.66943 .88215 L
.66026 .88566 L
.6356 .89391 L
.61095 .90045 L
.58629 .90537 L
.57802 .9068 L
.56164 .90873 L
.53698 .91058 L
.51233 .91093 L
.48767 .9098 L
.46302 .90718 L
.46022 .9068 L
.43836 .90304 L
.41371 .89734 L
.38905 .89002 L
.36726 .88215 L
.3644 .88101 L
.33974 .87018 L
.31529 .8575 L
.31509 .85738 L
.29043 .84242 L
.2764 .83284 L
.26578 .82502 L
.245 .80819 L
.24112 .8048 L
.21874 .78353 L
.21647 .78119 L
.19637 .75888 L
.19181 .75336 L
.17714 .73422 L
.16716 .71985 L
.16053 .70957 L
.14621 .68491 L
.1425 .67787 L
.13393 .66026 L
.1235 .6356 L
Mistroke
.11785 .62022 L
.11477 .61095 L
.10766 .58629 L
.10206 .56164 L
.09794 .53698 L
.09524 .51233 L
.09396 .48767 L
.09406 .46302 L
.09557 .43836 L
.0985 .41371 L
.10289 .38905 L
.10878 .3644 L
.11626 .33974 L
.11785 .33508 L
.12541 .31509 L
.13637 .29043 L
.1425 .27823 L
.1493 .26578 L
.16444 .24112 L
.16716 .23707 L
.18211 .21647 L
.19181 .20439 L
.20275 .19181 L
.21647 .17737 L
.22702 .16716 L
.24112 .15459 L
.25602 .1425 L
.26578 .13519 L
.29043 .11861 L
.29166 .11785 L
.31509 .10447 L
.33817 .0932 L
.33974 .09249 L
.3644 .08248 L
.38905 .07429 L
.41049 .06854 L
.41371 .0678 L
Mfstroke
.5 g
.43836 .11292 m
.46302 .1091 L
.48767 .10701 L
.51233 .1066 L
.53698 .10788 L
.56164 .11084 L
.58629 .11553 L
.59611 .11785 L
.61095 .122 L
.6356 .13036 L
.66026 .14071 L
.66408 .1425 L
.68491 .15326 L
.70793 .16716 L
.70957 .16823 L
.73422 .186 L
.74146 .19181 L
.75888 .20707 L
.76863 .21647 L
.78353 .23223 L
.79123 .24112 L
.80819 .26284 L
.81029 .26578 L
.82644 .29043 L
.83284 .30148 L
.84007 .31509 L
.8515 .33974 L
.8575 .35481 L
.86092 .3644 L
.86849 .38905 L
.87431 .41371 L
.87848 .43836 L
.88102 .46302 L
.88198 .48767 L
.88137 .51233 L
.87916 .53698 L
.87532 .56164 L
.8698 .58629 L
.86251 .61095 L
.8575 .62512 L
.85334 .6356 L
.8421 .66026 L
.83284 .67762 L
.82858 .68491 L
.81246 .70957 L
.80819 .71544 L
.79326 .73422 L
.78353 .74522 L
.77029 .75888 L
.75888 .76957 L
.74236 .78353 L
.73422 .78981 L
.70957 .80676 L
.70727 .80819 L
.68491 .82091 L
.66026 .83263 L
.65978 .83284 L
.6356 .84217 L
.61095 .8497 L
.58629 .85535 L
.57495 .8575 L
.56164 .85922 L
.53698 .86136 L
.51233 .86182 L
.48767 .86059 L
.46302 .85768 L
.46178 .8575 L
.43836 .85304 L
.41371 .84661 L
.38905 .83832 L
.37529 .83284 L
.3644 .82802 L
.33974 .81554 L
.32703 .80819 L
.31509 .80064 L
.29117 .78353 L
.29043 .78296 L
.26578 .76199 L
.26245 .75888 L
.24112 .73696 L
.23869 .73422 L
.2187 .70957 L
.21647 .70654 L
.20179 .68491 L
.19181 .66818 L
.18748 .66026 L
.17546 .6356 L
.16716 .61545 L
.16549 .61095 L
.15741 .58629 L
.15111 .56164 L
.14648 .53698 L
.14349 .51233 L
.1425 .49855 L
.14208 .48767 L
.14225 .46302 L
.1425 .45755 L
.14401 .43836 L
.14738 .41371 L
.15242 .38905 L
.1592 .3644 L
.16716 .34148 L
.16784 .33974 L
.17847 .31509 L
.19132 .29043 L
.19181 .28957 L
.20667 .26578 L
.21647 .25202 L
.22494 .24112 L
.24112 .22242 L
.24676 .21647 L
.26578 .19821 L
.27314 .19181 L
.29043 .17807 L
.30587 .16716 L
.31509 .16121 L
.33974 .14713 L
.34893 .1425 L
.3644 .13547 L
.38905 .126 L
.41371 .11852 L
.41619 .11785 L
F
0 g
.43836 .11292 m
.46302 .1091 L
.48767 .10701 L
.51233 .1066 L
.53698 .10788 L
.56164 .11084 L
.58629 .11553 L
.59611 .11785 L
.61095 .122 L
.6356 .13036 L
.66026 .14071 L
.66408 .1425 L
.68491 .15326 L
.70793 .16716 L
.70957 .16823 L
.73422 .186 L
.74146 .19181 L
.75888 .20707 L
.76863 .21647 L
.78353 .23223 L
.79123 .24112 L
.80819 .26284 L
.81029 .26578 L
.82644 .29043 L
.83284 .30148 L
.84007 .31509 L
.8515 .33974 L
.8575 .35481 L
.86092 .3644 L
.86849 .38905 L
.87431 .41371 L
.87848 .43836 L
.88102 .46302 L
.88198 .48767 L
.88137 .51233 L
.87916 .53698 L
.87532 .56164 L
.8698 .58629 L
.86251 .61095 L
.8575 .62512 L
.85334 .6356 L
.8421 .66026 L
.83284 .67762 L
.82858 .68491 L
.81246 .70957 L
.80819 .71544 L
.79326 .73422 L
.78353 .74522 L
.77029 .75888 L
.75888 .76957 L
Mistroke
.74236 .78353 L
.73422 .78981 L
.70957 .80676 L
.70727 .80819 L
.68491 .82091 L
.66026 .83263 L
.65978 .83284 L
.6356 .84217 L
.61095 .8497 L
.58629 .85535 L
.57495 .8575 L
.56164 .85922 L
.53698 .86136 L
.51233 .86182 L
.48767 .86059 L
.46302 .85768 L
.46178 .8575 L
.43836 .85304 L
.41371 .84661 L
.38905 .83832 L
.37529 .83284 L
.3644 .82802 L
.33974 .81554 L
.32703 .80819 L
.31509 .80064 L
.29117 .78353 L
.29043 .78296 L
.26578 .76199 L
.26245 .75888 L
.24112 .73696 L
.23869 .73422 L
.2187 .70957 L
.21647 .70654 L
.20179 .68491 L
.19181 .66818 L
.18748 .66026 L
.17546 .6356 L
.16716 .61545 L
.16549 .61095 L
.15741 .58629 L
.15111 .56164 L
.14648 .53698 L
.14349 .51233 L
.1425 .49855 L
.14208 .48767 L
.14225 .46302 L
.1425 .45755 L
.14401 .43836 L
.14738 .41371 L
.15242 .38905 L
Mistroke
.1592 .3644 L
.16716 .34148 L
.16784 .33974 L
.17847 .31509 L
.19132 .29043 L
.19181 .28957 L
.20667 .26578 L
.21647 .25202 L
.22494 .24112 L
.24112 .22242 L
.24676 .21647 L
.26578 .19821 L
.27314 .19181 L
.29043 .17807 L
.30587 .16716 L
.31509 .16121 L
.33974 .14713 L
.34893 .1425 L
.3644 .13547 L
.38905 .126 L
.41371 .11852 L
.41619 .11785 L
.43836 .11292 L
Mfstroke
.6 g
.43836 .16073 m
.46302 .15629 L
.48767 .15384 L
.51233 .15332 L
.53698 .15471 L
.56164 .15804 L
.58629 .16336 L
.60002 .16716 L
.61095 .17075 L
.6356 .18036 L
.65916 .19181 L
.66026 .19241 L
.68491 .20718 L
.69827 .21647 L
.70957 .22514 L
.72809 .24112 L
.73422 .24697 L
.75204 .26578 L
.75888 .27382 L
.7717 .29043 L
.78353 .30791 L
.78794 .31509 L
.80135 .33974 L
.80819 .35451 L
.81227 .3644 L
.82097 .38905 L
.82761 .41371 L
.83232 .43836 L
.83284 .43986 L
.83517 .46302 L
.83621 .48767 L
.83545 .51233 L
.83287 .53698 L
.83284 .53721 L
.82841 .56164 L
.822 .58629 L
.81348 .61095 L
.80819 .62377 L
.80268 .6356 L
.78931 .66026 L
.78353 .66955 L
.77296 .68491 L
.75888 .70281 L
.753 .70957 L
.73422 .72885 L
.72839 .73422 L
.70957 .74985 L
.69722 .75888 L
.68491 .76699 L
.66026 .78094 L
.65507 .78353 L
.6356 .79216 L
.61095 .80096 L
.58629 .80753 L
.58366 .80819 L
.56164 .81202 L
.53698 .81453 L
.51233 .8151 L
.48767 .81376 L
.46302 .81049 L
.45054 .80819 L
.43836 .80523 L
.41371 .7979 L
.38905 .78835 L
.37845 .78353 L
.3644 .77638 L
.33974 .76169 L
.33553 .75888 L
.31509 .74383 L
.30356 .73422 L
.29043 .72213 L
.27816 .70957 L
.26578 .69544 L
.25741 .68491 L
.24112 .6616 L
.24027 .66026 L
.22611 .6356 L
.21647 .61549 L
.21452 .61095 L
.20522 .58629 L
.19801 .56164 L
.19277 .53698 L
.19181 .53267 L
.1894 .51233 L
.18785 .48767 L
.1881 .46302 L
.19017 .43836 L
.19181 .42542 L
.19409 .41371 L
.19994 .38905 L
.20785 .3644 L
.21647 .34307 L
.21799 .33974 L
.2306 .31509 L
.24112 .29777 L
.24606 .29043 L
.26493 .26578 L
.26578 .26478 L
.28809 .24112 L
.29043 .2389 L
.31509 .21802 L
.31713 .21647 L
.33974 .20098 L
.35542 .19181 L
.3644 .18711 L
.38905 .17596 L
.41371 .16724 L
.41395 .16716 L
F
0 g
.43836 .16073 m
.46302 .15629 L
.48767 .15384 L
.51233 .15332 L
.53698 .15471 L
.56164 .15804 L
.58629 .16336 L
.60002 .16716 L
.61095 .17075 L
.6356 .18036 L
.65916 .19181 L
.66026 .19241 L
.68491 .20718 L
.69827 .21647 L
.70957 .22514 L
.72809 .24112 L
.73422 .24697 L
.75204 .26578 L
.75888 .27382 L
.7717 .29043 L
.78353 .30791 L
.78794 .31509 L
.80135 .33974 L
.80819 .35451 L
.81227 .3644 L
.82097 .38905 L
.82761 .41371 L
.83232 .43836 L
.83284 .43986 L
.83517 .46302 L
.83621 .48767 L
.83545 .51233 L
.83287 .53698 L
.83284 .53721 L
.82841 .56164 L
.822 .58629 L
.81348 .61095 L
.80819 .62377 L
.80268 .6356 L
.78931 .66026 L
.78353 .66955 L
.77296 .68491 L
.75888 .70281 L
.753 .70957 L
.73422 .72885 L
.72839 .73422 L
.70957 .74985 L
.69722 .75888 L
.68491 .76699 L
.66026 .78094 L
Mistroke
.65507 .78353 L
.6356 .79216 L
.61095 .80096 L
.58629 .80753 L
.58366 .80819 L
.56164 .81202 L
.53698 .81453 L
.51233 .8151 L
.48767 .81376 L
.46302 .81049 L
.45054 .80819 L
.43836 .80523 L
.41371 .7979 L
.38905 .78835 L
.37845 .78353 L
.3644 .77638 L
.33974 .76169 L
.33553 .75888 L
.31509 .74383 L
.30356 .73422 L
.29043 .72213 L
.27816 .70957 L
.26578 .69544 L
.25741 .68491 L
.24112 .6616 L
.24027 .66026 L
.22611 .6356 L
.21647 .61549 L
.21452 .61095 L
.20522 .58629 L
.19801 .56164 L
.19277 .53698 L
.19181 .53267 L
.1894 .51233 L
.18785 .48767 L
.1881 .46302 L
.19017 .43836 L
.19181 .42542 L
.19409 .41371 L
.19994 .38905 L
.20785 .3644 L
.21647 .34307 L
.21799 .33974 L
.2306 .31509 L
.24112 .29777 L
.24606 .29043 L
.26493 .26578 L
.26578 .26478 L
.28809 .24112 L
.29043 .2389 L
Mistroke
.31509 .21802 L
.31713 .21647 L
.33974 .20098 L
.35542 .19181 L
.3644 .18711 L
.38905 .17596 L
.41371 .16724 L
.41395 .16716 L
.43836 .16073 L
Mfstroke
.7 g
.41371 .2162 m
.43836 .20845 L
.46302 .20318 L
.48767 .20026 L
.51233 .19958 L
.53698 .20114 L
.56164 .20495 L
.58629 .21111 L
.60258 .21647 L
.61095 .21975 L
.6356 .23112 L
.65324 .24112 L
.66026 .24561 L
.68491 .26378 L
.68732 .26578 L
.70957 .28662 L
.71317 .29043 L
.73359 .31509 L
.73422 .31594 L
.74996 .33974 L
.75888 .3559 L
.76303 .3644 L
.77328 .38905 L
.78103 .41371 L
.78353 .42322 L
.78647 .43836 L
.78973 .46302 L
.79088 .48767 L
.78993 .51233 L
.78685 .53698 L
.78353 .55425 L
.78157 .56164 L
.77393 .58629 L
.7637 .61095 L
.75888 .62074 L
.75056 .6356 L
.73422 .65987 L
.73393 .66026 L
.71294 .68491 L
.70957 .68837 L
.68595 .70957 L
.68491 .71039 L
.66026 .72774 L
.64935 .73422 L
.6356 .7414 L
.61095 .75196 L
.5897 .75888 L
.58629 .75978 L
.56164 .76511 L
.53698 .7681 L
.51233 .76884 L
.48767 .76734 L
.46302 .76359 L
.44281 .75888 L
.43836 .75751 L
.41371 .74894 L
.38905 .73765 L
.38261 .73422 L
.3644 .72326 L
.3452 .70957 L
.33974 .70521 L
.31743 .68491 L
.31509 .68252 L
.29565 .66026 L
.29043 .65343 L
.27824 .6356 L
.26578 .61385 L
.2643 .61095 L
.25329 .58629 L
.24486 .56164 L
.24112 .548 L
.23879 .53698 L
.23492 .51233 L
.23318 .48767 L
.23354 .46302 L
.23602 .43836 L
.24067 .41371 L
.24112 .41173 L
.24763 .38905 L
.25709 .3644 L
.26578 .34632 L
.26938 .33974 L
.28495 .31509 L
.29043 .3076 L
.30458 .29043 L
.31509 .27932 L
.32964 .26578 L
.33974 .25746 L
.36296 .24112 L
.3644 .24023 L
.38905 .22666 L
.41296 .21647 L
F
0 g
.41371 .2162 m
.43836 .20845 L
.46302 .20318 L
.48767 .20026 L
.51233 .19958 L
.53698 .20114 L
.56164 .20495 L
.58629 .21111 L
.60258 .21647 L
.61095 .21975 L
.6356 .23112 L
.65324 .24112 L
.66026 .24561 L
.68491 .26378 L
.68732 .26578 L
.70957 .28662 L
.71317 .29043 L
.73359 .31509 L
.73422 .31594 L
.74996 .33974 L
.75888 .3559 L
.76303 .3644 L
.77328 .38905 L
.78103 .41371 L
.78353 .42322 L
.78647 .43836 L
.78973 .46302 L
.79088 .48767 L
.78993 .51233 L
.78685 .53698 L
.78353 .55425 L
.78157 .56164 L
.77393 .58629 L
.7637 .61095 L
.75888 .62074 L
.75056 .6356 L
.73422 .65987 L
.73393 .66026 L
.71294 .68491 L
.70957 .68837 L
.68595 .70957 L
.68491 .71039 L
.66026 .72774 L
.64935 .73422 L
.6356 .7414 L
.61095 .75196 L
.5897 .75888 L
.58629 .75978 L
.56164 .76511 L
.53698 .7681 L
Mistroke
.51233 .76884 L
.48767 .76734 L
.46302 .76359 L
.44281 .75888 L
.43836 .75751 L
.41371 .74894 L
.38905 .73765 L
.38261 .73422 L
.3644 .72326 L
.3452 .70957 L
.33974 .70521 L
.31743 .68491 L
.31509 .68252 L
.29565 .66026 L
.29043 .65343 L
.27824 .6356 L
.26578 .61385 L
.2643 .61095 L
.25329 .58629 L
.24486 .56164 L
.24112 .548 L
.23879 .53698 L
.23492 .51233 L
.23318 .48767 L
.23354 .46302 L
.23602 .43836 L
.24067 .41371 L
.24112 .41173 L
.24763 .38905 L
.25709 .3644 L
.26578 .34632 L
.26938 .33974 L
.28495 .31509 L
.29043 .3076 L
.30458 .29043 L
.31509 .27932 L
.32964 .26578 L
.33974 .25746 L
.36296 .24112 L
.3644 .24023 L
.38905 .22666 L
.41296 .21647 L
.41371 .2162 L
Mfstroke
.8 g
.43836 .25854 m
.46302 .25204 L
.48767 .24842 L
.51233 .24753 L
.53698 .24932 L
.56164 .25384 L
.58629 .26124 L
.59802 .26578 L
.61095 .2718 L
.6356 .28601 L
.6421 .29043 L
.66026 .30468 L
.67155 .31509 L
.68491 .32936 L
.69338 .33974 L
.70957 .36357 L
.71006 .3644 L
.72279 .38905 L
.73222 .41371 L
.73422 .41975 L
.73875 .43836 L
.7426 .46302 L
.7439 .48767 L
.74268 .51233 L
.73887 .53698 L
.73422 .55606 L
.73235 .56164 L
.72283 .58629 L
.70985 .61095 L
.70957 .61142 L
.69267 .6356 L
.68491 .64481 L
.66982 .66026 L
.66026 .66867 L
.63814 .68491 L
.6356 .68651 L
.61095 .6999 L
.58652 .70957 L
.58629 .70964 L
.56164 .71622 L
.53698 .71992 L
.51233 .72089 L
.48767 .71918 L
.46302 .71474 L
.44423 .70957 L
.43836 .70742 L
.41371 .69696 L
.39222 .68491 L
.38905 .68286 L
.3644 .66433 L
.35977 .66026 L
.33974 .63985 L
.33613 .6356 L
.31815 .61095 L
.31509 .60605 L
.30439 .58629 L
.29408 .56164 L
.29043 .55096 L
.28677 .53698 L
.28217 .51233 L
.28016 .48767 L
.28067 .46302 L
.28374 .43836 L
.28948 .41371 L
.29043 .4104 L
.29812 .38905 L
.31006 .3644 L
.31509 .3558 L
.32595 .33974 L
.33974 .32281 L
.347 .31509 L
.3644 .29915 L
.37564 .29043 L
.38905 .28145 L
.41371 .26818 L
.41896 .26578 L
F
0 g
.43836 .25854 m
.46302 .25204 L
.48767 .24842 L
.51233 .24753 L
.53698 .24932 L
.56164 .25384 L
.58629 .26124 L
.59802 .26578 L
.61095 .2718 L
.6356 .28601 L
.6421 .29043 L
.66026 .30468 L
.67155 .31509 L
.68491 .32936 L
.69338 .33974 L
.70957 .36357 L
.71006 .3644 L
.72279 .38905 L
.73222 .41371 L
.73422 .41975 L
.73875 .43836 L
.7426 .46302 L
.7439 .48767 L
.74268 .51233 L
.73887 .53698 L
.73422 .55606 L
.73235 .56164 L
.72283 .58629 L
.70985 .61095 L
.70957 .61142 L
.69267 .6356 L
.68491 .64481 L
.66982 .66026 L
.66026 .66867 L
.63814 .68491 L
.6356 .68651 L
.61095 .6999 L
.58652 .70957 L
.58629 .70964 L
.56164 .71622 L
.53698 .71992 L
.51233 .72089 L
.48767 .71918 L
.46302 .71474 L
.44423 .70957 L
.43836 .70742 L
.41371 .69696 L
.39222 .68491 L
.38905 .68286 L
.3644 .66433 L
Mistroke
.35977 .66026 L
.33974 .63985 L
.33613 .6356 L
.31815 .61095 L
.31509 .60605 L
.30439 .58629 L
.29408 .56164 L
.29043 .55096 L
.28677 .53698 L
.28217 .51233 L
.28016 .48767 L
.28067 .46302 L
.28374 .43836 L
.28948 .41371 L
.29043 .4104 L
.29812 .38905 L
.31006 .3644 L
.31509 .3558 L
.32595 .33974 L
.33974 .32281 L
.347 .31509 L
.3644 .29915 L
.37564 .29043 L
.38905 .28145 L
.41371 .26818 L
.41896 .26578 L
.43836 .25854 L
Mfstroke
.9 g
.46302 .3066 m
.48767 .30177 L
.51233 .3005 L
.53698 .30269 L
.56164 .30845 L
.58005 .31509 L
.58629 .31812 L
.61095 .33239 L
.62095 .33974 L
.6356 .35269 L
.64655 .3644 L
.66026 .38245 L
.66443 .38905 L
.67708 .41371 L
.68491 .43591 L
.68554 .43836 L
.69043 .46302 L
.692 .48767 L
.6903 .51233 L
.68522 .53698 L
.68491 .53816 L
.67645 .56164 L
.66326 .58629 L
.66026 .59087 L
.64434 .61095 L
.6356 .61983 L
.61642 .6356 L
.61095 .63931 L
.58629 .65278 L
.56667 .66026 L
.56164 .66161 L
.53698 .66655 L
.51233 .66792 L
.48767 .66583 L
.46313 .66026 L
.46302 .66016 L
.43836 .65064 L
.41371 .63648 L
.41242 .6356 L
.38905 .61638 L
.38368 .61095 L
.3644 .58694 L
.36397 .58629 L
.34997 .56164 L
.34042 .53698 L
.33974 .53559 L
.33455 .51233 L
.33207 .48767 L
.33284 .46302 L
.33695 .43836 L
.33974 .42702 L
.34463 .41371 L
.35647 .38905 L
.3644 .37645 L
.37356 .3644 L
.38905 .34791 L
.39837 .33974 L
.41371 .32863 L
.43836 .31534 L
.43887 .31509 L
F
0 g
.46302 .3066 m
.48767 .30177 L
.51233 .3005 L
.53698 .30269 L
.56164 .30845 L
.58005 .31509 L
.58629 .31812 L
.61095 .33239 L
.62095 .33974 L
.6356 .35269 L
.64655 .3644 L
.66026 .38245 L
.66443 .38905 L
.67708 .41371 L
.68491 .43591 L
.68554 .43836 L
.69043 .46302 L
.692 .48767 L
.6903 .51233 L
.68522 .53698 L
.68491 .53816 L
.67645 .56164 L
.66326 .58629 L
.66026 .59087 L
.64434 .61095 L
.6356 .61983 L
.61642 .6356 L
.61095 .63931 L
.58629 .65278 L
.56667 .66026 L
.56164 .66161 L
.53698 .66655 L
.51233 .66792 L
.48767 .66583 L
.46313 .66026 L
.46302 .66016 L
.43836 .65064 L
.41371 .63648 L
.41242 .6356 L
.38905 .61638 L
.38368 .61095 L
.3644 .58694 L
.36397 .58629 L
.34997 .56164 L
.34042 .53698 L
.33974 .53559 L
.33455 .51233 L
.33207 .48767 L
.33284 .46302 L
.33695 .43836 L
Mistroke
.33974 .42702 L
.34463 .41371 L
.35647 .38905 L
.3644 .37645 L
.37356 .3644 L
.38905 .34791 L
.39837 .33974 L
.41371 .32863 L
.43836 .31534 L
.43887 .31509 L
.46302 .3066 L
Mfstroke
1 g
.46302 .37761 m
.48767 .3695 L
.51233 .36728 L
.53698 .37048 L
.56164 .37961 L
.57756 .38905 L
.58629 .3963 L
.60239 .41371 L
.61095 .4263 L
.61666 .43836 L
.62435 .46302 L
.62659 .48767 L
.62368 .51233 L
.61506 .53698 L
.61095 .54518 L
.59923 .56164 L
.58629 .57458 L
.56999 .58629 L
.56164 .59041 L
.53698 .59877 L
.51233 .60118 L
.48767 .59811 L
.46302 .58909 L
.45743 .58629 L
.43836 .5727 L
.42722 .56164 L
.41371 .54295 L
.41059 .53698 L
.40117 .51233 L
.39747 .48767 L
.39892 .46302 L
.40581 .43836 L
.41371 .42168 L
.41933 .41371 L
.43836 .39328 L
.44339 .38905 L
F
0 g
.46302 .37761 m
.48767 .3695 L
.51233 .36728 L
.53698 .37048 L
.56164 .37961 L
.57756 .38905 L
.58629 .3963 L
.60239 .41371 L
.61095 .4263 L
.61666 .43836 L
.62435 .46302 L
.62659 .48767 L
.62368 .51233 L
.61506 .53698 L
.61095 .54518 L
.59923 .56164 L
.58629 .57458 L
.56999 .58629 L
.56164 .59041 L
.53698 .59877 L
.51233 .60118 L
.48767 .59811 L
.46302 .58909 L
.45743 .58629 L
.43836 .5727 L
.42722 .56164 L
.41371 .54295 L
.41059 .53698 L
.40117 .51233 L
.39747 .48767 L
.39892 .46302 L
.40581 .43836 L
.41371 .42168 L
.41933 .41371 L
.43836 .39328 L
.44339 .38905 L
.46302 .37761 L
s
.2 g
.98077 .44242 m
.9801 .43836 L
.97676 .41371 L
.97215 .38905 L
.96621 .3644 L
.95891 .33974 L
.95611 .33138 L
.95018 .31509 L
.93993 .29043 L
.93146 .27246 L
.92808 .26578 L
.91446 .24112 L
.9068 .22858 L
.89891 .21647 L
.88215 .19306 L
.8812 .19181 L
.86099 .16716 L
.8575 .1632 L
.83786 .1425 L
.83284 .13758 L
.81114 .11785 L
.80819 .11534 L
.78353 .09591 L
.7798 .0932 L
.75888 .07891 L
.74204 .06854 L
.73422 .06404 L
.70957 .0511 L
.6941 .04389 L
.68491 .03992 L
.66026 .03038 L
.6356 .02238 L
.62443 .01923 L
.98077 .01923 L
F
0 g
.98077 .44242 m
.9801 .43836 L
.97676 .41371 L
.97215 .38905 L
.96621 .3644 L
.95891 .33974 L
.95611 .33138 L
.95018 .31509 L
.93993 .29043 L
.93146 .27246 L
.92808 .26578 L
.91446 .24112 L
.9068 .22858 L
.89891 .21647 L
.88215 .19306 L
.8812 .19181 L
.86099 .16716 L
.8575 .1632 L
.83786 .1425 L
.83284 .13758 L
.81114 .11785 L
.80819 .11534 L
.78353 .09591 L
.7798 .0932 L
.75888 .07891 L
.74204 .06854 L
.73422 .06404 L
.70957 .0511 L
.6941 .04389 L
.68491 .03992 L
.66026 .03038 L
.6356 .02238 L
.62443 .01923 L
s
.1 g
.98077 .75048 m
.97619 .75888 L
.96157 .78353 L
.95611 .79201 L
.94506 .80819 L
.93146 .82648 L
.92644 .83284 L
.9068 .85592 L
.90538 .8575 L
.88215 .88148 L
.88146 .88215 L
.8575 .9039 L
.85406 .9068 L
.83284 .92366 L
.82221 .93146 L
.80819 .94113 L
.78431 .95611 L
.78353 .95657 L
.75888 .97018 L
.73717 .98077 L
.98077 .98077 L
F
0 g
.98077 .75048 m
.97619 .75888 L
.96157 .78353 L
.95611 .79201 L
.94506 .80819 L
.93146 .82648 L
.92644 .83284 L
.9068 .85592 L
.90538 .8575 L
.88215 .88148 L
.88146 .88215 L
.8575 .9039 L
.85406 .9068 L
.83284 .92366 L
.82221 .93146 L
.80819 .94113 L
.78431 .95611 L
.78353 .95657 L
.75888 .97018 L
.73717 .98077 L
s
.1 g
.98077 .23355 m
.97143 .21647 L
.95651 .19181 L
.95611 .1912 L
.93977 .16716 L
.93146 .1559 L
.92098 .1425 L
.9068 .12564 L
.89986 .11785 L
.88215 .09926 L
.87601 .0932 L
.8575 .07602 L
.84887 .06854 L
.83284 .05543 L
.81762 .04389 L
.80819 .03714 L
.78353 .02088 L
.78086 .01923 L
.98077 .01923 L
F
0 g
.98077 .23355 m
.97143 .21647 L
.95651 .19181 L
.95611 .1912 L
.93977 .16716 L
.93146 .1559 L
.92098 .1425 L
.9068 .12564 L
.89986 .11785 L
.88215 .09926 L
.87601 .0932 L
.8575 .07602 L
.84887 .06854 L
.83284 .05543 L
.81762 .04389 L
.80819 .03714 L
.78353 .02088 L
.78086 .01923 L
s
.98077 .89415 m
.9699 .9068 L
.95611 .92189 L
.94687 .93146 L
.93146 .94652 L
.92104 .95611 L
.9068 .96853 L
.89181 .98077 L
.98077 .98077 L
F
.98077 .89415 m
.9699 .9068 L
.95611 .92189 L
.94687 .93146 L
.93146 .94652 L
.92104 .95611 L
.9068 .96853 L
.89181 .98077 L
s
.98077 .08988 m
.96264 .06854 L
.95611 .06131 L
.93953 .04389 L
.93146 .03586 L
.91376 .01923 L
.98077 .01923 L
F
.98077 .08988 m
.96264 .06854 L
.95611 .06131 L
.93953 .04389 L
.93146 .03586 L
.91376 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.661 .742 .911 r
.39729 .59653 .40512 .60376 .41826 .59989 .41046 .59266 Mtetra
.66 .743 .912 r
.41046 .59266 .41826 .59989 .43146 .59602 .42371 .58879 Mtetra
.658 .744 .913 r
.42371 .58879 .43146 .59602 .44473 .59216 .43701 .58495 Mtetra
.657 .745 .915 r
.43701 .58495 .44473 .59216 .45806 .58832 .45039 .58115 Mtetra
.655 .746 .917 r
.45039 .58115 .45806 .58832 .47146 .58451 .46383 .57738 Mtetra
.653 .748 .919 r
.46383 .57738 .47146 .58451 .48493 .58072 .47734 .57366 Mtetra
.65 .75 .923 r
.47734 .57366 .48493 .58072 .49846 .57696 .49092 .56999 Mtetra
.648 .753 .926 r
.49092 .56999 .49846 .57696 .51207 .57323 .50456 .56638 Mtetra
.645 .756 .93 r
.50456 .56638 .51207 .57323 .52574 .56954 .51829 .56282 Mtetra
.642 .76 .935 r
.51829 .56282 .52574 .56954 .53949 .56587 .53208 .5593 Mtetra
.639 .765 .939 r
.53208 .5593 .53949 .56587 .55331 .56222 .54595 .55582 Mtetra
.636 .77 .944 r
.54595 .55582 .55331 .56222 .5672 .55857 .5599 .55235 Mtetra
.634 .776 .949 r
.5599 .55235 .5672 .55857 .58117 .55491 .57392 .54887 Mtetra
.633 .783 .953 r
.57392 .54887 .58117 .55491 .59522 .55122 .58802 .54536 Mtetra
.633 .789 .957 r
.58802 .54536 .59522 .55122 .60933 .54748 .6022 .54178 Mtetra
.634 .796 .96 r
.6022 .54178 .60933 .54748 .62352 .54366 .61645 .53809 Mtetra
.636 .802 .962 r
.61645 .53809 .62352 .54366 .63779 .53974 .63078 .53428 Mtetra
.639 .807 .964 r
.63078 .53428 .63779 .53974 .65213 .5357 .64518 .53031 Mtetra
.644 .812 .964 r
.64518 .53031 .65213 .5357 .66653 .53154 .65965 .52616 Mtetra
.649 .815 .963 r
.65965 .52616 .66653 .53154 .68101 .52723 .67419 .52183 Mtetra
.655 .817 .961 r
.67419 .52183 .68101 .52723 .69556 .52279 .6888 .5173 Mtetra
.661 .818 .959 r
.6888 .5173 .69556 .52279 .71017 .51821 .70347 .51259 Mtetra
.666 .816 .955 r
.70347 .51259 .71017 .51821 .72485 .51351 .71821 .50772 Mtetra
.671 .813 .951 r
.71821 .50772 .72485 .51351 .7396 .50869 .73301 .50269 Mtetra
.675 .809 .947 r
.73301 .50269 .7396 .50869 .75442 .50379 .74788 .49756 Mtetra
.678 .804 .943 r
.74788 .49756 .75442 .50379 .76931 .49882 .76282 .49233 Mtetra
.68 .798 .938 r
.76282 .49233 .76931 .49882 .78427 .4938 .77783 .48705 Mtetra
.68 .792 .934 r
.77783 .48705 .78427 .4938 .7993 .48876 .79291 .48175 Mtetra
.68 .785 .929 r
.79291 .48175 .7993 .48876 .81441 .48371 .80806 .47644 Mtetra
.679 .779 .926 r
.80806 .47644 .81441 .48371 .82959 .47867 .82329 .47116 Mtetra
.678 .773 .922 r
.82329 .47116 .82959 .47867 .84486 .47365 .83861 .46591 Mtetra
.676 .767 .919 r
.83861 .46591 .84486 .47365 .86021 .46866 .854 .46071 Mtetra
.674 .762 .917 r
.854 .46071 .86021 .46866 .87564 .46369 .86948 .45556 Mtetra
.673 .758 .915 r
.86948 .45556 .87564 .46369 .89116 .45875 .88505 .45046 Mtetra
.671 .754 .913 r
.88505 .45046 .89116 .45875 .90676 .45384 .9007 .44541 Mtetra
.67 .751 .912 r
.9007 .44541 .90676 .45384 .92245 .44894 .91645 .44039 Mtetra
.668 .749 .911 r
.91645 .44039 .92245 .44894 .93822 .44406 .93228 .4354 Mtetra
.667 .747 .91 r
.93228 .4354 .93822 .44406 .95409 .43919 .9482 .43044 Mtetra
.666 .745 .909 r
.9482 .43044 .95409 .43919 .97004 .43431 .96422 .42549 Mtetra
.659 .743 .912 r
.38938 .58927 .39729 .59653 .41046 .59266 .40259 .58539 Mtetra
.658 .743 .913 r
.40259 .58539 .41046 .59266 .42371 .58879 .41588 .58155 Mtetra
.656 .744 .915 r
.41588 .58155 .42371 .58879 .43701 .58495 .42922 .57774 Mtetra
.654 .746 .917 r
.42922 .57774 .43701 .58495 .45039 .58115 .44264 .57399 Mtetra
.651 .747 .92 r
.44264 .57399 .45039 .58115 .46383 .57738 .45612 .5703 Mtetra
.648 .75 .924 r
.45612 .5703 .46383 .57738 .47734 .57366 .46967 .56669 Mtetra
.644 .753 .928 r
.46967 .56669 .47734 .57366 .49092 .56999 .48329 .56315 Mtetra
.64 .756 .933 r
.48329 .56315 .49092 .56999 .50456 .56638 .49699 .5597 Mtetra
.636 .761 .938 r
.49699 .5597 .50456 .56638 .51829 .56282 .51075 .55633 Mtetra
.631 .766 .944 r
.51075 .55633 .51829 .56282 .53208 .5593 .5246 .55303 Mtetra
.627 .772 .95 r
.5246 .55303 .53208 .5593 .54595 .55582 .53852 .54979 Mtetra
.622 .779 .956 r
.53852 .54979 .54595 .55582 .5599 .55235 .55252 .54657 Mtetra
.619 .787 .962 r
.55252 .54657 .5599 .55235 .57392 .54887 .5666 .54335 Mtetra
.616 .796 .968 r
.5666 .54335 .57392 .54887 .58802 .54536 .58076 .54008 Mtetra
.615 .804 .973 r
.58076 .54008 .58802 .54536 .6022 .54178 .595 .53673 Mtetra
.615 .813 .976 r
.595 .53673 .6022 .54178 .61645 .53809 .60932 .53324 Mtetra
.618 .822 .979 r
.60932 .53324 .61645 .53809 .63078 .53428 .62372 .52958 Mtetra
.622 .829 .98 r
.62372 .52958 .63078 .53428 .64518 .53031 .63818 .52571 Mtetra
.629 .836 .98 r
.63818 .52571 .64518 .53031 .65965 .52616 .65272 .5216 Mtetra
.637 .841 .978 r
.65272 .5216 .65965 .52616 .67419 .52183 .66733 .51723 Mtetra
.646 .843 .976 r
.66733 .51723 .67419 .52183 .6888 .5173 .682 .51261 Mtetra
.656 .844 .972 r
.682 .51261 .6888 .5173 .70347 .51259 .69674 .50774 Mtetra
.665 .843 .968 r
.69674 .50774 .70347 .51259 .71821 .50772 .71154 .50264 Mtetra
.672 .839 .963 r
.71154 .50264 .71821 .50772 .73301 .50269 .7264 .49735 Mtetra
.678 .833 .958 r
.7264 .49735 .73301 .50269 .74788 .49756 .74132 .49191 Mtetra
.683 .826 .952 r
.74132 .49191 .74788 .49756 .76282 .49233 .75631 .48636 Mtetra
.686 .818 .946 r
.75631 .48636 .76282 .49233 .77783 .48705 .77136 .48074 Mtetra
.687 .809 .941 r
.77136 .48074 .77783 .48705 .79291 .48175 .78648 .4751 Mtetra
.687 .8 .935 r
.78648 .4751 .79291 .48175 .80806 .47644 .80168 .46947 Mtetra
.685 .792 .931 r
.80168 .46947 .80806 .47644 .82329 .47116 .81696 .46388 Mtetra
.684 .784 .926 r
.81696 .46388 .82329 .47116 .83861 .46591 .83231 .45835 Mtetra
.681 .776 .922 r
.83231 .45835 .83861 .46591 .854 .46071 .84775 .45289 Mtetra
.679 .769 .919 r
.84775 .45289 .854 .46071 .86948 .45556 .86328 .44752 Mtetra
.676 .764 .917 r
.86328 .44752 .86948 .45556 .88505 .45046 .87889 .44222 Mtetra
.674 .759 .914 r
.87889 .44222 .88505 .45046 .9007 .44541 .8946 .43699 Mtetra
.672 .755 .913 r
.8946 .43699 .9007 .44541 .91645 .44039 .91039 .43183 Mtetra
.67 .751 .911 r
.91039 .43183 .91645 .44039 .93228 .4354 .92628 .42671 Mtetra
.669 .749 .91 r
.92628 .42671 .93228 .4354 .9482 .43044 .94226 .42164 Mtetra
.667 .747 .91 r
.94226 .42164 .9482 .43044 .96422 .42549 .95833 .41659 Mtetra
.658 .743 .913 r
.3814 .58196 .38938 .58927 .40259 .58539 .39465 .57811 Mtetra
.656 .744 .915 r
.39465 .57811 .40259 .58539 .41588 .58155 .40797 .57429 Mtetra
.653 .745 .917 r
.40797 .57429 .41588 .58155 .42922 .57774 .42136 .57055 Mtetra
.65 .747 .92 r
.42136 .57055 .42922 .57774 .44264 .57399 .43481 .56688 Mtetra
.646 .749 .924 r
.43481 .56688 .44264 .57399 .45612 .5703 .44834 .5633 Mtetra
.642 .752 .929 r
.44834 .5633 .45612 .5703 .46967 .56669 .46193 .55983 Mtetra
.636 .756 .934 r
.46193 .55983 .46967 .56669 .48329 .56315 .47559 .55648 Mtetra
.63 .76 .941 r
.47559 .55648 .48329 .56315 .49699 .5597 .48933 .55326 Mtetra
.623 .766 .948 r
.48933 .55326 .49699 .5597 .51075 .55633 .50314 .55015 Mtetra
.616 .773 .955 r
.50314 .55015 .51075 .55633 .5246 .55303 .51704 .54715 Mtetra
.608 .781 .963 r
.51704 .54715 .5246 .55303 .53852 .54979 .53101 .54422 Mtetra
.601 .789 .971 r
.53101 .54422 .53852 .54979 .55252 .54657 .54507 .54134 Mtetra
.593 .799 .978 r
.54507 .54134 .55252 .54657 .5666 .54335 .55921 .53847 Mtetra
.588 .81 .984 r
.55921 .53847 .5666 .54335 .58076 .54008 .57343 .53554 Mtetra
.584 .821 .989 r
.57343 .53554 .58076 .54008 .595 .53673 .58774 .53249 Mtetra
.583 .832 .992 r
.58774 .53249 .595 .53673 .60932 .53324 .60213 .52927 Mtetra
.585 .842 .993 r
.60213 .52927 .60932 .53324 .62372 .52958 .6166 .52582 Mtetra
.591 .852 .994 r
.6166 .52582 .62372 .52958 .63818 .52571 .63114 .52208 Mtetra
.601 .861 .992 r
.63114 .52208 .63818 .52571 .65272 .5216 .64575 .51803 Mtetra
.614 .868 .99 r
.64575 .51803 .65272 .5216 .66733 .51723 .66043 .51364 Mtetra
.629 .873 .988 r
.66043 .51364 .66733 .51723 .682 .51261 .67518 .5089 Mtetra
.644 .875 .984 r
.67518 .5089 .682 .51261 .69674 .50774 .68998 .50383 Mtetra
.658 .874 .979 r
.68998 .50383 .69674 .50774 .71154 .50264 .70484 .49846 Mtetra
.671 .87 .974 r
.70484 .49846 .71154 .50264 .7264 .49735 .71976 .49283 Mtetra
.681 .863 .968 r
.71976 .49283 .7264 .49735 .74132 .49191 .73473 .48701 Mtetra
.688 .853 .962 r
.73473 .48701 .74132 .49191 .75631 .48636 .74977 .48104 Mtetra
.693 .843 .955 r
.74977 .48104 .75631 .48636 .77136 .48074 .76487 .475 Mtetra
.695 .831 .948 r
.76487 .475 .77136 .48074 .78648 .4751 .78003 .46893 Mtetra
.695 .819 .942 r
.78003 .46893 .78648 .4751 .80168 .46947 .79527 .46288 Mtetra
.694 .808 .936 r
.79527 .46288 .80168 .46947 .81696 .46388 .81059 .4569 Mtetra
.691 .797 .931 r
.81059 .4569 .81696 .46388 .83231 .45835 .82598 .45101 Mtetra
.688 .787 .926 r
.82598 .45101 .83231 .45835 .84775 .45289 .84146 .44524 Mtetra
.685 .778 .922 r
.84146 .44524 .84775 .45289 .86328 .44752 .85703 .43958 Mtetra
.681 .771 .919 r
.85703 .43958 .86328 .44752 .87889 .44222 .87269 .43403 Mtetra
.678 .764 .916 r
.87269 .43403 .87889 .44222 .8946 .43699 .88844 .4286 Mtetra
.675 .759 .914 r
.88844 .4286 .8946 .43699 .91039 .43183 .90429 .42325 Mtetra
.672 .754 .912 r
.90429 .42325 .91039 .43183 .92628 .42671 .92023 .41799 Mtetra
.67 .751 .911 r
.92023 .41799 .92628 .42671 .94226 .42164 .93627 .41279 Mtetra
.669 .748 .91 r
.93627 .41279 .94226 .42164 .95833 .41659 .9524 .40764 Mtetra
.656 .744 .914 r
.37334 .57463 .3814 .58196 .39465 .57811 .38663 .5708 Mtetra
.653 .745 .917 r
.38663 .5708 .39465 .57811 .40797 .57429 .39999 .56704 Mtetra
.65 .746 .92 r
.39999 .56704 .40797 .57429 .42136 .57055 .41342 .56338 Mtetra
.645 .748 .924 r
.41342 .56338 .42136 .57055 .43481 .56688 .42691 .55982 Mtetra
.64 .751 .929 r
.42691 .55982 .43481 .56688 .44834 .5633 .44047 .5564 Mtetra
.633 .754 .935 r
.44047 .5564 .44834 .5633 .46193 .55983 .4541 .55314 Mtetra
.625 .759 .942 r
.4541 .55314 .46193 .55983 .47559 .55648 .46781 .55003 Mtetra
.616 .764 .951 r
.46781 .55003 .47559 .55648 .48933 .55326 .48159 .5471 Mtetra
.605 .771 .96 r
.48159 .5471 .48933 .55326 .50314 .55015 .49545 .54434 Mtetra
.593 .779 .969 r
.49545 .54434 .50314 .55015 .51704 .54715 .50939 .54172 Mtetra
.58 .788 .978 r
.50939 .54172 .51704 .54715 .53101 .54422 .52342 .53922 Mtetra
.566 .799 .987 r
.52342 .53922 .53101 .54422 .54507 .54134 .53754 .53679 Mtetra
.553 .81 .993 r
.53754 .53679 .54507 .54134 .55921 .53847 .55174 .53437 Mtetra
.54 .821 .998 r
.55174 .53437 .55921 .53847 .57343 .53554 .56603 .53187 Mtetra
.531 .832 .999 r
.56603 .53187 .57343 .53554 .58774 .53249 .58041 .52923 Mtetra
.526 .844 .999 r
.58041 .52923 .58774 .53249 .60213 .52927 .59488 .52636 Mtetra
.527 .856 .996 r
.59488 .52636 .60213 .52927 .6166 .52582 .60942 .52319 Mtetra
.534 .868 .993 r
.60942 .52319 .6166 .52582 .63114 .52208 .62405 .51964 Mtetra
.549 .88 .99 r
.62405 .51964 .63114 .52208 .64575 .51803 .63874 .51567 Mtetra
.569 .891 .988 r
.63874 .51567 .64575 .51803 .66043 .51364 .6535 .51125 Mtetra
.593 .899 .986 r
.6535 .51125 .66043 .51364 .67518 .5089 .66832 .50637 Mtetra
.619 .905 .985 r
.66832 .50637 .67518 .5089 .68998 .50383 .68319 .50105 Mtetra
.643 .906 .982 r
.68319 .50105 .68998 .50383 .70484 .49846 .69812 .49534 Mtetra
.664 .903 .979 r
.69812 .49534 .70484 .49846 .71976 .49283 .7131 .48929 Mtetra
.681 .896 .974 r
.7131 .48929 .71976 .49283 .73473 .48701 .72812 .48299 Mtetra
.694 .885 .969 r
.72812 .48299 .73473 .48701 .74977 .48104 .74321 .4765 Mtetra
.701 .872 .962 r
.74321 .4765 .74977 .48104 .76487 .475 .75835 .46992 Mtetra
.705 .857 .955 r
.75835 .46992 .76487 .475 .78003 .46893 .77356 .46332 Mtetra
.706 .842 .948 r
.77356 .46332 .78003 .46893 .79527 .46288 .78883 .45676 Mtetra
.704 .827 .941 r
.78883 .45676 .79527 .46288 .81059 .4569 .80418 .45029 Mtetra
.701 .813 .935 r
.80418 .45029 .81059 .4569 .82598 .45101 .81961 .44396 Mtetra
.696 .8 .929 r
.81961 .44396 .82598 .45101 .84146 .44524 .83513 .43779 Mtetra
.692 .789 .925 r
.83513 .43779 .84146 .44524 .85703 .43958 .85074 .43178 Mtetra
.687 .779 .921 r
.85074 .43178 .85703 .43958 .87269 .43403 .86644 .42594 Mtetra
.683 .771 .918 r
.86644 .42594 .87269 .43403 .88844 .4286 .88224 .42025 Mtetra
.679 .764 .915 r
.88224 .42025 .88844 .4286 .90429 .42325 .89813 .41469 Mtetra
.676 .758 .913 r
.89813 .41469 .90429 .42325 .92023 .41799 .91413 .40925 Mtetra
.673 .754 .912 r
.91413 .40925 .92023 .41799 .93627 .41279 .93021 .40391 Mtetra
.67 .75 .91 r
.93021 .40391 .93627 .41279 .9524 .40764 .9464 .39863 Mtetra
.653 .744 .916 r
.36521 .56726 .37334 .57463 .38663 .5708 .37854 .56348 Mtetra
.65 .745 .919 r
.37854 .56348 .38663 .5708 .39999 .56704 .39193 .5598 Mtetra
.645 .747 .923 r
.39193 .5598 .39999 .56704 .41342 .56338 .4054 .55625 Mtetra
.639 .749 .929 r
.4054 .55625 .41342 .56338 .42691 .55982 .41893 .55285 Mtetra
.631 .753 .935 r
.41893 .55285 .42691 .55982 .44047 .5564 .43253 .54963 Mtetra
.621 .757 .943 r
.43253 .54963 .44047 .5564 .4541 .55314 .4462 .54663 Mtetra
.61 .762 .952 r
.4462 .54663 .4541 .55314 .46781 .55003 .45994 .54384 Mtetra
.596 .768 .962 r
.45994 .54384 .46781 .55003 .48159 .5471 .47376 .5413 Mtetra
.579 .776 .973 r
.47376 .5413 .48159 .5471 .49545 .54434 .48767 .53897 Mtetra
.559 .784 .983 r
.48767 .53897 .49545 .54434 .50939 .54172 .50166 .53685 Mtetra
.537 .793 .992 r
.50166 .53685 .50939 .54172 .52342 .53922 .51574 .53489 Mtetra
.512 .802 .998 r
.51574 .53489 .52342 .53922 .53754 .53679 .52992 .53303 Mtetra
.486 .811 1 r
.52992 .53303 .53754 .53679 .55174 .53437 .54419 .53117 Mtetra
.461 .819 .996 r
.54419 .53117 .55174 .53437 .56603 .53187 .55855 .52924 Mtetra
.44 .826 .987 r
.55855 .52924 .56603 .53187 .58041 .52923 .57301 .52712 Mtetra
.426 .833 .975 r
.57301 .52712 .58041 .52923 .59488 .52636 .58756 .5247 Mtetra
.423 .842 .962 r
.58756 .5247 .59488 .52636 .60942 .52319 .60219 .52188 Mtetra
.432 .854 .952 r
.60219 .52188 .60942 .52319 .62405 .51964 .6169 .51857 Mtetra
.454 .87 .947 r
.6169 .51857 .62405 .51964 .63874 .51567 .63168 .51471 Mtetra
.486 .887 .947 r
.63168 .51471 .63874 .51567 .6535 .51125 .64653 .51025 Mtetra
.526 .905 .951 r
.64653 .51025 .6535 .51125 .66832 .50637 .66143 .5052 Mtetra
.569 .92 .958 r
.66143 .5052 .66832 .50637 .68319 .50105 .67638 .49958 Mtetra
.61 .93 .964 r
.67638 .49958 .68319 .50105 .69812 .49534 .69137 .49345 Mtetra
.647 .933 .969 r
.69137 .49345 .69812 .49534 .7131 .48929 .70641 .48689 Mtetra
.676 .929 .97 r
.70641 .48689 .7131 .48929 .72812 .48299 .7215 .47999 Mtetra
.697 .919 .969 r
.7215 .47999 .72812 .48299 .74321 .4765 .73663 .47286 Mtetra
.71 .904 .965 r
.73663 .47286 .74321 .4765 .75835 .46992 .75181 .46562 Mtetra
.717 .886 .959 r
.75181 .46562 .75835 .46992 .77356 .46332 .76706 .45836 Mtetra
.719 .868 .952 r
.76706 .45836 .77356 .46332 .78883 .45676 .78237 .45116 Mtetra
.717 .849 .945 r
.78237 .45116 .78883 .45676 .80418 .45029 .79775 .44411 Mtetra
.712 .831 .938 r
.79775 .44411 .80418 .45029 .81961 .44396 .81321 .43724 Mtetra
.707 .815 .932 r
.81321 .43724 .81961 .44396 .83513 .43779 .82876 .43058 Mtetra
.701 .801 .927 r
.82876 .43058 .83513 .43779 .85074 .43178 .84441 .42415 Mtetra
.695 .788 .923 r
.84441 .42415 .85074 .43178 .86644 .42594 .86015 .41795 Mtetra
.689 .778 .919 r
.86015 .41795 .86644 .42594 .88224 .42025 .87599 .41196 Mtetra
.684 .769 .916 r
.87599 .41196 .88224 .42025 .89813 .41469 .89192 .40615 Mtetra
.679 .762 .914 r
.89192 .40615 .89813 .41469 .91413 .40925 .90797 .4005 Mtetra
.676 .757 .912 r
.90797 .4005 .91413 .40925 .93021 .40391 .92411 .39498 Mtetra
.672 .753 .911 r
.92411 .39498 .93021 .40391 .9464 .39863 .94035 .38957 Mtetra
.65 .744 .918 r
.357 .55987 .36521 .56726 .37854 .56348 .37036 .55615 Mtetra
.645 .746 .922 r
.37036 .55615 .37854 .56348 .39193 .5598 .3838 .55258 Mtetra
.639 .748 .928 r
.3838 .55258 .39193 .5598 .4054 .55625 .39729 .54917 Mtetra
.63 .75 .934 r
.39729 .54917 .4054 .55625 .41893 .55285 .41086 .54597 Mtetra
.62 .754 .942 r
.41086 .54597 .41893 .55285 .43253 .54963 .42449 .54301 Mtetra
.606 .758 .952 r
.42449 .54301 .43253 .54963 .4462 .54663 .4382 .54033 Mtetra
.589 .764 .962 r
.4382 .54033 .4462 .54663 .45994 .54384 .45198 .53795 Mtetra
.568 .77 .974 r
.45198 .53795 .45994 .54384 .47376 .5413 .46585 .53588 Mtetra
.541 .777 .985 r
.46585 .53588 .47376 .5413 .48767 .53897 .4798 .53411 Mtetra
.508 .784 .995 r
.4798 .53411 .48767 .53897 .50166 .53685 .49384 .5326 Mtetra
.47 .789 .999 r
.49384 .5326 .50166 .53685 .51574 .53489 .50797 .53131 Mtetra
.425 .79 .995 r
.50797 .53131 .51574 .53489 .52992 .53303 .52221 .53014 Mtetra
.378 .788 .981 r
.52221 .53014 .52992 .53303 .54419 .53117 .53654 .529 Mtetra
.332 .782 .955 r
.53654 .529 .54419 .53117 .55855 .52924 .55098 .52776 Mtetra
.293 .773 .922 r
.55098 .52776 .55855 .52924 .57301 .52712 .56552 .52628 Mtetra
.268 .767 .886 r
.56552 .52628 .57301 .52712 .58756 .5247 .58016 .52442 Mtetra
.261 .768 .856 r
.58016 .52442 .58756 .5247 .60219 .52188 .59488 .52204 Mtetra
.273 .778 .836 r
.59488 .52204 .60219 .52188 .6169 .51857 .60969 .51903 Mtetra
.306 .799 .83 r
.60969 .51903 .6169 .51857 .63168 .51471 .62457 .51531 Mtetra
.355 .829 .838 r
.62457 .51531 .63168 .51471 .64653 .51025 .63951 .51083 Mtetra
.416 .865 .857 r
.63951 .51083 .64653 .51025 .66143 .5052 .6545 .50557 Mtetra
.484 .9 .882 r
.6545 .50557 .66143 .5052 .67638 .49958 .66953 .49959 Mtetra
.551 .929 .908 r
.66953 .49959 .67638 .49958 .69137 .49345 .6846 .49294 Mtetra
.612 .948 .931 r
.6846 .49294 .69137 .49345 .70641 .48689 .69971 .48575 Mtetra
.66 .954 .947 r
.69971 .48575 .70641 .48689 .7215 .47999 .71485 .47813 Mtetra
.695 .949 .956 r
.71485 .47813 .7215 .47999 .73663 .47286 .73003 .47023 Mtetra
.718 .936 .959 r
.73003 .47023 .73663 .47286 .75181 .46562 .74525 .46219 Mtetra
.73 .917 .957 r
.74525 .46219 .75181 .46562 .76706 .45836 .76053 .45413 Mtetra
.733 .895 .953 r
.76053 .45413 .76706 .45836 .78237 .45116 .77587 .44617 Mtetra
.732 .873 .947 r
.77587 .44617 .78237 .45116 .79775 .44411 .79128 .4384 Mtetra
.727 .852 .94 r
.79128 .4384 .79775 .44411 .81321 .43724 .80678 .43088 Mtetra
.72 .832 .934 r
.80678 .43088 .81321 .43724 .82876 .43058 .82236 .42365 Mtetra
.712 .814 .929 r
.82236 .42365 .82876 .43058 .84441 .42415 .83803 .41672 Mtetra
.704 .799 .924 r
.83803 .41672 .84441 .42415 .86015 .41795 .8538 .41009 Mtetra
.696 .786 .92 r
.8538 .41009 .86015 .41795 .87599 .41196 .86968 .40374 Mtetra
.69 .776 .917 r
.86968 .40374 .87599 .41196 .89192 .40615 .88566 .39764 Mtetra
.684 .767 .915 r
.88566 .39764 .89192 .40615 .90797 .4005 .90175 .39175 Mtetra
.679 .76 .913 r
.90175 .39175 .90797 .4005 .92411 .39498 .91795 .38603 Mtetra
.675 .755 .911 r
.91795 .38603 .92411 .39498 .94035 .38957 .93424 .38045 Mtetra
.646 .745 .921 r
.3487 .55246 .357 .55987 .37036 .55615 .36211 .54883 Mtetra
.64 .746 .926 r
.36211 .54883 .37036 .55615 .3838 .55258 .37557 .54538 Mtetra
.631 .748 .932 r
.37557 .54538 .3838 .55258 .39729 .54917 .38911 .54215 Mtetra
.62 .751 .94 r
.38911 .54215 .39729 .54917 .41086 .54597 .40271 .5392 Mtetra
.605 .755 .95 r
.40271 .5392 .41086 .54597 .42449 .54301 .41637 .53656 Mtetra
.586 .759 .961 r
.41637 .53656 .42449 .54301 .4382 .54033 .43011 .53428 Mtetra
.561 .764 .973 r
.43011 .53428 .4382 .54033 .45198 .53795 .44393 .53238 Mtetra
.528 .769 .985 r
.44393 .53238 .45198 .53795 .46585 .53588 .45783 .53089 Mtetra
.486 .772 .995 r
.45783 .53089 .46585 .53588 .4798 .53411 .47182 .52978 Mtetra
.433 .771 .997 r
.47182 .52978 .4798 .53411 .49384 .5326 .48591 .52902 Mtetra
.369 .764 .987 r
.48591 .52902 .49384 .5326 .50797 .53131 .5001 .52853 Mtetra
.295 .746 .958 r
.5001 .52853 .50797 .53131 .52221 .53014 .51439 .52822 Mtetra
.217 .718 .909 r
.51439 .52822 .52221 .53014 .53654 .529 .5288 .52794 Mtetra
.147 .684 .844 r
.5288 .52794 .53654 .529 .55098 .52776 .54332 .52753 Mtetra
.094 .651 .775 r
.54332 .52753 .55098 .52776 .56552 .52628 .55794 .52683 Mtetra
.063 .627 .713 r
.55794 .52683 .56552 .52628 .58016 .52442 .57267 .52564 Mtetra
0 0 0 r
.57267 .52564 .58016 .52442 .59488 .52204 .5875 .52379 Mtetra
.5875 .52379 .59488 .52204 .60969 .51903 .60241 .52115 Mtetra
.60241 .52115 .60969 .51903 .62457 .51531 .61739 .5176 Mtetra
.61739 .5176 .62457 .51531 .63951 .51083 .63243 .51308 Mtetra
.273 .766 .7 r
.63243 .51308 .63951 .51083 .6545 .50557 .64752 .50759 Mtetra
.368 .829 .75 r
.64752 .50759 .6545 .50557 .66953 .49959 .66264 .50117 Mtetra
.466 .888 .805 r
.66264 .50117 .66953 .49959 .6846 .49294 .6778 .49391 Mtetra
.556 .934 .856 r
.6778 .49391 .6846 .49294 .69971 .48575 .69297 .48596 Mtetra
.631 .961 .897 r
.69297 .48596 .69971 .48575 .71485 .47813 .70818 .47749 Mtetra
.687 .97 .925 r
.70818 .47749 .71485 .47813 .73003 .47023 .72341 .46866 Mtetra
.723 .963 .941 r
.72341 .46866 .73003 .47023 .74525 .46219 .73867 .45967 Mtetra
.742 .946 .947 r
.73867 .45967 .74525 .46219 .76053 .45413 .75398 .45067 Mtetra
.75 .923 .948 r
.75398 .45067 .76053 .45413 .77587 .44617 .76935 .44181 Mtetra
.749 .898 .945 r
.76935 .44181 .77587 .44617 .79128 .4384 .78479 .4332 Mtetra
.743 .873 .94 r
.78479 .4332 .79128 .4384 .80678 .43088 .8003 .42492 Mtetra
.734 .849 .935 r
.8003 .42492 .80678 .43088 .82236 .42365 .81591 .41701 Mtetra
.725 .829 .929 r
.81591 .41701 .82236 .42365 .83803 .41672 .83161 .40949 Mtetra
.714 .811 .925 r
.83161 .40949 .83803 .41672 .8538 .41009 .84742 .40237 Mtetra
.705 .795 .921 r
.84742 .40237 .8538 .41009 .86968 .40374 .86333 .3956 Mtetra
.697 .783 .917 r
.86333 .3956 .86968 .40374 .88566 .39764 .87935 .38915 Mtetra
.689 .772 .915 r
.87935 .38915 .88566 .39764 .90175 .39175 .89548 .38299 Mtetra
.683 .764 .913 r
.89548 .38299 .90175 .39175 .91795 .38603 .91173 .37704 Mtetra
.678 .758 .911 r
.91173 .37704 .91795 .38603 .93424 .38045 .92808 .37128 Mtetra
.642 .745 .924 r
.34033 .54502 .3487 .55246 .36211 .54883 .35377 .5415 Mtetra
.633 .746 .93 r
.35377 .5415 .36211 .54883 .37557 .54538 .36727 .53821 Mtetra
.622 .748 .937 r
.36727 .53821 .37557 .54538 .38911 .54215 .38083 .5352 Mtetra
.607 .751 .947 r
.38083 .5352 .38911 .54215 .40271 .5392 .39446 .53254 Mtetra
.586 .754 .958 r
.39446 .53254 .40271 .5392 .41637 .53656 .40816 .53027 Mtetra
.559 .757 .97 r
.40816 .53027 .41637 .53656 .43011 .53428 .42193 .52847 Mtetra
.523 .76 .983 r
.42193 .52847 .43011 .53428 .44393 .53238 .43578 .52715 Mtetra
.474 .76 .993 r
.43578 .52715 .44393 .53238 .45783 .53089 .44972 .52633 Mtetra
.41 .754 .994 r
.44972 .52633 .45783 .53089 .47182 .52978 .46375 .52601 Mtetra
.327 .737 .979 r
.46375 .52601 .47182 .52978 .48591 .52902 .47788 .52612 Mtetra
.227 .703 .937 r
.47788 .52612 .48591 .52902 .5001 .52853 .49212 .52658 Mtetra
.118 .651 .864 r
.49212 .52658 .5001 .52853 .51439 .52822 .50647 .52727 Mtetra
.017 .587 .767 r
.50647 .52727 .51439 .52822 .5288 .52794 .52095 .528 Mtetra
.063 0 0 r
.52095 .528 .5288 .52794 .54332 .52753 .53554 .52858 Mtetra
.114 0 0 r
.53554 .52858 .54332 .52753 .55794 .52683 .55026 .52879 Mtetra
.135 0 0 r
.55026 .52879 .55794 .52683 .57267 .52564 .56509 .5284 Mtetra
.128 0 0 r
.56509 .5284 .57267 .52564 .5875 .52379 .58002 .52719 Mtetra
.097 0 0 r
.58002 .52719 .5875 .52379 .60241 .52115 .59504 .52497 Mtetra
.042 0 0 r
.59504 .52497 .60241 .52115 .61739 .5176 .61014 .52163 Mtetra
0 0 0 r
.61014 .52163 .61739 .5176 .63243 .51308 .62529 .51707 Mtetra
.62529 .51707 .63243 .51308 .64752 .50759 .64049 .51129 Mtetra
.64049 .51129 .64752 .50759 .66264 .50117 .65571 .50436 Mtetra
.369 .813 .671 r
.65571 .50436 .66264 .50117 .6778 .49391 .67095 .49639 Mtetra
.488 .891 .752 r
.67095 .49639 .6778 .49391 .69297 .48596 .6862 .48756 Mtetra
.593 .946 .822 r
.6862 .48756 .69297 .48596 .70818 .47749 .70147 .47808 Mtetra
.672 .976 .875 r
.70147 .47808 .70818 .47749 .72341 .46866 .71675 .46818 Mtetra
.725 .981 .909 r
.71675 .46818 .72341 .46866 .73867 .45967 .73206 .45808 Mtetra
.755 .97 .928 r
.73206 .45808 .73867 .45967 .75398 .45067 .7474 .44799 Mtetra
.768 .948 .936 r
.7474 .44799 .75398 .45067 .76935 .44181 .7628 .43808 Mtetra
.768 .921 .938 r
.7628 .43808 .76935 .44181 .78479 .4332 .77825 .4285 Mtetra
.762 .893 .936 r
.77825 .4285 .78479 .4332 .8003 .42492 .79379 .41934 Mtetra
.751 .867 .932 r
.79379 .41934 .8003 .42492 .81591 .41701 .80942 .41065 Mtetra
.739 .843 .928 r
.80942 .41065 .81591 .41701 .83161 .40949 .82514 .40247 Mtetra
.727 .822 .924 r
.82514 .40247 .83161 .40949 .84742 .40237 .84098 .39477 Mtetra
.715 .804 .92 r
.84098 .39477 .84742 .40237 .86333 .3956 .85692 .38753 Mtetra
.704 .79 .917 r
.85692 .38753 .86333 .3956 .87935 .38915 .87298 .3807 Mtetra
.695 .778 .915 r
.87298 .3807 .87935 .38915 .89548 .38299 .88916 .37422 Mtetra
.688 .768 .913 r
.88916 .37422 .89548 .38299 .91173 .37704 .90545 .36803 Mtetra
.681 .761 .911 r
.90545 .36803 .91173 .37704 .92808 .37128 .92185 .36206 Mtetra
.636 .744 .927 r
.33187 .53756 .34033 .54502 .35377 .5415 .34534 .53417 Mtetra
.625 .746 .934 r
.34534 .53417 .35377 .5415 .36727 .53821 .35888 .53106 Mtetra
.611 .748 .942 r
.35888 .53106 .36727 .53821 .38083 .5352 .37247 .52831 Mtetra
.591 .75 .953 r
.37247 .52831 .38083 .5352 .39446 .53254 .38613 .52598 Mtetra
.563 .752 .966 r
.38613 .52598 .39446 .53254 .40816 .53027 .39985 .52415 Mtetra
.526 .753 .979 r
.39985 .52415 .40816 .53027 .42193 .52847 .41365 .52289 Mtetra
.474 .75 .99 r
.41365 .52289 .42193 .52847 .43578 .52715 .42753 .52223 Mtetra
.403 .74 .993 r
.42753 .52223 .43578 .52715 .44972 .52633 .44149 .52219 Mtetra
.307 .717 .977 r
.44149 .52219 .44972 .52633 .46375 .52601 .45556 .52277 Mtetra
.187 .67 .928 r
.45556 .52277 .46375 .52601 .47788 .52612 .46973 .52389 Mtetra
.051 .598 .838 r
.46973 .52389 .47788 .52612 .49212 .52658 .48401 .52544 Mtetra
0 .508 .714 r
.48401 .52544 .49212 .52658 .50647 .52727 .49843 .52727 Mtetra
.181 0 0 r
.49843 .52727 .50647 .52727 .52095 .528 .51297 .52916 Mtetra
.249 0 0 r
.51297 .52916 .52095 .528 .53554 .52858 .52765 .53088 Mtetra
.282 0 0 r
.52765 .53088 .53554 .52858 .55026 .52879 .54246 .53213 Mtetra
.287 0 0 r
.54246 .53213 .55026 .52879 .56509 .5284 .55739 .53265 Mtetra
.267 0 0 r
.55739 .53265 .56509 .5284 .58002 .52719 .57244 .53216 Mtetra
.226 0 0 r
.57244 .53216 .58002 .52719 .59504 .52497 .58758 .53045 Mtetra
.165 0 0 r
.58758 .53045 .59504 .52497 .61014 .52163 .6028 .52733 Mtetra
.082 0 0 r
.6028 .52733 .61014 .52163 .62529 .51707 .61807 .52273 Mtetra
0 0 0 r
.61807 .52273 .62529 .51707 .64049 .51129 .63338 .51662 Mtetra
.63338 .51662 .64049 .51129 .65571 .50436 .64871 .5091 Mtetra
.64871 .5091 .65571 .50436 .67095 .49639 .66405 .50031 Mtetra
.427 .834 .643 r
.66405 .50031 .67095 .49639 .6862 .48756 .67938 .49047 Mtetra
.556 .917 .738 r
.67938 .49047 .6862 .48756 .70147 .47808 .69471 .47985 Mtetra
.658 .969 .814 r
.69471 .47985 .70147 .47808 .71675 .46818 .71005 .46872 Mtetra
.728 .99 .867 r
.71005 .46872 .71675 .46818 .73206 .45808 .7254 .45737 Mtetra
.769 .986 .9 r
.7254 .45737 .73206 .45808 .7474 .44799 .74078 .44604 Mtetra
.787 .967 .918 r
.74078 .44604 .7474 .44799 .7628 .43808 .7562 .43495 Mtetra
.789 .94 .926 r
.7562 .43495 .7628 .43808 .77825 .4285 .77168 .42427 Mtetra
.782 .911 .928 r
.77168 .42427 .77825 .4285 .79379 .41934 .78723 .41412 Mtetra
.77 .883 .927 r
.78723 .41412 .79379 .41934 .80942 .41065 .80288 .40456 Mtetra
.755 .856 .925 r
.80288 .40456 .80942 .41065 .82514 .40247 .81863 .39563 Mtetra
.74 .833 .922 r
.81863 .39563 .82514 .40247 .84098 .39477 .83448 .38729 Mtetra
.726 .813 .919 r
.83448 .38729 .84098 .39477 .85692 .38753 .85046 .37953 Mtetra
.713 .797 .916 r
.85046 .37953 .85692 .38753 .87298 .3807 .86656 .37227 Mtetra
.702 .783 .914 r
.86656 .37227 .87298 .3807 .88916 .37422 .88277 .36544 Mtetra
.693 .772 .912 r
.88277 .36544 .88916 .37422 .90545 .36803 .89911 .35897 Mtetra
.685 .764 .911 r
.89911 .35897 .90545 .36803 .92185 .36206 .91556 .35279 Mtetra
.63 .744 .93 r
.32333 .53007 .33187 .53756 .34534 .53417 .33684 .52682 Mtetra
.616 .745 .938 r
.33684 .52682 .34534 .53417 .35888 .53106 .3504 .52392 Mtetra
.598 .746 .948 r
.3504 .52392 .35888 .53106 .37247 .52831 .36402 .52146 Mtetra
.572 .747 .96 r
.36402 .52146 .37247 .52831 .38613 .52598 .3777 .51951 Mtetra
.535 .747 .973 r
.3777 .51951 .38613 .52598 .39985 .52415 .39145 .51817 Mtetra
.485 .743 .985 r
.39145 .51817 .39985 .52415 .41365 .52289 .40527 .51751 Mtetra
.413 .732 .991 r
.40527 .51751 .41365 .52289 .42753 .52223 .41917 .51759 Mtetra
.313 .705 .979 r
.41917 .51759 .42753 .52223 .44149 .52219 .43316 .51842 Mtetra
.181 .654 .933 r
.43316 .51842 .44149 .52219 .45556 .52277 .44725 .52 Mtetra
.025 .57 .839 r
.44725 .52 .45556 .52277 .46973 .52389 .46146 .52224 Mtetra
0 .461 .7 r
.46146 .52224 .46973 .52389 .48401 .52544 .47579 .52501 Mtetra
.256 0 0 r
.47579 .52501 .48401 .52544 .49843 .52727 .49026 .52811 Mtetra
.34 0 0 r
.49026 .52811 .49843 .52727 .51297 .52916 .50487 .53131 Mtetra
.385 0 0 r
.50487 .53131 .51297 .52916 .52765 .53088 .51962 .53428 Mtetra
.4 0 0 r
.51962 .53428 .52765 .53088 .54246 .53213 .53453 .53671 Mtetra
.39 0 0 r
.53453 .53671 .54246 .53213 .55739 .53265 .54957 .53825 Mtetra
.361 0 0 r
.54957 .53825 .55739 .53265 .57244 .53216 .56473 .53857 Mtetra
.313 0 0 r
.56473 .53857 .57244 .53216 .58758 .53045 .58 .5374 Mtetra
.246 0 0 r
.58 .5374 .58758 .53045 .6028 .52733 .59535 .53454 Mtetra
.159 0 0 r
.59535 .53454 .6028 .52733 .61807 .52273 .61075 .52988 Mtetra
.049 0 0 r
.61075 .52988 .61807 .52273 .63338 .51662 .62618 .5234 Mtetra
0 0 0 r
.62618 .5234 .63338 .51662 .64871 .5091 .64163 .51522 Mtetra
.64163 .51522 .64871 .5091 .66405 .50031 .65707 .50551 Mtetra
.65707 .50551 .66405 .50031 .67938 .49047 .67249 .49455 Mtetra
.535 .889 .664 r
.67249 .49455 .67938 .49047 .69471 .47985 .6879 .48265 Mtetra
.654 .958 .757 r
.6879 .48265 .69471 .47985 .71005 .46872 .70329 .47016 Mtetra
.737 .991 .825 r
.70329 .47016 .71005 .46872 .7254 .45737 .71869 .45741 Mtetra
.785 .995 .869 r
.71869 .45741 .7254 .45737 .74078 .44604 .7341 .44471 Mtetra
.807 .98 .896 r
.7341 .44471 .74078 .44604 .7562 .43495 .74954 .43231 Mtetra
.811 .955 .91 r
.74954 .43231 .7562 .43495 .77168 .42427 .76504 .42043 Mtetra
.803 .925 .917 r
.76504 .42043 .77168 .42427 .78723 .41412 .78062 .40919 Mtetra
.789 .895 .919 r
.78062 .40919 .78723 .41412 .80288 .40456 .79628 .39868 Mtetra
.772 .868 .919 r
.79628 .39868 .80288 .40456 .81863 .39563 .81205 .38892 Mtetra
.754 .843 .918 r
.81205 .38892 .81863 .39563 .83448 .38729 .82793 .3799 Mtetra
.737 .821 .916 r
.82793 .3799 .83448 .38729 .85046 .37953 .84394 .37156 Mtetra
.722 .803 .915 r
.84394 .37156 .85046 .37953 .86656 .37227 .86007 .36383 Mtetra
.709 .788 .913 r
.86007 .36383 .86656 .37227 .88277 .36544 .87632 .35663 Mtetra
.698 .776 .912 r
.87632 .35663 .88277 .36544 .89911 .35897 .89271 .34986 Mtetra
.689 .767 .91 r
.89271 .34986 .89911 .35897 .91556 .35279 .90921 .34344 Mtetra
.623 .743 .933 r
.31471 .52254 .32333 .53007 .33684 .52682 .32824 .51945 Mtetra
.606 .743 .942 r
.32824 .51945 .33684 .52682 .3504 .52392 .34183 .51678 Mtetra
.583 .743 .953 r
.34183 .51678 .3504 .52392 .36402 .52146 .35547 .51463 Mtetra
.55 .742 .966 r
.35547 .51463 .36402 .52146 .3777 .51951 .36918 .51309 Mtetra
.503 .738 .979 r
.36918 .51309 .3777 .51951 .39145 .51817 .38294 .51228 Mtetra
.436 .727 .987 r
.38294 .51228 .39145 .51817 .40527 .51751 .39678 .51228 Mtetra
.34 .703 .983 r
.39678 .51228 .40527 .51751 .41917 .51759 .4107 .51315 Mtetra
.208 .653 .949 r
.4107 .51315 .41917 .51759 .43316 .51842 .42471 .51493 Mtetra
.042 .567 .864 r
.42471 .51493 .43316 .51842 .44725 .52 .43883 .51759 Mtetra
0 .448 .724 r
.43883 .51759 .44725 .52 .46146 .52224 .45306 .52104 Mtetra
.286 0 0 r
.45306 .52104 .46146 .52224 .47579 .52501 .46743 .52513 Mtetra
.392 0 0 r
.46743 .52513 .47579 .52501 .49026 .52811 .48195 .52962 Mtetra
.452 0 0 r
.48195 .52962 .49026 .52811 .50487 .53131 .49662 .53422 Mtetra
.478 0 0 r
.49662 .53422 .50487 .53131 .51962 .53428 .51146 .53857 Mtetra
.479 0 0 r
.51146 .53857 .51962 .53428 .53453 .53671 .52646 .54226 Mtetra
.459 0 0 r
.52646 .54226 .53453 .53671 .54957 .53825 .5416 .5449 Mtetra
.423 0 0 r
.5416 .5449 .54957 .53825 .56473 .53857 .55689 .5461 Mtetra
.369 0 0 r
.55689 .5461 .56473 .53857 .58 .5374 .57229 .54553 Mtetra
.296 0 0 r
.57229 .54553 .58 .5374 .59535 .53454 .58777 .54294 Mtetra
.203 0 0 r
.58777 .54294 .59535 .53454 .61075 .52988 .60331 .53821 Mtetra
.086 0 0 r
.60331 .53821 .61075 .52988 .62618 .5234 .61887 .53133 Mtetra
0 0 0 r
.61887 .53133 .62618 .5234 .64163 .51522 .63444 .52241 Mtetra
.63444 .52241 .64163 .51522 .65707 .50551 .64999 .5117 Mtetra
.64999 .5117 .65707 .50551 .67249 .49455 .66551 .49951 Mtetra
.541 .878 .618 r
.66551 .49951 .67249 .49455 .6879 .48265 .68099 .48623 Mtetra
.668 .953 .717 r
.68099 .48623 .6879 .48265 .70329 .47016 .69645 .47226 Mtetra
.756 .991 .791 r
.69645 .47226 .70329 .47016 .71869 .45741 .7119 .458 Mtetra
.807 .999 .841 r
.7119 .458 .71869 .45741 .7341 .44471 .72735 .44382 Mtetra
.829 .986 .873 r
.72735 .44382 .7341 .44471 .74954 .43231 .74282 .43003 Mtetra
.832 .963 .892 r
.74282 .43003 .74954 .43231 .76504 .42043 .75834 .41685 Mtetra
.823 .934 .903 r
.75834 .41685 .76504 .42043 .78062 .40919 .77394 .40444 Mtetra
.807 .904 .909 r
.77394 .40444 .78062 .40919 .79628 .39868 .78962 .39291 Mtetra
.788 .876 .911 r
.78962 .39291 .79628 .39868 .81205 .38892 .80541 .38228 Mtetra
.768 .85 .912 r
.80541 .38228 .81205 .38892 .82793 .3799 .82131 .37253 Mtetra
.749 .827 .912 r
.82131 .37253 .82793 .3799 .84394 .37156 .83735 .36358 Mtetra
.732 .808 .912 r
.83735 .36358 .84394 .37156 .86007 .36383 .85351 .35536 Mtetra
.717 .792 .911 r
.85351 .35536 .86007 .36383 .87632 .35663 .86981 .34776 Mtetra
.704 .779 .91 r
.86981 .34776 .87632 .35663 .89271 .34986 .88624 .34068 Mtetra
.694 .769 .909 r
.88624 .34068 .89271 .34986 .90921 .34344 .9028 .33402 Mtetra
.616 .741 .935 r
.306 .51496 .31471 .52254 .32824 .51945 .31956 .51204 Mtetra
.596 .741 .945 r
.31956 .51204 .32824 .51945 .34183 .51678 .33317 .50961 Mtetra
.567 .739 .957 r
.33317 .50961 .34183 .51678 .35547 .51463 .34683 .50778 Mtetra
.526 .735 .97 r
.34683 .50778 .35547 .51463 .36918 .51309 .36056 .50668 Mtetra
.467 .726 .982 r
.36056 .50668 .36918 .51309 .38294 .51228 .37434 .50642 Mtetra
.382 .705 .985 r
.37434 .50642 .38294 .51228 .39678 .51228 .38819 .50711 Mtetra
.26 .663 .966 r
.38819 .50711 .39678 .51228 .4107 .51315 .40213 .50882 Mtetra
.097 .586 .903 r
.40213 .50882 .4107 .51315 .42471 .51493 .41615 .51159 Mtetra
0 .469 .78 r
.41615 .51159 .42471 .51493 .43883 .51759 .43028 .51538 Mtetra
.271 0 0 r
.43028 .51538 .43883 .51759 .45306 .52104 .44454 .5201 Mtetra
.405 0 0 r
.44454 .5201 .45306 .52104 .46743 .52513 .45894 .52557 Mtetra
.488 0 0 r
.45894 .52557 .46743 .52513 .48195 .52962 .4735 .53152 Mtetra
.529 0 0 r
.4735 .53152 .48195 .52962 .49662 .53422 .48824 .5376 Mtetra
.542 .005 0 r
.48824 .5376 .49662 .53422 .51146 .53857 .50315 .54339 Mtetra
.533 .015 0 r
.50315 .54339 .51146 .53857 .52646 .54226 .51823 .54842 Mtetra
.507 .004 0 r
.51823 .54842 .52646 .54226 .5416 .5449 .53349 .55222 Mtetra
.464 0 .006 r
.53349 .55222 .5416 .5449 .55689 .5461 .54889 .55434 Mtetra
.404 0 0 r
.54889 .55434 .55689 .5461 .57229 .54553 .56442 .55438 Mtetra
.324 0 0 r
.56442 .55438 .57229 .54553 .58777 .54294 .58004 .55207 Mtetra
.221 0 0 r
.58004 .55207 .58777 .54294 .60331 .53821 .59572 .54726 Mtetra
.091 0 0 r
.59572 .54726 .60331 .53821 .61887 .53133 .61142 .53993 Mtetra
0 0 0 r
.61142 .53993 .61887 .53133 .63444 .52241 .62712 .53024 Mtetra
.62712 .53024 .63444 .52241 .64999 .5117 .64279 .51845 Mtetra
.64279 .51845 .64999 .5117 .66551 .49951 .65841 .50496 Mtetra
.58 .889 .607 r
.65841 .50496 .66551 .49951 .68099 .48623 .67398 .49022 Mtetra
.705 .96 .701 r
.67398 .49022 .68099 .48623 .69645 .47226 .68951 .4747 Mtetra
.788 .994 .771 r
.68951 .4747 .69645 .47226 .7119 .458 .70501 .45887 Mtetra
.834 .999 .82 r
.70501 .45887 .7119 .458 .72735 .44382 .7205 .44314 Mtetra
.853 .986 .852 r
.7205 .44314 .72735 .44382 .74282 .43003 .73601 .42788 Mtetra
.854 .964 .873 r
.73601 .42788 .74282 .43003 .75834 .41685 .75156 .41335 Mtetra
.843 .936 .887 r
.75156 .41335 .75834 .41685 .77394 .40444 .76717 .39975 Mtetra
.825 .908 .896 r
.76717 .39975 .77394 .40444 .78962 .39291 .78288 .38716 Mtetra
.804 .88 .901 r
.78288 .38716 .78962 .39291 .80541 .38228 .79869 .37563 Mtetra
.782 .854 .905 r
.79869 .37563 .80541 .38228 .82131 .37253 .81462 .36511 Mtetra
.761 .831 .907 r
.81462 .36511 .82131 .37253 .83735 .36358 .83069 .35555 Mtetra
.741 .812 .907 r
.83069 .35555 .83735 .36358 .85351 .35536 .84689 .34682 Mtetra
.724 .795 .908 r
.84689 .34682 .85351 .35536 .86981 .34776 .86323 .33882 Mtetra
.71 .782 .908 r
.86323 .33882 .86981 .34776 .88624 .34068 .8797 .33142 Mtetra
.698 .771 .908 r
.8797 .33142 .88624 .34068 .9028 .33402 .89631 .3245 Mtetra
.608 .739 .938 r
.2972 .50731 .306 .51496 .31956 .51204 .31079 .50456 Mtetra
.584 .737 .948 r
.31079 .50456 .31956 .51204 .33317 .50961 .32442 .50237 Mtetra
.55 .734 .961 r
.32442 .50237 .33317 .50961 .34683 .50778 .33811 .50087 Mtetra
.501 .726 .973 r
.33811 .50087 .34683 .50778 .36056 .50668 .35185 .50021 Mtetra
.429 .71 .982 r
.35185 .50021 .36056 .50668 .37434 .50642 .36564 .50051 Mtetra
.325 .677 .977 r
.36564 .50051 .37434 .50642 .38819 .50711 .3795 .5019 Mtetra
.179 .616 .941 r
.3795 .5019 .38819 .50711 .40213 .50882 .39344 .50445 Mtetra
0 .513 .851 r
.39344 .50445 .40213 .50882 .41615 .51159 .40748 .50822 Mtetra
0 .373 .698 r
.40748 .50822 .41615 .51159 .43028 .51538 .42162 .51317 Mtetra
.375 0 0 r
.42162 .51317 .43028 .51538 .44454 .5201 .4359 .51918 Mtetra
.489 0 0 r
.4359 .51918 .44454 .5201 .45894 .52557 .45032 .52605 Mtetra
.554 0 0 r
.45032 .52605 .45894 .52557 .4735 .53152 .46492 .53347 Mtetra
.583 .037 0 r
.46492 .53347 .4735 .53152 .48824 .5376 .4797 .54105 Mtetra
.587 .061 0 r
.4797 .54105 .48824 .5376 .50315 .54339 .49468 .5483 Mtetra
.572 .063 .003 r
.49468 .5483 .50315 .54339 .51823 .54842 .50985 .55468 Mtetra
.541 .044 .024 r
.50985 .55468 .51823 .54842 .53349 .55222 .52521 .55966 Mtetra
.492 .005 .026 r
.52521 .55966 .53349 .55222 .54889 .55434 .54073 .5627 Mtetra
.425 0 .008 r
.54073 .5627 .54889 .55434 .56442 .55438 .55639 .56337 Mtetra
.334 0 0 r
.55639 .56337 .56442 .55438 .58004 .55207 .57215 .56133 Mtetra
.215 0 0 r
.57215 .56133 .58004 .55207 .59572 .54726 .58797 .55641 Mtetra
.065 0 0 r
.58797 .55641 .59572 .54726 .61142 .53993 .60382 .54862 Mtetra
0 0 0 r
.60382 .54862 .61142 .53993 .62712 .53024 .61965 .53812 Mtetra
.61965 .53812 .62712 .53024 .64279 .51845 .63544 .52524 Mtetra
.495 .825 .525 r
.63544 .52524 .64279 .51845 .65841 .50496 .65117 .51042 Mtetra
.65 .921 .629 r
.65117 .51042 .65841 .50496 .67398 .49022 .66683 .49418 Mtetra
.76 .975 .709 r
.66683 .49418 .67398 .49022 .68951 .4747 .68244 .47708 Mtetra
.829 .997 .767 r
.68244 .47708 .68951 .4747 .70501 .45887 .698 .45964 Mtetra
.865 .995 .807 r
.698 .45964 .70501 .45887 .7205 .44314 .71355 .44236 Mtetra
.877 .98 .836 r
.71355 .44236 .7205 .44314 .73601 .42788 .72909 .42562 Mtetra
.874 .958 .856 r
.72909 .42562 .73601 .42788 .75156 .41335 .74467 .40974 Mtetra
.86 .932 .871 r
.74467 .40974 .75156 .41335 .76717 .39975 .76032 .39493 Mtetra
.84 .906 .882 r
.76032 .39493 .76717 .39975 .78288 .38716 .77605 .38129 Mtetra
.818 .879 .89 r
.77605 .38129 .78288 .38716 .79869 .37563 .79188 .36885 Mtetra
.794 .855 .896 r
.79188 .36885 .79869 .37563 .81462 .36511 .80785 .35758 Mtetra
.771 .833 .9 r
.80785 .35758 .81462 .36511 .83069 .35555 .82394 .34739 Mtetra
.75 .813 .902 r
.82394 .34739 .83069 .35555 .84689 .34682 .84018 .33816 Mtetra
.731 .797 .904 r
.84018 .33816 .84689 .34682 .86323 .33882 .85657 .32976 Mtetra
.715 .783 .905 r
.85657 .32976 .86323 .33882 .8797 .33142 .87309 .32204 Mtetra
.702 .772 .906 r
.87309 .32204 .8797 .33142 .89631 .3245 .88976 .31487 Mtetra
.601 .737 .94 r
.28832 .49957 .2972 .50731 .31079 .50456 .30193 .49699 Mtetra
.573 .733 .951 r
.30193 .49699 .31079 .50456 .32442 .50237 .31559 .49503 Mtetra
.534 .727 .963 r
.31559 .49503 .32442 .50237 .33811 .50087 .32929 .49386 Mtetra
.477 .715 .974 r
.32929 .49386 .33811 .50087 .35185 .50021 .34304 .49361 Mtetra
.393 .691 .98 r
.34304 .49361 .35185 .50021 .36564 .50051 .35685 .49446 Mtetra
.272 .646 .966 r
.35685 .49446 .36564 .50051 .3795 .5019 .37072 .49652 Mtetra
.106 .567 .914 r
.37072 .49652 .3795 .5019 .39344 .50445 .38466 .4999 Mtetra
0 .444 .801 r
.38466 .4999 .39344 .50445 .40748 .50822 .3987 .50464 Mtetra
.292 0 0 r
.3987 .50464 .40748 .50822 .42162 .51317 .41285 .5107 Mtetra
.447 0 0 r
.41285 .5107 .42162 .51317 .4359 .51918 .42713 .51797 Mtetra
.546 0 0 r
.42713 .51797 .4359 .51918 .45032 .52605 .44158 .5262 Mtetra
.6 .039 0 r
.44158 .5262 .45032 .52605 .46492 .53347 .4562 .53506 Mtetra
.622 .082 0 r
.4562 .53506 .46492 .53347 .4797 .54105 .47103 .54409 Mtetra
.621 .098 0 r
.47103 .54409 .4797 .54105 .49468 .5483 .48606 .55276 Mtetra
.602 .092 .01 r
.48606 .55276 .49468 .5483 .50985 .55468 .50131 .56047 Mtetra
.566 .064 .023 r
.50131 .56047 .50985 .55468 .52521 .55966 .51677 .56658 Mtetra
.511 .015 .016 r
.51677 .56658 .52521 .55966 .54073 .5627 .5324 .57052 Mtetra
.432 0 0 r
.5324 .57052 .54073 .5627 .55639 .56337 .54818 .57178 Mtetra
.325 0 0 r
.54818 .57178 .55639 .56337 .57215 .56133 .56408 .56999 Mtetra
.181 0 0 r
.56408 .56999 .57215 .56133 .58797 .55641 .58005 .56496 Mtetra
0 0 0 r
.58005 .56496 .58797 .55641 .60382 .54862 .59603 .55669 Mtetra
.59603 .55669 .60382 .54862 .61965 .53812 .612 .54538 Mtetra
.612 .54538 .61965 .53812 .63544 .52524 .62791 .53141 Mtetra
.608 .895 .596 r
.62791 .53141 .63544 .52524 .65117 .51042 .64376 .51527 Mtetra
.74 .962 .677 r
.64376 .51527 .65117 .51042 .66683 .49418 .65953 .49757 Mtetra
.825 .99 .733 r
.65953 .49757 .66683 .49418 .68244 .47708 .67522 .47892 Mtetra
.872 .994 .772 r
.67522 .47892 .68244 .47708 .698 .45964 .69085 .45992 Mtetra
.894 .984 .801 r
.69085 .45992 .698 .45964 .71355 .44236 .70645 .44111 Mtetra
.897 .967 .823 r
.70645 .44111 .71355 .44236 .72909 .42562 .72205 .42295 Mtetra
.889 .945 .841 r
.72205 .42295 .72909 .42562 .74467 .40974 .73767 .40576 Mtetra
.873 .922 .856 r
.73767 .40576 .74467 .40974 .76032 .39493 .75335 .38978 Mtetra
.852 .898 .868 r
.75335 .38978 .76032 .39493 .77605 .38129 .76911 .37512 Mtetra
.829 .874 .878 r
.76911 .37512 .77605 .38129 .79188 .36885 .78498 .36182 Mtetra
.804 .852 .886 r
.78498 .36182 .79188 .36885 .80785 .35758 .80098 .34983 Mtetra
.78 .831 .892 r
.80098 .34983 .80785 .35758 .82394 .34739 .81712 .33904 Mtetra
.757 .813 .897 r
.81712 .33904 .82394 .34739 .84018 .33816 .8334 .32933 Mtetra
.737 .797 .9 r
.8334 .32933 .84018 .33816 .85657 .32976 .84983 .32054 Mtetra
.72 .784 .902 r
.84983 .32054 .85657 .32976 .87309 .32204 .8664 .31251 Mtetra
.706 .773 .904 r
.8664 .31251 .87309 .32204 .88976 .31487 .88312 .3051 Mtetra
.594 .734 .941 r
.27935 .49172 .28832 .49957 .30193 .49699 .29298 .48928 Mtetra
.563 .729 .952 r
.29298 .48928 .30193 .49699 .31559 .49503 .30666 .48755 Mtetra
.519 .719 .964 r
.30666 .48755 .31559 .49503 .32929 .49386 .32039 .48666 Mtetra
.455 .703 .974 r
.32039 .48666 .32929 .49386 .34304 .49361 .33415 .48681 Mtetra
.361 .672 .975 r
.33415 .48681 .34304 .49361 .35685 .49446 .34797 .48816 Mtetra
.227 .616 .954 r
.34797 .48816 .35685 .49446 .37072 .49652 .36184 .49085 Mtetra
.049 .522 .889 r
.36184 .49085 .37072 .49652 .38466 .4999 .37579 .49499 Mtetra
0 .388 .764 r
.37579 .49499 .38466 .4999 .3987 .50464 .38982 .50062 Mtetra
.348 0 0 r
.38982 .50062 .3987 .50464 .41285 .5107 .40397 .50772 Mtetra
.492 0 0 r
.40397 .50772 .41285 .5107 .42713 .51797 .41826 .51615 Mtetra
.582 .006 0 r
.41826 .51615 .42713 .51797 .44158 .5262 .43272 .52564 Mtetra
.63 .072 0 r
.43272 .52564 .44158 .5262 .4562 .53506 .44736 .53583 Mtetra
.649 .108 0 r
.44736 .53583 .4562 .53506 .47103 .54409 .46222 .54621 Mtetra
.645 .118 0 r
.46222 .54621 .47103 .54409 .48606 .55276 .47731 .5562 Mtetra
.623 .104 0 r
.47731 .5562 .48606 .55276 .50131 .56047 .49262 .56511 Mtetra
.582 .067 0 r
.49262 .56511 .50131 .56047 .51677 .56658 .50816 .57228 Mtetra
.518 .004 0 r
.50816 .57228 .51677 .56658 .5324 .57052 .5239 .57704 Mtetra
.424 0 0 r
.5239 .57704 .5324 .57052 .54818 .57178 .5398 .57883 Mtetra
.289 0 0 r
.5398 .57883 .54818 .57178 .56408 .56999 .55583 .57725 Mtetra
.104 0 0 r
.55583 .57725 .56408 .56999 .58005 .56496 .57193 .57209 Mtetra
0 0 0 r
.57193 .57209 .58005 .56496 .59603 .55669 .58805 .56336 Mtetra
.58805 .56336 .59603 .55669 .612 .54538 .60416 .55127 Mtetra
.585 .894 .617 r
.60416 .55127 .612 .54538 .62791 .53141 .6202 .53626 Mtetra
.737 .965 .689 r
.6202 .53626 .62791 .53141 .64376 .51527 .63617 .51888 Mtetra
.83 .991 .732 r
.63617 .51888 .64376 .51527 .65953 .49757 .65204 .4998 Mtetra
.882 .992 .76 r
.65204 .4998 .65953 .49757 .67522 .47892 .66782 .4797 Mtetra
.907 .981 .78 r
.66782 .4797 .67522 .47892 .69085 .45992 .68354 .45925 Mtetra
.915 .964 .797 r
.68354 .45925 .69085 .45992 .70645 .44111 .6992 .43904 Mtetra
.911 .946 .812 r
.6992 .43904 .70645 .44111 .72205 .42295 .71486 .41955 Mtetra
.899 .926 .827 r
.71486 .41955 .72205 .42295 .73767 .40576 .73053 .40116 Mtetra
.882 .906 .841 r
.73053 .40116 .73767 .40576 .75335 .38978 .74625 .3841 Mtetra
.86 .885 .854 r
.74625 .3841 .75335 .38978 .76911 .37512 .76206 .36852 Mtetra
.836 .865 .866 r
.76206 .36852 .76911 .37512 .78498 .36182 .77797 .35442 Mtetra
.811 .846 .876 r
.77797 .35442 .78498 .36182 .80098 .34983 .79401 .34176 Mtetra
.787 .827 .884 r
.79401 .34176 .80098 .34983 .81712 .33904 .81019 .33043 Mtetra
.763 .81 .89 r
.81019 .33043 .81712 .33904 .8334 .32933 .82652 .32028 Mtetra
.742 .796 .895 r
.82652 .32028 .8334 .32933 .84983 .32054 .843 .31113 Mtetra
.724 .783 .899 r
.843 .31113 .84983 .32054 .8664 .31251 .85963 .30282 Mtetra
.709 .772 .902 r
.85963 .30282 .8664 .31251 .88312 .3051 .87641 .29518 Mtetra
.588 .73 .942 r
.27029 .48373 .27935 .49172 .29298 .48928 .28396 .48143 Mtetra
.555 .723 .953 r
.28396 .48143 .29298 .48928 .30666 .48755 .29766 .47987 Mtetra
.506 .712 .964 r
.29766 .47987 .30666 .48755 .32039 .48666 .3114 .47924 Mtetra
.437 .69 .972 r
.3114 .47924 .32039 .48666 .33415 .48681 .32518 .47973 Mtetra
.336 .653 .97 r
.32518 .47973 .33415 .48681 .34797 .48816 .339 .48151 Mtetra
.195 .588 .943 r
.339 .48151 .34797 .48816 .36184 .49085 .35288 .48474 Mtetra
.012 .486 .872 r
.35288 .48474 .36184 .49085 .37579 .49499 .36682 .48954 Mtetra
0 .349 .746 r
.36682 .48954 .37579 .49499 .38982 .50062 .38086 .49596 Mtetra
.375 0 0 r
.38086 .49596 .38982 .50062 .40397 .50772 .39501 .50395 Mtetra
.512 0 0 r
.39501 .50395 .40397 .50772 .41826 .51615 .40929 .51338 Mtetra
.598 .026 0 r
.40929 .51338 .41826 .51615 .43272 .52564 .42375 .52397 Mtetra
.645 .087 0 r
.42375 .52397 .43272 .52564 .44736 .53583 .43841 .53531 Mtetra
.663 .117 0 r
.43841 .53531 .44736 .53583 .46222 .54621 .4533 .54686 Mtetra
.659 .12 0 r
.4533 .54686 .46222 .54621 .47731 .5562 .46842 .55798 Mtetra
.635 .098 0 r
.46842 .55798 .47731 .5562 .49262 .56511 .48379 .56795 Mtetra
.588 .049 0 r
.48379 .56795 .49262 .56511 .50816 .57228 .49941 .57601 Mtetra
.51 0 0 r
.49941 .57601 .50816 .57228 .5239 .57704 .51523 .58146 Mtetra
.389 0 0 r
.51523 .58146 .5239 .57704 .5398 .57883 .53124 .5837 Mtetra
.206 0 0 r
.53124 .5837 .5398 .57883 .55583 .57725 .54739 .58228 Mtetra
0 0 0 r
.54739 .58228 .55583 .57725 .57193 .57209 .56362 .57698 Mtetra
.56362 .57698 .57193 .57209 .58805 .56336 .57988 .56781 Mtetra
.58 .918 .7 r
.57988 .56781 .58805 .56336 .60416 .55127 .59611 .55502 Mtetra
.748 .983 .75 r
.59611 .55502 .60416 .55127 .6202 .53626 .61229 .53908 Mtetra
.844 .997 .769 r
.61229 .53908 .6202 .53626 .63617 .51888 .62837 .5206 Mtetra
.895 .988 .775 r
.62837 .5206 .63617 .51888 .65204 .4998 .64436 .50029 Mtetra
.918 .971 .779 r
.64436 .50029 .65204 .4998 .66782 .4797 .66024 .47892 Mtetra
.926 .953 .784 r
.66024 .47892 .66782 .4797 .68354 .45925 .67604 .45719 Mtetra
.925 .935 .792 r
.67604 .45719 .68354 .45925 .6992 .43904 .69178 .43575 Mtetra
.916 .918 .802 r
.69178 .43575 .6992 .43904 .71486 .41955 .7075 .41511 Mtetra
.903 .901 .814 r
.7075 .41511 .71486 .41955 .73053 .40116 .72324 .39567 Mtetra
.885 .885 .827 r
.72324 .39567 .73053 .40116 .74625 .3841 .73902 .37769 Mtetra
.863 .869 .841 r
.73902 .37769 .74625 .3841 .76206 .36852 .75487 .3613 Mtetra
.84 .853 .854 r
.75487 .3613 .76206 .36852 .77797 .35442 .77084 .34651 Mtetra
.815 .836 .865 r
.77084 .34651 .77797 .35442 .79401 .34176 .78693 .33328 Mtetra
.791 .821 .876 r
.78693 .33328 .79401 .34176 .81019 .33043 .80317 .32148 Mtetra
.768 .806 .884 r
.80317 .32148 .81019 .33043 .82652 .32028 .81955 .31094 Mtetra
.746 .793 .89 r
.81955 .31094 .82652 .32028 .843 .31113 .83609 .30149 Mtetra
.727 .781 .895 r
.83609 .30149 .843 .31113 .85963 .30282 .85278 .29293 Mtetra
.712 .771 .899 r
.85278 .29293 .85963 .30282 .87641 .29518 .86962 .28509 Mtetra
.583 .727 .942 r
.26115 .47559 .27029 .48373 .28396 .48143 .27484 .47338 Mtetra
.548 .718 .952 r
.27484 .47338 .28396 .48143 .29766 .47987 .28857 .47197 Mtetra
.497 .704 .962 r
.28857 .47197 .29766 .47987 .3114 .47924 .30233 .47154 Mtetra
.425 .679 .969 r
.30233 .47154 .3114 .47924 .32518 .47973 .31612 .47229 Mtetra
.321 .637 .964 r
.31612 .47229 .32518 .47973 .339 .48151 .32996 .47441 Mtetra
.179 .567 .935 r
.32996 .47441 .339 .48151 .35288 .48474 .34384 .47807 Mtetra
0 .463 .865 r
.34384 .47807 .35288 .48474 .36682 .48954 .35778 .48339 Mtetra
0 .329 .748 r
.35778 .48339 .36682 .48954 .38086 .49596 .37182 .49042 Mtetra
.373 0 0 r
.37182 .49042 .38086 .49596 .39501 .50395 .38596 .49913 Mtetra
.506 0 0 r
.38596 .49913 .39501 .50395 .40929 .51338 .40025 .50936 Mtetra
.592 .025 0 r
.40025 .50936 .40929 .51338 .42375 .52397 .41471 .52081 Mtetra
.641 .081 0 r
.41471 .52081 .42375 .52397 .43841 .53531 .42938 .53306 Mtetra
.66 .106 0 r
.42938 .53306 .43841 .53531 .4533 .54686 .44428 .54554 Mtetra
.656 .102 0 r
.44428 .54554 .4533 .54686 .46842 .55798 .45943 .55755 Mtetra
.628 .069 0 r
.45943 .55755 .46842 .55798 .48379 .56795 .47485 .56833 Mtetra
.57 0 0 r
.47485 .56833 .48379 .56795 .49941 .57601 .49052 .57709 Mtetra
.467 0 0 r
.49052 .57709 .49941 .57601 .51523 .58146 .50642 .58307 Mtetra
.297 0 0 r
.50642 .58307 .51523 .58146 .53124 .5837 .52252 .58563 Mtetra
.034 0 0 r
.52252 .58563 .53124 .5837 .54739 .58228 .53878 .5843 Mtetra
.292 .785 .748 r
.53878 .5843 .54739 .58228 .56362 .57698 .55512 .57885 Mtetra
.578 .942 .836 r
.55512 .57885 .56362 .57698 .57988 .56781 .5715 .56929 Mtetra
.759 .995 .85 r
.5715 .56929 .57988 .56781 .59611 .55502 .58786 .55591 Mtetra
.853 .994 .833 r
.58786 .55591 .59611 .55502 .61229 .53908 .60416 .53919 Mtetra
.9 .974 .811 r
.60416 .53919 .61229 .53908 .62837 .5206 .62037 .51979 Mtetra
.921 .952 .795 r
.62037 .51979 .62837 .5206 .64436 .50029 .63646 .4985 Mtetra
.929 .931 .785 r
.63646 .4985 .64436 .50029 .66024 .47892 .65245 .47609 Mtetra
.929 .914 .782 r
.65245 .47609 .66024 .47892 .67604 .45719 .66835 .45334 Mtetra
.923 .899 .785 r
.66835 .45334 .67604 .45719 .69178 .43575 .68418 .43091 Mtetra
.913 .885 .792 r
.68418 .43091 .69178 .43575 .7075 .41511 .69998 .40935 Mtetra
.899 .873 .802 r
.69998 .40935 .7075 .41511 .72324 .39567 .71579 .38908 Mtetra
.882 .861 .815 r
.71579 .38908 .72324 .39567 .73902 .37769 .73163 .37036 Mtetra
.862 .849 .829 r
.73163 .37036 .73902 .37769 .75487 .3613 .74756 .35332 Mtetra
.84 .837 .843 r
.74756 .35332 .75487 .3613 .77084 .34651 .76358 .33799 Mtetra
.817 .825 .856 r
.76358 .33799 .77084 .34651 .78693 .33328 .77974 .32431 Mtetra
.793 .812 .867 r
.77974 .32431 .78693 .33328 .80317 .32148 .79603 .31213 Mtetra
.77 .8 .877 r
.79603 .31213 .80317 .32148 .81955 .31094 .81248 .30128 Mtetra
.748 .788 .885 r
.81248 .30128 .81955 .31094 .83609 .30149 .82908 .29157 Mtetra
.729 .778 .892 r
.82908 .29157 .83609 .30149 .85278 .29293 .84584 .28281 Mtetra
.713 .769 .896 r
.84584 .28281 .85278 .29293 .86962 .28509 .86275 .27481 Mtetra
.58 .724 .941 r
.25193 .46728 .26115 .47559 .27484 .47338 .26565 .46513 Mtetra
.544 .713 .95 r
.26565 .46513 .27484 .47338 .28857 .47197 .2794 .4638 Mtetra
.492 .697 .96 r
.2794 .4638 .28857 .47197 .30233 .47154 .29318 .4635 Mtetra
.419 .669 .965 r
.29318 .4635 .30233 .47154 .31612 .47229 .307 .46443 Mtetra
.317 .625 .959 r
.307 .46443 .31612 .47229 .32996 .47441 .32084 .46678 Mtetra
.179 .554 .932 r
.32084 .46678 .32996 .47441 .34384 .47807 .33473 .47072 Mtetra
.009 .453 .868 r
.33473 .47072 .34384 .47807 .35778 .48339 .34868 .4764 Mtetra
0 .328 .765 r
.34868 .4764 .35778 .48339 .37182 .49042 .36272 .48385 Mtetra
0 .197 .638 r
.36272 .48385 .37182 .49042 .38596 .49913 .37686 .49304 Mtetra
.471 0 0 r
.37686 .49304 .38596 .49913 .40025 .50936 .39114 .50381 Mtetra
.558 .001 0 r
.39114 .50381 .40025 .50936 .41471 .52081 .4056 .51585 Mtetra
.608 .051 0 r
.4056 .51585 .41471 .52081 .42938 .53306 .42027 .52871 Mtetra
.628 .07 0 r
.42027 .52871 .42938 .53306 .44428 .54554 .43519 .5418 Mtetra
.619 .056 0 r
.43519 .5418 .44428 .54554 .45943 .55755 .45036 .55441 Mtetra
.58 .006 0 r
.45036 .55441 .45943 .55755 .47485 .56833 .46581 .56572 Mtetra
.497 0 0 r
.46581 .56572 .47485 .56833 .49052 .57709 .48152 .57492 Mtetra
.345 0 0 r
.48152 .57492 .49052 .57709 .50642 .58307 .49749 .58122 Mtetra
0 .492 .727 r
.49749 .58122 .50642 .58307 .52252 .58563 .51367 .58396 Mtetra
.24 .743 .896 r
.51367 .58396 .52252 .58563 .53878 .5843 .53001 .58264 Mtetra
.543 .905 .965 r
.53001 .58264 .53878 .5843 .55512 .57885 .54645 .57704 Mtetra
.733 .958 .944 r
.54645 .57704 .55512 .57885 .5715 .56929 .56294 .56717 Mtetra
.832 .955 .895 r
.56294 .56717 .5715 .56929 .58786 .55591 .57942 .55332 Mtetra
.881 .935 .85 r
.57942 .55332 .58786 .55591 .60416 .53919 .59583 .53602 Mtetra
.905 .914 .816 r
.59583 .53602 .60416 .53919 .62037 .51979 .61215 .51597 Mtetra
.916 .895 .794 r
.61215 .51597 .62037 .51979 .63646 .4985 .62836 .49396 Mtetra
.919 .88 .78 r
.62836 .49396 .63646 .4985 .65245 .47609 .64446 .47082 Mtetra
.917 .868 .775 r
.64446 .47082 .65245 .47609 .66835 .45334 .66046 .44734 Mtetra
.912 .859 .776 r
.66046 .44734 .66835 .45334 .68418 .43091 .67639 .42423 Mtetra
.903 .85 .782 r
.67639 .42423 .68418 .43091 .69998 .40935 .69228 .40203 Mtetra
.89 .843 .791 r
.69228 .40203 .69998 .40935 .71579 .38908 .70817 .38118 Mtetra
.875 .836 .804 r
.70817 .38118 .71579 .38908 .73163 .37036 .7241 .36195 Mtetra
.857 .828 .818 r
.7241 .36195 .73163 .37036 .74756 .35332 .7401 .34447 Mtetra
.837 .82 .833 r
.7401 .34447 .74756 .35332 .76358 .33799 .7562 .32877 Mtetra
.815 .811 .847 r
.7562 .32877 .76358 .33799 .77974 .32431 .77242 .31476 Mtetra
.792 .802 .86 r
.77242 .31476 .77974 .32431 .79603 .31213 .78879 .30232 Mtetra
.77 .792 .871 r
.78879 .30232 .79603 .31213 .81248 .30128 .80531 .29125 Mtetra
.749 .783 .881 r
.80531 .29125 .81248 .30128 .82908 .29157 .82198 .28136 Mtetra
.73 .774 .888 r
.82198 .28136 .82908 .29157 .84584 .28281 .8388 .27245 Mtetra
.714 .767 .894 r
.8388 .27245 .84584 .28281 .86275 .27481 .85578 .26432 Mtetra
.579 .721 .939 r
.24262 .45878 .25193 .46728 .26565 .46513 .25638 .45664 Mtetra
.543 .709 .948 r
.25638 .45664 .26565 .46513 .2794 .4638 .27016 .45534 Mtetra
.492 .691 .956 r
.27016 .45534 .2794 .4638 .29318 .4635 .28397 .45509 Mtetra
.421 .662 .961 r
.28397 .45509 .29318 .4635 .307 .46443 .2978 .45609 Mtetra
.323 .617 .955 r
.2978 .45609 .307 .46443 .32084 .46678 .31166 .45854 Mtetra
.195 .549 .931 r
.31166 .45854 .32084 .46678 .33473 .47072 .32557 .46262 Mtetra
.04 .455 .878 r
.32557 .46262 .33473 .47072 .34868 .4764 .33953 .46846 Mtetra
0 .342 .794 r
.33953 .46846 .34868 .4764 .36272 .48385 .35357 .47611 Mtetra
0 .224 .691 r
.35357 .47611 .36272 .48385 .37686 .49304 .36771 .48552 Mtetra
0 .122 .589 r
.36771 .48552 .37686 .49304 .39114 .50381 .382 .49654 Mtetra
.487 0 0 r
.382 .49654 .39114 .50381 .4056 .51585 .39646 .50885 Mtetra
.534 0 0 r
.39646 .50885 .4056 .51585 .42027 .52871 .41113 .52198 Mtetra
.547 .005 0 r
.41113 .52198 .42027 .52871 .43519 .5418 .42605 .53534 Mtetra
.523 0 0 r
.42605 .53534 .43519 .5418 .45036 .55441 .44124 .54819 Mtetra
.455 0 0 r
.44124 .54819 .45036 .55441 .46581 .56572 .4567 .55971 Mtetra
0 .225 .648 r
.4567 .55971 .46581 .56572 .48152 .57492 .47245 .56907 Mtetra
0 .412 .803 r
.47245 .56907 .48152 .57492 .49749 .58122 .48846 .57546 Mtetra
.18 .62 .942 r
.48846 .57546 .49749 .58122 .51367 .58396 .5047 .57821 Mtetra
.457 .774 .997 r
.5047 .57821 .51367 .58396 .53001 .58264 .52111 .57683 Mtetra
.652 .846 .975 r
.52111 .57683 .53001 .58264 .54645 .57704 .53763 .57107 Mtetra
.766 .865 .922 r
.53763 .57107 .54645 .57704 .56294 .56717 .55422 .56097 Mtetra
.829 .862 .871 r
.55422 .56097 .56294 .56717 .57942 .55332 .57079 .54684 Mtetra
.863 .853 .83 r
.57079 .54684 .57942 .55332 .59583 .53602 .58731 .5292 Mtetra
.883 .843 .801 r
.58731 .5292 .59583 .53602 .61215 .51597 .60374 .50877 Mtetra
.893 .834 .781 r
.60374 .50877 .61215 .51597 .62836 .49396 .62006 .48637 Mtetra
.897 .828 .77 r
.62006 .48637 .62836 .49396 .64446 .47082 .63627 .46284 Mtetra
.898 .823 .765 r
.63627 .46284 .64446 .47082 .66046 .44734 .65238 .43899 Mtetra
.894 .819 .766 r
.65238 .43899 .66046 .44734 .67639 .42423 .66841 .41551 Mtetra
.887 .816 .772 r
.66841 .41551 .67639 .42423 .69228 .40203 .6844 .393 Mtetra
.878 .813 .782 r
.6844 .393 .69228 .40203 .70817 .38118 .70039 .37186 Mtetra
.865 .81 .794 r
.70039 .37186 .70817 .38118 .7241 .36195 .71641 .35237 Mtetra
.849 .807 .809 r
.71641 .35237 .7241 .36195 .7401 .34447 .73249 .33467 Mtetra
.831 .802 .824 r
.73249 .33467 .7401 .34447 .7562 .32877 .74868 .31878 Mtetra
.811 .797 .839 r
.74868 .31878 .7562 .32877 .77242 .31476 .76499 .30461 Mtetra
.789 .791 .853 r
.76499 .30461 .77242 .31476 .78879 .30232 .78143 .29202 Mtetra
.768 .784 .866 r
.78143 .29202 .78879 .30232 .80531 .29125 .79803 .28084 Mtetra
.748 .777 .876 r
.79803 .28084 .80531 .29125 .82198 .28136 .81478 .27084 Mtetra
.73 .77 .885 r
.81478 .27084 .82198 .28136 .8388 .27245 .83168 .26183 Mtetra
.714 .763 .891 r
.83168 .26183 .8388 .27245 .85578 .26432 .84873 .25361 Mtetra
.58 .718 .937 r
.23323 .45009 .24262 .45878 .25638 .45664 .24702 .44791 Mtetra
.545 .706 .945 r
.24702 .44791 .25638 .45664 .27016 .45534 .26084 .44657 Mtetra
.496 .687 .952 r
.26084 .44657 .27016 .45534 .28397 .45509 .27468 .44629 Mtetra
.429 .657 .956 r
.27468 .44629 .28397 .45509 .2978 .45609 .28854 .44725 Mtetra
.339 .613 .951 r
.28854 .44725 .2978 .45609 .31166 .45854 .30243 .44967 Mtetra
.224 .55 .931 r
.30243 .44967 .31166 .45854 .32557 .46262 .31635 .45371 Mtetra
.087 .466 .889 r
.31635 .45371 .32557 .46262 .33953 .46846 .33033 .45951 Mtetra
0 .367 .825 r
.33033 .45951 .33953 .46846 .35357 .47611 .34438 .46712 Mtetra
0 .266 .748 r
.34438 .46712 .35357 .47611 .36771 .48552 .35853 .47648 Mtetra
0 .178 .672 r
.35853 .47648 .36771 .48552 .382 .49654 .37282 .48744 Mtetra
0 .114 .614 r
.37282 .48744 .382 .49654 .39646 .50885 .38729 .49967 Mtetra
0 .082 .584 r
.38729 .49967 .39646 .50885 .41113 .52198 .40197 .51272 Mtetra
0 .085 .588 r
.40197 .51272 .41113 .52198 .42605 .53534 .41689 .52598 Mtetra
0 .128 .631 r
.41689 .52598 .42605 .53534 .44124 .54819 .43209 .53871 Mtetra
0 .214 .709 r
.43209 .53871 .44124 .54819 .4567 .55971 .44757 .55011 Mtetra
0 .341 .811 r
.44757 .55011 .4567 .55971 .47245 .56907 .46334 .55932 Mtetra
.14 .488 .902 r
.46334 .55932 .47245 .56907 .48846 .57546 .47937 .56556 Mtetra
.364 .617 .948 r
.47937 .56556 .48846 .57546 .5047 .57821 .49565 .56816 Mtetra
.545 .701 .942 r
.49565 .56816 .5047 .57821 .52111 .57683 .51211 .56662 Mtetra
.669 .746 .908 r
.51211 .56662 .52111 .57683 .53763 .57107 .5287 .56072 Mtetra
.749 .766 .867 r
.5287 .56072 .53763 .57107 .55422 .56097 .54535 .55049 Mtetra
.799 .775 .83 r
.54535 .55049 .55422 .56097 .57079 .54684 .56201 .53624 Mtetra
.831 .777 .801 r
.56201 .53624 .57079 .54684 .58731 .5292 .57862 .51852 Mtetra
.852 .778 .779 r
.57862 .51852 .58731 .5292 .60374 .50877 .59515 .49802 Mtetra
.864 .779 .765 r
.59515 .49802 .60374 .50877 .62006 .48637 .61158 .47557 Mtetra
.871 .779 .757 r
.61158 .47557 .62006 .48637 .63627 .46284 .6279 .45202 Mtetra
.874 .78 .754 r
.6279 .45202 .63627 .46284 .65238 .43899 .64411 .42816 Mtetra
.873 .781 .757 r
.64411 .42816 .65238 .43899 .66841 .41551 .66025 .40469 Mtetra
.869 .783 .763 r
.66025 .40469 .66841 .41551 .6844 .393 .67635 .38218 Mtetra
.862 .784 .773 r
.67635 .38218 .6844 .393 .70039 .37186 .69244 .36106 Mtetra
.852 .785 .786 r
.69244 .36106 .70039 .37186 .71641 .35237 .70857 .34158 Mtetra
.839 .786 .801 r
.70857 .34158 .71641 .35237 .73249 .33467 .72475 .32389 Mtetra
.822 .785 .817 r
.72475 .32389 .73249 .33467 .74868 .31878 .74103 .308 Mtetra
.804 .783 .833 r
.74103 .308 .74868 .31878 .76499 .30461 .75743 .29383 Mtetra
.785 .779 .848 r
.75743 .29383 .76499 .30461 .78143 .29202 .77396 .28123 Mtetra
.765 .775 .861 r
.77396 .28123 .78143 .29202 .79803 .28084 .79064 .27002 Mtetra
.746 .77 .873 r
.79064 .27002 .79803 .28084 .81478 .27084 .80748 .25999 Mtetra
.728 .765 .882 r
.80748 .25999 .81478 .27084 .83168 .26183 .82446 .25095 Mtetra
.713 .76 .889 r
.82446 .25095 .83168 .26183 .84873 .25361 .8416 .24269 Mtetra
.583 .716 .935 r
.22376 .4412 .23323 .45009 .24702 .44791 .23759 .43893 Mtetra
.549 .703 .942 r
.23759 .43893 .24702 .44791 .26084 .44657 .25144 .43749 Mtetra
.503 .684 .948 r
.25144 .43749 .26084 .44657 .27468 .44629 .26532 .43709 Mtetra
.442 .655 .951 r
.26532 .43709 .27468 .44629 .28854 .44725 .27921 .43791 Mtetra
.362 .614 .947 r
.27921 .43791 .28854 .44725 .30243 .44967 .29313 .44015 Mtetra
.261 .557 .931 r
.29313 .44015 .30243 .44967 .31635 .45371 .30709 .44399 Mtetra
.145 .483 .9 r
.30709 .44399 .31635 .45371 .33033 .45951 .32109 .44955 Mtetra
.023 .399 .853 r
.32109 .44955 .33033 .45951 .34438 .46712 .33516 .45687 Mtetra
0 .314 .797 r
.33516 .45687 .34438 .46712 .35853 .47648 .34934 .46591 Mtetra
0 .241 .745 r
.34934 .46591 .35853 .47648 .37282 .48744 .36364 .47649 Mtetra
0 .191 .707 r
.36364 .47649 .37282 .48744 .38729 .49967 .37812 .48832 Mtetra
0 .17 .693 r
.37812 .48832 .38729 .49967 .40197 .51272 .3928 .50092 Mtetra
0 .182 .706 r
.3928 .50092 .40197 .51272 .41689 .52598 .40773 .51371 Mtetra
0 .228 .745 r
.40773 .51371 .41689 .52598 .43209 .53871 .42293 .52597 Mtetra
0 .305 .799 r
.42293 .52597 .43209 .53871 .44757 .55011 .43842 .5369 Mtetra
.129 .401 .851 r
.43842 .5369 .44757 .55011 .46334 .55932 .4542 .54568 Mtetra
.298 .497 .883 r
.4542 .54568 .46334 .55932 .47937 .56556 .47025 .55153 Mtetra
.451 .576 .888 r
.47025 .55153 .47937 .56556 .49565 .56816 .48655 .55381 Mtetra
.573 .632 .872 r
.48655 .55381 .49565 .56816 .51211 .56662 .50304 .55205 Mtetra
.662 .668 .845 r
.50304 .55205 .51211 .56662 .5287 .56072 .51967 .54602 Mtetra
.724 .691 .818 r
.51967 .54602 .5287 .56072 .54535 .55049 .53638 .53577 Mtetra
.768 .706 .794 r
.53638 .53577 .54535 .55049 .56201 .53624 .5531 .52159 Mtetra
.799 .717 .774 r
.5531 .52159 .56201 .53624 .57862 .51852 .56979 .50403 Mtetra
.82 .725 .759 r
.56979 .50403 .57862 .51852 .59515 .49802 .58641 .48377 Mtetra
.835 .731 .75 r
.58641 .48377 .59515 .49802 .61158 .47557 .60293 .46163 Mtetra
.845 .737 .745 r
.60293 .46163 .61158 .47557 .6279 .45202 .61935 .43841 Mtetra
.85 .743 .745 r
.61935 .43841 .6279 .45202 .64411 .42816 .63568 .4149 Mtetra
.852 .748 .748 r
.63568 .4149 .64411 .42816 .66025 .40469 .65193 .39179 Mtetra
.85 .754 .756 r
.65193 .39179 .66025 .40469 .67635 .38218 .66815 .36962 Mtetra
.846 .758 .766 r
.66815 .36962 .67635 .38218 .69244 .36106 .68435 .3488 Mtetra
.838 .763 .78 r
.68435 .3488 .69244 .36106 .70857 .34158 .70058 .3296 Mtetra
.826 .766 .795 r
.70058 .3296 .70857 .34158 .72475 .32389 .71687 .31215 Mtetra
.813 .768 .812 r
.71687 .31215 .72475 .32389 .74103 .308 .73326 .29645 Mtetra
.796 .769 .828 r
.73326 .29645 .74103 .308 .75743 .29383 .74975 .28243 Mtetra
.778 .768 .844 r
.74975 .28243 .75743 .29383 .77396 .28123 .76638 .26994 Mtetra
.76 .766 .858 r
.76638 .26994 .77396 .28123 .79064 .27002 .78316 .25881 Mtetra
.742 .763 .87 r
.78316 .25881 .79064 .27002 .80748 .25999 .80008 .24883 Mtetra
.726 .76 .88 r
.80008 .24883 .80748 .25999 .82446 .25095 .81715 .2398 Mtetra
.711 .756 .888 r
.81715 .2398 .82446 .25095 .8416 .24269 .83437 .23154 Mtetra
.587 .715 .932 r
.2142 .43211 .22376 .4412 .23759 .43893 .22807 .42971 Mtetra
.556 .702 .938 r
.22807 .42971 .23759 .43893 .25144 .43749 .24197 .42811 Mtetra
.514 .683 .943 r
.24197 .42811 .25144 .43749 .26532 .43709 .25589 .4275 Mtetra
.459 .655 .945 r
.25589 .4275 .26532 .43709 .27921 .43791 .26983 .42808 Mtetra
.389 .617 .942 r
.26983 .42808 .27921 .43791 .29313 .44015 .28379 .43002 Mtetra
.304 .566 .93 r
.28379 .43002 .29313 .44015 .30709 .44399 .29778 .4335 Mtetra
.207 .503 .907 r
.29778 .4335 .30709 .44399 .32109 .44955 .31182 .43862 Mtetra
.108 .432 .873 r
.31182 .43862 .32109 .44955 .33516 .45687 .32593 .44543 Mtetra
.019 .362 .834 r
.32593 .44543 .33516 .45687 .34934 .46591 .34013 .45388 Mtetra
0 .303 .797 r
.34013 .45388 .34934 .46591 .36364 .47649 .35446 .4638 Mtetra
0 .264 .772 r
.35446 .4638 .36364 .47649 .37812 .48832 .36896 .4749 Mtetra
0 .25 .763 r
.36896 .4749 .37812 .48832 .3928 .50092 .38366 .48673 Mtetra
0 .263 .772 r
.38366 .48673 .3928 .50092 .40773 .51371 .39859 .49871 Mtetra
.033 .302 .793 r
.39859 .49871 .40773 .51371 .42293 .52597 .4138 .51016 Mtetra
.141 .359 .817 r
.4138 .51016 .42293 .52597 .43842 .5369 .42929 .52032 Mtetra
.264 .425 .835 r
.42929 .52032 .43842 .5369 .4542 .54568 .44507 .52839 Mtetra
.386 .488 .841 r
.44507 .52839 .4542 .54568 .47025 .55153 .46113 .53364 Mtetra
.494 .541 .834 r
.46113 .53364 .47025 .55153 .48655 .55381 .47743 .53546 Mtetra
.582 .583 .819 r
.47743 .53546 .48655 .55381 .50304 .55205 .49394 .5334 Mtetra
.651 .614 .8 r
.49394 .5334 .50304 .55205 .51967 .54602 .51059 .52726 Mtetra
.702 .638 .782 r
.51059 .52726 .51967 .54602 .53638 .53577 .52733 .51708 Mtetra
.741 .656 .765 r
.52733 .51708 .53638 .53577 .5531 .52159 .5441 .50316 Mtetra
.771 .67 .752 r
.5441 .50316 .5531 .52159 .56979 .50403 .56085 .486 Mtetra
.792 .682 .743 r
.56085 .486 .56979 .50403 .58641 .48377 .57755 .46628 Mtetra
.808 .693 .737 r
.57755 .46628 .58641 .48377 .60293 .46163 .59416 .44475 Mtetra
.82 .702 .735 r
.59416 .44475 .60293 .46163 .61935 .43841 .61067 .42221 Mtetra
.827 .711 .737 r
.61067 .42221 .61935 .43841 .63568 .4149 .6271 .39939 Mtetra
.831 .72 .742 r
.6271 .39939 .63568 .4149 .65193 .39179 .64347 .37696 Mtetra
.831 .728 .75 r
.64347 .37696 .65193 .39179 .66815 .36962 .6598 .35543 Mtetra
.829 .735 .762 r
.6598 .35543 .66815 .36962 .68435 .3488 .67611 .3352 Mtetra
.823 .742 .776 r
.67611 .3352 .68435 .3488 .70058 .3296 .69246 .31652 Mtetra
.814 .748 .791 r
.69246 .31652 .70058 .3296 .71687 .31215 .70887 .29951 Mtetra
.802 .753 .808 r
.70887 .29951 .71687 .31215 .73326 .29645 .72536 .28417 Mtetra
.787 .756 .825 r
.72536 .28417 .73326 .29645 .74975 .28243 .74197 .27045 Mtetra
.771 .758 .841 r
.74197 .27045 .74975 .28243 .76638 .26994 .7587 .25819 Mtetra
.754 .758 .856 r
.7587 .25819 .76638 .26994 .78316 .25881 .77557 .24722 Mtetra
.738 .757 .868 r
.77557 .24722 .78316 .25881 .80008 .24883 .79258 .23736 Mtetra
.722 .755 .878 r
.79258 .23736 .80008 .24883 .81715 .2398 .80974 .22841 Mtetra
.709 .753 .887 r
.80974 .22841 .81715 .2398 .83437 .23154 .82705 .22018 Mtetra
.592 .714 .929 r
.20456 .42283 .2142 .43211 .22807 .42971 .21848 .42026 Mtetra
.564 .701 .934 r
.21848 .42026 .22807 .42971 .24197 .42811 .23242 .41844 Mtetra
.527 .683 .938 r
.23242 .41844 .24197 .42811 .25589 .4275 .24639 .41756 Mtetra
.479 .657 .939 r
.24639 .41756 .25589 .4275 .26983 .42808 .26038 .4178 Mtetra
.419 .623 .937 r
.26038 .4178 .26983 .42808 .28379 .43002 .27439 .41932 Mtetra
.347 .578 .927 r
.27439 .41932 .28379 .43002 .29778 .4335 .28843 .42229 Mtetra
.269 .523 .91 r
.28843 .42229 .29778 .4335 .31182 .43862 .30252 .4268 Mtetra
.19 .464 .885 r
.30252 .4268 .31182 .43862 .32593 .44543 .31667 .43291 Mtetra
.122 .406 .856 r
.31667 .43291 .32593 .44543 .34013 .45388 .33091 .44054 Mtetra
.073 .358 .828 r
.33091 .44054 .34013 .45388 .35446 .4638 .34528 .44955 Mtetra
.051 .326 .808 r
.34528 .44955 .35446 .4638 .36896 .4749 .3598 .45965 Mtetra
.061 .315 .798 r
.3598 .45965 .36896 .4749 .38366 .48673 .37453 .47041 Mtetra
.102 .324 .798 r
.37453 .47041 .38366 .48673 .39859 .49871 .38948 .48129 Mtetra
.17 .351 .802 r
.38948 .48129 .39859 .49871 .4138 .51016 .4047 .49165 Mtetra
.256 .391 .808 r
.4047 .49165 .4138 .51016 .42929 .52032 .42019 .50076 Mtetra
.349 .435 .809 r
.42019 .50076 .42929 .52032 .44507 .52839 .43597 .5079 Mtetra
.438 .479 .804 r
.43597 .5079 .44507 .52839 .46113 .53364 .45202 .51237 Mtetra
.518 .518 .795 r
.45202 .51237 .46113 .53364 .47743 .53546 .46832 .51361 Mtetra
.586 .551 .782 r
.46832 .51361 .47743 .53546 .49394 .5334 .48482 .51121 Mtetra
.641 .578 .769 r
.48482 .51121 .49394 .5334 .51059 .52726 .50148 .50498 Mtetra
.685 .601 .756 r
.50148 .50498 .51059 .52726 .52733 .51708 .51824 .49497 Mtetra
.72 .619 .745 r
.51824 .49497 .52733 .51708 .5441 .50316 .53504 .48145 Mtetra
.747 .636 .737 r
.53504 .48145 .5441 .50316 .56085 .486 .55184 .4649 Mtetra
.768 .65 .731 r
.55184 .4649 .56085 .486 .57755 .46628 .56859 .44596 Mtetra
.785 .662 .728 r
.56859 .44596 .57755 .46628 .59416 .44475 .58527 .42533 Mtetra
.797 .674 .728 r
.58527 .42533 .59416 .44475 .61067 .42221 .60187 .40375 Mtetra
.806 .685 .732 r
.60187 .40375 .61067 .42221 .6271 .39939 .61841 .38192 Mtetra
.811 .696 .738 r
.61841 .38192 .6271 .39939 .64347 .37696 .63488 .36044 Mtetra
.813 .706 .747 r
.63488 .36044 .64347 .37696 .6598 .35543 .65132 .33982 Mtetra
.812 .716 .759 r
.65132 .33982 .6598 .35543 .67611 .3352 .66776 .32041 Mtetra
.808 .725 .773 r
.66776 .32041 .67611 .3352 .69246 .31652 .68422 .30246 Mtetra
.8 .733 .789 r
.68422 .30246 .69246 .31652 .70887 .29951 .70075 .28607 Mtetra
.79 .74 .806 r
.70075 .28607 .70887 .29951 .72536 .28417 .71735 .27126 Mtetra
.777 .745 .823 r
.71735 .27126 .72536 .28417 .74197 .27045 .73407 .25795 Mtetra
.763 .748 .84 r
.73407 .25795 .74197 .27045 .7587 .25819 .75091 .24602 Mtetra
.747 .75 .854 r
.75091 .24602 .7587 .25819 .77557 .24722 .76788 .2353 Mtetra
.732 .751 .867 r
.76788 .2353 .77557 .24722 .79258 .23736 .78499 .22561 Mtetra
.718 .75 .878 r
.78499 .22561 .79258 .23736 .80974 .22841 .80225 .21678 Mtetra
.705 .749 .886 r
.80225 .21678 .80974 .22841 .82705 .22018 .81965 .20862 Mtetra
.598 .714 .926 r
.19483 .41339 .20456 .42283 .21848 .42026 .2088 .4106 Mtetra
.573 .702 .929 r
.2088 .4106 .21848 .42026 .23242 .41844 .2228 .40852 Mtetra
.54 .685 .933 r
.2228 .40852 .23242 .41844 .24639 .41756 .23682 .40731 Mtetra
.499 .661 .934 r
.23682 .40731 .24639 .41756 .26038 .4178 .25087 .40712 Mtetra
.449 .63 .931 r
.25087 .40712 .26038 .4178 .27439 .41932 .26493 .40813 Mtetra
.39 .59 .924 r
.26493 .40813 .27439 .41932 .28843 .42229 .27903 .41048 Mtetra
.327 .544 .91 r
.27903 .41048 .28843 .42229 .30252 .4268 .29318 .41424 Mtetra
.265 .493 .89 r
.29318 .41424 .30252 .4268 .31667 .43291 .30739 .41947 Mtetra
.213 .445 .867 r
.30739 .41947 .31667 .43291 .33091 .44054 .32168 .42611 Mtetra
.178 .404 .844 r
.32168 .42611 .33091 .44054 .34528 .44955 .3361 .43399 Mtetra
.165 .377 .825 r
.3361 .43399 .34528 .44955 .3598 .45965 .35066 .44287 Mtetra
.178 .365 .812 r
.35066 .44287 .3598 .45965 .37453 .47041 .36542 .45233 Mtetra
.213 .369 .804 r
.36542 .45233 .37453 .47041 .38948 .48129 .3804 .46188 Mtetra
.268 .386 .798 r
.3804 .46188 .38948 .48129 .4047 .49165 .39563 .47092 Mtetra
.334 .412 .793 r
.39563 .47092 .4047 .49165 .42019 .50076 .41113 .47879 Mtetra
.405 .443 .787 r
.41113 .47879 .42019 .50076 .43597 .5079 .4269 .48481 Mtetra
.473 .474 .779 r
.4269 .48481 .43597 .5079 .45202 .51237 .44294 .48838 Mtetra
.534 .504 .769 r
.44294 .48838 .45202 .51237 .46832 .51361 .45923 .48895 Mtetra
.588 .531 .758 r
.45923 .48895 .46832 .51361 .48482 .51121 .47572 .48617 Mtetra
.634 .554 .748 r
.47572 .48617 .48482 .51121 .50148 .50498 .49237 .47987 Mtetra
.671 .575 .739 r
.49237 .47987 .50148 .50498 .51824 .49497 .50912 .4701 Mtetra
.702 .593 .731 r
.50912 .4701 .51824 .49497 .53504 .48145 .52594 .45711 Mtetra
.728 .61 .726 r
.52594 .45711 .53504 .48145 .55184 .4649 .54276 .44135 Mtetra
.748 .625 .723 r
.54276 .44135 .55184 .4649 .56859 .44596 .55956 .42338 Mtetra
.765 .639 .722 r
.55956 .42338 .56859 .44596 .58527 .42533 .5763 .40387 Mtetra
.777 .652 .724 r
.5763 .40387 .58527 .42533 .60187 .40375 .59299 .38349 Mtetra
.787 .664 .728 r
.59299 .38349 .60187 .40375 .61841 .38192 .60961 .36287 Mtetra
.793 .677 .736 r
.60961 .36287 .61841 .38192 .63488 .36044 .62619 .34257 Mtetra
.796 .688 .746 r
.62619 .34257 .63488 .36044 .65132 .33982 .64274 .32306 Mtetra
.796 .7 .758 r
.64274 .32306 .65132 .33982 .66776 .32041 .65929 .30466 Mtetra
.793 .71 .773 r
.65929 .30466 .66776 .32041 .68422 .30246 .67588 .2876 Mtetra
.787 .72 .789 r
.67588 .2876 .68422 .30246 .70075 .28607 .69252 .27198 Mtetra
.778 .728 .807 r
.69252 .27198 .70075 .28607 .71735 .27126 .70924 .2578 Mtetra
.767 .735 .824 r
.70924 .2578 .71735 .27126 .73407 .25795 .72607 .24501 Mtetra
.754 .74 .84 r
.72607 .24501 .73407 .25795 .75091 .24602 .74302 .23349 Mtetra
.74 .744 .855 r
.74302 .23349 .75091 .24602 .76788 .2353 .7601 .22308 Mtetra
.726 .746 .867 r
.7601 .22308 .76788 .2353 .78499 .22561 .77731 .21362 Mtetra
.713 .746 .878 r
.77731 .21362 .78499 .22561 .80225 .21678 .79466 .20493 Mtetra
.702 .746 .886 r
.79466 .20493 .80225 .21678 .81965 .20862 .81216 .19687 Mtetra
.605 .715 .923 r
.18501 .40379 .19483 .41339 .2088 .4106 .19904 .40077 Mtetra
.583 .704 .926 r
.19904 .40077 .2088 .4106 .2228 .40852 .21309 .39838 Mtetra
.555 .687 .928 r
.21309 .39838 .2228 .40852 .23682 .40731 .22717 .39679 Mtetra
.52 .666 .928 r
.22717 .39679 .23682 .40731 .25087 .40712 .24128 .39613 Mtetra
.478 .638 .926 r
.24128 .39613 .25087 .40712 .26493 .40813 .25542 .39655 Mtetra
.43 .603 .919 r
.25542 .39655 .26493 .40813 .27903 .41048 .26958 .39818 Mtetra
.379 .563 .907 r
.26958 .39818 .27903 .41048 .29318 .41424 .2838 .4011 Mtetra
.331 .52 .891 r
.2838 .4011 .29318 .41424 .30739 .41947 .29807 .40533 Mtetra
.291 .478 .871 r
.29807 .40533 .30739 .41947 .32168 .42611 .31243 .41083 Mtetra
.265 .443 .851 r
.31243 .41083 .32168 .42611 .3361 .43399 .32691 .41744 Mtetra
.257 .418 .832 r
.32691 .41744 .3361 .43399 .35066 .44287 .34153 .42493 Mtetra
.268 .405 .816 r
.34153 .42493 .35066 .44287 .36542 .45233 .35633 .43293 Mtetra
.297 .404 .802 r
.35633 .43293 .36542 .45233 .3804 .46188 .37134 .44099 Mtetra
.339 .413 .791 r
.37134 .44099 .3804 .46188 .39563 .47092 .38659 .44855 Mtetra
.39 .43 .781 r
.38659 .44855 .39563 .47092 .41113 .47879 .4021 .45504 Mtetra
.444 .451 .772 r
.4021 .45504 .41113 .47879 .4269 .48481 .41787 .45984 Mtetra
.497 .474 .762 r
.41787 .45984 .4269 .48481 .44294 .48838 .4339 .4624 Mtetra
.546 .497 .752 r
.4339 .4624 .44294 .48838 .45923 .48895 .45016 .46225 Mtetra
.59 .519 .743 r
.45016 .46225 .45923 .48895 .47572 .48617 .46663 .45908 Mtetra
.628 .539 .735 r
.46663 .45908 .47572 .48617 .49237 .47987 .48326 .45273 Mtetra
.661 .558 .728 r
.48326 .45273 .49237 .47987 .50912 .4701 .5 .44326 Mtetra
.689 .575 .722 r
.5 .44326 .50912 .4701 .52594 .45711 .51682 .43089 Mtetra
.712 .591 .719 r
.51682 .43089 .52594 .45711 .54276 .44135 .53366 .41603 Mtetra
.732 .607 .718 r
.53366 .41603 .54276 .44135 .55956 .42338 .55049 .39918 Mtetra
.747 .621 .719 r
.55049 .39918 .55956 .42338 .5763 .40387 .56728 .38094 Mtetra
.76 .635 .722 r
.56728 .38094 .5763 .40387 .59299 .38349 .58403 .36191 Mtetra
.77 .648 .728 r
.58403 .36191 .59299 .38349 .60961 .36287 .60074 .34266 Mtetra
.776 .662 .736 r
.60074 .34266 .60961 .36287 .62619 .34257 .61741 .32371 Mtetra
.78 .674 .747 r
.61741 .32371 .62619 .34257 .64274 .32306 .63407 .30545 Mtetra
.781 .687 .76 r
.63407 .30545 .64274 .32306 .65929 .30466 .65074 .2882 Mtetra
.779 .699 .775 r
.65074 .2882 .65929 .30466 .67588 .2876 .66744 .27214 Mtetra
.774 .71 .791 r
.66744 .27214 .67588 .2876 .69252 .27198 .6842 .25739 Mtetra
.767 .719 .808 r
.6842 .25739 .69252 .27198 .70924 .2578 .70104 .24394 Mtetra
.757 .727 .825 r
.70104 .24394 .70924 .2578 .72607 .24501 .71798 .23174 Mtetra
.745 .734 .841 r
.71798 .23174 .72607 .24501 .74302 .23349 .73504 .22067 Mtetra
.733 .738 .856 r
.73504 .22067 .74302 .23349 .7601 .22308 .75222 .21061 Mtetra
.72 .741 .868 r
.75222 .21061 .7601 .22308 .77731 .21362 .76954 .20141 Mtetra
.708 .743 .878 r
.76954 .20141 .77731 .21362 .79466 .20493 .78699 .1929 Mtetra
.698 .744 .887 r
.78699 .1929 .79466 .20493 .81216 .19687 .80458 .18496 Mtetra
.612 .716 .92 r
.1751 .39405 .18501 .40379 .19904 .40077 .18918 .39077 Mtetra
.593 .706 .922 r
.18918 .39077 .19904 .40077 .21309 .39838 .2033 .38807 Mtetra
.569 .691 .923 r
.2033 .38807 .21309 .39838 .22717 .39679 .21745 .38606 Mtetra
.539 .671 .923 r
.21745 .38606 .22717 .39679 .24128 .39613 .23162 .38488 Mtetra
.505 .647 .92 r
.23162 .38488 .24128 .39613 .25542 .39655 .24583 .38467 Mtetra
.466 .616 .914 r
.24583 .38467 .25542 .39655 .26958 .39818 .26007 .38553 Mtetra
.425 .581 .904 r
.26007 .38553 .26958 .39818 .2838 .4011 .27436 .38753 Mtetra
.387 .544 .889 r
.27436 .38753 .2838 .4011 .29807 .40533 .28871 .39069 Mtetra
.356 .508 .872 r
.28871 .39069 .29807 .40533 .31243 .41083 .30315 .39497 Mtetra
.336 .476 .853 r
.30315 .39497 .31243 .41083 .32691 .41744 .31769 .40022 Mtetra
.33 .452 .834 r
.31769 .40022 .32691 .41744 .34153 .42493 .33238 .40623 Mtetra
.338 .438 .816 r
.33238 .40623 .34153 .42493 .35633 .43293 .34723 .41268 Mtetra
.361 .433 .8 r
.34723 .41268 .35633 .43293 .37134 .44099 .36229 .41915 Mtetra
.393 .436 .786 r
.36229 .41915 .37134 .44099 .38659 .44855 .37757 .42516 Mtetra
.432 .446 .774 r
.37757 .42516 .38659 .44855 .4021 .45504 .39309 .43019 Mtetra
.474 .461 .762 r
.39309 .43019 .4021 .45504 .41787 .45984 .40886 .4337 Mtetra
.516 .477 .752 r
.40886 .4337 .41787 .45984 .4339 .4624 .42487 .43522 Mtetra
.556 .495 .743 r
.42487 .43522 .4339 .4624 .45016 .46225 .44112 .43434 Mtetra
.592 .513 .734 r
.44112 .43434 .45016 .46225 .46663 .45908 .45756 .43077 Mtetra
.625 .531 .727 r
.45756 .43077 .46663 .45908 .48326 .45273 .47416 .42439 Mtetra
.654 .547 .722 r
.47416 .42439 .48326 .45273 .5 .44326 .49089 .41526 Mtetra
.678 .564 .718 r
.49089 .41526 .5 .44326 .51682 .43089 .50769 .40356 Mtetra
.7 .579 .716 r
.50769 .40356 .51682 .43089 .53366 .41603 .52454 .38966 Mtetra
.718 .594 .716 r
.52454 .38966 .53366 .41603 .55049 .39918 .54139 .37401 Mtetra
.733 .608 .719 r
.54139 .37401 .55049 .39918 .56728 .38094 .55822 .35713 Mtetra
.745 .623 .723 r
.55822 .35713 .56728 .38094 .58403 .36191 .57503 .33954 Mtetra
.755 .637 .73 r
.57503 .33954 .58403 .36191 .60074 .34266 .59181 .32176 Mtetra
.762 .651 .739 r
.59181 .32176 .60074 .34266 .61741 .32371 .60857 .30422 Mtetra
.766 .664 .75 r
.60857 .30422 .61741 .32371 .63407 .30545 .62533 .28731 Mtetra
.767 .678 .764 r
.62533 .28731 .63407 .30545 .65074 .2882 .64211 .27127 Mtetra
.766 .69 .779 r
.64211 .27127 .65074 .2882 .66744 .27214 .65892 .25629 Mtetra
.762 .702 .795 r
.65892 .25629 .66744 .27214 .6842 .25739 .67579 .24246 Mtetra
.755 .712 .812 r
.67579 .24246 .6842 .25739 .70104 .24394 .69275 .22978 Mtetra
.746 .721 .829 r
.69275 .22978 .70104 .24394 .71798 .23174 .70981 .21821 Mtetra
.736 .728 .844 r
.70981 .21821 .71798 .23174 .73504 .22067 .72697 .20764 Mtetra
.725 .734 .858 r
.72697 .20764 .73504 .22067 .75222 .21061 .74426 .19795 Mtetra
.714 .738 .87 r
.74426 .19795 .75222 .21061 .76954 .20141 .76168 .18902 Mtetra
.703 .74 .88 r
.76168 .18902 .76954 .20141 .78699 .1929 .77923 .18071 Mtetra
.694 .741 .888 r
.77923 .18071 .78699 .1929 .80458 .18496 .79691 .17288 Mtetra
.619 .718 .917 r
.16509 .38419 .1751 .39405 .18918 .39077 .17923 .38065 Mtetra
.602 .708 .919 r
.17923 .38065 .18918 .39077 .2033 .38807 .19341 .37761 Mtetra
.582 .695 .919 r
.19341 .37761 .2033 .38807 .21745 .38606 .20763 .37518 Mtetra
.558 .678 .919 r
.20763 .37518 .21745 .38606 .23162 .38488 .22188 .37347 Mtetra
.529 .656 .916 r
.22188 .37347 .23162 .38488 .24583 .38467 .23617 .3726 Mtetra
.498 .629 .91 r
.23617 .3726 .24583 .38467 .26007 .38553 .25049 .37266 Mtetra
.466 .599 .901 r
.25049 .37266 .26007 .38553 .27436 .38753 .26486 .37372 Mtetra
.435 .567 .888 r
.26486 .37372 .27436 .38753 .28871 .39069 .2793 .37578 Mtetra
.41 .535 .872 r
.2793 .37578 .28871 .39069 .30315 .39497 .29382 .3788 Mtetra
.394 .506 .854 r
.29382 .3788 .30315 .39497 .31769 .40022 .30844 .38266 Mtetra
.388 .483 .835 r
.30844 .38266 .31769 .40022 .33238 .40623 .3232 .38717 Mtetra
.394 .467 .817 r
.3232 .38717 .33238 .40623 .34723 .41268 .33812 .39203 Mtetra
.411 .459 .8 r
.33812 .39203 .34723 .41268 .36229 .41915 .35322 .39689 Mtetra
.436 .458 .784 r
.35322 .39689 .36229 .41915 .37757 .42516 .36854 .40132 Mtetra
.466 .463 .771 r
.36854 .40132 .37757 .42516 .39309 .43019 .38408 .40489 Mtetra
.499 .472 .758 r
.38408 .40489 .39309 .43019 .40886 .4337 .39985 .40712 Mtetra
.532 .484 .748 r
.39985 .40712 .40886 .4337 .42487 .43522 .41586 .4076 Mtetra
.565 .498 .739 r
.41586 .4076 .42487 .43522 .44112 .43434 .43208 .40598 Mtetra
.595 .512 .731 r
.43208 .40598 .44112 .43434 .45756 .43077 .4485 .40203 Mtetra
.623 .527 .725 r
.4485 .40203 .45756 .43077 .47416 .42439 .46507 .39564 Mtetra
.648 .542 .721 r
.46507 .39564 .47416 .42439 .49089 .41526 .48177 .38686 Mtetra
.67 .557 .718 r
.48177 .38686 .49089 .41526 .50769 .40356 .49856 .37586 Mtetra
.69 .572 .717 r
.49856 .37586 .50769 .40356 .52454 .38966 .5154 .36294 Mtetra
.707 .586 .718 r
.5154 .36294 .52454 .38966 .54139 .37401 .53227 .34851 Mtetra
.721 .6 .721 r
.53227 .34851 .54139 .37401 .55822 .35713 .54913 .333 Mtetra
.733 .615 .727 r
.54913 .333 .55822 .35713 .57503 .33954 .56599 .31688 Mtetra
.742 .629 .734 r
.56599 .31688 .57503 .33954 .59181 .32176 .58284 .30058 Mtetra
.749 .643 .744 r
.58284 .30058 .59181 .32176 .60857 .30422 .59968 .28449 Mtetra
.753 .657 .756 r
.59968 .28449 .60857 .30422 .62533 .28731 .61653 .26893 Mtetra
.755 .671 .769 r
.61653 .26893 .62533 .28731 .64211 .27127 .63341 .25413 Mtetra
.754 .685 .785 r
.63341 .25413 .64211 .27127 .65892 .25629 .65033 .24025 Mtetra
.75 .697 .801 r
.65033 .24025 .65892 .25629 .67579 .24246 .66731 .22736 Mtetra
.744 .708 .817 r
.66731 .22736 .67579 .24246 .69275 .22978 .68438 .21546 Mtetra
.736 .717 .833 r
.68438 .21546 .69275 .22978 .70981 .21821 .70155 .20452 Mtetra
.727 .725 .848 r
.70155 .20452 .70981 .21821 .72697 .20764 .71882 .19445 Mtetra
.717 .731 .861 r
.71882 .19445 .72697 .20764 .74426 .19795 .73622 .18515 Mtetra
.707 .735 .872 r
.73622 .18515 .74426 .19795 .76168 .18902 .75374 .17649 Mtetra
.698 .738 .882 r
.75374 .17649 .76168 .18902 .77923 .18071 .77138 .16837 Mtetra
.69 .74 .889 r
.77138 .16837 .77923 .18071 .79691 .17288 .78916 .16067 Mtetra
.625 .72 .915 r
.15498 .37424 .16509 .38419 .17923 .38065 .16919 .37043 Mtetra
.612 .711 .916 r
.16919 .37043 .17923 .38065 .19341 .37761 .18343 .36705 Mtetra
.595 .7 .916 r
.18343 .36705 .19341 .37761 .20763 .37518 .19772 .36419 Mtetra
.575 .684 .915 r
.19772 .36419 .20763 .37518 .22188 .37347 .21205 .36195 Mtetra
.552 .665 .912 r
.21205 .36195 .22188 .37347 .23617 .3726 .22641 .36043 Mtetra
.526 .642 .906 r
.22641 .36043 .23617 .3726 .25049 .37266 .24082 .3597 Mtetra
.5 .616 .898 r
.24082 .3597 .25049 .37266 .26486 .37372 .25529 .35982 Mtetra
.476 .587 .886 r
.25529 .35982 .26486 .37372 .2793 .37578 .26981 .36079 Mtetra
.456 .559 .871 r
.26981 .36079 .2793 .37578 .29382 .3788 .28442 .36257 Mtetra
.442 .533 .855 r
.28442 .36257 .29382 .3788 .30844 .38266 .29913 .36506 Mtetra
.437 .511 .837 r
.29913 .36506 .30844 .38266 .3232 .38717 .31397 .36808 Mtetra
.44 .494 .819 r
.31397 .36808 .3232 .38717 .33812 .39203 .32896 .37139 Mtetra
.452 .484 .802 r
.32896 .37139 .33812 .39203 .35322 .39689 .34412 .37467 Mtetra
.47 .48 .786 r
.34412 .37467 .35322 .39689 .36854 .40132 .35948 .37758 Mtetra
.494 .481 .772 r
.35948 .37758 .36854 .40132 .38408 .40489 .37505 .37972 Mtetra
.52 .486 .759 r
.37505 .37972 .38408 .40489 .39985 .40712 .39083 .38071 Mtetra
.547 .494 .748 r
.39083 .38071 .39985 .40712 .41586 .4076 .40683 .38019 Mtetra
.573 .504 .739 r
.40683 .38019 .41586 .4076 .43208 .40598 .42304 .37787 Mtetra
.599 .516 .732 r
.42304 .37787 .43208 .40598 .4485 .40203 .43943 .37356 Mtetra
.623 .529 .727 r
.43943 .37356 .4485 .40203 .46507 .39564 .45598 .36717 Mtetra
.645 .542 .723 r
.45598 .36717 .46507 .39564 .48177 .38686 .47266 .35874 Mtetra
.665 .555 .721 r
.47266 .35874 .48177 .38686 .49856 .37586 .48942 .34842 Mtetra
.682 .569 .721 r
.48942 .34842 .49856 .37586 .5154 .36294 .50626 .33647 Mtetra
.697 .583 .723 r
.50626 .33647 .5154 .36294 .53227 .34851 .52313 .32322 Mtetra
.711 .597 .727 r
.52313 .32322 .53227 .34851 .54913 .333 .54002 .30906 Mtetra
.722 .611 .733 r
.54002 .30906 .54913 .333 .56599 .31688 .55692 .29436 Mtetra
.73 .625 .741 r
.55692 .29436 .56599 .31688 .58284 .30058 .57382 .27951 Mtetra
.737 .64 .751 r
.57382 .27951 .58284 .30058 .59968 .28449 .59074 .26483 Mtetra
.741 .654 .763 r
.59074 .26483 .59968 .28449 .61653 .26893 .60767 .25059 Mtetra
.743 .668 .777 r
.60767 .25059 .61653 .26893 .63341 .25413 .62465 .237 Mtetra
.742 .681 .792 r
.62465 .237 .63341 .25413 .65033 .24025 .64167 .22418 Mtetra
.739 .694 .808 r
.64167 .22418 .65033 .24025 .66731 .22736 .65876 .21221 Mtetra
.734 .705 .824 r
.65876 .21221 .66731 .22736 .68438 .21546 .67594 .20107 Mtetra
.727 .715 .839 r
.67594 .20107 .68438 .21546 .70155 .20452 .69321 .19075 Mtetra
.719 .722 .853 r
.69321 .19075 .70155 .20452 .71882 .19445 .71059 .18117 Mtetra
.71 .729 .865 r
.71059 .18117 .71882 .19445 .73622 .18515 .72809 .17224 Mtetra
.701 .733 .875 r
.72809 .17224 .73622 .18515 .75374 .17649 .74571 .16385 Mtetra
.693 .736 .884 r
.74571 .16385 .75374 .17649 .77138 .16837 .76345 .15592 Mtetra
.686 .738 .891 r
.76345 .15592 .77138 .16837 .78916 .16067 .78132 .14833 Mtetra
.631 .722 .913 r
.14477 .3642 .15498 .37424 .16919 .37043 .15904 .36014 Mtetra
.62 .715 .913 r
.15904 .36014 .16919 .37043 .18343 .36705 .17335 .35643 Mtetra
.607 .704 .913 r
.17335 .35643 .18343 .36705 .19772 .36419 .18771 .35316 Mtetra
.59 .691 .912 r
.18771 .35316 .19772 .36419 .21205 .36195 .20212 .3504 Mtetra
.571 .674 .909 r
.20212 .3504 .21205 .36195 .22641 .36043 .21657 .34825 Mtetra
.551 .654 .904 r
.21657 .34825 .22641 .36043 .24082 .3597 .23106 .34676 Mtetra
.53 .632 .896 r
.23106 .34676 .24082 .3597 .25529 .35982 .24562 .34597 Mtetra
.51 .607 .885 r
.24562 .34597 .25529 .35982 .26981 .36079 .26024 .34589 Mtetra
.494 .582 .872 r
.26024 .34589 .26981 .36079 .28442 .36257 .27494 .34649 Mtetra
.482 .558 .856 r
.27494 .34649 .28442 .36257 .29913 .36506 .28974 .34767 Mtetra
.477 .537 .84 r
.28974 .34767 .29913 .36506 .31397 .36808 .30467 .34928 Mtetra
.478 .52 .822 r
.30467 .34928 .31397 .36808 .32896 .37139 .31973 .35111 Mtetra
.486 .508 .806 r
.31973 .35111 .32896 .37139 .34412 .37467 .33496 .35291 Mtetra
.5 .502 .79 r
.33496 .35291 .34412 .37467 .35948 .37758 .35036 .35437 Mtetra
.518 .5 .776 r
.35036 .35437 .35948 .37758 .37505 .37972 .36597 .35517 Mtetra
.538 .502 .763 r
.36597 .35517 .37505 .37972 .39083 .38071 .38177 .35499 Mtetra
.56 .507 .753 r
.38177 .35499 .39083 .38071 .40683 .38019 .39777 .35354 Mtetra
.582 .514 .744 r
.39777 .35354 .40683 .38019 .42304 .37787 .41397 .35057 Mtetra
.603 .523 .737 r
.41397 .35057 .42304 .37787 .43943 .37356 .43034 .34593 Mtetra
.624 .534 .732 r
.43034 .34593 .43943 .37356 .45598 .36717 .44687 .33954 Mtetra
.643 .545 .729 r
.44687 .33954 .45598 .36717 .47266 .35874 .46352 .33144 Mtetra
.661 .557 .728 r
.46352 .33144 .47266 .35874 .48942 .34842 .48027 .32177 Mtetra
.676 .57 .728 r
.48027 .32177 .48942 .34842 .50626 .33647 .49709 .31073 Mtetra
.69 .583 .731 r
.49709 .31073 .50626 .33647 .52313 .32322 .51397 .2986 Mtetra
.702 .597 .735 r
.51397 .2986 .52313 .32322 .54002 .30906 .53088 .2857 Mtetra
.712 .611 .742 r
.53088 .2857 .54002 .30906 .55692 .29436 .54781 .27235 Mtetra
.721 .625 .75 r
.54781 .27235 .55692 .29436 .57382 .27951 .56477 .25886 Mtetra
.727 .639 .761 r
.56477 .25886 .57382 .27951 .59074 .26483 .58175 .2455 Mtetra
.731 .654 .773 r
.58175 .2455 .59074 .26483 .60767 .25059 .59877 .23252 Mtetra
.732 .668 .787 r
.59877 .23252 .60767 .25059 .62465 .237 .61583 .22006 Mtetra
.731 .681 .801 r
.61583 .22006 .62465 .237 .64167 .22418 .63295 .20825 Mtetra
.729 .693 .816 r
.63295 .20825 .64167 .22418 .65876 .21221 .65014 .19713 Mtetra
.724 .704 .831 r
.65014 .19713 .65876 .21221 .67594 .20107 .66742 .18672 Mtetra
.718 .714 .845 r
.66742 .18672 .67594 .20107 .69321 .19075 .6848 .17698 Mtetra
.71 .721 .858 r
.6848 .17698 .69321 .19075 .71059 .18117 .70228 .16785 Mtetra
.703 .727 .869 r
.70228 .16785 .71059 .18117 .72809 .17224 .71988 .15926 Mtetra
.695 .732 .879 r
.71988 .15926 .72809 .17224 .74571 .16385 .73759 .15113 Mtetra
.689 .735 .886 r
.73759 .15113 .74571 .16385 .76345 .15592 .75543 .14336 Mtetra
.683 .738 .892 r
.75543 .14336 .76345 .15592 .78132 .14833 .7734 .13589 Mtetra
.637 .725 .911 r
.13445 .3541 .14477 .3642 .15904 .36014 .14878 .34979 Mtetra
.628 .718 .911 r
.14878 .34979 .15904 .36014 .17335 .35643 .16316 .34577 Mtetra
.617 .709 .911 r
.16316 .34577 .17335 .35643 .18771 .35316 .17759 .3421 Mtetra
.604 .697 .91 r
.17759 .3421 .18771 .35316 .20212 .3504 .19208 .33886 Mtetra
.589 .683 .907 r
.19208 .33886 .20212 .3504 .21657 .34825 .20661 .33611 Mtetra
.572 .666 .902 r
.20661 .33611 .21657 .34825 .23106 .34676 .2212 .33391 Mtetra
.555 .647 .895 r
.2212 .33391 .23106 .34676 .24562 .34597 .23585 .33228 Mtetra
.539 .625 .885 r
.23585 .33228 .24562 .34597 .26024 .34589 .25056 .33123 Mtetra
.526 .603 .873 r
.25056 .33123 .26024 .34589 .27494 .34649 .26536 .33072 Mtetra
.516 .581 .859 r
.26536 .33072 .27494 .34649 .28974 .34767 .28026 .33068 Mtetra
.511 .562 .844 r
.28026 .33068 .28974 .34767 .30467 .34928 .29527 .33099 Mtetra
.511 .545 .828 r
.29527 .33099 .30467 .34928 .31973 .35111 .31041 .33146 Mtetra
.516 .533 .812 r
.31041 .33146 .31973 .35111 .33496 .35291 .32571 .33189 Mtetra
.526 .525 .797 r
.32571 .33189 .33496 .35291 .35036 .35437 .34117 .33203 Mtetra
.539 .52 .783 r
.34117 .33203 .35036 .35437 .36597 .35517 .35681 .3316 Mtetra
.555 .52 .771 r
.35681 .3316 .36597 .35517 .38177 .35499 .37264 .33036 Mtetra
.572 .522 .76 r
.37264 .33036 .38177 .35499 .39777 .35354 .38865 .32805 Mtetra
.591 .527 .752 r
.38865 .32805 .39777 .35354 .41397 .35057 .40485 .3245 Mtetra
.609 .534 .745 r
.40485 .3245 .41397 .35057 .43034 .34593 .42121 .31955 Mtetra
.626 .543 .741 r
.42121 .31955 .43034 .34593 .44687 .33954 .43771 .31318 Mtetra
.643 .553 .738 r
.43771 .31318 .44687 .33954 .46352 .33144 .45435 .30539 Mtetra
.658 .564 .737 r
.45435 .30539 .46352 .33144 .48027 .32177 .47108 .2963 Mtetra
.672 .575 .738 r
.47108 .2963 .48027 .32177 .49709 .31073 .4879 .28609 Mtetra
.685 .588 .741 r
.4879 .28609 .49709 .31073 .51397 .2986 .50478 .27498 Mtetra
.695 .601 .746 r
.50478 .27498 .51397 .2986 .53088 .2857 .52171 .26323 Mtetra
.705 .614 .753 r
.52171 .26323 .53088 .2857 .54781 .27235 .53868 .2511 Mtetra
.712 .628 .762 r
.53868 .2511 .54781 .27235 .56477 .25886 .55568 .23885 Mtetra
.718 .642 .772 r
.55568 .23885 .56477 .25886 .58175 .2455 .57273 .22671 Mtetra
.721 .656 .784 r
.57273 .22671 .58175 .2455 .59877 .23252 .58982 .21486 Mtetra
.722 .669 .798 r
.58982 .21486 .59877 .23252 .61583 .22006 .60696 .20344 Mtetra
.722 .682 .812 r
.60696 .20344 .61583 .22006 .63295 .20825 .62417 .19254 Mtetra
.719 .694 .826 r
.62417 .19254 .63295 .20825 .65014 .19713 .64146 .18221 Mtetra
.715 .705 .84 r
.64146 .18221 .65014 .19713 .66742 .18672 .65883 .17245 Mtetra
.709 .714 .852 r
.65883 .17245 .66742 .18672 .6848 .17698 .67631 .16324 Mtetra
.703 .721 .864 r
.67631 .16324 .6848 .17698 .70228 .16785 .69389 .15452 Mtetra
.696 .727 .874 r
.69389 .15452 .70228 .16785 .71988 .15926 .71158 .14624 Mtetra
.69 .732 .882 r
.71158 .14624 .71988 .15926 .73759 .15113 .7294 .13833 Mtetra
.684 .735 .889 r
.7294 .13833 .73759 .15113 .75543 .14336 .74733 .13072 Mtetra
.679 .737 .894 r
.74733 .13072 .75543 .14336 .7734 .13589 .76539 .12333 Mtetra
.642 .727 .91 r
.12402 .34393 .13445 .3541 .14878 .34979 .13841 .33939 Mtetra
.635 .721 .91 r
.13841 .33939 .14878 .34979 .16316 .34577 .15286 .33508 Mtetra
.626 .714 .909 r
.15286 .33508 .16316 .34577 .17759 .3421 .16737 .33105 Mtetra
.615 .704 .908 r
.16737 .33105 .17759 .3421 .19208 .33886 .18193 .32737 Mtetra
.603 .692 .905 r
.18193 .32737 .19208 .33886 .20661 .33611 .19654 .32408 Mtetra
.59 .677 .901 r
.19654 .32408 .20661 .33611 .2212 .33391 .21122 .32122 Mtetra
.577 .661 .895 r
.21122 .32122 .2212 .33391 .23585 .33228 .22596 .31882 Mtetra
.564 .642 .886 r
.22596 .31882 .23585 .33228 .25056 .33123 .24077 .31688 Mtetra
.553 .623 .876 r
.24077 .31688 .25056 .33123 .26536 .33072 .25567 .31538 Mtetra
.544 .604 .863 r
.25567 .31538 .26536 .33072 .28026 .33068 .27066 .31424 Mtetra
.539 .586 .85 r
.27066 .31424 .28026 .33068 .29527 .33099 .28576 .31337 Mtetra
.538 .57 .835 r
.28576 .31337 .29527 .33099 .31041 .33146 .30098 .31262 Mtetra
.541 .557 .82 r
.30098 .31262 .31041 .33146 .32571 .33189 .31635 .31183 Mtetra
.548 .548 .806 r
.31635 .31183 .32571 .33189 .34117 .33203 .33187 .31078 Mtetra
.558 .542 .793 r
.33187 .31078 .34117 .33203 .35681 .3316 .34756 .30926 Mtetra
.571 .54 .781 r
.34756 .30926 .35681 .3316 .37264 .33036 .36342 .30707 Mtetra
.585 .54 .771 r
.36342 .30707 .37264 .33036 .38865 .32805 .37945 .30401 Mtetra
.599 .543 .763 r
.37945 .30401 .38865 .32805 .40485 .3245 .39565 .29993 Mtetra
.614 .548 .756 r
.39565 .29993 .40485 .3245 .42121 .31955 .412 .29472 Mtetra
.629 .555 .752 r
.412 .29472 .42121 .31955 .43771 .31318 .4285 .28835 Mtetra
.643 .563 .75 r
.4285 .28835 .43771 .31318 .45435 .30539 .44512 .28084 Mtetra
.657 .573 .749 r
.44512 .28084 .45435 .30539 .47108 .2963 .46185 .27227 Mtetra
.669 .584 .751 r
.46185 .27227 .47108 .2963 .4879 .28609 .47866 .26279 Mtetra
.68 .595 .754 r
.47866 .26279 .4879 .28609 .50478 .27498 .49555 .25258 Mtetra
.69 .608 .759 r
.49555 .25258 .50478 .27498 .52171 .26323 .5125 .24184 Mtetra
.698 .62 .766 r
.5125 .24184 .52171 .26323 .53868 .2511 .5295 .2308 Mtetra
.705 .634 .775 r
.5295 .2308 .53868 .2511 .55568 .23885 .54655 .21965 Mtetra
.709 .647 .785 r
.54655 .21965 .55568 .23885 .57273 .22671 .56365 .20858 Mtetra
.712 .661 .797 r
.56365 .20858 .57273 .22671 .58982 .21486 .58081 .19774 Mtetra
.713 .674 .81 r
.58081 .19774 .58982 .21486 .60696 .20344 .59803 .18723 Mtetra
.712 .686 .823 r
.59803 .18723 .60696 .20344 .62417 .19254 .61532 .17714 Mtetra
.71 .697 .836 r
.61532 .17714 .62417 .19254 .64146 .18221 .6327 .1675 Mtetra
.706 .707 .848 r
.6327 .1675 .64146 .18221 .65883 .17245 .65017 .15832 Mtetra
.701 .715 .86 r
.65017 .15832 .65883 .17245 .67631 .16324 .66774 .14957 Mtetra
.696 .722 .87 r
.66774 .14957 .67631 .16324 .69389 .15452 .68542 .14121 Mtetra
.69 .728 .879 r
.68542 .14121 .69389 .15452 .71158 .14624 .70321 .1332 Mtetra
.685 .732 .886 r
.70321 .1332 .71158 .14624 .7294 .13833 .72111 .12548 Mtetra
.68 .735 .892 r
.72111 .12548 .7294 .13833 .74733 .13072 .73914 .11799 Mtetra
.676 .737 .896 r
.73914 .11799 .74733 .13072 .76539 .12333 .75729 .11067 Mtetra
.646 .729 .909 r
.11348 .33371 .12402 .34393 .13841 .33939 .12793 .32896 Mtetra
.641 .724 .909 r
.12793 .32896 .13841 .33939 .15286 .33508 .14244 .32438 Mtetra
.634 .718 .908 r
.14244 .32438 .15286 .33508 .16737 .33105 .15702 .32003 Mtetra
.625 .71 .907 r
.15702 .32003 .16737 .33105 .18193 .32737 .17166 .31594 Mtetra
.616 .7 .904 r
.17166 .31594 .18193 .32737 .19654 .32408 .18636 .31216 Mtetra
.606 .688 .9 r
.18636 .31216 .19654 .32408 .21122 .32122 .20112 .30872 Mtetra
.595 .674 .895 r
.20112 .30872 .21122 .32122 .22596 .31882 .21595 .30564 Mtetra
.585 .658 .888 r
.21595 .30564 .22596 .31882 .24077 .31688 .23086 .30292 Mtetra
.576 .641 .879 r
.23086 .30292 .24077 .31688 .25567 .31538 .24584 .30053 Mtetra
.568 .625 .868 r
.24584 .30053 .25567 .31538 .27066 .31424 .26093 .29843 Mtetra
.564 .609 .856 r
.26093 .29843 .27066 .31424 .28576 .31337 .27612 .29652 Mtetra
.562 .594 .843 r
.27612 .29652 .28576 .31337 .30098 .31262 .29143 .2947 Mtetra
.564 .581 .83 r
.29143 .2947 .30098 .31262 .31635 .31183 .30687 .29283 Mtetra
.569 .572 .817 r
.30687 .29283 .31635 .31183 .33187 .31078 .32245 .29074 Mtetra
.576 .565 .804 r
.32245 .29074 .33187 .31078 .34756 .30926 .33819 .28827 Mtetra
.585 .561 .793 r
.33819 .28827 .34756 .30926 .36342 .30707 .35409 .28525 Mtetra
.596 .56 .784 r
.35409 .28525 .36342 .30707 .37945 .30401 .37014 .28154 Mtetra
.608 .561 .776 r
.37014 .28154 .37945 .30401 .39565 .29993 .38635 .277 Mtetra
.621 .565 .77 r
.38635 .277 .39565 .29993 .412 .29472 .40271 .27156 Mtetra
.633 .57 .766 r
.40271 .27156 .412 .29472 .4285 .28835 .4192 .26519 Mtetra
.645 .577 .764 r
.4192 .26519 .4285 .28835 .44512 .28084 .43582 .25791 Mtetra
.657 .586 .764 r
.43582 .25791 .44512 .28084 .46185 .27227 .45255 .24979 Mtetra
.667 .595 .765 r
.45255 .24979 .46185 .27227 .47866 .26279 .46936 .24094 Mtetra
.677 .606 .769 r
.46936 .24094 .47866 .26279 .49555 .25258 .48626 .2315 Mtetra
.685 .617 .774 r
.48626 .2315 .49555 .25258 .5125 .24184 .50323 .22164 Mtetra
.693 .63 .781 r
.50323 .22164 .5125 .24184 .5295 .2308 .52026 .21153 Mtetra
.698 .642 .79 r
.52026 .21153 .5295 .2308 .54655 .21965 .53736 .20132 Mtetra
.702 .655 .8 r
.53736 .20132 .54655 .21965 .56365 .20858 .55452 .19117 Mtetra
.704 .667 .811 r
.55452 .19117 .56365 .20858 .58081 .19774 .57174 .1812 Mtetra
.705 .679 .822 r
.57174 .1812 .58081 .19774 .59803 .18723 .58904 .17148 Mtetra
.704 .691 .834 r
.58904 .17148 .59803 .18723 .61532 .17714 .60641 .16209 Mtetra
.702 .701 .846 r
.60641 .16209 .61532 .17714 .6327 .1675 .62387 .15304 Mtetra
.698 .71 .857 r
.62387 .15304 .6327 .1675 .65017 .15832 .64143 .14434 Mtetra
.694 .718 .867 r
.64143 .14434 .65017 .15832 .66774 .14957 .65909 .13599 Mtetra
.69 .724 .876 r
.65909 .13599 .66774 .14957 .68542 .14121 .67686 .12793 Mtetra
.685 .729 .883 r
.67686 .12793 .68542 .14121 .70321 .1332 .69474 .12014 Mtetra
.681 .733 .89 r
.69474 .12014 .70321 .1332 .72111 .12548 .71274 .11257 Mtetra
.677 .735 .894 r
.71274 .11257 .72111 .12548 .73914 .11799 .73086 .10518 Mtetra
.674 .737 .898 r
.73086 .10518 .73914 .11799 .75729 .11067 .7491 .09792 Mtetra
.65 .731 .909 r
.10282 .32343 .11348 .33371 .12793 .32896 .11733 .31849 Mtetra
.645 .727 .908 r
.11733 .31849 .12793 .32896 .14244 .32438 .13191 .31368 Mtetra
.64 .722 .907 r
.13191 .31368 .14244 .32438 .15702 .32003 .14655 .30904 Mtetra
.634 .715 .906 r
.14655 .30904 .15702 .32003 .17166 .31594 .16127 .3046 Mtetra
.626 .707 .904 r
.16127 .3046 .17166 .31594 .18636 .31216 .17604 .30039 Mtetra
.618 .697 .901 r
.17604 .30039 .18636 .31216 .20112 .30872 .19089 .29644 Mtetra
.61 .685 .896 r
.19089 .29644 .20112 .30872 .21595 .30564 .20581 .29276 Mtetra
.602 .672 .89 r
.20581 .29276 .21595 .30564 .23086 .30292 .2208 .28936 Mtetra
.595 .658 .882 r
.2208 .28936 .23086 .30292 .24584 .30053 .23588 .2862 Mtetra
.589 .644 .873 r
.23588 .2862 .24584 .30053 .26093 .29843 .25106 .28326 Mtetra
.585 .63 .863 r
.25106 .28326 .26093 .29843 .27612 .29652 .26633 .28047 Mtetra
.583 .617 .851 r
.26633 .28047 .27612 .29652 .29143 .2947 .28172 .27773 Mtetra
.583 .605 .84 r
.28172 .27773 .29143 .2947 .30687 .29283 .29724 .27493 Mtetra
.587 .595 .828 r
.29724 .27493 .30687 .29283 .32245 .29074 .31289 .27196 Mtetra
.592 .588 .817 r
.31289 .27196 .32245 .29074 .33819 .28827 .32868 .26867 Mtetra
.599 .584 .807 r
.32868 .26867 .33819 .28827 .35409 .28525 .34462 .26495 Mtetra
.608 .581 .798 r
.34462 .26495 .35409 .28525 .37014 .28154 .36071 .26067 Mtetra
.617 .581 .791 r
.36071 .26067 .37014 .28154 .38635 .277 .37694 .25574 Mtetra
.627 .584 .786 r
.37694 .25574 .38635 .277 .40271 .27156 .39331 .2501 Mtetra
.637 .588 .782 r
.39331 .2501 .40271 .27156 .4192 .26519 .40981 .24373 Mtetra
.648 .594 .78 r
.40981 .24373 .4192 .26519 .43582 .25791 .42643 .23664 Mtetra
.657 .601 .78 r
.42643 .23664 .43582 .25791 .45255 .24979 .44316 .22888 Mtetra
.666 .609 .782 r
.44316 .22888 .45255 .24979 .46936 .24094 .45999 .22055 Mtetra
.675 .619 .785 r
.45999 .22055 .46936 .24094 .48626 .2315 .47691 .21176 Mtetra
.682 .63 .79 r
.47691 .21176 .48626 .2315 .50323 .22164 .4939 .20263 Mtetra
.688 .641 .797 r
.4939 .20263 .50323 .22164 .52026 .21153 .51097 .1933 Mtetra
.692 .652 .805 r
.51097 .1933 .52026 .21153 .53736 .20132 .52811 .18389 Mtetra
.696 .664 .815 r
.52811 .18389 .53736 .20132 .55452 .19117 .54532 .17451 Mtetra
.697 .675 .825 r
.54532 .17451 .55452 .19117 .57174 .1812 .56261 .16525 Mtetra
.698 .686 .835 r
.56261 .16525 .57174 .1812 .58904 .17148 .57997 .15619 Mtetra
.697 .696 .846 r
.57997 .15619 .58904 .17148 .60641 .16209 .59743 .14738 Mtetra
.695 .706 .856 r
.59743 .14738 .60641 .16209 .62387 .15304 .61497 .13882 Mtetra
.692 .714 .865 r
.61497 .13882 .62387 .15304 .64143 .14434 .63262 .13053 Mtetra
.688 .72 .874 r
.63262 .13053 .64143 .14434 .65909 .13599 .65036 .12249 Mtetra
.684 .726 .881 r
.65036 .12249 .65909 .13599 .67686 .12793 .66822 .11468 Mtetra
.68 .73 .888 r
.66822 .11468 .67686 .12793 .69474 .12014 .68619 .10707 Mtetra
.677 .733 .893 r
.68619 .10707 .69474 .12014 .71274 .11257 .70428 .09962 Mtetra
.674 .736 .897 r
.70428 .09962 .71274 .11257 .73086 .10518 .72249 .09229 Mtetra
.671 .738 .9 r
.72249 .09229 .73086 .10518 .7491 .09792 .74081 .08505 Mtetra
.653 .733 .908 r
.09204 .3131 .10282 .32343 .11733 .31849 .10661 .30799 Mtetra
.65 .73 .908 r
.10661 .30799 .11733 .31849 .13191 .31368 .12125 .30297 Mtetra
.645 .726 .907 r
.12125 .30297 .13191 .31368 .14655 .30904 .13597 .29807 Mtetra
.64 .72 .906 r
.13597 .29807 .14655 .30904 .16127 .3046 .15075 .29332 Mtetra
.635 .714 .904 r
.15075 .29332 .16127 .3046 .17604 .30039 .1656 .28875 Mtetra
.629 .705 .901 r
.1656 .28875 .17604 .30039 .19089 .29644 .18053 .28436 Mtetra
.622 .696 .897 r
.18053 .28436 .19089 .29644 .20581 .29276 .19553 .28017 Mtetra
.616 .685 .892 r
.19553 .28017 .20581 .29276 .2208 .28936 .21061 .27618 Mtetra
.61 .674 .886 r
.21061 .27618 .2208 .28936 .23588 .2862 .22578 .27238 Mtetra
.606 .662 .878 r
.22578 .27238 .23588 .2862 .25106 .28326 .24104 .26873 Mtetra
.602 .649 .869 r
.24104 .26873 .25106 .28326 .26633 .28047 .2564 .26518 Mtetra
.6 .638 .86 r
.2564 .26518 .26633 .28047 .28172 .27773 .27187 .26167 Mtetra
.6 .627 .85 r
.27187 .26167 .28172 .27773 .29724 .27493 .28746 .2581 Mtetra
.602 .618 .84 r
.28746 .2581 .29724 .27493 .31289 .27196 .30318 .25438 Mtetra
.606 .611 .83 r
.30318 .25438 .31289 .27196 .32868 .26867 .31903 .25041 Mtetra
.611 .606 .821 r
.31903 .25041 .32868 .26867 .34462 .26495 .33501 .24609 Mtetra
.618 .603 .814 r
.33501 .24609 .34462 .26495 .36071 .26067 .35114 .24133 Mtetra
.626 .603 .807 r
.35114 .24133 .36071 .26067 .37694 .25574 .3674 .23607 Mtetra
.634 .604 .802 r
.3674 .23607 .37694 .25574 .39331 .2501 .38379 .23026 Mtetra
.642 .607 .799 r
.38379 .23026 .39331 .2501 .40981 .24373 .40031 .22387 Mtetra
.65 .612 .797 r
.40031 .22387 .40981 .24373 .42643 .23664 .41694 .21693 Mtetra
.658 .618 .797 r
.41694 .21693 .42643 .23664 .44316 .22888 .43368 .20947 Mtetra
.666 .625 .799 r
.43368 .20947 .44316 .22888 .45999 .22055 .45053 .20157 Mtetra
.673 .634 .803 r
.45053 .20157 .45999 .22055 .47691 .21176 .46747 .1933 Mtetra
.679 .643 .807 r
.46747 .1933 .47691 .21176 .4939 .20263 .48449 .18476 Mtetra
.684 .653 .814 r
.48449 .18476 .4939 .20263 .51097 .1933 .50159 .17606 Mtetra
.687 .664 .821 r
.50159 .17606 .51097 .1933 .52811 .18389 .51878 .16729 Mtetra
.69 .674 .83 r
.51878 .16729 .52811 .18389 .54532 .17451 .53605 .15854 Mtetra
.691 .684 .838 r
.53605 .15854 .54532 .17451 .56261 .16525 .5534 .14987 Mtetra
.691 .694 .848 r
.5534 .14987 .56261 .16525 .57997 .15619 .57084 .14134 Mtetra
.69 .703 .857 r
.57084 .14134 .57997 .15619 .59743 .14738 .58836 .13299 Mtetra
.688 .711 .865 r
.58836 .13299 .59743 .14738 .61497 .13882 .60599 .12483 Mtetra
.686 .717 .873 r
.60599 .12483 .61497 .13882 .63262 .13053 .62372 .11686 Mtetra
.683 .723 .88 r
.62372 .11686 .63262 .13053 .65036 .12249 .64155 .10907 Mtetra
.68 .728 .886 r
.64155 .10907 .65036 .12249 .66822 .11468 .65949 .10145 Mtetra
.677 .732 .892 r
.65949 .10145 .66822 .11468 .68619 .10707 .67755 .09397 Mtetra
.674 .734 .896 r
.67755 .09397 .68619 .10707 .70428 .09962 .69573 .0866 Mtetra
.671 .737 .899 r
.69573 .0866 .70428 .09962 .72249 .09229 .71402 .07931 Mtetra
.67 .738 .902 r
.71402 .07931 .72249 .09229 .74081 .08505 .73244 .07209 Mtetra
.656 .735 .908 r
.08115 .30271 .09204 .3131 .10661 .30799 .09577 .29744 Mtetra
.653 .732 .907 r
.09577 .29744 .10661 .30799 .12125 .30297 .11047 .29224 Mtetra
.65 .729 .907 r
.11047 .29224 .12125 .30297 .13597 .29807 .12525 .28713 Mtetra
.646 .725 .906 r
.12525 .28713 .13597 .29807 .15075 .29332 .1401 .28211 Mtetra
.642 .719 .904 r
.1401 .28211 .15075 .29332 .1656 .28875 .15503 .27722 Mtetra
.637 .713 .902 r
.15503 .27722 .1656 .28875 .18053 .28436 .17003 .27246 Mtetra
.632 .705 .899 r
.17003 .27246 .18053 .28436 .19553 .28017 .18511 .26785 Mtetra
.628 .697 .894 r
.18511 .26785 .19553 .28017 .21061 .27618 .20027 .26337 Mtetra
.623 .687 .889 r
.20027 .26337 .21061 .27618 .22578 .27238 .21552 .25903 Mtetra
.619 .677 .883 r
.21552 .25903 .22578 .27238 .24104 .26873 .23087 .25479 Mtetra
.616 .667 .876 r
.23087 .25479 .24104 .26873 .2564 .26518 .24631 .25062 Mtetra
.615 .657 .868 r
.24631 .25062 .2564 .26518 .27187 .26167 .26186 .24645 Mtetra
.615 .648 .86 r
.26186 .24645 .27187 .26167 .28746 .2581 .27752 .24224 Mtetra
.616 .64 .852 r
.27752 .24224 .28746 .2581 .30318 .25438 .29331 .23791 Mtetra
.619 .634 .843 r
.29331 .23791 .30318 .25438 .31903 .25041 .30921 .23337 Mtetra
.622 .629 .836 r
.30921 .23337 .31903 .25041 .33501 .24609 .32525 .22856 Mtetra
.627 .625 .829 r
.32525 .22856 .33501 .24609 .35114 .24133 .34142 .22341 Mtetra
.633 .624 .823 r
.34142 .22341 .35114 .24133 .3674 .23607 .35771 .21787 Mtetra
.64 .625 .819 r
.35771 .21787 .3674 .23607 .38379 .23026 .37413 .2119 Mtetra
.646 .627 .816 r
.37413 .2119 .38379 .23026 .40031 .22387 .39067 .2055 Mtetra
.653 .631 .815 r
.39067 .2055 .40031 .22387 .41694 .21693 .40733 .19867 Mtetra
.66 .636 .815 r
.40733 .19867 .41694 .21693 .43368 .20947 .4241 .19144 Mtetra
.666 .642 .817 r
.4241 .19144 .43368 .20947 .45053 .20157 .44097 .18386 Mtetra
.671 .65 .82 r
.44097 .18386 .45053 .20157 .46747 .1933 .45793 .176 Mtetra
.676 .658 .824 r
.45793 .176 .46747 .1933 .48449 .18476 .47499 .16793 Mtetra
.68 .666 .83 r
.47499 .16793 .48449 .18476 .50159 .17606 .49214 .15973 Mtetra
.683 .675 .837 r
.49214 .15973 .50159 .17606 .51878 .16729 .50937 .15146 Mtetra
.685 .684 .844 r
.50937 .15146 .51878 .16729 .53605 .15854 .5267 .1432 Mtetra
.686 .693 .851 r
.5267 .1432 .53605 .15854 .5534 .14987 .54411 .135 Mtetra
.685 .701 .859 r
.54411 .135 .5534 .14987 .57084 .14134 .56161 .12688 Mtetra
.684 .709 .867 r
.56161 .12688 .57084 .14134 .58836 .13299 .57922 .11889 Mtetra
.683 .716 .874 r
.57922 .11889 .58836 .13299 .60599 .12483 .59692 .11103 Mtetra
.681 .721 .88 r
.59692 .11103 .60599 .12483 .62372 .11686 .61473 .10331 Mtetra
.678 .726 .886 r
.61473 .10331 .62372 .11686 .64155 .10907 .63264 .09571 Mtetra
.676 .73 .891 r
.63264 .09571 .64155 .10907 .65949 .10145 .65067 .08822 Mtetra
.673 .733 .895 r
.65067 .08822 .65949 .10145 .67755 .09397 .66882 .08083 Mtetra
.671 .736 .898 r
.66882 .08083 .67755 .09397 .69573 .0866 .68708 .07351 Mtetra
.67 .737 .901 r
.68708 .07351 .69573 .0866 .71402 .07931 .70546 .06624 Mtetra
.668 .739 .903 r
.70546 .06624 .71402 .07931 .73244 .07209 .72396 .05901 Mtetra
.658 .736 .908 r
.07013 .29225 .08115 .30271 .09577 .29744 .08481 .28685 Mtetra
.656 .734 .907 r
.08481 .28685 .09577 .29744 .11047 .29224 .09957 .28149 Mtetra
.653 .732 .907 r
.09957 .28149 .11047 .29224 .12525 .28713 .11441 .27618 Mtetra
.651 .728 .906 r
.11441 .27618 .12525 .28713 .1401 .28211 .12932 .27095 Mtetra
.647 .724 .904 r
.12932 .27095 .1401 .28211 .15503 .27722 .14432 .26579 Mtetra
.644 .719 .903 r
.14432 .26579 .15503 .27722 .17003 .27246 .15939 .26072 Mtetra
.64 .713 .9 r
.15939 .26072 .17003 .27246 .18511 .26785 .17455 .25575 Mtetra
.637 .706 .897 r
.17455 .25575 .18511 .26785 .20027 .26337 .18979 .25087 Mtetra
.633 .699 .893 r
.18979 .25087 .20027 .26337 .21552 .25903 .20512 .24608 Mtetra
.63 .691 .888 r
.20512 .24608 .21552 .25903 .23087 .25479 .22054 .24136 Mtetra
.628 .683 .882 r
.22054 .24136 .23087 .25479 .24631 .25062 .23606 .23667 Mtetra
.627 .674 .876 r
.23606 .23667 .24631 .25062 .26186 .24645 .25169 .23199 Mtetra
.626 .667 .869 r
.25169 .23199 .26186 .24645 .27752 .24224 .26742 .22725 Mtetra
.627 .66 .862 r
.26742 .22725 .27752 .24224 .29331 .23791 .28327 .22241 Mtetra
.629 .654 .856 r
.28327 .22241 .29331 .23791 .30921 .23337 .29924 .21741 Mtetra
.632 .65 .849 r
.29924 .21741 .30921 .23337 .32525 .22856 .31533 .2122 Mtetra
.636 .647 .844 r
.31533 .2122 .32525 .22856 .34142 .22341 .33154 .20673 Mtetra
.64 .645 .839 r
.33154 .20673 .34142 .22341 .35771 .21787 .34788 .20095 Mtetra
.645 .645 .835 r
.34788 .20095 .35771 .21787 .37413 .2119 .36433 .19485 Mtetra
.65 .647 .833 r
.36433 .19485 .37413 .2119 .39067 .2055 .38091 .18842 Mtetra
.656 .65 .832 r
.38091 .18842 .39067 .2055 .40733 .19867 .3976 .18166 Mtetra
.661 .654 .832 r
.3976 .18166 .40733 .19867 .4241 .19144 .41439 .17459 Mtetra
.666 .659 .834 r
.41439 .17459 .4241 .19144 .44097 .18386 .43129 .16726 Mtetra
.67 .665 .836 r
.43129 .16726 .44097 .18386 .45793 .176 .4483 .15971 Mtetra
.674 .672 .84 r
.4483 .15971 .45793 .176 .47499 .16793 .46539 .152 Mtetra
.677 .68 .845 r
.46539 .152 .47499 .16793 .49214 .15973 .48259 .14418 Mtetra
.679 .687 .851 r
.48259 .14418 .49214 .15973 .50937 .15146 .49987 .1363 Mtetra
.68 .695 .857 r
.49987 .1363 .50937 .15146 .5267 .1432 .51725 .12841 Mtetra
.681 .702 .863 r
.51725 .12841 .5267 .1432 .54411 .135 .53473 .12055 Mtetra
.68 .709 .869 r
.53473 .12055 .54411 .135 .56161 .12688 .5523 .11275 Mtetra
.679 .715 .876 r
.5523 .11275 .56161 .12688 .57922 .11889 .56998 .10503 Mtetra
.678 .72 .881 r
.56998 .10503 .57922 .11889 .59692 .11103 .58776 .09739 Mtetra
.676 .725 .886 r
.58776 .09739 .59692 .11103 .61473 .10331 .60565 .08984 Mtetra
.674 .729 .891 r
.60565 .08984 .61473 .10331 .63264 .09571 .62364 .08237 Mtetra
.673 .732 .895 r
.62364 .08237 .63264 .09571 .65067 .08822 .64176 .07498 Mtetra
.671 .735 .898 r
.64176 .07498 .65067 .08822 .66882 .08083 .65999 .06764 Mtetra
.669 .737 .9 r
.65999 .06764 .66882 .08083 .68708 .07351 .67833 .06034 Mtetra
.668 .738 .903 r
.67833 .06034 .68708 .07351 .70546 .06624 .6968 .05306 Mtetra
.667 .739 .904 r
.6968 .05306 .70546 .06624 .72396 .05901 .71539 .0458 Mtetra
.659 .737 .908 r
.05899 .28172 .07013 .29225 .08481 .28685 .07372 .2762 Mtetra
.658 .736 .907 r
.07372 .2762 .08481 .28685 .09957 .28149 .08854 .2707 Mtetra
.656 .734 .907 r
.08854 .2707 .09957 .28149 .11441 .27618 .10343 .26523 Mtetra
.654 .731 .906 r
.10343 .26523 .11441 .27618 .12932 .27095 .11841 .2598 Mtetra
.652 .728 .905 r
.11841 .2598 .12932 .27095 .14432 .26579 .13347 .25442 Mtetra
.649 .724 .903 r
.13347 .25442 .14432 .26579 .15939 .26072 .14862 .2491 Mtetra
.647 .72 .901 r
.14862 .2491 .15939 .26072 .17455 .25575 .16384 .24383 Mtetra
.644 .714 .899 r
.16384 .24383 .17455 .25575 .18979 .25087 .17916 .23863 Mtetra
.641 .709 .896 r
.17916 .23863 .18979 .25087 .20512 .24608 .19456 .23347 Mtetra
.639 .702 .892 r
.19456 .23347 .20512 .24608 .22054 .24136 .21006 .22836 Mtetra
.637 .696 .888 r
.21006 .22836 .22054 .24136 .23606 .23667 .22565 .22326 Mtetra
.636 .689 .883 r
.22565 .22326 .23606 .23667 .25169 .23199 .24135 .21815 Mtetra
.636 .683 .877 r
.24135 .21815 .25169 .23199 .26742 .22725 .25716 .21299 Mtetra
.636 .677 .872 r
.25716 .21299 .26742 .22725 .28327 .22241 .27307 .20774 Mtetra
.638 .672 .867 r
.27307 .20774 .28327 .22241 .29924 .21741 .2891 .20237 Mtetra
.64 .669 .862 r
.2891 .20237 .29924 .21741 .31533 .2122 .30525 .19683 Mtetra
.643 .666 .857 r
.30525 .19683 .31533 .2122 .33154 .20673 .32151 .19109 Mtetra
.646 .664 .853 r
.32151 .19109 .33154 .20673 .34788 .20095 .33789 .18512 Mtetra
.65 .664 .85 r
.33789 .18512 .34788 .20095 .36433 .19485 .35439 .1789 Mtetra
.654 .665 .849 r
.35439 .1789 .36433 .19485 .38091 .18842 .371 .17243 Mtetra
.658 .667 .848 r
.371 .17243 .38091 .18842 .3976 .18166 .38773 .16571 Mtetra
.662 .671 .848 r
.38773 .16571 .3976 .18166 .41439 .17459 .40456 .15876 Mtetra
.666 .675 .849 r
.40456 .15876 .41439 .17459 .43129 .16726 .4215 .1516 Mtetra
.669 .68 .852 r
.4215 .1516 .43129 .16726 .4483 .15971 .43855 .14428 Mtetra
.672 .686 .855 r
.43855 .14428 .4483 .15971 .46539 .152 .45569 .13682 Mtetra
.674 .692 .859 r
.45569 .13682 .46539 .152 .48259 .14418 .47293 .12928 Mtetra
.675 .698 .863 r
.47293 .12928 .48259 .14418 .49987 .1363 .49027 .12168 Mtetra
.676 .704 .868 r
.49027 .12168 .49987 .1363 .51725 .12841 .50771 .11406 Mtetra
.676 .71 .873 r
.50771 .11406 .51725 .12841 .53473 .12055 .52525 .10645 Mtetra
.676 .715 .878 r
.52525 .10645 .53473 .12055 .5523 .11275 .5429 .09888 Mtetra
.675 .72 .883 r
.5429 .09888 .5523 .11275 .56998 .10503 .56064 .09134 Mtetra
.674 .725 .888 r
.56064 .09134 .56998 .10503 .58776 .09739 .5785 .08386 Mtetra
.673 .728 .892 r
.5785 .08386 .58776 .09739 .60565 .08984 .59647 .07643 Mtetra
.672 .732 .895 r
.59647 .07643 .60565 .08984 .62364 .08237 .61455 .06904 Mtetra
.67 .734 .898 r
.61455 .06904 .62364 .08237 .64176 .07498 .63274 .06169 Mtetra
.669 .736 .9 r
.63274 .06169 .64176 .07498 .65999 .06764 .65105 .05437 Mtetra
.668 .738 .902 r
.65105 .05437 .65999 .06764 .67833 .06034 .66948 .04707 Mtetra
.667 .739 .904 r
.66948 .04707 .67833 .06034 .6968 .05306 .68804 .03977 Mtetra
.666 .739 .905 r
.68804 .03977 .6968 .05306 .71539 .0458 .70671 .03247 Mtetra
.66 .738 .908 r
.04772 .2711 .05899 .28172 .07372 .2762 .06251 .26548 Mtetra
.659 .737 .907 r
.06251 .26548 .07372 .2762 .08854 .2707 .07738 .25986 Mtetra
.658 .736 .907 r
.07738 .25986 .08854 .2707 .10343 .26523 .09233 .25425 Mtetra
.657 .734 .906 r
.09233 .25425 .10343 .26523 .11841 .2598 .10737 .24866 Mtetra
.655 .731 .905 r
.10737 .24866 .11841 .2598 .13347 .25442 .12249 .24309 Mtetra
.653 .728 .904 r
.12249 .24309 .13347 .25442 .14862 .2491 .1377 .23755 Mtetra
.651 .725 .903 r
.1377 .23755 .14862 .2491 .16384 .24383 .153 .23205 Mtetra
.649 .721 .901 r
.153 .23205 .16384 .24383 .17916 .23863 .16838 .22658 Mtetra
.647 .717 .898 r
.16838 .22658 .17916 .23863 .19456 .23347 .18385 .22113 Mtetra
.646 .712 .896 r
.18385 .22113 .19456 .23347 .21006 .22836 .19942 .2157 Mtetra
.645 .707 .892 r
.19942 .2157 .21006 .22836 .22565 .22326 .21509 .21027 Mtetra
.644 .702 .888 r
.21509 .21027 .22565 .22326 .24135 .21815 .23086 .20481 Mtetra
.643 .697 .884 r
.23086 .20481 .24135 .21815 .25716 .21299 .24673 .19932 Mtetra
.644 .692 .88 r
.24673 .19932 .25716 .21299 .27307 .20774 .26271 .19374 Mtetra
.645 .688 .876 r
.26271 .19374 .27307 .20774 .2891 .20237 .2788 .18807 Mtetra
.646 .685 .872 r
.2788 .18807 .2891 .20237 .30525 .19683 .295 .18226 Mtetra
.648 .683 .869 r
.295 .18226 .30525 .19683 .32151 .19109 .31132 .1763 Mtetra
.651 .681 .866 r
.31132 .1763 .32151 .19109 .33789 .18512 .32775 .17017 Mtetra
.654 .681 .864 r
.32775 .17017 .33789 .18512 .35439 .1789 .3443 .16384 Mtetra
.657 .682 .862 r
.3443 .16384 .35439 .1789 .371 .17243 .36096 .15732 Mtetra
.66 .684 .862 r
.36096 .15732 .371 .17243 .38773 .16571 .37772 .15062 Mtetra
.663 .686 .862 r
.37772 .15062 .38773 .16571 .40456 .15876 .3946 .14374 Mtetra
.665 .689 .863 r
.3946 .14374 .40456 .15876 .4215 .1516 .41159 .13669 Mtetra
.668 .693 .865 r
.41159 .13669 .4215 .1516 .43855 .14428 .42868 .12952 Mtetra
.67 .698 .867 r
.42868 .12952 .43855 .14428 .45569 .13682 .44587 .12224 Mtetra
.671 .703 .87 r
.44587 .12224 .45569 .13682 .47293 .12928 .46317 .11489 Mtetra
.672 .708 .874 r
.46317 .11489 .47293 .12928 .49027 .12168 .48057 .10748 Mtetra
.673 .712 .878 r
.48057 .10748 .49027 .12168 .50771 .11406 .49807 .10005 Mtetra
.673 .717 .882 r
.49807 .10005 .50771 .11406 .52525 .10645 .51567 .09262 Mtetra
.673 .721 .886 r
.51567 .09262 .52525 .10645 .5429 .09888 .53339 .08519 Mtetra
.672 .725 .889 r
.53339 .08519 .5429 .09888 .56064 .09134 .55121 .07778 Mtetra
.671 .729 .893 r
.55121 .07778 .56064 .09134 .5785 .08386 .56914 .07039 Mtetra
.67 .731 .896 r
.56914 .07039 .5785 .08386 .59647 .07643 .58718 .06303 Mtetra
.669 .734 .898 r
.58718 .06303 .59647 .07643 .61455 .06904 .60534 .05568 Mtetra
.668 .736 .9 r
.60534 .05568 .61455 .06904 .63274 .06169 .62362 .04835 Mtetra
.667 .737 .902 r
.62362 .04835 .63274 .06169 .65105 .05437 .64202 .04103 Mtetra
.666 .738 .904 r
.64202 .04103 .65105 .05437 .66948 .04707 .66053 .0337 Mtetra
.666 .739 .905 r
.66053 .0337 .66948 .04707 .68804 .03977 .67917 .02636 Mtetra
.665 .74 .906 r
.67917 .02636 .68804 .03977 .70671 .03247 .69794 .019 Mtetra
.661 .739 .908 r
.03633 .2604 .04772 .2711 .06251 .26548 .05117 .25468 Mtetra
.661 .738 .907 r
.05117 .25468 .06251 .26548 .07738 .25986 .06609 .24895 Mtetra
.66 .737 .907 r
.06609 .24895 .07738 .25986 .09233 .25425 .0811 .24322 Mtetra
.659 .736 .907 r
.0811 .24322 .09233 .25425 .10737 .24866 .0962 .23749 Mtetra
.658 .734 .906 r
.0962 .23749 .10737 .24866 .12249 .24309 .11138 .23177 Mtetra
.656 .732 .905 r
.11138 .23177 .12249 .24309 .1377 .23755 .12665 .22605 Mtetra
.655 .729 .904 r
.12665 .22605 .1377 .23755 .153 .23205 .14201 .22035 Mtetra
.653 .726 .902 r
.14201 .22035 .153 .23205 .16838 .22658 .15746 .21466 Mtetra
.652 .723 .901 r
.15746 .21466 .16838 .22658 .18385 .22113 .173 .20898 Mtetra
.651 .719 .899 r
.173 .20898 .18385 .22113 .19942 .2157 .18864 .20329 Mtetra
.65 .716 .896 r
.18864 .20329 .19942 .2157 .21509 .21027 .20437 .19759 Mtetra
.649 .712 .893 r
.20437 .19759 .21509 .21027 .23086 .20481 .22021 .19187 Mtetra
.649 .708 .89 r
.22021 .19187 .23086 .20481 .24673 .19932 .23614 .1861 Mtetra
.649 .705 .887 r
.23614 .1861 .24673 .19932 .26271 .19374 .25219 .18027 Mtetra
.65 .702 .884 r
.25219 .18027 .26271 .19374 .2788 .18807 .26834 .17435 Mtetra
.651 .699 .881 r
.26834 .17435 .2788 .18807 .295 .18226 .2846 .16833 Mtetra
.653 .697 .879 r
.2846 .16833 .295 .18226 .31132 .1763 .30098 .16218 Mtetra
.654 .696 .876 r
.30098 .16218 .31132 .1763 .32775 .17017 .31746 .15591 Mtetra
.656 .696 .875 r
.31746 .15591 .32775 .17017 .3443 .16384 .33406 .14948 Mtetra
.659 .696 .874 r
.33406 .14948 .3443 .16384 .36096 .15732 .35076 .14291 Mtetra
.661 .697 .873 r
.35076 .14291 .36096 .15732 .37772 .15062 .36758 .1362 Mtetra
.663 .699 .873 r
.36758 .1362 .37772 .15062 .3946 .14374 .38451 .12934 Mtetra
.665 .702 .874 r
.38451 .12934 .3946 .14374 .41159 .13669 .40154 .12237 Mtetra
.667 .705 .876 r
.40154 .12237 .41159 .13669 .42868 .12952 .41869 .11529 Mtetra
.668 .708 .878 r
.41869 .11529 .42868 .12952 .44587 .12224 .43593 .10812 Mtetra
.669 .712 .88 r
.43593 .10812 .44587 .12224 .46317 .11489 .45329 .10089 Mtetra
.67 .716 .883 r
.45329 .10089 .46317 .11489 .48057 .10748 .47075 .09361 Mtetra
.67 .719 .886 r
.47075 .09361 .48057 .10748 .49807 .10005 .48831 .08629 Mtetra
.67 .723 .889 r
.48831 .08629 .49807 .10005 .51567 .09262 .50599 .07896 Mtetra
.67 .726 .892 r
.50599 .07896 .51567 .09262 .53339 .08519 .52377 .07162 Mtetra
.67 .729 .894 r
.52377 .07162 .53339 .08519 .55121 .07778 .54167 .06428 Mtetra
.669 .732 .897 r
.54167 .06428 .55121 .07778 .56914 .07039 .55967 .05695 Mtetra
.668 .734 .899 r
.55967 .05695 .56914 .07039 .58718 .06303 .5778 .04961 Mtetra
.668 .736 .901 r
.5778 .04961 .58718 .06303 .60534 .05568 .59604 .04227 Mtetra
.667 .737 .903 r
.59604 .04227 .60534 .05568 .62362 .04835 .61439 .03493 Mtetra
.666 .738 .904 r
.61439 .03493 .62362 .04835 .64202 .04103 .63287 .02757 Mtetra
.666 .739 .905 r
.63287 .02757 .64202 .04103 .66053 .0337 .65147 .0202 Mtetra
.665 .74 .906 r
.65147 .0202 .66053 .0337 .67917 .02636 .6702 .01281 Mtetra
.6702 .01281 .67917 .02636 .69794 .019 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.535 .771 .984 r
.39721 .59862 .40512 .60371 .41819 .60205 .41031 .59721 Mtetra
.516 .774 .99 r
.41031 .59721 .41819 .60205 .43134 .60053 .42349 .59598 Mtetra
.494 .776 .995 r
.42349 .59598 .43134 .60053 .44457 .59915 .43676 .59491 Mtetra
.47 .778 .997 r
.43676 .59491 .44457 .59915 .45787 .59789 .45011 .59397 Mtetra
.444 .778 .998 r
.45011 .59397 .45787 .59789 .47127 .59674 .46354 .59315 Mtetra
.417 .778 .995 r
.46354 .59315 .47127 .59674 .48475 .59566 .47707 .59243 Mtetra
.388 .776 .989 r
.47707 .59243 .48475 .59566 .49833 .59464 .4907 .59176 Mtetra
.359 .772 .98 r
.4907 .59176 .49833 .59464 .51199 .59362 .50442 .59111 Mtetra
.331 .768 .967 r
.50442 .59111 .51199 .59362 .52575 .59259 .51823 .59044 Mtetra
.305 .763 .951 r
.51823 .59044 .52575 .59259 .5396 .59149 .53215 .5897 Mtetra
.282 .758 .933 r
.53215 .5897 .5396 .59149 .55355 .59029 .54616 .58884 Mtetra
.264 .754 .914 r
.54616 .58884 .55355 .59029 .56758 .58893 .56027 .58781 Mtetra
.251 .752 .896 r
.56027 .58781 .56758 .58893 .58171 .58738 .57447 .58657 Mtetra
.245 .752 .879 r
.57447 .58657 .58171 .58738 .59593 .5856 .58877 .58506 Mtetra
.246 .755 .866 r
.58877 .58506 .59593 .5856 .61024 .58353 .60315 .58323 Mtetra
.253 .763 .855 r
.60315 .58323 .61024 .58353 .62462 .58114 .61762 .58105 Mtetra
.268 .773 .849 r
.61762 .58105 .62462 .58114 .63909 .57841 .63217 .57847 Mtetra
.289 .788 .848 r
.63217 .57847 .63909 .57841 .65362 .57528 .6468 .57546 Mtetra
.316 .805 .85 r
.6468 .57546 .65362 .57528 .66823 .57176 .66149 .57199 Mtetra
.348 .825 .856 r
.66149 .57199 .66823 .57176 .6829 .56781 .67625 .56805 Mtetra
.384 .846 .866 r
.67625 .56805 .6829 .56781 .69763 .56344 .69107 .56363 Mtetra
.424 .868 .877 r
.69107 .56363 .69763 .56344 .71241 .55863 .70594 .55872 Mtetra
.464 .889 .89 r
.70594 .55872 .71241 .55863 .72724 .55341 .72086 .55334 Mtetra
.505 .908 .904 r
.72086 .55334 .72724 .55341 .74212 .54778 .73582 .54751 Mtetra
.545 .925 .917 r
.73582 .54751 .74212 .54778 .75704 .54177 .75082 .54124 Mtetra
.582 .938 .928 r
.75082 .54124 .75704 .54177 .772 .53539 .76585 .53457 Mtetra
.616 .947 .938 r
.76585 .53457 .772 .53539 .787 .5287 .78092 .52755 Mtetra
.646 .952 .946 r
.78092 .52755 .787 .5287 .80203 .52173 .79603 .5202 Mtetra
.671 .953 .952 r
.79603 .5202 .80203 .52173 .8171 .51451 .81117 .51259 Mtetra
.692 .95 .955 r
.81117 .51259 .8171 .51451 .83222 .50709 .82634 .50476 Mtetra
.709 .945 .957 r
.82634 .50476 .83222 .50709 .84737 .49952 .84155 .49675 Mtetra
.721 .937 .957 r
.84155 .49675 .84737 .49952 .86257 .49184 .8568 .48863 Mtetra
.73 .928 .956 r
.8568 .48863 .86257 .49184 .87782 .48409 .8721 .48043 Mtetra
.736 .917 .954 r
.8721 .48043 .87782 .48409 .89312 .47632 .88744 .47221 Mtetra
.739 .905 .952 r
.88744 .47221 .89312 .47632 .90847 .46855 .90284 .464 Mtetra
.74 .893 .949 r
.90284 .464 .90847 .46855 .92389 .46083 .9183 .45585 Mtetra
.739 .88 .945 r
.9183 .45585 .92389 .46083 .93938 .45318 .93383 .44778 Mtetra
.737 .868 .942 r
.93383 .44778 .93938 .45318 .95494 .44562 .94942 .43982 Mtetra
.734 .856 .938 r
.94942 .43982 .95494 .44562 .97057 .43818 .9651 .432 Mtetra
.512 .768 .989 r
.3892 .59362 .39721 .59862 .41031 .59721 .40234 .5925 Mtetra
.489 .769 .994 r
.40234 .5925 .41031 .59721 .42349 .59598 .41556 .59157 Mtetra
.462 .77 .996 r
.41556 .59157 .42349 .59598 .43676 .59491 .42886 .59082 Mtetra
.432 .769 .997 r
.42886 .59082 .43676 .59491 .45011 .59397 .44224 .59023 Mtetra
.4 .766 .994 r
.44224 .59023 .45011 .59397 .46354 .59315 .45573 .58978 Mtetra
.366 .761 .986 r
.45573 .58978 .46354 .59315 .47707 .59243 .4693 .58943 Mtetra
.331 .755 .975 r
.4693 .58943 .47707 .59243 .4907 .59176 .48297 .58915 Mtetra
.296 .747 .958 r
.48297 .58915 .4907 .59176 .50442 .59111 .49674 .5889 Mtetra
.262 .737 .938 r
.49674 .5889 .50442 .59111 .51823 .59044 .51062 .58861 Mtetra
.232 .727 .915 r
.51062 .58861 .51823 .59044 .53215 .5897 .52459 .58826 Mtetra
.206 .717 .89 r
.52459 .58826 .53215 .5897 .54616 .58884 .53867 .58777 Mtetra
.185 .709 .865 r
.53867 .58777 .54616 .58884 .56027 .58781 .55285 .5871 Mtetra
.172 .704 .842 r
.55285 .5871 .56027 .58781 .57447 .58657 .56713 .58619 Mtetra
.166 .703 .822 r
.56713 .58619 .57447 .58657 .58877 .58506 .58151 .58498 Mtetra
.169 .706 .806 r
.58151 .58498 .58877 .58506 .60315 .58323 .59598 .58342 Mtetra
.179 .714 .795 r
.59598 .58342 .60315 .58323 .61762 .58105 .61053 .58145 Mtetra
.197 .727 .789 r
.61053 .58145 .61762 .58105 .63217 .57847 .62517 .57904 Mtetra
.222 .744 .789 r
.62517 .57904 .63217 .57847 .6468 .57546 .63989 .57615 Mtetra
.254 .765 .794 r
.63989 .57615 .6468 .57546 .66149 .57199 .65468 .57275 Mtetra
.292 .79 .804 r
.65468 .57275 .66149 .57199 .67625 .56805 .66953 .56881 Mtetra
.334 .817 .817 r
.66953 .56881 .67625 .56805 .69107 .56363 .68444 .56434 Mtetra
.38 .844 .834 r
.68444 .56434 .69107 .56363 .70594 .55872 .6994 .55933 Mtetra
.428 .871 .852 r
.6994 .55933 .70594 .55872 .72086 .55334 .71441 .55378 Mtetra
.476 .896 .87 r
.71441 .55378 .72086 .55334 .73582 .54751 .72946 .54773 Mtetra
.522 .918 .888 r
.72946 .54773 .73582 .54751 .75082 .54124 .74454 .54119 Mtetra
.566 .936 .905 r
.74454 .54119 .75082 .54124 .76585 .53457 .75965 .53421 Mtetra
.605 .949 .919 r
.75965 .53421 .76585 .53457 .78092 .52755 .7748 .52682 Mtetra
.64 .957 .93 r
.7748 .52682 .78092 .52755 .79603 .5202 .78997 .51908 Mtetra
.67 .96 .939 r
.78997 .51908 .79603 .5202 .81117 .51259 .80518 .51105 Mtetra
.694 .96 .945 r
.80518 .51105 .81117 .51259 .82634 .50476 .82041 .50277 Mtetra
.713 .956 .949 r
.82041 .50277 .82634 .50476 .84155 .49675 .83568 .4943 Mtetra
.727 .948 .951 r
.83568 .4943 .84155 .49675 .8568 .48863 .85099 .4857 Mtetra
.738 .939 .951 r
.85099 .4857 .8568 .48863 .8721 .48043 .86633 .47703 Mtetra
.744 .928 .95 r
.86633 .47703 .8721 .48043 .88744 .47221 .88173 .46833 Mtetra
.748 .916 .949 r
.88173 .46833 .88744 .47221 .90284 .464 .89717 .45965 Mtetra
.749 .903 .946 r
.89717 .45965 .90284 .464 .9183 .45585 .91267 .45104 Mtetra
.748 .89 .943 r
.91267 .45104 .9183 .45585 .93383 .44778 .92824 .44252 Mtetra
.745 .877 .94 r
.92824 .44252 .93383 .44778 .94942 .43982 .94387 .43414 Mtetra
.742 .864 .937 r
.94387 .43414 .94942 .43982 .9651 .432 .95958 .42591 Mtetra
.487 .763 .992 r
.38111 .58871 .3892 .59362 .40234 .5925 .39428 .58788 Mtetra
.458 .762 .995 r
.39428 .58788 .40234 .5925 .41556 .59157 .40753 .58728 Mtetra
.426 .76 .996 r
.40753 .58728 .41556 .59157 .42886 .59082 .42086 .58688 Mtetra
.39 .755 .992 r
.42086 .58688 .42886 .59082 .44224 .59023 .43429 .58667 Mtetra
.351 .749 .985 r
.43429 .58667 .44224 .59023 .45573 .58978 .44781 .5866 Mtetra
.31 .739 .971 r
.44781 .5866 .45573 .58978 .4693 .58943 .46143 .58666 Mtetra
.268 .727 .953 r
.46143 .58666 .4693 .58943 .48297 .58915 .47515 .58679 Mtetra
.227 .713 .929 r
.47515 .58679 .48297 .58915 .49674 .5889 .48897 .58696 Mtetra
.189 .697 .9 r
.48897 .58696 .49674 .5889 .51062 .58861 .50291 .58709 Mtetra
.154 .682 .87 r
.50291 .58709 .51062 .58861 .52459 .58826 .51694 .58715 Mtetra
.126 .668 .838 r
.51694 .58715 .52459 .58826 .53867 .58777 .53109 .58707 Mtetra
.105 .657 .808 r
.53109 .58707 .53867 .58777 .55285 .5871 .54534 .58678 Mtetra
.093 .65 .781 r
.54534 .58678 .55285 .5871 .56713 .58619 .5597 .58622 Mtetra
.089 .648 .758 r
.5597 .58622 .56713 .58619 .58151 .58498 .57415 .58533 Mtetra
.094 .651 .741 r
.57415 .58533 .58151 .58498 .59598 .58342 .58871 .58404 Mtetra
.107 .661 .731 r
.58871 .58404 .59598 .58342 .61053 .58145 .60335 .58231 Mtetra
.129 .676 .726 r
.60335 .58231 .61053 .58145 .62517 .57904 .61809 .58009 Mtetra
.159 .697 .728 r
.61809 .58009 .62517 .57904 .63989 .57615 .6329 .57733 Mtetra
.195 .723 .737 r
.6329 .57733 .63989 .57615 .65468 .57275 .64778 .57399 Mtetra
.239 .752 .75 r
.64778 .57399 .65468 .57275 .66953 .56881 .66273 .57007 Mtetra
.287 .784 .768 r
.66273 .57007 .66953 .56881 .68444 .56434 .67773 .56554 Mtetra
.339 .818 .789 r
.67773 .56554 .68444 .56434 .6994 .55933 .69279 .56041 Mtetra
.394 .851 .813 r
.69279 .56041 .6994 .55933 .71441 .55378 .70789 .55469 Mtetra
.448 .882 .836 r
.70789 .55469 .71441 .55378 .72946 .54773 .72302 .5484 Mtetra
.501 .909 .859 r
.72302 .5484 .72946 .54773 .74454 .54119 .73819 .54158 Mtetra
.551 .931 .88 r
.73819 .54158 .74454 .54119 .75965 .53421 .75339 .53426 Mtetra
.596 .949 .898 r
.75339 .53426 .75965 .53421 .7748 .52682 .76861 .52649 Mtetra
.636 .96 .913 r
.76861 .52649 .7748 .52682 .78997 .51908 .78386 .51833 Mtetra
.67 .966 .925 r
.78386 .51833 .78997 .51908 .80518 .51105 .79914 .50985 Mtetra
.697 .967 .934 r
.79914 .50985 .80518 .51105 .82041 .50277 .81444 .50109 Mtetra
.719 .964 .94 r
.81444 .50109 .82041 .50277 .83568 .4943 .82976 .49214 Mtetra
.735 .958 .943 r
.82976 .49214 .83568 .4943 .85099 .4857 .84512 .48304 Mtetra
.746 .949 .945 r
.84512 .48304 .85099 .4857 .86633 .47703 .86052 .47386 Mtetra
.753 .937 .945 r
.86052 .47386 .86633 .47703 .88173 .46833 .87596 .46465 Mtetra
.757 .925 .944 r
.87596 .46465 .88173 .46833 .89717 .45965 .89145 .45548 Mtetra
.758 .912 .943 r
.89145 .45548 .89717 .45965 .91267 .45104 .90699 .44637 Mtetra
.757 .898 .94 r
.90699 .44637 .91267 .45104 .92824 .44252 .9226 .43739 Mtetra
.755 .885 .938 r
.9226 .43739 .92824 .44252 .94387 .43414 .93827 .42856 Mtetra
.751 .871 .935 r
.93827 .42856 .94387 .43414 .95958 .42591 .95402 .4199 Mtetra
.458 .756 .994 r
.37293 .58386 .38111 .58871 .39428 .58788 .38612 .58336 Mtetra
.424 .752 .995 r
.38612 .58336 .39428 .58788 .40753 .58728 .3994 .5831 Mtetra
.386 .746 .992 r
.3994 .5831 .40753 .58728 .42086 .58688 .41277 .58307 Mtetra
.343 .738 .984 r
.41277 .58307 .42086 .58688 .43429 .58667 .42623 .58325 Mtetra
.297 .726 .97 r
.42623 .58325 .43429 .58667 .44781 .5866 .43979 .5836 Mtetra
.249 .71 .95 r
.43979 .5836 .44781 .5866 .46143 .58666 .45345 .58408 Mtetra
.201 .692 .923 r
.45345 .58408 .46143 .58666 .47515 .58679 .46722 .58465 Mtetra
.155 .671 .891 r
.46722 .58465 .47515 .58679 .48897 .58696 .4811 .58526 Mtetra
.113 .65 .855 r
.4811 .58526 .48897 .58696 .50291 .58709 .49509 .58584 Mtetra
.077 .63 .818 r
.49509 .58584 .50291 .58709 .51694 .58715 .50919 .58633 Mtetra
.048 .613 .781 r
.50919 .58633 .51694 .58715 .53109 .58707 .5234 .58667 Mtetra
.028 .599 .747 r
.5234 .58667 .53109 .58707 .54534 .58678 .53772 .58679 Mtetra
.018 .592 .718 r
.53772 .58679 .54534 .58678 .5597 .58622 .55216 .5866 Mtetra
0 0 0 r
.55216 .5866 .5597 .58622 .57415 .58533 .5667 .58605 Mtetra
.5667 .58605 .57415 .58533 .58871 .58404 .58134 .58507 Mtetra
.58134 .58507 .58871 .58404 .60335 .58231 .59607 .58359 Mtetra
.59607 .58359 .60335 .58231 .61809 .58009 .6109 .58156 Mtetra
.6109 .58156 .61809 .58009 .6329 .57733 .62581 .57893 Mtetra
.62581 .57893 .6329 .57733 .64778 .57399 .64079 .57568 Mtetra
.192 .716 .7 r
.64079 .57568 .64778 .57399 .66273 .57007 .65583 .57176 Mtetra
.246 .753 .723 r
.65583 .57176 .66273 .57007 .67773 .56554 .67094 .56718 Mtetra
.304 .792 .748 r
.67094 .56718 .67773 .56554 .69279 .56041 .68609 .56193 Mtetra
.365 .831 .776 r
.68609 .56193 .69279 .56041 .70789 .55469 .70129 .55602 Mtetra
.426 .868 .804 r
.70129 .55602 .70789 .55469 .72302 .5484 .71652 .54948 Mtetra
.485 .9 .832 r
.71652 .54948 .72302 .5484 .73819 .54158 .73177 .54235 Mtetra
.541 .927 .857 r
.73177 .54235 .73819 .54158 .75339 .53426 .74706 .53468 Mtetra
.591 .948 .879 r
.74706 .53468 .75339 .53426 .76861 .52649 .76236 .52651 Mtetra
.635 .963 .897 r
.76236 .52651 .76861 .52649 .78386 .51833 .77769 .51791 Mtetra
.672 .971 .911 r
.77769 .51791 .78386 .51833 .79914 .50985 .79303 .50895 Mtetra
.702 .974 .922 r
.79303 .50895 .79914 .50985 .81444 .50109 .8084 .49969 Mtetra
.726 .972 .93 r
.8084 .49969 .81444 .50109 .82976 .49214 .82379 .49022 Mtetra
.743 .966 .935 r
.82379 .49022 .82976 .49214 .84512 .48304 .8392 .48059 Mtetra
.755 .957 .938 r
.8392 .48059 .84512 .48304 .86052 .47386 .85465 .47087 Mtetra
.763 .946 .939 r
.85465 .47087 .86052 .47386 .87596 .46465 .87014 .46114 Mtetra
.767 .933 .939 r
.87014 .46114 .87596 .46465 .89145 .45548 .88568 .45144 Mtetra
.768 .92 .938 r
.88568 .45144 .89145 .45548 .90699 .44637 .90126 .44183 Mtetra
.767 .906 .936 r
.90126 .44183 .90699 .44637 .9226 .43739 .91691 .43235 Mtetra
.764 .892 .934 r
.91691 .43235 .9226 .43739 .93827 .42856 .93262 .42305 Mtetra
.759 .878 .932 r
.93262 .42305 .93827 .42856 .95402 .4199 .94841 .41394 Mtetra
.428 .746 .993 r
.36465 .57906 .37293 .58386 .38612 .58336 .37787 .57889 Mtetra
.388 .739 .992 r
.37787 .57889 .38612 .58336 .3994 .5831 .39118 .57899 Mtetra
.342 .729 .985 r
.39118 .57899 .3994 .5831 .41277 .58307 .40458 .57935 Mtetra
.293 .715 .972 r
.40458 .57935 .41277 .58307 .42623 .58325 .41808 .57994 Mtetra
.24 .698 .951 r
.41808 .57994 .42623 .58325 .43979 .5836 .43167 .58072 Mtetra
.186 .676 .923 r
.43167 .58072 .43979 .5836 .45345 .58408 .44538 .58165 Mtetra
.133 .651 .889 r
.44538 .58165 .45345 .58408 .46722 .58465 .45919 .58269 Mtetra
.083 .625 .849 r
.45919 .58269 .46722 .58465 .4811 .58526 .47312 .58376 Mtetra
.039 .599 .806 r
.47312 .58376 .4811 .58526 .49509 .58584 .48716 .58481 Mtetra
.003 .575 .763 r
.48716 .58481 .49509 .58584 .50919 .58633 .50132 .58576 Mtetra
0 .556 .723 r
.50132 .58576 .50919 .58633 .5234 .58667 .5156 .58655 Mtetra
.042 0 0 r
.5156 .58655 .5234 .58667 .53772 .58679 .53 .58708 Mtetra
.05 0 0 r
.53 .58708 .53772 .58679 .55216 .5866 .54451 .58729 Mtetra
.048 0 0 r
.54451 .58729 .55216 .5866 .5667 .58605 .55913 .5871 Mtetra
.036 0 0 r
.55913 .5871 .5667 .58605 .58134 .58507 .57386 .58643 Mtetra
.015 0 0 r
.57386 .58643 .58134 .58507 .59607 .58359 .58869 .58521 Mtetra
0 0 0 r
.58869 .58521 .59607 .58359 .6109 .58156 .60361 .58339 Mtetra
.60361 .58339 .6109 .58156 .62581 .57893 .61862 .58091 Mtetra
.61862 .58091 .62581 .57893 .64079 .57568 .6337 .57773 Mtetra
.6337 .57773 .64079 .57568 .65583 .57176 .64885 .57382 Mtetra
.214 .727 .685 r
.64885 .57382 .65583 .57176 .67094 .56718 .66405 .56918 Mtetra
.278 .771 .714 r
.66405 .56918 .67094 .56718 .68609 .56193 .6793 .5638 Mtetra
.344 .815 .746 r
.6793 .5638 .68609 .56193 .70129 .55602 .6946 .5577 Mtetra
.411 .857 .779 r
.6946 .5577 .70129 .55602 .71652 .54948 .70992 .5509 Mtetra
.476 .893 .809 r
.70992 .5509 .71652 .54948 .73177 .54235 .72527 .54345 Mtetra
.536 .924 .838 r
.72527 .54345 .73177 .54235 .74706 .53468 .74065 .5354 Mtetra
.591 .948 .862 r
.74065 .5354 .74706 .53468 .76236 .52651 .75604 .52681 Mtetra
.638 .965 .883 r
.75604 .52681 .76236 .52651 .77769 .51791 .77144 .51775 Mtetra
.678 .975 .899 r
.77144 .51775 .77769 .51791 .79303 .50895 .78686 .50829 Mtetra
.71 .979 .911 r
.78686 .50829 .79303 .50895 .8084 .49969 .80229 .49851 Mtetra
.735 .977 .92 r
.80229 .49851 .8084 .49969 .82379 .49022 .81775 .48849 Mtetra
.753 .972 .926 r
.81775 .48849 .82379 .49022 .8392 .48059 .83322 .47831 Mtetra
.766 .963 .93 r
.83322 .47831 .8392 .48059 .85465 .47087 .84873 .46804 Mtetra
.774 .952 .932 r
.84873 .46804 .85465 .47087 .87014 .46114 .86426 .45775 Mtetra
.778 .94 .933 r
.86426 .45775 .87014 .46114 .88568 .45144 .87984 .44751 Mtetra
.779 .926 .932 r
.87984 .44751 .88568 .45144 .90126 .44183 .89547 .43737 Mtetra
.777 .912 .932 r
.89547 .43737 .90126 .44183 .91691 .43235 .91116 .42738 Mtetra
.774 .898 .93 r
.91116 .42738 .91691 .43235 .93262 .42305 .92691 .41758 Mtetra
.769 .884 .928 r
.92691 .41758 .93262 .42305 .94841 .41394 .94274 .40801 Mtetra
.395 .734 .991 r
.35628 .57428 .36465 .57906 .37787 .57889 .36953 .57446 Mtetra
.349 .723 .986 r
.36953 .57446 .37787 .57889 .39118 .57899 .38286 .57494 Mtetra
.297 .708 .974 r
.38286 .57494 .39118 .57899 .40458 .57935 .39629 .5757 Mtetra
.241 .689 .955 r
.39629 .5757 .40458 .57935 .41808 .57994 .40982 .57672 Mtetra
.182 .665 .928 r
.40982 .57672 .41808 .57994 .43167 .58072 .42345 .57794 Mtetra
.123 .637 .892 r
.42345 .57794 .43167 .58072 .44538 .58165 .4372 .57934 Mtetra
.066 .607 .85 r
.4372 .57934 .44538 .58165 .45919 .58269 .45105 .58085 Mtetra
.014 .576 .804 r
.45105 .58085 .45919 .58269 .47312 .58376 .46503 .5824 Mtetra
0 .547 .757 r
.46503 .5824 .47312 .58376 .48716 .58481 .47913 .58394 Mtetra
0 .521 .711 r
.47913 .58394 .48716 .58481 .50132 .58576 .49335 .58537 Mtetra
.09 0 0 r
.49335 .58537 .50132 .58576 .5156 .58655 .50769 .58662 Mtetra
.104 0 0 r
.50769 .58662 .5156 .58655 .53 .58708 .52216 .58759 Mtetra
.109 0 0 r
.52216 .58759 .53 .58708 .54451 .58729 .53675 .58821 Mtetra
.103 0 0 r
.53675 .58821 .54451 .58729 .55913 .5871 .55145 .58839 Mtetra
.087 0 0 r
.55145 .58839 .55913 .5871 .57386 .58643 .56627 .58805 Mtetra
.062 0 0 r
.56627 .58805 .57386 .58643 .58869 .58521 .58119 .5871 Mtetra
.027 0 0 r
.58119 .5871 .58869 .58521 .60361 .58339 .59621 .58549 Mtetra
0 0 0 r
.59621 .58549 .60361 .58339 .61862 .58091 .61132 .58316 Mtetra
.61132 .58316 .61862 .58091 .6337 .57773 .6265 .58006 Mtetra
.6265 .58006 .6337 .57773 .64885 .57382 .64175 .57617 Mtetra
.64175 .57617 .64885 .57382 .66405 .56918 .65706 .57147 Mtetra
.261 .757 .691 r
.65706 .57147 .66405 .56918 .6793 .5638 .67242 .56595 Mtetra
.333 .805 .726 r
.67242 .56595 .6793 .5638 .6946 .5577 .68781 .55965 Mtetra
.405 .851 .761 r
.68781 .55965 .6946 .5577 .70992 .5509 .70324 .55258 Mtetra
.474 .891 .794 r
.70324 .55258 .70992 .5509 .72527 .54345 .71869 .5448 Mtetra
.539 .924 .824 r
.71869 .5448 .72527 .54345 .74065 .5354 .73415 .53635 Mtetra
.596 .95 .85 r
.73415 .53635 .74065 .5354 .75604 .52681 .74962 .52732 Mtetra
.646 .968 .872 r
.74962 .52732 .75604 .52681 .77144 .51775 .76511 .51778 Mtetra
.687 .979 .889 r
.76511 .51778 .77144 .51775 .78686 .50829 .78061 .5078 Mtetra
.72 .983 .902 r
.78061 .5078 .78686 .50829 .80229 .49851 .79611 .49748 Mtetra
.746 .982 .911 r
.79611 .49748 .80229 .49851 .81775 .48849 .81163 .4869 Mtetra
.764 .976 .918 r
.81163 .4869 .81775 .48849 .83322 .47831 .82717 .47615 Mtetra
.777 .968 .922 r
.82717 .47615 .83322 .47831 .84873 .46804 .84273 .4653 Mtetra
.785 .957 .925 r
.84273 .4653 .84873 .46804 .86426 .45775 .85832 .45444 Mtetra
.789 .944 .926 r
.85832 .45444 .86426 .45775 .87984 .44751 .87395 .44364 Mtetra
.789 .93 .926 r
.87395 .44364 .87984 .44751 .89547 .43737 .88962 .43295 Mtetra
.787 .916 .926 r
.88962 .43295 .89547 .43737 .91116 .42738 .90535 .42243 Mtetra
.783 .902 .925 r
.90535 .42243 .91116 .42738 .92691 .41758 .92114 .41213 Mtetra
.778 .888 .924 r
.92114 .41213 .92691 .41758 .94274 .40801 .93701 .40208 Mtetra
.361 .719 .987 r
.34781 .5695 .35628 .57428 .36953 .57446 .36108 .57003 Mtetra
.309 .704 .978 r
.36108 .57003 .36953 .57446 .38286 .57494 .37444 .5709 Mtetra
.251 .685 .961 r
.37444 .5709 .38286 .57494 .39629 .5757 .3879 .57207 Mtetra
.189 .66 .936 r
.3879 .57207 .39629 .5757 .40982 .57672 .40146 .57352 Mtetra
.125 .63 .902 r
.40146 .57352 .40982 .57672 .42345 .57794 .41512 .57521 Mtetra
.062 .596 .86 r
.41512 .57521 .42345 .57794 .4372 .57934 .42891 .57708 Mtetra
.003 .561 .812 r
.42891 .57708 .4372 .57934 .45105 .58085 .44281 .57908 Mtetra
0 .527 .761 r
.44281 .57908 .45105 .58085 .46503 .5824 .45683 .58113 Mtetra
0 .496 .711 r
.45683 .58113 .46503 .5824 .47913 .58394 .47098 .58316 Mtetra
.124 0 0 r
.47098 .58316 .47913 .58394 .49335 .58537 .48526 .58508 Mtetra
.146 0 0 r
.48526 .58508 .49335 .58537 .50769 .58662 .49967 .58681 Mtetra
.157 0 0 r
.49967 .58681 .50769 .58662 .52216 .58759 .51421 .58824 Mtetra
.51421 .58824 .52216 .58759 .53675 .58821 .52887 .58928 Mtetra
.147 0 0 r
.52887 .58928 .53675 .58821 .55145 .58839 .54366 .58984 Mtetra
.128 0 0 r
.54366 .58984 .55145 .58839 .56627 .58805 .55856 .58983 Mtetra
.098 0 0 r
.55856 .58983 .56627 .58805 .58119 .5871 .57358 .58917 Mtetra
.059 0 0 r
.57358 .58917 .58119 .5871 .59621 .58549 .58869 .58778 Mtetra
.011 0 0 r
.58869 .58778 .59621 .58549 .61132 .58316 .6039 .5856 Mtetra
0 0 0 r
.6039 .5856 .61132 .58316 .6265 .58006 .61919 .58258 Mtetra
.61919 .58258 .6265 .58006 .64175 .57617 .63455 .5787 Mtetra
.63455 .5787 .64175 .57617 .65706 .57147 .64996 .57393 Mtetra
.256 .751 .679 r
.64996 .57393 .65706 .57147 .67242 .56595 .66543 .56827 Mtetra
.333 .804 .717 r
.66543 .56827 .67242 .56595 .68781 .55965 .68092 .56176 Mtetra
.41 .852 .754 r
.68092 .56176 .68781 .55965 .70324 .55258 .69645 .55441 Mtetra
.483 .894 .788 r
.69645 .55441 .70324 .55258 .71869 .5448 .712 .54628 Mtetra
.55 .929 .819 r
.712 .54628 .71869 .5448 .73415 .53635 .72755 .53744 Mtetra
.609 .955 .845 r
.72755 .53744 .73415 .53635 .74962 .52732 .74312 .52795 Mtetra
.66 .973 .866 r
.74312 .52795 .74962 .52732 .76511 .51778 .75869 .51791 Mtetra
.701 .983 .882 r
.75869 .51791 .76511 .51778 .78061 .5078 .77426 .50741 Mtetra
.734 .987 .895 r
.77426 .50741 .78061 .5078 .79611 .49748 .78984 .49653 Mtetra
.759 .985 .904 r
.78984 .49653 .79611 .49748 .81163 .4869 .80543 .48537 Mtetra
.777 .979 .91 r
.80543 .48537 .81163 .4869 .82717 .47615 .82103 .47403 Mtetra
.79 .97 .914 r
.82103 .47403 .82717 .47615 .84273 .4653 .83665 .46259 Mtetra
.797 .959 .917 r
.83665 .46259 .84273 .4653 .85832 .45444 .85229 .45115 Mtetra
.8 .947 .919 r
.85229 .45115 .85832 .45444 .87395 .44364 .86797 .43977 Mtetra
.8 .933 .92 r
.86797 .43977 .87395 .44364 .88962 .43295 .88369 .42852 Mtetra
.797 .919 .92 r
.88369 .42852 .88962 .43295 .90535 .42243 .89947 .41746 Mtetra
.793 .905 .92 r
.89947 .41746 .90535 .42243 .92114 .41213 .9153 .40664 Mtetra
.787 .891 .919 r
.9153 .40664 .92114 .41213 .93701 .40208 .93121 .3961 Mtetra
.327 .703 .982 r
.33925 .56468 .34781 .5695 .36108 .57003 .35254 .56557 Mtetra
.269 .683 .968 r
.35254 .56557 .36108 .57003 .37444 .5709 .36593 .56683 Mtetra
.206 .659 .946 r
.36593 .56683 .37444 .5709 .3879 .57207 .37941 .56842 Mtetra
.139 .628 .915 r
.37941 .56842 .3879 .57207 .40146 .57352 .39299 .57031 Mtetra
.071 .593 .875 r
.39299 .57031 .40146 .57352 .41512 .57521 .40669 .57247 Mtetra
.006 .556 .828 r
.40669 .57247 .41512 .57521 .42891 .57708 .42051 .57482 Mtetra
0 .518 .776 r
.42051 .57482 .42891 .57708 .44281 .57908 .43445 .57732 Mtetra
0 .482 .722 r
.43445 .57732 .44281 .57908 .45683 .58113 .44851 .57988 Mtetra
.144 0 0 r
.44851 .57988 .45683 .58113 .47098 .58316 .46272 .58241 Mtetra
.174 0 0 r
.46272 .58241 .47098 .58316 .48526 .58508 .47705 .58483 Mtetra
.192 0 0 r
.47705 .58483 .48526 .58508 .49967 .58681 .49152 .58703 Mtetra
.199 0 0 r
.49152 .58703 .49967 .58681 .51421 .58824 .50613 .58892 Mtetra
.196 0 0 r
.50613 .58892 .51421 .58824 .52887 .58928 .52087 .59039 Mtetra
.182 0 0 r
.52087 .59039 .52887 .58928 .54366 .58984 .53574 .59134 Mtetra
.158 0 0 r
.53574 .59134 .54366 .58984 .55856 .58983 .55073 .59167 Mtetra
.124 0 0 r
.55073 .59167 .55856 .58983 .57358 .58917 .56584 .59129 Mtetra
.081 0 0 r
.56584 .59129 .57358 .58917 .58869 .58778 .58106 .59012 Mtetra
.028 0 0 r
.58106 .59012 .58869 .58778 .6039 .5856 .59637 .5881 Mtetra
0 0 0 r
.59637 .5881 .6039 .5856 .61919 .58258 .61176 .58516 Mtetra
.61176 .58516 .61919 .58258 .63455 .5787 .62722 .58129 Mtetra
.62722 .58129 .63455 .5787 .64996 .57393 .64275 .57645 Mtetra
.262 .756 .68 r
.64275 .57645 .64996 .57393 .66543 .56827 .65832 .57065 Mtetra
.345 .811 .72 r
.65832 .57065 .66543 .56827 .68092 .56176 .67392 .56392 Mtetra
.425 .861 .757 r
.67392 .56392 .68092 .56176 .69645 .55441 .68955 .55628 Mtetra
.501 .903 .792 r
.68955 .55628 .69645 .55441 .712 .54628 .7052 .5478 Mtetra
.569 .937 .821 r
.7052 .5478 .712 .54628 .72755 .53744 .72085 .53855 Mtetra
.629 .962 .845 r
.72085 .53855 .72755 .53744 .74312 .52795 .73651 .5286 Mtetra
.679 .978 .864 r
.73651 .5286 .74312 .52795 .75869 .51791 .75217 .51805 Mtetra
.719 .987 .879 r
.75217 .51805 .75869 .51791 .77426 .50741 .76782 .50701 Mtetra
.751 .989 .89 r
.76782 .50701 .77426 .50741 .78984 .49653 .78348 .49556 Mtetra
.775 .987 .898 r
.78348 .49556 .78984 .49653 .80543 .48537 .79914 .48382 Mtetra
.791 .98 .903 r
.79914 .48382 .80543 .48537 .82103 .47403 .81481 .47188 Mtetra
.802 .971 .907 r
.81481 .47188 .82103 .47403 .83665 .46259 .83049 .45984 Mtetra
.809 .96 .91 r
.83049 .45984 .83665 .46259 .85229 .45115 .84619 .4478 Mtetra
.811 .947 .912 r
.84619 .4478 .85229 .45115 .86797 .43977 .86192 .43584 Mtetra
.81 .934 .913 r
.86192 .43584 .86797 .43977 .88369 .42852 .87769 .42402 Mtetra
.807 .92 .913 r
.87769 .42402 .88369 .42852 .89947 .41746 .89351 .41242 Mtetra
.802 .906 .913 r
.89351 .41242 .89947 .41746 .9153 .40664 .90939 .40108 Mtetra
.795 .892 .913 r
.90939 .40108 .9153 .40664 .93121 .3961 .92534 .39004 Mtetra
.294 .685 .975 r
.3306 .55979 .33925 .56468 .35254 .56557 .34391 .56104 Mtetra
.231 .661 .957 r
.34391 .56104 .35254 .56557 .36593 .56683 .35731 .56269 Mtetra
.163 .632 .931 r
.35731 .56269 .36593 .56683 .37941 .56842 .37081 .5647 Mtetra
.092 .597 .895 r
.37081 .5647 .37941 .56842 .39299 .57031 .38443 .56703 Mtetra
.022 .558 .85 r
.38443 .56703 .39299 .57031 .40669 .57247 .39815 .56965 Mtetra
0 .517 .799 r
.39815 .56965 .40669 .57247 .42051 .57482 .412 .57249 Mtetra
0 .477 .745 r
.412 .57249 .42051 .57482 .43445 .57732 .42598 .57549 Mtetra
.15 0 0 r
.42598 .57549 .43445 .57732 .44851 .57988 .44009 .57855 Mtetra
.188 0 0 r
.44009 .57855 .44851 .57988 .46272 .58241 .45434 .58159 Mtetra
.214 0 0 r
.45434 .58159 .46272 .58241 .47705 .58483 .46873 .5845 Mtetra
.229 0 0 r
.46873 .5845 .47705 .58483 .49152 .58703 .48326 .58719 Mtetra
.232 0 0 r
.48326 .58719 .49152 .58703 .50613 .58892 .49794 .58954 Mtetra
.225 0 0 r
.49794 .58954 .50613 .58892 .52087 .59039 .51275 .59144 Mtetra
.207 0 0 r
.51275 .59144 .52087 .59039 .53574 .59134 .5277 .59277 Mtetra
.179 0 0 r
.5277 .59277 .53574 .59134 .55073 .59167 .54278 .59344 Mtetra
.141 0 0 r
.54278 .59344 .55073 .59167 .56584 .59129 .55798 .59335 Mtetra
.092 0 0 r
.55798 .59335 .56584 .59129 .58106 .59012 .57329 .5924 Mtetra
.033 0 0 r
.57329 .5924 .58106 .59012 .59637 .5881 .5887 .59053 Mtetra
0 0 0 r
.5887 .59053 .59637 .5881 .61176 .58516 .6042 .58768 Mtetra
.6042 .58768 .61176 .58516 .62722 .58129 .61977 .58381 Mtetra
.61977 .58381 .62722 .58129 .64275 .57645 .6354 .5789 Mtetra
.282 .77 .696 r
.6354 .5789 .64275 .57645 .65832 .57065 .65108 .57295 Mtetra
.368 .827 .736 r
.65108 .57295 .65832 .57065 .67392 .56392 .6668 .56599 Mtetra
.452 .877 .772 r
.6668 .56599 .67392 .56392 .68955 .55628 .68253 .55807 Mtetra
.529 .918 .804 r
.68253 .55807 .68955 .55628 .7052 .5478 .69828 .54923 Mtetra
.597 .949 .831 r
.69828 .54923 .7052 .5478 .72085 .53855 .71404 .53956 Mtetra
.655 .971 .852 r
.71404 .53956 .72085 .53855 .73651 .5286 .72979 .52915 Mtetra
.703 .984 .868 r
.72979 .52915 .73651 .5286 .75217 .51805 .74554 .51809 Mtetra
.741 .99 .879 r
.74554 .51809 .75217 .51805 .76782 .50701 .76128 .5065 Mtetra
.77 .991 .888 r
.76128 .5065 .76782 .50701 .78348 .49556 .77701 .49448 Mtetra
.791 .987 .894 r
.77701 .49448 .78348 .49556 .79914 .48382 .79275 .48214 Mtetra
.806 .979 .898 r
.79275 .48214 .79914 .48382 .81481 .47188 .80848 .46961 Mtetra
.815 .969 .901 r
.80848 .46961 .81481 .47188 .83049 .45984 .82422 .45697 Mtetra
.82 .958 .903 r
.82422 .45697 .83049 .45984 .84619 .4478 .83999 .44433 Mtetra
.822 .945 .904 r
.83999 .44433 .84619 .4478 .86192 .43584 .85577 .43178 Mtetra
.82 .932 .905 r
.85577 .43178 .86192 .43584 .87769 .42402 .8716 .4194 Mtetra
.816 .919 .906 r
.8716 .4194 .87769 .42402 .89351 .41242 .88747 .40725 Mtetra
.81 .905 .907 r
.88747 .40725 .89351 .41242 .90939 .40108 .90339 .39539 Mtetra
.803 .891 .907 r
.90339 .39539 .90939 .40108 .92534 .39004 .91939 .38386 Mtetra
.263 .666 .967 r
.32185 .55479 .3306 .55979 .34391 .56104 .33518 .5564 Mtetra
.196 .638 .946 r
.33518 .5564 .34391 .56104 .35731 .56269 .3486 .55843 Mtetra
.124 .605 .916 r
.3486 .55843 .35731 .56269 .37081 .5647 .36212 .56085 Mtetra
.051 .566 .876 r
.36212 .56085 .37081 .5647 .38443 .56703 .37576 .56362 Mtetra
0 .525 .828 r
.37576 .56362 .38443 .56703 .39815 .56965 .38951 .5667 Mtetra
0 .482 .775 r
.38951 .5667 .39815 .56965 .412 .57249 .40339 .57002 Mtetra
0 .443 .72 r
.40339 .57002 .412 .57249 .42598 .57549 .4174 .5735 Mtetra
.187 0 0 r
.4174 .5735 .42598 .57549 .44009 .57855 .43155 .57706 Mtetra
.222 0 0 r
.43155 .57706 .44009 .57855 .45434 .58159 .44584 .5806 Mtetra
.245 0 0 r
.44584 .5806 .45434 .58159 .46873 .5845 .46029 .58401 Mtetra
.256 0 0 r
.46029 .58401 .46873 .5845 .48326 .58719 .47488 .58717 Mtetra
.47488 .58717 .48326 .58719 .49794 .58954 .48962 .58998 Mtetra
.245 0 0 r
.48962 .58998 .49794 .58954 .51275 .59144 .5045 .5923 Mtetra
.223 0 0 r
.5045 .5923 .51275 .59144 .5277 .59277 .51953 .59402 Mtetra
.19 0 0 r
.51953 .59402 .5277 .59277 .54278 .59344 .5347 .59503 Mtetra
.146 0 0 r
.5347 .59503 .54278 .59344 .55798 .59335 .54999 .59521 Mtetra
.092 0 0 r
.54999 .59521 .55798 .59335 .57329 .5924 .56539 .59448 Mtetra
.026 0 0 r
.56539 .59448 .57329 .5924 .5887 .59053 .58091 .59276 Mtetra
0 0 0 r
.58091 .59276 .5887 .59053 .6042 .58768 .59651 .58998 Mtetra
.59651 .58998 .6042 .58768 .61977 .58381 .61219 .58611 Mtetra
.222 .732 .684 r
.61219 .58611 .61977 .58381 .6354 .5789 .62793 .58113 Mtetra
.314 .795 .726 r
.62793 .58113 .6354 .5789 .65108 .57295 .64372 .57503 Mtetra
.404 .851 .764 r
.64372 .57503 .65108 .57295 .6668 .56599 .65954 .56785 Mtetra
.489 .898 .798 r
.65954 .56785 .6668 .56599 .68253 .55807 .67539 .55963 Mtetra
.565 .936 .825 r
.67539 .55963 .68253 .55807 .69828 .54923 .69124 .55043 Mtetra
.631 .963 .847 r
.69124 .55043 .69828 .54923 .71404 .53956 .70709 .54035 Mtetra
.685 .98 .862 r
.70709 .54035 .71404 .53956 .72979 .52915 .72294 .52947 Mtetra
.729 .989 .874 r
.72294 .52947 .72979 .52915 .74554 .51809 .73879 .5179 Mtetra
.764 .992 .881 r
.73879 .5179 .74554 .51809 .76128 .5065 .75461 .50576 Mtetra
.789 .99 .887 r
.75461 .50576 .76128 .5065 .77701 .49448 .77043 .49317 Mtetra
.808 .984 .89 r
.77043 .49317 .77701 .49448 .79275 .48214 .78624 .48025 Mtetra
.82 .976 .893 r
.78624 .48025 .79275 .48214 .80848 .46961 .80205 .46712 Mtetra
.828 .965 .894 r
.80205 .46712 .80848 .46961 .82422 .45697 .81786 .45388 Mtetra
.832 .954 .896 r
.81786 .45388 .82422 .45697 .83999 .44433 .83368 .44066 Mtetra
.832 .941 .897 r
.83368 .44066 .83999 .44433 .85577 .43178 .84953 .42753 Mtetra
.829 .929 .898 r
.84953 .42753 .85577 .43178 .8716 .4194 .86541 .41458 Mtetra
.824 .915 .899 r
.86541 .41458 .8716 .4194 .88747 .40725 .88133 .40189 Mtetra
.818 .902 .9 r
.88133 .40189 .88747 .40725 .90339 .39539 .89731 .38951 Mtetra
.81 .889 .901 r
.89731 .38951 .90339 .39539 .91939 .38386 .91335 .3775 Mtetra
.234 .647 .959 r
.31301 .54964 .32185 .55479 .33518 .5564 .32635 .55159 Mtetra
.165 .616 .935 r
.32635 .55159 .33518 .5564 .3486 .55843 .33979 .55399 Mtetra
.091 .58 .902 r
.33979 .55399 .3486 .55843 .36212 .56085 .35333 .55681 Mtetra
.017 .539 .86 r
.35333 .55681 .36212 .56085 .37576 .56362 .36698 .56001 Mtetra
0 .495 .811 r
.36698 .56001 .37576 .56362 .38951 .5667 .38076 .56354 Mtetra
0 .453 .758 r
.38076 .56354 .38951 .5667 .40339 .57002 .39467 .56732 Mtetra
0 .414 .704 r
.39467 .56732 .40339 .57002 .4174 .5735 .40871 .57128 Mtetra
.215 0 0 r
.40871 .57128 .4174 .5735 .43155 .57706 .4229 .57532 Mtetra
.246 0 0 r
.4229 .57532 .43155 .57706 .44584 .5806 .43724 .57935 Mtetra
.266 0 0 r
.43724 .57935 .44584 .5806 .46029 .58401 .45173 .58323 Mtetra
.274 0 0 r
.45173 .58323 .46029 .58401 .47488 .58717 .46637 .58687 Mtetra
.27 0 0 r
.46637 .58687 .47488 .58717 .48962 .58998 .48117 .59011 Mtetra
.255 0 0 r
.48117 .59011 .48962 .58998 .5045 .5923 .49613 .59285 Mtetra
.229 0 0 r
.49613 .59285 .5045 .5923 .51953 .59402 .51123 .59494 Mtetra
.191 0 0 r
.51123 .59494 .51953 .59402 .5347 .59503 .52648 .59627 Mtetra
.141 0 0 r
.52648 .59627 .5347 .59503 .54999 .59521 .54186 .59672 Mtetra
.08 0 0 r
.54186 .59672 .54999 .59521 .56539 .59448 .55736 .5962 Mtetra
.007 0 0 r
.55736 .5962 .56539 .59448 .58091 .59276 .57298 .59462 Mtetra
0 0 0 r
.57298 .59462 .58091 .59276 .59651 .58998 .58868 .59192 Mtetra
.58868 .59192 .59651 .58998 .61219 .58611 .60447 .58804 Mtetra
.263 .765 .728 r
.60447 .58804 .61219 .58611 .62793 .58113 .62032 .58298 Mtetra
.359 .827 .768 r
.62032 .58298 .62793 .58113 .64372 .57503 .63622 .57673 Mtetra
.451 .88 .802 r
.63622 .57673 .64372 .57503 .65954 .56785 .65215 .56933 Mtetra
.534 .923 .83 r
.65215 .56933 .65954 .56785 .67539 .55963 .6681 .56082 Mtetra
.607 .954 .851 r
.6681 .56082 .67539 .55963 .69124 .55043 .68406 .55126 Mtetra
.669 .975 .866 r
.68406 .55126 .69124 .55043 .70709 .54035 .70002 .54077 Mtetra
.718 .987 .876 r
.70002 .54077 .70709 .54035 .72294 .52947 .71597 .52942 Mtetra
.757 .992 .881 r
.71597 .52942 .72294 .52947 .73879 .5179 .7319 .51735 Mtetra
.787 .991 .885 r
.7319 .51735 .73879 .5179 .75461 .50576 .74782 .50468 Mtetra
.809 .986 .886 r
.74782 .50468 .75461 .50576 .77043 .49317 .76373 .49153 Mtetra
.824 .979 .887 r
.76373 .49153 .77043 .49317 .78624 .48025 .77962 .47804 Mtetra
.834 .969 .888 r
.77962 .47804 .78624 .48025 .80205 .46712 .7955 .46432 Mtetra
.839 .959 .888 r
.7955 .46432 .80205 .46712 .81786 .45388 .81138 .4505 Mtetra
.841 .947 .889 r
.81138 .4505 .81786 .45388 .83368 .44066 .82727 .43669 Mtetra
.84 .935 .889 r
.82727 .43669 .83368 .44066 .84953 .42753 .84317 .423 Mtetra
.837 .923 .89 r
.84317 .423 .84953 .42753 .86541 .41458 .85911 .4095 Mtetra
.832 .91 .891 r
.85911 .4095 .86541 .41458 .88133 .40189 .87509 .39629 Mtetra
.825 .898 .893 r
.87509 .39629 .88133 .40189 .89731 .38951 .89112 .38341 Mtetra
.817 .886 .894 r
.89112 .38341 .89731 .38951 .91335 .3775 .90722 .37092 Mtetra
.21 .63 .952 r
.30407 .5443 .31301 .54964 .32635 .55159 .31743 .54658 Mtetra
.139 .596 .926 r
.31743 .54658 .32635 .55159 .33979 .55399 .33088 .54933 Mtetra
.064 .557 .891 r
.33088 .54933 .33979 .55399 .35333 .55681 .34444 .55253 Mtetra
0 .515 .848 r
.34444 .55253 .35333 .55681 .36698 .56001 .35812 .55614 Mtetra
0 .471 .799 r
.35812 .55614 .36698 .56001 .38076 .56354 .37191 .56009 Mtetra
0 .429 .748 r
.37191 .56009 .38076 .56354 .39467 .56732 .38585 .56431 Mtetra
0 .392 .697 r
.38585 .56431 .39467 .56732 .40871 .57128 .39992 .56873 Mtetra
.233 0 0 r
.39992 .56873 .40871 .57128 .4229 .57532 .41414 .57324 Mtetra
.261 0 0 r
.41414 .57324 .4229 .57532 .43724 .57935 .42852 .57772 Mtetra
.277 0 0 r
.42852 .57772 .43724 .57935 .45173 .58323 .44305 .58207 Mtetra
.282 0 0 r
.44305 .58207 .45173 .58323 .46637 .58687 .45775 .58615 Mtetra
.275 0 0 r
.45775 .58615 .46637 .58687 .48117 .59011 .47261 .58981 Mtetra
.256 0 0 r
.47261 .58981 .48117 .59011 .49613 .59285 .48763 .59294 Mtetra
.224 0 0 r
.48763 .59294 .49613 .59285 .51123 .59494 .50281 .59539 Mtetra
.181 0 0 r
.50281 .59539 .51123 .59494 .52648 .59627 .51814 .59703 Mtetra
.125 0 0 r
.51814 .59703 .52648 .59627 .54186 .59672 .5336 .59774 Mtetra
.055 0 0 r
.5336 .59774 .54186 .59672 .55736 .5962 .5492 .59741 Mtetra
0 0 0 r
.5492 .59741 .55736 .5962 .57298 .59462 .56491 .59596 Mtetra
.117 .665 .698 r
.56491 .59596 .57298 .59462 .58868 .59192 .58072 .59332 Mtetra
.216 .737 .742 r
.58072 .59332 .58868 .59192 .60447 .58804 .59661 .58944 Mtetra
.316 .804 .783 r
.59661 .58944 .60447 .58804 .62032 .58298 .61256 .5843 Mtetra
.414 .863 .818 r
.61256 .5843 .62032 .58298 .63622 .57673 .62857 .5779 Mtetra
.505 .91 .846 r
.62857 .5779 .63622 .57673 .65215 .56933 .64461 .57027 Mtetra
.585 .946 .866 r
.64461 .57027 .65215 .56933 .6681 .56082 .66067 .56147 Mtetra
.652 .97 .879 r
.66067 .56147 .6681 .56082 .68406 .55126 .67674 .55157 Mtetra
.707 .984 .886 r
.67674 .55157 .68406 .55126 .70002 .54077 .6928 .54067 Mtetra
.75 .99 .888 r
.6928 .54067 .70002 .54077 .71597 .52942 .70885 .52888 Mtetra
.783 .99 .889 r
.70885 .52888 .71597 .52942 .7319 .51735 .72489 .51632 Mtetra
.808 .986 .887 r
.72489 .51632 .7319 .51735 .74782 .50468 .7409 .50313 Mtetra
.826 .979 .886 r
.7409 .50313 .74782 .50468 .76373 .49153 .75689 .48944 Mtetra
.838 .97 .884 r
.75689 .48944 .76373 .49153 .77962 .47804 .77286 .47539 Mtetra
.845 .96 .883 r
.77286 .47539 .77962 .47804 .7955 .46432 .78882 .4611 Mtetra
.849 .949 .882 r
.78882 .4611 .7955 .46432 .81138 .4505 .80478 .44672 Mtetra
.85 .938 .881 r
.80478 .44672 .81138 .4505 .82727 .43669 .82073 .43236 Mtetra
.848 .927 .882 r
.82073 .43236 .82727 .43669 .84317 .423 .83671 .41812 Mtetra
.843 .915 .883 r
.83671 .41812 .84317 .423 .85911 .4095 .85271 .40409 Mtetra
.838 .903 .884 r
.85271 .40409 .85911 .4095 .87509 .39629 .86874 .39037 Mtetra
.83 .892 .885 r
.86874 .39037 .87509 .39629 .89112 .38341 .88483 .37701 Mtetra
.822 .881 .887 r
.88483 .37701 .89112 .38341 .90722 .37092 .90098 .36406 Mtetra
.191 .613 .946 r
.29505 .53872 .30407 .5443 .31743 .54658 .30842 .5413 Mtetra
.119 .577 .919 r
.30842 .5413 .31743 .54658 .33088 .54933 .32189 .54439 Mtetra
.045 .537 .883 r
.32189 .54439 .33088 .54933 .34444 .55253 .33546 .54795 Mtetra
0 .495 .841 r
.33546 .54795 .34444 .55253 .35812 .55614 .34915 .55193 Mtetra
0 .452 .794 r
.34915 .55193 .35812 .55614 .37191 .56009 .36297 .55628 Mtetra
0 .412 .746 r
.36297 .55628 .37191 .56009 .38585 .56431 .37692 .56092 Mtetra
0 .377 .699 r
.37692 .56092 .38585 .56431 .39992 .56873 .39102 .56576 Mtetra
.241 0 0 r
.39102 .56576 .39992 .56873 .41414 .57324 .40528 .5707 Mtetra
.266 0 0 r
.40528 .5707 .41414 .57324 .42852 .57772 .41969 .57563 Mtetra
.279 0 0 r
.41969 .57563 .42852 .57772 .44305 .58207 .43427 .5804 Mtetra
.28 0 0 r
.43427 .5804 .44305 .58207 .45775 .58615 .44901 .58489 Mtetra
.269 0 0 r
.44901 .58489 .45775 .58615 .47261 .58981 .46393 .58895 Mtetra
.245 0 0 r
.46393 .58895 .47261 .58981 .48763 .59294 .47901 .59244 Mtetra
.209 0 0 r
.47901 .59244 .48763 .59294 .50281 .59539 .49426 .59522 Mtetra
.158 0 0 r
.49426 .59522 .50281 .59539 .51814 .59703 .50966 .59715 Mtetra
.094 0 0 r
.50966 .59715 .51814 .59703 .5336 .59774 .52521 .59809 Mtetra
.017 0 0 r
.52521 .59809 .5336 .59774 .5492 .59741 .5409 .59795 Mtetra
.073 .635 .721 r
.5409 .59795 .5492 .59741 .56491 .59596 .5567 .59662 Mtetra
.172 .709 .766 r
.5567 .59662 .56491 .59596 .58072 .59332 .57261 .59403 Mtetra
.277 .781 .808 r
.57261 .59403 .58072 .59332 .59661 .58944 .5886 .59013 Mtetra
.38 .844 .844 r
.5886 .59013 .59661 .58944 .61256 .5843 .60467 .58491 Mtetra
.477 .897 .871 r
.60467 .58491 .61256 .5843 .62857 .5779 .62078 .57836 Mtetra
.563 .936 .89 r
.62078 .57836 .62857 .5779 .64461 .57027 .63693 .57052 Mtetra
.636 .963 .9 r
.63693 .57052 .64461 .57027 .66067 .56147 .6531 .56144 Mtetra
.696 .978 .903 r
.6531 .56144 .66067 .56147 .67674 .55157 .66927 .5512 Mtetra
.743 .985 .902 r
.66927 .5512 .67674 .55157 .6928 .54067 .68544 .53992 Mtetra
.779 .986 .899 r
.68544 .53992 .6928 .54067 .70885 .52888 .70159 .5277 Mtetra
.806 .982 .894 r
.70159 .5277 .70885 .52888 .72489 .51632 .71772 .51467 Mtetra
.826 .976 .889 r
.71772 .51467 .72489 .51632 .7409 .50313 .73383 .50098 Mtetra
.84 .967 .884 r
.73383 .50098 .7409 .50313 .75689 .48944 .74991 .48677 Mtetra
.849 .958 .88 r
.74991 .48677 .75689 .48944 .77286 .47539 .76597 .47219 Mtetra
.854 .948 .877 r
.76597 .47219 .77286 .47539 .78882 .4611 .78201 .45737 Mtetra
.856 .937 .875 r
.78201 .45737 .78882 .4611 .80478 .44672 .79804 .44246 Mtetra
.856 .927 .874 r
.79804 .44246 .80478 .44672 .82073 .43236 .81407 .42756 Mtetra
.853 .916 .874 r
.81407 .42756 .82073 .43236 .83671 .41812 .83012 .4128 Mtetra
.848 .905 .875 r
.83012 .4128 .83671 .41812 .85271 .40409 .84618 .39828 Mtetra
.842 .895 .876 r
.84618 .39828 .85271 .40409 .86874 .39037 .86228 .38408 Mtetra
.834 .884 .878 r
.86228 .38408 .86874 .39037 .88483 .37701 .87843 .37026 Mtetra
.826 .874 .88 r
.87843 .37026 .88483 .37701 .90098 .36406 .89464 .35688 Mtetra
.177 .598 .941 r
.28595 .53287 .29505 .53872 .30842 .5413 .29933 .53573 Mtetra
.106 .562 .914 r
.29933 .53573 .30842 .5413 .32189 .54439 .31281 .53911 Mtetra
.033 .522 .879 r
.31281 .53911 .32189 .54439 .33546 .54795 .32639 .54299 Mtetra
0 .48 .839 r
.32639 .54299 .33546 .54795 .34915 .55193 .3401 .54732 Mtetra
0 .439 .795 r
.3401 .54732 .34915 .55193 .36297 .55628 .35393 .55204 Mtetra
0 .401 .751 r
.35393 .55204 .36297 .55628 .37692 .56092 .36791 .55706 Mtetra
0 .369 .709 r
.36791 .55706 .37692 .56092 .39102 .56576 .38203 .56229 Mtetra
0 .345 .673 r
.38203 .56229 .39102 .56576 .40528 .5707 .39631 .56763 Mtetra
.261 0 0 r
.39631 .56763 .40528 .5707 .41969 .57563 .41076 .57294 Mtetra
.27 0 0 r
.41076 .57294 .41969 .57563 .43427 .5804 .42537 .57811 Mtetra
.268 0 0 r
.42537 .57811 .43427 .5804 .44901 .58489 .44017 .58297 Mtetra
.252 0 0 r
.44017 .58297 .44901 .58489 .46393 .58895 .45513 .5874 Mtetra
.223 0 0 r
.45513 .5874 .46393 .58895 .47901 .59244 .47027 .59122 Mtetra
.18 0 0 r
.47027 .59122 .47901 .59244 .49426 .59522 .48559 .5943 Mtetra
.122 0 0 r
.48559 .5943 .49426 .59522 .50966 .59715 .50106 .59648 Mtetra
0 .535 .708 r
.50106 .59648 .50966 .59715 .52521 .59809 .51669 .59764 Mtetra
.036 .606 .751 r
.51669 .59764 .52521 .59809 .5409 .59795 .53246 .59765 Mtetra
.134 .681 .797 r
.53246 .59765 .5409 .59795 .5567 .59662 .54835 .59642 Mtetra
.24 .755 .839 r
.54835 .59642 .5567 .59662 .57261 .59403 .56436 .59388 Mtetra
.346 .822 .876 r
.56436 .59388 .57261 .59403 .5886 .59013 .58045 .58996 Mtetra
.448 .879 .903 r
.58045 .58996 .5886 .59013 .60467 .58491 .59662 .58465 Mtetra
.54 .922 .92 r
.59662 .58465 .60467 .58491 .62078 .57836 .61284 .57795 Mtetra
.618 .951 .927 r
.61284 .57795 .62078 .57836 .63693 .57052 .6291 .5699 Mtetra
.682 .969 .927 r
.6291 .5699 .63693 .57052 .6531 .56144 .64537 .56056 Mtetra
.733 .977 .921 r
.64537 .56056 .6531 .56144 .66927 .5512 .66165 .55001 Mtetra
.772 .978 .913 r
.66165 .55001 .66927 .5512 .68544 .53992 .67793 .53836 Mtetra
.802 .975 .904 r
.67793 .53836 .68544 .53992 .70159 .5277 .69418 .52573 Mtetra
.824 .969 .895 r
.69418 .52573 .70159 .5277 .71772 .51467 .71041 .51227 Mtetra
.84 .961 .887 r
.71041 .51227 .71772 .51467 .73383 .50098 .72661 .49811 Mtetra
.85 .952 .88 r
.72661 .49811 .73383 .50098 .74991 .48677 .74279 .48342 Mtetra
.857 .942 .875 r
.74279 .48342 .74991 .48677 .76597 .47219 .75893 .46834 Mtetra
.861 .932 .871 r
.75893 .46834 .76597 .47219 .78201 .45737 .77506 .45302 Mtetra
.861 .923 .868 r
.77506 .45302 .78201 .45737 .79804 .44246 .79117 .43761 Mtetra
.86 .913 .867 r
.79117 .43761 .79804 .44246 .81407 .42756 .80728 .42222 Mtetra
.856 .904 .866 r
.80728 .42222 .81407 .42756 .83012 .4128 .8234 .40698 Mtetra
.851 .894 .867 r
.8234 .40698 .83012 .4128 .84618 .39828 .83953 .392 Mtetra
.845 .885 .869 r
.83953 .392 .84618 .39828 .86228 .38408 .8557 .37734 Mtetra
.837 .875 .871 r
.8557 .37734 .86228 .38408 .87843 .37026 .87191 .3631 Mtetra
.829 .866 .873 r
.87191 .3631 .87843 .37026 .89464 .35688 .88819 .34932 Mtetra
.169 .586 .937 r
.27676 .52669 .28595 .53287 .29933 .53573 .29015 .5298 Mtetra
.099 .55 .911 r
.29015 .5298 .29933 .53573 .31281 .53911 .30364 .53345 Mtetra
.029 .51 .879 r
.30364 .53345 .31281 .53911 .32639 .54299 .31724 .53762 Mtetra
0 .47 .842 r
.31724 .53762 .32639 .54299 .3401 .54732 .33096 .54225 Mtetra
0 .431 .802 r
.33096 .54225 .3401 .54732 .35393 .55204 .34481 .54729 Mtetra
0 .396 .763 r
.34481 .54729 .35393 .55204 .36791 .55706 .3588 .55264 Mtetra
0 .368 .727 r
.3588 .55264 .36791 .55706 .38203 .56229 .37294 .55822 Mtetra
0 .347 .696 r
.37294 .55822 .38203 .56229 .39631 .56763 .38725 .56391 Mtetra
0 .336 .674 r
.38725 .56391 .39631 .56763 .41076 .57294 .40173 .56957 Mtetra
.251 0 0 r
.40173 .56957 .41076 .57294 .42537 .57811 .41638 .57508 Mtetra
.243 0 0 r
.41638 .57508 .42537 .57811 .44017 .58297 .43121 .58028 Mtetra
.223 0 0 r
.43121 .58028 .44017 .58297 .45513 .5874 .44623 .58502 Mtetra
.187 0 0 r
.44623 .58502 .45513 .5874 .47027 .59122 .46142 .58913 Mtetra
0 .451 .706 r
.46142 .58913 .47027 .59122 .48559 .5943 .4768 .59247 Mtetra
0 .509 .742 r
.4768 .59247 .48559 .5943 .50106 .59648 .49234 .59488 Mtetra
.009 .577 .784 r
.49234 .59488 .50106 .59648 .51669 .59764 .50804 .59622 Mtetra
.103 .65 .829 r
.50804 .59622 .51669 .59764 .53246 .59765 .52389 .59637 Mtetra
.207 .724 .872 r
.52389 .59637 .53246 .59765 .54835 .59642 .53987 .59522 Mtetra
.314 .794 .909 r
.53987 .59522 .54835 .59642 .56436 .59388 .55597 .5927 Mtetra
.418 .853 .935 r
.55597 .5927 .56436 .59388 .58045 .58996 .57216 .58876 Mtetra
.514 .9 .951 r
.57216 .58876 .58045 .58996 .59662 .58465 .58843 .58336 Mtetra
.597 .932 .955 r
.58843 .58336 .59662 .58465 .61284 .57795 .60475 .57652 Mtetra
.665 .952 .952 r
.60475 .57652 .61284 .57795 .6291 .5699 .62111 .56827 Mtetra
.72 .962 .943 r
.62111 .56827 .6291 .5699 .64537 .56056 .63749 .55868 Mtetra
.762 .964 .931 r
.63749 .55868 .64537 .56056 .66165 .55001 .65388 .54783 Mtetra
.794 .962 .917 r
.65388 .54783 .66165 .55001 .67793 .53836 .67025 .53585 Mtetra
.818 .957 .905 r
.67025 .53585 .67793 .53836 .69418 .52573 .68661 .52285 Mtetra
.836 .949 .893 r
.68661 .52285 .69418 .52573 .71041 .51227 .70294 .50898 Mtetra
.848 .941 .883 r
.70294 .50898 .71041 .51227 .72661 .49811 .71924 .4944 Mtetra
.856 .932 .875 r
.71924 .4944 .72661 .49811 .74279 .48342 .73551 .47927 Mtetra
.861 .924 .868 r
.73551 .47927 .74279 .48342 .75893 .46834 .75175 .46373 Mtetra
.864 .915 .863 r
.75175 .46373 .75893 .46834 .77506 .45302 .76796 .44796 Mtetra
.864 .906 .86 r
.76796 .44796 .77506 .45302 .79117 .43761 .78416 .43209 Mtetra
.862 .898 .859 r
.78416 .43209 .79117 .43761 .80728 .42222 .80035 .41626 Mtetra
.858 .89 .859 r
.80035 .41626 .80728 .42222 .8234 .40698 .81654 .40058 Mtetra
.853 .881 .859 r
.81654 .40058 .8234 .40698 .83953 .392 .83275 .38517 Mtetra
.846 .873 .861 r
.83275 .38517 .83953 .392 .8557 .37734 .84899 .37012 Mtetra
.839 .865 .863 r
.84899 .37012 .8557 .37734 .87191 .3631 .86528 .35549 Mtetra
.83 .857 .866 r
.86528 .35549 .87191 .3631 .88819 .34932 .88162 .34135 Mtetra
.167 .576 .935 r
.26749 .52016 .27676 .52669 .29015 .5298 .28089 .52347 Mtetra
.099 .54 .911 r
.28089 .52347 .29015 .5298 .30364 .53345 .29439 .52735 Mtetra
.032 .502 .881 r
.29439 .52735 .30364 .53345 .31724 .53762 .308 .53176 Mtetra
0 .464 .848 r
.308 .53176 .31724 .53762 .33096 .54225 .32173 .53666 Mtetra
0 .428 .813 r
.32173 .53666 .33096 .54225 .34481 .54729 .3356 .54197 Mtetra
0 .396 .78 r
.3356 .54197 .34481 .54729 .3588 .55264 .34961 .54761 Mtetra
0 .372 .75 r
.34961 .54761 .3588 .55264 .37294 .55822 .36377 .55347 Mtetra
0 .355 .726 r
.36377 .55347 .37294 .55822 .38725 .56391 .3781 .55946 Mtetra
0 .348 .71 r
.3781 .55946 .38725 .56391 .40173 .56957 .39261 .56542 Mtetra
0 .353 .703 r
.39261 .56542 .40173 .56957 .41638 .57508 .40729 .57122 Mtetra
0 .368 .706 r
.40729 .57122 .41638 .57508 .43121 .58028 .42216 .5767 Mtetra
0 .396 .72 r
.42216 .5767 .43121 .58028 .44623 .58502 .43722 .5817 Mtetra
0 .435 .743 r
.43722 .5817 .44623 .58502 .46142 .58913 .45247 .58606 Mtetra
0 .486 .775 r
.45247 .58606 .46142 .58913 .4768 .59247 .4679 .58962 Mtetra
0 .548 .815 r
.4679 .58962 .4768 .59247 .49234 .59488 .4835 .59221 Mtetra
.08 .617 .857 r
.4835 .59221 .49234 .59488 .50804 .59622 .49927 .5937 Mtetra
.178 .688 .899 r
.49927 .5937 .50804 .59622 .52389 .59637 .5152 .59395 Mtetra
.283 .757 .935 r
.5152 .59395 .52389 .59637 .53987 .59522 .53126 .59287 Mtetra
.387 .818 .962 r
.53126 .59287 .53987 .59522 .55597 .5927 .54744 .59036 Mtetra
.485 .867 .977 r
.54744 .59036 .55597 .5927 .57216 .58876 .56373 .58638 Mtetra
.57 .903 .98 r
.56373 .58638 .57216 .58876 .58843 .58336 .58009 .5809 Mtetra
.642 .926 .974 r
.58009 .5809 .58843 .58336 .60475 .57652 .59651 .57392 Mtetra
.7 .938 .962 r
.59651 .57392 .60475 .57652 .62111 .56827 .61297 .56549 Mtetra
.746 .943 .947 r
.61297 .56549 .62111 .56827 .63749 .55868 .62946 .55567 Mtetra
.781 .943 .931 r
.62946 .55567 .63749 .55868 .65388 .54783 .64595 .54455 Mtetra
.807 .939 .915 r
.64595 .54455 .65388 .54783 .67025 .53585 .66243 .53226 Mtetra
.827 .933 .9 r
.66243 .53226 .67025 .53585 .68661 .52285 .67888 .51892 Mtetra
.842 .926 .887 r
.67888 .51892 .68661 .52285 .70294 .50898 .69532 .50469 Mtetra
.852 .918 .876 r
.69532 .50469 .70294 .50898 .71924 .4944 .71171 .48973 Mtetra
.858 .911 .867 r
.71171 .48973 .71924 .4944 .73551 .47927 .72808 .47421 Mtetra
.862 .903 .86 r
.72808 .47421 .73551 .47927 .75175 .46373 .74441 .45827 Mtetra
.864 .896 .856 r
.74441 .45827 .75175 .46373 .76796 .44796 .76071 .4421 Mtetra
.863 .888 .853 r
.76071 .4421 .76796 .44796 .78416 .43209 .77699 .42582 Mtetra
.861 .881 .851 r
.77699 .42582 .78416 .43209 .80035 .41626 .79327 .40959 Mtetra
.857 .875 .851 r
.79327 .40959 .80035 .41626 .81654 .40058 .80954 .39353 Mtetra
.852 .868 .852 r
.80954 .39353 .81654 .40058 .83275 .38517 .82583 .37775 Mtetra
.846 .861 .854 r
.82583 .37775 .83275 .38517 .84899 .37012 .84215 .36234 Mtetra
.839 .854 .856 r
.84215 .36234 .84899 .37012 .86528 .35549 .85851 .34737 Mtetra
.83 .847 .86 r
.85851 .34737 .86528 .35549 .88162 .34135 .87493 .3329 Mtetra
.171 .569 .934 r
.25814 .51324 .26749 .52016 .28089 .52347 .27156 .51672 Mtetra
.106 .534 .913 r
.27156 .51672 .28089 .52347 .29439 .52735 .28507 .52078 Mtetra
.043 .498 .886 r
.28507 .52078 .29439 .52735 .308 .53176 .29869 .52538 Mtetra
0 .462 .857 r
.29869 .52538 .308 .53176 .32173 .53666 .31244 .53048 Mtetra
0 .429 .828 r
.31244 .53048 .32173 .53666 .3356 .54197 .32631 .53601 Mtetra
0 .402 .8 r
.32631 .53601 .3356 .54197 .34961 .54761 .34034 .54188 Mtetra
0 .38 .776 r
.34034 .54188 .34961 .54761 .36377 .55347 .35452 .54798 Mtetra
0 .368 .759 r
.35452 .54798 .36377 .55347 .3781 .55946 .36887 .5542 Mtetra
0 .365 .75 r
.36887 .5542 .3781 .55946 .39261 .56542 .3834 .5604 Mtetra
0 .373 .749 r
.3834 .5604 .39261 .56542 .40729 .57122 .39811 .56643 Mtetra
0 .393 .759 r
.39811 .56643 .40729 .57122 .42216 .5767 .41302 .57213 Mtetra
0 .424 .777 r
.41302 .57213 .42216 .5767 .43722 .5817 .42812 .57734 Mtetra
0 .467 .805 r
.42812 .57734 .43722 .5817 .45247 .58606 .44341 .58189 Mtetra
0 .52 .84 r
.44341 .58189 .45247 .58606 .4679 .58962 .45889 .58562 Mtetra
.065 .582 .879 r
.45889 .58562 .4679 .58962 .4835 .59221 .47455 .58835 Mtetra
.156 .648 .918 r
.47455 .58835 .4835 .59221 .49927 .5937 .49039 .58995 Mtetra
.255 .713 .952 r
.49039 .58995 .49927 .5937 .5152 .59395 .50638 .59028 Mtetra
.356 .773 .978 r
.50638 .59028 .5152 .59395 .53126 .59287 .52252 .58923 Mtetra
.452 .823 .992 r
.52252 .58923 .53126 .59287 .54744 .59036 .53879 .58671 Mtetra
.538 .862 .996 r
.53879 .58671 .54744 .59036 .56373 .58638 .55516 .58269 Mtetra
.613 .888 .99 r
.55516 .58269 .56373 .58638 .58009 .5809 .57161 .57711 Mtetra
.674 .904 .977 r
.57161 .57711 .58009 .5809 .59651 .57392 .58813 .57001 Mtetra
.723 .913 .96 r
.58813 .57001 .59651 .57392 .61297 .56549 .60469 .56141 Mtetra
.761 .915 .942 r
.60469 .56141 .61297 .56549 .62946 .55567 .62127 .55138 Mtetra
.791 .914 .923 r
.62127 .55138 .62946 .55567 .64595 .54455 .63786 .54003 Mtetra
.813 .91 .906 r
.63786 .54003 .64595 .54455 .66243 .53226 .65444 .52747 Mtetra
.83 .905 .891 r
.65444 .52747 .66243 .53226 .67888 .51892 .671 .51384 Mtetra
.842 .899 .878 r
.671 .51384 .67888 .51892 .69532 .50469 .68753 .4993 Mtetra
.851 .893 .867 r
.68753 .4993 .69532 .50469 .71171 .48973 .70403 .48401 Mtetra
.857 .887 .859 r
.70403 .48401 .71171 .48973 .72808 .47421 .72049 .46815 Mtetra
.86 .881 .852 r
.72049 .46815 .72808 .47421 .74441 .45827 .73691 .45187 Mtetra
.861 .875 .847 r
.73691 .45187 .74441 .45827 .76071 .4421 .75331 .43535 Mtetra
.861 .87 .844 r
.75331 .43535 .76071 .4421 .77699 .42582 .76968 .41873 Mtetra
.859 .864 .843 r
.76968 .41873 .77699 .42582 .79327 .40959 .78604 .40217 Mtetra
.855 .859 .843 r
.78604 .40217 .79327 .40959 .80954 .39353 .8024 .38578 Mtetra
.85 .853 .844 r
.8024 .38578 .80954 .39353 .82583 .37775 .81878 .36968 Mtetra
.844 .848 .847 r
.81878 .36968 .82583 .37775 .84215 .36234 .83517 .35396 Mtetra
.837 .843 .85 r
.83517 .35396 .84215 .36234 .85851 .34737 .85161 .3387 Mtetra
.829 .837 .853 r
.85161 .3387 .85851 .34737 .87493 .3329 .86811 .32396 Mtetra
.179 .564 .935 r
.24872 .50591 .25814 .51324 .27156 .51672 .26215 .5095 Mtetra
.119 .531 .915 r
.26215 .5095 .27156 .51672 .28507 .52078 .27568 .51369 Mtetra
.06 .497 .893 r
.27568 .51369 .28507 .52078 .29869 .52538 .28931 .51843 Mtetra
.005 .464 .868 r
.28931 .51843 .29869 .52538 .31244 .53048 .30307 .52368 Mtetra
0 .435 .844 r
.30307 .52368 .31244 .53048 .32631 .53601 .31696 .52937 Mtetra
0 .41 .822 r
.31696 .52937 .32631 .53601 .34034 .54188 .331 .5354 Mtetra
0 .393 .804 r
.331 .5354 .34034 .54188 .35452 .54798 .3452 .54167 Mtetra
0 .384 .793 r
.3452 .54167 .35452 .54798 .36887 .5542 .35957 .54806 Mtetra
0 .385 .789 r
.35957 .54806 .36887 .5542 .3834 .5604 .37412 .55443 Mtetra
0 .396 .794 r
.37412 .55443 .3834 .5604 .39811 .56643 .38886 .56063 Mtetra
0 .419 .808 r
.38886 .56063 .39811 .56643 .41302 .57213 .40379 .56649 Mtetra
0 .452 .83 r
.40379 .56649 .41302 .57213 .42812 .57734 .41893 .57185 Mtetra
0 .496 .858 r
.41893 .57185 .42812 .57734 .44341 .58189 .43426 .57653 Mtetra
.061 .548 .892 r
.43426 .57653 .44341 .58189 .45889 .58562 .44979 .58037 Mtetra
.142 .606 .926 r
.44979 .58037 .45889 .58562 .47455 .58835 .4655 .58319 Mtetra
.232 .665 .957 r
.4655 .58319 .47455 .58835 .49039 .58995 .4814 .58486 Mtetra
.325 .722 .981 r
.4814 .58486 .49039 .58995 .50638 .59028 .49746 .58522 Mtetra
.417 .771 .996 r
.49746 .58522 .50638 .59028 .52252 .58923 .51367 .58418 Mtetra
.502 .811 1 r
.51367 .58418 .52252 .58923 .53879 .58671 .53001 .58165 Mtetra
.577 .841 .995 r
.53001 .58165 .53879 .58671 .55516 .58269 .54646 .57756 Mtetra
.641 .861 .983 r
.54646 .57756 .55516 .58269 .57161 .57711 .56299 .57191 Mtetra
.693 .873 .966 r
.56299 .57191 .57161 .57711 .58813 .57001 .5796 .56468 Mtetra
.734 .88 .948 r
.5796 .56468 .58813 .57001 .60469 .56141 .59625 .55593 Mtetra
.767 .882 .929 r
.59625 .55593 .60469 .56141 .62127 .55138 .61293 .54573 Mtetra
.793 .881 .911 r
.61293 .54573 .62127 .55138 .63786 .54003 .62962 .53417 Mtetra
.812 .879 .894 r
.62962 .53417 .63786 .54003 .65444 .52747 .6463 .52139 Mtetra
.827 .875 .88 r
.6463 .52139 .65444 .52747 .671 .51384 .66296 .50752 Mtetra
.838 .871 .867 r
.66296 .50752 .671 .51384 .68753 .4993 .67959 .49272 Mtetra
.846 .867 .857 r
.67959 .49272 .68753 .4993 .70403 .48401 .69618 .47716 Mtetra
.852 .863 .849 r
.69618 .47716 .70403 .48401 .72049 .46815 .71274 .46102 Mtetra
.855 .858 .843 r
.71274 .46102 .72049 .46815 .73691 .45187 .72926 .44446 Mtetra
.856 .854 .839 r
.72926 .44446 .73691 .45187 .75331 .43535 .74575 .42766 Mtetra
.856 .85 .836 r
.74575 .42766 .75331 .43535 .76968 .41873 .76222 .41076 Mtetra
.854 .846 .835 r
.76222 .41076 .76968 .41873 .78604 .40217 .77867 .39392 Mtetra
.851 .842 .835 r
.77867 .39392 .78604 .40217 .8024 .38578 .79512 .37726 Mtetra
.847 .839 .837 r
.79512 .37726 .8024 .38578 .81878 .36968 .81158 .36091 Mtetra
.841 .835 .84 r
.81158 .36091 .81878 .36968 .83517 .35396 .82806 .34494 Mtetra
.835 .83 .843 r
.82806 .34494 .83517 .35396 .85161 .3387 .84459 .32945 Mtetra
.827 .826 .847 r
.84459 .32945 .85161 .3387 .86811 .32396 .86116 .31449 Mtetra
.192 .561 .935 r
.23924 .49813 .24872 .50591 .26215 .5095 .25268 .50179 Mtetra
.136 .53 .918 r
.25268 .50179 .26215 .5095 .27568 .51369 .26622 .50605 Mtetra
.082 .499 .899 r
.26622 .50605 .27568 .51369 .28931 .51843 .27986 .51088 Mtetra
.033 .469 .879 r
.27986 .51088 .28931 .51843 .30307 .52368 .29363 .51622 Mtetra
0 .442 .859 r
.29363 .51622 .30307 .52368 .31696 .52937 .30754 .522 Mtetra
0 .421 .843 r
.30754 .522 .31696 .52937 .331 .5354 .32159 .52813 Mtetra
0 .407 .83 r
.32159 .52813 .331 .5354 .3452 .54167 .33581 .5345 Mtetra
0 .402 .824 r
.33581 .5345 .3452 .54167 .35957 .54806 .3502 .54099 Mtetra
0 .405 .825 r
.3502 .54099 .35957 .54806 .37412 .55443 .36477 .54746 Mtetra
0 .419 .833 r
.36477 .54746 .37412 .55443 .38886 .56063 .37953 .55375 Mtetra
0 .443 .848 r
.37953 .55375 .38886 .56063 .40379 .56649 .3945 .55971 Mtetra
.009 .476 .87 r
.3945 .55971 .40379 .56649 .41893 .57185 .40966 .56514 Mtetra
.066 .518 .897 r
.40966 .56514 .41893 .57185 .43426 .57653 .42503 .5699 Mtetra
.135 .566 .925 r
.42503 .5699 .43426 .57653 .44979 .58037 .4406 .57379 Mtetra
.214 .618 .952 r
.4406 .57379 .44979 .58037 .4655 .58319 .45636 .57665 Mtetra
.299 .668 .973 r
.45636 .57665 .4655 .58319 .4814 .58486 .47231 .57834 Mtetra
.384 .715 .987 r
.47231 .57834 .4814 .58486 .49746 .58522 .48843 .57871 Mtetra
.465 .755 .993 r
.48843 .57871 .49746 .58522 .51367 .58418 .5047 .57765 Mtetra
.539 .787 .99 r
.5047 .57765 .51367 .58418 .53001 .58165 .52111 .57507 Mtetra
.603 .811 .98 r
.52111 .57507 .53001 .58165 .54646 .57756 .53763 .57092 Mtetra
.657 .827 .965 r
.53763 .57092 .54646 .57756 .56299 .57191 .55425 .56518 Mtetra
.702 .838 .948 r
.55425 .56518 .56299 .57191 .5796 .56468 .57094 .55785 Mtetra
.738 .844 .929 r
.57094 .55785 .5796 .56468 .59625 .55593 .58768 .54897 Mtetra
.767 .847 .911 r
.58768 .54897 .59625 .55593 .61293 .54573 .60445 .53862 Mtetra
.79 .847 .895 r
.60445 .53862 .61293 .54573 .62962 .53417 .62123 .5269 Mtetra
.807 .847 .88 r
.62123 .5269 .62962 .53417 .6463 .52139 .638 .51393 Mtetra
.821 .845 .866 r
.638 .51393 .6463 .52139 .66296 .50752 .65476 .49987 Mtetra
.832 .843 .855 r
.65476 .49987 .66296 .50752 .67959 .49272 .67149 .48487 Mtetra
.839 .841 .846 r
.67149 .48487 .67959 .49272 .69618 .47716 .68818 .46911 Mtetra
.845 .838 .839 r
.68818 .46911 .69618 .47716 .71274 .46102 .70483 .45275 Mtetra
.848 .836 .833 r
.70483 .45275 .71274 .46102 .72926 .44446 .72145 .43598 Mtetra
.85 .833 .83 r
.72145 .43598 .72926 .44446 .74575 .42766 .73804 .41897 Mtetra
.85 .831 .828 r
.73804 .41897 .74575 .42766 .76222 .41076 .7546 .40186 Mtetra
.849 .829 .827 r
.7546 .40186 .76222 .41076 .77867 .39392 .77114 .38481 Mtetra
.846 .826 .828 r
.77114 .38481 .77867 .39392 .79512 .37726 .78769 .36796 Mtetra
.842 .824 .83 r
.78769 .36796 .79512 .37726 .81158 .36091 .80424 .35141 Mtetra
.837 .821 .833 r
.80424 .35141 .81158 .36091 .82806 .34494 .82081 .33526 Mtetra
.831 .818 .837 r
.82081 .33526 .82806 .34494 .84459 .32945 .83742 .31958 Mtetra
.824 .815 .841 r
.83742 .31958 .84459 .32945 .86116 .31449 .85409 .30445 Mtetra
.21 .56 .936 r
.22969 .48988 .23924 .49813 .25268 .50179 .24314 .49356 Mtetra
.158 .531 .922 r
.24314 .49356 .25268 .50179 .26622 .50605 .2567 .49785 Mtetra
.109 .502 .906 r
.2567 .49785 .26622 .50605 .27986 .51088 .27036 .5027 Mtetra
.065 .475 .889 r
.27036 .5027 .27986 .51088 .29363 .51622 .28414 .50806 Mtetra
.028 .452 .874 r
.28414 .50806 .29363 .51622 .30754 .522 .29806 .51387 Mtetra
0 .434 .861 r
.29806 .51387 .30754 .522 .32159 .52813 .31213 .52003 Mtetra
0 .423 .853 r
.31213 .52003 .32159 .52813 .33581 .5345 .32636 .52643 Mtetra
0 .419 .85 r
.32636 .52643 .33581 .5345 .3502 .54099 .34077 .53295 Mtetra
0 .425 .853 r
.34077 .53295 .3502 .54099 .36477 .54746 .35536 .53944 Mtetra
.001 .439 .863 r
.35536 .53944 .36477 .54746 .37953 .55375 .37014 .54576 Mtetra
.034 .463 .878 r
.37014 .54576 .37953 .55375 .3945 .55971 .38513 .55173 Mtetra
.079 .495 .898 r
.38513 .55173 .3945 .55971 .40966 .56514 .40033 .55718 Mtetra
.137 .533 .919 r
.40033 .55718 .40966 .56514 .42503 .5699 .41573 .56194 Mtetra
.204 .575 .941 r
.41573 .56194 .42503 .5699 .4406 .57379 .43134 .56582 Mtetra
.278 .619 .959 r
.43134 .56582 .4406 .57379 .45636 .57665 .44714 .56868 Mtetra
.354 .661 .972 r
.44714 .56868 .45636 .57665 .47231 .57834 .46314 .57034 Mtetra
.43 .699 .977 r
.46314 .57034 .47231 .57834 .48843 .57871 .47931 .57067 Mtetra
.5 .731 .976 r
.47931 .57067 .48843 .57871 .5047 .57765 .49564 .56956 Mtetra
.563 .757 .969 r
.49564 .56956 .5047 .57765 .52111 .57507 .51211 .56692 Mtetra
.619 .777 .957 r
.51211 .56692 .52111 .57507 .53763 .57092 .5287 .5627 Mtetra
.665 .791 .942 r
.5287 .5627 .53763 .57092 .55425 .56518 .54539 .55687 Mtetra
.704 .801 .925 r
.54539 .55687 .55425 .56518 .57094 .55785 .56216 .54944 Mtetra
.736 .808 .909 r
.56216 .54944 .57094 .55785 .58768 .54897 .57898 .54046 Mtetra
.762 .812 .892 r
.57898 .54046 .58768 .54897 .60445 .53862 .59583 .52999 Mtetra
.783 .814 .878 r
.59583 .52999 .60445 .53862 .62123 .5269 .6127 .51815 Mtetra
.799 .815 .864 r
.6127 .51815 .62123 .5269 .638 .51393 .62956 .50505 Mtetra
.813 .816 .853 r
.62956 .50505 .638 .51393 .65476 .49987 .64641 .49085 Mtetra
.823 .816 .843 r
.64641 .49085 .65476 .49987 .67149 .48487 .66323 .47571 Mtetra
.831 .815 .835 r
.66323 .47571 .67149 .48487 .68818 .46911 .68002 .45981 Mtetra
.836 .815 .829 r
.68002 .45981 .68818 .46911 .70483 .45275 .69677 .44331 Mtetra
.84 .814 .824 r
.69677 .44331 .70483 .45275 .72145 .43598 .71349 .4264 Mtetra
.842 .813 .821 r
.71349 .4264 .72145 .43598 .73804 .41897 .73017 .40924 Mtetra
.843 .812 .82 r
.73017 .40924 .73804 .41897 .7546 .40186 .74683 .392 Mtetra
.842 .811 .82 r
.74683 .392 .7546 .40186 .77114 .38481 .76347 .37482 Mtetra
.84 .81 .821 r
.76347 .37482 .77114 .38481 .78769 .36796 .78011 .35783 Mtetra
.837 .809 .824 r
.78011 .35783 .78769 .36796 .80424 .35141 .79676 .34115 Mtetra
.832 .808 .827 r
.79676 .34115 .80424 .35141 .82081 .33526 .81342 .32488 Mtetra
.827 .806 .831 r
.81342 .32488 .82081 .33526 .83742 .31958 .83013 .30909 Mtetra
.82 .804 .836 r
.83013 .30909 .83742 .31958 .85409 .30445 .84688 .29385 Mtetra
.23 .561 .936 r
.22007 .48117 .22969 .48988 .24314 .49356 .23355 .48481 Mtetra
.183 .534 .924 r
.23355 .48481 .24314 .49356 .2567 .49785 .24712 .48906 Mtetra
.14 .508 .911 r
.24712 .48906 .2567 .49785 .27036 .5027 .26079 .49387 Mtetra
.101 .483 .898 r
.26079 .49387 .27036 .5027 .28414 .50806 .27459 .4992 Mtetra
.07 .462 .886 r
.27459 .4992 .28414 .50806 .29806 .51387 .28853 .50497 Mtetra
.047 .447 .876 r
.28853 .50497 .29806 .51387 .31213 .52003 .30261 .51108 Mtetra
.034 .438 .871 r
.30261 .51108 .31213 .52003 .32636 .52643 .31686 .51744 Mtetra
.032 .436 .87 r
.31686 .51744 .32636 .52643 .34077 .53295 .33129 .52391 Mtetra
.043 .442 .874 r
.33129 .52391 .34077 .53295 .35536 .53944 .3459 .53036 Mtetra
.065 .457 .883 r
.3459 .53036 .35536 .53944 .37014 .54576 .3607 .53662 Mtetra
.1 .479 .896 r
.3607 .53662 .37014 .54576 .38513 .55173 .37572 .54253 Mtetra
.146 .507 .911 r
.37572 .54253 .38513 .55173 .40033 .55718 .39094 .54793 Mtetra
.201 .54 .927 r
.39094 .54793 .40033 .55718 .41573 .56194 .40637 .55262 Mtetra
.264 .576 .941 r
.40637 .55262 .41573 .56194 .43134 .56582 .42201 .55644 Mtetra
.331 .613 .952 r
.42201 .55644 .43134 .56582 .44714 .56868 .43785 .55922 Mtetra
.398 .647 .958 r
.43785 .55922 .44714 .56868 .46314 .57034 .45388 .56081 Mtetra
.464 .678 .958 r
.45388 .56081 .46314 .57034 .47931 .57067 .4701 .56107 Mtetra
.525 .705 .953 r
.4701 .56107 .47931 .57067 .49564 .56956 .48648 .55988 Mtetra
.579 .727 .944 r
.48648 .55988 .49564 .56956 .51211 .56692 .50301 .55717 Mtetra
.627 .744 .931 r
.50301 .55717 .51211 .56692 .5287 .5627 .51966 .55286 Mtetra
.668 .757 .917 r
.51966 .55286 .5287 .5627 .54539 .55687 .53642 .54695 Mtetra
.702 .767 .902 r
.53642 .54695 .54539 .55687 .56216 .54944 .55325 .53944 Mtetra
.731 .774 .888 r
.55325 .53944 .56216 .54944 .57898 .54046 .57015 .53037 Mtetra
.755 .78 .874 r
.57015 .53037 .57898 .54046 .59583 .52999 .58708 .51982 Mtetra
.774 .783 .861 r
.58708 .51982 .59583 .52999 .6127 .51815 .60403 .50789 Mtetra
.79 .786 .849 r
.60403 .50789 .6127 .51815 .62956 .50505 .62099 .49472 Mtetra
.803 .788 .839 r
.62099 .49472 .62956 .50505 .64641 .49085 .63792 .48044 Mtetra
.813 .79 .831 r
.63792 .48044 .64641 .49085 .66323 .47571 .65484 .46522 Mtetra
.821 .791 .824 r
.65484 .46522 .66323 .47571 .68002 .45981 .67172 .44924 Mtetra
.827 .792 .819 r
.67172 .44924 .68002 .45981 .69677 .44331 .68857 .43268 Mtetra
.831 .793 .816 r
.68857 .43268 .69677 .44331 .71349 .4264 .70538 .4157 Mtetra
.833 .794 .813 r
.70538 .4157 .71349 .4264 .73017 .40924 .72216 .39847 Mtetra
.835 .794 .813 r
.72216 .39847 .73017 .40924 .74683 .392 .73892 .38116 Mtetra
.834 .794 .813 r
.73892 .38116 .74683 .392 .76347 .37482 .75566 .36392 Mtetra
.833 .795 .815 r
.75566 .36392 .76347 .37482 .78011 .35783 .77239 .34687 Mtetra
.83 .795 .818 r
.77239 .34687 .78011 .35783 .79676 .34115 .78913 .33014 Mtetra
.826 .795 .822 r
.78913 .33014 .79676 .34115 .81342 .32488 .8059 .31381 Mtetra
.822 .794 .826 r
.8059 .31381 .81342 .32488 .83013 .30909 .8227 .29796 Mtetra
.816 .793 .831 r
.8227 .29796 .83013 .30909 .84688 .29385 .83955 .28266 Mtetra
.252 .563 .936 r
.2104 .47198 .22007 .48117 .23355 .48481 .22389 .47553 Mtetra
.211 .538 .926 r
.22389 .47553 .23355 .48481 .24712 .48906 .23748 .47969 Mtetra
.172 .514 .915 r
.23748 .47969 .24712 .48906 .26079 .49387 .25118 .4844 Mtetra
.139 .492 .904 r
.25118 .4844 .26079 .49387 .27459 .4992 .265 .48962 Mtetra
.113 .473 .894 r
.265 .48962 .27459 .4992 .28853 .50497 .27895 .49528 Mtetra
.095 .46 .887 r
.27895 .49528 .28853 .50497 .30261 .51108 .29305 .50128 Mtetra
.086 .452 .883 r
.29305 .50128 .30261 .51108 .31686 .51744 .30732 .50752 Mtetra
.089 .451 .883 r
.30732 .50752 .31686 .51744 .33129 .52391 .32176 .51387 Mtetra
.102 .457 .887 r
.32176 .51387 .33129 .52391 .3459 .53036 .33639 .52019 Mtetra
.126 .47 .894 r
.33639 .52019 .3459 .53036 .3607 .53662 .35122 .52633 Mtetra
.161 .49 .903 r
.35122 .52633 .3607 .53662 .37572 .54253 .36625 .53211 Mtetra
.205 .514 .914 r
.36625 .53211 .37572 .54253 .39094 .54793 .38149 .53737 Mtetra
.257 .542 .924 r
.38149 .53737 .39094 .54793 .40637 .55262 .39695 .54194 Mtetra
.314 .572 .932 r
.39695 .54194 .40637 .55262 .42201 .55644 .41262 .54563 Mtetra
.373 .602 .937 r
.41262 .54563 .42201 .55644 .43785 .55922 .42849 .54829 Mtetra
.432 .631 .938 r
.42849 .54829 .43785 .55922 .45388 .56081 .44456 .54976 Mtetra
.489 .657 .934 r
.44456 .54976 .45388 .56081 .4701 .56107 .46082 .54991 Mtetra
.542 .679 .928 r
.46082 .54991 .4701 .56107 .48648 .55988 .47725 .54861 Mtetra
.589 .698 .918 r
.47725 .54861 .48648 .55988 .50301 .55717 .49382 .5458 Mtetra
.631 .713 .906 r
.49382 .5458 .50301 .55717 .51966 .55286 .51053 .5414 Mtetra
.667 .726 .893 r
.51053 .5414 .51966 .55286 .53642 .54695 .52734 .53541 Mtetra
.698 .736 .88 r
.52734 .53541 .53642 .54695 .55325 .53944 .54425 .52783 Mtetra
.724 .744 .868 r
.54425 .52783 .55325 .53944 .57015 .53037 .56121 .5187 Mtetra
.746 .75 .856 r
.56121 .5187 .57015 .53037 .58708 .51982 .57822 .5081 Mtetra
.764 .755 .845 r
.57822 .5081 .58708 .51982 .60403 .50789 .59524 .49613 Mtetra
.78 .759 .835 r
.59524 .49613 .60403 .50789 .62099 .49472 .61228 .48293 Mtetra
.792 .763 .827 r
.61228 .48293 .62099 .49472 .63792 .48044 .6293 .46863 Mtetra
.802 .766 .82 r
.6293 .46863 .63792 .48044 .65484 .46522 .6463 .4534 Mtetra
.81 .769 .814 r
.6463 .4534 .65484 .46522 .67172 .44924 .66328 .43741 Mtetra
.817 .771 .81 r
.66328 .43741 .67172 .44924 .68857 .43268 .68022 .42084 Mtetra
.821 .773 .807 r
.68022 .42084 .68857 .43268 .70538 .4157 .69712 .40387 Mtetra
.824 .775 .806 r
.69712 .40387 .70538 .4157 .72216 .39847 .714 .38665 Mtetra
.826 .777 .806 r
.714 .38665 .72216 .39847 .73892 .38116 .73086 .36935 Mtetra
.826 .779 .807 r
.73086 .36935 .73892 .38116 .75566 .36392 .7477 .35212 Mtetra
.825 .78 .809 r
.7477 .35212 .75566 .36392 .77239 .34687 .76453 .33509 Mtetra
.823 .781 .813 r
.76453 .33509 .77239 .34687 .78913 .33014 .78138 .31836 Mtetra
.82 .782 .817 r
.78138 .31836 .78913 .33014 .8059 .31381 .79824 .30204 Mtetra
.816 .783 .822 r
.79824 .30204 .8059 .31381 .8227 .29796 .81514 .2862 Mtetra
.81 .783 .827 r
.81514 .2862 .8227 .29796 .83955 .28266 .83209 .2709 Mtetra
.276 .566 .935 r
.20066 .46232 .2104 .47198 .22389 .47553 .21418 .46573 Mtetra
.239 .543 .926 r
.21418 .46573 .22389 .47553 .23748 .47969 .2278 .46973 Mtetra
.206 .52 .917 r
.2278 .46973 .23748 .47969 .25118 .4844 .24152 .47429 Mtetra
.177 .5 .908 r
.24152 .47429 .25118 .4844 .265 .48962 .25535 .47934 Mtetra
.156 .484 .9 r
.25535 .47934 .265 .48962 .27895 .49528 .26933 .48482 Mtetra
.142 .472 .894 r
.26933 .48482 .27895 .49528 .29305 .50128 .28345 .49064 Mtetra
.137 .465 .891 r
.28345 .49064 .29305 .50128 .30732 .50752 .29773 .49669 Mtetra
.142 .464 .89 r
.29773 .49669 .30732 .50752 .32176 .51387 .3122 .50284 Mtetra
.157 .47 .892 r
.3122 .50284 .32176 .51387 .33639 .52019 .32684 .50896 Mtetra
.182 .481 .897 r
.32684 .50896 .33639 .52019 .35122 .52633 .34169 .5149 Mtetra
.216 .497 .902 r
.34169 .5149 .35122 .52633 .36625 .53211 .35674 .52048 Mtetra
.257 .518 .909 r
.35674 .52048 .36625 .53211 .38149 .53737 .37201 .52555 Mtetra
.304 .541 .914 r
.37201 .52555 .38149 .53737 .39695 .54194 .38749 .52992 Mtetra
.355 .566 .917 r
.38749 .52992 .39695 .54194 .41262 .54563 .40318 .53342 Mtetra
.407 .591 .918 r
.40318 .53342 .41262 .54563 .42849 .54829 .41909 .53591 Mtetra
.459 .614 .916 r
.41909 .53591 .42849 .54829 .44456 .54976 .43519 .53721 Mtetra
.508 .636 .911 r
.43519 .53721 .44456 .54976 .46082 .54991 .45148 .5372 Mtetra
.554 .655 .903 r
.45148 .5372 .46082 .54991 .47725 .54861 .46794 .53577 Mtetra
.595 .672 .894 r
.46794 .53577 .47725 .54861 .49382 .5458 .48456 .53284 Mtetra
.632 .686 .883 r
.48456 .53284 .49382 .5458 .51053 .5414 .50132 .52835 Mtetra
.664 .698 .872 r
.50132 .52835 .51053 .5414 .52734 .53541 .51818 .52228 Mtetra
.692 .708 .86 r
.51818 .52228 .52734 .53541 .54425 .52783 .53514 .51464 Mtetra
.716 .717 .849 r
.53514 .51464 .54425 .52783 .56121 .5187 .55217 .50548 Mtetra
.737 .724 .839 r
.55217 .50548 .56121 .5187 .57822 .5081 .56924 .49486 Mtetra
.754 .73 .83 r
.56924 .49486 .57822 .5081 .59524 .49613 .58634 .48289 Mtetra
.769 .735 .822 r
.58634 .48289 .59524 .49613 .61228 .48293 .60345 .46971 Mtetra
.781 .74 .815 r
.60345 .46971 .61228 .48293 .6293 .46863 .62055 .45545 Mtetra
.792 .744 .809 r
.62055 .45545 .6293 .46863 .6463 .4534 .63764 .44027 Mtetra
.8 .748 .805 r
.63764 .44027 .6463 .4534 .66328 .43741 .6547 .42434 Mtetra
.806 .752 .802 r
.6547 .42434 .66328 .43741 .68022 .42084 .67173 .40784 Mtetra
.811 .755 .8 r
.67173 .40784 .68022 .42084 .69712 .40387 .68873 .39094 Mtetra
.815 .758 .799 r
.68873 .39094 .69712 .40387 .714 .38665 .70571 .3738 Mtetra
.817 .761 .8 r
.70571 .3738 .714 .38665 .73086 .36935 .72266 .35659 Mtetra
.818 .764 .802 r
.72266 .35659 .73086 .36935 .7477 .35212 .7396 .33944 Mtetra
.818 .766 .804 r
.7396 .33944 .7477 .35212 .76453 .33509 .75654 .32248 Mtetra
.816 .768 .808 r
.75654 .32248 .76453 .33509 .78138 .31836 .77348 .30583 Mtetra
.813 .77 .812 r
.77348 .30583 .78138 .31836 .79824 .30204 .79045 .28958 Mtetra
.81 .772 .818 r
.79045 .28958 .79824 .30204 .81514 .2862 .80745 .2738 Mtetra
.805 .773 .823 r
.80745 .2738 .81514 .2862 .83209 .2709 .82451 .25856 Mtetra
.301 .57 .933 r
.19087 .45219 .20066 .46232 .21418 .46573 .20442 .45541 Mtetra
.269 .548 .925 r
.20442 .45541 .21418 .46573 .2278 .46973 .21806 .45921 Mtetra
.239 .527 .917 r
.21806 .45921 .2278 .46973 .24152 .47429 .23181 .46355 Mtetra
.215 .509 .91 r
.23181 .46355 .24152 .47429 .25535 .47934 .24567 .46837 Mtetra
.197 .494 .903 r
.24567 .46837 .25535 .47934 .26933 .48482 .25967 .47361 Mtetra
.187 .483 .897 r
.25967 .47361 .26933 .48482 .28345 .49064 .27381 .47918 Mtetra
.185 .476 .894 r
.27381 .47918 .28345 .49064 .29773 .49669 .28812 .48496 Mtetra
.192 .475 .892 r
.28812 .48496 .29773 .49669 .3122 .50284 .3026 .49085 Mtetra
.208 .48 .892 r
.3026 .49085 .3122 .50284 .32684 .50896 .31727 .4967 Mtetra
.232 .489 .894 r
.31727 .4967 .32684 .50896 .34169 .5149 .33213 .50236 Mtetra
.264 .503 .897 r
.33213 .50236 .34169 .5149 .35674 .52048 .34721 .50768 Mtetra
.301 .519 .899 r
.34721 .50768 .35674 .52048 .37201 .52555 .36249 .51248 Mtetra
.343 .539 .901 r
.36249 .51248 .37201 .52555 .38749 .52992 .378 .51659 Mtetra
.388 .559 .901 r
.378 .51659 .38749 .52992 .40318 .53342 .39371 .51986 Mtetra
.434 .58 .899 r
.39371 .51986 .40318 .53342 .41909 .53591 .40964 .52211 Mtetra
.479 .599 .895 r
.40964 .52211 .41909 .53591 .43519 .53721 .42577 .52321 Mtetra
.522 .618 .889 r
.42577 .52321 .43519 .53721 .45148 .5372 .44209 .52301 Mtetra
.562 .635 .881 r
.44209 .52301 .45148 .5372 .46794 .53577 .45858 .52142 Mtetra
.599 .65 .872 r
.45858 .52142 .46794 .53577 .48456 .53284 .47524 .51836 Mtetra
.631 .663 .862 r
.47524 .51836 .48456 .53284 .50132 .52835 .49203 .51376 Mtetra
.661 .674 .852 r
.49203 .51376 .50132 .52835 .51818 .52228 .50894 .50762 Mtetra
.686 .684 .843 r
.50894 .50762 .51818 .52228 .53514 .51464 .52595 .49993 Mtetra
.709 .693 .833 r
.52595 .49993 .53514 .51464 .55217 .50548 .54303 .49076 Mtetra
.728 .701 .825 r
.54303 .49076 .55217 .50548 .56924 .49486 .56017 .48016 Mtetra
.745 .708 .817 r
.56017 .48016 .56924 .49486 .58634 .48289 .57733 .46823 Mtetra
.759 .714 .81 r
.57733 .46823 .58634 .48289 .60345 .46971 .59451 .45512 Mtetra
.771 .72 .805 r
.59451 .45512 .60345 .46971 .62055 .45545 .61169 .44094 Mtetra
.781 .725 .8 r
.61169 .44094 .62055 .45545 .63764 .44027 .62885 .42587 Mtetra
.789 .73 .797 r
.62885 .42587 .63764 .44027 .6547 .42434 .646 .41007 Mtetra
.796 .734 .795 r
.646 .41007 .6547 .42434 .67173 .40784 .66312 .39371 Mtetra
.802 .738 .794 r
.66312 .39371 .67173 .40784 .68873 .39094 .68022 .37695 Mtetra
.805 .742 .794 r
.68022 .37695 .68873 .39094 .70571 .3738 .69729 .35996 Mtetra
.808 .746 .795 r
.69729 .35996 .70571 .3738 .72266 .35659 .71434 .3429 Mtetra
.809 .75 .797 r
.71434 .3429 .72266 .35659 .7396 .33944 .73138 .3259 Mtetra
.81 .753 .8 r
.73138 .3259 .7396 .33944 .75654 .32248 .74842 .30909 Mtetra
.808 .756 .804 r
.74842 .30909 .75654 .32248 .77348 .30583 .76546 .29258 Mtetra
.806 .759 .809 r
.76546 .29258 .77348 .30583 .79045 .28958 .78254 .27646 Mtetra
.803 .761 .814 r
.78254 .27646 .79045 .28958 .80745 .2738 .79964 .2608 Mtetra
.799 .763 .82 r
.79964 .2608 .80745 .2738 .82451 .25856 .8168 .24567 Mtetra
.326 .574 .93 r
.18103 .44162 .19087 .45219 .20442 .45541 .19461 .4446 Mtetra
.297 .554 .924 r
.19461 .4446 .20442 .45541 .21806 .45921 .20828 .44814 Mtetra
.272 .535 .917 r
.20828 .44814 .21806 .45921 .23181 .46355 .22205 .45221 Mtetra
.252 .518 .909 r
.22205 .45221 .23181 .46355 .24567 .46837 .23594 .45674 Mtetra
.237 .503 .903 r
.23594 .45674 .24567 .46837 .25967 .47361 .24996 .46168 Mtetra
.23 .493 .897 r
.24996 .46168 .25967 .47361 .27381 .47918 .26413 .46693 Mtetra
.23 .487 .893 r
.26413 .46693 .27381 .47918 .28812 .48496 .27846 .47239 Mtetra
.237 .485 .891 r
.27846 .47239 .28812 .48496 .3026 .49085 .29297 .47795 Mtetra
.253 .488 .889 r
.29297 .47795 .3026 .49085 .31727 .4967 .30766 .48346 Mtetra
.276 .495 .889 r
.30766 .48346 .31727 .4967 .33213 .50236 .32255 .48878 Mtetra
.305 .506 .889 r
.32255 .48878 .33213 .50236 .34721 .50768 .33764 .49376 Mtetra
.339 .52 .888 r
.33764 .49376 .34721 .50768 .36249 .51248 .35295 .49824 Mtetra
.376 .536 .887 r
.35295 .49824 .36249 .51248 .378 .51659 .36847 .50204 Mtetra
.416 .553 .884 r
.36847 .50204 .378 .51659 .39371 .51986 .38421 .50501 Mtetra
.456 .57 .881 r
.38421 .50501 .39371 .51986 .40964 .52211 .40015 .50698 Mtetra
.495 .586 .875 r
.40015 .50698 .40964 .52211 .42577 .52321 .4163 .50783 Mtetra
.533 .602 .869 r
.4163 .50783 .42577 .52321 .44209 .52301 .43265 .50742 Mtetra
.568 .617 .861 r
.43265 .50742 .44209 .52301 .45858 .52142 .44917 .50564 Mtetra
.601 .631 .853 r
.44917 .50564 .45858 .52142 .47524 .51836 .46586 .50243 Mtetra
.63 .643 .844 r
.46586 .50243 .47524 .51836 .49203 .51376 .48269 .49772 Mtetra
.657 .654 .836 r
.48269 .49772 .49203 .51376 .50894 .50762 .49964 .49151 Mtetra
.68 .664 .827 r
.49964 .49151 .50894 .50762 .52595 .49993 .51669 .4838 Mtetra
.701 .673 .819 r
.51669 .4838 .52595 .49993 .54303 .49076 .53382 .47463 Mtetra
.719 .681 .812 r
.53382 .47463 .54303 .49076 .56017 .48016 .551 .46407 Mtetra
.735 .688 .806 r
.551 .46407 .56017 .48016 .57733 .46823 .56823 .45223 Mtetra
.749 .695 .8 r
.56823 .45223 .57733 .46823 .59451 .45512 .58547 .43923 Mtetra
.761 .702 .796 r
.58547 .43923 .59451 .45512 .61169 .44094 .60272 .42519 Mtetra
.771 .708 .792 r
.60272 .42519 .61169 .44094 .62885 .42587 .61996 .41029 Mtetra
.779 .713 .79 r
.61996 .41029 .62885 .42587 .646 .41007 .63719 .39467 Mtetra
.786 .718 .788 r
.63719 .39467 .646 .41007 .66312 .39371 .65439 .37851 Mtetra
.792 .723 .788 r
.65439 .37851 .66312 .39371 .68022 .37695 .67158 .36196 Mtetra
.796 .728 .789 r
.67158 .36196 .68022 .37695 .69729 .35996 .68874 .34519 Mtetra
.799 .733 .79 r
.68874 .34519 .69729 .35996 .71434 .3429 .70589 .32834 Mtetra
.801 .737 .793 r
.70589 .32834 .71434 .3429 .73138 .3259 .72303 .31155 Mtetra
.801 .741 .796 r
.72303 .31155 .73138 .3259 .74842 .30909 .74017 .29495 Mtetra
.801 .745 .801 r
.74017 .29495 .74842 .30909 .76546 .29258 .75732 .27864 Mtetra
.799 .748 .806 r
.75732 .27864 .76546 .29258 .78254 .27646 .7745 .26271 Mtetra
.796 .752 .812 r
.7745 .26271 .78254 .27646 .79964 .2608 .79171 .24723 Mtetra
.793 .754 .818 r
.79171 .24723 .79964 .2608 .8168 .24567 .80898 .23226 Mtetra
.351 .579 .927 r
.17112 .43063 .18103 .44162 .19461 .4446 .18474 .43333 Mtetra
.325 .56 .921 r
.18474 .43333 .19461 .4446 .20828 .44814 .19844 .43656 Mtetra
.304 .542 .915 r
.19844 .43656 .20828 .44814 .22205 .45221 .21225 .4403 Mtetra
.286 .526 .908 r
.21225 .4403 .22205 .45221 .23594 .45674 .22617 .44449 Mtetra
.274 .513 .901 r
.22617 .44449 .23594 .45674 .24996 .46168 .24023 .44907 Mtetra
.269 .503 .896 r
.24023 .44907 .24996 .46168 .26413 .46693 .25443 .45395 Mtetra
.27 .496 .891 r
.25443 .45395 .26413 .46693 .27846 .47239 .26878 .45902 Mtetra
.278 .494 .887 r
.26878 .45902 .27846 .47239 .29297 .47795 .28331 .46418 Mtetra
.293 .496 .884 r
.28331 .46418 .29297 .47795 .30766 .48346 .29803 .4693 Mtetra
.314 .501 .881 r
.29803 .4693 .30766 .48346 .32255 .48878 .31294 .47423 Mtetra
.34 .509 .879 r
.31294 .47423 .32255 .48878 .33764 .49376 .32805 .47881 Mtetra
.371 .52 .876 r
.32805 .47881 .33764 .49376 .35295 .49824 .34338 .4829 Mtetra
.404 .533 .873 r
.34338 .4829 .35295 .49824 .36847 .50204 .35892 .48634 Mtetra
.439 .547 .869 r
.35892 .48634 .36847 .50204 .38421 .50501 .37467 .48896 Mtetra
.474 .561 .864 r
.37467 .48896 .38421 .50501 .40015 .50698 .39064 .49062 Mtetra
.508 .576 .858 r
.39064 .49062 .40015 .50698 .4163 .50783 .40681 .49118 Mtetra
.542 .589 .852 r
.40681 .49118 .4163 .50783 .43265 .50742 .42318 .49052 Mtetra
.573 .603 .844 r
.42318 .49052 .43265 .50742 .44917 .50564 .43972 .48854 Mtetra
.602 .615 .837 r
.43972 .48854 .44917 .50564 .46586 .50243 .45643 .48516 Mtetra
.629 .626 .829 r
.45643 .48516 .46586 .50243 .48269 .49772 .47329 .48034 Mtetra
.653 .637 .821 r
.47329 .48034 .48269 .49772 .49964 .49151 .49027 .47406 Mtetra
.675 .647 .814 r
.49027 .47406 .49964 .49151 .51669 .4838 .50736 .46633 Mtetra
.694 .656 .807 r
.50736 .46633 .51669 .4838 .53382 .47463 .52453 .45719 Mtetra
.711 .664 .801 r
.52453 .45719 .53382 .47463 .551 .46407 .54176 .44671 Mtetra
.727 .672 .796 r
.54176 .44671 .551 .46407 .56823 .45223 .55904 .43499 Mtetra
.74 .679 .792 r
.55904 .43499 .56823 .45223 .58547 .43923 .57634 .42214 Mtetra
.751 .686 .788 r
.57634 .42214 .58547 .43923 .60272 .42519 .59365 .40829 Mtetra
.761 .692 .786 r
.59365 .40829 .60272 .42519 .61996 .41029 .61097 .3936 Mtetra
.77 .698 .784 r
.61097 .3936 .61996 .41029 .63719 .39467 .62827 .37822 Mtetra
.777 .704 .783 r
.62827 .37822 .63719 .39467 .65439 .37851 .64556 .36232 Mtetra
.783 .71 .783 r
.64556 .36232 .65439 .37851 .67158 .36196 .66283 .34604 Mtetra
.787 .715 .785 r
.66283 .34604 .67158 .36196 .68874 .34519 .68008 .32954 Mtetra
.79 .721 .787 r
.68008 .32954 .68874 .34519 .70589 .32834 .69733 .31296 Mtetra
.792 .726 .79 r
.69733 .31296 .70589 .32834 .72303 .31155 .71456 .29645 Mtetra
.793 .73 .794 r
.71456 .29645 .72303 .31155 .74017 .29495 .73181 .28011 Mtetra
.793 .735 .798 r
.73181 .28011 .74017 .29495 .75732 .27864 .74906 .26405 Mtetra
.792 .739 .804 r
.74906 .26405 .75732 .27864 .7745 .26271 .76635 .24836 Mtetra
.79 .743 .81 r
.76635 .24836 .7745 .26271 .79171 .24723 .78367 .23311 Mtetra
.786 .746 .816 r
.78367 .23311 .79171 .24723 .80898 .23226 .80104 .21834 Mtetra
.375 .584 .924 r
.16116 .41925 .17112 .43063 .18474 .43333 .17481 .42161 Mtetra
.352 .566 .918 r
.17481 .42161 .18474 .43333 .19844 .43656 .18856 .4245 Mtetra
.334 .55 .912 r
.18856 .4245 .19844 .43656 .21225 .4403 .2024 .42787 Mtetra
.319 .534 .905 r
.2024 .42787 .21225 .4403 .22617 .44449 .21636 .43167 Mtetra
.309 .522 .899 r
.21636 .43167 .22617 .44449 .24023 .44907 .23045 .43584 Mtetra
.305 .512 .893 r
.23045 .43584 .24023 .44907 .25443 .45395 .24468 .44029 Mtetra
.307 .505 .887 r
.24468 .44029 .25443 .45395 .26878 .45902 .25907 .44493 Mtetra
.315 .502 .882 r
.25907 .44493 .26878 .45902 .28331 .46418 .27363 .44964 Mtetra
.328 .503 .878 r
.27363 .44964 .28331 .46418 .29803 .4693 .28837 .4543 Mtetra
.347 .506 .874 r
.28837 .4543 .29803 .4693 .31294 .47423 .3033 .45878 Mtetra
.371 .512 .87 r
.3033 .45878 .31294 .47423 .32805 .47881 .31844 .46292 Mtetra
.398 .521 .865 r
.31844 .46292 .32805 .47881 .34338 .4829 .33379 .46658 Mtetra
.427 .531 .861 r
.33379 .46658 .34338 .4829 .35892 .48634 .34935 .4696 Mtetra
.458 .543 .856 r
.34935 .4696 .35892 .48634 .37467 .48896 .36512 .47183 Mtetra
.489 .555 .85 r
.36512 .47183 .37467 .48896 .39064 .49062 .3811 .47314 Mtetra
.519 .567 .844 r
.3811 .47314 .39064 .49062 .40681 .49118 .39729 .47338 Mtetra
.549 .579 .837 r
.39729 .47338 .40681 .49118 .42318 .49052 .41367 .47245 Mtetra
.577 .591 .83 r
.41367 .47245 .42318 .49052 .43972 .48854 .43023 .47024 Mtetra
.603 .602 .823 r
.43023 .47024 .43972 .48854 .45643 .48516 .44697 .46669 Mtetra
.627 .613 .816 r
.44697 .46669 .45643 .48516 .47329 .48034 .46384 .46175 Mtetra
.65 .623 .81 r
.46384 .46175 .47329 .48034 .49027 .47406 .48085 .45541 Mtetra
.67 .632 .803 r
.48085 .45541 .49027 .47406 .50736 .46633 .49797 .44767 Mtetra
.688 .641 .798 r
.49797 .44767 .50736 .46633 .52453 .45719 .51518 .43858 Mtetra
.704 .649 .793 r
.51518 .43858 .52453 .45719 .54176 .44671 .53245 .4282 Mtetra
.718 .657 .788 r
.53245 .4282 .54176 .44671 .55904 .43499 .54977 .41662 Mtetra
.731 .665 .785 r
.54977 .41662 .55904 .43499 .57634 .42214 .56713 .40396 Mtetra
.743 .672 .782 r
.56713 .40396 .57634 .42214 .59365 .40829 .5845 .39035 Mtetra
.752 .679 .78 r
.5845 .39035 .59365 .40829 .61097 .3936 .60188 .37592 Mtetra
.761 .686 .779 r
.60188 .37592 .61097 .3936 .62827 .37822 .61925 .36083 Mtetra
.768 .692 .779 r
.61925 .36083 .62827 .37822 .64556 .36232 .63662 .34523 Mtetra
.774 .698 .78 r
.63662 .34523 .64556 .36232 .66283 .34604 .65397 .32927 Mtetra
.778 .704 .781 r
.65397 .32927 .66283 .34604 .68008 .32954 .67132 .3131 Mtetra
.782 .71 .784 r
.67132 .3131 .68008 .32954 .69733 .31296 .68865 .29685 Mtetra
.784 .715 .787 r
.68865 .29685 .69733 .31296 .71456 .29645 .70599 .28066 Mtetra
.785 .721 .792 r
.70599 .28066 .71456 .29645 .73181 .28011 .72333 .26464 Mtetra
.786 .726 .797 r
.72333 .26464 .73181 .28011 .74906 .26405 .7407 .24888 Mtetra
.785 .73 .802 r
.7407 .24888 .74906 .26405 .76635 .24836 .75808 .23348 Mtetra
.783 .735 .808 r
.75808 .23348 .76635 .24836 .78367 .23311 .77551 .21849 Mtetra
.78 .739 .815 r
.77551 .21849 .78367 .23311 .80104 .21834 .793 .20397 Mtetra
.398 .59 .921 r
.15113 .4075 .16116 .41925 .17481 .42161 .16483 .40951 Mtetra
.378 .573 .915 r
.16483 .40951 .17481 .42161 .18856 .4245 .17862 .41201 Mtetra
.362 .557 .909 r
.17862 .41201 .18856 .4245 .2024 .42787 .19251 .41496 Mtetra
.349 .543 .902 r
.19251 .41496 .2024 .42787 .21636 .43167 .20651 .41833 Mtetra
.341 .53 .895 r
.20651 .41833 .21636 .43167 .23045 .43584 .22064 .42204 Mtetra
.338 .521 .889 r
.22064 .42204 .23045 .43584 .24468 .44029 .2349 .42602 Mtetra
.34 .514 .883 r
.2349 .42602 .24468 .44029 .25907 .44493 .24933 .43017 Mtetra
.347 .51 .877 r
.24933 .43017 .25907 .44493 .27363 .44964 .26392 .43439 Mtetra
.36 .509 .871 r
.26392 .43439 .27363 .44964 .28837 .4543 .27869 .43855 Mtetra
.377 .511 .866 r
.27869 .43855 .28837 .4543 .3033 .45878 .29365 .44253 Mtetra
.398 .516 .861 r
.29365 .44253 .3033 .45878 .31844 .46292 .30881 .44618 Mtetra
.421 .522 .855 r
.30881 .44618 .31844 .46292 .33379 .46658 .32417 .44937 Mtetra
.447 .531 .85 r
.32417 .44937 .33379 .46658 .34935 .4696 .33975 .45194 Mtetra
.474 .54 .844 r
.33975 .45194 .34935 .4696 .36512 .47183 .35554 .45375 Mtetra
.502 .55 .838 r
.35554 .45375 .36512 .47183 .3811 .47314 .37154 .45467 Mtetra
.529 .561 .832 r
.37154 .45467 .3811 .47314 .39729 .47338 .38774 .45457 Mtetra
.555 .571 .825 r
.38774 .45457 .39729 .47338 .41367 .47245 .40414 .45334 Mtetra
.58 .582 .819 r
.40414 .45334 .41367 .47245 .43023 .47024 .42072 .45089 Mtetra
.604 .592 .812 r
.42072 .45089 .43023 .47024 .44697 .46669 .43746 .44716 Mtetra
.626 .602 .806 r
.43746 .44716 .44697 .46669 .46384 .46175 .45436 .4421 Mtetra
.646 .611 .8 r
.45436 .4421 .46384 .46175 .48085 .45541 .47139 .4357 Mtetra
.665 .62 .795 r
.47139 .4357 .48085 .45541 .49797 .44767 .48854 .42796 Mtetra
.682 .629 .79 r
.48854 .42796 .49797 .44767 .51518 .43858 .50577 .41893 Mtetra
.697 .637 .785 r
.50577 .41893 .51518 .43858 .53245 .4282 .52308 .40867 Mtetra
.711 .645 .782 r
.52308 .40867 .53245 .4282 .54977 .41662 .54044 .39727 Mtetra
.723 .653 .779 r
.54044 .39727 .54977 .41662 .56713 .40396 .55785 .38483 Mtetra
.734 .66 .777 r
.55785 .38483 .56713 .40396 .5845 .39035 .57527 .37149 Mtetra
.744 .668 .776 r
.57527 .37149 .5845 .39035 .60188 .37592 .59271 .35736 Mtetra
.752 .675 .775 r
.59271 .35736 .60188 .37592 .61925 .36083 .61015 .3426 Mtetra
.759 .681 .776 r
.61015 .3426 .61925 .36083 .63662 .34523 .62759 .32735 Mtetra
.765 .688 .777 r
.62759 .32735 .63662 .34523 .65397 .32927 .64503 .31175 Mtetra
.77 .694 .779 r
.64503 .31175 .65397 .32927 .67132 .3131 .66246 .29595 Mtetra
.774 .7 .782 r
.66246 .29595 .67132 .3131 .68865 .29685 .67988 .28008 Mtetra
.776 .706 .786 r
.67988 .28008 .68865 .29685 .70599 .28066 .69732 .26426 Mtetra
.778 .712 .79 r
.69732 .26426 .70599 .28066 .72333 .26464 .71476 .24859 Mtetra
.778 .717 .796 r
.71476 .24859 .72333 .26464 .7407 .24888 .73222 .23318 Mtetra
.778 .723 .801 r
.73222 .23318 .7407 .24888 .75808 .23348 .74972 .2181 Mtetra
.776 .727 .808 r
.74972 .2181 .75808 .23348 .77551 .21849 .76726 .20341 Mtetra
.773 .732 .814 r
.76726 .20341 .77551 .21849 .793 .20397 .78485 .18918 Mtetra
.42 .595 .917 r
.14105 .39543 .15113 .4075 .16483 .40951 .15479 .39704 Mtetra
.402 .58 .912 r
.15479 .39704 .16483 .40951 .17862 .41201 .16863 .39912 Mtetra
.388 .565 .905 r
.16863 .39912 .17862 .41201 .19251 .41496 .18256 .40164 Mtetra
.377 .551 .899 r
.18256 .40164 .19251 .41496 .20651 .41833 .19661 .40453 Mtetra
.37 .539 .892 r
.19661 .40453 .20651 .41833 .22064 .42204 .21078 .40775 Mtetra
.367 .529 .885 r
.21078 .40775 .22064 .42204 .2349 .42602 .22509 .41122 Mtetra
.37 .522 .878 r
.22509 .41122 .2349 .42602 .24933 .43017 .23955 .41485 Mtetra
.376 .518 .872 r
.23955 .41485 .24933 .43017 .26392 .43439 .25417 .41853 Mtetra
.387 .516 .865 r
.25417 .41853 .26392 .43439 .27869 .43855 .26898 .42215 Mtetra
.403 .517 .859 r
.26898 .42215 .27869 .43855 .29365 .44253 .28396 .4256 Mtetra
.421 .519 .853 r
.28396 .4256 .29365 .44253 .30881 .44618 .29915 .42872 Mtetra
.442 .524 .847 r
.29915 .42872 .30881 .44618 .32417 .44937 .31454 .4314 Mtetra
.465 .531 .841 r
.31454 .4314 .32417 .44937 .33975 .45194 .33014 .43348 Mtetra
.488 .538 .834 r
.33014 .43348 .33975 .45194 .35554 .45375 .34594 .43484 Mtetra
.513 .547 .828 r
.34594 .43484 .35554 .45375 .37154 .45467 .36196 .43535 Mtetra
.537 .556 .822 r
.36196 .43535 .37154 .45467 .38774 .45457 .37817 .43488 Mtetra
.561 .565 .815 r
.37817 .43488 .38774 .45457 .40414 .45334 .39458 .43334 Mtetra
.583 .575 .809 r
.39458 .43334 .40414 .45334 .42072 .45089 .41117 .43064 Mtetra
.605 .584 .803 r
.41117 .43064 .42072 .45089 .43746 .44716 .42793 .42672 Mtetra
.625 .593 .798 r
.42793 .42672 .43746 .44716 .45436 .4421 .44484 .42154 Mtetra
.644 .602 .792 r
.44484 .42154 .45436 .4421 .47139 .4357 .46189 .41508 Mtetra
.661 .611 .788 r
.46189 .41508 .47139 .4357 .48854 .42796 .47906 .40736 Mtetra
.677 .619 .783 r
.47906 .40736 .48854 .42796 .50577 .41893 .49632 .3984 Mtetra
.691 .627 .78 r
.49632 .3984 .50577 .41893 .52308 .40867 .51366 .38829 Mtetra
.704 .635 .777 r
.51366 .38829 .52308 .40867 .54044 .39727 .53106 .37708 Mtetra
.716 .643 .775 r
.53106 .37708 .54044 .39727 .55785 .38483 .5485 .36489 Mtetra
.727 .651 .773 r
.5485 .36489 .55785 .38483 .57527 .37149 .56598 .35184 Mtetra
.736 .658 .773 r
.56598 .35184 .57527 .37149 .59271 .35736 .58347 .33805 Mtetra
.744 .665 .773 r
.58347 .33805 .59271 .35736 .61015 .3426 .60097 .32365 Mtetra
.751 .672 .774 r
.60097 .32365 .61015 .3426 .62759 .32735 .61848 .30878 Mtetra
.757 .679 .775 r
.61848 .30878 .62759 .32735 .64503 .31175 .63599 .29359 Mtetra
.762 .686 .778 r
.63599 .29359 .64503 .31175 .66246 .29595 .65351 .2782 Mtetra
.766 .692 .781 r
.65351 .2782 .66246 .29595 .67988 .28008 .67102 .26274 Mtetra
.769 .698 .785 r
.67102 .26274 .67988 .28008 .69732 .26426 .68855 .24732 Mtetra
.77 .705 .79 r
.68855 .24732 .69732 .26426 .71476 .24859 .70609 .23205 Mtetra
.771 .71 .795 r
.70609 .23205 .71476 .24859 .73222 .23318 .72365 .21701 Mtetra
.77 .716 .801 r
.72365 .21701 .73222 .23318 .74972 .2181 .74125 .20229 Mtetra
.769 .721 .808 r
.74125 .20229 .74972 .2181 .76726 .20341 .7589 .18794 Mtetra
.767 .726 .815 r
.7589 .18794 .76726 .20341 .78485 .18918 .7766 .17401 Mtetra
.44 .602 .914 r
.13089 .38307 .14105 .39543 .15479 .39704 .14469 .38427 Mtetra
.425 .587 .908 r
.14469 .38427 .15479 .39704 .16863 .39912 .15858 .3859 Mtetra
.412 .572 .902 r
.15858 .3859 .16863 .39912 .18256 .40164 .17256 .38794 Mtetra
.403 .559 .895 r
.17256 .38794 .18256 .40164 .19661 .40453 .18666 .39034 Mtetra
.397 .548 .888 r
.18666 .39034 .19661 .40453 .21078 .40775 .20088 .39304 Mtetra
.394 .538 .881 r
.20088 .39304 .21078 .40775 .22509 .41122 .21523 .39597 Mtetra
.396 .53 .874 r
.21523 .39597 .22509 .41122 .23955 .41485 .22973 .39904 Mtetra
.402 .525 .867 r
.22973 .39904 .23955 .41485 .25417 .41853 .2444 .40215 Mtetra
.412 .523 .86 r
.2444 .40215 .25417 .41853 .26898 .42215 .25923 .40521 Mtetra
.425 .522 .853 r
.25923 .40521 .26898 .42215 .28396 .4256 .27425 .40808 Mtetra
.442 .524 .847 r
.27425 .40808 .28396 .4256 .29915 .42872 .28947 .41065 Mtetra
.46 .527 .84 r
.28947 .41065 .29915 .42872 .31454 .4314 .30488 .41279 Mtetra
.48 .532 .833 r
.30488 .41279 .31454 .4314 .33014 .43348 .3205 .41437 Mtetra
.501 .538 .827 r
.3205 .41437 .33014 .43348 .34594 .43484 .33632 .41525 Mtetra
.523 .545 .82 r
.33632 .41525 .34594 .43484 .36196 .43535 .35235 .41533 Mtetra
.544 .553 .814 r
.35235 .41533 .36196 .43535 .37817 .43488 .36858 .41448 Mtetra
.565 .561 .808 r
.36858 .41448 .37817 .43488 .39458 .43334 .385 .41262 Mtetra
.586 .57 .802 r
.385 .41262 .39458 .43334 .41117 .43064 .4016 .40966 Mtetra
.606 .578 .796 r
.4016 .40966 .41117 .43064 .42793 .42672 .41837 .40554 Mtetra
.624 .586 .791 r
.41837 .40554 .42793 .42672 .44484 .42154 .43529 .40024 Mtetra
.641 .595 .787 r
.43529 .40024 .44484 .42154 .46189 .41508 .45235 .39373 Mtetra
.657 .603 .782 r
.45235 .39373 .46189 .41508 .47906 .40736 .46953 .38602 Mtetra
.672 .611 .779 r
.46953 .38602 .47906 .40736 .49632 .3984 .48682 .37716 Mtetra
.686 .619 .776 r
.48682 .37716 .49632 .3984 .51366 .38829 .50418 .36719 Mtetra
.698 .627 .773 r
.50418 .36719 .51366 .38829 .53106 .37708 .52161 .3562 Mtetra
.71 .635 .772 r
.52161 .3562 .53106 .37708 .5485 .36489 .53909 .34428 Mtetra
.72 .643 .771 r
.53909 .34428 .5485 .36489 .56598 .35184 .55661 .33155 Mtetra
.729 .65 .771 r
.55661 .33155 .56598 .35184 .58347 .33805 .57416 .31811 Mtetra
.737 .657 .771 r
.57416 .31811 .58347 .33805 .60097 .32365 .59172 .3041 Mtetra
.744 .664 .772 r
.59172 .3041 .60097 .32365 .61848 .30878 .6093 .28965 Mtetra
.75 .672 .774 r
.6093 .28965 .61848 .30878 .63599 .29359 .62688 .27489 Mtetra
.754 .678 .777 r
.62688 .27489 .63599 .29359 .65351 .2782 .64447 .25994 Mtetra
.758 .685 .781 r
.64447 .25994 .65351 .2782 .67102 .26274 .66207 .24491 Mtetra
.761 .692 .785 r
.66207 .24491 .67102 .26274 .68855 .24732 .67969 .22993 Mtetra
.763 .698 .79 r
.67969 .22993 .68855 .24732 .70609 .23205 .69733 .21508 Mtetra
.764 .704 .796 r
.69733 .21508 .70609 .23205 .72365 .21701 .71499 .20045 Mtetra
.764 .71 .802 r
.71499 .20045 .72365 .21701 .74125 .20229 .7327 .18611 Mtetra
.762 .715 .808 r
.7327 .18611 .74125 .20229 .7589 .18794 .75045 .17212 Mtetra
.76 .721 .815 r
.75045 .17212 .7589 .18794 .7766 .17401 .76826 .15852 Mtetra
.46 .608 .91 r
.12066 .37046 .13089 .38307 .14469 .38427 .13452 .37123 Mtetra
.446 .594 .905 r
.13452 .37123 .14469 .38427 .15858 .3859 .14846 .3724 Mtetra
.435 .58 .899 r
.14846 .3724 .15858 .3859 .17256 .38794 .1625 .37394 Mtetra
.427 .567 .892 r
.1625 .37394 .17256 .38794 .18666 .39034 .17665 .37582 Mtetra
.421 .556 .885 r
.17665 .37582 .18666 .39034 .20088 .39304 .19092 .37798 Mtetra
.419 .547 .878 r
.19092 .37798 .20088 .39304 .21523 .39597 .20532 .38034 Mtetra
.421 .539 .87 r
.20532 .38034 .21523 .39597 .22973 .39904 .21987 .38283 Mtetra
.426 .533 .863 r
.21987 .38283 .22973 .39904 .2444 .40215 .23458 .38536 Mtetra
.435 .53 .856 r
.23458 .38536 .2444 .40215 .25923 .40521 .24945 .38782 Mtetra
.446 .528 .848 r
.24945 .38782 .25923 .40521 .27425 .40808 .26451 .39011 Mtetra
.46 .529 .841 r
.26451 .39011 .27425 .40808 .28947 .41065 .27975 .3921 Mtetra
.476 .531 .834 r
.27975 .3921 .28947 .41065 .30488 .41279 .29519 .39368 Mtetra
.494 .535 .827 r
.29519 .39368 .30488 .41279 .3205 .41437 .31083 .39473 Mtetra
.513 .54 .821 r
.31083 .39473 .3205 .41437 .33632 .41525 .32668 .39513 Mtetra
.532 .545 .814 r
.32668 .39513 .33632 .41525 .35235 .41533 .34272 .39476 Mtetra
.551 .552 .808 r
.34272 .39476 .35235 .41533 .36858 .41448 .35896 .39352 Mtetra
.57 .559 .802 r
.35896 .39352 .36858 .41448 .385 .41262 .37539 .39132 Mtetra
.589 .566 .797 r
.37539 .39132 .385 .41262 .4016 .40966 .392 .3881 Mtetra
.607 .574 .791 r
.392 .3881 .4016 .40966 .41837 .40554 .40878 .38379 Mtetra
.624 .582 .787 r
.40878 .38379 .41837 .40554 .43529 .40024 .42571 .37836 Mtetra
.64 .59 .782 r
.42571 .37836 .43529 .40024 .45235 .39373 .44278 .3718 Mtetra
.655 .598 .779 r
.44278 .3718 .45235 .39373 .46953 .38602 .45998 .36412 Mtetra
.668 .605 .775 r
.45998 .36412 .46953 .38602 .48682 .37716 .47727 .35535 Mtetra
.681 .613 .773 r
.47727 .35535 .48682 .37716 .50418 .36719 .49466 .34555 Mtetra
.693 .621 .771 r
.49466 .34555 .50418 .36719 .52161 .3562 .51212 .33478 Mtetra
.704 .628 .77 r
.51212 .33478 .52161 .3562 .53909 .34428 .52964 .32315 Mtetra
.714 .636 .769 r
.52964 .32315 .53909 .34428 .55661 .33155 .5472 .31075 Mtetra
.722 .643 .77 r
.5472 .31075 .55661 .33155 .57416 .31811 .56479 .29769 Mtetra
.73 .651 .77 r
.56479 .29769 .57416 .31811 .59172 .3041 .58241 .28409 Mtetra
.737 .658 .772 r
.58241 .28409 .59172 .3041 .6093 .28965 .60004 .27007 Mtetra
.743 .665 .775 r
.60004 .27007 .6093 .28965 .62688 .27489 .61769 .25576 Mtetra
.747 .672 .778 r
.61769 .25576 .62688 .27489 .64447 .25994 .63536 .24126 Mtetra
.751 .679 .782 r
.63536 .24126 .64447 .25994 .66207 .24491 .65304 .2267 Mtetra
.754 .686 .786 r
.65304 .2267 .66207 .24491 .67969 .22993 .67075 .21217 Mtetra
.756 .693 .791 r
.67075 .21217 .67969 .22993 .69733 .21508 .68848 .19776 Mtetra
.757 .699 .797 r
.68848 .19776 .69733 .21508 .71499 .20045 .70624 .18355 Mtetra
.757 .705 .803 r
.70624 .18355 .71499 .20045 .7327 .18611 .72405 .16961 Mtetra
.756 .711 .81 r
.72405 .16961 .7327 .18611 .75045 .17212 .74191 .156 Mtetra
.754 .716 .817 r
.74191 .156 .75045 .17212 .76826 .15852 .75983 .14275 Mtetra
.478 .614 .907 r
.11036 .35765 .12066 .37046 .13452 .37123 .12428 .35796 Mtetra
.466 .601 .902 r
.12428 .35796 .13452 .37123 .14846 .3724 .13828 .35866 Mtetra
.456 .588 .896 r
.13828 .35866 .14846 .3724 .1625 .37394 .15238 .35969 Mtetra
.448 .576 .889 r
.15238 .35969 .1625 .37394 .17665 .37582 .16658 .36104 Mtetra
.444 .565 .882 r
.16658 .36104 .17665 .37582 .19092 .37798 .18091 .36263 Mtetra
.442 .555 .875 r
.18091 .36263 .19092 .37798 .20532 .38034 .19536 .36441 Mtetra
.443 .547 .867 r
.19536 .36441 .20532 .38034 .21987 .38283 .20996 .36631 Mtetra
.447 .541 .86 r
.20996 .36631 .21987 .38283 .23458 .38536 .22471 .36824 Mtetra
.455 .537 .852 r
.22471 .36824 .23458 .38536 .24945 .38782 .23963 .37009 Mtetra
.465 .535 .845 r
.23963 .37009 .24945 .38782 .26451 .39011 .25472 .37178 Mtetra
.477 .535 .837 r
.25472 .37178 .26451 .39011 .27975 .3921 .27 .37319 Mtetra
.491 .536 .83 r
.27 .37319 .27975 .3921 .29519 .39368 .28547 .3742 Mtetra
.507 .538 .823 r
.28547 .3742 .29519 .39368 .31083 .39473 .30114 .37471 Mtetra
.523 .542 .817 r
.30114 .37471 .31083 .39473 .32668 .39513 .317 .37461 Mtetra
.54 .547 .81 r
.317 .37461 .32668 .39513 .34272 .39476 .33306 .37379 Mtetra
.557 .552 .804 r
.33306 .37379 .34272 .39476 .35896 .39352 .34931 .37215 Mtetra
.575 .558 .798 r
.34931 .37215 .35896 .39352 .37539 .39132 .36575 .36962 Mtetra
.591 .565 .793 r
.36575 .36962 .37539 .39132 .392 .3881 .38237 .36613 Mtetra
.608 .572 .788 r
.38237 .36613 .392 .3881 .40878 .38379 .39915 .36162 Mtetra
.623 .579 .784 r
.39915 .36162 .40878 .38379 .42571 .37836 .41609 .35606 Mtetra
.638 .586 .78 r
.41609 .35606 .42571 .37836 .44278 .3718 .43318 .34946 Mtetra
.652 .594 .776 r
.43318 .34946 .44278 .3718 .45998 .36412 .45038 .3418 Mtetra
.665 .601 .774 r
.45038 .3418 .45998 .36412 .47727 .35535 .46769 .33314 Mtetra
.677 .609 .771 r
.46769 .33314 .47727 .35535 .49466 .34555 .4851 .32351 Mtetra
.688 .616 .77 r
.4851 .32351 .49466 .34555 .51212 .33478 .50258 .31298 Mtetra
.699 .624 .769 r
.50258 .31298 .51212 .33478 .52964 .32315 .52013 .30164 Mtetra
.708 .631 .769 r
.52013 .30164 .52964 .32315 .5472 .31075 .53772 .28958 Mtetra
.716 .638 .77 r
.53772 .28958 .5472 .31075 .56479 .29769 .55536 .2769 Mtetra
.724 .646 .771 r
.55536 .2769 .56479 .29769 .58241 .28409 .57303 .26373 Mtetra
.73 .653 .773 r
.57303 .26373 .58241 .28409 .60004 .27007 .59072 .25015 Mtetra
.736 .66 .775 r
.59072 .25015 .60004 .27007 .61769 .25576 .60844 .2363 Mtetra
.741 .668 .779 r
.60844 .2363 .61769 .25576 .63536 .24126 .62618 .22228 Mtetra
.744 .675 .783 r
.62618 .22228 .63536 .24126 .65304 .2267 .64394 .20819 Mtetra
.747 .682 .788 r
.64394 .20819 .65304 .2267 .67075 .21217 .66173 .19412 Mtetra
.749 .688 .793 r
.66173 .19412 .67075 .21217 .68848 .19776 .67955 .18016 Mtetra
.75 .695 .799 r
.67955 .18016 .68848 .19776 .70624 .18355 .69741 .16639 Mtetra
.75 .701 .805 r
.69741 .16639 .70624 .18355 .72405 .16961 .71532 .15286 Mtetra
.75 .707 .812 r
.71532 .15286 .72405 .16961 .74191 .156 .73328 .13964 Mtetra
.748 .712 .818 r
.73328 .13964 .74191 .156 .75983 .14275 .75131 .12675 Mtetra
.495 .621 .905 r
.09997 .34467 .11036 .35765 .12428 .35796 .11395 .34453 Mtetra
.485 .608 .899 r
.11395 .34453 .12428 .35796 .13828 .35866 .12802 .34473 Mtetra
.476 .596 .894 r
.12802 .34473 .13828 .35866 .15238 .35969 .14218 .34525 Mtetra
.469 .584 .887 r
.14218 .34525 .15238 .35969 .16658 .36104 .15645 .34605 Mtetra
.464 .574 .88 r
.15645 .34605 .16658 .36104 .18091 .36263 .17083 .34708 Mtetra
.462 .564 .873 r
.17083 .34708 .18091 .36263 .19536 .36441 .18534 .34828 Mtetra
.463 .556 .865 r
.18534 .34828 .19536 .36441 .20996 .36631 .19999 .34957 Mtetra
.467 .55 .857 r
.19999 .34957 .20996 .36631 .22471 .36824 .21479 .35088 Mtetra
.473 .545 .85 r
.21479 .35088 .22471 .36824 .23963 .37009 .22976 .35213 Mtetra
.482 .542 .842 r
.22976 .35213 .23963 .37009 .25472 .37178 .24489 .35321 Mtetra
.492 .541 .835 r
.24489 .35321 .25472 .37178 .27 .37319 .2602 .35402 Mtetra
.505 .541 .827 r
.2602 .35402 .27 .37319 .28547 .3742 .27571 .35447 Mtetra
.518 .543 .82 r
.27571 .35447 .28547 .3742 .30114 .37471 .2914 .35444 Mtetra
.533 .545 .814 r
.2914 .35444 .30114 .37471 .317 .37461 .30728 .35383 Mtetra
.548 .549 .807 r
.30728 .35383 .317 .37461 .33306 .37379 .32336 .35255 Mtetra
.564 .554 .801 r
.32336 .35255 .33306 .37379 .34931 .37215 .33962 .35052 Mtetra
.579 .559 .796 r
.33962 .35052 .34931 .37215 .36575 .36962 .35608 .34765 Mtetra
.594 .565 .791 r
.35608 .34765 .36575 .36962 .38237 .36613 .3727 .34389 Mtetra
.609 .571 .786 r
.3727 .34389 .38237 .36613 .39915 .36162 .3895 .33919 Mtetra
.623 .577 .782 r
.3895 .33919 .39915 .36162 .41609 .35606 .40644 .33351 Mtetra
.637 .584 .778 r
.40644 .33351 .41609 .35606 .43318 .34946 .42353 .32686 Mtetra
.65 .591 .775 r
.42353 .32686 .43318 .34946 .45038 .3418 .44074 .31924 Mtetra
.662 .598 .773 r
.44074 .31924 .45038 .3418 .46769 .33314 .45807 .31067 Mtetra
.674 .606 .771 r
.45807 .31067 .46769 .33314 .4851 .32351 .47549 .30122 Mtetra
.684 .613 .77 r
.47549 .30122 .4851 .32351 .50258 .31298 .49299 .29093 Mtetra
.694 .62 .77 r
.49299 .29093 .50258 .31298 .52013 .30164 .51057 .27988 Mtetra
.703 .627 .77 r
.51057 .27988 .52013 .30164 .53772 .28958 .5282 .26817 Mtetra
.711 .635 .771 r
.5282 .26817 .53772 .28958 .55536 .2769 .54587 .25589 Mtetra
.718 .642 .772 r
.54587 .25589 .55536 .2769 .57303 .26373 .56359 .24313 Mtetra
.724 .65 .774 r
.56359 .24313 .57303 .26373 .59072 .25015 .58134 .23001 Mtetra
.73 .657 .777 r
.58134 .23001 .59072 .25015 .60844 .2363 .59912 .21663 Mtetra
.734 .664 .781 r
.59912 .21663 .60844 .2363 .62618 .22228 .61693 .20308 Mtetra
.738 .671 .785 r
.61693 .20308 .62618 .22228 .64394 .20819 .63477 .18946 Mtetra
.741 .678 .79 r
.63477 .18946 .64394 .20819 .66173 .19412 .65264 .17586 Mtetra
.743 .685 .795 r
.65264 .17586 .66173 .19412 .67955 .18016 .67055 .16236 Mtetra
.744 .692 .801 r
.67055 .16236 .67955 .18016 .69741 .16639 .6885 .14903 Mtetra
.744 .698 .807 r
.6885 .14903 .69741 .16639 .71532 .15286 .70651 .13592 Mtetra
.743 .704 .814 r
.70651 .13592 .71532 .15286 .73328 .13964 .72457 .12308 Mtetra
.742 .709 .821 r
.72457 .12308 .73328 .13964 .75131 .12675 .74271 .11056 Mtetra
.511 .628 .902 r
.0895 .33155 .09997 .34467 .11395 .34453 .10354 .33096 Mtetra
.502 .616 .897 r
.10354 .33096 .11395 .34453 .12802 .34473 .11768 .33067 Mtetra
.494 .604 .892 r
.11768 .33067 .12802 .34473 .14218 .34525 .1319 .33068 Mtetra
.487 .593 .885 r
.1319 .33068 .14218 .34525 .15645 .34605 .14623 .33093 Mtetra
.483 .583 .878 r
.14623 .33093 .15645 .34605 .17083 .34708 .16068 .33139 Mtetra
.481 .573 .871 r
.16068 .33139 .17083 .34708 .18534 .34828 .17525 .33199 Mtetra
.482 .565 .864 r
.17525 .33199 .18534 .34828 .19999 .34957 .18995 .33269 Mtetra
.485 .559 .856 r
.18995 .33269 .19999 .34957 .21479 .35088 .20481 .33339 Mtetra
.49 .554 .848 r
.20481 .33339 .21479 .35088 .22976 .35213 .21982 .33402 Mtetra
.497 .55 .841 r
.21982 .33402 .22976 .35213 .24489 .35321 .235 .3345 Mtetra
.507 .548 .833 r
.235 .3345 .24489 .35321 .2602 .35402 .25035 .33472 Mtetra
.517 .548 .826 r
.25035 .33472 .2602 .35402 .27571 .35447 .26589 .33459 Mtetra
.529 .548 .819 r
.26589 .33459 .27571 .35447 .2914 .35444 .28161 .33403 Mtetra
.542 .55 .812 r
.28161 .33403 .2914 .35444 .30728 .35383 .29752 .33292 Mtetra
.556 .553 .806 r
.29752 .33292 .30728 .35383 .32336 .35255 .31361 .3312 Mtetra
.569 .557 .8 r
.31361 .3312 .32336 .35255 .33962 .35052 .3299 .32877 Mtetra
.583 .561 .795 r
.3299 .32877 .33962 .35052 .35608 .34765 .34636 .32557 Mtetra
.597 .566 .79 r
.34636 .32557 .35608 .34765 .3727 .34389 .36299 .32154 Mtetra
.611 .572 .786 r
.36299 .32154 .3727 .34389 .3895 .33919 .37979 .31664 Mtetra
.624 .578 .782 r
.37979 .31664 .3895 .33919 .40644 .33351 .39675 .31085 Mtetra
.637 .584 .778 r
.39675 .31085 .40644 .33351 .42353 .32686 .41384 .30415 Mtetra
.649 .59 .776 r
.41384 .30415 .42353 .32686 .44074 .31924 .43107 .29656 Mtetra
.66 .597 .774 r
.43107 .29656 .44074 .31924 .45807 .31067 .4484 .2881 Mtetra
.671 .604 .772 r
.4484 .2881 .45807 .31067 .47549 .30122 .46584 .27882 Mtetra
.681 .611 .771 r
.46584 .27882 .47549 .30122 .49299 .29093 .48336 .26876 Mtetra
.69 .618 .771 r
.48336 .26876 .49299 .29093 .51057 .27988 .50096 .25801 Mtetra
.698 .625 .771 r
.50096 .25801 .51057 .27988 .5282 .26817 .51862 .24665 Mtetra
.706 .632 .773 r
.51862 .24665 .5282 .26817 .54587 .25589 .53633 .23475 Mtetra
.713 .64 .774 r
.53633 .23475 .54587 .25589 .56359 .24313 .55409 .22242 Mtetra
.719 .647 .777 r
.55409 .22242 .56359 .24313 .58134 .23001 .5719 .20974 Mtetra
.724 .654 .78 r
.5719 .20974 .58134 .23001 .59912 .21663 .58974 .19682 Mtetra
.728 .661 .784 r
.58974 .19682 .59912 .21663 .61693 .20308 .60761 .18374 Mtetra
.732 .669 .788 r
.60761 .18374 .61693 .20308 .63477 .18946 .62552 .1706 Mtetra
.735 .676 .793 r
.62552 .1706 .63477 .18946 .65264 .17586 .64348 .15747 Mtetra
.737 .682 .798 r
.64348 .15747 .65264 .17586 .67055 .16236 .66147 .14442 Mtetra
.738 .689 .804 r
.66147 .14442 .67055 .16236 .6885 .14903 .67952 .13153 Mtetra
.738 .695 .81 r
.67952 .13153 .6885 .14903 .70651 .13592 .69762 .11883 Mtetra
.737 .702 .817 r
.69762 .11883 .70651 .13592 .72457 .12308 .71579 .10639 Mtetra
.736 .707 .824 r
.71579 .10639 .72457 .12308 .74271 .11056 .73402 .09422 Mtetra
.526 .635 .9 r
.07893 .31835 .0895 .33155 .10354 .33096 .09304 .31729 Mtetra
.518 .623 .896 r
.09304 .31729 .10354 .33096 .11768 .33067 .10724 .31652 Mtetra
.51 .612 .89 r
.10724 .31652 .11768 .33067 .1319 .33068 .12154 .31601 Mtetra
.505 .602 .884 r
.12154 .31601 .1319 .33068 .14623 .33093 .13593 .31572 Mtetra
.501 .592 .877 r
.13593 .31572 .14623 .33093 .16068 .33139 .15044 .31562 Mtetra
.499 .583 .87 r
.15044 .31562 .16068 .33139 .17525 .33199 .16508 .31564 Mtetra
.499 .575 .863 r
.16508 .31564 .17525 .33199 .18995 .33269 .17984 .31574 Mtetra
.501 .568 .855 r
.17984 .31574 .18995 .33269 .20481 .33339 .19475 .31584 Mtetra
.506 .563 .848 r
.19475 .31584 .20481 .33339 .21982 .33402 .20982 .31587 Mtetra
.512 .559 .84 r
.20982 .31587 .21982 .33402 .235 .3345 .22504 .31574 Mtetra
.52 .556 .833 r
.22504 .31574 .235 .3345 .25035 .33472 .24044 .31538 Mtetra
.529 .555 .826 r
.24044 .31538 .25035 .33472 .26589 .33459 .25601 .31469 Mtetra
.54 .555 .819 r
.25601 .31469 .26589 .33459 .28161 .33403 .27176 .3136 Mtetra
.551 .556 .812 r
.27176 .3136 .28161 .33403 .29752 .33292 .2877 .312 Mtetra
.563 .558 .806 r
.2877 .312 .29752 .33292 .31361 .3312 .30382 .30983 Mtetra
.575 .561 .8 r
.30382 .30983 .31361 .3312 .3299 .32877 .32012 .30701 Mtetra
.588 .564 .795 r
.32012 .30701 .3299 .32877 .34636 .32557 .33659 .30349 Mtetra
.6 .569 .79 r
.33659 .30349 .34636 .32557 .36299 .32154 .35324 .2992 Mtetra
.613 .574 .786 r
.35324 .2992 .36299 .32154 .37979 .31664 .37005 .29411 Mtetra
.625 .579 .783 r
.37005 .29411 .37979 .31664 .39675 .31085 .38701 .2882 Mtetra
.636 .585 .78 r
.38701 .2882 .39675 .31085 .41384 .30415 .40411 .28146 Mtetra
.647 .591 .777 r
.40411 .28146 .41384 .30415 .43107 .29656 .42134 .2739 Mtetra
.658 .597 .775 r
.42134 .2739 .43107 .29656 .4484 .2881 .43869 .26554 Mtetra
.668 .604 .774 r
.43869 .26554 .4484 .2881 .46584 .27882 .45614 .25643 Mtetra
.677 .61 .773 r
.45614 .25643 .46584 .27882 .48336 .26876 .47368 .24661 Mtetra
.686 .617 .773 r
.47368 .24661 .48336 .26876 .50096 .25801 .4913 .23615 Mtetra
.694 .624 .774 r
.4913 .23615 .50096 .25801 .51862 .24665 .50899 .22512 Mtetra
.701 .631 .775 r
.50899 .22512 .51862 .24665 .53633 .23475 .52674 .2136 Mtetra
.708 .638 .777 r
.52674 .2136 .53633 .23475 .55409 .22242 .54454 .20168 Mtetra
.714 .646 .78 r
.54454 .20168 .55409 .22242 .5719 .20974 .56239 .18944 Mtetra
.719 .653 .783 r
.56239 .18944 .5719 .20974 .58974 .19682 .58029 .17698 Mtetra
.723 .66 .787 r
.58029 .17698 .58974 .19682 .60761 .18374 .59823 .16436 Mtetra
.726 .667 .792 r
.59823 .16436 .60761 .18374 .62552 .1706 .61621 .15168 Mtetra
.729 .674 .796 r
.61621 .15168 .62552 .1706 .64348 .15747 .63424 .13901 Mtetra
.731 .681 .802 r
.63424 .13901 .64348 .15747 .66147 .14442 .65232 .12641 Mtetra
.732 .688 .808 r
.65232 .12641 .66147 .14442 .67952 .13153 .67046 .11394 Mtetra
.732 .694 .814 r
.67046 .11394 .67952 .13153 .69762 .11883 .68865 .10165 Mtetra
.732 .7 .82 r
.68865 .10165 .69762 .11883 .71579 .10639 .70692 .08959 Mtetra
.731 .706 .827 r
.70692 .08959 .71579 .10639 .73402 .09422 .72526 .07777 Mtetra
.54 .642 .899 r
.06825 .30508 .07893 .31835 .09304 .31729 .08244 .30357 Mtetra
.532 .631 .894 r
.08244 .30357 .09304 .31729 .10724 .31652 .09671 .30232 Mtetra
.526 .621 .889 r
.09671 .30232 .10724 .31652 .12154 .31601 .11108 .3013 Mtetra
.52 .61 .883 r
.11108 .3013 .12154 .31601 .13593 .31572 .12555 .30048 Mtetra
.517 .601 .876 r
.12555 .30048 .13593 .31572 .15044 .31562 .14012 .29982 Mtetra
.515 .592 .87 r
.14012 .29982 .15044 .31562 .16508 .31564 .15482 .29928 Mtetra
.515 .584 .863 r
.15482 .29928 .16508 .31564 .17984 .31574 .16965 .29879 Mtetra
.517 .577 .855 r
.16965 .29879 .17984 .31574 .19475 .31584 .18462 .2983 Mtetra
.52 .572 .848 r
.18462 .2983 .19475 .31584 .20982 .31587 .19974 .29773 Mtetra
.525 .567 .84 r
.19974 .29773 .20982 .31587 .22504 .31574 .21501 .29702 Mtetra
.532 .564 .833 r
.21501 .29702 .22504 .31574 .24044 .31538 .23045 .29609 Mtetra
.54 .562 .826 r
.23045 .29609 .24044 .31538 .25601 .31469 .24606 .29486 Mtetra
.549 .562 .82 r
.24606 .29486 .25601 .31469 .27176 .3136 .26185 .29324 Mtetra
.559 .562 .813 r
.26185 .29324 .27176 .3136 .2877 .312 .27781 .29117 Mtetra
.57 .563 .807 r
.27781 .29117 .2877 .312 .30382 .30983 .29396 .28857 Mtetra
.581 .566 .802 r
.29396 .28857 .30382 .30983 .32012 .30701 .31028 .28538 Mtetra
.592 .569 .797 r
.31028 .28538 .32012 .30701 .33659 .30349 .32677 .28153 Mtetra
.604 .573 .792 r
.32677 .28153 .33659 .30349 .35324 .2992 .34343 .27698 Mtetra
.615 .577 .788 r
.34343 .27698 .35324 .2992 .37005 .29411 .36024 .27171 Mtetra
.626 .582 .785 r
.36024 .27171 .37005 .29411 .38701 .2882 .37721 .26568 Mtetra
.636 .587 .782 r
.37721 .26568 .38701 .2882 .40411 .28146 .39432 .2589 Mtetra
.647 .593 .78 r
.39432 .2589 .40411 .28146 .42134 .2739 .41156 .25137 Mtetra
.657 .598 .778 r
.41156 .25137 .42134 .2739 .43869 .26554 .42892 .24311 Mtetra
.666 .605 .777 r
.42892 .24311 .43869 .26554 .45614 .25643 .44638 .23416 Mtetra
.675 .611 .776 r
.44638 .23416 .45614 .25643 .47368 .24661 .46394 .22456 Mtetra
.683 .618 .777 r
.46394 .22456 .47368 .24661 .4913 .23615 .48158 .21438 Mtetra
.69 .624 .778 r
.48158 .21438 .4913 .23615 .50899 .22512 .4993 .20368 Mtetra
.697 .631 .779 r
.4993 .20368 .50899 .22512 .52674 .2136 .51709 .19253 Mtetra
.703 .638 .781 r
.51709 .19253 .52674 .2136 .54454 .20168 .53493 .18101 Mtetra
.709 .645 .784 r
.53493 .18101 .54454 .20168 .56239 .18944 .55283 .1692 Mtetra
.714 .652 .787 r
.55283 .1692 .56239 .18944 .58029 .17698 .57078 .15717 Mtetra
.718 .66 .791 r
.57078 .15717 .58029 .17698 .59823 .16436 .58878 .145 Mtetra
.721 .667 .796 r
.58878 .145 .59823 .16436 .61621 .15168 .60684 .13277 Mtetra
.724 .673 .801 r
.60684 .13277 .61621 .15168 .63424 .13901 .62494 .12054 Mtetra
.725 .68 .806 r
.62494 .12054 .63424 .13901 .65232 .12641 .6431 .10837 Mtetra
.726 .687 .812 r
.6431 .10837 .65232 .12641 .67046 .11394 .66133 .09632 Mtetra
.727 .693 .818 r
.66133 .09632 .67046 .11394 .68865 .10165 .67961 .08442 Mtetra
.726 .699 .824 r
.67961 .08442 .68865 .10165 .70692 .08959 .69798 .07272 Mtetra
.725 .705 .831 r
.69798 .07272 .70692 .08959 .72526 .07777 .71642 .06125 Mtetra
.553 .648 .898 r
.05748 .29177 .06825 .30508 .08244 .30357 .07174 .28983 Mtetra
.546 .639 .893 r
.07174 .28983 .08244 .30357 .09671 .30232 .08608 .28811 Mtetra
.54 .629 .888 r
.08608 .28811 .09671 .30232 .11108 .3013 .10052 .2866 Mtetra
.535 .619 .882 r
.10052 .2866 .11108 .3013 .12555 .30048 .11506 .28526 Mtetra
.532 .61 .876 r
.11506 .28526 .12555 .30048 .14012 .29982 .1297 .28406 Mtetra
.53 .601 .87 r
.1297 .28406 .14012 .29982 .15482 .29928 .14447 .28295 Mtetra
.529 .594 .863 r
.14447 .28295 .15482 .29928 .16965 .29879 .15936 .2819 Mtetra
.531 .587 .856 r
.15936 .2819 .16965 .29879 .18462 .2983 .17439 .28083 Mtetra
.534 .581 .849 r
.17439 .28083 .18462 .2983 .19974 .29773 .18957 .2797 Mtetra
.538 .577 .842 r
.18957 .2797 .19974 .29773 .21501 .29702 .20489 .27842 Mtetra
.544 .573 .835 r
.20489 .27842 .21501 .29702 .23045 .29609 .22038 .27694 Mtetra
.551 .571 .828 r
.22038 .27694 .23045 .29609 .24606 .29486 .23603 .27517 Mtetra
.559 .57 .821 r
.23603 .27517 .24606 .29486 .26185 .29324 .25186 .27306 Mtetra
.567 .569 .815 r
.25186 .27306 .26185 .29324 .27781 .29117 .26785 .27052 Mtetra
.577 .57 .809 r
.26785 .27052 .27781 .29117 .29396 .28857 .28402 .26751 Mtetra
.587 .572 .804 r
.28402 .26751 .29396 .28857 .31028 .28538 .30036 .26394 Mtetra
.597 .574 .799 r
.30036 .26394 .31028 .28538 .32677 .28153 .31687 .25979 Mtetra
.607 .577 .795 r
.31687 .25979 .32677 .28153 .34343 .27698 .33355 .255 Mtetra
.617 .581 .791 r
.33355 .255 .34343 .27698 .36024 .27171 .35038 .24954 Mtetra
.627 .585 .788 r
.35038 .24954 .36024 .27171 .37721 .26568 .36736 .24341 Mtetra
.637 .59 .785 r
.36736 .24341 .37721 .26568 .39432 .2589 .38448 .23658 Mtetra
.646 .595 .783 r
.38448 .23658 .39432 .2589 .41156 .25137 .40172 .22907 Mtetra
.656 .601 .781 r
.40172 .22907 .41156 .25137 .42892 .24311 .41909 .22091 Mtetra
.664 .607 .781 r
.41909 .22091 .42892 .24311 .44638 .23416 .43657 .21211 Mtetra
.672 .613 .78 r
.43657 .21211 .44638 .23416 .46394 .22456 .45415 .20273 Mtetra
.68 .619 .781 r
.45415 .20273 .46394 .22456 .48158 .21438 .47181 .19281 Mtetra
.687 .626 .782 r
.47181 .19281 .48158 .21438 .4993 .20368 .48956 .18242 Mtetra
.694 .632 .784 r
.48956 .18242 .4993 .20368 .51709 .19253 .50738 .17162 Mtetra
.699 .639 .786 r
.50738 .17162 .51709 .19253 .53493 .18101 .52526 .16048 Mtetra
.705 .646 .789 r
.52526 .16048 .53493 .18101 .55283 .1692 .54321 .14907 Mtetra
.709 .653 .792 r
.54321 .14907 .55283 .1692 .57078 .15717 .56121 .13746 Mtetra
.713 .66 .796 r
.56121 .13746 .57078 .15717 .58878 .145 .57927 .12572 Mtetra
.716 .667 .8 r
.57927 .12572 .58878 .145 .60684 .13277 .59739 .11392 Mtetra
.718 .674 .805 r
.59739 .11392 .60684 .13277 .62494 .12054 .61557 .10212 Mtetra
.72 .68 .811 r
.61557 .10212 .62494 .12054 .6431 .10837 .63381 .09036 Mtetra
.721 .687 .816 r
.63381 .09036 .6431 .10837 .66133 .09632 .65212 .0787 Mtetra
.721 .693 .822 r
.65212 .0787 .66133 .09632 .67961 .08442 .6705 .06718 Mtetra
.721 .699 .829 r
.6705 .06718 .67961 .08442 .69798 .07272 .68895 .05583 Mtetra
.72 .704 .835 r
.68895 .05583 .69798 .07272 .71642 .06125 .70749 .04468 Mtetra
.565 .655 .897 r
.04658 .27846 .05748 .29177 .07174 .28983 .06092 .27609 Mtetra
.559 .646 .893 r
.06092 .27609 .07174 .28983 .08608 .28811 .07534 .27392 Mtetra
.553 .637 .888 r
.07534 .27392 .08608 .28811 .10052 .2866 .08985 .27192 Mtetra
.549 .628 .882 r
.08985 .27192 .10052 .2866 .11506 .28526 .10446 .27008 Mtetra
.545 .619 .877 r
.10446 .27008 .11506 .28526 .1297 .28406 .11918 .26836 Mtetra
.544 .611 .87 r
.11918 .26836 .1297 .28406 .14447 .28295 .13401 .26672 Mtetra
.543 .603 .864 r
.13401 .26672 .14447 .28295 .15936 .2819 .14897 .26512 Mtetra
.544 .597 .857 r
.14897 .26512 .15936 .2819 .17439 .28083 .16406 .2635 Mtetra
.546 .591 .85 r
.16406 .2635 .17439 .28083 .18957 .2797 .1793 .26181 Mtetra
.55 .586 .843 r
.1793 .26181 .18957 .2797 .20489 .27842 .19468 .25999 Mtetra
.555 .582 .837 r
.19468 .25999 .20489 .27842 .22038 .27694 .21022 .25798 Mtetra
.56 .58 .83 r
.21022 .25798 .22038 .27694 .23603 .27517 .22592 .25571 Mtetra
.567 .578 .824 r
.22592 .25571 .23603 .27517 .25186 .27306 .24178 .25311 Mtetra
.575 .577 .818 r
.24178 .25311 .25186 .27306 .26785 .27052 .25781 .25014 Mtetra
.583 .578 .812 r
.25781 .25014 .26785 .27052 .28402 .26751 .27401 .24672 Mtetra
.592 .579 .807 r
.27401 .24672 .28402 .26751 .30036 .26394 .29037 .2428 Mtetra
.601 .581 .802 r
.29037 .2428 .30036 .26394 .31687 .25979 .3069 .23835 Mtetra
.61 .583 .798 r
.3069 .23835 .31687 .25979 .33355 .255 .32359 .23332 Mtetra
.62 .586 .795 r
.32359 .23332 .33355 .255 .35038 .24954 .34044 .22769 Mtetra
.629 .59 .792 r
.34044 .22769 .35038 .24954 .36736 .24341 .35743 .22145 Mtetra
.638 .595 .789 r
.35743 .22145 .36736 .24341 .38448 .23658 .37456 .21458 Mtetra
.646 .599 .787 r
.37456 .21458 .38448 .23658 .40172 .22907 .39182 .20709 Mtetra
.655 .605 .786 r
.39182 .20709 .40172 .22907 .41909 .22091 .4092 .19901 Mtetra
.663 .61 .785 r
.4092 .19901 .41909 .22091 .43657 .21211 .42669 .19036 Mtetra
.67 .616 .785 r
.42669 .19036 .43657 .21211 .45415 .20273 .44429 .18117 Mtetra
.678 .622 .786 r
.44429 .18117 .45415 .20273 .47181 .19281 .46198 .17151 Mtetra
.684 .628 .787 r
.46198 .17151 .47181 .19281 .48956 .18242 .47975 .16141 Mtetra
.69 .635 .789 r
.47975 .16141 .48956 .18242 .50738 .17162 .4976 .15094 Mtetra
.696 .641 .791 r
.4976 .15094 .50738 .17162 .52526 .16048 .51552 .14015 Mtetra
.701 .648 .794 r
.51552 .14015 .52526 .16048 .54321 .14907 .53352 .12913 Mtetra
.705 .655 .797 r
.53352 .12913 .54321 .14907 .56121 .13746 .55157 .11791 Mtetra
.708 .661 .801 r
.55157 .11791 .56121 .13746 .57927 .12572 .56969 .10658 Mtetra
.711 .668 .806 r
.56969 .10658 .57927 .12572 .59739 .11392 .58788 .09518 Mtetra
.713 .675 .811 r
.58788 .09518 .59739 .11392 .61557 .10212 .60613 .08378 Mtetra
.715 .681 .816 r
.60613 .08378 .61557 .10212 .63381 .09036 .62445 .07241 Mtetra
.716 .687 .821 r
.62445 .07241 .63381 .09036 .65212 .0787 .64284 .06112 Mtetra
.716 .693 .827 r
.64284 .06112 .65212 .0787 .6705 .06718 .66131 .04996 Mtetra
.716 .699 .833 r
.66131 .04996 .6705 .06718 .68895 .05583 .67985 .03894 Mtetra
.715 .704 .839 r
.67985 .03894 .68895 .05583 .70749 .04468 .69849 .0281 Mtetra
.576 .662 .896 r
.03557 .26515 .04658 .27846 .06092 .27609 .04998 .26237 Mtetra
.57 .653 .892 r
.04998 .26237 .06092 .27609 .07534 .27392 .06447 .25976 Mtetra
.565 .645 .888 r
.06447 .25976 .07534 .27392 .08985 .27192 .07906 .25731 Mtetra
.561 .636 .883 r
.07906 .25731 .08985 .27192 .10446 .27008 .09374 .25499 Mtetra
.558 .628 .877 r
.09374 .25499 .10446 .27008 .11918 .26836 .10853 .25277 Mtetra
.556 .62 .871 r
.10853 .25277 .11918 .26836 .13401 .26672 .12344 .25062 Mtetra
.556 .613 .865 r
.12344 .25062 .13401 .26672 .14897 .26512 .13847 .2485 Mtetra
.556 .607 .859 r
.13847 .2485 .14897 .26512 .16406 .2635 .15362 .24635 Mtetra
.558 .601 .852 r
.15362 .24635 .16406 .2635 .1793 .26181 .16892 .24413 Mtetra
.561 .596 .846 r
.16892 .24413 .1793 .26181 .19468 .25999 .18436 .24179 Mtetra
.565 .592 .839 r
.18436 .24179 .19468 .25999 .21022 .25798 .19995 .23927 Mtetra
.57 .589 .833 r
.19995 .23927 .21022 .25798 .22592 .25571 .21569 .23652 Mtetra
.576 .587 .827 r
.21569 .23652 .22592 .25571 .24178 .25311 .2316 .23347 Mtetra
.583 .586 .821 r
.2316 .23347 .24178 .25311 .25781 .25014 .24767 .23006 Mtetra
.59 .586 .816 r
.24767 .23006 .25781 .25014 .27401 .24672 .2639 .22626 Mtetra
.598 .586 .811 r
.2639 .22626 .27401 .24672 .29037 .2428 .28029 .22202 Mtetra
.606 .588 .807 r
.28029 .22202 .29037 .2428 .3069 .23835 .29684 .21728 Mtetra
.614 .59 .803 r
.29684 .21728 .3069 .23835 .32359 .23332 .31355 .21203 Mtetra
.622 .593 .799 r
.31355 .21203 .32359 .23332 .34044 .22769 .33041 .20623 Mtetra
.631 .596 .796 r
.33041 .20623 .34044 .22769 .35743 .22145 .34742 .19987 Mtetra
.639 .6 .794 r
.34742 .19987 .35743 .22145 .37456 .21458 .36456 .19296 Mtetra
.647 .604 .792 r
.36456 .19296 .37456 .21458 .39182 .20709 .38184 .18549 Mtetra
.655 .609 .791 r
.38184 .18549 .39182 .20709 .4092 .19901 .39924 .17748 Mtetra
.662 .614 .791 r
.39924 .17748 .4092 .19901 .42669 .19036 .41675 .16896 Mtetra
.669 .62 .791 r
.41675 .16896 .42669 .19036 .44429 .18117 .43436 .15996 Mtetra
.676 .625 .791 r
.43436 .15996 .44429 .18117 .46198 .17151 .45207 .15052 Mtetra
.682 .631 .793 r
.45207 .15052 .46198 .17151 .47975 .16141 .46987 .1407 Mtetra
.687 .638 .794 r
.46987 .1407 .47975 .16141 .4976 .15094 .48776 .13053 Mtetra
.692 .644 .797 r
.48776 .13053 .4976 .15094 .51552 .14015 .50572 .12008 Mtetra
.697 .65 .8 r
.50572 .12008 .51552 .14015 .53352 .12913 .52376 .10941 Mtetra
.701 .657 .803 r
.52376 .10941 .53352 .12913 .55157 .11791 .54187 .09857 Mtetra
.704 .663 .807 r
.54187 .09857 .55157 .11791 .56969 .10658 .56004 .08761 Mtetra
.707 .67 .811 r
.56004 .08761 .56969 .10658 .58788 .09518 .57829 .07659 Mtetra
.709 .676 .816 r
.57829 .07659 .58788 .09518 .60613 .08378 .59661 .06556 Mtetra
.71 .682 .821 r
.59661 .06556 .60613 .08378 .62445 .07241 .61501 .05455 Mtetra
.711 .689 .827 r
.61501 .05455 .62445 .07241 .64284 .06112 .63348 .04362 Mtetra
.711 .694 .832 r
.63348 .04362 .64284 .06112 .66131 .04996 .65203 .03278 Mtetra
.711 .7 .838 r
.65203 .03278 .66131 .04996 .67985 .03894 .67067 .02207 Mtetra
.71 .705 .844 r
.67067 .02207 .67985 .03894 .69849 .0281 .6894 .01151 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonDo`0003?oooooU?l0000Kooooo`006_oo
ool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool2o`00
01;ooooo0P00000Eooooo`8000008_ooool4o`0001?ooooo0_l0000Aooooo`;o00002oooool00ol0
003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0900000003o`00000I6AT06ATI01006ATI0P00000Coc<c<`@0
0000:01<C4`3o`000180<c<c0_l0000A01TI6@03o`0000000000000000D000000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0800000003o`00000I6AT06ATI00l06ATI0P00000Aoc<c<`@00000
;`1<C4`2o`000180<c<c00?o000001TI6@0I6AT03`0I6AT00ol00000000000000004000000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01`0000000ol000006ATI01TI6@0?01TI6@0300000?lc
<c?o<c<c00ko<c<c0`00000e04a<C0?o0000400c<c<00ol000006ATI01TI6@0?01TI6@03o`000000
0000000000<000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=
o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0700000003o`00000I6AT0
6ATI00h06ATI00<00000oc<c<olc<c<03_lc<c<00`000000C4a<04a<C00i04a<C0;o00003`0c<c<0
0ol000006ATI01TI6@0>01TI6@03o`0000000000000000<000000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0600000003o`00000I6AT06ATI00h06ATI00<00000oc<c<olc<c<03Olc<c<20000
01X0C4a<3000000H04a<C0;o00003P0c<c<2o`0000l06ATI00?o00000000000000000P000003oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00D0000000?o000001TI6@0I6AT03P0I6AT00`00003o
<c<coc<c<`0<oc<c<`8000005@1<C4`7000000`0IVIV1P00000D04a<C003o`00000c<c<0<c<c00d0
<c<c00?o000001TI6@0I6AT03@0I6AT01?l000000000000000000003ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00@0000000?o000001TI6@0I6AT03@0I6AT00`00003o0000oc<c<`0<oc<c<`80
00004`1<C4`01000003o0000o`000000000I06IVIPD00000401<C4`2o`0000h0<c<c00?o000001TI
6@0I6AT03@0I6AT00ol00000000000000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00<0
00000_l0000>01TI6@0300000?lc<c?o<c<c00_o<c<c0P00000B04a<C0<000008P1VIVH200000100
C4a<0_l0000=03<c<`;o00003P0I6AT00ol000000000ooooo`02ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo0080000000?o000001TI6@0I6AT03@0I6AT00`00003o<c<coc<c<`0;oc<c<`030000
001<C4`0C4a<00h0C4a<1000000W06IVIP800000401<C4`00ol00000<c<c03<c<`0<03<c<`03o`00
000I6AT06ATI00`06ATI00Go0000ooooooooooooooooo`00000Kooooo`006_ooool00ol0003ooooo
ooooo`0lo`00000300000?l00000000001000000?_l00003ooooo`03o`000?oooooooooo037ooooo
00Go0000ooooooooool00000o`00000?01TI6@03o`000?lc<c?o<c<c00_o<c<c00?o000004a<C01<
C4`0301<C4`3000002d0IVIV1000000=04a<C003o`00000c<c<0<c<c00`0<c<c00?o000001TI6@0I
6AT0300I6AT01?l0003oooooooooool0000Kooooo`006_ooool00ol0003oooooooooo`0ho`0000@0
00004`0I6AT4000003[o00000oooool00ol0003oooooooooo`0aooooo`05o`000?oooooooooo0000
0?l000003P0I6AT00`00003o<c<coc<c<`0;oc<c<`030000001<C4`0C4a<00/0C4a<0P00000d06IV
IP800000301<C4`2o`0000`0<c<c00?o000001TI6@0I6AT0300I6AT3ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo03Go00000`00000K01TI6@<00000=ol00003ooooo`03
o`000?oooooooooo037ooooo00Co0000oooooooooooo00003P0I6AT00`00003o<c<coc<c<`0;oc<c
<`030000001<C4`0C4a<00X0C4a<0P00000K06IVIP@000006@1VIVH00`000000C4a<04a<C00;04a<
C003o`00000c<c<0<c<c00X0<c<c00?o000001TI6@0I6AT02`0I6AT3ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo037o00001000000Q01TI6@@00000<ol00003ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03P0I6AT00`00003o<c<coc<c<`0;oc<c<`03
0000001<C4`0C4a<00X0C4a<00<0000006IVIP1VIVH0401VIVH;000000@0Ogmo1`00000C06IVIP80
0000301<C4`00ol00000<c<c03<c<`0:03<c<`03o`00000I6AT06ATI00X06ATI0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0^o`0000<00000:@0I6AT00ol000000000
0000000`o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0>01TI6@03o`00
0?lc<c?o<c<c00Wo<c<c0P00000;04a<C08000003`1VIVH4000001H0Ogmo1@00000@06IVIP800000
2`1<C4`00ol00000<c<c03<c<`0:03<c<`03o`00000I6AT06ATI00T06ATI0oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00ol0003oooooooooo`0/o`0000800000;`0I6AT00`00003o0000o`00
000]o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=01TI6@0300000?lc
<c?o<c<c00Wo<c<c00<0000004a<C01<C4`02P1<C4`00`000000IVIV06IVIP0<06IVIP<000007`1o
Ogl3000000l0IVIV00<0000004a<C01<C4`02@1<C4`00ol00000<c<c03<c<`0:03<c<`03o`00000I
6AT06ATI00P06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Z
o`0000800000<P0I6AT3000002co00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00`06ATI00<00000oc<c<olc<c<02_lc<c<00`000000C4a<04a<C00904a<C0030000001VIVH0
IVIV00`0IVIV00<0000007moO`1oOgl08`1oOgl3000000d0IVIV00<0000004a<C01<C4`02@1<C4`0
0ol00000<c<c03<c<`0903<c<`03o`00000I6AT06ATI00P06ATI0oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`0Xo`0000800000=`0I6AT00`00003o0000o`00000Yo`00
00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;01TI6@0300000?lc<c?o<c<c
00[o<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0;06IVIP800000:@1oOgl00`00
003o000006IVIP0;06IVIP030000001<C4`0C4a<00T0C4a<00?o000003<c<`0c<c<02@0c<c<00ol0
00006ATI01TI6@0701TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool09_l000000`00003o000001TI6@0i01TI6@<00000:?l00003ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02`0I6AT00ol0003o<c<coc<c<`09oc<c<`030000001<C4`0C4a<00P0
C4a<00<00000o`00001VIVH02@1VIVH01000003o000000000000000]07moO`<000002P1VIVH20000
00X0C4a<00?o000003<c<`0c<c<02@0c<c<00ol000006ATI01TI6@0601TI6@?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00?o0000ooooooooool09Ol000000`0000006ATI01TI6@0m01TI6@80
00009_l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02P0I6AT00`00003o
<c<coc<c<`09oc<c<`03o`00001<C4`0C4a<00L0C4a<0P00000:06IVIP8000005@1oOgl8000001L0
Ogmo0P00000:06IVIP030000001<C4`0C4a<00P0C4a<00?o000003<c<`0c<c<02@0c<c<00ol00000
6ATI01TI6@0501TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
8ol00002000004806ATI00<00000o`000?l000008ol00003ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02@0I6AT00`00003o<c<coc<c<`09oc<c<`030000001<C4`0C4a<00L0C4a<
00<0000006IVIP1VIVH02@1VIVH00`000000Ogmo07moO`0>07moO`L00000202IVIT700000180Ogmo
00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00804a<C003o`00000c<c<0<c<c00T0<c<c
00?o000001TI6@0I6AT0100I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooooooo02;o000000<0000001TI6@0I6AT05`0I6AT00`00003o00000000000@000001T06ATI9Ol0
0003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0200I6AT00`00003o<c<coc<c
<`09oc<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH02@1VIVH00ol00000Ogmo07mo
O`0<07moO`<000005P2IVIT5000000h0Ogmo0P00000906IVIP03o`0000000000C4a<00P0C4a<00?o
000003<c<`0c<c<02@0c<c<00ol000006ATI01TI6@0301TI6@?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool08?l000000`00003o000001TI6@0E01TI6@@000004`0c<c<4
000001H06ATI0P00000Ro`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08
01TI6@0300000?lc<c?o<c<c00So<c<c00<0000004a<C01<C4`0201<C4`00`000000IVIV06IVIP08
06IVIP030000001oOgl0Ogmo00/0Ogmo0P00000N09VIV@<000003@1oOgl00`000000IVIV06IVIP08
06IVIP030000001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<02@0c<c<00ol000006ATI01TI6@03
01TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool07ol000000`00
00006ATI01TI6@0C01TI6@<000006`0c<c<3000001D06ATI00<00000o`000?l000007ol00003oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01`0I6AT00`00003o<c<coc<c<`08oc<c
<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01`1VIVH2000000`0Ogmo0P00000S09VI
V@800000301oOgl00`000000IVIV06IVIP0806IVIP030000001<C4`0C4a<00H0C4a<00?o000003<c
<`0c<c<02@0c<c<00ol000006ATI01TI6@0201TI6@?ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool07_l000000`0000006ATI01TI6@0A01TI6@<000008@0c<c<3000001<0
6ATI00<00000o`000?l000007_l00003ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01`0I6AT00`00003o<c<coc<c<`08oc<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1V
IVH01`1VIVH00`000000Ogmo07moO`0907moO`<000009`2IVIT2000000/0Ogmo00?o000006IVIP1V
IVH0201VIVH00ol00000C4a<04a<C00604a<C003o`00000c<c<0<c<c00P0<c<c00?o000001TI6@0I
6AT00P0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo01go0000
00<0000001TI6@0I6AT0400I6AT2000002L0<c<c00?o000001TI6@0I6AT04@0I6AT00`00003o0000
o`00000Mo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0601TI6@030000
0?lc<c?o<c<c00So<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0706IVIP030000
001oOgl0Ogmo00P0Ogmo0P00000/09VIV@8000002P1oOgl00`000000IVIV06IVIP0706IVIP030000
001<C4`0C4a<00L0C4a<00?o000003<c<`0c<c<0200c<c<01?l000006ATI01TI6@0I6AT3ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo01co000000<0000001TI6@0I6AT0
3`0I6AT2000002X0<c<c0P00000B01TI6@0300000?l0003o000001co00000oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00H06ATI00<00000oc<c<olc<c<01olc<c<00`000000C4a<
04a<C00704a<C0030000001VIVH0IVIV00L0IVIV00?o000007moO`1oOgl0201oOgl00`000000VIVI
09VIV@0A09VIV@`000004@2IVIT2000000T0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<
04a<C00604a<C003o`00000c<c<0<c<c00P0<c<c00Co000001TI6@0I6AT06ATI0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Ko`0000030000000I6AT06ATI00h06ATI
0P00000^03<c<`8000004@0I6AT00`00003o0000o`00000Ko`0000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0501TI6@0300000?lc<c?o<c<c00Oo<c<c00<0000004a<C01<C4`0
1`1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00P0Ogmo00<0000009VIV@2IVIT0
2`2IVIT7000000`0/k>c0`00000@09VIV@030000001oOgl0Ogmo00L0Ogmo00<0000006IVIP1VIVH0
1`1VIVH00`000000C4a<04a<C00604a<C003o`00000c<c<0<c<c00P0<c<c00?o000001TI6@0I6AT0
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Jo`0000030000000I
6AT06ATI00h06ATI00<0000003<c<`0c<c<03`0c<c<00ol0000000000000000>00000100<c<c0P00
000@01TI6Ago00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00@06ATI0P00
0008oc<c<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07mo
O`0807moO`030000002IVIT0VIVI00/0VIVI00<000000;>c/`2c/k<0502c/k<3000000h0VIVI00<0
000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0706IVIP03o`00001<C4`0C4a<00H0C4a<00?o
000003<c<`0c<c<0200c<c<00ol000006ATIooooo`02ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo01Wo000000<0000001TI6@0I6AT03@0I6AT00`00003o000003<c<`0<
03<c<`@0000000?o000004a<C01<C4`03`1<C4`5000000d0<c<c0P00000?01TI6@0300000?l0003o
000001Wo00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00@06ATI00<00000
oc<c<olc<c<01olc<c<00ol00000C4a<04a<C00704a<C0030000001VIVH0IVIV00D0IVIV00?o0000
0000001oOgl0201oOgl00ol00000000009VIV@0:09VIV@80000000?o00000;>c/`2c/k<0602c/k<4
000000/0VIVI00?o000007moO`1oOgl01`1oOgl00`000000IVIV06IVIP0606IVIP030000001<C4`0
C4a<00L0C4a<00?o000003<c<`0c<c<0200c<c<01Ol0003ooooooooooooooooo000001_ooooo000J
ooooo`03o`000?oooooooooo01So000000<0000001TI6@0I6AT0300I6AT2000000`0<c<c0`00000K
04a<C0<00000300c<c<2000000h06ATI00<00000o`000?l000006?l00003ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0100I6AT00`00003o<c<coc<c<`07oc<c<`030000001<C4`0
C4a<00L0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0
VIVI00P0VIVI0`00000Q0;>c/`030000002IVIT0VIVI00T0VIVI0P00000807moO`030000001VIVH0
IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00ol00000<c<c03<c<`0703<c<`05o`000?oooooo
ooooooooool000006oooool001[ooooo00?o0000ooooooooool05ol000000`0000006ATI01TI6@0<
01TI6@030000000c<c<0<c<c00/0<c<c00<0000004a<C01<C4`07`1<C4`00`00003o000003<c<`0;
03<c<`030000000I6AT06ATI00`06ATI00<00000o`000?l000005ol00003ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool00`0I6AT00`00003o<c<coc<c<`07oc<c<`030000001<C4`0
C4a<00L0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0707moO`030000002IVIT0
VIVI00P0VIVI00<000000;>c/`2c/k<08`2c/k<3000000X0VIVI00<0000007moO`1oOgl01P1oOgl0
0ol00000IVIV06IVIP0606IVIP030000001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<0200c<c<0
1?l0003oooooooooool0000Kooooo`006_ooool00ol0003oooooooooo`0Fo`0000030000000I6AT0
6ATI00`06ATI00<0000003<c<`0c<c<02@0c<c<00`00003o00000000000T04a<C08000002`0c<c<0
0ol000006ATI01TI6@0<01TI6@0300000?l0003o000001Ko00000oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00806ATI00<00000oc<c<olc<c<01olc<c<00`000000C4a<04a<C006
04a<C003o`0000000000IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl00ol00000000009VIV@08
09VIV@03o`0000000000/k>c02P0/k>c00?o000009VIV@2IVIT0202IVIT00ol00000Ogmo07moO`06
07moO`030000001VIVH0IVIV00H0IVIV00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`07
03<c<`?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool05ol0000=01TI
6@03o`00000c<c<0<c<c00T0<c<c00<0000004a<C01<C4`0301<C4`<000000l0C4a<0P00000903<c
<`8000003@0I6AT00`00003o0000o`00000Fo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0201TI6@0300000?lc<c?o<c<c00Oo<c<c00<0000004a<C01<C4`01P1<C4`00`00
0000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT01`2IVIT00`00
0000/k>c0;>c/`0?0;>c/``000003`2c/k<2000000T0VIVI00<0000007moO`1oOgl01P1oOgl00`00
0000IVIV06IVIP0606IVIP030000001<C4`0C4a<00D0C4a<00?o000003<c<`0c<c<01`0c<c<3oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo01Ko000000<0000001TI6@0I
6AT02P0I6AT00`000000<c<c03<c<`0803<c<`800000301<C4`3000000`0IVIV1`00000:04a<C003
0000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT02`0I6AT00`00003o0000o`00000Eo`0000?o
oooo00?o0000ooooooooool0<Oooool01Ol0003oooooooooo`0I6AT0000000Wo<c<c00<0000004a<
C01<C4`01P1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VI
V@2IVIT01`2IVIT00`000000/k>c0;>c/`0<0;>c/`@00000303<c<`3000000h0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`0707moO`030000001VIVH0IVIV00D0IVIV00<0000004a<
C01<C4`01P1<C4`00ol00000<c<c03<c<`0603<c<`?ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool05Ol000000`0000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00P0
<c<c00<0000004a<C01<C4`02@1<C4`3000001H0IVIV00<0000004a<C01<C4`0201<C4`00`000000
<c<c03<c<`0803<c<`030000000I6AT06ATI00/06ATI00<00000o`000?l000005?l00003ooooo`03
o`000?oooooooooo037ooooo00Go0000ooooooooool06ATI00000009oc<c<`030000001<C4`0C4a<
00H0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI
00H0VIVI0P00000<0;>c/`<000004`3<c<`3000000`0/k>c00<0000009VIV@2IVIT01P2IVIT00`00
0000Ogmo07moO`0707moO`03o`00001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00ol0
0000<c<c03<c<`0603<c<`?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool05?l000000`0000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00L0<c<c00?o00000000001<
C4`01`1<C4`01000003o000000000000000J06IVIP<00000201<C4`2000000T0<c<c00<0000001TI
6@0I6AT02`0I6ATFo`0000?ooooo00?o0000ooooooooool0<Oooool01?l0003oooooooooo`000009
oc<c<`03o`00001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`06
07moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<02@2c/k<00`00003o00000000000I
0<c<c08000002`2c/k<00`000000VIVI09VIV@0609VIV@03o`00001oOgl0Ogmo00H0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C003o`00000c<c<0<c<c00D0<c<c0oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Co`0000030000000I6AT06ATI
00X06ATI00<00000o`00000c<c<01`0c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV
01l0IVIV0`00000704a<C0800000200c<c<00`0000006ATI01TI6@0:01TI6@0300000?l0003o0000
01?o00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[o<c<c00<0000004a<
C01<C4`01P1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VI
V@2IVIT01P2IVIT00`000000/k>c0;>c/`080;>c/`8000007P3<c<`2000000X0/k>c00<0000009VI
V@2IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV00<0000004a<
C01<C4`01`1<C4`00ol00000<c<c03<c<`0403<c<`?ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool04_l000000`0000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00L0
<c<c00<0000004a<C01<C4`01P1<C4`2000000/0IVIV4000000:06IVIP030000001<C4`0C4a<00H0
C4a<00?o000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@0300000?l0003o000001;o
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wo<c<c00<0000004a<C01<
C4`01P1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2I
VIT01P2IVIT00`000000/k>c0;>c/`070;>c/`8000008P3<c<`00`000000/k>c0;>c/`080;>c/`03
0000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV06IVIP0506IVIP03
0000001<C4`0C4a<00H0C4a<00?o000003<c<`0c<c<0100c<c<3ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`03o`000?oooooooooo01;o0000300I6AT00`000000<c<c03<c<`0703<c<`030000
001<C4`0C4a<00D0C4a<0P00000806IVIPD00000401oOgl3000000P0IVIV0P00000704a<C0030000
000c<c<0<c<c00H0<c<c00?o000001TI6@0I6AT02P0I6AT00`00003o0000o`00000Ao`0000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09oc<c<`030000001<C4`0C4a<00D0C4a<
00?o000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI
00?o00000;>c/`2c/k<01`2c/k<00`000000c<c<0<c<c00S0<c<c003o`0000000000/k>c00P0/k>c
00?o00000000002IVIT01P2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00D0IVIV
00?o000004a<C01<C4`01P1<C4`00ol00000<c<c03<c<`0303<c<`?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool04Ol000000`0000006ATI01TI6@0:01TI6@030000000c
<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0606IVIP80000000?o
000007moO`1oOgl05@1oOgl00`000000IVIV06IVIP0706IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o0000017o00000ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wo<c<c00<0000004a<C01<C4`01@1<
C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00@0Ogmo00?o000009VIV@2IVIT01`2I
VIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<02D0c<c<00<000000;>c/`2c/k<01`2c
/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1V
IVH00`000000C4a<04a<C00604a<C003o`00000c<c<0<c<c00<0<c<c0oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00ol0003oooooooooo`0@o`0000030000000I6AT06ATI00X06ATI00<00000
03<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV0`00000K
07moO`800000201VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<00000
01TI6@0I6AT02P0I6AT00`00003o0000o`00000@o`0000?ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`08oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH0
0`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<2
000000l0c<c<3000000>0<c<c0030000002c/k<0/k>c00L0/k>c00<0000009VIV@2IVIT01@2IVIT0
0`000000Ogmo07moO`0507moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`0
0ol00000<c<c03<c<`0303<c<`?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool04?l000000`0000006ATI01TI6@0:01TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<
C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00P0Ogmo3000000:07mo
O`8000001`1VIVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c00H0<c<c00<0000001TI
6@0I6AT02@0I6AT00`00003o0000o`00000@o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`08oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`00
0000Ogmo07moO`0407moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<00`00
0000c<c<0<c<c00;0<c<c0@00000303Vi^H3000000`0c<c<0P0000080;>c/`030000002IVIT0VIVI
00D0VIVI00?o000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<
00H0C4a<00?o000003<c<`0c<c<00P0c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo00oo000000<0000001TI6@0I6AT02P0I6AT00`000000<c<c03<c<`0503<c<`03
0000001<C4`0C4a<00@0C4a<00?o00000000001VIVH0101VIVH2000000P0Ogmo00<00000o`000000
0000302IVIT00`00003o000000000002000000L0Ogmo0P00000606IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o000000oo
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo<c<c00<0000004a<C01<
C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2I
VIT01@2IVIT00ol00000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00T0c<c<0`00000C0>KViP03
o`0000000000000000/0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0509VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C003
o`00000c<c<0<c<c0080<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooo
ooooo`0?o`0000030000000I6AT06ATI00X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl01@1oOgl3000001@0VIVI
0`00000607moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c
03<c<`0503<c<`030000000I6AT06ATI00T06ATI00<00000o`000?l000003ol00003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01olc<c<00`000000C4a<04a<C00504a<C0030000
001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@030000
002c/k<0/k>c00D0/k>c00?o00000<c<c03<c<`02@3<c<`00`000000i^KV0>KViP0G0>KViP030000
003<c<`0c<c<00T0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0509VIV@030000
001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C003o`00
000c<c<0<c<c0080<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooooooo
o`0>o`0000030000000I6AT06ATI00X06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<
C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl2000001X0VIVI00<0
000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o000000ko00000ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo<c<c00<0000004a<C01<C4`0101<
C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2I
VIT00`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3Vi^H06@3V
i^H00`000000c<c<0<c<c0090<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT01@2I
VIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<
C4`01?l00000<c<c03<c<`0c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oo
oooooooo00ko000000<0000001TI6@0I6AT02P0I6AT00`000000<c<c03<c<`0503<c<`030000001<
C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002I
VIT0VIVI00P0VIVI00?o00000000000000001`00000909VIV@030000001oOgl0Ogmo00@0Ogmo00<0
000006IVIP1VIVH0101VIVH00ol00000C4a<04a<C00404a<C003o`00000c<c<0<c<c00@0<c<c00<0
000001TI6@0I6AT02@0I6AT00`00003o0000o`00000>o`0000?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`06oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1V
IVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c
/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV01/0i^KV00?o00000<c<c03<c<`0203<
c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl0101o
Ogl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00Co000003<c<`0c<c<0<c<c
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0>o`0000030000000I
6AT06ATI00P06ATI00?o00000000000c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001V
IVH0IVIV00<0IVIV00<00000o`00001oOgl0101oOgl00`00003o000009VIV@0409VIV@@0000000?o
00000;>c/`2c/k<0202c/k<01?l00000000000000000000609VIV@8000001@1oOgl00`000000IVIV
06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI
01TI6@0901TI6@0300000?l0003o000000go00000oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Ko<c<c00<0000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0506IVIP030000
001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`050;>c/`030000
003<c<`0c<c<00L0c<c<0P00000O0>KViP030000003<c<`0c<c<00P0c<c<00<000000;>c/`2c/k<0
1@2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0
1@1VIVH00ol00000C4a<04a<C00504a<C003o`00000c<c<0<c<c00?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00?o0000ooooooooool03_l000000`0000006ATI01TI6@0801TI6@030000000c
<c<0<c<c00D0<c<c00?o000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001o
Ogl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`0A0;>c/`<000001@2I
VIT2000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c
<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`00000=o`0000?ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`06oc<c<`030000001<C4`0C4a<00D0C4a<00<0
000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00?o
00000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0070<c<c0030000003Vi^H0i^KV0200i^KV00<0
00000<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0
000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00?o
000003<c<`0c<c<00oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0=
o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C004
04a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl2000000D0VIVI0P00000G
0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00P1oOgl00ol00000IVIV06IVIP03
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@09
01TI6@0300000?l0003o000000co00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Go<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0
Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0
c<c<00L0c<c<00<000000>KViP3Vi^H08P3Vi^H2000000P0c<c<00<000000;>c/`2c/k<01@2c/k<0
0ol00000VIVI09VIV@0509VIV@03o`00001oOgl0Ogmo00@0Ogmo00?o000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00604a<C003o`00000c<c?ooooo00;ooooo00?o0000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool03?l000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c
00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo
00<0Ogmo00<0000009VIV@2IVIT00`2IVIT2000000X0/k>c1Ol0000;0;>c/`8000001@2IVIT00ol0
0000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0503<c<`030000000I6AT06ATI00P06ATI3ol00003ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01Olc<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV
00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c
00D0/k>c00?o00000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0U0>KViP030000003<c<`0c<c<
00H0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo
00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C003o`00000c<c?ooooo
00;ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool03?l000000`000000
6ATI01TI6@0901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000
/k>c0;>c/`060;>c/`Co00001@3<c<`6o`0000L0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000
Ogmo07moO`0307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0403<c<`030000000I6AT06ATI00T06ATI00<00000o`000?l000002ol00003ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01Olc<c<00`000000C4a<04a<C00504a<C003
0000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0<0>KViPco
00003@3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2I
VIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<
C4`01@1<C4`00ol00000<c<cooooo`02ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`00
0?oooooooooo00co000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c<`030000
001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`030000
002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<0102c/k<3o`0000l0c<c<0_l000060;>c/`030000
002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP030000
001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@030000
0?l0003o000000_o00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Go<c<c
00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo
00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00H0c<c<
00<000000>KViP3Vi^H02P3Vi^H3o`0000`0oooo0_l0000<0>KViP030000003<c<`0c<c<00H0c<c<
00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C003o`00000c<c?ooooo00;ooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02ol000000`0000006ATI01TI
6@0901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c
/`040;>c/`03o`00003<c<`0c<c<0180c<c<00?o00000;>c/`2c/k<0102c/k<00ol00000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo00<0Ogmo00Go000006IVIP1VIVH0IVIV0000000604a<C0030000
000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`00000:o`0000?ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04oc<c<`030000001<C4`0C4a<00D0C4a<
00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00X0i^KV
00?o00000?ooo`3oool03`3oool00ol00000i^KV0>KViP0:0>KViP03o`00003<c<`0c<c<00D0c<c<
00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C005o`000?ooooooooooooooool0
00006oooool001[ooooo00?o0000ooooooooool02ol000000`0000006ATI01TI6@0901TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0206IVIP030000
001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`;o0000
5P3<c<`00ol00000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0
100c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o000000[o00000oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Co<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV
06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c
0;>c/`050;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H02@3Vi^H2o`0001<0oooo
00?o00000>KViP3Vi^H02P3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00D0/k>c
00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00D0IVIV
00<0000004a<C01<C4`01@1<C4`01Ol0003ooooooooooooooooo000001_ooooo000Jooooo`03o`00
0?oooooooooo00co00002`0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<
00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI
00?o00000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0080<c<c0So00001`3<c<`00ol00000/k>c
0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV
06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI
01TI6@0901TI6@0300000?l0003o000000[o00000oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Co<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000
001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`030000
003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00
003Vi^H0i^KV00T0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`050;>c/`030000
002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0506IVIP030000
001<C4`0C4a<00D0C4a<00Go0000ooooooooooooooooo`00000Kooooo`006_ooool00ol0003ooooo
ooooo`0;o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00304a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI
09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`01@3<c<`4o`0000P0i^KV
0ol000050<c<c0;o0000102c/k<00`000000VIVI09VIV@0209VIV@03o`00001oOgl0Ogmo0080Ogmo
00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c
00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`000009o`0000?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`04oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0
101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0
1@2c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00T0i^KV00?o00000?ooo`3oool0
5@3oool00ol00000i^KV0>KViP090>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0
1@2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0
1@1VIVH00`000000C4a<04a<C00404a<C005o`000?ooooooooooooooool000006oooool001[ooooo
00?o0000ooooooooool02_l000000`0000006ATI01TI6@0801TI6@03o`00000c<c<0<c<c00D0<c<c
00?o000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP03o`00001oOgl0Ogmo0080Ogmo
00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00@0c<c<
0_l0000?0>KViP03o`00003<c<`0c<c<00@0c<c<00?o00000;>c/`2c/k<00P2c/k<00ol00000VIVI
09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<
04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT00`00003o0000
o`000009o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04oc<c<`030000
001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000
002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c0050<c<c0030000
003Vi^H0i^KV00P0i^KV00?o00000?ooo`3oool05`3oool00ol00000i^KV0>KViP080>KViP030000
003<c<`0c<c<00H0c<c<00?o00000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000
001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00404a<C005o`00
0?ooooooooooooooool000006oooool001[ooooo00?o0000ooooooooool02_l000000`0000006ATI
01TI6@0801TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV
06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c
0;>c/`020;>c/`03o`00003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H0403Vi^H00ol00000c<c<
0<c<c0030<c<c003o`00002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo
07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c
03<c<`0403<c<`030000000I6AT06ATI00P06ATI00<00000o`000?l000002Ol00003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool01?lc<c<00`000000C4a<04a<C00504a<C0030000
001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0309VIV@030000
002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP080>KViP03o`00
003oool0oooo01P0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0060<c<c0030000
002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0407moO`030000
001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0101<C4`01Ol0003ooooooooooooooooo000001_o
oooo000Jooooo`03o`000?oooooooooo00[o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c
03<c<`0503<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo
07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0030<c<c003
o`00003Vi^H0i^KV0180i^KV00?o00000<c<c03<c<`00`3<c<`01Ol00000/k>c0;>c/`2c/k<00000
00D0VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<00<0C4a<00<00000
03<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@0300000?l0003o000000Wo00000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Co<c<c00<0000004a<C01<C4`01@1<C4`0
0`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT0
0`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00@0c<c<00<000000>KViP3Vi^H0203Vi^H0
0ol00000oooo0?ooo`0J0?ooo`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`01@3<c<`0
0`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl0
0`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00@0C4a<00Go0000ooooooooooooooooo`00
000Kooooo`006_ooool00ol0003oooooooooo`0:o`0000030000000I6AT06ATI00P06ATI00<00000
03<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<00000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00?o0000
0<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP0D0>KViP03o`00003<c<`0c<c<00<0c<c<00Go0000
0;>c/`2c/k<0/k>c0000000409VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1V
IVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I
6AT00`00003o0000o`000008o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`04oc<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07mo
O`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<
c0050<c<c0030000003Vi^H0i^KV00P0i^KV00?o00000?ooo`3oool06P3oool00ol00000i^KV0>KV
iP070>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VI
V@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<
C00504a<C004o`000?ooooooooooo`0001_ooooo000Jooooo`03o`000?oooooooooo00[o000000<0
000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0
000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<0
0P2c/k<00ol00000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00H0i^KV2?l000080>KViP03o`00
003<c<`0c<c<00<0c<c<00Go00000;>c/`2c/k<0/k>c0000000409VIV@050000001oOgl0Ogmo07mo
O`000000101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI
6@0I6AT0200I6AT00`00003o0000o`000008o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`03oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`00
0000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`00
0000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool0703oool00ol0
0000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`00
0000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`00
0000C4a<04a<C00504a<C004o`000?ooooooooooo`0001_ooooo000Jooooo`03o`000?oooooooooo
00[o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<
0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00<00000
0;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00D0i^KV00?o0000
0?ooo`3oool01P3oool2o`0000L0i^KV00?o00000<c<c03<c<`00P3<c<`01Ol00000/k>c0;>c/`2c
/k<0000000@0VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<00<0C4a<
00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@0300000?l0003o000000So0000
0oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?o<c<c00<0000004a<C01<C4`0
1@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0
102IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H0
1`3Vi^H00ol00000oooo0?ooo`0L0?ooo`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`0
103<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0
101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00Co0000oooooooooooo
00006oooool001[ooooo00?o0000ooooooooool02_l000000`0000006ATI01TI6@0801TI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000
001oOgl0Ogmo07moO`000000102IVIT01@000000/k>c0;>c/`2c/k?o000000@0c<c<00?o00000>KV
iP3Vi^H01@3Vi^H00ol00000oooo0?ooo`090?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<
c03<c<`00P3<c<`00ol00000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00@0000007mo
O`1oOgl00000101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<00000
01TI6@0I6AT0200I6AT00`00003o0000o`000008o`0000?ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`03oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH0
0`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<0
0`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool0703oool0
0ol00000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<0
0`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00504a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool02Ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<
C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVH0000000<0Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0103Vi^H0
0ol00000oooo0?ooo`0;0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00P3<c<`0
1Ol00000/k>c0;>c/`2c/k<0000000@0VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP030000
001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@030000
0?l0003o000000So00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?o<c<c
00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo
00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<
00<000000>KViP3Vi^H01`3Vi^H00ol00000oooo0?ooo`0N0?ooo`03o`00003Vi^H0i^KV00H0i^KV
00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI
00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`09o`0000030000000I
6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001V
IVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@050000002c/k<0/k>c0;>c/ol0
0000103<c<`00ol00000i^KV0>KViP030>KViP;o00003`3oool00ol00000i^KV0>KViP030>KViP03
o`00003<c<`0c<c<0080c<c<00?o00000;>c/`2c/k<00P2c/k<01Ol00000VIVI09VIV@2IVIT00000
00<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c
00@0<c<c00<0000001TI6@0I6AT0200I6AT00`00003o0000o`000008o`0000?ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`03oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IV
IP1VIVH0101VIVH00ol00000Ogmo07moO`0407moO`030000002IVIT0VIVI00<0VIVI00<000000;>c
/`2c/k<0102c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00L0i^KV00?o00000?oo
o`3oool07P3oool00ol00000i^KV0>KViP060>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c
/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IV
IP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0?ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool02Ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0
<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07mo
O`000000102IVIT01@000000/k>c0;>c/`2c/k?o000000@0c<c<00?o00000>KViP3Vi^H00`3Vi^H0
0ol00000oooo0?ooo`0>0?ooo`03o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00P3<c<`0
0ol00000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@0801TI6@0300000?l0003o000000So00000oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00?o<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001o
Ogl0Ogmo00@0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000003<
c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00ol00000oooo0?ooo`0N0?ooo`03o`00003V
i^H0i^KV00H0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002I
VIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<
C4`0C4a<00D0C4a<0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`09
o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C002
04a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@050000002c
/k<0/k>c0;>c/ol00000103<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo0100oooo
00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<c005o`00002c/k<0/k>c0;>c/`00
0000102IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00P1<C4`00`00
0000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI00<00000o`000?l000002?l00003oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool00olc<c<00`000000C4a<04a<C00504a<
C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0309VI
V@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP060>KV
iP03o`00003oool0oooo01l0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0040<c<
c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307mo
O`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0101<C4`3ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo00Wo000000<0000001TI6@0I6AT0200I6AT00`000000
<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000
Ogmo07moO`1oOgl0000000<0VIVI00D000000;>c/`2c/k<0/k>co`0000040<c<c003o`00003Vi^H0
i^KV00<0i^KV00?o00000?ooo`3oool04@3oool00ol00000i^KV0>KViP030>KViP05o`00003<c<`0
c<c<0<c<c?l000000`2c/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`000000
101VIVH00`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0
1`0I6AT00`00003o0000o`000008o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`03oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo
07moO`0407moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<
0<c<c0050<c<c0030000003Vi^H0i^KV00H0i^KV00?o00000?ooo`3oool07`3oool00ol00000i^KV
0>KViP070>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<
04a<C00404a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02Ol0
00000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c
0;>c/`2c/k?o000000@0c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0A0?ooo`03
o`00003Vi^H0i^KV00<0i^KV00Go00000<c<c03<c<`0c<c<o`0000030;>c/`030000002IVIT0VIVI
0080VIVI00D0000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<00000
03<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@0300000?l0003o000000So00000oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?o<c<c00<0000004a<C01<C4`01@1<C4`0
0`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT00`2IVIT0
0`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01P3Vi^H0
0ol00000oooo0?ooo`0O0?ooo`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`0103<c<`0
0`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl0
0`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00@0C4a<0oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`09o`0000030000000I6AT06ATI00P06ATI00<0000003<c
<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0000007mo
O`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c0;>c/ol00000103<c<`00ol00000i^KV0>KV
iP030>KViP03o`00003oool0oooo0140oooo00?o00000>KViP3Vi^H00`3Vi^H01Ol00000c<c<0<c<
c03<c<co000000<0/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000@0
IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00L0
6ATI00<00000o`000?l000002?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool00olc<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1o
Ogl0101oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<
c<`01@3<c<`00`000000i^KV0>KViP060>KViP03o`00003oool0oooo01l0oooo00?o00000>KViP3V
i^H01`3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2I
VIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<
C4`0101<C4`3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00Wo0000
00<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<
00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00D000000;>c/`2c
/k<0/k>co`0000040<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool04@3oool00ol0
0000i^KV0>KViP030>KViP05o`00003<c<`0c<c<0<c<c?l00000102c/k<01@000000VIVI09VIV@2I
VIT0000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0030000000c
<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT00`00003o0000o`000007o`0000?ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`03oc<c<`030000001<C4`0C4a<00D0C4a<00<0
000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<0
00000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00L0i^KV00?o
00000?ooo`3oool07P3oool00ol00000i^KV0>KViP060>KViP030000003<c<`0c<c<00D0c<c<00<0
00000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<0
000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C0?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool02Ol000000`0000006ATI01TI6@0801TI6@030000000c<c<0
<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0
Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c/k?o000000@0c<c<00?o00000>KViP3Vi^H0
0`3Vi^H00ol00000oooo0?ooo`0A0?ooo`03o`00003Vi^H0i^KV00<0i^KV00Go00000<c<c03<c<`0
c<c<o`0000040;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI
6@0300000?l0003o000000Oo00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00?o<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo
00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<
00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00ol00000oooo0?ooo`0N0?ooo`03o`00003Vi^H0i^KV
00H0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI
00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<
00D0C4a<0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`09o`000003
0000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C003
0000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c
0;>c/ol00000103<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo0140oooo00?o0000
0>KViP3Vi^H00`3Vi^H01Ol00000c<c<0<c<c03<c<co000000@0/k>c00D0000009VIV@2IVIT0VIVI
0000000307moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c
03<c<`0403<c<`030000000I6AT06ATI00P06ATI00<00000o`000?l000001ol00003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool00olc<c<00`000000C4a<04a<C00504a<C0030000
001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000
002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`00`000000i^KV0>KViP070>KViP03o`00
003oool0oooo01h0oooo00?o00000>KViP3Vi^H01P3Vi^H00`000000c<c<0<c<c0050<c<c0030000
002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000
001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`3ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00Wo000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c
<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00P1VIVH01@000000Ogmo07mo
O`1oOgl0000000<0VIVI00D000000;>c/`2c/k<0/k>co`0000040<c<c003o`00003Vi^H0i^KV00<0
i^KV00?o00000?ooo`3oool04@3oool00ol00000i^KV0>KViP030>KViP05o`00003<c<`0c<c<0<c<
c?l00000102c/k<01@000000VIVI09VIV@2IVIT0000000<0Ogmo00<0000006IVIP1VIVH00P1VIVH0
0`000000C4a<04a<C00204a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT0200I6AT0
0`00003o0000o`000007o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`04
oc<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`04
07moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c006
0<c<c0030000003Vi^H0i^KV00H0i^KV00?o00000?ooo`3oool07@3oool00ol00000i^KV0>KViP07
0>KViP030000003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@04
09VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C005
04a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02Ol000000`00
00006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`00
0000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102IVIT01@000000/k>c0;>c/`2c
/k?o000000<0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003V
i^H0i^KV0080i^KV00?o00000<c<c03<c<`00P3<c<`01Ol00000/k>c0;>c/`2c/k<0000000@0VIVI
00D0000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c
<c<0100c<c<00`0000006ATI01TI6@0701TI6@0300000?l0003o000000So00000oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Co<c<c00<0000004a<C01<C4`0101<C4`00`000000
IVIV06IVIP0506IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000
/k>c0;>c/`040;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H01`3Vi^H00ol00000
oooo0?ooo`0L0?ooo`03o`00003Vi^H0i^KV00L0i^KV00<000000<c<c03<c<`0103<c<`00`000000
/k>c0;>c/`050;>c/`030000002IVIT0VIVI00<0VIVI00<00000o`00001oOgl0101oOgl00`000000
IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<0oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00ol0003oooooooooo`09o`0000030000000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0
100c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0
Ogmo0000000409VIV@050000002c/k<0/k>c0;>c/ol00000103<c<`00ol00000i^KV0>KViP030>KV
iP03o`00003oool0oooo00l0oooo00?o00000>KViP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<
c005o`00002c/k<0/k>c0;>c/`000000102IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0
000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00L06ATI00<0
0000o`000?l000002?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01?lc
<c<00ol00000C4a<04a<C00404a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl00`1o
Ogl00ol00000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01@3<
c<`00ol00000i^KV0>KViP070>KViP;o0000703oool00ol00000i^KV0>KViP080>KViP030000003<
c<`0c<c<00@0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0309VIV@030000001o
Ogl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C00400000?oo
ooooooooo`0001_ooooo000Jooooo`03o`000?oooooooooo00Wo000000<0000001TI6@0I6AT0200I
6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00Go000006IVIP1VIVH0IVIV
0000000307moO`030000002IVIT0VIVI0080VIVI00D000000;>c/`2c/k<0/k>co`0000040<c<c003
o`00003Vi^H0i^KV00<0i^KV0_l0000?0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o00000<c<c03<
c<`00P3<c<`01Ol00000/k>c0;>c/`2c/k<0000000@0VIVI00D0000007moO`1oOgl0Ogmo00000004
06IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@07
01TI6@0300000?l0003o000000So00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Co<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00ol00000/k>c0;>c/`040;>c/`030000003<c<`0
c<c<00D0c<c<00<000000>KViP3Vi^H0203Vi^H00ol00000oooo0?ooo`0J0?ooo`03o`00003Vi^H0
i^KV00P0i^KV00<000000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0
VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0
C4a<00D0C4a<00@00000oooooooooooo00006oooool001[ooooo00?o0000ooooooooool02_l00000
0`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`0
0`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102IVIT01@000000/k>c0;>c
/`2c/k?o000000@0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0;0?ooo`03o`00
003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00P3<c<`00ol00000/k>c0;>c/`020;>c/`05o`00
002IVIT0VIVI09VIV@0000000`1oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<0080
C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@0300000?l0003o000000So
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Co<c<c00<0000004a<C01<
C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2I
VIT00`2IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3V
i^H0203Vi^H00ol00000oooo0?ooo`0H0?ooo`03o`00003Vi^H0i^KV00P0i^KV00<000000<c<c03<
c<`01@3<c<`00ol00000/k>c0;>c/`040;>c/`03o`00002IVIT0VIVI00@0VIVI00<0000007moO`1o
Ogl00`1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00@00000oooooooo
oooo00006oooool001[ooooo00?o0000ooooooooool02_l000000`0000006ATI01TI6@0801TI6@03
0000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP05
0000001oOgl0Ogmo07moO`000000102IVIT01@000000/k>c0;>c/`2c/k?o000000@0c<c<00?o0000
0>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`080?ooo`;o00001`3Vi^H00ol00000c<c<0<c<c002
0<c<c005o`00002c/k<0/k>c0;>c/`000000102IVIT01Ol00000Ogmo07moO`1oOgl0000000@0IVIV
00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI
00<00000o`000?l000002?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
1?lc<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0
101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00@0/k>c00?o00000<c<c03<c<`0
1@3<c<`00`000000i^KV0>KViP090>KViP03o`00003oool0oooo01H0oooo00?o00000>KViP3Vi^H0
203Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0
102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`0
1@1<C4`01000003oooooooooool0000Kooooo`006_ooool00ol0003oooooooooo`0:o`0000030000
000I6AT06ATI00P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000
001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@050000002c/k<0/k>c0;>c
/ol00000103<c<`00ol00000i^KV0>KViP060>KViP?o00001@3oool2o`0000P0i^KV00?o00000<c<
c03<c<`00`3<c<`01Ol00000/k>c0;>c/`2c/k<0000000@0VIVI00D0000007moO`1oOgl0Ogmo0000
000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI
6@0801TI6@0300000?l0003o000000So00000oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Co<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP030000001o
Ogl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`040;>c/`030000003<
c<`0c<c<00D0c<c<00<000000>KViP3Vi^H02@3Vi^H00ol00000oooo0?ooo`0E0?ooo`03o`00003V
i^H0i^KV00T0i^KV00<000000<c<c03<c<`01P3<c<`00`000000/k>c0;>c/`040;>c/`030000002I
VIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0506IVIP030000001<
C4`0C4a<00D0C4a<00@00000oooooooooooo00006oooool001[ooooo00?o0000ooooooooool02_l0
00000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0206IVIP050000001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c
0;>c/`020;>c/`03o`00003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H0203Vi^H5o`0000X0i^KV
00?o00000<c<c03<c<`00P3<c<`00ol00000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI
00D0000007moO`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<0080C4a<00<0000003<c<`0c
<c<0100c<c<00`0000006ATI01TI6@0801TI6@0300000?l0003o000000So00000oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Co<c<c00<0000004a<C01<C4`01@1<C4`00`000000
IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000
/k>c0;>c/`050;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H02@3Vi^H2o`0001@0
oooo00?o00000>KViP3Vi^H02@3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0
/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00D0
IVIV00<0000004a<C01<C4`01@1<C4`01000003oooooooooool0000Kooooo`006_ooool00ol0003o
ooooooooo`0;o`0000030000000I6AT06ATI00L06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00304a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000309VI
V@030000002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP0E0>KV
iP03o`00003<c<`0c<c<00<0c<c<00Go00000;>c/`2c/k<0/k>c0000000409VIV@050000001oOgl0
Ogmo07moO`000000101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0
000001TI6@0I6AT0200I6AT00`00003o0000o`000008o`0000?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`05oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101V
IVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c
/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00/0i^KV00?o00000?ooo`3oool0403o
ool00ol00000i^KV0>KViP0:0>KViP030000003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<0102c
/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101V
IVH00`000000C4a<04a<C00504a<C00500000?ooooooooooooooool000006oooool001[ooooo00?o
0000ooooooooool02ol000000`0000006ATI01TI6@0701TI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP060000001oOgl0Ogmo07moO`00003o
00000`2IVIT00`000000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00<0c<c<00?o00000>KViP3V
i^H04`3Vi^H00ol00000c<c<0<c<c0030<c<c003o`00002c/k<0/k>c0080/k>c00<0000009VIV@2I
VIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0403<c<`030000000I6AT06ATI00P06ATI00<00000o`000?l000002?l00003oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool01Olc<c<00`000000C4a<04a<C00504a<
C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VI
V@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`01@3<c<`00`00003o00000>KViP0;0>KV
iP?o00002`3oool4o`0000`0i^KV00<000000<c<c03<c<`01P3<c<`00`000000/k>c0;>c/`050;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00D0C4a<00D00000ooooooooooooooooo`00000Kooooo`006_ooool00ol0
003oooooooooo`0<o`0000X06ATI00?o000003<c<`0c<c<0100c<c<00ol00000C4a<04a<C00204a<
C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VI
V@030000002c/k<0/k>c0080/k>c00?o00000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP0@0>KV
iP;o00001@3<c<`00ol00000/k>c0;>c/`020;>c/`030000002IVIT0VIVI00<0VIVI00D0000007mo
O`1oOgl0Ogmo0000000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0801TI6@0300000?l0003o000000So00000oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Go<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP04
06IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`05
0;>c/`030000003<c<`0c<c<00H0c<c<00<000000>KViP3Vi^H03@3Vi^H2o`0000P0oooo00?o0000
0>KViP3Vi^H03P3Vi^H00`000000c<c<0<c<c0060<c<c0030000002c/k<0/k>c00D0/k>c00<00000
09VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<00000
04a<C01<C4`01@1<C4`01@00003ooooooooooooooooo000001_ooooo000Jooooo`03o`000?oooooo
oooo00_o000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0
VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00ol00000c<c<0<c<c0030<c<c0?o00003@3Vi^H2
o`0000H0c<c<00?o00000;>c/`2c/k<00P2c/k<00ol00000VIVI09VIV@0309VIV@050000001oOgl0
Ogmo07moO`000000101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0
000001TI6@0I6AT0200I6AT00`00003o0000o`000009o`0000?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`06oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101V
IVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01@2c
/k<00`000000c<c<0<c<c0060<c<c0030000003Vi^H0i^KV00h0i^KV2?l0000@0>KViP030000003<
c<`0c<c<00H0c<c<00<000000;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001o
Ogl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<C00300000?lc
<c?ooooo00;ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool02ol00000
0`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`0
0`000000IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`020;>c/`03o`00003<c<`0c<c<00D0c<c<1?l000060>KViP?o00001`3<c<`0
0ol00000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl0
0`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<0
0`0000006ATI01TI6@0801TI6@0300000?l0003o000000Wo00000oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Ko<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP04
06IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`04
0;>c/`0300000?l00000c<c<00L0c<c<00<000000>KViP3Vi^H0903Vi^H00`000000c<c<0<c<c006
0<c<c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`05
07moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`00003o<c<cooooo`02
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo00_o000000<0000001TI
6@0I6AT02@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<0080C4a<00<0000006IV
IP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00?o00000;>c
/`2c/k<00`2c/k<00ol00000c<c<0<c<c0080<c<c0Ko00002@3<c<`00ol00000/k>c0;>c/`040;>c
/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IV
IP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI
6@0300000?l0003o000000Wo00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Ko<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP03o`00001oOgl0Ogmo
00@0Ogmo00?o000009VIV@2IVIT0102IVIT00ol00000/k>c0;>c/`050;>c/`030000003<c<`0c<c<
00L0c<c<00?o00000000003Vi^H08P3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c
00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0IVIV
00@0IVIV00<0000004a<C01<C4`01@1<C4`00`00003o<c<cooooo`02ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`03o`000?oooooooooo00co000000<0000001TI6@0I6AT0200I6AT00`000000
<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000
Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<2o`0001H0
c<c<00?o00000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080
Ogmo00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0
<c<c00<0000001TI6@0I6AT0200I6AT00`00003o0000o`000009o`0000?ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`06oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1V
IVH01@1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c
/k<01P2c/k<00`000000c<c<0<c<c0080<c<c0030000003Vi^H0i^KV01l0i^KV00<000000<c<c03<
c<`01`3<c<`00`000000/k>c0;>c/`050;>c/`030000002IVIT0VIVI00D0VIVI00<0000007moO`1o
Ogl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00H0C4a<00<00000oc<c<ooo
ool00_ooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0<o`0000030000
000I6AT06ATI00T06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0030000
001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000
002c/k<0/k>c00@0/k>c00?o00000<c<c03<c<`04P3<c<`00ol00000/k>c0;>c/`040;>c/`030000
002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP030000
001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0801TI6@030000
0?l0003o000000[o00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oo<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00@0Ogmo
00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<00T0c<c<
00<000000>KViP3Vi^H07@3Vi^H00`000000c<c<0<c<c0080<c<c0030000002c/k<0/k>c00D0/k>c
00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`03o`00001VIVH0IVIV00@0IVIV
00?o000004a<C01<C4`01@1<C4`00`00003o<c<coc<c<`03ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo00go000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c
<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0207moO`03o`00002IVIT0VIVI00<0VIVI0P0000050;>c/`Co00003@3<c<`3o`0000@0/k>c0P00
00000ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1V
IVH00`000000C4a<04a<C00304a<C003o`00000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT0200I
6AT00`00003o0000o`00000:o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`07oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07mo
O`0407moO`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<
c0090<c<c0800000703Vi^H00ol00000c<c<0<c<c0080<c<c003o`00002c/k<0/k>c00D0/k>c00<0
000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00D0IVIV00<0
000004a<C01<C4`01@1<C4`00`00003o<c<coc<c<`03ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo00go000000<0000001TI6@0I6AT0200I6AT00`000000<c<c03<c<`05
03<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`03
07moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<3o`0000H0c<c<1?l00006
0;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP02
06IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@08
01TI6@0300000?l0003o000000[o00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Oo<c<c00?o000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0
Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00`000000/k>c0;>c/`060;>c/`03o`00003<c<`0
c<c<00X0c<c<00<000000>KViP3Vi^H05`3Vi^H2000000X0c<c<00<000000;>c/`2c/k<01P2c/k<0
0`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH0
0`000000C4a<04a<C00504a<C00300000?lc<c?o<c<c00?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool03Ol000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo
00<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`080;>c/`Ko00002@2c/k<00`00
0000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH00P1VIVH00`00
0000C4a<04a<C00404a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT02@0I6AT00`00
003o0000o`00000:o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07oc<c
<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0407mo
O`030000002IVIT0VIVI00D0VIVI00<000000;>c/`2c/k<01P2c/k<00`000000c<c<0<c<c00:0<c<
c08000005@3Vi^H2000000/0c<c<00<000000;>c/`2c/k<01P2c/k<00`000000VIVI09VIV@0509VI
V@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00504a<
C00400000?lc<c?o<c<coc<c<`?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool03_l000000`0000006ATI01TI6@0801TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<
C01<C4`00`1<C4`2000000@0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VI
V@8000005P2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IV
IP1VIVH00P1VIVH00ol00000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI
6@0I6AT0200I6AT00`00003o0000o`00000;o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`08oc<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`00
0000Ogmo07moO`0407moO`030000002IVIT0VIVI00H0VIVI00<000000;>c/`2c/k<01P2c/k<00`00
0000c<c<0<c<c00;0<c<c080000000?o00000>KViP3Vi^H03P3Vi^H2000000`0c<c<00<000000;>c
/`2c/k<01`2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00504a<C00400000?lc<c?o<c<coc<c<`?ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool03_l000000`0000006ATI01TI6@0901TI
6@03o`00000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo00<0Ogmo00?o00000000002IVIT01@2IVIT01000003o000000000000000>
0;>c/`<0000000?o000009VIV@2IVIT0102IVIT2000000D0Ogmo00?o000006IVIP1VIVH00`1VIVH0
0`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT0
0`00003o0000o`00000;o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08
oc<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`04
07moO`030000002IVIT0VIVI00D0VIVI00?o00000;>c/`2c/k<01`2c/k<00`00003o00000<c<c00<
0<c<c0L000001P3Vi^H200000003o`0000000000c<c<00`0c<c<00?o00000;>c/`2c/k<01`2c/k<0
0`000000VIVI09VIV@0509VIV@03o`00001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH0101VIVH0
0`000000C4a<04a<C00604a<C00400000?lc<c?o<c<coc<c<`?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool03ol0000;01TI6@030000000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP03o`0000000000Ogmo00@0Ogmo0P000008
09VIV@@000001P2c/k<4000000P0VIVI0P00000507moO`8000001@1VIVH00`000000C4a<04a<C004
04a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`00000;
o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08oc<c<`030000001<C4`0
C4a<00H0C4a<00<0000006IVIP1VIVH01@1VIVH00ol00000Ogmo07moO`0507moO`030000002IVIT0
VIVI00D0VIVI00<000000;>c/`2c/k<0202c/k<00`000000c<c<0<c<c00A0<c<c0H000003`3<c<`2
000000T0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0507moO`030000001VIVH0
IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`01000003o<c<coc<c<olc<c<3ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`03o`000?oooooooooo00oo000000<0000001TI6@0I6AT02@0I6AT0
0`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH0
0`000000Ogmo07moO`0407moO`8000002P2IVIT6000000X0VIVI0P00000607moO`030000001VIVH0
IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0503<c<`030000000I6AT0
6ATI00T06ATI00<00000o`000?l000003?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool02Olc<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00D0IVIV00<00000
07moO`1oOgl01@1oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00P0/k>c00<00000
0<c<c03<c<`0903<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00D0VIVI00<00000
07moO`1oOgl01@1oOgl00ol00000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<00000
oc<c<olc<c<00_lc<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo
013o000000<0000001TI6@0I6AT02@0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<
00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`8000005P2IVIT20000
00L0Ogmo00?o000006IVIP1VIVH0101VIVH00ol00000C4a<04a<C00404a<C0030000000c<c<0<c<c
00D0<c<c00<0000001TI6@0I6AT02@0I6AT00`00003o0000o`00000=o`0000?ooooo00?o0000oooo
ooooool0<Oooool01?l0003oooooooooool00009oc<c<`030000001<C4`0C4a<00H0C4a<00?o0000
06IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00D0VIVI00<00000
o`00002c/k<0202c/k<00`00003o00000000000R0<c<c003o`00002c/k<0/k>c00P0/k>c00?o0000
09VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV00?o0000
04a<C01<C4`01@1<C4`00`00003o<c<coc<c<`03oc<c<`?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00?o0000ooooooooool04?l000000`0000006ATI01TI6@0901TI6@030000000c<c<0<c<c
00D0<c<c00?o000004a<C01<C4`0101<C4`00ol00000000006IVIP0506IVIP03o`0000000000Ogmo
00H0Ogmo00<0000009VIV@2IVIT04P2IVIT00`000000Ogmo07moO`0507moO`8000001P1VIVH20000
00H0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0901TI6@0300000?l0003o0000
00go00000oooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000Wo<c<c00<00000
04a<C01<C4`01P1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0Ogmo00D0Ogmo00<00000
09VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`090;>c/`030000003<c<`0c<c<01d0c<c<0P00000:
0;>c/`030000002IVIT0VIVI00H0VIVI00<0000007moO`1oOgl01P1oOgl00`000000IVIV06IVIP04
06IVIP030000001<C4`0C4a<00H0C4a<00<00000oc<c<olc<c<00olc<c<3ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`03o`000?oooooooooo013o000000<0000001TI6@0I6AT02P0I6AT00`00
0000<c<c03<c<`0503<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`00
0000Ogmo07moO`0507moO`<000003P2IVIT3000000L0Ogmo00<0000006IVIP1VIVH01@1VIVH00`00
0000C4a<04a<C00504a<C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02@0I6AT00`00
003o0000o`00000>o`0000?ooooo00?o0000ooooooooool0<Oooool01Ol0003oooooooooo`0I6AWo
000000Wo<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0
Ogmo00D0Ogmo00<0000009VIV@2IVIT01`2IVIT00`000000/k>c0;>c/`090;>c/`8000006P3<c<`3
000000/0/k>c00<0000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0
IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`00003o<c<coc<c<`03oc<c<`?ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool04Ol000000`0000006ATI01TI6@0901TI
6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IV
IP030000001oOgl0Ogmo00L0Ogmo3P00000907moO`03o`00001VIVH0IVIV00D0IVIV00<0000004a<
C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00T06ATI00<00000o`00
0?l000003_l00003ooooo`03o`000?oooooooooo037ooooo00Go0000ooooooooool06ATIo`000009
oc<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`05
07moO`030000002IVIT0VIVI00L0VIVI00<000000;>c/`2c/k<02P2c/k<00`000000c<c<0<c<c00E
0<c<c08000003@2c/k<00`000000VIVI09VIV@0609VIV@03o`00001oOgl0Ogmo00H0Ogmo00<00000
06IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C00300000?lc<c?o<c<c00Co<c<c0oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Ao`0000030000000I6AT06ATI
00X06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00504a<C08000001P1VIVH00ol0
000000000000000K07moO`8000001P1VIVH2000000L0C4a<00?o000003<c<`0c<c<01P0c<c<00`00
00006ATI01TI6@0901TI6A;o00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00806ATI00?o0000oc<c<olc<c<01olc<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV
00D0IVIV00?o000007moO`1oOgl01P1oOgl00`000000VIVI09VIV@0709VIV@03o`0000000000/k>c
00X0/k>c00@00000o`00000000000000403<c<`3000000d0/k>c0P00000909VIV@030000001oOgl0
Ogmo00D0Ogmo00?o000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C00300000?lc<c?o
<c<c00Co<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Co`00
00`06ATI00<0000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00604a<C0030000001VIVH0IVIV
00H0IVIV0`00000E07moO`<000001P1VIVH2000000P0C4a<00<0000003<c<`0c<c<01`0c<c<00`00
00006ATI01TI6@0901TI6@0300000?l0003o000000oo00000oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00806ATI00?o0000oc<c<olc<c<01olc<c<00`000000C4a<04a<C00704a<
C003o`00001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0809VI
V@030000002c/k<0/k>c00`0/k>c1`0000020<c<c0L000003`2c/k<00`000000VIVI09VIV@0809VI
V@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<
C00300000?lc<c?o<c<c00Co<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003o
ooooooooo`0Bo`0000030000000I6AT06ATI00/06ATI00<0000003<c<`0c<c<01P0c<c<00`000000
C4a<04a<C00604a<C0030000001VIVH0IVIV00P0IVIV0`00000>07moO`@00000201VIVH00`000000
C4a<04a<C00704a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02P0I6AT00`00003o
0000o`00000?o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0201TI6@03
o`000?lc<c?o<c<c00So<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0506IVIP03
0000001oOgl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0202IVIT00`000000/k>c0;>c/`0B0;>c/`80
00005@2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1V
IVH01P1VIVH00`000000C4a<04a<C00604a<C00300000?lc<c?o<c<c00Go<c<c0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Co`0000030000000I6AT06ATI00/06ATI
00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00X0IVIV
3P00000<06IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<00ol000006ATI
01TI6@0:01TI6@0300000?l0003o0000013o00000oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00<06ATI00?o0000oc<c<olc<c<01olc<c<00`000000C4a<04a<C00704a<C0030000
001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0809VIV@030000
002c/k<0/k>c02H0/k>c0P00000:09VIV@03o`00001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH0
1P1VIVH00ol00000C4a<04a<C00704a<C00300000?lc<c?o<c<c00Go<c<c0oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Do`0000030000000I6AT06ATI00X06ATI00?o
000003<c<`0c<c<01`0c<c<2000000L0C4a<00Co00000000000000000000801VIVH2000000L0C4a<
0P00000903<c<`030000000I6AT06ATI00X06ATI00<00000o`000?l000004Ol00003ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool00`0I6AT2o`0000Wo<c<c00<0000004a<C01<C4`0
1P1<C4`00`000000IVIV06IVIP0606IVIP800000201oOgl00`000000VIVI09VIV@0809VIV@030000
0?l00000000002<0/k>c0P00000:09VIV@800000201oOgl00ol00000IVIV06IVIP0606IVIP030000
001<C4`0C4a<00L0C4a<00<00000oc<c<olc<c<01_lc<c<3ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`03o`000?oooooooooo01Go000000<0000001TI6@0I6AT02P0I6AT00`000000<c<c03<c
<`0803<c<`030000001<C4`0C4a<00P0C4a<0P00000K06IVIP<00000201<C4`00`000000<c<c03<c
<`0803<c<`030000000I6AT06ATI00X06ATI00<00000o`000?l000004_l00003ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0100I6AT00ol0003o<c<coc<c<`07oc<c<`030000001<
C4`0C4a<00L0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0607moO`03o`000000
0000VIVI00X0VIVI0P00000O0;>c/`8000002`2IVIT00`000000Ogmo07moO`0707moO`030000001V
IVH0IVIV00L0IVIV00<0000004a<C01<C4`01P1<C4`00`00003o<c<coc<c<`07oc<c<`?ooooo00?o
0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool05_l000000`0000006ATI01TI6@0:
01TI6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`02@1<C4`3000001D0IVIV0`00000:
04a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT02P0I6ATFo`0000?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0501TI6@03o`000?lc<c?o<c<c00Oo<c<c00<00000
04a<C01<C4`01`1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00L0Ogmo00<00000
09VIV@2IVIT02P2IVIT3000001T0/k>c0`00000;09VIV@8000002@1oOgl00`000000IVIV06IVIP07
06IVIP030000001<C4`0C4a<00H0C4a<00?o0000oc<c<olc<c<02?lc<c<01?l0003oooooooooool0
000Kooooo`006_ooool00ol0003oooooooooo`0Go`0000d06ATI00<00000o`00000c<c<0200c<c<0
0`00003o00000000000;04a<C00400000?l000000000000000d0IVIV1000000:04a<C080000000?o
000003<c<`0c<c<01`0c<c<00`00003o000001TI6@0<01TI6@0300000?l0003o000001?o00000ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00D06ATI00?o0000oc<c<olc<c<02?lc
<c<00`000000C4a<04a<C00704a<C003o`00001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl01`1o
Ogl00`000000VIVI09VIV@0<09VIV@0400000?l00000000000000100/k>c0`0000000ol000000000
09VIV@0<09VIV@03o`00001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH01`1VIVH00ol00000C4a<
04a<C00704a<C00300000?lc<c?o<c<c00Oo<c<c00Go0000ooooooooooooooooo`00000Kooooo`00
6_ooool00ol0003oooooooooo`0Fo`0000030000000I6AT06ATI00d06ATI00<0000003<c<`0c<c<0
2@0c<c<00`000000C4a<04a<C00<04a<C0d000003@1<C4`00`000000<c<c03<c<`0903<c<`030000
000I6AT06ATI00d06ATI00<00000o`000?l000004ol00003ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01@0I6AT00ol0003o<c<coc<c<`08oc<c<`030000001<C4`0C4a<00P0C4a<
00<0000006IVIP1VIVH01P1VIVH00ol00000000007moO`0807moO`03o`0000000000VIVI00l0VIVI
1`0000020;>c/`L00000402IVIT2000000X0Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<
04a<C00804a<C00300000?lc<c?o<c<c00Oo<c<c00Go0000ooooooooooooooooo`00000Kooooo`00
6_ooool00ol0003oooooooooo`0Go`0000030000000I6AT06ATI00d06ATI00<0000003<c<`0c<c<0
2@0c<c<3000002<0C4a<0P00000;03<c<`030000000I6AT06ATI00d06ATI00<00000o`000?l00000
5?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01P0I6AT00ol0003o<c<c
oc<c<`08oc<c<`030000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo
07moO`0807moO`8000005@2IVIT2000001D0VIVI0P00000;07moO`030000001VIVH0IVIV00P0IVIV
00<0000004a<C01<C4`01`1<C4`00`00003o<c<coc<c<`07oc<c<`03o`00000I6AWooooo00;ooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool06?l000000`0000006ATIo`00
000=01TI6@030000000c<c<0<c<c00/0<c<c00<0000004a<C01<C4`07P1<C4`00ol00000000003<c
<`0;03<c<`03o`00000I6AT06ATI00d06ATI00<00000o`000?l000005Ol00003ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool01`0I6AT00ol0003o<c<coc<c<`08oc<c<`030000001<
C4`0C4a<00P0C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0907moO`800000:@2I
VIT00ol00000Ogmo07moO`0:07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<C4`01`1<
C4`00`00003o<c<coc<c<`08oc<c<`03o`00000I6AWooooo00;ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00?o0000ooooooooool06Ol00002000000h06ATI00?o00000000000c<c<02`0c<c<0
0ol0000000000000000K04a<C0800000300c<c<2000000l06ATI00<00000o`000?l000005_l00003
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0200I6AT00ol0003o<c<coc<c<`08
oc<c<`03o`00001<C4`0C4a<00L0C4a<00?o000006IVIP1VIVH0201VIVH2000000/0Ogmo00<00000
o`0000000000902IVIT2000000`0Ogmo00?o000006IVIP1VIVH0201VIVH00ol00000C4a<04a<C006
04a<C00300000?l0003o<c<c00Wo<c<c00?o000001TI6@0I6AT00oooool00ol0003oooooooooo`0I
ooooo`006_ooool00ol0003oooooooooo`0Ko`0000030000000I6AT06ATI00d06ATI0P00000=03<c
<`<000005@1<C4`3000000`0<c<c0P00000@01TI6@0300000?l0003o000001Oo00000oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00P06ATI00?o0000oc<c<olc<c<02Olc<c<00`00
0000C4a<04a<C00704a<C0030000001VIVH0IVIV00T0IVIV00<0000007moO`1oOgl02`1oOgl20000
01l0VIVI0`00000<07moO`8000002@1VIVH2000000T0C4a<00<00000oc<c<olc<c<02?lc<c<01?l0
00006ATI01TI6@0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo
01co000000<0000001TI6@0I6AT03P0I6AT2000000h0<c<c1`00000604a<C0P000003@0c<c<20000
01406ATI00<00000o`000?l000006?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02@0I6AT00ol0003o<c<coc<c<`09oc<c<`030000001<C4`0C4a<00L0C4a<00<0000006IV
IP1VIVH02@1VIVH2000000d0Ogmo0`00000H09VIV@@000003@1oOgl2000000X0IVIV00<0000004a<
C01<C4`0201<C4`00`00003o<c<coc<c<`09oc<c<`04o`00000I6AT06ATI01TI6@?ooooo00?o0000
ooooooooool06Oooool001[ooooo00?o0000ooooooooool07Ol000000`0000006ATI01TI6@0?01TI
6@8000004`0c<c<6000001@0<c<c00?o000001TI6@0I6AT0400I6ATLo`0000?ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0:01TI6@03o`000?lc<c?o<c<c00Wo<c<c00<0000004a<
C01<C4`01`1<C4`00`00003o000006IVIP0:06IVIP8000003P1oOgl400000100VIVI1000000?07mo
O`8000002`1VIVH00ol00000C4a<04a<C00804a<C00300000?lc<c?o<c<c00Wo<c<c00?o000001TI
6@0I6AT00P0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo01ko
000000<0000001TI6@0I6AT0400I6AT2000002T0<c<c0`00000A01TI6@0300000?l0003o000001[o
00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00/06ATI00?o0000oc<c<olc
<c<02?lc<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00X0IVIV0P00000@07moOa00
00004P1oOgl00`000000IVIV06IVIP0906IVIP8000002`1<C4`00`00003o<c<coc<c<`09oc<c<`03
o`00000I6AT06ATI00806ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooo
ooooo`0Oo`0000030000000I6AT06ATI01406ATI0P00000T03<c<`<000004`0I6AT00`00003o0000
o`00000Ko`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;01TI6@03o`00
0?lc<c?o<c<c00Wo<c<c00<0000004a<C01<C4`02@1<C4`00`000000IVIV06IVIP0;06IVIP800000
;P1oOgl2000000/0IVIV00<0000004a<C01<C4`02P1<C4`00`00003o<c<coc<c<`09oc<c<`03o`00
000I6AT06ATI00<06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooooooo
o`0Po`0000030000000I6AT06ATI01806ATI00<0000003<c<`0c<c<0800c<c<00`0000006ATI01TI
6@0C01TI6@0300000?l0003o000001co00000oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00`06ATI00?o0000oc<c<olc<c<02Olc<c<00`000000C4a<04a<C00904a<C08000003@1V
IVH00`000000Ogmo07moO`0Y07moO`800000301VIVH00`000000C4a<04a<C00:04a<C00300000?lc
<c?o<c<c00Wo<c<c00?o000001TI6@0I6AT0100I6AT3ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`03o`000?oooooooooo027o00000P00000C01TI6@@000006`0c<c<200000003o`00000I6AT0
6ATI01806ATI00<00000o`000?l000007_l00003ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03@0I6AT00ol0003o<c<coc<c<`09oc<c<`8000002`1<C4`2000000`0IVIV00?o0000
0000001oOgl09@1oOgl3000000`0IVIV0P0000000ol00000C4a<04a<C00804a<C08000002olc<c<0
0ol000006ATI01TI6@0501TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool08ol000000`0000006ATI01TI6@0D01TI6@H000004P0c<c<3000001H06ATI00<00000o`00
0?l000007ol00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03@0I6AT00ol0
003o<c<coc<c<`0;oc<c<`030000001<C4`0C4a<00X0C4a<00<0000006IVIP1VIVH02`1VIVH30000
0200Ogmo0`00000>06IVIP030000001<C4`0C4a<00X0C4a<00<00000oc<c<olc<c<02_lc<c<00ol0
00006ATI01TI6@0601TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool09?l000000`0000006ATI01TI6@0I01TI6A800000600I6AT00`00003o0000o`00000Po`0000?o
oooo00?o0000ooooooooool0<Oooool01?l0003oooooooooo`00000=01TI6@03o`000?lc<c?o<c<c
00_o<c<c00<0000004a<C01<C4`02P1<C4`00`000000IVIV06IVIP0=06IVIP@00000601oOgl40000
0100IVIV00<0000004a<C01<C4`02`1<C4`00`00003o<c<coc<c<`09oc<c<`03o`00000I6AT06ATI
00L06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0Uo`000003
0000000I6AT06ATI04006ATI0P00000So`0000?ooooo00?o0000ooooooooool0<Oooool01?l0003o
ooooooooo`00000>01TI6@03o`000?lc<c?o<c<c00_o<c<c00<0000004a<C01<C4`02P1<C4`00`00
0000IVIVo`00000@06IVIP<000004P1oOgl3000001<0IVIV00<0000004a<C01<C4`02`1<C4`00`00
003o<c<coc<c<`09oc<c<`03o`00000I6AT06ATI00P06ATI0oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00ol0003oooooooooo`0Vo`0000800000?P0I6AT2000002Go00000oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo008000003P0I6AT2o`0000co<c<c00?o000004a<C01<
C4`02P1<C4`300000180IVIV4P00000B06IVIP@000002`1<C4`200000003o`000?lc<c?o<c<c00Wo
<c<c0_l0000:01TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0
:?l00002000003X06ATI0P00000Wo`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`03000000l06ATI00?o0000oc<c<olc<c<02_lc<c<00`000000C4a<04a<C00<04a<C0<00000
<P1VIVH00`000000C4a<04a<C00<04a<C00300000?lc<c?o<c<c00_o<c<c00?o000001TI6@0I6AT0
2P0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo02[o000000<0
000001TI6@0I6AT0=P0I6AT00`00003o0000o`00000Wo`0000?ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`04000000l06ATI00?o0000oc<c<olc<c<02_lc<c<2000000l0C4a<0P00
000^06IVIP8000003P1<C4`00`00003o<c<coc<c<`0;oc<c<`03o`00000I6AT06ATI00/06ATI0ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`0[o`0000@00000<@0I6AT2
000002_o00000oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00D000003`0I6AT0
0ol0003o<c<coc<c<`0;oc<c<`8000003`1<C4`3000002T0IVIV00?o00000000001<C4`03@1<C4`2
000000go<c<c00?o000001TI6@0I6AT0300I6AT3ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`03o`000?oooooooooo02oo00000P00000^01TI6@0300000?l0003o000002_o00000oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00D00000400I6AT00ol0003o<c<coc<c<`0<oc<c
<`800000401<C4`3000002<0IVIV0`00000>04a<C08000003_lc<c<00ol000006ATI01TI6@0=01TI
6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0<Ol00002000002T0
6ATI0`00000^o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0600000100
6ATI00?o0000oc<c<olc<c<03Olc<c<00`000000C4a<04a<C00@04a<C0@00000701VIVH300000100
C4a<00<00000oc<c<olc<c<03Olc<c<00ol000006ATI01TI6@0>01TI6@04o`000?ooooooooooo`00
01_ooooo000Jooooo`03o`000?oooooooooo03?o00000`00000S01TI6@<00000<Ol00003ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01`00000@01TI6@03o`000?lc<c?o<c<c00go
<c<c00<0000004a<C01<C4`04`1<C4`3000001D0IVIV1000000B04a<C00300000?lc<c?o<c<c00go
<c<c00?o000001TI6@0I6AT03P0I6AT01Ol0003ooooooooooooooooo000001_ooooo000Jooooo`03
o`000?oooooooooo03Ko00000`00000L01TI6@<00000=Ol00003ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02@00000?01TI6@03o`000?lc<c?o<c<c00go<c<c0`00000E04a<C1<0
000000?o00000000001<C4`0501<C4`00ol0003o<c<coc<c<`0<oc<c<`;o0000400I6AT00ol00000
0000ooooo`02ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo03Wo0000
1`00000B01TI6@<00000>?l00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
2P00000?01TI6@;o00004?lc<c<2000003X0C4a<0`00000>oc<c<`03o`00000I6AT06ATI00l06ATI
00?o00000000000000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooooooo
o`10o`0001800000>ol00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02`00
000@01TI6@;o00004?lc<c<2000003D0C4a<0`00000@oc<c<`03o`00000I6AT06ATI00l06ATI00Co
000000000000000000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003ooooooooo
o`2=o`0000?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;00000003o`00000I
6AT06ATI00l06ATI00?o0000oc<c<olc<c<03olc<c<01000003o000000000000000`04a<C003o`00
0?lc<c?o<c<c013o<c<c00?o000001TI6@0I6AT03`0I6AT00ol00000000000000002000000?ooooo
00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool03000000B01TI6@03o`000?lc<c?o<c<c01;o<c<c0P00
000[04a<C0<000004_lc<c<00ol000006ATI01TI6@0@01TI6@03o`00000000000000008000000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0=000001806ATI00?o0000oc<c<olc<c<04olc<c<0
0`000000C4a<04a<C00T04a<C0@000004olc<c<2o`0001806ATI00?o00000000000000000`000003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03o`000?oooooooooo08go00000oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00h000004P0I6AT2o`0001Co<c<c0`00000P04a<
C0<000005Olc<c<2o`0001806ATI0_l00006000000?ooooo00?o0000ooooooooool06Oooool001[o
oooo00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04000000B01TI6@;o00005Olc<c<400000003o`0000000000000001D0C4a<1000000Foc<c<`;o
00004`0I6AT00ol00000000000000006000000?ooooo00?o0000ooooooooool06Oooool001[ooooo
00?o0000ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
4@00000C01TI6@;o00006_lc<c<E000001So<c<c0_l0000D01TI6@03o`0000000000000000L00000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00ol0003oooooooooo`2=o`0000?ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0B000001@06ATI0_l00013oc<c<`;o00005@0I
6AT00ol00000000000000008000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000
ooooooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04P000000
0ol000006ATI01TI6@0C01TI6@03o`000?lc<c?o<c<c03oo<c<c00?o000001TI6@0I6AT0500I6AT0
0ol00000000000000009000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooo
ooooool0SOl00003ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04`0000000ol0
00006ATI01TI6@0C01TI6@03o`000?lc<c?o<c<c03go<c<c00?o000001TI6@0I6AT0500I6AT00ol0
000000000000000:000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000oooooooo
ool0T?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo093ooooo00?o0000oooooooo
ool06Oooool001[oooooU?l0000coooooiCo00006oooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool008Gooooo0_l00035ooooo`;o0000@_ooool008;ooooo0ol0
00000ooooooo0000ooooo`31ooooo`?o000000?oooooo`000?ooool0@Oooool0083ooooo0_l00002
ooooo`;oZ[gW0_l0002oooooo`;o00001?ooool2o`00047ooooo001mooooo`?o000000?oooooojZm
ionZ_NL00onZ_NL00ol0003oooooo`00002kooooo`?o00001Oooool01?ne]=So0000ooooool00010
ooooo`00N_ooool3o`0000?ooooo1_nZ_NL00ol0003oooooo`00002hooooo`?o00001_ooool3okFd
f003o`000?oooooo0000043ooooo001hooooo`;o00001?ooool8ojZmi`04o`000?nZ_NOoooooo`00
0;Gooooo0_l00007ooooo`03okJce_ne]=So]KCH00;o]KCH00Co0000oooooooooooo0000?oooool0
07Gooooo0ol00002ooooo`;oZ[cW2_nZ_NL01Ol0003oZ[gWojZmiooooooo00000;7ooooo0ol00008
ooooo`?o][?F0one]=P01Ol0003ooooooooooooooooo000003kooooo001cooooo`;o00000_ooool6
ojZli`?oZ[gW00?oZ[cWojZmionZ_NL00onZ_NL01Ol0003oZ[gWojZmiooooooo00000:oooooo0_l0
0009ooooo`03okJae?nf/mKo][?F00?o][?F00Co]KCHokNde_l0003o]kCF0_ooool00ol0003ooooo
ooooo`0looooo`00L?ooool3o`0000?ooooo1onZ_>L00onZ_NOoZ[cWojZli`02ojZli`CoZ[gW00Ko
0000ojZmionZ_NOoZ[gWooooool0002[ooooo`?o00002_ooool3okJae0?o][?F00Co]k;EokNde_ng
]=Ko00000_ng]=H2ooooo`03o`000?oooooooooo03_ooooo001^ooooo`;o00001?ooool2oj^liPKo
Z[cW0_nZ_>H4ojZli`CoZ[gW00Ko0000ojZmionZ_NOoZ[gWooooool0002Yooooo`;o00002oooool0
0onf/=?o][7DokJae003okJae008okJce_ng/]Go]k;EokNbeOng]=Ko0000okNde_nh]=D2ooooo`03
o`000?oooooooooo03_ooooo001[ooooo`?o00000_ooool2oj^kiPGoZkcV0_nZ_>L2oj^liPCoZ[cV
0_nZ_>L2oj^liP?oZ[gW00?o0000ojZmionZ_NL00_nZ_NL00ooooooo0000ooooo`2Tooooo`?o0000
2oooool4okJ`d`?o][7D00?o]k7CokNbeOng/]D00ong/]D01?l0003o^;CEokRdeOnh]=D2ooooo`03
o`000?oooooooooo03[ooooo001Xooooo`?o00000_ooool00on[^nGoZk_Voj^kiP03oj^kiP?oZkcV
00?oZk_Uoj^li_n[_>H00on[_>H2ojZliPKoZkcV0_nZ_NL00ol0003oZkcWojZmi`03ojZmi`03oooo
ool0003ooooo0:3ooooo0ol0000<ooooo`03okF^d_nf/=?o][3C00?o][3C00?o][7DokNadong/M<0
0_ng/M<3okNbe@03okRbe?l0003o^;CE00?o^;CE0_ooool00ol0003oooooooooo`0iooooo`00I_oo
ool2o`0000Cooooo0on[^nD4oj^kiP03oj^li_n[^nGoZk_U00;oZk_U0on[_>H00on[^nGoZkcVoj^l
iP06oj^liP?oZkcW00Co0000oj^lionZ_NOoZ[gW0_n[_NL00ol0003oooooooooo`2Mooooo`;o0000
3_ooool3okF^dP?o][3C00?o]joBokNadong/M<00ong/M<00ong/]Go^;;DokRbe002okRbe004o`00
0?nh]=Go^;CEokVde0;ooooo00?o0000ooooooooool0>Oooool006?ooooo0ol00004ooooo`;oZk[T
1?n[^nD2oj^kiPKoZk_U00?oZkcVoj^kiOn[^nD00_n[^nD2oj^liP03oj^liOn[_>KoZkcV00?oZkcV
0_n[_>L00ol0003oZkcVoj^mi`04oj^mi`03o`000?oooooooooo09Wooooo0ol0000>ooooo`03okF]
d?ne[];o]JkB00?o]JkB00Co][3CokN_d_ng[m;o]joB0ong/M<00onh/M;o^;;DokRbe003okRbe003
o`000?ni]=Co^KCD00;o^KCD0_ooool00ol0003oooooooooo`0hooooo`00HOooool2o`0000Cooooo
00?oZkWToj^ji?n[^^@00on[^^@2oj^ki@;oZk[T1_n[^nD2ojbki@CoZk_U00CoZkcVoj^liOn[_>Go
ZkcU0on[_>H01?n[_>GoZkcVoj^li_l00002oj^liP;oZkgW0_n[_>H00ooooooo0000ooooo`2Goooo
o`;o00004?ooool3okF]d0?o]JkB00?o]jk@okN_d_ng[m800ong[m801?ng/M?o^;7BokRad_nh/M83
okRbe003okVbd_l0003o^KCD00?o^KCD0oooool00ol0003oooooooooo`0gooooo`00G_ooool3o`00
00?ooooo00?oZkWSoj^ii?n[^N@00_n[^N@3oj^ji003ojbihon[^^CoZk[T00?oZk[T0_n[^nD2ojbj
i0Co[;_U0_n[^nD2ojbki@CoZkcU00KoZkcVoj^liOn[_>GoZkcUoj^li_l00007oj^liP03o`000?oo
oooooooo09?ooooo0ol0000@ooooo`03okB[cone[M3o]Jg@00?o]Jg@00Co]JkBokN^d?ng[]3o]jk@
0ong[m800onh[m3o^;7BokRadP03okRadP04okRbe?ni/];o^K;Bo`0000?o^KCD00Go^kCCoooooooo
ooooooooo`00000iooooo`00G?ooool2o`0000Cooooo1?n[^N<4oj^ii004oj^ji?n/^N?o[;WSojbi
h`?oZk[T00?o[;WSojbji?n/^^@00on/^^@2ojbki@;o[;[T1?n/^nD2oj^li@;o[;_U1?n[_>D00ol0
003oZkcVoj^liP05oj^liP03ooooool0003ooooo097ooooo0_l0000Aooooo`Co]:_?0one[M000onf
[<oo]jk@okN^d003okN^d004okN_d_nh[m3o^:o@okR_d0Co^;7B0oni/]800ol0003o^K;BokVde003
ok^dd`?ooooo00?o0000ooooooooool0=_ooool005Wooooo0ol00004ooooo`;oZkSR1?n[^N<2oj^i
i0;o[;SR1?n/^N<00on[^^Co[;WSojbih`02ojbih`?o[;[T00?o[KWRojbji?n/^^@00on/^^@2ojbk
i@03ojfji?n/^nGo[;_U00?o[;_U0_n[_>D00on/^nGo0000oj^liP07oj^liP03ooooool0003ooooo
08gooooo0ol0000Aooooo`03okBYc_ndZloo]:_?00?o]:_?00Co]Jg@okJ/conf[<oo]Zc?1?ng[]00
0onh[/oo^:o@okR_d002okR_d0?o^;7B0_nj/M42okVbdP03o`000?ni/];o^kCC00Co^kCC0oooool0
0ol0003oooooooooo`0eooooo`00Eoooool2o`0000Cooooo00?oZkORoj^hh_n[^>800on[^>82oj^i
h`;o[;OQ1?n/^>82ojbih`;o[;SR1?n/^N<00on/^^Co[KWRojfihP02ojfihP?o[;[T00?o[KWRojfj
i?n]^^@00_n]^^@2ojbki@;o[K_T0on/^nD00ol0003oZkcVoj^liP02ojbli@GoZkcV00?o0000oooo
ooooool0R_ooool2o`0001?ooooo0ondZLh3okB[c`03okJ[c_nf[<oo]Zc?00?o]Zc?0_ng[]02okR^
c`Go^:o@00Co^;7BokZadOnj/M7o^[7A0_ni/]800ol0003o^k?Aok^cd@03ok^dd`05okbdd_oooooo
ooooooooool00000=oooool005Cooooo0ol00003ooooo`03oj^fhOn[]n;oZkOR00;oZkOR0on[^>80
0on/]^3o[;OQojbgh@03ojbgh@;o[;SR00?o[KOPojbhh_n/^>800on/^>82ojbih`;o[KSQ1?n]^N80
0on/^^Co[KWRojfihP02ojfihP;o[K[T00?o[[[Rojfki?n]^n@00on]^n@2ojbki@03o`000?n]^nCo
[;cU00?o[;cU0_n[_>H2ojbli@03ooooool0003ooooo08Oooooo0ol0000Cooooo`03ok>XcOndZLko
]:W>00?o]:W>00Co]:_?okJ[c_nfZlko]Z_>1?nf[<l00ong[]3o^:k?okR^c`02okR^c`?o^:o@00?o
^Jo?okZadOnj/M400onj/M401Oni/];o0000ok^cdOnk/m7o^kCC00Co_;CB0oooool00ol0003ooooo
ooooo`0dooooo`00DOooool3o`0000Gooooo0on[]^44oj^ghP04oj^hh_n/]^3o[;KPojbfh0?o[;OQ
00?o[KGOojfgh?n]]n000_n]]n03ojbhhP03ojfgh?n]^>7o[KSQ00?o[KSQ0_n]^N82ojjhh@Co[KWR
00Co[K[Tojjjh_n^^^;o[[[R0on]^n@01?n^^^?o[K_Tojfki?l00002ojfki0;o[;cU0_n]_>@4ojbl
i@03ooooool0003ooooo08?ooooo0ol0000Eooooo`?o/jS=0ondZLh00oneZLgo]Z_>okJ[cP02okJ[
cP?o]Zc?00?o]jc>okR^conh[/l00onh[/l00onh[m3o^Jo?okV_c`02okV_c`?o^[7A00?o^k7@ok^c
dOl000000_nk/m45okbddPCooooo00?o0000ooooooooool0<oooool004oooooo0_l00006ooooo`;o
ZkGP1?n[]^42oj^ghP;o[;GO1?n/]^001?n/]n7o[KGOojfegon]]Ml4ojfgh004ojbhh_n]]n3o[KOP
ojfgh0?o[KSQ00?o[[OOojjhhOn^^>400on^^>42ojfihP;o[[WQ1?n^^^802?n]^nCo[[[Sojjjhon^
^^?o[K_To`000?n]^nCo[[_S1On]_>@2ojbli@;o[KcU00?o0000ooooooooool0P?ooool2o`0001Ko
oooo00?o/ZK<ok>XcOncZ<d00oncZ<d01?ndZLko]JW=okFYcOneZLd4okJ[cP04okJ/cong[<ko]jc>
okN/cP?o^:k?00?o^Jk>okV_coni[ll00oni[ll00onj/M7o^k7@ok^ad002ok^ad004o`000?nk/m7o
_;?Aokbcd@?o_;CB00?o_KGBooooooooool00_ooool00ol0003oooooooooo`0cooooo`00C?ooool3
o`0000Gooooo00?oZ[CPoj^eh?n[]N000on[]N02oj^fh@03oj^cg_n/]Moo[;GO00?o[;GO0_n/]^02
ojfdgPCo[KGO0_n]]n02ojjegPCo[KOP00Co[KSQojjggon^]moo[[OO0on^^>400on_]moo[[WQojji
h@03ojjih@;o[[[R0_n_^N44ojjjh`04o`000?n^^n?o[[_Sojjkh`?o[KcT00?o[[cTojfliOn]_>D0
0on]_>D00ol0003oooooooooo`1looooo`?o00005_ooool4ok:Vc0?o/jS=00?o]:O<okFYcOneZLd0
0_neZLd3okJ[cP03okNZc?ng[<ko]jc>00?o]jc>00Co^:k?okV^c_ni[/ko^Jk>0oni[ll00onk/<ko
^k7@ok^ad003ok^ad003o`000?nl/m7o_;?A00;o_;?A00Co_;CBokfed_nm]M;o_KGB1?ooool00ol0
003oooooooooo`0booooo`00B_ooool2o`0000Gooooo00?oZ[?OojZdh?nZ]>000_nZ]>03oj^eh003
oj^bgOn[/mkoZk?N00;oZk?N0on/]Ml00on//]co[KCNojfdgP03ojfdgP;o[KGO00?o[[?Lojjeg_n^
]Mh00on^]Mh2ojfgh0;o[kGM1?n^]ml01?n^^>7o[kOOojnggon_]ml3ojjih@03ok2hgon_^N7o[kWQ
00?o[kWQ0_n^^^<00on_^^;o0000ojjkh`03ojjkh`04ojfli?n^_>Co[[cTojjli0?o[KcU00?o[KcT
o`000?ooool0Noooool2o`0001Oooooo00?o/JC<ok:Vc?nbY/`01?nbY/`01?ncZ<go]:O<okBWc?nd
Yl`4okFYc@04okJ[c_ngZ/co]j[<okNZc0?o]jc>00?o^Jc=okV^c_ni[/h00oni[/h01?ni[loo^k3>
ok^`c_nk/<h3ok^ad003okbacol0003o_;?A00?o_;?A1Onm]M83ooooo`03o`000?oooooooooo03;o
oooo0017ooooo`?o00001_ooool3ojZcg`CoZ[CP00CoZkGPoj^bgOn[/]goZk;M1?n[/mh01?n/]Moo
[;;Lojbbg?n//]`3ojfdgP03ojjafon^/mco[[?L00;o[[?L0on^]Mh00on_/m_o[kGMojneg@03ojne
g@;o[[OO00?o/;KMojnggon_]ml00on_]ml01?n^^N7o/;SOok2hgon`^=l3ojnih@05ok2ih?n_^^;o
[k[Rojnjh_l000000_n^^n<2ojnkhPCo[[cT00?o[KcUojfli?n]_>@00_n]_>@00ol0003ooooooooo
o`1fooooo`?o00006?ooool3ok6Tc0Co/ZK<00?o/jG;okBWc?ndYl`00_ndYl`3okFYc@03okJXbong
Z/co]j[<00?o]j[<00Co]jc>okV/cOni[<go^Jc=0oni[/h00onk[/go^k3>ok^`cP03ok^`cP04ok^a
d?nl/Loo_;7?o`0000?o_;?A0_nn]=03okfedP03oknfdOoooooooooo00;ooooo00?o0000oooooooo
ool0<Oooool004Gooooo0_l00007ooooo`03ojVbgonZ/mooZ[?O00?oZ[?O0_nZ]>000on[/MgoZk;M
oj^bg@03oj^bg@;oZk?N00?o[;7Kojbbg?n//]`00on//]`01?n]]=ko[[7Kojjafon^/M/4ojjcg004
ojjeg_n_/m_o[k?Kojncf`?o[kGM00?o/;?Kok2fgOn`]]d00_n`]]d2ojngg`;o/KKM1?n`^=l00on_
^N7o/;WPok2ih002ok2ih0;o[k[R00?o0000ojnkh_n_^n800on_^n82ojjli0;o[kcS1?n]_>@00ooo
oooo0000ooooo`1dooooo`;o00006Oooool00on_Xl_o/JC<ok6Tc003ok6Tc004ok:Vc?ncYL_o/jG;
ok>Ub`Go]:O<00Co]JW=okJXbonfZ<_o]ZS;0ongZ/`00onhZ/_o^Jc=okV/c@03okV/c@04okV^c_nk
[/go^jk=ok^^c@?o^k3>00Oo_;3=okbaconl/Loo_;7?o`000?nl/Loo_;?A00Co_[C@00Co_KGBoknf
dOno]]7o_kKA1?ooool00ol0003oooooooooo`0`ooooo`00@_ooool3o`0000Kooooo1OnY/]l2ojZc
g`;oZ[3L1?n[/Md2oj^bg@;o[:oJ1?n//M/2ojbbg0;o[JoI1?n^/M/2ojjcg0;o[k7I1?n_/m/00on_
]Mgo/;?Kok2cf`02ok2cf`;o/;KM00?o/KCKok6fgOna]]d00ona]]d2ok2hg`;o/KOM1?n`^N001?n_
^^;o/;[Qo`000?n`^^43ojnkhP03ok2khOn__>?o[kcS00?o[kcS0_n]_>@00on^_>Coooooo`00001b
ooooo`?o00006_ooool3ojnSb`?o/JC<00?o/ZC:ok>UboncYL/00oncYL/3okBWc003okFWb_nfZ<_o
]ZS;00;o]ZS;00Co]j[<okRZbonhZ/_o^:[;1?ni[<d00onj[<_o^jk=ok^^c@03ok^^c@04ok^`c_nl
/<go_;3=okb`c@;o_;7?00?o0000okjbc_nn]=000onn]=000ono]<oo_kKAoknfd@02oknfd@Cooooo
00?o0000ooooooooool0<?ooool003oooooo0ol00006ooooo`03ojRbgonY/]ooZK;O00CoZK;O00?o
ZJoLojZ`g?nZ/=`00onZ/=`2oj^ag@03oj^^f_n/[m[o[:oJ00?o[:oJ0_n//M/00on][]So[JoIojf_
f@03ojf_f@;o[[7K00?o[joHojnafOn_/MT00on_/MT2ojncf`;o/;7I1?n`/m/01?n`]]go/KCKok6d
fona]=/3ok6fg@03ok:efona]mgo/KOM00?o/KOM0_n`^N02ok:hgP05ok2jhOl0003o/;[Qok2jhOn_
^n800on`^n42ojnlh`;o/;cR1?n^_>@00ooooooo0000ooooo`1]ooooo`?o00006oooool00on^XL_o
[j?;ojnSb`03ojnSb`04ok6Tc?nbY<[o/ZC:ok:TbPCo/jG;00Co]:O<okFWb_neYl[o]JO:1?nfZ</5
okRZb`;o^Jc=0_nj[</4ok^^c@03okb^c?nl/<go_;3=00?o_;3=00Co_;7?o`000?nn//ko_[;>0_nn
]=03okndc`;o_kKA00?o`KOAooooooooool00oooool00ol0003oooooooooo`0_ooooo`00?Oooool2
o`0000Kooooo00?oYk;OojRbgonX/]l00_nX/]l2ojVbg`03ojR_g?nY[mcoZJoL00;oZJoL1?nZ/=`0
1?n[/MgoZjkJoj^^f_n[[]X4ojb_fP04ojbafon][]So[JkHojf^f0Co[JoI00Co[[7Kojn_f?n_[mSo
[joH0on_/MT00on`[mKo/;7Iok2af@03ok2af@;o/;?K0_nb/]P4ok6df`04ok6fgOnb]M_o/[GKok:e
f`?o/KOM00?o/kOLok:hg_nb^=h00onb^=h00ol0003o/;[Qok:jg`03ok2kh@03ok6khOn`_>;o/;cR
00?o/;cR0_n^_>@2ojnli003ooooool0003ooooo06[ooooo0_l0000Kooooo`03ojfOb_n^XL_o[Z7;
00;o[Z7;0on_Xl/00on`X/Wo/ZC:ok:TbP02ok:TbP?o/jG;00?o]:G9okFWb_neYlX00oneYlX2okJX
b`;o]jS:1?nhZ//00oni[<go^Zc;okZ/b`02okZ/b`;o^jk=0onl[/`3okb`c@03okjacOnn//ko0000
00;o_[;>00?o_[C@okndcono]<l00_no]<l01?no]]7o`KOAol6gdOo1]m45ooooo`03o`000?oooooo
oooo02kooooo000jooooo`?o00001Oooool00onW/^3oYk;OojNbg`02ojNbg`?oZ;;O00CoZK;OojR_
g?nX[mcoZ:oL1?nY[m`2ojZ`g0;oZZcI1?n[[]X2ojb_fP;o[:cG1?n][]P2ojf_f@;o[ZcF1?n_[mP0
1?n_/MWo/:oFok2_e_n`[mH3ok2af@03ok:_eOnb/]So/[;H00?o/[;H0_na]=/2ok>cf0Co/[GK00Co
/KOMok>gg?nc]mco/kOL0onb^=h00onc^=go0000ok:jg`02ok:jg`04ok2khOna^n7o/K_Qok6kh@?o
/;cR00?o/KcRojnli?n__>@00on__>@00ol0003oooooooooo`1Vooooo`?o00007?ooool3ojfObPCo
[Z7;00Co[j?;ok2RbOn`X/Wo/:;91?nbY<X01?ncYL_o]:G9okBUbOndYLT4okFWbP04okJXbongZ<[o
]jS:okNXbP?o^:[;00?o^J[:okZ/bonj[</00onj[</00onk[/go_:k<okb^c002okb^c003okb`cOnn
/Lgo_[7=00;o_[7=00?o0000okjbc_no/lh01Ono]<l5ol6gd@Cooooo00?o0000ooooooooool0;_oo
ool003Sooooo0_l00005ooooo`03ojNbhOnW/^3oYk;P00;oYk;P0onW/]l2ojRbg`;oZ:kL1?nX[m`2
ojV_g003ojV[fOnZ[=WoZZcI00?oZZcI0_n[[]X00on[Z]Ko[:cGojb/e`03ojb/e`;o[JkH00?o[Z[D
ojj/e_n^[=H00on^[=H2ojn_f003ok2/e?n`[mKo/:oF00?o/:oF00Co/;7Iok:_eOnb[mGo/ZoE0onb
/]P00ond/=Go/k?Hok>cf003ok>cf0;o/[GK00?o];CIok>gg?nc]m`00_nc]m`01Onb^=ko/kSMok>h
gOnc^=go000000;o/[[O0_nc^]h4ok6kh@04ok2lh_na_>;o/KcRok6lhP?o[kcT00?o/;gSooooool0
0000IOooool2o`0001gooooo00?oZik:ojfOb_n]WlX00_n]WlX3ojjQb`03ojnPbOn`X/Wo/:;900;o
/:;90onbY<X00onbXlWo]:G9okBUb@02okBUb@?o]JO:00?o]ZK9okNXb_ngZ<X00ongZ<X01?nhZ/_o
^J[:okVZb_niZ/X3okZ/b`03okb]bonl[/co_:k<00?o_:k<1Onn/Ld01?l0003o_k?>okncc_no/lh3
okndc`;o`KK?0oo1]m400oo2^=3oooooooooo`03ooooo`03o`000?oooooooooo02gooooo000eoooo
o`?o00001_ooool3ojNbh@?oYk;P0_nW/]l2ojN^g@CoZ:kL0_nX[m`00onXZ]WoZJ_IojV[f@02ojV[
f@?oZZcI00?oZZSEoj^Ze_n[Z]H00_n[Z]H3ojb/e`03ojfXd_n^Z]Co[Z[D00;o[Z[D0on^[=H00on_
ZM;o/:cDok2/e002ok2/e0?o/:oF00?o/ZcCok:_eOnb[mD00onb[mD01?nb/]So];3EokB`eOnd/=D3
ok>cf003okFbe_nd]=Wo];CI00;o];CI0_nc]m`2okFffP?o/kSM00?o0000ok>jg_nc^]h00onc^]h2
ok6kh@03ok>kgona_>;o/KcR00?o/KcR00Ko[kcTok2mhon`_N?o/;gSooooool0001Qooooo`?o0000
7Oooool3oj^NbPGo[Io:00Co[Z7;ojnPbOn_X<Wo[j391?n`X/T01?nbY<[o/Z?9ok:SbOnbXlT4okBU
b@04okFWb_nfY/Wo]ZK9okJVb@?o]jS:00?o^JS9okVZb_niZ/X00oniZ/X01?nj[<_o_:g;okb]bonl
[L/3okb^c0;o_Zo;1?nn/Ld00ol0003o_k?>oknccP02oknccP03okndcoo1]/oo`KK?00;o`KK?00Co
`KOAol:hd?o2^=3o`[S@1Oooool00ol0003oooooooooo`0/ooooo`00<oooool2o`0000Oooooo00?o
Y[;QojNbhOnW/^400_nW/^42ojNbh003ojJ^gOnW[]goYjkM00?oYjkM0_nX[]`00onWZ]WoZ:[IojRZ
f@02ojRZf@CoZJ_I00CoZZcIojZXeOnZZ=GoZZSE1?n[Z]H01?n/[=Oo[JSBojfXd_n]Z=84ojjZe004
ojj/e_n_ZM;o[jWBojnYdPCo/:cD00Co/:oFok:/donb[=?o/ZcC0onb[mD00ond[M;o];3EokB`e@02
okB`e@03ok>cf?ne/]Ko]K;F00;o]K;F0_nd]=T00ong]=Oo]KKJokFffP03okFffP04ok>hgOne^=_o
0000okFhf`?o/k[N00?o]K[Mok>kgonc^ml00_nc^ml2ok6lhP;o/[cQ0on`_N<00ona_N?oooooo`00
001Oooooo`;o00007_ooool00onYWL[oZik:oj^NbP03oj^NbP?o[Io:00?o[Io9ojnPbOn_X<T00_n_
X<T3ok2Rb@03ok6Qb?nbXlWo/Z?900;o/Z?90ondYLT00oneYLSo]ZK9okJVb@03okJVb@04okNXb_ni
Z<Wo^JS9okVXb@?o^J[:00?o^j_9okb]bonl[L/00onl[L/01?nl[/co_Zo;okj_bonn[l/3okjac@03
oknac?l0003o_k?>00;o_k?>00?o`KC=ol6fcoo1]/l00oo1]/l4ol:hd0Gooooo00?o0000oooooooo
ool0;?ooool0033ooooo0ol00006ooooo`;oY[?R0onV/^42ojNbh@03ojF^g_nV[]goYZkM00;oYZkM
0onW[]d00onVZMWoYj[IojNZf@02ojNZf@CoZ:[I0_nYZmT00onYYmCoZZSEojZXe@03ojZXe@;oZj[F
00?oZjKAojfXd_n]Z=800_n]Z=83ojjZe003ojnWd?n_ZM;o[jWB00?o[jWB0_n`[=@00onbZM3o/ZcC
ok:/d`03ok:/d`04ok:_eOnd[M;o]:gBokB]dP;o];3E00?o]ZoBokFbe_ne/]H00one/]H01?nd]=Wo
]kCGokNdeong]=L3okFffP04okNff?ne^=_o]KSKo`0000;o]KSK00Co/k[NokFjgOne^]go]K[M0_nc
^ml2okBlg`Co/[cQ00Ko/;gSok6mhona_N?o/KgSooooool0001Kooooo`?o00007Oooool00onWVl[o
ZIg:ojVMbP02ojVMbPCoZik:00Co[Io:ojfObOn]WlWo[Io91On_X<T01?n`X/Wo/J78ok6Qb?naXLP4
ok:Sb@04okBUbOneYLSo]JG8okFUb0?o]ZK900?o^:O8okVXbOniZ<T00oniZ<T01?niZ/[o^j_9ok^[
bOnkZlT3okb]b`03okf]b_nn[l_o_Zo;00?o_Zo;00Ko_[7=oknac?no/Lco0000oknac?no/lh3ol6d
c@?o`KK?0_o3]lh2ol:hd0;oa;W@1Oooool00ol0003oooooooooo`0[ooooo`00;Oooool3o`0000Ko
oooo0_nV]><4ojJchP03ojJbhOnU[mooYJkN00?oYJkN1?nV[]d01?nW[]goYZWIojJYfOnVZMT4ojNZ
f@;oZ:[I00?oYjKDojVWe?nYYm@00_nYYm@3ojZXe@03ojZTdOn[Y]7oZjKA00;oZjKA1?n]Z=801?n^
Z]Co[jO@ojnWd?n_Ym03ojnYdP03ok6Vc_nbZM3o/ZW@00;o/ZW@0onb[=<00ondZ/oo]:gBokB]dP02
okB]dP04okB`eOnf[m;o]ZoBokJ_dP?o]K;F00?o^;7CokNdeong]=L00ong]=L02?ne]][o]kKHokNf
f?ng]]So]KSKo`000?ne^=_o^;SJ1?ne^]d00onc^moo];cOokBlg`02okBlg`;o/[cQ00?o/kgQok6m
hona_N<00ona_N<00ol0003oooooooooo`1Fooooo`?o00007oooool3ojNKbP?oZIg:0on[W/X00on[
WLSo[Io9ojfOb@03ojfOb@?o[j3900?o[j38ok6Qb?naXLP00_naXLP3ok:Sb@03ok>SaoneYLSo]JG8
00?o]JG800Co]ZK9okRWb?nhYlSo^:O81?niZ<T5ok^[b@04okb]bonm[L[o_Jg:okf]bP?o_Zo;00Ko
_k3;oknac?no/Lco_k7<o`000?no/L`5ol6dc@05ol6fcoo3]lko`kO>ol>gc_o2^=001?o4^M04oooo
o`03o`000?oooooooooo02_ooooo000[ooooo`;o00001_ooool2ojJeh`CoY[CS0_nV/n801?nU/>3o
YJoOojF_gonU[ml4ojF^gP;oYZkM0_nUZMX4ojJYf@;oYj[I00?oYZGEojNVe?nWY]@00_nWY]@4ojVW
e004ojZXeOnZY=7oZZCAojZTd@CoZjKA0_n]Z=800on]Y<ko[jO@ojnWd003ojnWd003ojnYd_naY/ko
/JK>00Co/ZW@00?o/ZcCokBZcondZ/l00_ndZ/l2okB]dP03okJ/conf[m;o]ZoB00?o]ZoB00Co]K;F
okRadonh/M?o^;7C0ong]=L00oni]=Co]kKHokNff002okNff003okFhfonh^=[o000000;o^;SJ0_ne
^]d2okNkg0?o];cO00?o][cNok>mhOnc_N400_nc_N42ok6mh`;o/[kS00?oooooo`000?ooool0E?oo
ool2o`00023ooooo00?oYI[:ojNKb_nWVlX00_nWVlX4ojVMbP04oj^Nb_n[WLSoZig8oj^Mb0Co[Io9
00Co[j39ojnPb?n_X<So[j381OnaXLP00onbXlWo/j?7ok>Sa`04okFUb003okJUaonhYlSo^:O800;o
^:O80oniZ<T2okZYb0Co^j_91Onm[LX01?nn[l_o_k3;okn`bono/</3oknac003o`000?o1//co`KC=
00;o`KC=00?o`kG=ol>gc_o3]lh00_o3]lh5olBid0Gooooo00?o0000ooooooooool0:_ooool002So
oooo0ol00005ooooo`;oY[KT1?nV]N<2ojJdh`03ojBahOnU/>3oYK3P00;oYK3P0onU[ml2ojF^gP03
ojBZfonUZM[oYJWJ00?oYJWJ0_nVZMT00onUYMGoYZGEojJUe@02ojJUe@CoYjKD0_nYYm@00onXX]3o
ZZCAojZTd@02ojZTd@?oZjKA00?o[:;=ojfTc_n]Y<h00_n]Y<h3ojnWd003ok2Tc?naY/ko/JK>00;o
/JK>0_nbZM000oncYlco]:[?okBZc`03okBZc`04okB]d_nf[<oo]Zc?okJ/c`?o]ZoB00?o^:k?okRa
donh/M<00onh/M<01?ng]=Oo^KCDokVde?ni]=@2okNff0;o^[OF00Co^;SJo`000?nh^=[o^[WI1Ong
^m`01?nd_=oo][cNokJlg_nf_=h2ok>mh@;o]KkP1?nb_^<00ooooooo0000ooooo`1@ooooo`?o0000
7oooool00onSVL_oYI[:ojFJbP02ojFJbPCoYi_:0_nYWLX00onYW<SoZig8oj^Mb002oj^Mb0?o[Io9
00?o[Yk7ojnPb?n_X<P00on_X<P3ok6Qb003ok:QaoncXlOo/j?700;o/j?70_neYLP2okJUa`Go^:O8
00Co^JS9okZYb?njZLSo^ZW80onkZlT00onlZlSo_Jg:okf]bP02okf]bP03okn^bOno/<_o_k3;00?o
_k3;00Go_k7<ol6bc?l0003o`K;<ol6dc@04ol>ec@;o`kO>0_o4^<h3olBid0;oaK_@1Oooool00ol0
003oooooooooo`0Yooooo`009_ooool2o`0000Gooooo0_nV]nD4ojJfi0;oY[GS00?oY;;RojBahOnT
/N400_nT/N43ojF`h0;oYJoO00?oXj_LojBZfonTZ]/00_nTZ]/3ojFYfP03oj>Ue_nUYMGoYJGE00;o
YJGE1?nVYMD2ojNVe003ojNQd?nXX]3oZ:;@00;oZ:;@1?nZY=401?n[Y]7o[:;=ojbRcOn/X/d3ojfT
cP03ojnWd?n`Y<co/:C<00;o/:C<0onaY/h01?nbZM3o/jO<ok>Wc?ncYl`3okBZc`03okJYc?nf[<oo
]Zc?00?o]Zc?00Co]ZoBokR^conh[/oo^:k?0onh/M<00onj/M3o^KCDokVde002okVde0Go^[OF00Co
0000okZifOnj^MWo^[WI0ong^m`00oni^m_o][cNokJlgP02okJlgP03ok>mhOne_^3o]KkP00;o]KkP
0_nb_^<00onc_^;oooooo`00001?ooooo`;o00007oooool00onQV<_oXiW;oj>Ib`02oj>Ib`?oYI[:
0onWVlX00onWV/WoZIc8ojVLb002ojVLb0CoZig800Co[Io9ojjNaon^W/Oo[Yk71?n_X<P01?naXLSo
/Z77ok:QaonbXLL4ok>Sa`03okFUb?nfYLOo]ZG700;o]ZG70onhYlP00oniYlOo^ZW8okZYb003okZY
b004ok^[bOnlZlSo_:_8okb[b0;o_Jg:0ono[/T3okn`b`05ol6ab_o1//co`K;<o`000?o1//`01Oo3
]Ld00oo3]lkoa;S>olBhcP02olBhcP04olBid?o5^m3oaK_@olFkd0Gooooo00?o0000ooooooooool0
:Oooool002?ooooo0ol00004ooooo`;oY[SV1?nV]nD2ojJfi003ojBchonT/^;oY;;R00;oY;;R1?nT
/N400onU/>3oXjcMoj>/g@03oj>[g0CoY:[K00CoYJWJoj>Ue_nSYMKoXjGF1?nUYMD2ojJUe@03ojFP
d?nWXM3oYj7@00;oYj7@1?nXX]02ojZTd@03ojZOc?n/X/go[:;=00;o[:;=0_n]Y<h00on^XL[o/:C<
ok2Tc003ok2Tc0;o/JK>00?o/ZC:ok>Wc?ncYl`00oncYl`01?ndZ/oo]ZW<okJYc?nfZL`3okJ/c`03
okR[c?nh[/oo^:k?00?o^:k?00Co^;7CokZad?nj/M3o^[7@0_ni]=@2ok^ddP?o^[OF00?o_;OEo`00
0?nj^MT00onj^MT01?ng^mco^K_KokVkfoni^m/2okJlgP;o^;gN0one_^000onf_^3o/kkRok>nhP02
ok>nhP03ooooool0003ooooo04[ooooo0ol0000Nooooo`03oinGc?nQV<_oXIS;00;oXIS;0onSVL/4
ojFJbP04ojNKb_nWV/WoYi[9ojNJb@CoZIc80_n[WLP00on/W<Oo[Yk7ojjNa`02ojjNa`?o[j3800?o
/9o7ok:QaonbXLL00onbXLL2ok>Sa`03okFSa_nfYLOo]ZG700?o]ZG700?o^:O8okVWaoniYlL00_ni
YlL3okZYb003ok^YaonlZlSo_:_800;o_:_800?o_Jg:okn^bOno[/T00_no[/T00ono/<_o`K7:ol6a
bP02ol6abP04ol6bc?l0003o`kC;ol>db`?o`kG=00?oaKO=olBhc_o4^<h00oo4^<h4olFkd0Kooooo
00?o0000ooooooooool0:?ooool0027ooooo0_l00004ooooo`;oY[WV1?nV^>H2ojJgi@03ojFdi?nT
/n?oY;?S00;oY;?S1?nT/^82ojBah@03oj:]gonS[=goXjcM00;oXjcM0onSZm`2ojBZf`03oj:Uf?nS
YMKoXjGF00;oXjGF0onUYMD00onSWm7oYJ3@ojFPd002ojFPd0CoYj7@0_nXX]000onXW/coZYo<ojZO
c002ojZOc0;o[:;=00?o[9k8ojjQb_n^XLX00_n^XLX3ok2Tc003ok6QaonbY<[o/ZC:00;o/ZC:0onc
Yl`00oneYLSo]ZW<okJYc003okJYc004okJ/conhZlco^:_<okR[c0?o^:k?00?o^jk=okZad?nj/M00
0_nj/M000oni]=Co^kCBok^ddP02ok^ddP04okZge_nl]mGo_;OEo`0000?o^[WI00Co_;[HokVkfoni
^m_o^K_K0_nk_=/4okRmgP04okFnh?nf_^3o][kPokJnh0;o/kkR0_nd_n800ooooooo0000ooooo`17
ooooo`;o00007_ooool00onMUlgoWiO<oinGc002oinGc0?oXIS;1?nSVL/2ojFJbP03ojFIbOnWV/Wo
Yi[900;oYi[90onYW<P00onYVlOo[9c7ojbLa`02ojbLa`Co[Yk700Co[j38ok2Oaon`WlOo/9o71?nb
XLL01?ncXlOo]J?6okFSa_neXlH3okJUa`03okRUa_niYlOo^JO700?o^JO700?o^ZW8ok^YaonkZLL0
0_nkZLL2okb[b003okj/b?no[/Wo_jk900?o_jk91Oo1/LX00oo1//co0000ol>db`02ol>db`04ol>e
cOo5]lgoaKO=olFgc@?oa;S>0_o6^/h2olFkd0;oakg@1_ooool00ol0003oooooooooo`0Wooooo`00
7_ooool3o`0000Cooooo0_nW^NH3ojJiiP;oY[SV0_nU]^D3ojFdi0CoY;?S0_nT/^800onR[^3oXZgO
oj:]g`02oj:]g`;oXjcM00?oXJOKoj6VfOnQY]T00_nQY]T3oj:Uf0CoXjGF00CoYJGEoj>OdOnSWm7o
XioA0onUX=03ojNQd004ojJLc?nXW/coZ9k<ojRNc0CoZYo<00Co[:;=ojbNb?n/W/So[9k81?n^XLX0
1?n`Y<co/J77ok6QaonaXLL4ok:TbP04ok>Wc?neYLSo]JG8okFUb0?o]ZW<00?o^:O8okR[c?nhZl`0
0_nhZl`00onh[/oo^jk=ok^^c@02ok^^c@;o^[7@0_nm/Lh3ok^ddP06okjedOnl]mGo_;OEokbgeOl0
003o^[WI1?nl^]P00oni^m_o^kcKok^lf`02ok^lf`;o^;gN00Co^KkMokJnh?nf_^3o][kP0_ng_n04
okBohP03o`000?oooooooooo04?ooooo0ol0000Mooooo`03oi^Fc_nMUlgoWIO=00;oWIO=0onOUl`4
oj6Hb`;oXiW;00?oXiS9ojFIbOnUVLT00_nUVLT4ojNJb@04ojVLb?nYVlOoZI_7ojVKa`?o[9c70on^
W/L00on^W/Ko/9o7ok2Oa`02ok2Oa`?o/Z7700?o/j76okFSa_neXlH00oneXlH01?nfYLOo^:G6okRU
a_nhYLH4okVWa`Go^jW700Co_:_8okj/b?nn[<So_Zc80ono[/T2ol6_b@Co`K7:00?o`kC;o`000?o3
]</00_o3]</5olFgc@05olBhc_o6^/koa[[>olJjc_o5^m001?o7_M05ooooo`03o`000?oooooooooo
02Oooooo000Looooo`;o00001?ooool2ojNji`CoYkWV00?oY[WVojFgiOnU]nD01?nU]^D3ojFdi0;o
Y;?S0_nR/>83oj:^h0;oXZgO00?oX:SLoj6WfonQYm/00_nQYm/4oj6Vf@?oXZGH0_nSYMH00onRWm;o
XioAoj>Od@02oj>Od@CoYJ3@00?oYj7@ojJLc?nVW<`01?nXW/`2ojZOc003ojZKb?n/W/So[9k800;o
[9k80on^XLX00on_WLKo/J77ok6Qa`02ok6Qa`?o/ZC:00?o]:;6okFUb?neYLP00oneYLP01?nfZLco
^:O8okRWb?nhYlP2okR[c003ok^[bOnk[/go^jk=00?o^jk=00?o^[7@okfac_nm/Lh00_nm/Lh01?nk
]=;o_[GAokjedOnn]M42okbge@03o`000?nn^=Co_;[H00;o_;[H00?o_[_Gok^lfonk_=/00_nk_=/0
0onm_][o^KkMokVng@02okVng@03okJnh?ng_n3o]koP00;o]koP0_nd_n800one`>?oooooo`000012
ooooo`;o00007Oooool00onIU/ooViK>oi^FcP02oi^FcP?oWIO=1?nOUl`2oj6Hb`03oj6Gb_nSV<Wo
XiS900;oXiS90onUVLT3ojNJb@03ojNIaonYVlOoZI_700;oZI_71?n/W<L01?n^W/Oo[Yk6ojjNa_n^
W/H4ok2Oa`04ok:QaoncXLKo/j76ok>QaPCo]J?61?nhYLH3okVWa`;o^ZS61?nkZLL5okj/b004okn^
bOo1[lWo`Jo9ol6_b@?o`K7:0_o3//X00ol0003o`kC;ol>db`02olFeb`?oaKO=00CoakW=olJjc_o6
^/koa[[>0_o8_<h3olNmd003olVnd?oooooooooo00Cooooo00?o0000ooooooooool09_ooool001Wo
oooo0ol00003ooooo`;oYk_W1?nW^^L2ojNiiP;oY[SV0onU]nD2ojFfi@03oj>ci?nS/^?oXk;S00;o
Xk;S1?nR/>800onR[^3oX:[Noj2Xg003oj2Xg0CoXJOK0_nQY]T01?nOXMKoX9oDoj2Oe?nPWm@4oj:O
dPCoXioA0_nUX=000onTVlcoYYc<ojJLc002ojJLc0?oZ9k<00CoZYo<ojZKb?nZVlSoZY_81?n/W/P0
1?n^XL[o[ig6ojnMa_n_WLH4ok6Qa`04ok:Tb_ndX/Ko]:;6okBRaP?o]JG800?o]jC5okRWb?nhYlP0
0_nhYlP01?nhZlco^j_9ok^[bOnkZlT3ok^^c@03okf^b_nm/Lko_K7>00?o_K7>1?nn]M400onl]mGo
_[SDo`000002okjhe005okbjf?nn^mOo_[_Gokjkeonk_=/01?nm_]X2okVng@03ok_0gOng_n3o]koP
00;o]koP00?o^<7PokG0hone`><00_ne`><00ooooooo0000ooooo`0mooooo`?o00007?ooool00onG
U]3oVIK?oiVFc`02oiVFc`?oViK>1?nMUld2oinGc004oijFbonQUl[oXIO:oj6GbPCoXiS91?nUVLT0
1?nWV/WoYiW7ojNIaonWVLL4ojVKa`;o[9c700?o[9c6ojjNa_n^W/H00_n^W/H3ok2Oa`03ok6Oa_nc
XLKo/j7600;o/j760oneXlH2okJSaPCo^:G600Co^JO7okZXa_njZ<Ko^ZS60onkZLL2okf[a`Co_Zc8
1Oo1[lT01_o1/L[o`k;:ol>bb_o3//[o0000ol>db`?oaKG;00?oaKO=olNicOo7^Ld00_o7^Ld00oo6
^/kob;c>olRlcP02olRlcP04olNmd?o9_]3obKk@olVnd0Kooooo00?o0000ooooooooool09Oooool0
01Kooooo0ol00003ooooo`;oZ;_W1?nW^nL2ojNji`;oY[WW1?nV^>H00onU]nGoY;GUoj>ci003oj>c
i0CoXk;S0_nR/>801?nP[>3oX:[Noj2Zg_nPZ]h4oj2Xg0;oXJOK00?oWZ;GoinQe_nOXMH00_nOXMH3
oj2Oe0CoXYoB0_nSWm400onRV/goY9_<ojBKc002ojBKc0?oYYc<0_nXW/`00onXVLOoZY_8ojZKb002
ojZKb0?o[9k800?o[I_4ojnMa_n_WLH00_n_WLH3ok6Qa`03ok:Na?ndX/Ko]:;600?o]:;600?o]JG8
okNTaOngY<D01?nhYlP5ok^[b@04ok^^cOnm[/[o_Jk:okf^bP?o_K7>0_no//d2okjed@;o`KK?00Co
_[SDo`000?nn^=Co`K[C0onn^mL00oo1_MOo_KkJokfnfP03okfnfP05okVngOnk`=go^l3Mok_0gOng
_n001?nh`N02okG0h`03okK1hooooooo000003_ooooo0ol0000Iooooo`04oi>FdonEU];oUIKBoiFF
dPCoUiK@0onIU/l4oi^FcP;oWIO=00CoW9G<oijFbonNU/_oWYK;1?nQUlX4oj>Hb@;oYIW900?oYIS8
ojNIaonWVLL00_nWVLL3ojVKa`03ojZJa_n/W<Ko[9c600;o[9c61?n^W/H01?n`WlOo/Io6ok6Oa_na
WlH4ok>QaP04okFSa_nfXlKo]Z?6okJSaP?o^:G600?o^JK6okZXa_njZ<H00onjZ<H01?nkZLOo_J_7
okf[aonmZlL3okj/b0;o`:g80oo1[lT00oo2/LSo`k;:ol>bbP02ol>bbP03o`000?o5]L_oaKG;00;o
aKG;1Oo7^Ld5olRlcPCobKk@1_ooool00ol0003oooooooooo`0Uooooo`005?ooool2o`0000Cooooo
0_nX_>P3ojRki`;oYk_W0_nW^^L4ojJii`;oY[SV00CoY;KVojBeiOnT]NGoY;GU1?nS/n@2oj>bh`;o
X:kQ0onP[>03oj2ZgP;oX:SL00?oWJ?JoijReonNX]L00_nNX]L3oinQePCoX9oD0_nRWm800onPV/ko
XY[=oj:Jc@02oj:Jc@?oY9_<0_nVW<`00onUV<OoZ9W7ojRIa`02ojRIa`CoZY_800Co[9k8ojfKa?n]
VlCo[I_41?n_WLH01?naXLOo/Yk4ok:Na?nbW/@4okBRaPCo]jC50_nhYlP2ok^Wa@?o^j_900?o_Z_6
okf^b_nm[/X00onm[/X01Onm/Lko_k;=oknbcOno//go_[GA00Co`KK?00Go0000ol6jdoo1^]?o`K[C
okjke`03ol6me`?o_KkJ00Co_koJok_0gOnk`=go^l3M0_nl`Mh3okS1h003okW2hOnf`N?o]/7S00;o
]/7S00?oooooo`000?ooool0=oooool2o`0001Kooooo00CoT9OFoi6FeOnAU]GoTIKE1?nCU]<3oiFF
dP?oUiK@1?nIU/l2oi^FcP04oiVDcOnLULcoW9G<oibEc0CoWYK;0onQUlX2oj>Hb@;oXiO80onUV<P5
ojNIa`04ojVKaonZV/KoZY[6ojZJaP?o[9c60on^W/H00on_WLGo/Io6ok6OaP02ok6OaP?o/j7600?o
]:75okJSa_nfXlH00onfXlH01?nhYLKo^JK6okVVa_niY/H3okZXaP03okbXa_nmZlOo_J_700?o_J_7
00?o_Zc8ol2]b?o0[LP00_o0[LP01?o1[lWo`[78ol:ab?o2/LP3ol>bbP04o`000?o5]<[oaKG;olFe
b`;oakO;0oo7^Ld2olRjc@?ob;c>0_o:_/l2olVnd0;obl7A1_ooool00ol0003oooooooooo`0Toooo
o`004Oooool3o`0000?ooooo1_nX_>P00onX^nOoYk_WojNki`04ojNji`;oY[WW0_nU^>H3ojBfiP?o
Y;GU0_nS/n@2oj6`h`CoX:kQ0_nP[>02oj2ZgP03oifUg?nMXm[oWJ?J00;oWJ?J1?nNX]L3oinQeP;o
X9oD00?oWY[@oj2Jc_nPV/h00_nPV/h3oj:Jc@;oY9_<00?oXiK8ojFHaonUV<L00_nUV<L4ojRIa`;o
ZY_800?oZYS3ojfKa?n]Vl@00_n]Vl@3ojnMaP03ok2K`_nbW/Co/Yk400;o/Yk40ondX/H00onfX<?o
]jC5okNTa@02okNTa@03okRWb?nkYlGo^jO500;o^jO500Co^j_9okj[a_nnZlKo_Z_60onm[/X01Oo1
[lSo_k;=oknbcOno//go`k?;00Co`KK?0_l00003ol6jd`Go`KgG00Go_KkJoknof_no_m[o_koJok_0
g@04okc1gP04okS1h?ni`^7o^L;QokW2h@;o]/7S0_nf`^<00ooooooo0000ooooo`0cooooo`?o0000
4oooool00on>VM[oSiSHohnHf004oi2GeP?oTIKE0onCU]<4oiFFdP?oUiK@0_nIU/l01?nGU<koVIC=
oiVDcOnIU<d4oibEc0?oWYK;0_nQUlX00onPULWoXiO8oj>Gb002oj>Gb0CoYIS80onWVLL00onXVLOo
ZY[6ojZJaP02ojZJaPCo[9c600Co[Yk6ojnMaOn_WLGo[ig51?naWlH01?ncXLKo]:75okBQaOndXLD3
okJSaP03okNTaOniY/Ko^JK600?o^JK600Co^ZS6okbXa_nlZ<Ko_:S60onmZlL00ono[<Oo`:g8ol2]
b003ol2]b0Go`[7800Go`k;:o`000?l0003oaKC:olFeb`04olNgb`03olNicOo8^/gob;[=00;ob;[=
00Gob;c>olZncoo:_/oob[k?olVnd004ol_1d@Kooooo00?o0000ooooooooool08oooool0013ooooo
0_l00002ooooo`;oZKcX1_nX_>P2ojRki`?oYk_W0_nW^^L2ojJii`CoYKSV00?oY;KVoj>diOnR/^@0
0onR/^@4oj6`h`;oX:kQ00CoWJ[PoifXg_nMZ=koWJSN0onMYM`4oifSfP;oWZ;G00CoVicDoibKd_nL
Vm;oW9_B1?nNV]03oj2JcP;oXY[=00?oX9G9oj>Fb?nSU/P00_nSU/P3ojFHa`?oZ9W700?oZ9K3ojZH
`onZV<<00_nZV<<4ojfKa003ojnMa_n`Vl;o/9_200Go/Yk400Co]:;6okJP`onfX<?o]Z330_ngY<D0
0onjXl;o^jO5ok^Wa@03ok^Wa@Go_Z_600Go_Jk:ol6_b?o1[lSo`Jo8oknbc@03ol>cb`?o000000Co
a;S>o`000?o1^]?o`K[C0_o4_=83ol6me`04ol>oeono_m[o_koJoknofP;o`L;K0onl`Mh00onm`mko
^L;QokW2h@02okW2h@03okK1honf`^?o]/;S00;o]/;S00?o0000ooooooooool0<Oooool2o`0000co
oooo00CoSYkNohjLgOn>W=goSYcM0on>Vm/4ohjIfP;oSiSH0on@UmH4oi6Fe@?oTiKC0_nEU]801?nC
Tm7oUI??oiFCconETll3oiNDcPCoVIC=0onLUL`2oijFb`03oifDb_nPULWoX9G900;oX9G91?nSUlP3
ojFHb004ojNIaonXVLOoZ9W7ojRIa`GoZY[60_n/W<H00on]W<Go[ig5ojnMa@02ojnMa@?o/Io600?o
/Yo5okBQaOndXLD00ondXLD01?nfXlKo]jC5okNTaOngY<D4okVVaPGo_:S600Co_J_7okn/aono[<Oo
_jc70oo0[LP01?o2[lOo`[78ol:ab?o2/LP3o`000003olFdb_l0003oaKC:00GoakO;1?o8^/d00oo:
_Lgob[k?olZnc`02olZnc`05ol_0coo;`M7obl7Aol_1dOo<`m401_ooool00ol0003oooooooooo`0S
ooooo`004?ooool00ol0003oZKgXojVmj004ojVlj0CoZ;cX1?nX^nL00onW^nOoY[[WojJji`04ojJi
i`;oYKSV00CoXkKVoj>diOnS]>GoXkCU1?nR/^@2oj6`h`03oij]h_nMZ^3oWJ[P00;oWJ[P0onMZ=h3
oifUg0;oWJ?J00?oVYkGoi^Le?nKW=@00_nKW=@3oibKdP?oWY[@0_nPV/h00onMU<[oX9G9oj2Eb@02
oj2Eb@?oXiK81?nUV<L01?nXVLOoZ9K3ojRF`onXU/<3ojZH``?o[I_400?o[YS1ok2K`_n`Vl800_n`
Vl83ok:Na003okBM`?nfX<?o]Z3300;o]Z3300Co]jC5okZS`_njXl;o^Z?20onkYlD2okfW``Co_Z_6
1?o1[lP01_o3/l_o0000o`000?l0003o`k?;ol6fc`?oa;S>00?o0000olBld_o4_=800_o4_=801Oo1
_MOo`koGol>oeoo3_mOo_koJ00Co`L;K00Co_<7Nokg3g_nm`mko_L?N0_ni`^43ok[3h@;o]/;S00?o
]/?Tooooool00000<_ooool00ol0003oooooo`000006ooooo`04ohnRh_n>X>3oSZ3PohjPh0?oSYkN
0on>W=d3ohjKf`?oSYWJ0on?V=P3oi2GeP;oTIKE00CoSiCDoi6Cd_nATm;oTI?B0onCTm43oiFCc`Co
UiC>0onIU<d2oibEc003oi^CbonMU<[oWIC:00;oWIC:0onPULT4oj>Gb0;oYIS800?oYIO7ojRIaonX
VLL00onXVLL3ojZJaP04oj^Ja_n]W<Go[Ic5ojfLa@Go[ig500Co/Io6ok:OaOnbWlGo/Yo51?ndXLD4
okNTa@?o^JK60_njYlD4okbXaPGo_jc700?o`:g8ol:_aoo2[lL00ol00003olBbb0;oaKC:00?o0000
olNfb_o7]l/00_o7]l/2olVic0;ob;[=0oo:_Ld2olZnc`?obl3?00Cobl7Aolc3dOo<`m7oc<?A1_oo
ool00ol0003oooooooooo`0Rooooo`004?ooool01?l0003oZKgXojVmj?nY_NP2ojVlj0KoZ;cX0_nX
^nL2ojNki`?oY[[W0_nV^NL2ojBhi`?oXkKV0onS]>D2oj:bi0;oWjoS0onN[N83oifZh0;oWJSN00Co
VJ?LoiVPfOnIX=WoVJ3I1?nJW]L3oi^Le0?oW9_B0_nNV]000onKU<coWIC:oifDbP02oifDbP?oX9G9
1?nSU/P2ojFHa`03ojFC`onXU/?oZ9K300;oZ9K31?nZV<<00on]VlCo[YS1ojjH`@04ok2K`P03ok:N
a?ndWL3o]9g000;o]9g00_nfX<<00onhWkoo^Z?2okZS`P03okZS`P04ok^WaOnmYl?o_JO3okfW``?o
_Z_60_o1Zl@01?o1[lSo0000o`000?l00003ol>cb`04olJeb_o4^<koa;S>olBhcP;oak[>00Co0000
olBld_o4_=;oa[kB0oo3_mL2olG2e`?o`L;K00Go`/CKokg3g_nm`mko_L?Nokk5g`04ok[3h@03ok[5
h_nf`nCo]/?T00;o]/?T00?o0000ooooooooool0<?ooool01Ol0003oooooooooool0003oTJOT00?o
T:GS0on?X^83ohjPh0?oSYkN0on>W=d3ohjKf`03ohjIf_n;UmWoS9KG00;oS9KG0on>U=H4ohnDe0?o
TI?B0onCTm43oiFCc`?oUiC>0_nIU<d00onHT/coVi?;oi^Cb`02oi^Cb`?oWIC:1?nPULT2oj>Gb003
oj:Fb?nUUlOoYIO700;oYIO71?nXVLL01?nZV/KoZi[6oj^Ja_n[V/H4ojfLa@?o[ig500?o/9k5ok:O
aOnbWlD00_nbWlD3okBQa@03okJRaOngY<Go]jC500?o]jC500Co^JK6okZWaOnjYlGo^ZO50onlZ<H0
0onnZ/Ko_jc7okn/a`02okn/a`06ol6]a_l0003o0000o`000?o2[lOo`[781?o4//P01_o5]<[oakK:
olNfb_l0003oakK:olNgb`?obKW<00?ob;[=olZmcOo:_Ld00_o:_Ld00oo:_/oobl3?ol_0c`02ol_0
c`Coc<?A1_ooool00ol0003oooooooooo`0Rooooo`004?ooool00ol0003oooooojVmj008ojRlj0;o
Yk_X1?nW^nL00onV^^OoYKWWojFii`04ojBhi`?oXkKV00?oXkCUoj2bi?nP/^@01?nO[n<3oij]hP03
oifZh?nJY]koVJ?L00?oVJ?L0onIX=T4oiZNe`?oVicD00?oW9_BoiVEc_nKU<`00onKU<`3oifDbPCo
X9G90_nSU/P00onRTLCoYI?3ojFC``02ojFC``CoZ9K30_nZV<<00on[UL3o[YS1ojjH`@02ojjH`@;o
/9_200?o/IVnokBM`?ndWL000ondWL001?nfX<?o^9nookRO_onhWkl4okZS`PGo_JO300?o_Z_6ol6[
a?l000000_l00004olB`a`05ol>cboo6]L[oa[G:olJeb_o4^<h01?o7^/h01Ol0003oa[kBolJnd_o6
_];o`koG00CoaL;G00Go`L;Kol;4foo2a=_o`/CKokg3gP03okk5g`03ok[3hOnjaN;o^/GR00;o^/GR
0_nf`n@00onfa>Coooooo`00000aooooo`03o`000?nCZNGoTjWU00?oTJOT0on@YN<3ohnRhP?oSZ3P
00?oSYkNoh^Lg_n;V]d00_n;V]d3oh^Hf`?oRiOI0on<U]L3ohjDeP?oSiCD0onATm83oi>Cd@?oUI??
0_nGU<h00onFT/goV9;<oiRBc002oiRBc0?oVi?;1?nMU<X2oj2Eb@03oj2Db?nRU/SoXYK800;oXYK8
0onUUlL3ojRIa`03ojRHa_n[V/KoZi[600?oZi[60on]W<D01?n_WLGo/9k5ok2NaOn`W/D5ok:Oa@04
okBQaOnfX/Go]Z;5okJRa@?o]jC500?o^JG5okZWaOnjYlD00onjYlD01OnlZ<Ko_Z[6okjZa_nnZ/Ko
_jc700?o000000Co`Jg6ol:_aoo2[lOoa;771Oo4//P4olNfbP03o`000?o9^LcobKW<00;obKW<1Oo:
_Ld01?o<_lkobl3?ol_0coo;`<l2olg2d0;oc<?A0_o>aM86ooooo`03o`000?oooooooooo027ooooo
000?ooooo`04o`000?ooooooooooooooo`OoZ;cX1?nW^nP2ojNki`03ojJjionU^NOoYKWW00;oYKWW
0_nT^>L01?nS]^KoXKCVoj6di_nQ]>H4oj2bi0;oWjoS00?oW:cRoi^Yh?nKZN000_nKZN02oiZVgPCo
VJ?L0onIX=T2oiZNe`04oiJHdonGU]7oUiKAoiNFd@?oVIG>0onKU<`4oifDbP;oX9G900?oWY35oj:A
a?nRTL@00_nRTL@3ojFC``?oZ9K300CoZ9:ooj^E`?n[UL3oZiG01?n^V<401?n`Vl;o/IVnok6I__na
VKh4okBM`0Co^9no0onjXl82okbS`0?o_JO30ol00002ol6[a0Goa;371?o6]LX5olNjcP05o`000?o6
_];oa[kBolJnd_o9`M<00oo5`]L01Oo7a=So`/CKol;4foo2a=_o`lKL00?o_/GO0_noa^03ok[5hP03
ok[6honfa>Co]/CT00;o]/CT00?oooooo`000?ooool0;_ooool00ol0003ooooooi>Yi@02oi>Yi@?o
TJOT00?oT:GSohfShon<X>400_n<X>43oh^Nh0?oRicN0on;V]d3oh^Hf`;oRiOI1?n<U]L3ohjDeP?o
SiCD0onATm800onCTm7oTI7@oi>Ac`02oi>Ac`CoUY;=0onHT/`4oi^Cb`;oWIC:00?oWI?9oj2Db?nP
U<P00_nPU<P3oj:Fb0CoYIO700CoZ9W7ojRHa_nXV<KoZ9S61?n[V/H2ojfLa@03ojjLaOn`W/Go/9k5
00?o/9k50onbWlD00oncX<Go]Z;5okJRa@02okJRa@03okNTaOniYLGo^JG500;o^JG50onjYlD00onl
Z<Go_Z[6okjZaP03o`0000Co`Jg600Co`Zo7olBaaoo4/LOoa;770oo4//P2olJdb@?oakK:00Co0000
olRhb_o9^LcobKW<0_o;_<`3olZmc@?oc;o>00Gobl3?olg2d?o=`]3ocL;@olc3d@03olk5dP03olo8
dooooooooooo00Cooooo00?o0000ooooooooool08?ooool000oooooo00?o0000ooooooooool00_oo
ool7ojRlj0CoYk_X0onV^^L2ojFii`;oY;SW0onS]^H3oj6diP;oX;;T0_nM[n@3oib/hPCoVjWP0_nJ
Y]h2oiVSg004oiFMfOnEV]OoUI[GoiFJe`?oUYSC1?nGU]42oiVEcPCoViC<0_nMU<X00onKSlKoWY35
oij@a@02oij@a@?oXY741?nUTl<00onXU/?oZ9:oojRB_`04oj^E`0;o[YS100?o[iJmok6I__naVKh0
0_naVKh3okBM`0;o]Ybm1?nhWkl01?njXl;o_:?0okbS`?nlXl03o`0000;o`:S10_o1Zl@2olB]``?o
a;370_o7//H2olJebP;obKS90oo7^/h2olZmcP03o`000?o6_];obL7C00;obL7C00GoaL;GolO4f?o7
a=SoalCHol;4f`03ol?6g003okk5gonoa^3o_lKP00;o_lKP00Co^/GRok[6honja^?o^/KS0_nfa>@0
0onfa>Goooooo`00000_ooooo`03o`000?ooooooT:OU00;oT:OU1?n?YN@2ohfSh`?oS:3Q0on;W^03
oh^LgP?oRi[M0on;V=/2oh^Gf@;oS9KG00CoRI?Goh^BeOn;T]GoRi;E0on=T]<3ohnAdP?oTI7@0onC
TLl3oiJBc@CoV9;<0_nKTl/00onJT/[oWI?9oifCb@02oifCb@?oX9C81?nRU/P2ojFGa`03ojFGa_nX
V<KoZ9S600;oZ9S61?n[V/H01?n]W<Go[Yc5ojjLaOn^W<D4ok2Na@03ok:OaOncX<Go/j3500;o/j35
0_nfX/D00ongXlGo^JG5okVUa@03okVUa@03okZWaOnlZ<Go_:S500?o00000_nnZ/H5ol6]aPGoa;77
00?oa;;8olJdbOo6]<T00_o6]<T01Oo7]/[ob;S:olRhb_l0003obKW<00Cobkc<00Gob[g=olboc_o<
_lkoc;o>olk2c`03olg2d004olo5dOo>aM;oc/GBolk5dP?oclSC1Oooool00ol0003oooooooooo`0P
ooooo`003oooool00ol0003oooooooooo`03ooooo`GoZ;cX1_nW^nP00onV^^OoYKWWojFii`04ojBh
i`?oXkKV00?oXKCVoinbiOnO/^D01?nM[n@3oib/hP;oVjWP00?oUZCOoiFQg?nEXM`01?nEWMT3oiFJ
e`?oUYSC0onGU]43oiVEcP;oViC<00?oV8o8oi^?a_nKSlH00_nKSlH3oij@a@CoXY740_nUTl<00onT
T;ooZ9:oojRB_`02ojRB_`?oZiG000Co[YS1ojnF_On_U[go[iJm1?naVKh01?ndWL3o]YbmokJL_Onf
W;d3okRO_`03okZO_OnlXl3o000000;o000000?o_:?0okfW`oo0Z<400_o0Z<400oo1ZlCoa:g3olB]
``02olB]``05olB`aoo7//Koak;6olNba_o6]LX01?o9^<T01_o7^/kob[g>olZmc_o:_Lkoa[kBo`00
00?obL7C0oo7a=P01?o8amWo`lKLol?6g?o3a]`2olC8g@?o_lKP00Go_lSQok[6honja^?o^/KSok[7
i004okK4i@03ooooool0003ooooo02gooooo00?o0000ooooooooool00on@YnD4ohnUi0;oSJ?S0on<
X>400on;W^3oR9cPohNIgP02ohNIgP?oQiSL0on7U]/2ohRDf@CoRI?G0on;T]D3ohfBd`?oSi7B0_nA
TM04oi>Ac`?oUY;=0_nHT/`00onGTLcoVY;:oiZBbP02oiZBbP?oWI?91?nPU<P2oj:Fb003oj:EaonU
UlKoYIO600;oYIO61?nXV<H2oj^JaP03oj^JaOn^W<Go[Yc500;o[Yc50on`W/D00onaW/Go/j35ok>P
a@03ok>Pa@04okJRaOngXlGo]j?5okNSa@Co^JG50ol00002okbXa@;o_Z[60_no[<H3ol6]aP;o`jo7
1?o4/LL5olJdb@Cob;S:00Go0000ol^lc?o;_<cobkc<olfnc@03olbocP?oc/;?00GocL;@olo5dOo?
aM7oclGAolk5dP04olo8d`Kooooo00?o0000ooooooooool07oooool000oooooo00?o0000oooooooo
ool01?ooool3ojRlj0KoYk_X0_nV^^P3ojFii`;oY;SW0_nR]^L3oj6diP?oWk;U0_nM[n@00onJ[>?o
V:SQoiRXh@02oiRXh@?oUZCO0_nEXM`4oiFMf@?oUI[G0_nFV=<2oiNFd@04oi>@cOnESl_oUHo;oiF?
b`CoV8o80onKSlH4oij@a@;oXY7400CoXHk0ojB@_onTT;ooY92o1?nXT[l2oj^E`003ojbC_?n_U[go
[iJm00;o[iJm0onaVKh00oncV;co]YbmokJL_@03okJL_@04okRO_ol0003o0000o`0000?o_:?000?o
_jBnol2X`Oo0Z<400_o0Z<45olB]``Coak;61Oo9^<T3olZmcP;ocL3>00?obL7Co`000?o9`M<00_o;
a=<01Oo7a=Sob<OIolS7fOo8amWo`lKL00Coa<SM00Go_lKPoko8hOnob>7o_lSQok[6h`03ok[7i0;o
]/CU0_nfaNH00ooooooo0000ooooo`0/ooooo`04o`000?ooooooooooooooo`?oT:OU0_n?YN@00on;
XnCoRZ7SohZQh`04ohRNh@;oR9cP0on7VMh3ohNHg0?oQiKK0_n8U=T3ohVCe`?oRi;E1?n=T]<2ohnA
dP?oTI7@0_nCTLl01?nAT<koU93=oiB@cOnDT<d4oiNAc0?oVY;:1?nMTlT2oj2Db003oinDb?nRULOo
XYG700;oXYG70onUUlH4ojRHaPCoZi[51?n^W<D01?n`W/Go/Ik5ok6NaOnaW/D4ok>Pa@Co]j?500Go
^JG5o`000?l0003o0000okZVa@04okbXa@03okjZa_no[<Ko_jc600;o_jc600Co`Jg6ol>_aoo3[lOo
`jo70oo4/LL2olJcb0?oa[C90_o8]lT2olRhbP;obk[;00?o0000ol^lc?o=_/d00_o=_/d00oo<_lko
c/;?olk2c`02olk2c`CoclGA00Cod<SBolo8doo?b=?oclSC0_o@bm@6ooooo`03o`000?oooooooooo
01kooooo000?ooooo`03o`000?oooooooooo00Gooooo0onX_>P4ojNkj0CoY[[X00?oYKWWoj>hionS
^>L01?nR]^L3oj6diP03oinbiOnL[nGoW:oU00?oVZcS1?nHZ>42oiJTg`?oUJ7L0_nEWMT01?n?V=Oo
T9CDoi2De?n@U=@2oi6Bd@CoTi3=0onESl/3oiR?b0CoVho60_nNT<D01?nMS<7oXHk0oj6>`?nQS/04
ojB@_`?oZ9:o00CoZiG0ojbC_?n/Tkco[9>l1?n_U[d01?naVKko/iRlok>H_?ncV;`3okJL_@;o0000
1?njWkd01?nlXl3o_jBnoknT__noY;h2ol2X`@;oa:Vo0oo4[L<2olN_`P;oak;60_o;]LD3olVhb@;o
c;_900?ob[g>olg0c_o=`<h00_o=`<h01?l0003oblCCol_4doo;a=<3olS7f@;obL[J0oo4b=d01Oo5
b]ko_lSQoko8hOnob>7o_lWR00?o^/OT0_njanD4okK5iP03o`000?oooooooooo02_ooooo00?o0000
ooooooooool00_ooool3ohfUi@?oRj?T0_n:XN<4ohRNh@;oR9cP0on7VMh3ohNHg0;oQiKK0on8U=T3
ohVCe`?oRi;E0_n=T]<00on:Sm?oS8oAohb?d@03ohn?d0CoTI3>0onDT<d3oiNAc0CoVY;:0_nMTlT0
0onLT/WoWiC8oinDb002oinDb0?oXYG71?nUUlH4ojRHaP?oZi[50on^W<D00on_W<Go/Ik5ok6Na@02
ok6Na@?o/j350_neXL@2okNSa@;o000000Co^JG5okZVaOnjY/Go^ZK50onlZ<D00onnZLGo_jc6okn/
aP03okn/aPGo`jo700?oa;77olJcb?o6/lP00_o6/lP01Oo6]<Wob;O9olRgbOo8]lWob;S:00?obk[;
00?o0000olfncOo=_/d00_o=_/d01?o>`Lgoc/;?olk2coo>`/l2om35c`;oclGA0oo@b=801?o?b=?o
d<_Dom3;e?o@bm@6ooooo`03o`000?oooooooooo01kooooo000?ooooo`03o`000?oooooooooo00Ko
oooo00?oZ;cXojNlj?nW_>P01?nW^nP2ojJjj0;oYKWX0onS^>L2oj:fi`04oj2dionN/^KoW[;Voijb
iPCoW:oU0onJ[><2oiRXh@03oi>ThOnAWmkoTIoN00?oT9_K1?n?V=L2oi2De0?oTI;A0onCT<d3oiF?
b`CoV8o80_nKSlH01?nIRl?oWHc1oif<`OnMS<44oj6>`0?oY92o0_nXT[l00onXT;co[9>lojbC_002
ojbC_0?o[iJm00?o/9Fkok>H_?ncV;`00_ncV;`3o`000003okRL^onjWkgo^Ynm00;o^Ynm00?o_J6k
oknT__noY;h00_noY;h00oo0Z<7oa:VoolBY_`02olBY_`05olB]`oo7[l;oajo2olN_`_o7//H01?o;
]LD01?o9^<Woc;_9olbkbOo<^lT5olg0cP03ol_4dol0003oblCC00;ocLSE00?ob<OIolW:f_o9b]X0
0_o9b]X01Oo4b=goaL[NolG:g_o5b]ko_lSQ00?o_lWR00?o^/OTok[7iOnjanD00_njanD2okK5iP;o
]LGV00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`?oSJGU0on;Xn@2ohZQh`;o
R9kQ00?oQIcRohBIh?n4VN000on3Umh3oh>Eg0;oQ9?J0on5T]T3ohJAe`?oR93E0on:Sm<3ohb?d@?o
Sho@0onAT<h3oiB@c@CoUi7<0_nJT/X00onITL[oW9;9oibBb@02oibBb@?oWiC81?nRULL2ojFGaP03
ojJGa_nXV<KoZ9S600;oZ9S61?n[V/D01?n^W<Go[ic5ojnLaOn_W<D4ok6Na@03ok>PaOneXLCo]J74
00?o000000?o]j?5okRTaOnjY/D01?njY/D01?nlZ<Go_ZW5okjYaOnnZLD3okn/aP;o`Jg61?o3[lL4
olJcb003olReb?o8]lWob;O900;ob;O900Kob[W:ol^jboo;^/_obk[;olfmbol00002olfnc@?oc/7=
00Goc/;?om35coo@aLood<G?olo5d@04om38dP?od<_D0_oAcMH6ooooo`03o`000?oooooooooo01go
oooo000>ooooo`03o`000?oooooooooo00Sooooo0onW_>P2ojNkj0;oY[[X1?nU^NP00onS^>OoX[OW
oj:gi`03oj2di`?oW[;V0_nL[nD00onH[>GoUJSSoiFXh`02oiFXh`?oTjCQ0_nAWmh3oi2Kf`?oSiSG
0on@U=@3oi6Bd@?oTi3=0onESl/2oiR?b004oiF:aOnIRl?oVH_3oiV;``CoWHc10onQS/02ojB@_`03
ojB=_?nXT;coZ92l00;oZ92l1?n/Tk`01?n_U[go/9Fkok2E^on`UK/3o`000003ok>H_?nfW;go^9bk
00;o^9bk0_njWkd2okfQ^`Co_jBn1Oo4ZKl4olN_`PGobkG50oo<^lT2om2obP?ocL3>0_o@a<l01Oo;
a=?o0000olg8eOo=b=GoclcF00?obL[J00Cob/gLolG:g_o5b]koaL[N0_o5c>02oko9hP?o_/_S0_nj
anD01onib>Ko]LGVokG5i_neaNKo]<GWooooool00000:_ooool00ol0003oooooooooo`04ooooo`?o
RZCV0on8XN@3ohJNh`?oQIcR0_n4VN03oh>GgP?oPiGL0_n4TmX3ohFBf@?oQY7G0on8T=D3ohZ?d`;o
S8oA0on?Sm04oi6@cP?oU93=0_nGTL`00onFT<_oVI7:oiVAbP02oiVAbP?oW9;91?nOU<P2oj:Ea`03
oj>EaonVUlKoYYO600;oYYO61?nXV<H2oj^Ja@03ojbKaOn_W<Go[ic500;o[ic50onaW/D01?nbWlCo
0000o`000?l00002okFQa004okNSaOnhY<Go^:C5okRTa@Co^ZK51OnnZLD01?no[<Ko`Jg6ol6]a_o1
[LH3ol>_a`;oaK770_o6/lP3olReb0;ob;O90oo:^LX01Oo;^/_ocKg;olfmboo=_L_o000000Coc/7=
1?o@aLl01?oAb=7od<SBom38d_o@b=82om;;d`05om3;e?oAcMKodLgFom7=e_oBd=L01_ooool00ol0
003oooooooooo`0Looooo`003_ooool00ol0003oooooooooo`09ooooo`03ojNlj?nW^nSoYk_X00Co
Y[[X0_nU^NP2oj>hj0?oX[OW0onP]>L00onN/^KoVk3Voi^`iP03oiR/i@CoUJSS0_nCY>43oi6OgP?o
T9_K0on?V=L2oi2De0;oTI;A00CoS8c>ohj:bon>R/_oSX[;0onBR/L3oiF:a@CoVH_30onMS<43oj6>
`004ojB@_onTSKcoY8flojB=_0?oZ92l0on/Tk`00on]TK[o/9Fko`000002o`0000Co/iRl1?nhW;/0
0onjWkgo_J6kokfQ^`02okfQ^`;o_jBn0_o3Y[d4olBY_`Coajo200Cobk?2ol^eaOo;]LGobkG50_o>
^LD00oo<^lWod;o:om2obP02om2obP04olg0c_o@a<ood<C?om34c`;ocLSE00Go0000olo<e_o?c=Ko
clcFolW:fP03ol[=g003olG:g_o5c>3oaLcP00;oa<kR0onnbn<00onmbnGo^LSVokW8iP02okW8iP05
okG5i_ndaNOo]<GWokC5iol00000:_ooool00ol0003oooooooooo`05ooooo`?oRZCV0on8XN@3ohJN
h`?oQIcR0_n4VN03oh>GgP?oPiGL0_n4TmX3ohFBf@?oQY7G0on8T=D2ohZ?d`?oS8oA0on?Sm02oi6@
cP04oi2>c_nCSlcoTho<oi>?c0CoUY3;0onITLX4oibBb@;oWiC800?oWi?8oj>EaonSULL00_nSULL3
ojJGaP?oZ9S600?oZIW5ojbKaOn/VlD00_n/VlD4ojnLa@?o000000?o/Yo4okFQa?neXL@00_neXL@4
okRTa@?o^ZK50_nlZ<D4okjYa@Go`Jg600Go`jo7olFaaoo5/LOoaK77olJcb004olReb003olRgbOo:
^L[ob[W:00;ob[W:1?o=_L/01?o?`<co0000olk1cOo>`Ld2om34cP;od<G?0ooAb=401?o@b=;od/_C
om;;dooBbm<3om7=eP?od]3G1Oooool00ol0003oooooooooo`0Looooo`003_ooool00ol0003ooooo
ooooo`0:ooooo`?oYk_X0_nV^^P2ojFjj0CoXkSX00?oX[OWoinej?nO]NP00onM/nL3oi^`iP?oV:cU
0_nEZ><00on@Y>;oSIoPohfOh003oh^Jg0?oRIKI0on9TMD2ohZ>d@CoS8c>0on>R//3oi::a`?oUH[5
0onIRl<3oif<`@;oXHk000?oX8^mojB=_?nTSK`00_nTSK`4ojR@_004ojbC_?l0003o0000o`0000?o
/9Fk0oncV;`00onfV;[o^9bkokRL^`02okRL^`Go_J6k00Co_jBnol>V_Oo3Y[go`jJm0oo4ZKl2olN/
_`;oajo20oo;/l801?o;]LGoc[W5oljiaOo>^LD5om2obP?od<C?0_oBb=400oo=b=Go0000olo<eP02
olo<eP?ob/gL0_o;cmd00oo5c>3oa<kRolC>hP02olC>hP04okk;honmbnGo_L_Uokg;i@;o^LSV0_nh
b>H2okC5i`03ok?5iooooooo000002Wooooo00?o0000ooooooooool01_ooool3ohZTiP03ohRQi?n4
WnGoPYcS00;oPYcS0on1V^82oh2Gh0?oOiGN0omoTm`2oh2AfP?oPI3I0on3SmL3ohF>e@;oQhkC0on:
S]43ohf>c`CoT8k>0onCSl`3oiJ@b`CoVI7:0onLT/T4oinCb0?oXiG71?nVUlH01?nXV<KoZIW5ojVI
aOnYVLD3ojbKa@04ojnLaOl0003o0000o`0000Co/Yo40oneXL@2okJRa0Co^:C500Co^ZK5okbXaOnl
Z<Go_:S50onnZLD2ol2/aP?o`Jg600?o`k36olFaaoo5/LL00_o5/LL5olReb0Gob[W:00?ocKc;olfm
boo=_L/00_o?`<`00ol0003oc/7=om34cP02om34cP03om35cooAb=7odLSA00;odLSA0ooBbm<2om?>
e003om7=e_oBd=Ood]3G00;od]3G1_ooool00ol0003oooooooooo`0Kooooo`003_ooool00ol0003o
ooooooooo`0;ooooo`03ojNkj?nV^nSoY[_X00CoYK[X0_nS^>P00onR]nSoWkGXoinej002oinej0?o
WK?W00?oVk3VoiN]i_nCZND00onCZND3oi2ThP;oSIoP0on;V]`3ohVFf@?oRI7E0_n:S]43ohb<cP?o
SX[;0onBR/L3oiF:a@?oVH_30_nMS<400onKR;koX8^moj2;_@02oj2;_@?oY8fl0_nXT;`3o`0000?o
[I6j1?n`UK/01?ncV;co]YRjokJH^_nfV;X2okRL^`;o^ifj1?nmXK/5ol>V_@05olBY_oo7[;ooajbo
olN/_oo7[l801?o;/l84oljia@04om:ma_o@_l[od;o:om2obP;odlC;00Sod<C?om;8dOoBb=7od/SA
omC=d_o?c=Ko0000olo<eP;od<oH00?ob/gLol_?gOo;cmd00_o:d^03olC>hP05ol??honmbnGo_L_U
okg;iOnlc>H00onhb>H00ongb>Oo/lGWok?5i`02ok?5i`03ooooool0003ooooo02Oooooo00?o0000
ooooooooool01oooool3ohJRiP;oQ9oU0on2W><3oh6JhP;oP9OP0omoUMh3ognCg0;oP97J0on1T=T3
oh>?e`;oQHkE0on7S]<3ohZ>d@?oSHk?0on@S/h3oi>?c0CoUY3;0_nITLX01?nHT<[oW9;9oibBbOnL
T/T4oinCb0CoXiG70onVUlH4ojVIa@05ojbKaOl0003o0000o`000?n_W<D00on`WLD4ok:Oa004okFQ
a?nfX/Co]Z;4okJRa0?o^:C500?o^ZK5okbXaOnlZ<D00onlZ<D00onnZLGo`:c6ol2/aP02ol2/aP04
ol6]a_o3/<Ko`k36ol>`aP;oaK770_o7]<L3olReb0;ob[S90oo:^LX2olflb`03olfmboo?`<cocl3<
00;ocl3<00Go0000om34c_o@a<kod<C>om;7d003om78d@;odl_B00God/_Com?>e?oCc]CodlkDomCA
eP03om;@e`;odm?H1_ooool00ol0003oooooooooo`0Jooooo`003_ooool00ol0003oooooooooo`0=
ooooo`;oY[_X0_nU^^P2ojBij0?oX[OX0_nO]NP2oifdj0;oV[7W0onG[NH4oi>Yi@;oT:CR0on=Wn03
oh^Jg0?oRIKI0_n9TMD3ohZ>d@?oS8c>0on>R//3oi::a`03oiF:aOnBQL;oUhK000;oUhK01?nKR;h3
oj2;_@;oY8fl0ol00003ojV>^P?o[I6j0on`UK/00onbUKWo]YRjokJH^P02okJH^P04okRL^onkWK[o
^ifjok^M^PCo_J6k00?o`J>jol>V_Oo3Y[d00_o3Y[d4olN/_`Gobk?200?ockO2oljiaOo>^LD00ooB
_LH01Oo@_l[odlC;om?4booCa<_oe/W=00?od/SA0_oDcM800oo?c=Ko0000om3?f002om7Cf`03ol_?
gOo:d^3ob];P00;ob];P00Goa<kRol??hoo3cn?o`loSokg;i@03okc<iP04okS8i_ngb>Oo]lSWokO8
i`;o/lGW00?o//GXooooool00000:?ooool00ol0003oooooooooo`08ooooo`?oQZ;V0_n4WnD3oh:L
h`;oPI[R0on0Un03ognEgP;oOi?L0on0TMX2oh6@f@?oPhoG0on5S]D2ohN>d`?oRXkA1?n=S/l3oi2>
cP?oTho<0_nFT</01?nESl_oV93:oiR@b_nHT<X4oibBb@CoWi?80onSULL3ojJGaP;oZIW50ol00002
ojbKa@03ojfKaOn`WLGo/9g500;o/9g50onbWl@00ondX<Go]Z;4okJRa003okJRa004okRTaOnjY/Go
^ZK5okZVa@?o_:S500?o_Z[5ol2/a_o0[<H00_o0[<H00oo2[/Ko`k36ol>`aP02ol>`aP03olFaaoo7
]<OoakC700;oakC700?ob;G8olZhbOo:^<T00_o:^<T01?o:^L[ocKc;olflboo=_</5olo0c003om74
cOl0003od<C>00?od/O@00CodLSAom?;d_oCbm;odl_B0ooCc]@3omCAeP03om;@eooCdmSodm?H00;o
e=KJ1Oooool00ol0003oooooooooo`0Jooooo`003_ooool00ol0003oooooooooo`0>ooooo`;oYK[X
1?nT^NP00onR]nSoX;KXoj2fj004oifdj0;oV[7W0onG[NH2oi>Yi@03ohjUiOn9Wn;oRIoR00?oQY[O
0on4U=/3oh:?f0;oPX_C0on4R<l3ohJ6c0?oRHG80on>QLD3oi:5`P?oUhK00onKR;h2oj2;_@?o0000
00?oY8flojB;^_nYS[X00onYS[X4ojfA^P03ok2E^onbUKWo/YFi00Co]YRj1?nkWKX3okfQ^`;o`J>j
0oo3Y[d2olJY_0;oajbo0_o;/;h3ol^c`P;ockO200?oc[W5om:ma_oB_LH00_oB_LH3om?4b`?oe/W=
00?od/SAomC=d_oDcM800_oFdMD01Ol0003odM?Kom7CfooAdm_od=KM00?ob];P0_o9dn82ol??h`;o
`M3U0_nlc>H2ok_<i`;o]lSW00?o]LSXok;5j?nbaNP00_nbaNP00ooooooo0000ooooo`0Vooooo`03
o`000?oooooooooo00Wooooo0on2X>H2oh2Mi@;oOY[T0_mlUn83og^Eh0?oNi;N0_mkT=d3ogb?f`?o
OHgI0on3SmL2ohF>e@?oQhkC0on:S]42ohf>c`04ohZ<con>SLkoSXg>ohj=cP?oTHk<0onESl/4oiR@
bP?oW9;91?nOTlP3oj>Ea`;oYYO60ol00002ojVIa@04ojZIa_n]VlGo[I_5ojfKa@Go/9g500Co/Yo4
okBPaOndX<Go]:350onfX/@00onhY<Go^ZK5okZVa@03okZVa@04okbXaOnnZ/Go_Z[5okjZa@;o`:c6
0_o2[/H4ol>`aPGoakC71Oo:^<T3olflb`;ocko<0oo?`<`2om74c@03o`000?oBam3od/O@00;od/O@
0ooCbm82omC>d`03om?>e?oDdMKoe=7F00;oe=7F00?oeMCGom?Cf?oDe]X00_oDe]X6ooooo`03o`00
0?oooooooooo01Wooooo000=ooooo`03o`000?oooooooooo013ooooo0_nU^^P2ojBij0;oX[SX0onP
]^P2oifdj0;oV[;X0_nF[^P3oi:ZiP?oSZGU0_n9Wn83ohJJg`?oQ9CK0on2SmP2oh:;d`?oQ8S?0_n6
Q/`3ohV5b0?oSXG50onBQL83oiN6`0;oVhRn0ol00002oj2;_@04ojB=_?nTRk[oY8^jojB;^P?oZHjj
0on]TKX00on^TKSo/YFiok:E^@02ok:E^@;o]YRj0_nhVKP4ok^M^P03okfQ^oo1Xk[o`J>j00;o`J>j
00Go`jJmolJY_?o6ZKcoaZVlolN/_`04ol^`_P05ol^c`_o?]l;ockO2olng`_oD_<<00ooB_LH2omK3
a`03om?4booFbLgoe/W=00;oe/W=00?ofLk?omC=d_oFdMD00_oFdMD01?oGe]Oo0000om7CfooAdm/2
om3Fg@04ol[Bh?o9dn;obM?RolODi0?o`M3U00Go_m3Vok_<ionkc>Oo^lcWokW;j004okG8j0;o//GX
0_naa>P00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo0on2X>H2oh2Mi@;oOY[T
0_mlUn83og^Eh0?oNi;N0_mkT=d3ogb?f`;oOHgI0omoS=L2oh6<e@?oQ8cC0on7S=44ohZ<c`;oSXg>
0onAS/`4oiF?b`?oV93:0_nLT/T00onKT/WoWi?8oinCb002oinCb0;oXiG70ol00002ojJGaP04ojVI
aOnZVLKoZYW6ojZIaPCo[I_50on`WLD00onaW/Go]:35okBPa@03okBPa@03okJRa?nhY<Go^:C500Co
^ZK500?o_:S5okjZaOnnZ/D00_nnZ/D00oo0[<Ko`Zk6ol:^aP02ol:^aP;o`k360_o6//L3olNda`;o
bKO80oo:^<T2olbkbP03olflboo?_lcocko<00;ocko<00Kocl3<om74cOoAa<godLC=om?7col00002
om;7d0;oe<_A00Godl_BomC>dooDc]?oe<kComKBe@03omCAeP;oeMCG0ooDe]X2omCHg0Gooooo00?o
0000ooooooooool06Oooool000gooooo00?o0000ooooooooool04?ooool4ojBjj0?oX[SX00?oX;KX
oifejOnM]NT01?nJ/^P2oiJ^j0?oTZ[V0on>YND2ohVOhP?oQY[O0on4U=/2oh:?f0;oPX_C0on4R<l3
ohJ6c0?oRHG80on>QLD2oi:5`P?oUhK00_l00002oi^8_P;oX8^m00?oWhRkojB;^_nTRkX00_nTRkX4
ojV>^P03ojfA^_n^TKSo[Y6h00Co/YFi00Co]YRjokRI^?nhVKSo^9Vh1?nkWKX5ol6S^PCoaZVl1Oo;
/;h3olng`P?oe;c300God[g6omK3aooF`lOoe/?7om[8b@03omK9c@;ofLk?0ooFdMD3omOFe`03o`00
0?o@e]god=KM00;ocmSP00GobM?RolODi?o7e>CoamCTol7@i@03oko@iP04ok_<ionibnSo^L_XokW;
j0;o]LSX0ondanP2ok74j003ok34j?l0003ooooo02Cooooo00?o0000ooooooooool02oooool3ogjN
i`;oO9_V0omiV>@2ogbGhP?oNiGP0omkT]h2og^@g@;oO8oK0ommSMT3ogn<e`;oPHcE0on4S=<3ohN<
d@?oRXc?0on>SLh3oi6>c0?oUHo;0onHT<X4oi^Bb@?oWi?80_l00002oj>Ea`;oYYO600?oYYS6ojZI
a_nZVLH00onZVLH3ojfKa@04ok2MaOnaW/Go/Ik5ok6Na@Co]:3500?o]J;5okRTaOnhY<D00_nhY<D2
okZVa@;o_:S51?nnZ/D5ol:^aP03ol>`a_o6//Ooa[;700;oa[;700?oakC7olVgb?o9]lP00_o9]lP0
1?o:^<Woc;_:olbkb_o<^lX5olnoc0?odLC=0ooCall01?l0003oe<_AomC;dOoDbm43omC>d`?oe];E
00?oe=7FomGDeooEe=L00_oFemT00ooDe][oe=SLomCHg003omCKg@Cooooo00?o0000ooooooooool0
6?ooool000gooooo00?o0000ooooooooool04Oooool2ojBjj0;oXkWY0_nP]nT4oifej@;oV[;X00Co
Uk3Yoi:/j?nB[>SoTZcX0on=YnL2ohNQi@?oPY_R0_mnU=l3og^>f`;oNXWG0omjQM83ohB8c`;oQXK<
0on9QLP3ohj5a@;oTXG20ol000001?nGQ/3oVhRnoi^8__nJQK`4oin8^`?oY8^j0onYS[X00onZS[So
[Y6hojjA^002ojjA^0?o/YFi1?nhVKP3ok^M^P;o_Yni1?o1XkX4olJY_004ol^]_?o;/;kobk2nol^`
_P;od;Bo00?ockO2omBl`ooD_<<00_oD_<<3omK3a`?of/S900Koe/W=omW>cooIc/oofLk?om_CdOoF
dMD3omOFe`;oem[J00Co0000oloHh?o?f>3ocmSP0oo7e>@2olGEiP;o_m3V0_nmcnP2okW;j0;o]l[Y
0ondanP00onba^Wo/<CXok34j002ok34j003o`000?oooooooooo02;ooooo00?o0000ooooooooool0
3?ooool3ogjNi`;oO9_V0omiV>@2ogREh`;oMY;Q0omfT=l2ogJ>g@?oMhcK0ommSMT2ogn<e`?oPHcE
0on4S=<3ohN<d@?oRXc?0_n>SLh3oi6>c0;oUHo;00?oU8o;oiR@b_nHT<X00_nHT<X3oi^Bb@?o0000
00CoWi?8oj>EaonSULOoXiK71?nVV<H4ojZIaP;o[I_500?o[Yc5ok6NaOnaW/D00onaW/D2okBPa@;o
]J;51?nhY<D00onjY/Go_:S5okbXa@02okbXa@;o_Z[50_o0[<H3ol:^aP03olBaaoo6//Ooa[;700?o
a[;71?o9]lP01?o;^/Woc;_:olbkb_o<^lX2oljnb`?ocko<0_oA`ld00ooAa<godlO?om?7c`02om?7
c`03omC;dOl0003oe<_A00;oe/oB00Coe<kComKBeOoFd]Goe];E0_oGeML01_oEe=Ooe]OIomKGfOoF
emWoe][KomCHg0Coe=_M1Oooool00ol0003oooooooooo`0Gooooo`003Oooool00ol0003ooooooooo
o`0Booooo`CoXkWY0_nP]nT2oifej@;oVkCY0onG/>T3oi:/j0?oSJOW0_n7XND3oh:KhP;oOYCO0omk
S]/2ogZ9e`;oNXGB0omlP/h2ogn0bP?oQ7o60_n9P<<3o`000004ohn1`?nDPkkoU8>noiB3_PCoVXFl
0onOR;/4ojB;^P03ojV>^_nZS[SoZXjh00Co[Y6h0_nbUKT2okBF]`Co^9Vh00Co^ifjokjO^OnnWkWo
_Yni0oo1XkX2olFU^P;oaZVl0oo;[K`01?o;/;kod;Boom2d_oo@];l5omBl``03omS2a?oF`lOof/S9
00?of/S90ooIc/l2om_Cd@;og=WD00GoemKGomOJf_oGf][oem[Jo`000002oloHh0;ocM[R00?oamCT
olGEi_o5eNH00_o2e>P3okg?j003ok_>jOngb^Wo]l[Y00;o]l[Y00Co]<OXok;6jOnba^Wo//KY0_n`
a>P00on_`nWo0000ooooo`0Sooooo`03o`000?oooooooooo00gooooo0_mnW^L3ogbKiP?oNIST0_mh
UN<2ogJBh@?oMY3O0_mfS]d2ogN<f`?oNH_I0_mkR]L3ogf:e@?oPH[C0on4Rm43ohR;d0;oS8c>0on@
SLd4oiB?b`?oV93:0ol00004oinCb004oj>EaonSU/OoXiK7oj>Fa`?oYYS60onZVLH00on[V/Ko[Yc5
ojjLa@02ojjLa@Co/Ik500?o]:35okFRaOneX/D00_neX/D2okRTa@03okZVaOnlZ<Go_:S500?o_:S5
00?o_Z[5ol2/a_o0[<H00_o0[<H01?o2[/Koa;77olBaaoo4/LL3olJba`;ob;G80_o9]lP3ol^jb@03
olbkb_o>_/_oc[k;00;oc[k;00Gocko<om73cOoA`lgodL?=om?7cP03om?7c`;oeL_@00Co0000omK?
d_oFcm;oe/oB0_oGd]@01?oFd]GoemGGomOEeooGeML3omKGf@;oe][K00Coe]gLomCKgOoDfmgoe=_M
0_oDgMl4ooooo`03o`000?oooooooooo01Oooooo000=ooooo`03o`000?oooooooooo01?ooooo0_nS
^NT2oj6hj@;oW[OY1?nK]>T2oiN`j@;oTZcX00CoSJ[YohJTion6Y>OoQZCW0_moWND3ogVFhP?oM8oN
0_mkS]/2ogZ9e`?oNXGB0_mlP/h3ogn0bP04ohAoa_l0003o0000o`0000;oRH330on?PL03oiB3_P?o
VXFl0onOR;/3ojB;^P03ojF:^OnZS[SoZXjh00;oZXjh0on^TKP01?nbUKWo]9JgokBF]ondU[L4okRI
^0Go_Yni00Go`J>jolFU^_o5YK[oaJFjolJY_004ol^]_0Cod;Bo00Coe;ZoomBl`ooD_<?oe;c30_oH
`/@01?oLb<Gof/S9om[8bOoJb<T2omg?b`03omW>cooKdm7ofm?A00?og=WD0ooGf]X2omKMg@03o`00
0?o=f^;ocM[R00;obm[U00?oaMGVol;Dj?o2e>P00_o2e>P01?nmcnSo^lkYok_>jOnkc^T2okO:j@;o
]LWY0_nba^T00onaaNWo[l?Yojo3j@02ojo3j@03o`000?oooooooooo027ooooo00?o0000oooooooo
ool03_ooool2ogZMj0?oMiWV0_mdU^D2og:Ch`?oLI3Q0_mfT=l3ogJ>g@;oMhcK0omiRmT2og^:e`?o
OH[E0on1R]<2ohB;d@?oR8_@0on<S<h3oi2=c@?oU8o;0ol000001?nHT<[oVi;9oi^BbOnKT/T2oinC
b003oinDb?nSU/OoXiK700;oXiK71?nVV<H01?nZVLKoZi[6oj^Ja_n[V/H3ojjLa@?o/Ik500?o/Z35
okFRaOneX/D00oneX/D01?nhY<Go^ZK5okZVaOnjY/D3okbXa@03okj[a_o0[<Ko`:c600?o`:c61Oo4
/LL01Oo6//Oob;G8olReb?o8]LSobKO800Cobk[91Oo>_//3om73c@?odlO>00OodlO?omG;d?oEbm3o
eL_@omK?d_l0003oe/oB00?oem;D0ooGeML2omSIf004omKGfOoFf]_oe][KomKJf`;oe]gL00?oe=_M
omCMgooDgMl00_oCgn44ooooo`03o`000?oooooooooo01Kooooo000=ooooo`03o`000?oooooooooo
01Cooooo1?nQ^>T2oijgj@;oVkCY0_nH/nX2oi>_jP?oSJ[Y0on6Y>L2ognMi@?oNIKR0_mdSmh2og68
fP?oKh;F0omjQM82ogb2cP?o00000_n4OlH3ohV0``?oSh700onDPkh3oiZ5_0CoWhRk00?oY8^jojF:
^OnUR[T01?nZS[P2ojjA^003ok2B]ondU[Oo]9Jg00;o]9Jg0onhVKP2ok^K^0Co_Yni1?o5YKX5ol^]
_003olnb_?o@];ood;Bo00?oe;Zo00Coe;c3omS2a?oH`/Cof<;40_oLb<D01_oJb<WogLo;omg?booM
cl_ogmK=om_Cd@?og=WD0_oLg]L00ooGf][oe]gMomKMg@02omCOh004o`000?o;f^Gobm[Uol_Ji@;o
b=[W0_o2e>P2okoCj@;o^lkY0_nhcNX2okG9j@03ok?8jOnaaNWo/LGY00;o/LGY0_n_`nT2ojk2j@03
o`000?oooooooooo023ooooo00?o0000ooooooooool03oooool2ogZMj0?oMiWV0_mdU^D2og:Ch`?o
LI3Q00CoLHkOog6<gOmaS=goLHcM0ombR]`2ogV;f@?oNh[G0_mmR]D3oh6:d`?oQ8_A0on8Rm02ohb<
cP?oT8g=0ol000001?nDSl_oV93:oiR@b_nGT</3oi^Bb@CoWiC81?nSU/L2ojJHaP03ojNIaon[V/Ko
Zi[600;oZi[61?n^W<D01?naW/Go/Z35ok:PaOnbX<D3okFRa@03okNTa_njY/Go^ZK500?o^ZK500Co
_:S5okj[a_nnZlKo_Z_60oo0[<H2ol:_a`Coa;771?o8]LP01?o:^LWobk[9ol^jbOo;^/T2oljmb`?o
c[k;0_oA`/`00ooA`lgodlO>om?7cP02om?7cP?oeL_@0_oGcm801?oFcm;o0000omOBe?oGd]@2omSF
eP03omOEeooHfMSof=WH00?of=cJ00?oe][KomKMg?oFgM`00_oFgmh00ooDgMoodmoQom?Oh@02om;Q
h`Cooooo00?o0000ooooooooool05Oooool000cooooo00?o0000ooooooooool05_ooool2oj6hj@;o
WkSZ0onL]^X3oiRcjP;oTjoZ0on=Z^T2ohJTi`?oOigU0omiU^82ogB?gP;oLHSJ0_m_P]H2og1nd@?o
00000omoP<X2ohAoaP?oRH330on?PL04oiB3_P?oVXFl0_nOR;/00onOQk[oYHZiojF:^@02ojF:^@?o
ZXjh00Co[Y6hok2B]on`T[Oo/9:g1?ndU[L01?nhVKSo^i^hok^K^?nkVkP3okjO^@;o`Z:h0_o5YKX2
olVY^P?objfl0_o?/[`00oo@];ooe;ZoomBj_`02omBj_`?of<;40ooLb<D3omg?b`;ogmK=0_oQg=00
1_oLfMCog=kGomcNeooLg]Oog>;JomKMg@;oe=oP0_oAhN<01Ol0003obm[UolSJioo8f^Ooa=WY00?o
_m?Y00Go_=;ZokS=j_nhcN[o^<gZokK<jP04ok?8j@;o/LGY0_n`a>T2ojk2j@03ojg2jOl0003ooooo
023ooooo00?o0000ooooooooool04Oooool01?meVnSoLYSWog:HiombV>L2ofnDiP?oLY?S0omaT>40
1?maS]ooLHcMog6<gOmaS=d2og::g0;oM8WJ0omgR=P3ogZ8eP?oPH[C0_n4Rm43ohR;d0;oS8c>0ol0
00001?n>SLgoThk<oi>>c?nCS/`4oiN@b`?oVi;90onOU<P3oj>Fa`03oj>Gb?nWVLOoYiW700;oYiW7
1?n[V/H2ojjLa@03ojnNa_nbX<Go/Z3500?o/Z3500Co]J;5okNTa_ngY<Ko]jC61?njY/D5okj[aP04
ol2/a_o2[lOo`Zo7ol:_a`?oa;770_o6]<P2olReb0?ob[W900?obk[9oljmboo>_L/00_o>_L/01Oo>
_/_odL;<om72c?oA`/codlK>00?odlO>0ooEbm03omO?dP;of=?C00Ko0000omSFe_oHe]Kof=KFomWJ
f?oHfMP4omSLfP03omSOg?oFgMcoe]oN00;oe]oN00CoeN;Pom?OhOoBhN?od^7S0_oAh^@3ooooo`03
o`000?oooooooooo01Gooooo000<ooooo`03o`000?oooooooooo01Oooooo1?nO^>X00onL]^[oV[G[
oiZej`02oiBaj`?oSZg[0on7YnX2ognQj0?oMiWV0_m_TN<2ofR8g`?oLHSJ0ol000000om`O]7oLg_=
og=kc@03ogQjb@?oOW_50on9P<<3ohn1`0;oU8>n00CoTX6moiV4^onIQ;_oVHBk0onOQkX4ojF:^@;o
ZXjh00?oZhjgok2B]on`T[L00_n`T[L4okBF]`Go^i^h00Go_Yniol:R^?o2X[So`Z:holFU^P04olVY
^P04ol^]_?o?/[cock:lolnb_0Goe;Zo00?ofL71omS2a?oLb<D00ooLb<D00ooPd<SogLo;omoFc@02
omoFc@;ohMc@0ooLg]L2omcRfP03om[Ug_oDgn3odN7S00;odN7S00?o0000olgQi_o8f^L00oo4fNT0
1OnodnWo_=;ZokcBj_nld^[o^<gZ00?o]/cZ0_ncb>T2ok77jP;o/<CY00?o[/?Yojg2jOn]`^T00_n]
`^T00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo00CoMI_Xog:HiombV>OoLYSW
0_m_U>H2offAi0?oJhkR0_m[S>03og6<g@;oLX[L0_mdRMX3ogN8f0;oNXSF0ommRM@2oh69dP;oQH[A
0ol000000on:S<ooSXg=ohj=c@02ohj=c@?oThk<0onGT</3oi^Bb@CoWiC800CoXiK7oj>Gb?nSUlSo
XiO80onWVLL3oj^JaP03ojbLaon_W/Ko[ik600;o[ik60onbX<D00ondX/Ko]jC6okNTaP02okNTaP?o
^ZK50_nkZ<H4okj[aPGo`Zo700Goa;77olJdb?o6]<Soa[C8olReb004olZib@Goc[g;0ooA`/`3om?6
cP04om?7c_oEbm3oeL_@omG;d0?oeloB0ooHdm<00ol0003of=KFomSFeP02omWJf004om[Nf_oHg=[o
f=cJomSLfP;of=oL0ooFgmh2omGRh003omCTh_oBhN?odN;T00;odN;T1?ooool00ol0003ooooooooo
o`0Dooooo`003?ooool00ol0003oooooooooo`0Hooooo`;oWkSZ00?oW[OZoiZejonJ]N/00_nJ]N/2
oiBaj`?oSZg[0on7YnX2ognQj0?oMiWV0_m_TN<01?mXR=oo0000o`000?l00003of=ke@;oL7kA0_mc
Nld3ogQjb@;oOW_50on5O<83ohan_`?oTX6m0onIQ;/4oin7^P?oYHZi00CoZXjhoj^>]on[S[OoZhjg
0on`T[L3okBF]`;o]iRg1?nkVkP4ol:R^0GobJVj1?o?/[`01?oD^;goe;ZoomBj_ooD^[l2omW1`@04
omk8`ooLb<Gog<S5omc8a@;oh=380_oSelX01_oOe/gohMc@on7Ld?oQg=3oh^;ComcNe`;og>;J0_oJ
iMh2omOWh@05om7Qhoo=hNKocN7Vo`000?o9h>T00_o4fNT2ol7Gj`;o_=;Z0_nid>/2okK<jP;o]<[Z
0_naanX00on`aN[o[/?Yojk3j@02ojk3j@;o[L;Y00?o[<7Yooooool000007oooool00ol0003ooooo
ooooo`0Booooo`;oL9[Y0ombV>L2ofnDiP;oKI7T0om[S^801?m[S>3oJhWNof^9g_m[RMh2off8g0?o
M8WJ0_mgR=P3ogZ8eP?oOHWD0ol00002ohF:d@?oRXc?0on>SLd3oi>>c0CoUi3;0onKT/T2oinDb003
oinDbOnSUlSoXiO800;oXiO81?nWVLL01?n[V/Ko[9c7ojbLaon/W<L4ojnNaP04ok:PaOndX/Ko]:;6
okBRaPCo]jC600Co^ZK5ok^Xa_nkZ<Ko^jS60onnZlH2ol2]a`?o`Zo700CoaK;8olJdb?o6]<Soa[C8
0_o9]lT3olZib@;ocKc;0oo>_L/2om32c003om72c?oCa/kodlK>00;odlK>0ooEbm02omO?d@04omO?
d_oHdm?of=?ComSCd`;ofMOE00?o0000omWJf?oIf]P00ooJg]X00ooHg=[of=oLomSOg002omSRgP03
omKOg_oEh^3oeN;P00;oe>CR0ooAh^@2oloSiPCooooo00?o0000ooooooooool04oooool000cooooo
00?o0000ooooooooool06_ooool2oijgjP;oV[G[0_nG]>`2oi6`k0?oRJ_/0_n1YN/3ogNMj@;oK9CW
00CoHh_So`000?l0003oJ8SO0omTPMX2of=ke@;oI7OA0_mcNld3ogQjb@?oOW_50_n5O<83ohan_`?o
TX6m1?nIQ;/3oin7^P;oYHZi00?oYHZhoj^>]on[S[L00_n[S[L4ok2B]`04okBF]ongV;Oo]iRgokNH
]`?o^i^h00?o_ijhol:R^?o2X[P00_o2X[P00oo6Y[WobJVjolVY^P02olVY^P03olj_^oo?/[cock:l
00?oe;Rm00Coe;ZoomW1`OoI`L7ofL710_oNb<<01?oLb<Goh=38on3@b?oPd<P2on?GbP?ohMc@0_oR
h]<00ooQimOog>;Jom[UgP02om[UgP04omOWhOoCj>GodnSUolgQiP;obN3Y00Go0000ol7Gjoo1en_o
`MO[okgEk003okW@j`05okO=jondb^[o]<[ZokC:j_nbb>X01?n`aNX2ojk3j@03ojg2jOn/`NWo[<7Y
00;o[<7Y00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`;oL9[Y0om/U^P01?mY
T^KoIhoUofN?iOmWSnD2of^>hP;oJhcP0om[RMh01?m]R=coKhOKofn7fom_Qm/3og:7f@?oNXSF0_l0
0002oh69dP?oQH[A0on:S<l4ohj=c@?oThk<0_nGT</01?nFT<coVi;:oi^Bb_nKT/X4oinDb@CoXiO8
0_nWVLL00onXV/So[9c7ojbLa`02ojbLa`?o[ik600?o/:37okBRa_ndX/H00_ndX/H3okNTaP03okVW
aonkZ<Ko^jS600?o^jS600?o_Z_6ol2]aoo0[LL00_o0[LL01Oo2[lOoaK;8olFbb?o5//Soa[C800Co
bKO900?ob[W9olflboo=_</00_o=_</01Oo>_L_od<;<om32c?o@`/cod/K>00?odlK>0ooEbm03omO?
d@;ofMCC00Kof=?ComWGeOoIemGofMOEom[Keol00004om[NfP04om[QfooHgmcof>;NomSRgP;oenGP
00?oeN;PomCTh_oDi>800_oCiN@00ooAh^Cocn?VoloSiP02olgTj0?ooooo00?o0000ooooooooool0
4oooool000cooooo00?o0000ooooooooool06oooool2oibgj`CoUkC/0_nA/>`3ohV[k0;oPJG[0_mg
WNT3o`0000;oHh_S0_mKP]l3ofB1fP03of=keOmTMm7oI7OA00?oJGG<0_mhN/T3ogika@?oQGc20on<
O[l3oi:1_@?oVHBk0onOQkX01?nUR[WoYHZhojF:^?nUR[P3oj^>]`?o/9:g00?o/iBgokNH]ongV;L0
0ongV;L01?nkVkSo_ijhoknN^?noW[P2ol:R^0;oaZJi0oo9ZKX3olj_^`05olnb_?oD^;goe;RmomBh
_OoJ_kl00_oI`L43omk8``?oh=380ooSelX01?oVglgohMc@on;RdooRh]<2on7We`;ogncK00Cof^GN
omOWhOoCj>GodnSU0_o>inP01Oo9h>WoaMk[olGNjol0003o`MO[00?o_MG/00Go^M3[okO=jongcN_o
]lg[okC:jP03ok;8jP;o/<GZ00?o[lCZojg2jOn]`^T00_n]`^T2ojc1j@;o[<3Y00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Dooooo`;oL9[Y0om/U^P01OmYT^KoIhoUofN?iOmWSnGoIHcS
00?oI8WQ0om[RMh01?m]R=coKhOKofn7fom_Qm/2og:7f@?o00000_miQmD3ogj8d`?oQH[A0on:S<l2
ohj=c@04ohf=c_nASlgoTHo=oi6?c@CoUY3<0onKT/X3oinDb@?oXiO800?oY9S9ojRJb?nXV/P00_nX
V/P4ojbLa`04ojnNa_n`X<Oo/:37ok2Pa`Co]:;600Co]jC6okVWaoniYlOo^JO70onkZ<H00onn[<So
`:g7ol2]a`02ol2]a`03ol:abOo5//SoaK;800;oaK;81Oo9]lT4olflb`04olo1c?o@`/cod<;<om32
c0?od/K>00CodlK>omG;d?oEbm3oeL_@0ooGcm43omWDd`?ofMOE0_oJfmL01?oKgmWo0000om[Nf_oJ
g]X2om[Qf`04omWTgOoHh]koenGPomOUh0;oe^OR00?oe>CRom?Ui?oCiN@00_oAi^H00oo?hnKocNCX
olgTj002ol_Tj@?ooooo00?o0000ooooooooool04_ooool000cooooo00?o0000ooooooooool07?oo
ool2oibgj`;oUkC/00CoUKC]ohj_kOn>[ngoSZo]0_n5Z^d01?mjXngo0000o`000?l00002ofjJj`04
of6@j?mSRn?oHh_Sof>;h`;oFh;O0_mFNMX01?mDLmGoHg_EofAgdOmTMm42ofUec0?oKgG80omnNlD2
ohEl`P?oS7jo0onBPKd3oiV4^`;oWhNj00?oWhJiojF:^?nUR[P00_nUR[P4oj^>]`04ok2B]oncU;Oo
/iBgok>D]`Co]iRg1?noW[P00oo2X[SoaZJiolJV^@02olJV^@03olVY^_o>[k_ocZnk00;ocZnk1?oD
^;d2omZo_`06omW1`OoNb<?og/S3omk8`ooSd<Goh=380ooSelX2onKOc@03onOVd?oRh]?ohNOG00;o
hNOG00GogncKomc^g_oLk]koenoSom?Xi@02olkWj0;obNG[0_o5g^/01?l0003o`M_/okgEk?nmeN`2
ok[Bk0;o]lg[0_ndbn/2ok;8jP03ok36j_n_a>[o[lCZ00;o[lCZ0_n]`^T2ojg1j@;o[<3Y00?oZkoX
o`000?ooool07Oooool00ol0003oooooooooo`0Dooooo`?oJiSZ0_mVU>T2of>@i`?oIhoU00CoIHcS
ofB9hOmTRN7oI8WQ0_mUQml2ofJ6g@05ofn7fol0003o0000o`000?mbQmT00omeQmL2ogV7e@;oOXSC
0on3R]83ohR;d0CoSHg>0onASld3oiJ@c0CoVi;:0onOU<T01?nSUlSoY9S9ojBHbOnTV<T3ojRJb0?o
[9c700?o[Ik8ok2Paon`X<L00_n`X<L3okBRaP03okJUb?niYlOo^JO700?o^JO700Co^jS6okj/b?nn
[<So_Zc80_o0[LL3ol:ab@;oaK;80_o7]/X3olVgb@;obk_;0_o=_</3olo1c003om32c?oBa/kod/K>
00;od/K>0ooEbm03omO?d@?ofMCC0_oJf=D00ooIemGof]_Gom[Ke`02om_Of@04o`000?oJg][of^7K
om[Qf`;ofNCM00CofNOOomOUh?oFin;oe^OR0_oDj>@01_oCiNCodNKVom7Vi_oAi^KocnOXolgTj0?o
bnCY00CobNC[oooooooooooo00005?ooool000cooooo00?o0000ooooooooool07?ooool4oiZgk0;o
UKC]0_n>[nd3o`0000?oNZ?]0om^V^/00omQT>SoE8GToeB5i003odYjgP03oeIif_mDLmGoE7?E00;o
I7OA0omYML`2ofmeb0?oMgK50_moN<83ohan_`?oTX6m0_nIQ;/00onHPk_oWhJioin6^@02oin6^@?o
YHZh0on[S[L00on]T;Oo/iBgok>D]`02ok>D]`?o]iRg00?o^i^goknN^?noW[P00_noW[P5olJV^@Go
cZnk00?odkJlomBh_OoD^;d00ooJ_kl3omk8``;ohm350_oWfLP00ooSel[oi]o=onKOc@02onOVd0;o
i^gC00CohNOGomo/fooLk]kog>kN0_oGkn<01?oBknOoc^OXolWUjoo9iN/2olGRk@;o`M_/00Co0000
okgGkOnjd^co^];/0onfcn`00ondbn_o//W[ok;9j`03ok36jP;o[lCZ0_n]`nT2ojg1j@03ojc1jOn[
_nSoZkoX00;oZkoX00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`?oJiSZ0_mV
U>T2of>@i`;oH8gV0_mNRN@3ofB9h@04ofF7gol0003o0000o`0000;oJHGL0om/QMX2ogF7e`;oNHOE
0omnR=<3oh>:dP?oR8_@0on=SLh3oi6?c@CoUY3<0_nKT/X01?nKTl_oWiK:oinFb_nOU/X4ojBHb@Co
Z9[800?o[9c7ojfNb?n]W/P01On`X<L01?ndX/Ko]ZG8okJUb?nfYLP3okVWa`03ok^Zb?nn[<So_Zc8
00;o_Zc800?o`:g7ol:abOo2/LT00_o2/LT00oo5//SoakK:olNfbP02olNfbP05olVgbOo;^l_obk_;
ol^kboo=_</01?o?`L`01?oBaLkod/K>om;6c_oBa/h3omG;d0?oeloA0ooIe=<3om[He@03om_MeooJ
fmOofmoI00;ofmoI00?ofn?Ko`000?oJhM/00_oIi=d2omWWg`03omOZh_oFin;oe>ST00;oe>ST0_oB
j^H00ooAi^KocnOXoloWj002olgWj@03ol_TjOo9i>_obNC[00;oan?/00?oooooo`000?ooool04_oo
ool000_ooooo00?o0000ooooooooool07_ooool2oiZgk0;oVKK]0ol00002ohZ_kP;oOjW_0ombXNh2
of>Gk0;oDh_X0_mDQN@2odYjgP03od=afOmFNM[oE7?E00?oEW3@0_mYML`2ofmeb0?oMgK50_moN<83
ohQk_`?oT7nm1?nHPk/3oin6^@CoYHZh00CoZhjgojf@]on]T;Oo[I2g1?ncU;L01?ngV;Oo^i^gok^K
]onkVkL3oknN^003ol>S^?o6Y[WoaZJi00;oaZJi00Coc:bjolj_^oo>[k_ocZnk0_oC][`00ooD^;go
f[noomZo_`02omZo_`03omo7`OoNb<?ohm3500;ohm350_oWfLP01?oYh/[oi]o=onOVd?oWi]03onK]
d`03on?aeooOmM_og>kN00;oenoS00Cod^oWolg/j_o=k>[obNG[0oo5h^d01?o0gNko_MO]okgGkOl0
0002okWDk@;o]/o/00?o]<c/ok;9jonbbN/00_nbbN/01On`a^[o[lCZojo4j_n_a>[o[L?Y00;o[L;Y
0on/`NT4oj^oj003o`000?oooooooooo01Wooooo00?o0000ooooooooool05oooool3ofFGj`04of2B
j_mST>OoHi3Wof>@i`;oH8gV0_mNRN@3o`000003oej5h?mVQ]goIXKM00?oJHGL0_m/QMX2og66f0?o
MHKG0omnR=<3oh>:dP?oR8_@0on=SLh3oi6?c@;oUY3<00CoUY7=oi^CbonKTl_oVi?;1?nOU/X4ojBH
b@;oZ9[800?oZIc9ojfNb?n]W/P00_n]W/P3ok2Pa`03ok:Sb?nfYLSo]ZG800;o]ZG800?o^JO7ok^Z
b?nkZ/P00_nkZ/P2okj/b003ol2_bOo2/LWo`[7900?o`[791Oo7]/X4ol^kb`04olk0cOo?`Lcocl7<
olo1c0?od/G>00Cod/K>omG;d?oEbm3oeL_@0ooGcm43omWDd`?of]SE0_oKgML2omcQf@06om_OfOoK
hm_ofn?Kom_WgOl0003ofNCM0_oIiml2omOZhP;oe^cS00?oe>STom;Zi_oBj^H00_o@jnL00oo?inSo
cNOYolgWj@02ol_Wj`03olWTjoo7hncoan?/00;oa>;]00?oooooo`000?ooool04Oooool000_ooooo
00?o0000ooooooooool07oooool3o`000003oiVfkOnB/ngoT[?]00?oRZo^0_moZNl3og:QkP;oHiO/
0_mCRnP2od=nh`;oBW[N00?o@g7IoeAceOmDLmD00_mFL=03oea^c0;oKgG80omgM/D2ogmh`P?oR7^o
0on@Okd3oiR3^`?oWhJi0onUR[P00onWS;So[I2gojf@]`02ojf@]`Co/iBg1?nkVkL2oknN^0;o`j>h
0oo6Y[T3olb/^P04olj_^ooC][codkJlom>f_0Cof[no0_oOal43on?@a@?oimW800?ojN;:on[[cOoW
i]000ooVkM<01_oSlMOogoGKomoefooJm]ooenoSom;_i`?ocNcZ0_o8jNd02?o5h^go`=g^ol3Mk_o0
gNko_MO]okWDkOl0003o]]3]1?ndc>`2ok;9j`;o/<O[0_n_a>X00on]`n[o[L;Yojg2j@02ojg2j@03
ojc1jOn[`>WoZl3Y00;oZkoX00?oZ[oXo`000?ooool06_ooool00ol0003oooooooooo`0Hooooo`?o
IIO[00CoH9;Zoeb>j?mLS^SoG8kX0ol000001?mNRNCoGHORoef7h_mNQN03of24g`?oJHGL0_m/QMX2
og66f0;oMHKG0omjR=D3oh29d`?oQH_A0on;SM03oi2?cP?oUY7=1?nKTl/3oinFbP;oY9S90_nTV/X3
ojVLb@Co[Ik800Co/:37ok:Sb?nbXlSo/Z?81?nfYLP5ok^Zb004okj/b?o0[lWo`:o9ol2_b@?o`[79
0_o5]LX3olNfbP;obK[<0_o;^l/3olk0c@03olo1c?oBaLkod/G>00;od/G>0ooEbm02omO@dP04omO?
dOoIe=?ofMCComWDd`;ofmWF00Cof]SEom_MeooKgMOofmgG0_oLhMT01ooLiM_ofn?Kom_WgOoKimgo
f^[Oo`000?oIiml00_oGj^82omK/h`;oe>gU00?od^[Vom3[ioo@jnL00_o>jnT00oo=inWobnO[ol_W
j`02olSVk003olOSk?o4h^goa>;]00;o`^3^00?o0000ooooooooool04?ooool000_ooooo00?o0000
ooooooooool07?ooool3o`000004oooooonI]^goVKK]oiNfk@?oT;?_0on6[_02ogZXl0;oJio_0_mH
Tnd3odB5j004od=nholfLMgo=W7Mod=af@?o@F_D0_mFL=02oea^c0;oI6o90omgM/D2ogmh`P?oR7^o
0on@Okd3oiR3^`CoWhJi00CoYHZhojN<^?nWS;SoYhbh0on]T;L3ok>D]`03okJG^?nkVkOo^i^g00;o
^i^g00?o_ijhol>S^?o3XkP00_o3XkP00oo6Y[Woc:bjolb/^P02olb/^PCodkJl00?ofKjnomZo_ooJ
_kl00ooOal400ooTdLCohm35onOIb002onOIb0;ojN;:00Goj^_=onWbcooYl/ooi^gCon?ae`02omoe
f`03om[fgooDm^Coe?KT00;ocoCX00?ocNcZolSYkOo8jNd00_o3i>l2ol3MkP;o^mW_00Co^MC]o`00
0?nfd>go]]3]0_ndc>`2ok79k0;o/<O[00?o[/G[ojg3j_n]`nX00_n]`nX2ojg2j@;o[<7Y00?oZl3Y
oj^oj?n[_nP00onZ_nP00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo0_mOUN`0
1_mJT>_o0000o`000?l0003oG8kXoeV;iP;oEhOU0_mFQN<2oej5h0;oH8CO0omSQ=d2ofN4f`;oLHKH
0omeQ]L3ogZ8e@?oP8WC0_n5Rm43oh^=d0CoT8o>0onFTLd3oi^Cb`;oWiK:00?oWiO<ojBJb_nTV/X0
0_nTV/X4ojVLb@;o[Ik800?o[Z7:ok:Sb?nbXlP00onbXlP2okJUb0;o]jS91?nkZ/P5ol2_b@03ol:a
bOo5]L[oaKG:00;oaKG:00GoakK:olVjc?o9^/cobK[<ol^kb`04olk0c@04om75cooBaLkod/G>om;5
cP;oe<_@00CoeL_@omO@d_oGd=;oem3B0_oIeM@01?oIe=?ofmWFom_Ie_oKfMH2omcNf003om_MeooL
hMWog>7I00;og>GK00Oog>WMom_WgOoJj]oof^[Oo`000?oIkN7oen[R00;oe^cS0_oDkND2om7^i`03
om3[ioo>jnWoc^_Y00;oc>_[00?obnO[olSVk?o8i^`00_o6iNh00oo4h^go`^3^ol;PkP02ol3Nk`03
o`000?oooooooooo00oooooo000;ooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`;oUkK]
0on@/nl00on6[_3oPjkaoh>^l@02ogFWl@;oJio_0_mHTnd3odB5j004oc1fh_lfLMgo;FOHobeWf0;o
@F_D0om4Im000omLK/coI6o9ofA_b@03ofibaP;oOgS20on8Nkl3oi1o_@CoV8>k0_nOQ[T00onOQk[o
YhbhojN<^002ojN<^0Co[I2g00Co/iBgokJG^?nfUkSo]YNh0onkVkL5ol>S^0Goc:bj00?odK>lom>f
_?oC][`00ooI_[h00ooJ_kooglO1omo7`@02onCAa0;ojM_600?oimW8onWRb_oYh/X00_oZjld2onWb
c`04onGgd_oPn]KogoGKom[fg`;oe?KT0_o?m>P2olW`k@03olSYkOo3i>oo`nC_00;o_]o`0_nkfNl2
okSDk`04okK@kOl0003o/lg]ok?=k@;o/LW/00?o[lO[ojk5jon^aN/00_n^aN/2ojg3jP;o[<;Y0_n/
`NT00on[`>WoZkoXoj^oj002oj^oj004ojZoj?nZ_^SoZ[kXo`0001Wooooo00?o0000ooooooooool0
6Oooool3o`0000;oFY3[0_mES>T2oe68i`;oEhOU00CoEXGSoeN3h_mGPn;oEh?R0_mPQ=l3of>4g@04
ofN4fom[Q=[oJhCJof^4fP?oMHKG0_mjR=D3oh29d`?oQH_A0on;SM03oi2?cP?oUY7=0_nKTl/00onJ
ULgoWiO<oinGc002oinGc0CoY9[:0onYW<T01?n]W/So[Z7:ojjQb_n^XLX4ok:Sb004okJUb?ngZ<Wo
]jS9okNXb@?o^j[80_nm[LX4ol2_b@GoaKG:1?o9^/`01?o<_lkoc/3=olk0cOo>`<d3om75c`04om;5
c_oDbm3oe<_@omC;d0?oem3B0ooIeM@3om_IeP?og=kH00Cog>?JomcQfOoLiM_og>GK0_oLjMd01OoK
kMoof^[OomW]hOoIkN7o000000;oenoS00Coe?3UomC]iOoAk^OodNkW0_o?knT01?o>jnWoc>_[olc[
joo9j^d2olKYkP;oa^G^0_o3i>l00oo2h>ko`=k_ol3Nk`02okgMk`03o`000?oooooooooo00kooooo
000;ooooo`03o`000?oooooooooo01Kooooo0ol0000:ooooo`?oU[O^0on>/o02oh>^l@?oMJOa00?o
Higaodf@k_m=T>h00om4QNP2oamWf`;o;FOH0_m1Jm@2odAWd004odaWcOmLK/coI6o9ofA_b@;oKW;6
0omiM/<3ohQk_`?oT7nm0_nHPk/00onGPk_oWhNjoin7^P02oin7^P?oYhbh0on]T;L00on`TkSo]YNh
okJG^002okJG^0;o^i^g0_noWkT4ol>S^004olRY^_o<[;[oc:bjolb/^P;odK>l00?odkJlomVn__oI
_[h00_oI_[h2omo7`@?oi=740_oYflH01?o/i/SojN;:on[[cOoZjld2onWbc`04onGgd_oPn]Kof_cJ
om[lfP;oe?cO00Goc_[Uolodj?o9l>gobO3]olC[l002okoUl@;o_]o`0_njf_02okSDk`;o]=3^00?o
/lg]o`000?nabN`01?n_an/2ojk5j`;o[L?Z0_n/`^T00on/`NWoZl3Yoj_0j@02oj_0j@;oZkoX00Go
Z[oXojZnj?nZ_^SoZ[kXo`00000Iooooo`03o`000?oooooooooo01Kooooo0ol00002ooooo`04oeVD
kOmCSn_oDho[oe>?j`;oEHcY00GoDHSWodn5i_m?QNKoChGVoeJ5h`02oeN3hP?oF8;P0_mSQ=d2ofN4
f`;oJhCJ0omaQ]P3ogN7e`?oP8WC0_n5Rm43oh^=d0;oT8o>00CoSi3@oiFCconETlooUI??1?nJULd3
oinGc0CoY9[:0_nYW<T00onZW/_o[Z7:ojjQbP03ojjQbP;o/Z?800?o]:K;okNXbOngZ<T00ongZ<T0
1?nkZ/So_Jg:okf]b_nm[LX3ol2_b@;o`[?;0oo5]LX2olNic0;obK[<0oo<_lh01Oo>`<godLG?om75
cooAaLoodl[A00?oe<_@0ooGd=83omWEe0;ofm[F00CofmWFomcNf?oLg]Sog=kH0_oLhmX01?oMimco
g>GKomcYgOoLjMd2om_]g`;ofO3Q00CofNgQomO_hol0003oe?3U0_oBlNL01?oAk^OocnoYolo_jOo<
k^/2olW^k@03olWZkOo6jNkoa^W^00;oa>O_0_o3i>l2ol7Rl005ol3NkonmgNoo_Mg_ok_Kl?l00000
4?ooool000_ooooo00?o0000ooooooooool05?ooool2o`0000kooooo00?oU[O^oiFgkonE]nl00_n<
/o43oh2_lP;oLJOc0_mLWO83odf@kP04ocB0j?lKK]oo7fOKoamWf`;o;FOH0_lZH=<00om4Im3oC6O=
odaWc@02ofA_b@?oKW;60_miM/<3ohAj`0?oSWjn0onGPk/4oin7^PCoYhbh00?o[I2gok2C^?n`TkP0
1?nfUkP01?nkVkOo_inioknO^OnoWkT3ol>S^0;ob:Vj0_o<[;X3om6c_0GofKjn0_oOal42onCAa0?o
jM_600Ook>K8onc_b_o/kl[oj^_=onWbcooUmm;oh?[F00;of_cJ0_oDo=l01Oo>n^GobOO[olCbkoo4
l^ooa>_`00;o_nGa0_nkgo82ok[Jl0;o]]C`0_ndd>h01Onbc>go/LW/ok79k?l0003o/LW/00;o[lO[
0_n^aN/2ojg3jP03ojc2jOn/`NWo[<7Y00;o[<7Y0_n[`>T2oj^oj@?oZ[oX0_nZ_^P00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Cooooo0_l00006ooooo`05oeVDkOmCSn_oDho[oe>?jom=
R^X00_mAR>L2odn5iP;oCX?T0_mGPn83oeR2h004oeb2g_mPP]goH8;Mof22g@;oJhCJ0omaQ]P2ogN7
e`?oO8WE0_n3S=<3ohV>dPCoSi3@0onETll3oiZEc@CoWiO<0_nTV/X00onUW<coZYk;ojZNb`02ojZN
b`?o[Z7:00?o/:C<okBVbondY//00_ndY//3okNXb@03okZ/bonm[L[o_Jg:00?o_Jg:00?o`:o9ol:c
boo2/l/00_o2/l/01Oo5]L[oakW<olNic?o7^LcobK[<00Coc;o>0ooAaLl3om?:d@04omC;d?oGd=;o
em3BomO@dP;ofMKE00CofMGDom_Je_oKf]Kofm[F0_oLgmP00ooLg]Sog>?JomcSfP02omgWg003omc/
g_oLjMgofngO00;ofngO0_oIl>401OoGl^?oenoSomC`iOl0003od_7W00;oco;Y00CocnoYolc^joo9
k^gobNk]0_o7kNh00oo6jNkoa>O_olCWk`02ol7Ul0;o`N;`0_nnh?001?nmgNoo^m_`ok_Kl?l0000@
ooooo`002_ooool00ol0003oooooooooo`0Booooo`?o00004?ooool4oiFgk`;oS;?a0on0[o82og6W
l`?oG9gb00Co@Xk^obEki_lUNnKo6fkO0_lOIm/2oa9Kd`04obYPdol]GLooA6O@odaWc@?oEVW:0_m^
L/H3ogUf``?oQ7[00on>O[h3oiN3^`?oWhNj0onWS;P00onYS[[o/9>hok2C^002ok2C^0?o]YNh1Ono
WkT00oo3XkSob:VjolRY^P02olRY^P05olb/^_oA/kcodK>lom6c_?oH_;h00ooI_[h2omo7`@;oiM;3
00?oi=74onWKa_oYflH00_o/i/P2onc_bP03on[fc?oTnlgogOk>00;oeOoA00Coc_oGomClgoo>n^Go
bOO[0_o4l^l2oko/lP05okoUlOnkgo;o^mobok_Ol_ngfO400onfe?04ok;<k@04ok79k?l0003o[lO/
ojo7k0;o[/G[00?o[L?Zojc2jOn/`^T00_n/`^T2ojc1j@;oZl3Y0_n[_nT6ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04_ooool3o`0000Wooooo00GoDi;^oe>?jomCSn_oDho[odf:
jP02odV6j0;oChGV0_m>Pn@2odj1h`?oF8;P00?oG8;Nof22gOmPP]d00omUQ=`3og66f0;oMhOG0oml
RMD2oh><d`?oRHkB0on?T=03oiFCc`CoVYG=0_nOUl`00onPV/koYIc<ojFLc002ojFLc0CoZYk;00Co
[Z7:ok2Tc?n`Y<co/:C<1?ndY//01?ngZ<Wo^Zc;okZ/bonj[</3okf]bP;o_k7<0oo2/l/01?o5^<ko
akW<olNic?o7^L`2olZnc`?oc;o>0_o?a=000ooAaLoodl[Aom?:d@02om?:d@?oem3B0ooIe]D3om_J
eP?og=oH00CogNGKomcSf_oMimcogNOL0_oLk=h2om__g`04om_]gooIl>7ofO3QomObh`;oe?CU00Go
dOGWo`000?o?l^Woco;Yolcbj`02olWak@03olW^kOo7kNkoang^00;oa>_`00?oa>O_ol7Ul?o1iO00
0_noho42okkPl0;o_=ka00?o^m_`ooooool000004?ooool000[ooooo00?o0000ooooooooool03ooo
ool3o`0001Cooooo0_nE]nl00onD]nooRkCaoh^dl@02oh^dl@;oOZoc0_m]Z?@2oeJLl`;o>Hc^0_lU
NnH01ol5I][o15cEo`ALeOlBFm?o3E?>obYPdol]GLl00_m<Ild2oeIYbP?oHfk70_miM/<3ohAj`0?o
SWjn0onGPk/4oin7^P03ojN<^?nYS[[oZHjj00Co/9>h0_nfUkP2okZL^@Co_ini1Oo8ZKX3om6c_0?o
f;bn00CofKjnomo7`OoOal7oglO10_oUd/<01?oZg/KojM_6oncVb?o/i/P2onc_bP08on[fc?oTnlgo
gOk>omgnc_oEom7oc_oGolSng_o4o>H2ol7hk@03olCbkonok?;o_ncb00?o^nGc00Go^mobokOIlOng
fO7o]mWaokKDl002ok?@k`;o//c]0_n`bNd00on_anco0000ojg4j`04ojg3jP;o[<;Y0_n[`NT2oj_0
j@[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`?o00003Oooool2oe>B
kP03odb=k?m5R>[oAHSZ00;oBHKX00CoAX?VodB0iOm4P>GoA83U0_m>PN<2oe20h@;oDh3P0_mPP]d2
ofF4g0?oJhGJ0_mbQmT3ogb9e@?oPhcC0on9S]83ohn@d0?oUI??0_nJULd00onJUlooX9[>oj2JcP02
oj2JcPCoYIc<0_nZW//00on[XLgo/:C<ok2Tc002ok2Tc0?o]:K;00?o]ZW=okZ/bonj[</00onj[</0
0onm[L[o_k7<oknac002oknac005ol:cboo5^<koaKS>olFhc_o7^L`01?o:_/l01Oo<_lkoclC@olo4
d?o?a=3od/[B00?odl[A0_oFd=@01?oGd=;ofMKEomWFeOoIe]D2om[Ke`04om_Je_oLgmSog=oHomcO
f0;ogNGK00CogN[LomgWg?oLk=kog>cN0ooKkml00ooIl^7ofO3QomObh`02omCdi@05om7eioo?mNSo
coGXo`000?o<l^/00_o9lNd2olO`kP03olO]k_o4jo3oa>_`00;o`^Wa00?o`NG`okoSlOnoho400_nm
hO42okcNl@Cooooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool03?ooool3
o`0001Wooooo0_nD]nl2oh^dl@;oRkGb0_mm/?@2of^YmP;oEYcc0_liS>h2oaIgh`06o`EVf_l4G=Go
04g<oa9Kdol=Dlko;Eg?0_lfG/d3oeIYbP;oHfk70omaLlD2ohAj`0?oSWjn0onGPk/2oin7^P;oX8Vl
1?nYS[X3ok2C^004okJG^?njW;Wo^YbiokZL^@?o_ini0_o4Y[/3olRY^P;oc[6l00?odK>lomRl__oH
_;h00_oH_;h3omo7`@?oiM;300?oj]k6ongYb?o/i/P00_o/klX02?oZm/coi?_=omgnc_oMo/koeOoA
olkoeoo8o]koa?cV0_o1n>d2okgblP;o^^[d0_nkiO<2okSNl`;o]mWa0_nddo001Oncd>oo/<c^ok3<
k_n`c>ko/<W]00?o[/K/00Co0000ojg4jon]`n[o[L?Z0_n/`^X2oj_1j@gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0<ooooo`?o00004?ooool3odfAkP03odB<k?m5R>[oAHSZ00;o
@8CX00?oAX?VodB0iOm4P>D00om5O^@2oe20h@04oe>0h?mHPMooF87OoeR1g`;oIHCL0om[QMX01?mb
QmWoNH[HogV:f?miR]P3oh2<eP?oQhoD0on>T]<3oiBDd@CoVYO?0onPV/h3ojFLc003ojJOcon[XLgo
Zj7=00;oZj7=1?n`Y<`01?ndY/_o]ZW=okJYcOnfZLd3okZ/b`03okb`c_no/Lco_k7<00;o_k7<00?o
`[K?olFhc_o5^<h00_o5^<h5olZnc`?oclC@0ooBb]801?oCb]7oe]3DomK@e?oFd=@2omSFeP04omWF
eOoJfmOof]_Gom[Ke`;og>7J00?og=oHomgUfooMiM/00_oMj]`00ooLk]kog>cNom__g`02om__g`06
omWbhOoFmN?oe_GSom?gi?oDm>GodOGW0_o?mNP01?o<mN[ob?C/o`000?o9lNd2olO`kP03olC^l?o1
k?7o`Nca00;o`^Wa0_noio800onoho7o_N7aokgQl@07ooooo`03o`000?oooooooooo00gooooo000:
ooooo`03o`000?oooooooooo00Wooooo0ol0000Mooooo`?oU;S`0on;]O82ogf`m0?oJjWf00?oDYgd
oc6<k_laS>h00_lFMn<2o`1@c004o`1=c?l=Dlko3e3<o`m@c0;o=Uk=0_mFJLX2of=^a`?oLG?50omo
NL<3ohin_P03oiN3^onGQ;koX8Vl00?oX8Vl1?nYS[X2ok2C^003ok>G^onjW;Wo^Ybi00?o^Ybi00?o
_iniolBV^oo4Y[/00_o4Y[/01Oo8ZK[oc[6lolja_?o>/KcodK>l00Cof;bn00?og/O1omo7`OoUd/<0
0_oUd/<2on[NaP05ongYb?o]llSokO?8onSkaooOo/D00_oDol@01Oo9o/Go_?gCokcmdonjoMgo^O_X
00;o^OK`00?o_O;bok[Zm?njj_@00_ngh_D2okSNl`;o]=Ob0_nddo02ok7>k`;o/<c^0_n_b>d2ojk6
k004ojg4jol0003o[<?Zojc3jP;o[<;Z4?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Wooooo0ol0000Dooooo`?oCI7^00CoA8c/ocf6j_lmQ^[o@8CX0_llP>L2odB0i@;oAGkT0_m7
O^<2oe>0h0;oF87O0omNPmh2of^5fP;oLXOI0omiR]P3oh2<eP?oQhoD0on>T]<3oiBDd@?oVYO?1?nP
V/h01?nUW<coYYo?ojJOconVWll4oj^Qc@;o/:C<00?o/JO>okJYcOnfZLd00onfZLd01?nj[<_o_;3>
okb`c_nl/<h2oknac0?o`[K?0_o5^<h2olNmd0?ob[k?0_o=a=400oo?a=3od/[Bom;:dP02om;:dP?o
e]3D0ooHe]H3om[Ke`?og>7J00Cog>OLomgUfooMj]cogN[L0_oLk]h2om[bh006om__gooIl^7oe_GS
omKehooCmnCod?SV0_o=n>P02?o?mNSoc?GZolSdk?o8m>co0000olKck_o7l>koa>k`0_o1k?42okoZ
lP;o_nOb00?o_NCbooooooooool02?ooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003o
ooooooooo`06ooooo`?o00008Oooool00onD^?3oU;W`oiBil003oh^fl`?oOK;e00?oJj_goe6OmOmA
WoD00olaS>h01Ol:M>3o053<o`1@c?l0?Kko04?500;o3e3<00Co=Uk=odARc?m4H/coA6;<0_mSK/L2
og5ca@?oOgW30on;Ol03oiN4_PCoX8Vl0onYS[X01?n`TkSo/iNkok>G^oncUk/4okZL^@Goa:Jk1?o>
/K`01?oE^koof;bnomRl__oH_;h2omk7`@;oiM?500?oiM;3on[Na_oZg/H00_o]jLP2ongcb004onSk
aooOo/Goe?o4olWna@;o_?gC00Go^_gMokWkj?nim_3o^OK`okO_m@02okGWm`;o]n;e0_ndfo@2okCG
lP;o/M7a0_nac^l2ojo:kP;o[lS]00?o[LG/ojg4jon]a>/00_n]a>/00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool3o`0001Wooooo0_m6T>l01?lm
Rngo?HKZocf6j_lgP^P2ocb0i`;o>WkU0_m5O^@01?m7O^?oBgkRod]nh_m;O^82oeR1g`;oGX?N0_mU
QMd3off7g0?oNH[H0_n0S=H3ohN?e0?oSY;C1?nDU=43oiZGc`;oX9[>00?oX9c@ojJOconVWll00_nV
Wll3oj^Qc@03ojbUd?naYlko/JO>00;o/JO>0onfZLd00onh[/oo_;3>okb`cP02okb`cP03oknac?o2
]/oo`[K?00;o`[K?00?oaKS>olNmd?o7_M000_o7_M001Oo:_/oocLCAolg4dOo=a=7od<[D00?od/[B
0_oDd=D01?oFd=Cof=KFomSFe_oHe]H2om[Lf@04om[KeooLhM[og>7JomcQfP;og>OL00?og>cNomgZ
g?oLk]h00_oLk]h01ooJl^3of?GRomSeh_oEn>?oe_GSom?gi?o@n>H00_o=n>P2ol[hj@;oa_O/00Ko
b?C/olKck_l0003o`o;`ol3_lOo1k?43okoZlP03okgWlonmi?;ooooo00[ooooo00?o0000oooooooo
ool03Oooool000[ooooo00?o0000ooooooooool00oooool3o`0002Gooooo0onD^O000on;]_?oS;Oc
ohbgl`02ogndmP;oK:gh0omAWoD02?l]SNko0W?No`9cg_l0El_o04Boo`0m__l0@lGo3e3<0_lJD/`2
odARc003oeEYbomSK/OoLG?500;oLG?50_moNL<3oh]o`0?oUhBn1?nPRK`2ojV>^P03oj^C_OncUk_o
/iNk00;o/iNk0onjW;T2oknR_0Coa:Jk1?o>/K`2omFk_`04omRl__oNal7og/O1omk7`@;oiM?500Co
jn77on[Na_o]jLSokNW80_o]llP02?oXnlOogok5omCoa?o9o/GoYoG1ojShd?n/nMoo[oS/0_nal_@0
0ongkoGo]NOgokGWm`02ok?OmP;o]=_d0_nae?82ok7Al@;o[lc_0_n_b^h00on]ango[LG/ojg5k002
ojg5k0;o[LC[0_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool00oooool3o`0001gooooo0_m0T>l01?lmRngo=8GZocB5j_lgP^P2oc9ni`;o>WkU00?o
>WcTodMnhom7O^<00_m;O^83oe20h@;oGX?N0_mUQMd2off7g0?oMH_K0ommS]T3ohN?e0?oSY;C0_nD
U=401?nCUmCoVY[BoiZJd_nJV]84oj2Ld0CoYYo?00?oZj7=ojbUd?n/YM001OnaYlh01?nfZLgo^:k?
okR^conh[/l2okb`cP;o_[GA0oo2]/l2olBldP?oakg@00Cob/?Colg4dOo=a=7ocLCA0oo@b]@01?oB
b];oe=3EomC@eOoDd=D2omKGf004omSFe_oJg=Wof]cIom[Lf@;ofn?K00?og>7JomcWg?oLim`00_oL
k=h2om_ag`06omc^g_oJl^3of?GRomSeh_oEn>?odOWT0_o>n^D01?o:n^OocOSXol[hjOo:n>T2olKg
k005olCfk_o1m?3o`OC`ol?bl?l000000onnkO<00onoj_;o_NOcooooo`0<ooooo`03o`000?oooooo
oooo00gooooo0009ooooo`04o`000?ooooooooooooooo`?o0000:Oooool3oiFjl@?oS;Oc0_mo]?H3
ofb]n0;oDZ?f00So;I7_o`9cg_l2Lmko05?3o`0i/?l0;Jco03o3o`m@c0;o6U;<00?oA6;<oeEYbomE
JL/00omaLlD3ogmi``?oRgo00_nGQ;h4oj29_004ojV>^_n[TkgoZi>moj^C_@Co/iNk00Co^YbioknR
_?noX[co_j:l0oo4Y[/2olZ^_P;oc[6l0ooE^kl3omk7`@?oiM?500gojn77ong^b?o]k/SokNW8ongc
b?oXnlOodofkol;i]On[lkOoYoG1ojShd?nQm^Go[oS/00;o/O;d0_nbjoP2ok7Rn005ok?Om_naeoCo
/MOdok7Gm?nae?800_n_co02ojo<k`03ojk8kOn]ango[LO]00;o[LO]0_n]aN`6ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool3o`00027ooooo
00Co@93_ocJ9kOlfRNgo=8GZ0_l]OnP2oc9ni`;o;g_U00?o>WcTocali?llO>@00_m;O^82oe20h@;o
Eh;Q0omUQMd2off7g0?oMH_K0_mmS]T3ohBAf0?oS9CF1?nCUm@3oiZJdPCoX9c@0_nVWll00onWXm;o
[:G@ojbUd002ojbUd0?o/JO>00?o/jcAokR^conh[/l00_nh[/l00onl/<ko_[GAokjed@02okjed@03
ol:fcoo4_=;oa;cB00;oa;cB00Goakg@ol[3doo:`m?ob/?Colg4d@04om3:e0?oe=3E0ooFemP3om[L
f@?ofn?K00CofnWMomcWg?oLk=kog>cN0_oKlMl2omWeh@04omKhh_oHmN;oeOSSom7ii0?oc_[U00Ko
b_[WolKjj?o3nN_o`oW[olKgk?o4m^h2ol7dl006okkblOnll??o_?3co`000?nnkO?o_>[d3oooool0
0ol0003oooooooooo`0=ooooo`002Oooool4o`0002gooooo00?oUK[aoiJjlOnF^_401?n>^O<2oh6f
mP?oKk3h0_mFYoP01_laU_7o07KMo`1C`ol0>K3o02f/o`0o``;o6U;<00?o:eW=odARc?mEJL/00omW
LLT3ogmi``?oRgo00onGQ;h2oj29_003oj:=_on[TkgoZi>m00;oZi>m1?ncUk/5oknR_005olBV^oo:
[[kobZjnolZ^__o>/K`01?oE^kl00ooMal?og/O1onGCa@02onGCa@;ojn770_o]k/P01_o[n<OohOg2
om?m^oo2nKGoR^2NohkZ_0;oXOKU0_nXm?800on]kOSo[^GiojkUn@02ok7Rn0;o/=[f0_naeo@2ojoA
lP03ojo?l?n^b^oo[/[_00?o[/S]0_n]and9ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05?ooool4o`0002Gooooo00Co>Xo_ocJ9kOlfRNgo;8?Z0_l]OnP2obMkiP03obmkiOl_NNCo
;gWT00;o?7cT0_m0O><2oe20h@;oEh;Q0_mNQN03ofN8g`;oMH_K0ommS]T3ohBAf0?oS9CF1?nCUm@3
oiZJdP;oX9c@00?oXJ3DojNSd_nWXm800_nWXm83ojbUd003ok6Wc_nc[=7o/jcA00;o/jcA0_nh[/l0
0onj/m?o_[GAokjed@03okjed@Goa;cB1?o:`m<01?o=bMKod<[Dom3:e?o@b]@2om;@e`04omC@eOoF
emSoe]OHomKGf0;of=gK00Cof]cIom_SfooKhm_ofn?K0_oKjMd01?oKk]oog>cNom_agooKlMl2omWe
h@04omKhh_oBn^?oc__Solkkh`;ob_cT00?oc_[Uol[jioo6n^P00_o3nN/01Oo0n>go__O_okcelOnl
mO7o__;a00;o_?3c00?o^^gdo`000?nlj_@04?ooool00ol0003oooooooooo`0=ooooo`002Oooool2
o`00037ooooo0_nF^_42ohjil`03oi2jlon4^?KoQ;Sf00;oQ;Sf0_md/oT2oeb/n@;o>Ygd00?o05Bo
o`0bXol07Id00_l0@lD01?lJD/co:eW=oeEYbomEJL/2ofMab@?oNGW70on8PL@2oiN4_P03oiJ7`_nR
SKooXXfo00;oXXfo0on[Tkd3ok>G^`;o^9jn1?noX[`4olZ^_P04om6i`_oE^kooeK^oomFk_`;ogLO3
0_oTeLL00ooUdlGojn77on_Qa`03ong^b004on_haooCoK_o`_Veoh[PWP;oS^oK00CoW?;^ojG^n?nU
k_So[Ngh0_n^iOT2ojkLm`;o/=[f0_n^do<2ojoAlP;o[/c`0on^b^l00on^b>goooooooooo`0;oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool2o`0002Sooooo0_ljSnl01Ol^
R>co;8?Zobb3j_lSONOo9g_V00;o97ST0_l_NN@2oc5ii003od1lhom6O^?oAWkS00?oEh;Q0_mNQN02
ofN8g`?oL8cN0ommS]T3ohBAf0?oS9CF0_nCUm@01?nBV]SoVYgFoiZMe_nJWMH4oj6Pe0?oYj?B0_n/
YM000on^ZM?o/jcAok>/d@03ok>/d@04okR^conj/m?o^[?CokZcd`?o_[GA0_o1^]@3olBldP;oal;E
0_o:`m<3olg9eP04om3:e?oBd=Ood]3Gom;@e`;oe=OJ00?oe]OHomSMfooHgM/00ooIi=d01?oKhm_o
fnWMom_YgOoKk]l3omWch@04omOgh_oImN7oe_SRom;jh`?oc__S00Cob_cTolKliOo2o>Oo___Y0_nl
n^/01Oo0n>go__O_okcelOnlmO7o^_;c00;o^>od0_njkO@00ooooooo0000ooooo`0@ooooo`03o`00
0?oooooooooo00cooooo000;ooooo`03o`000?oooooooooo02oooooo0onH^o02oi2jl`;oQ;Sf00Co
R;[fogZgnOmj]oWoN[Oi0_mT/?X2ocZMm003o`b5hol0FKko01fM00;o04?500?o:eW=od5Tc_m1I<h0
0omWLLT3ogUia`;oR8741?nFQl83oj:=_`CoZi>m00Co/iNkokRN__nhW[ko^9jn0onoX[`2olF[`0;o
bZjn0ooA^L801?oE^koogLO3omg7`ooMal<2onCEa`03on[Uboo[hLOokNk800;okNk800GojoS7okgf
[On:h9koR^2Nohg]j002oic^mP;oYNkh00?oZNOjoj_NnOn[g_T00_n^g?L2ojgEm@;o[]?c0_n]cO42
ojk<l1?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo02Kooooo0_leSnl00olXQnco8h;Yob>2j@02oaUki@;o97ST0_lSMn@00olaNNCo=G[TocEji002
odInh`;oCX7S0omFQN<2ofN8g`?oL8cN0_miSmd3oh:Cf`?oRYKJ0onBV]P4oiZMeP?oXJ3D0_nWXm80
0onXYmKo[ZWCojjYd`02ojjYd`?o/jcA00?o]K7EokZcdonj/m<00onj/m<00onn]M7o`K[Dol6je002
ol6je005olBld_o7`]Goal;EolO2eOo:`m<00oo=bMH01?o@d=[od]3Gom;@eooBd=L3omCGfP03omKN
gOoHgM_ofNCM00;ofNCM0_oJjn000ooKjMgofnkOomWch@02omWch@04omOgh_oCn^;ococRololhP;o
bOgS00Goc__Sol[li?o6o>Go`_cWokkkj@02okcjj`05okWhk_nhm_3o^?K`okcelOnjl_<00_nhko@5
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool000cooooo00?o0000oooo
ooooool0;oooool3oiVll0?oT[_c0_n8^_H3ogZgn@;oI;3j0om5YOL00olKTNWo06?3o`13a@02o`Q=
b`;o@FC>0_mWLLT3ogUia`?oR8740onFQl84oj:=_`;oZi>m00?o[iW1okRN__nhW[h00onhW[h01Ono
X[coaJ_0olF[`?o5Zl3obZjn00CodKW20ooMal<3onCEa`07on[Uboo[ll_ojo?;ong^b?o[n<Oo_OJ]
o`000003oi7[m@03oic^m_nTio_oY>Ok00;oZ=oj00GoZmkiojcFm_n/e_Ko[=KfojgEm@03ojc?lP03
ojg=lOoooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02Kooooo0_laSnl01?lXQnco6h3Woa^0iolINnD2oa5fhP04oaQeholSMnCo8gOT
obAfh`;o=G[T0_lkON@2odj1h`;oEXGS0omPRN<3og2<gP;oNHoM0on2Tm/3ohZFfP?oTY[H0onJWMH2
oj6Pe003oj6Tf?nXYmKoZ:OF00;oZ:OF1?n^ZM<01?nc[=7o]K7EokFaeOne/MD3okZcd`;o_;WF0oo1
^]@01?o3`MSoal;EolO2eOo7`]D3ol[9f@05olg9e_o@d=[od=3Jom3@f_oBd=L00ooDemX2omKNg@;o
enKP00?ofNCMom[[h?oJjn000_oIl>82omOfh`03omWchOoGmn;odo[R00;ococR0_o9oN<01Oo5oN?o
`?gSok_liOnhnnKo]O[Y00;o/oW/00Co^OS^okSfl?nhm_3o]_Cb0_nelO@8ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0;oooool00onI
_?3oVkg`oi^ml003oiFllP?oS;_f0_n0^OT3offen`;oDjgj0_l]WO001?l0;[Co24g;o`Q=bom1I<h3
oeU_c`;oNGW70on8PL@3oiJ7`P?oXXfo00CoY9?4ojnI`On_VL7o[iW11?nhW[h00onmYl?oaJ_0olF[
`002olF[`0GodKW200?of/O7omg7`ooTeLL00_oTeLL2on[Ub`;ojo?;00CoiOc6omCm^ol0003oQ^Oc
0_nAjoD00onNiocoY=okojCOn`02ojSOnP;oZ]Og0_n/e_H2oj_@l`;o[<ob6Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09_ooool2oc6?k`04ob:7
jolKP>Oo6h3Woa1ih`;o4GKR00Co37;PoaIch_lFLn;o97KS0_lXN>@2oc]mi0;o@h3U0_mFQN<2of29
h`?oJXgR0_mdTN43oh:Cf`?oRYKJ0onBV]P2oiZMeP03oiVQf_nQY=SoXJCH00;oXJCH1?nXYmH2ojjY
d`;o[joG1?ne/MD00onj/m?o_;WFokbieP02okbieP05ol6je?o3`MSo`l7Hol?1f?o7`]D01?o:bMT3
om3@fP?od]SM00?oe=OJomKNgOoFg]d00ooGi^001?oGkN?of^_PomW`h_oIl>82omOfh`05om?ihoo>
o>?oc_cSolWmh_o?o>800_o9oN<01Oo5oN?o`?gSok_liOnhnnKo]O[Y00;o/oW/0_nbmnl01?namO7o
/O?dok7cm?nelO@9ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000ko
oooo0_l0000`ooooo`?oVkg`00?oUKcboiRmlOnH_O400onA_O@3ohJln0;oMkWk0omQ]?`00ol059Go
02jdo`Q=b`02obAKd@;oFFo?0om`N/d3ohR1a0?oUXO200?oXXfoojBCa?nTTl@01?n_VL42okRN_P?o
_JO30_o5Zl02olbgaP?odKW20_oJalL2on;Gc@03onCEaooZiL_oj^G;00;ojo?;00GoiOc6omCm^ol0
003oQ^OcoiOVo002oj7Oo0;oY=ok0_nWf?P2oj[Gm`;oZ]3d0_n[d?<Mooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool06?ooool2o`0002Sooooo00Co;I3_oaj7j_lNQn[o57oV0_l@NN<0
0ol7Lmoo37;PoaIchP02oaIchP;o:7ST0_l^NnD2od>0i@;oCHCV0_mPRN<3ofZ=hP04ogBAhOmnU]oo
OYKOogjFg`?oR9[N1?nAWM`3oiVQfPCoXJCH0_nXYmH00onY[=[o[joGojn_e`03ojn_e`;o]K7E0_ng
]mT3okbieP04okjofoo3`MSo`l7Hol?1f0;oa/SL0oo:bMT2olc@g@04om3@f_oBf=god]SMom;Hg@;o
dmoQ00Coe]kMomOVh?oGi^3oenKP0_oGkN<01OoFl^CofO3RomOfhooGm^?odoWS00;oc_cS0_o9oN80
1?o3oN7o_OgQokSlhOncnn42ojojh`06ojgii_n/n>WoZoO/oj_gk?nbmnoo/OGa0_nalo@<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0013ooooo00?o0000ooooooooool0
;_ooool3oifmk`?oV;ga00CoTKgdoiFnlonE__?oUKkc0_n<_OL3oh2lnP;oKk[l0_l05IH00ol0>[ko
95_AobAKd@02oeU_c`;oL7[=0on4Q</3oiJ=b0CoY9?40on_VL400onhW[ko_JO3okfW``02okfW``03
olF[`?o<]lKoc;O600;oc;O600CodKW2om[7aooJalOof/O70_oReld01_oWjM3oj^G;on_cboo[ll_o
iOc6okcg/0;oTNCl0_nMg_d01OnQgocoYMOiojGGnOnUeoWoYmSh00?oZM7e00?oZ]3dooooooooool0
7oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
9_ooool01?l[TNoo7XOZoaj7j_lNQnX2o`Qhh@03o`1afol0Kmco273N00;o5W?R0_lJM><2obiki@;o
=goV00?oCHCVoeN9i_mGRNH00omZSN82ogBAh@?oOYKO0on8V]h4oi6Mg0?oVJ7J0_nQY=P00onQZMco
ZJcJojV/fP02ojV/fP?o[joG00?o/KGLokNgfOng]mT00ong]mT01Onl^MKo_[oKokjofonn_m_o`l7H
00Coa/SL00?ob/WIolc@gOo<d=d00oo>f>401?oBf=godmoQom?OhOoCgn42omCWi003omOVh?oGkN?o
engS00;oe_;T0_oBn>D00oo>nnCob?gSolklh`02olWmhP04ol?mhOnmoN7o^?cQok?kh@;o[o[S00Ko
[OWVojchjOn[mncoZoO/oj_el?n[lo<@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03?ooool0017ooooo00?o0000ooooooooool0;_ooool01?nM_NooWkk^oinnk_nO_^h2oi^nl@;o
UKkc00?oVKkboi:omOnB_oD00_nB_oD2ohRon@;oO;kl0_l05IH01?l0>[ko95_Aod=/eOm3K=D3og1j
c@;oQ8C;0onFSLP4ojBCa0;o[iW100?o/j?8okfW`onmYl<00onmYl<5olbgaP?of/O70ooReld01_oW
jM3oi_W?onKicooHolCo_?N`oiWLo@;oXMKj0_nSeoX2ojK@mP?oYm7f0_nYdODTooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Wooooo`07obZCkolK
R>Wo6hSYo`]oh_l1M]ko077Ko`1_g002o`1/fP03o`Q_g_lJM>?o6WCS00;o87ST00?o=goVod64j?m1
Q>P00_mGRNH2of>?iP?oKiCV0omnU]l3ohRJgP;oTIgL00?oSj;QoiVVgonIY]l00_nIY]l3oj6Yg0Co
ZJcJ00Co[joGok6eg?na]Mco/KGL0ong]mT01?ni_]ko_[oKokjofonn_m/2ol77g`?oa/SL0_o8d>00
0oo<d=goc]SQolkHh@02olkHh@?odmoQ0_oDin@2om?^iP03omO]hooFl^Coe_;T00;od_SU00Soc__T
olSmhoo1oN7o`OgQok[mgoncnmko[O[MojSig@;oYOOO00GoXoORoj;fiOnRmNWoXoC^ojGclP0Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool001;ooooo00?o0000oooooooo
ool0;oooool00onO_^koXKk^oj6nkP03oifnl0;oVKkb0_nB_oD2oiNol`?oT<3g0_n6`?X00ol0>[ko
04k<obAKd@02od=/e@;oL7[=0on4Q</3oiJ=b0;oY9?400?oYYg<ok>Sb?ncXlP00_ncXlP3okfW``;o
a;C;0oo<]lH2omC6c@04om[7aooRelgoh]O=on;Gc@;oinW@0_oVnLl01?nlmk3oWmCjoioDn_nQe_X3
ojC?mP03ojK@m_oooooooooo02Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02Sooooo0_lIR^T2o`R0h@05o`1ffol0JmOo06cJo`1/f_l0JmT00_l;
LMl00olPN>Co:GgWobUmi`02od64j0;oCH[Y0_mSSnH3ofnDiP?oNYWU0on5W^<3ohnRh@CoVJKO0onQ
ZM`2ojV/fP03ojVbgona]Mco/KGL00;o/KGL00?o]kOIokVng_ni_]h00_ni_]h00onn_m_o`LOOol77
g`02ol77g`05olK8g?o8d>3ob=3PolS@h?o:f>D00oo>f>42oloQi003om?OhOoDinCoe>OT00;odnkV
0_oAm>L2olgii`03om;hiOo>nnCob?gS00;o`OgQ00Oo^_gOok?kg_n]n]goV??IoiObg?nGl^7oV?;U
00;oV_;[00?oXoC^ojGcl_ooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo000Cooooo`;o0000<?ooool3oj6nkP04oifnl?nO_^ooWkk_oinnk`;oW;oa00?oUkocoi_0
l_nK`?800onF`OD2oho1n004o`0j__l0C/co@fcEod=/e@?oHWcG0_n4Q</3oiJ=b004ojBCa?nVWLco
YYg<ojJMc0Co/j?800?o_JO3olBdboo4]</00_o4]</01?o<]lKoe<K=omC6cOoDa/d2omcJe003on;G
cOoWjM3oinW@00;oi_W?00?oUNBMoioDn_nOe?X00_nSc_H2ojC?mRgooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Looooo`;o0000:?ooool2obfIl009oaV<jOl8P>7o283Qo`1ffOl0
KM?o06SBo`1Xe?l0JmWo2g7O00;o47CR0_lYONL2ocB3j@;oCH[Y0_mJT>X3ofnDiP?oNYWU0on5W^<3
ohnRh@;oVJKO00CoV:cToj6_h_nQ[n;oXJoR1?nY/]l2ok6eg0;o/[cQ0oni_]h2ok_6h`?o`LOO00Co
`loTolS@h?o8d>3ob=3P0oo:f>D00oo>f>7ocn7ToloQi003om3Xi`04olk`j_oCk^KodOCWom7di`;o
cOWW00coaocVokomhonooN?o]ocPojojg?nWn=[oXOKHoi_df?nHlmWoUo;LoiObhOnHl^D2oi[bj`03
oigbl?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`00
5Oooool00ol0003oooooooooo`0^ooooo`?oX[k]0_nO_^l01?nR_^koWko_oinokonO_nl3oi_0lP06
oiK1mOnJ`O?oV/7coi[1lonF`_Ko04k<0_lQI]T00om3K=GoHWcGof9le`02ogj:e@?oU9GA1?nVWL`3
ok>Sb003okV`dOo4]<_oa;C;00?oa;C;0ooDa/d3omcJe005on7_fOoWjM3oi_W?onKiconEi9d00_nR
cOH2oj?>mS7ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo0ol]VO002?lKSnWo1h;Qo`N2hOl0N=Oo06g@o`1Vc?l0I];o06cJ0_l@M>82oaUj
i@;o=8?Y0_m1R^`2oeZ@jP?oJ9O[0_meWNX3oh:Rj@?oSJOW1?nH[>@3oj6_hP;oZK;O0_nZ^N@4ok:l
h@03okVng_nka^?o^lKS00;o^lKS00Go`LOOol??i?o3cnCo`loTolS@h003ol[Hi@;obn7Y00Gocn7T
om3Xioo@j>Ood>SWolk`jP03ol_fjP03olGjjOo=nNOoaocV00;o_ogS00So]ocPojojg?nWn=[oS>gA
ohW/d_n9k=KoR^gKohg^h@;oT>oW00?oU?3]ooooooooool06Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00_ooooo000Fooooo`03o`000?oooooooooo02kooooo00CoX[k]ojBnk?nT
_^coY;k/0_nR_^h01?nO_nooXKo^oj6ok_nQ_nh2oik0l0;oV/7c00CoW/7aoi_2lonK`_?oVl;c0_lQ
I]T3of9le`;oOX[E0onDUM44ojJMc004ok>Sb?ni/=7o^K3AokV`d@?oa;C;0_o<a]@01?oDa/gog=[D
omcJe?oLf]@2on7_f@03om[neOnonkooUNBM03Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo02Oooooo0_l`W?802_lNTn_o28GQo`R5hOl8QN7o07[F
o`1Uaol0HLKo06;;o`1Wdol0L=`2oaUji@;o9H7Y0_m1R^`2oe2BkP?oJ9O[0_meWNX3oh:Rj@?oSJOW
0onH[>@2oj6_hP;oXKKW1?nZ^N@2ok:lh@?o/lCV0_nka^<2okc>j0;o`loT0oo4f>T00oo:f>Gobn7Y
ol_Qj@03ol[Yk003om3Xioo>l>[oboKZ00;oboKZ00WoaO[Yokkli_ndnn;o]?_Roj_igOnQm]SoV?;D
oi7_d_n<kM400_mli]@00on0j=_oQN_Soh_/jP0Oooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool001Oooooo00?o0000ooooooooool0;_ooool2ojBnk003ojFnjonS_^goXkk]
00;oXkk]00?oXKo^oj>okOnQ_nl00onQ_nl2oik1l@;oVl;c00?oW/7aob5VfOlQI]T00_m<On83ogj:
e@?oU9GA0_nVWL`00onYZmSo^K3AokV`d@03okV`d@04olBdboo<a]Coc<KDolc6e0;oe=cN00Gog=[D
on7_fOoQkmWof_kEokok_`0iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Xooooo`;o=J7c0_lSV>d02_l@S^Co07kGo`1`bol0IL?o05noo`1N`_l0
H/Wo06_Eo`Qfh?lUPNT3oc>:k@04oe2Bk_mOV^ooGi[_oenJk`;oKZ7`0on2X^T2ohfWi`;oRZg]0onF
/^/4oj6fi`;oZ[WT0_n[`NX3ok?4iP04okC=k?nlc^So_<kXokc>j0;o_=S]0oo4f>T2olCQk@05ol_Q
jOo:jNcob^W/ol[Yk?o7lNh00oo3m^h00oo;m^[oaO[YokkliP02okCkhP08oj_igOn7jlgoP>O:og_T
bOm]g/goL^7FogWUg_n1j>LRooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02ooo
ool001Sooooo0_l0000`ooooo`;oYKk[0_nS_^d2ojFnk0;oXko]0_nQ_nl2oj>ok@?oXL3_00CoW/7a
oj;1konR`Noo05O?0_m<On82og>Ch`?oTZ7O1?nYZmP3okV`d@04oko4gOo<a]Coc<KDolc6e0?oe=cN
00Coe?CUon7_fOo2o]Wo0000>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027o
oooo0_l0000[ooooo`09od>ZmolZWNoo:Yg_oaNDi_l0PmWo07?;o`1V`?l0F[Wo05fo00;o077I00?o
57kUoc>:kOlcR^d00_m3To03oenJk`;oKZ7`0ommZ>l4ohZ]k@?oU[;[0_nQ]^L2oj2nkPCoZl7Z00Go
/lCVokC=k?ndcNco]<g/okc>j004okcHk@03olCHjOo4hNgoa>7]00?o`^[a00?ob^W/olOak_o3m^h0
0_o3m^h01Onkn^_o/_[WojKhhOnVn>7oVoCI00;oQn_=00?oImW2ofWKaom]g]X00_mfhn<Uooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool001[ooooo00?o0000ooooooooool0
;Oooool4ojJnj`03ojFnk?nV_^_oYKo/00?oYKo/00?oXko]ojFok?nU_n`00onS`>d2oj;1k`04ojC0
kOl0>JGo8gcVob=liP;oLi?S0onBXMl4ojV[f005okV`dOnoa=go_lCMoko4gOo<a]@00ooDg=h00ooD
m>Go`_kIol;nf@0nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Yooooo`05od^_nOlbXo;o<Z?boc:Sl_lOV^X00_l4RM`01?l0G[Go05Rbo`1afOl0
LMT2o`9igP04ob>8jom3To3o@i?`od>Cl0;oE9cc0_mUYOD3ogfXk`;oRZg]0_n6]?<3oiBjl@CoX;k^
0_n[`NX2oj[:l@;o]<g/0once_82okcHk@;o^n7b00Goa>7]ol;ZlOo2j_7o`^[aokkalP02okSfl@;o
[_S]00Co^o[[ok;jionVn>7oY_SQ0_mch<D01?mEc[WoF=2nof7HeOm/g^0Yooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0;Oooool2ojJn
j`;oYkkZ0_nV_^/2ojFok0;oY[k[0onU_n`01?nS`>goYKo/ojFok?nU_n`2ojC0k@03oj;1kolSO>Ko
GIgb00;oGIgb0onBXMl2ojV[f0;oZkkX0_noa=d3olCMk004omCLg_oDm>Go`_kIol;nfD3ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02[ooooo0_mC
/o/02?m4[_Oo:J7^obVQk_lYXNko5iSUo`1c`_l0I;;o06_>0_l2NMh2oa24i@;o=9?`0_m7W_D3ofFU
m@?oMZge0on6]?<3oiBjl@;oX;k^0_nNa_@2oj[:l@;oZ=?g0once_82ok7Om`;o^n7b0_nijOD2ok?`
mP03okkal_nhm_7o^?Ka00;o[_S]00SoX_KVoiGbgOnEl]goG]>loeS?^?m7aKKoEM7Aof;HgBgooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003ooooooooo
o`0^ooooo`03ojNnj_nW_^WoYkkZ00?oYkkZ00?oY[k[ojNnj_nW_^X00onV_n/2ojFok006ojJojonU
_ncoYKo/ojFok?nT`>go06W=0_mMWO84oh^cl@;oZkkX0onVf?T2olCMk004ok_elOnClMKoTo7Fo`00
047ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
02[ooooo0omL^?`2odndnP07od2_m_lSX>[o8j3Zob>Pj_lBUmoo@000o`1ce003oa24i@05ob:@k?m7
W_GoAikeodNNmOmJZOP00om^/_X3ognkn@CoT<7h0_nNa_@2oi[?nPCoZ=?g00?o/mKbok7OmonagoL0
0on/ioX00onijOGo/o3fok?`mP02oj[cl`08oikckOn@kn?oT>oSoh7Xf?mchLgoImW3ocJj[om:b/d2
oeWCfboooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`007Oooool00ol0
003oooooooooo`0^ooooo`;oYkkY1onW_^X01?nV_n_oYkkZojNnj_nW_^X2ojJoj`07ojFok?nW_n_o
Yko[ojNojonV_ncoooooobjNl@02oh^cl@?oM<Ko0_nVf?T2oh_Wm`03ok_elOl0003o000004Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02_ooooo
0_mU^od3oeVio0;oC;Gi0olm/?@01Ol^Z^go07kKo`1nfol0O]_o3hcT00;o=Ykc0_m<ZoT3ofjbnP?o
Ok_i0_n@`OP3ohW9o@?oV/oj0_nXdoL01?nTg?_oW>?moicSoOnLhod2ojcWnP06ojC]nOnHk_CoV>kd
oiS^m?nZlo?oW_?]0_n@kn<2oe3;^CKooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`007_ooool2o`0002oooooo0onX_^T00onW_^[oZ;kYojRnj@05ojNnjP04ojRnj_nW_^[o
YkkZojNnjP;oYko[1Oooool00ol0OK[oM<KoogC6o`03ocfni@03oh_Wmooooooooooo04Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`;o0000;?ooool3offnoP;oHkgm0omG
^_`2od^gn0?o?K;c00Co>@00o`1___l0QMOo99_]0om<ZoT3of:go0?oMl7n0_n9bOd2oh3?o`;oTmOn
0on9g?h2oicSo@;oTNOj00GoY>gioiS^m?nHk_CoV>kdoh[/j`02og[UgP03ocRk[ooooooooooo03So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`008?ooool00ol0003ooooo
ooooo`0]ooooo`KoZ;kY00CoYkkZojRnjOnX_^WoZ;kY0_nX_^X00onW_^[oooooooooo`1Fooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0[ooooo`04
ogG1o_ml`ogoO<?mogc3o@;oML?n0om]`_h2of?1o@;oFKol00CoCkgho`1la_l0O<Ko49CQ0olkZ_@3
oe>hn`?oJ/Gn00CoP<ooog?BoOmcd_goLm;m0_n9g?h2ogcMnP;oTNOj0_n3i_<00ombhNOoHMSHof7H
f00nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0027ooooo00?o0000
ooooooooool0;Oooool00onX_^WoZKgYojVmj@05ojRnjEgooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo0_n3a?d3ogg4oP;oM/Gn0_m^a?l2
ofK4oP;oLLOo0omZaoh01Ol0P[go59gKoaBMfolDWM_o;K3V00;oFlGj0om8`Nl2of?AmP;oD<_X0_m[
f^l00omHd^3oooooooooo`12ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool002;ooooo00?o0000ooooooooool0;Oooool3ojVmj@03ojRnjOoooooooooo05oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo0on8aO/2
ohC6o@03ogk6o_oooooooooo05gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`008oooool2o`0002gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo0_l0000]ooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`009Oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
I?ooool01Ol0003ooooooooooooooooo000002oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1Tooooo`05o`000?ooooooooooooooool000002oooool002Oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`00033ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo000Xoooo
o`;o0000:?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo0000037ooooo0_l0000Xoooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool002[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000003?ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000_ooooo000[ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooo`00000cooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooo`00000:ooooo`00;?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo0_l0000dooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0J?ooool2o`0000[ooooo000]ooooo`;o00008oooool0
0ol0003oooooooooo`1Wooooo`?o0000=Oooool2o`0002?ooooo00?o0000ooooooooool0Ioooool3
o`0000[ooooo000_ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4o`00
03[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Sooooo`Co00003Oooool0033o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Pooooo`?o0000?oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo063ooooo0ol0000Aooooo`00<Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l00013ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0G?ooool4o`0001Cooooo000booooo`;o00007_ooool00ol0003ooooooooo
o`1Hooooo`Co0000B?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0001Sooooo000d
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0004kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`1Dooooo`Co00007?ooool003Gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1Aooooo`?o0000Doooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo057ooooo0ol0000Pooooo`00=_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04gooooo1?l0001Gooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0COooool4o`0002?ooooo000gooooo`;o00006Oooool00ol0003oooooooooo`19ooooo`Co0000
G?ooool2o`0001Wooooo00?o0000ooooooooool0BOooool4o`0002Oooooo000iooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0006;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`15ooooo`Co0000:oooool003[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`13ooooo`?o0000Ioooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo04?ooooo0ol0000_ooooo`00>oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03oooooo1?l0001[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?oooool4o`00
03;ooooo000looooo`;o00004oooool00ol0003oooooooooo`0kooooo`Co0000L?ooool2o`0001?o
oooo00?o0000ooooooooool0>oooool4o`0003Kooooo000nooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0=oooool4o`0007Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0gooooo`Co0000>_ooool003oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0cooooo`Co0000Noooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo1?l0
000nooooo`00@?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0ol00020
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool3o`0004;ooooo0011oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4o`0008Cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0/ooooo`Co0000AOooool004;ooooo0_l0000=ooooo`03
o`000?oooooooooo02Sooooo1?l00029ooooo`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co
0000BOooool004Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`Co0000
Soooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Cooooo1?l0001=ooooo`00AOoo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0002Dooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo0016ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07Oooool4o`0009Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Mooooo`Co0000E?ooool004Oooooo0_l00008ooooo`03o`000?oooooooooo
01Wooooo1?l0002Mooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool004Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000Xoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0001Looooo`00B_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0002Xooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04_ooool3o`00063ooooo001;ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool4o`000:cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0>ooooo`Co0000Hoooool004cooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002a
ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000Ioooool004kooooo00Co0000oooo
oooooooo00002?ooool4o`000;Oooooo00Co0000oooooooooooo00002?ooool4o`0006_ooooo001?
ooooo`03o`000?oooooo000000Gooooo0ol0002looooo`03o`000?oooooo000000Gooooo0ol0001_
ooooo`00D?ooool2o`000003ooooool0003o000000;o0000`?ooool2o`000003ooooool0003o0000
00;o0000L_ooool0057ooooo0_l00035ooooo`;o0000M_ooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-0.209219, \
-0.0749526, 0.00708998, 0.00708998}, {{208.5, 389.375}, {315.688, 169}} -> \
{-1.61946, -0.0749526, 0.00708998, 0.00708998}, {{9.625, 190.438}, {154.375, \
7.6875}} -> {-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, \
389.375}, {154.375, 7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{PlotTwoClassificationRegions[pdf1, pdf2, pr, x, 
              y, {class2Color, class1Color}, Axes \[Rule] False, 
              Frame \[Rule] True, nF, nS], idealPlot}], yS, \ 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.15002 .50927 m
.15085 .4858 L
.1516 .47681 L
.1533 .4626 L
.15637 .44454 L
.15994 .42857 L
.16332 .41609 L
.17734 .37727 L
.19163 .34834 L
.20715 .32323 L
.23605 .28675 L
.26389 .25978 L
.29065 .23909 L
.31914 .22142 L
.34657 .20794 L
.37573 .19686 L
.39029 .19247 L
.40381 .18903 L
.41772 .18612 L
.43083 .18394 L
.4378 .183 L
.44534 .18214 L
.45215 .18152 L
.4585 .18107 L
.46523 .18072 L
.46879 .18059 L
.47079 .18053 L
.47261 .18049 L
.47353 .18047 L
.47451 .18046 L
.47536 .18045 L
.47627 .18044 L
.47678 .18043 L
.47725 .18043 L
.47817 .18043 L
.47865 .18043 L
.47919 .18043 L
.47974 .18043 L
.48026 .18043 L
.48071 .18043 L
.4812 .18043 L
.48209 .18044 L
.48296 .18045 L
.48376 .18046 L
.48558 .18048 L
.48751 .18053 L
.49099 .18063 L
.49418 .18075 L
.50135 .18115 L
.508 .18165 L
Mistroke
.51431 .18224 L
.52834 .184 L
.54136 .18617 L
.56907 .19253 L
.59852 .20204 L
.6269 .21411 L
.6542 .22872 L
.68324 .24802 L
.71121 .27104 L
.7381 .29851 L
.76673 .33605 L
.77994 .35774 L
.79429 .38643 L
.80211 .4056 L
.80934 .42712 L
.81625 .45416 L
.81974 .47323 L
.82069 .4799 L
.82172 .48845 L
.82219 .49317 L
.82269 .49906 L
.82358 .51757 L
.82365 .52433 L
Mfstroke
.15002 .50954 m
.15085 .53305 L
.1516 .54207 L
.1533 .55637 L
.15637 .57456 L
.15994 .59069 L
.16332 .60332 L
.17734 .64276 L
.19163 .67233 L
.20715 .69814 L
.23605 .73591 L
.26389 .76413 L
.29065 .78601 L
.31914 .80495 L
.34657 .81967 L
.37573 .83205 L
.40381 .84113 L
.43083 .84743 L
.44474 .84978 L
.45958 .85165 L
.46685 .85232 L
.47068 .85261 L
.47472 .85287 L
.47826 .85306 L
.48215 .85322 L
.48386 .85328 L
.48569 .85333 L
.48726 .85337 L
.48899 .8534 L
.48986 .85342 L
.4908 .85343 L
.49132 .85343 L
.49179 .85344 L
.49273 .85344 L
.49353 .85344 L
.49441 .85345 L
.49533 .85344 L
.49618 .85344 L
.49667 .85344 L
.4972 .85343 L
.49817 .85342 L
.49997 .8534 L
.50207 .85336 L
.50401 .85331 L
.5073 .8532 L
.51092 .85304 L
.51824 .8526 L
.52543 .85201 L
.532 .85133 L
.54678 .84933 L
Mistroke
.56023 .84692 L
.5749 .84363 L
.60369 .83508 L
.6314 .82403 L
.66085 .80887 L
.68923 .79037 L
.71653 .76813 L
.74557 .73811 L
.76004 .7198 L
.77354 .69991 L
.78761 .67507 L
.80043 .6467 L
.80615 .63111 L
.81236 .61058 L
.81521 .59912 L
.81823 .58446 L
.82081 .56802 L
.82152 .56225 L
.82228 .55481 L
.82299 .54546 L
.82365 .5246 L
Mfstroke
.5 1 1 r
.15002 .50927 m
.15085 .4858 L
.1516 .47681 L
.1533 .4626 L
.15637 .44454 L
.15994 .42857 L
.16332 .41609 L
.17734 .37727 L
.19163 .34834 L
.20715 .32323 L
.23605 .28675 L
.26389 .25978 L
.29065 .23909 L
.31914 .22142 L
.34657 .20794 L
.37573 .19686 L
.39029 .19247 L
.40381 .18903 L
.41772 .18612 L
.43083 .18394 L
.4378 .183 L
.44534 .18214 L
.45215 .18152 L
.4585 .18107 L
.46523 .18072 L
.46879 .18059 L
.47079 .18053 L
.47261 .18049 L
.47353 .18047 L
.47451 .18046 L
.47536 .18045 L
.47627 .18044 L
.47678 .18043 L
.47725 .18043 L
.47817 .18043 L
.47865 .18043 L
.47919 .18043 L
.47974 .18043 L
.48026 .18043 L
.48071 .18043 L
.4812 .18043 L
.48209 .18044 L
.48296 .18045 L
.48376 .18046 L
.48558 .18048 L
.48751 .18053 L
.49099 .18063 L
.49418 .18075 L
.50135 .18115 L
.508 .18165 L
.51431 .18224 L
.52834 .184 L
.54136 .18617 L
.56907 .19253 L
.59852 .20204 L
.6269 .21411 L
.6542 .22872 L
.68324 .24802 L
.71121 .27104 L
.7381 .29851 L
.76673 .33605 L
.77994 .35774 L
.79429 .38643 L
.80211 .4056 L
.80934 .42712 L
.81625 .45416 L
.81974 .47323 L
.82069 .4799 L
.82172 .48845 L
.82219 .49317 L
.82269 .49906 L
.82358 .51757 L
.82365 .52433 L
.82365 .5246 L
.82299 .54546 L
.82228 .55481 L
.82152 .56225 L
.82081 .56802 L
.81823 .58446 L
.81521 .59912 L
.81236 .61058 L
.80615 .63111 L
.80043 .6467 L
.78761 .67507 L
.77354 .69991 L
.76004 .7198 L
.74557 .73811 L
.71653 .76813 L
.68923 .79037 L
.66085 .80887 L
.6314 .82403 L
.60369 .83508 L
.5749 .84363 L
.56023 .84692 L
.54678 .84933 L
.532 .85133 L
.52543 .85201 L
.51824 .8526 L
.51092 .85304 L
.5073 .8532 L
.50401 .85331 L
.50207 .85336 L
.49997 .8534 L
.49817 .85342 L
.4972 .85343 L
.49667 .85344 L
.49618 .85344 L
.49533 .85344 L
.49441 .85345 L
.49353 .85344 L
.49273 .85344 L
.49179 .85344 L
.49132 .85343 L
.4908 .85343 L
.48986 .85342 L
.48899 .8534 L
.48726 .85337 L
.48569 .85333 L
.48386 .85328 L
.48215 .85322 L
.47826 .85306 L
.47472 .85287 L
.47068 .85261 L
.46685 .85232 L
.45958 .85165 L
.44474 .84978 L
.43083 .84743 L
.40381 .84113 L
.37573 .83205 L
.34657 .81967 L
.31914 .80495 L
.29065 .78601 L
.26389 .76413 L
.23605 .73591 L
.20715 .69814 L
.19163 .67233 L
.17734 .64276 L
.16332 .60332 L
.15994 .59069 L
.15637 .57456 L
.1533 .55637 L
.1516 .54207 L
.15085 .53305 L
.15002 .50954 L
F
0 g
.15002 .50927 m
.15085 .4858 L
.1516 .47681 L
.1533 .4626 L
.15637 .44454 L
.15994 .42857 L
.16332 .41609 L
.17734 .37727 L
.19163 .34834 L
.20715 .32323 L
.23605 .28675 L
.26389 .25978 L
.29065 .23909 L
.31914 .22142 L
.34657 .20794 L
.37573 .19686 L
.39029 .19247 L
.40381 .18903 L
.41772 .18612 L
.43083 .18394 L
.4378 .183 L
.44534 .18214 L
.45215 .18152 L
.4585 .18107 L
.46523 .18072 L
.46879 .18059 L
.47079 .18053 L
.47261 .18049 L
.47353 .18047 L
.47451 .18046 L
.47536 .18045 L
.47627 .18044 L
.47678 .18043 L
.47725 .18043 L
.47817 .18043 L
.47865 .18043 L
.47919 .18043 L
.47974 .18043 L
.48026 .18043 L
.48071 .18043 L
.4812 .18043 L
.48209 .18044 L
.48296 .18045 L
.48376 .18046 L
.48558 .18048 L
.48751 .18053 L
.49099 .18063 L
.49418 .18075 L
.50135 .18115 L
.508 .18165 L
Mistroke
.51431 .18224 L
.52834 .184 L
.54136 .18617 L
.56907 .19253 L
.59852 .20204 L
.6269 .21411 L
.6542 .22872 L
.68324 .24802 L
.71121 .27104 L
.7381 .29851 L
.76673 .33605 L
.77994 .35774 L
.79429 .38643 L
.80211 .4056 L
.80934 .42712 L
.81625 .45416 L
.81974 .47323 L
.82069 .4799 L
.82172 .48845 L
.82219 .49317 L
.82269 .49906 L
.82358 .51757 L
.82365 .52433 L
Mfstroke
.15002 .50954 m
.15085 .53305 L
.1516 .54207 L
.1533 .55637 L
.15637 .57456 L
.15994 .59069 L
.16332 .60332 L
.17734 .64276 L
.19163 .67233 L
.20715 .69814 L
.23605 .73591 L
.26389 .76413 L
.29065 .78601 L
.31914 .80495 L
.34657 .81967 L
.37573 .83205 L
.40381 .84113 L
.43083 .84743 L
.44474 .84978 L
.45958 .85165 L
.46685 .85232 L
.47068 .85261 L
.47472 .85287 L
.47826 .85306 L
.48215 .85322 L
.48386 .85328 L
.48569 .85333 L
.48726 .85337 L
.48899 .8534 L
.48986 .85342 L
.4908 .85343 L
.49132 .85343 L
.49179 .85344 L
.49273 .85344 L
.49353 .85344 L
.49441 .85345 L
.49533 .85344 L
.49618 .85344 L
.49667 .85344 L
.4972 .85343 L
.49817 .85342 L
.49997 .8534 L
.50207 .85336 L
.50401 .85331 L
.5073 .8532 L
.51092 .85304 L
.51824 .8526 L
.52543 .85201 L
.532 .85133 L
.54678 .84933 L
Mistroke
.56023 .84692 L
.5749 .84363 L
.60369 .83508 L
.6314 .82403 L
.66085 .80887 L
.68923 .79037 L
.71653 .76813 L
.74557 .73811 L
.76004 .7198 L
.77354 .69991 L
.78761 .67507 L
.80043 .6467 L
.80615 .63111 L
.81236 .61058 L
.81521 .59912 L
.81823 .58446 L
.82081 .56802 L
.82152 .56225 L
.82228 .55481 L
.82299 .54546 L
.82365 .5246 L
Mfstroke
.0098 .0098 m
.01549 .0098 L
.0217 .0098 L
.02752 .0098 L
.03312 .0098 L
.03909 .0098 L
.04483 .0098 L
.05093 .0098 L
.05681 .0098 L
.06246 .0098 L
.06848 .0098 L
.07427 .0098 L
.07984 .0098 L
.08578 .0098 L
.09148 .0098 L
.09755 .0098 L
.1034 .0098 L
.10902 .0098 L
.11501 .0098 L
.12077 .0098 L
.12689 .0098 L
.13279 .0098 L
.13846 .0098 L
.1445 .0098 L
.15002 .0098 L
s
.0098 .9902 m
.01549 .9902 L
.0217 .9902 L
.02752 .9902 L
.03312 .9902 L
.03909 .9902 L
.04483 .9902 L
.05093 .9902 L
.05681 .9902 L
.06246 .9902 L
.06848 .9902 L
.07427 .9902 L
.07984 .9902 L
.08578 .9902 L
.09148 .9902 L
.09755 .9902 L
.1034 .9902 L
.10902 .9902 L
.11501 .9902 L
.12077 .9902 L
.12689 .9902 L
.13279 .9902 L
.13846 .9902 L
.1445 .9902 L
.15002 .9902 L
s
1 1 .5 r
.0098 .0098 m
.01549 .0098 L
.0217 .0098 L
.02752 .0098 L
.03312 .0098 L
.03909 .0098 L
.04483 .0098 L
.05093 .0098 L
.05681 .0098 L
.06246 .0098 L
.06848 .0098 L
.07427 .0098 L
.07984 .0098 L
.08578 .0098 L
.09148 .0098 L
.09755 .0098 L
.1034 .0098 L
.10902 .0098 L
.11501 .0098 L
.12077 .0098 L
.12689 .0098 L
.13279 .0098 L
.13846 .0098 L
.1445 .0098 L
.15002 .0098 L
.15002 .9902 L
.1445 .9902 L
.13846 .9902 L
.13279 .9902 L
.12689 .9902 L
.12077 .9902 L
.11501 .9902 L
.10902 .9902 L
.1034 .9902 L
.09755 .9902 L
.09148 .9902 L
.08578 .9902 L
.07984 .9902 L
.07427 .9902 L
.06848 .9902 L
.06246 .9902 L
.05681 .9902 L
.05093 .9902 L
.04483 .9902 L
.03909 .9902 L
.03312 .9902 L
.02752 .9902 L
.0217 .9902 L
.01549 .9902 L
.0098 .9902 L
F
0 g
.0098 .0098 m
.01549 .0098 L
.0217 .0098 L
.02752 .0098 L
.03312 .0098 L
.03909 .0098 L
.04483 .0098 L
.05093 .0098 L
.05681 .0098 L
.06246 .0098 L
.06848 .0098 L
.07427 .0098 L
.07984 .0098 L
.08578 .0098 L
.09148 .0098 L
.09755 .0098 L
.1034 .0098 L
.10902 .0098 L
.11501 .0098 L
.12077 .0098 L
.12689 .0098 L
.13279 .0098 L
.13846 .0098 L
.1445 .0098 L
.15002 .0098 L
s
.0098 .9902 m
.01549 .9902 L
.0217 .9902 L
.02752 .9902 L
.03312 .9902 L
.03909 .9902 L
.04483 .9902 L
.05093 .9902 L
.05681 .9902 L
.06246 .9902 L
.06848 .9902 L
.07427 .9902 L
.07984 .9902 L
.08578 .9902 L
.09148 .9902 L
.09755 .9902 L
.1034 .9902 L
.10902 .9902 L
.11501 .9902 L
.12077 .9902 L
.12689 .9902 L
.13279 .9902 L
.13846 .9902 L
.1445 .9902 L
.15002 .9902 L
s
.15002 .0098 m
.17734 .0098 L
.20715 .0098 L
.23514 .0098 L
.26205 .0098 L
.29071 .0098 L
.31829 .0098 L
.3476 .0098 L
.37585 .0098 L
.40302 .0098 L
.43192 .0098 L
.45976 .0098 L
.48652 .0098 L
.51501 .0098 L
.54244 .0098 L
.5716 .0098 L
.59968 .0098 L
.6267 .0098 L
.65545 .0098 L
.68312 .0098 L
.71254 .0098 L
.74088 .0098 L
.76814 .0098 L
.79715 .0098 L
.82365 .0098 L
s
.15002 .50927 m
.15085 .4858 L
.1516 .47681 L
.1533 .4626 L
.15637 .44454 L
.15994 .42857 L
.16332 .41609 L
.17734 .37727 L
.19163 .34834 L
.20715 .32323 L
.23605 .28675 L
.26389 .25978 L
.29065 .23909 L
.31914 .22142 L
.34657 .20794 L
.37573 .19686 L
.39029 .19247 L
.40381 .18903 L
.41772 .18612 L
.43083 .18394 L
.4378 .183 L
.44534 .18214 L
.45215 .18152 L
.4585 .18107 L
.46523 .18072 L
.46879 .18059 L
.47079 .18053 L
.47261 .18049 L
.47353 .18047 L
.47451 .18046 L
.47536 .18045 L
.47627 .18044 L
.47678 .18043 L
.47725 .18043 L
.47817 .18043 L
.47865 .18043 L
.47919 .18043 L
.47974 .18043 L
.48026 .18043 L
.48071 .18043 L
.4812 .18043 L
.48209 .18044 L
.48296 .18045 L
.48376 .18046 L
.48558 .18048 L
.48751 .18053 L
.49099 .18063 L
.49418 .18075 L
.50135 .18115 L
.508 .18165 L
Mistroke
.51431 .18224 L
.52834 .184 L
.54136 .18617 L
.56907 .19253 L
.59852 .20204 L
.6269 .21411 L
.6542 .22872 L
.68324 .24802 L
.71121 .27104 L
.7381 .29851 L
.76673 .33605 L
.77994 .35774 L
.79429 .38643 L
.80211 .4056 L
.80934 .42712 L
.81625 .45416 L
.81974 .47323 L
.82069 .4799 L
.82172 .48845 L
.82219 .49317 L
.82269 .49906 L
.82358 .51757 L
.82365 .52433 L
Mfstroke
1 1 .5 r
.15002 .0098 m
.17734 .0098 L
.20715 .0098 L
.23514 .0098 L
.26205 .0098 L
.29071 .0098 L
.31829 .0098 L
.3476 .0098 L
.37585 .0098 L
.40302 .0098 L
.43192 .0098 L
.45976 .0098 L
.48652 .0098 L
.51501 .0098 L
.54244 .0098 L
.5716 .0098 L
.59968 .0098 L
.6267 .0098 L
.65545 .0098 L
.68312 .0098 L
.71254 .0098 L
.74088 .0098 L
.76814 .0098 L
.79715 .0098 L
.82365 .0098 L
.82365 .52433 L
.82358 .51757 L
.82269 .49906 L
.82219 .49317 L
.82172 .48845 L
.82069 .4799 L
.81974 .47323 L
.81625 .45416 L
.80934 .42712 L
.80211 .4056 L
.79429 .38643 L
.77994 .35774 L
.76673 .33605 L
.7381 .29851 L
.71121 .27104 L
.68324 .24802 L
.6542 .22872 L
.6269 .21411 L
.59852 .20204 L
.56907 .19253 L
.54136 .18617 L
.52834 .184 L
.51431 .18224 L
.508 .18165 L
.50135 .18115 L
.49418 .18075 L
.49099 .18063 L
.48751 .18053 L
.48558 .18048 L
.48376 .18046 L
.48296 .18045 L
.48209 .18044 L
.4812 .18043 L
.48071 .18043 L
.48026 .18043 L
.47974 .18043 L
.47919 .18043 L
.47865 .18043 L
.47817 .18043 L
.47725 .18043 L
.47678 .18043 L
.47627 .18044 L
.47536 .18045 L
.47451 .18046 L
.47353 .18047 L
.47261 .18049 L
.47079 .18053 L
.46879 .18059 L
.46523 .18072 L
.4585 .18107 L
.45215 .18152 L
.44534 .18214 L
.4378 .183 L
.43083 .18394 L
.41772 .18612 L
.40381 .18903 L
.39029 .19247 L
.37573 .19686 L
.34657 .20794 L
.31914 .22142 L
.29065 .23909 L
.26389 .25978 L
.23605 .28675 L
.20715 .32323 L
.19163 .34834 L
.17734 .37727 L
.16332 .41609 L
.15994 .42857 L
.15637 .44454 L
.1533 .4626 L
.1516 .47681 L
.15085 .4858 L
.15002 .50927 L
F
0 g
.15002 .0098 m
.17734 .0098 L
.20715 .0098 L
.23514 .0098 L
.26205 .0098 L
.29071 .0098 L
.31829 .0098 L
.3476 .0098 L
.37585 .0098 L
.40302 .0098 L
.43192 .0098 L
.45976 .0098 L
.48652 .0098 L
.51501 .0098 L
.54244 .0098 L
.5716 .0098 L
.59968 .0098 L
.6267 .0098 L
.65545 .0098 L
.68312 .0098 L
.71254 .0098 L
.74088 .0098 L
.76814 .0098 L
.79715 .0098 L
.82365 .0098 L
s
.15002 .50927 m
.15085 .4858 L
.1516 .47681 L
.1533 .4626 L
.15637 .44454 L
.15994 .42857 L
.16332 .41609 L
.17734 .37727 L
.19163 .34834 L
.20715 .32323 L
.23605 .28675 L
.26389 .25978 L
.29065 .23909 L
.31914 .22142 L
.34657 .20794 L
.37573 .19686 L
.39029 .19247 L
.40381 .18903 L
.41772 .18612 L
.43083 .18394 L
.4378 .183 L
.44534 .18214 L
.45215 .18152 L
.4585 .18107 L
.46523 .18072 L
.46879 .18059 L
.47079 .18053 L
.47261 .18049 L
.47353 .18047 L
.47451 .18046 L
.47536 .18045 L
.47627 .18044 L
.47678 .18043 L
.47725 .18043 L
.47817 .18043 L
.47865 .18043 L
.47919 .18043 L
.47974 .18043 L
.48026 .18043 L
.48071 .18043 L
.4812 .18043 L
.48209 .18044 L
.48296 .18045 L
.48376 .18046 L
.48558 .18048 L
.48751 .18053 L
.49099 .18063 L
.49418 .18075 L
.50135 .18115 L
.508 .18165 L
Mistroke
.51431 .18224 L
.52834 .184 L
.54136 .18617 L
.56907 .19253 L
.59852 .20204 L
.6269 .21411 L
.6542 .22872 L
.68324 .24802 L
.71121 .27104 L
.7381 .29851 L
.76673 .33605 L
.77994 .35774 L
.79429 .38643 L
.80211 .4056 L
.80934 .42712 L
.81625 .45416 L
.81974 .47323 L
.82069 .4799 L
.82172 .48845 L
.82219 .49317 L
.82269 .49906 L
.82358 .51757 L
.82365 .52433 L
Mfstroke
.82365 .0098 m
.83041 .0098 L
.83778 .0098 L
.8447 .0098 L
.85135 .0098 L
.85844 .0098 L
.86525 .0098 L
.8725 .0098 L
.87948 .0098 L
.8862 .0098 L
.89335 .0098 L
.90023 .0098 L
.90685 .0098 L
.91389 .0098 L
.92067 .0098 L
.92788 .0098 L
.93482 .0098 L
.9415 .0098 L
.94861 .0098 L
.95545 .0098 L
.96272 .0098 L
.96973 .0098 L
.97647 .0098 L
.98364 .0098 L
.9902 .0098 L
s
.82365 .9902 m
.83041 .9902 L
.83778 .9902 L
.8447 .9902 L
.85135 .9902 L
.85844 .9902 L
.86525 .9902 L
.8725 .9902 L
.87948 .9902 L
.8862 .9902 L
.89335 .9902 L
.90023 .9902 L
.90685 .9902 L
.91389 .9902 L
.92067 .9902 L
.92788 .9902 L
.93482 .9902 L
.9415 .9902 L
.94861 .9902 L
.95545 .9902 L
.96272 .9902 L
.96973 .9902 L
.97647 .9902 L
.98364 .9902 L
.9902 .9902 L
s
1 1 .5 r
.82365 .0098 m
.83041 .0098 L
.83778 .0098 L
.8447 .0098 L
.85135 .0098 L
.85844 .0098 L
.86525 .0098 L
.8725 .0098 L
.87948 .0098 L
.8862 .0098 L
.89335 .0098 L
.90023 .0098 L
.90685 .0098 L
.91389 .0098 L
.92067 .0098 L
.92788 .0098 L
.93482 .0098 L
.9415 .0098 L
.94861 .0098 L
.95545 .0098 L
.96272 .0098 L
.96973 .0098 L
.97647 .0098 L
.98364 .0098 L
.9902 .0098 L
.9902 .9902 L
.98364 .9902 L
.97647 .9902 L
.96973 .9902 L
.96272 .9902 L
.95545 .9902 L
.94861 .9902 L
.9415 .9902 L
.93482 .9902 L
.92788 .9902 L
.92067 .9902 L
.91389 .9902 L
.90685 .9902 L
.90023 .9902 L
.89335 .9902 L
.8862 .9902 L
.87948 .9902 L
.8725 .9902 L
.86525 .9902 L
.85844 .9902 L
.85135 .9902 L
.8447 .9902 L
.83778 .9902 L
.83041 .9902 L
.82365 .9902 L
F
0 g
.82365 .0098 m
.83041 .0098 L
.83778 .0098 L
.8447 .0098 L
.85135 .0098 L
.85844 .0098 L
.86525 .0098 L
.8725 .0098 L
.87948 .0098 L
.8862 .0098 L
.89335 .0098 L
.90023 .0098 L
.90685 .0098 L
.91389 .0098 L
.92067 .0098 L
.92788 .0098 L
.93482 .0098 L
.9415 .0098 L
.94861 .0098 L
.95545 .0098 L
.96272 .0098 L
.96973 .0098 L
.97647 .0098 L
.98364 .0098 L
.9902 .0098 L
s
.82365 .9902 m
.83041 .9902 L
.83778 .9902 L
.8447 .9902 L
.85135 .9902 L
.85844 .9902 L
.86525 .9902 L
.8725 .9902 L
.87948 .9902 L
.8862 .9902 L
.89335 .9902 L
.90023 .9902 L
.90685 .9902 L
.91389 .9902 L
.92067 .9902 L
.92788 .9902 L
.93482 .9902 L
.9415 .9902 L
.94861 .9902 L
.95545 .9902 L
.96272 .9902 L
.96973 .9902 L
.97647 .9902 L
.98364 .9902 L
.9902 .9902 L
s
.15002 .50954 m
.15085 .53305 L
.1516 .54207 L
.1533 .55637 L
.15637 .57456 L
.15994 .59069 L
.16332 .60332 L
.17734 .64276 L
.19163 .67233 L
.20715 .69814 L
.23605 .73591 L
.26389 .76413 L
.29065 .78601 L
.31914 .80495 L
.34657 .81967 L
.37573 .83205 L
.40381 .84113 L
.43083 .84743 L
.44474 .84978 L
.45958 .85165 L
.46685 .85232 L
.47068 .85261 L
.47472 .85287 L
.47826 .85306 L
.48215 .85322 L
.48386 .85328 L
.48569 .85333 L
.48726 .85337 L
.48899 .8534 L
.48986 .85342 L
.4908 .85343 L
.49132 .85343 L
.49179 .85344 L
.49273 .85344 L
.49353 .85344 L
.49441 .85345 L
.49533 .85344 L
.49618 .85344 L
.49667 .85344 L
.4972 .85343 L
.49817 .85342 L
.49997 .8534 L
.50207 .85336 L
.50401 .85331 L
.5073 .8532 L
.51092 .85304 L
.51824 .8526 L
.52543 .85201 L
.532 .85133 L
.54678 .84933 L
Mistroke
.56023 .84692 L
.5749 .84363 L
.60369 .83508 L
.6314 .82403 L
.66085 .80887 L
.68923 .79037 L
.71653 .76813 L
.74557 .73811 L
.76004 .7198 L
.77354 .69991 L
.78761 .67507 L
.80043 .6467 L
.80615 .63111 L
.81236 .61058 L
.81521 .59912 L
.81823 .58446 L
.82081 .56802 L
.82152 .56225 L
.82228 .55481 L
.82299 .54546 L
.82365 .5246 L
Mfstroke
.15002 .9902 m
.17734 .9902 L
.20715 .9902 L
.23514 .9902 L
.26205 .9902 L
.29071 .9902 L
.31829 .9902 L
.3476 .9902 L
.37585 .9902 L
.40302 .9902 L
.43192 .9902 L
.45976 .9902 L
.48652 .9902 L
.51501 .9902 L
.54244 .9902 L
.5716 .9902 L
.59968 .9902 L
.6267 .9902 L
.65545 .9902 L
.68312 .9902 L
.71254 .9902 L
.74088 .9902 L
.76814 .9902 L
.79715 .9902 L
.82365 .9902 L
s
1 1 .5 r
.15002 .50954 m
.15085 .53305 L
.1516 .54207 L
.1533 .55637 L
.15637 .57456 L
.15994 .59069 L
.16332 .60332 L
.17734 .64276 L
.19163 .67233 L
.20715 .69814 L
.23605 .73591 L
.26389 .76413 L
.29065 .78601 L
.31914 .80495 L
.34657 .81967 L
.37573 .83205 L
.40381 .84113 L
.43083 .84743 L
.44474 .84978 L
.45958 .85165 L
.46685 .85232 L
.47068 .85261 L
.47472 .85287 L
.47826 .85306 L
.48215 .85322 L
.48386 .85328 L
.48569 .85333 L
.48726 .85337 L
.48899 .8534 L
.48986 .85342 L
.4908 .85343 L
.49132 .85343 L
.49179 .85344 L
.49273 .85344 L
.49353 .85344 L
.49441 .85345 L
.49533 .85344 L
.49618 .85344 L
.49667 .85344 L
.4972 .85343 L
.49817 .85342 L
.49997 .8534 L
.50207 .85336 L
.50401 .85331 L
.5073 .8532 L
.51092 .85304 L
.51824 .8526 L
.52543 .85201 L
.532 .85133 L
.54678 .84933 L
.56023 .84692 L
.5749 .84363 L
.60369 .83508 L
.6314 .82403 L
.66085 .80887 L
.68923 .79037 L
.71653 .76813 L
.74557 .73811 L
.76004 .7198 L
.77354 .69991 L
.78761 .67507 L
.80043 .6467 L
.80615 .63111 L
.81236 .61058 L
.81521 .59912 L
.81823 .58446 L
.82081 .56802 L
.82152 .56225 L
.82228 .55481 L
.82299 .54546 L
.82365 .5246 L
.82365 .9902 L
.79715 .9902 L
.76814 .9902 L
.74088 .9902 L
.71254 .9902 L
.68312 .9902 L
.65545 .9902 L
.6267 .9902 L
.59968 .9902 L
.5716 .9902 L
.54244 .9902 L
.51501 .9902 L
.48652 .9902 L
.45976 .9902 L
.43192 .9902 L
.40302 .9902 L
.37585 .9902 L
.3476 .9902 L
.31829 .9902 L
.29071 .9902 L
.26205 .9902 L
.23514 .9902 L
.20715 .9902 L
.17734 .9902 L
.15002 .9902 L
F
0 g
.15002 .50954 m
.15085 .53305 L
.1516 .54207 L
.1533 .55637 L
.15637 .57456 L
.15994 .59069 L
.16332 .60332 L
.17734 .64276 L
.19163 .67233 L
.20715 .69814 L
.23605 .73591 L
.26389 .76413 L
.29065 .78601 L
.31914 .80495 L
.34657 .81967 L
.37573 .83205 L
.40381 .84113 L
.43083 .84743 L
.44474 .84978 L
.45958 .85165 L
.46685 .85232 L
.47068 .85261 L
.47472 .85287 L
.47826 .85306 L
.48215 .85322 L
.48386 .85328 L
.48569 .85333 L
.48726 .85337 L
.48899 .8534 L
.48986 .85342 L
.4908 .85343 L
.49132 .85343 L
.49179 .85344 L
.49273 .85344 L
.49353 .85344 L
.49441 .85345 L
.49533 .85344 L
.49618 .85344 L
.49667 .85344 L
.4972 .85343 L
.49817 .85342 L
.49997 .8534 L
.50207 .85336 L
.50401 .85331 L
.5073 .8532 L
.51092 .85304 L
.51824 .8526 L
.52543 .85201 L
.532 .85133 L
.54678 .84933 L
Mistroke
.56023 .84692 L
.5749 .84363 L
.60369 .83508 L
.6314 .82403 L
.66085 .80887 L
.68923 .79037 L
.71653 .76813 L
.74557 .73811 L
.76004 .7198 L
.77354 .69991 L
.78761 .67507 L
.80043 .6467 L
.80615 .63111 L
.81236 .61058 L
.81521 .59912 L
.81823 .58446 L
.82081 .56802 L
.82152 .56225 L
.82228 .55481 L
.82299 .54546 L
.82365 .5246 L
Mfstroke
.15002 .9902 m
.17734 .9902 L
.20715 .9902 L
.23514 .9902 L
.26205 .9902 L
.29071 .9902 L
.31829 .9902 L
.3476 .9902 L
.37585 .9902 L
.40302 .9902 L
.43192 .9902 L
.45976 .9902 L
.48652 .9902 L
.51501 .9902 L
.54244 .9902 L
.5716 .9902 L
.59968 .9902 L
.6267 .9902 L
.65545 .9902 L
.68312 .9902 L
.71254 .9902 L
.74088 .9902 L
.76814 .9902 L
.79715 .9902 L
.82365 .9902 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
1 1 .5 r
.5 .5 m
.5 .5 .11429 0 365.73 arc
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_oooonco`000003
ooooool0003ooooo013ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0:l0oomo0_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooojcooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooom>ooooOa<0OoooBoooogl4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo04h0oomo2ol0001F0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooom8ooooOal0OoooAOooogl4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo04L0oomo1@000002o`0000/0Oooo2@00001=
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooom5ooooOb@0Oooo@ooo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0480oomo1@00000K
07ooo`<00000BP3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo@_oo
oglZ07oood3ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0o
0?ooO`<000008`1oool3000004L0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooocoooomo<01ooolmooooO`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0?03oogl3000002T0Oooo0`0000140?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolmooooOcD0Oooo>_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo03X0oomo0P00000_07ooo`<00000@@3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo>_ooogli07ooocWooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0h0?ooO`800000=01oool2000003l0oomo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocWooomo>`1ooolhooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0=`3oogl00`000000Oooo07ooo`0f
07ooo`800000?@3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo=ooo
ogm007ooocGooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0e
0?ooO`800000>`1oool00`000000oomo0?ooO`0j0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooooooooleooooOd<0Oooo=?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo03<0oomo0P00000n07ooo`800000>P3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo=?ooogm507oooc?ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0b0?ooO`030000001oool0Oooo0400Oooo0P00000h
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolcooooOdP0Oooo<Ooo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0300oomo0P000015
07ooo`030000003oogl0oomo03D0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooc;ooomoBP1oool`ooooO`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0;`3oogl00`000000Oooo07ooo`1607ooo`030000003oogl0oomo03@0oomo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc3ooomoC@1oool_ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0;P3oogl00`000000Oooo07ooo`18
07ooo`030000003oogl0oomo03<0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooboooomoC`1oool^ooooO`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0;@3oogl00`000000Oooo07ooo`1:07ooo`030000003oogl0oomo0380oomo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooobkooomoD@1oool]ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0:`3oogl2000004h0Oooo00<00000
0?ooO`3oogl0<@3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo;Ooo
ogmC07ooobcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0Z
0?ooO`030000001oool0Oooo04l0Oooo00<000000?ooO`3oogl0<03oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo;?ooogmE07ooob_ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0Y0?ooO`030000001oool0Oooo0540Oooo00<00000
0?ooO`3oogl0;`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:ooo
ogmG07ooob[ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0X
0?ooO`030000001oool0Oooo05<0Oooo00<000000?ooO`3oogl0;P3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo:_ooogmI07ooobWooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0W0?ooO`030000001oool0Oooo05D0Oooo00<00000
0?ooO`3oogl0;@3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:Ooo
ogmK07ooobSooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0W
0?ooO`030000001oool0Oooo05H0Oooo00<000000?ooO`3oogl0;03oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo:?ooogmL07ooobSooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0V0?ooO`030000001oool0Oooo05P0Oooo00<00000
0?ooO`3oogl0:`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo:?oo
ogmM07ooobOooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0U
0?ooO`030000001oool0Oooo05X0Oooo00<000000?ooO`3oogl0:P3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo9oooogmO07ooobKooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0T0?ooO`030000001oool0Oooo05/0Oooo00<00000
0?ooO`3oogl0:P3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo9_oo
ogmQ07ooobGooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0T
0?ooO`030000001oool0Oooo05`0Oooo00<000000?ooO`3oogl0:@3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo9_ooogmR07ooobCooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0S0?ooO`030000001oool0Oooo05h0Oooo00<00000
0?ooO`3oogl0:03oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo9Ooo
ogmS07ooobCooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0R
0?ooO`030000001oool0Oooo0600Oooo00<000000?ooO`3oogl09`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo9?ooogmU07ooob?ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0R0?ooO`030000001oool0Oooo0640Oooo00<00000
0?ooO`3oogl09P3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8ooo
ogmV07ooob?ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0Q
0?ooO`030000001oool0Oooo06<0Oooo00<000000?ooO`3oogl09@3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8oooogmW07ooob;ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0P0?ooO`030000001oool0Oooo06@0Oooo00<00000
0?ooO`3oogl09@3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8_oo
ogmY07ooob7ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0O
0?ooO`030000001oool0Oooo06H0Oooo00<000000?ooO`3oogl0903oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8OooogmZ07ooob7ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0O0?ooO`030000001oool0Oooo06H0Oooo00<00000
0?ooO`3oogl0903oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8Ooo
ogm[07ooob3ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0N
0?ooO`030000001oool0Oooo06P0Oooo00<000000?ooO`3oogl08`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8?ooogm/07ooob3ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0N0?ooO`030000001oool0Oooo06P0Oooo00<00000
0?ooO`3oogl08`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8?oo
ogm]07oooaoooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0N
0?ooO`030000001oool0Oooo06T0Oooo00<000000?ooO`3oogl08P3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8?ooogm^07oooakooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0M0?ooO`030000001oool0Oooo06/0Oooo00<00000
0?ooO`3oogl08@3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7ooo
ogm_07oooakooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0M
0?ooO`030000001oool0Oooo06/0Oooo00<000000?ooO`3oogl08@3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7oooogm`07oooagooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0M0?ooO`030000001oool0Oooo06`0Oooo00<00000
0?ooO`3oogl0803oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo7_oo
ogma07oooagooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0L
0?ooO`030000001oool0Oooo06d0Oooo00<000000?ooO`3oogl0803oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7_ooogle07ooo`L0oomo=@1ooolMooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0703oogl00`000000Oooo07ooo`1]
07ooo`030000003oogl0oomo0200oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooakooomo<@1oool?0?ooOc80Oooo7?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01/0oomo00<0000007ooo`1oool0K`1oool00`000000oomo0?ooO`0O
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolMooooOc00Oooo4`3o
ogl`07oooacooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0K
0?ooO`030000001oool0Oooo06l0Oooo00<000000?ooO`3oogl07`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7Oooogl^07oooaH0oomo;`1ooolLooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl06`3oogl00`000000Oooo07ooo`1_
07ooo`030000003oogl0oomo01l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooagooomo;@1ooolI0?ooObd0Oooo7?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01X0oomo00<0000007ooo`1oool0L01oool00`000000oomo0?ooO`0O
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolLooooObd0Oooo6`3o
ogl/07oooacooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0J
0?ooO`030000001oool0Oooo0740Oooo00<000000?ooO`3oogl07P3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7?ooogl/07oooad0oomo:`1ooolLooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl06@3oogl00`000000Oooo07ooo`1b
07ooo`030000003oogl0oomo01h0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooacooomo:`1ooolO0?ooOb/0Oooo6oooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01T0oomo00<0000007ooo`1oool0LP1oool00`000000oomo0?ooO`0N
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolKooooOb/0Oooo8@3o
oglZ07oooa_ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0I
0?ooO`030000001oool0Oooo07<0Oooo00<000000?ooO`3oogl07@3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6oooogl[07ooob40oomo:P1ooolKooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl06@3oogl00`000000Oooo07ooo`1c
07ooo`030000003oogl0oomo01d0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa_ooomo:P1ooolS0?ooObX0Oooo6_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01T0oomo00<0000007ooo`1oool0L`1oool00`000000oomo0?ooO`0M
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolKooooObX0Oooo8`3o
oglZ07oooa[ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0H
0?ooO`030000001oool0Oooo07D0Oooo00<000000?ooO`3oogl0703oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6ooooglY07ooobD0oomo:@1ooolJooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0603oogl00`000000Oooo07ooo`1e
07ooo`030000003oogl0oomo01`0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa_ooomo:@1ooolU0?ooObT0Oooo6_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01P0oomo00<0000007ooo`1oool0M@1oool00`000000oomo0?ooO`0L
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJooooObT0Oooo9`3o
oglX07oooa[ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0H
0?ooO`030000001oool0Oooo07D0Oooo00?o00000?ooO`3oogl0703oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6_oooglY07ooobL0oomo:01ooolJooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0603oogl00`000000Oooo07ooo`1f
07oooah0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooa[ooomo:01o
oolX0?ooObP0Oooo6_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo01P0oomo00?o000007ooo`1oool0MP1ooolN0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolJooooObP0Oooo:03ooglX07oooa[ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0H0?ooO`030000001oool0Oooo07H0Oooo7P3oogl2
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6_oooglX07ooobT0oomo9`1o
oolJooooO`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0603oogl0
0`000000Oooo07ooo`1f07oooah0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa[ooomo:01ooolY0?ooObL0Oooo6_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01P0oomo00<0000007ooo`1oool0MP1ooolN0?ooO`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolJooooObP0Oooo:@3ooglW07oooa[ooomo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0H0?ooO`030000001oool0
Oooo07H0Oooo7P3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo6_oo
oglX07ooobT0oomo9`1ooolJooooO`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0603oogl00`000000Oooo07ooo`1f07oooah0oomo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooa[ooomo:01ooolY0?ooObL0Oooo6_ooogl4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo01P0oomo00<0000007ooo`1oool0MP1ooolN
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJooooObP0Oooo:@3o
oglW07oooa[ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0H
0?ooO`030000001oool0Oooo07H0Oooo00<000000?ooO`3oogl06`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6_oooglX07ooobT0oomo9`1ooolJooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0603oogl00`000000Oooo07ooo`1f
07ooo`030000003oogl0oomo01/0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa[ooomo:01ooolX0?ooObP0Oooo6_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01P0oomo00?o000007ooo`1oool0MP1oool00`000000oomo0?ooO`0K
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolJooooObP0Oooo:03o
oglX07oooa[ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0H
0?ooO`030000001oool0Oooo07H0Oooo00<000000?ooO`3oogl06`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6_oooglY07ooobL0oomo:01ooolJooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0603oogl00`000000Oooo07ooo`1f
07ooo`030000003oogl0oomo01/0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa_ooomo:01ooolW0?ooObP0Oooo6_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01P0oomo00<0000007ooo`1oool0MP1oool00`000000oomo0?ooO`0K
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolKooooObT0Oooo9@3o
oglY07oooa[ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0H
0?ooO`030000001oool0Oooo07H0Oooo00<000000?ooO`3oogl06`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6ooooglY07ooobD0oomo:@1ooolJooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0603oogl00`000000Oooo07ooo`1f
07ooo`03o`00003oogl0oomo01/0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooa_ooomo:P1ooolS0?ooObX0Oooo6_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01T0oomo00<0000007ooo`1oool0M@1oool00ol00000oomo0?ooO`0K
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolKooooOb/0Oooo8@3o
oglZ07oooa_ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0I
0?ooO`030000001oool0Oooo07D0Oooo00<000000?ooO`3oogl06`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo6oooogl[07ooob40oomo:P1ooolKooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl06@3oogl00`000000Oooo07ooo`1d
07ooo`030000003oogl0oomo01`0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooacooomo:`1ooolO0?ooOb/0Oooo6oooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01T0oomo00<0000007ooo`1oool0M01oool00`000000oomo0?ooO`0L
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolLooooObd0Oooo7@3o
oglZ07oooacooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0I
0?ooO`030000001oool0Oooo07@0Oooo00<000000?ooO`3oogl0703oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7?ooogl]07oooa/0oomo;01ooolLooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl06@3oogl00`000000Oooo07ooo`1d
07ooo`030000003oogl0oomo01`0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooagooomo;@1ooolH0?ooObh0Oooo7?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01X0oomo00<0000007ooo`1oool0L`1oool00`000000oomo0?ooO`0L
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolMooooObl0Oooo5@3o
ogl_07oooacooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0J
0?ooO`030000001oool0Oooo07<0Oooo00<000000?ooO`3oogl0703oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo7Oooogla07oooa40oomo<@1ooolLooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl06`3oogl00`000000Oooo07ooo`1a
07ooo`030000003oogl0oomo01d0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooakooomo=01oool;0?ooOc<0Oooo7?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01/0oomo00<0000007ooo`1oool0L@1oool00`000000oomo0?ooO`0M
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolNooooOg40Oooo7Ooo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo01/0oomo00<00000
07ooo`1oool0L01oool00`000000oomo0?ooO`0N0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolOooooOg00Oooo7Oooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01`0oomo00<0000007ooo`1oool0K`1oool00`000000oomo0?ooO`0N
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolOooooOfl0Oooo7_oo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo01`0oomo00<00000
07ooo`1oool0K`1oool00`000000oomo0?ooO`0N0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolOooooOfl0Oooo7_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01`0oomo00<0000007ooo`1oool0KP1oool00`000000oomo0?ooO`0O
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolPooooOfh0Oooo7_oo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo01d0oomo00<00000
07ooo`1oool0K@1oool00`000000oomo0?ooO`0O0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolPooooOfd0Oooo7oooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01d0oomo00<0000007ooo`1oool0K@1oool00`000000oomo0?ooO`0O
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolPooooOf`0Oooo8?oo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo01h0oomo00<00000
07ooo`1oool0J`1oool00`000000oomo0?ooO`0P0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolQooooOf/0Oooo8?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01h0oomo00<0000007ooo`1oool0J`1oool00`000000oomo0?ooO`0P
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolQooooOfX0Oooo8Ooo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo01h0oomo00<00000
07ooo`1oool0J`1oool00`000000oomo0?ooO`0P0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolRooooOfT0Oooo8Oooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo01l0oomo00<0000007ooo`1oool0J@1oool00`000000oomo0?ooO`0Q
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolSooooOfL0Oooo8_oo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo01l0oomo00<00000
07ooo`1oool0J@1oool00`000000oomo0?ooO`0Q0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolSooooOfH0Oooo8oooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0200oomo00<0000007ooo`1oool0I`1oool00`000000oomo0?ooO`0R
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolTooooOfD0Oooo8ooo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0240oomo00<00000
07ooo`1oool0I@1oool00`000000oomo0?ooO`0S0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolUooooOf<0Oooo9?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0240oomo00<0000007ooo`1oool0I@1oool00`000000oomo0?ooO`0S
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolUooooOf<0Oooo9?oo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0280oomo00<00000
07ooo`1oool0H`1oool00`000000oomo0?ooO`0T0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolVooooOf40Oooo9Oooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0280oomo00<0000007ooo`1oool0H`1oool00`000000oomo0?ooO`0T
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolWooooOel0Oooo9_oo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo02<0oomo00<00000
07ooo`1oool0H@1oool00`000000oomo0?ooO`0U0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolXooooOed0Oooo9oooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo02@0oomo00<0000007ooo`1oool0G`1oool00`000000oomo0?ooO`0V
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolXooooOe`0Oooo:?oo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo02D0oomo00<00000
07ooo`1oool0GP1oool00`000000oomo0?ooO`0V0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolYooooOe/0Oooo:?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo02H0oomo00<0000007ooo`1oool0G01oool00`000000oomo0?ooO`0W
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolZooooOeT0Oooo:Ooo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo02L0oomo00<00000
07ooo`1oool0FP1oool00`000000oomo0?ooO`0X0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooooooool[ooooOeL0Oooo:_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo02P0oomo00<0000007ooo`1oool0F01oool00`000000oomo0?ooO`0Y
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool/ooooOeD0Oooo:ooo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo02T0oomo00<00000
07ooo`1oool0EP1oool00`000000oomo0?ooO`0Z0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooooooool]ooooOe<0Oooo;?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo02X0oomo00<0000007ooo`1oool0E01oool00`000000oomo0?ooO`0[
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003oooooooooooooool^ooooOe40Oooo;Ooo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo02/0oomo00<00000
07ooo`1oool0DP1oool00`000000oomo0?ooO`0/0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003oooooooooooooool`ooooOdh0Oooo;_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo02`0oomo0P00001A07ooo`030000003oogl0oomo02d0oomo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooc7ooomoC01oool_ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0;P3oogl00`000000Oooo07ooo`1<
07ooo`800000<03oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo<_oo
ogm907oooc7ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0_
0?ooO`030000001oool0Oooo04X0Oooo00<000000?ooO`3oogl0<03oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo<oooogm707oooc;ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0`0?ooO`030000001oool0Oooo04P0Oooo00<00000
0?ooO`3oogl0<@3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo=_oo
ogm207ooocCooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0a
0?ooO`800000A`1oool00`000000oomo0?ooO`0b0?ooO`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolgooooOcl0Oooo=_ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo03<0oomo00<0000007ooo`1oool0@P1oool2000003D0oomo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooocSooomo?@1ooolgooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0=03oogl00`000000Oooo07ooo`0o
07ooo`800000=`3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo>ooo
oglh07ooocWooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0e
0?ooO`030000001oool0Oooo03d0Oooo00<000000?ooO`3oogl0=`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo?Oooogld07oooc_ooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`0f0?ooO`800000>`1oool2000003X0oomo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooockooomo<P1ooollooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0>03oogl3000003H0Oooo0P00000l
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooom0ooooObh0Oooo?_oo
ogl4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo03/0oomo0P00000b
07ooo`800000?P3oogl2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo@ooo
oglX07oood7ooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`0m
0?ooO`800000;P1oool200000400oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooodKooomo8P1ooom4ooooO`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0?`3oogl00`000000Oooo07ooo`0X07ooo`<00000@P3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooC?oooglG07ooodWooomo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`100?ooO`@00000901oool2000004D0oomo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooe;ooomo2`1ooom?ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0A03oogl5000001`0Oooo0`000017
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0B@3oogl4000001@0Oooo1000001:
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0C@3oogl4000000[o00001P00001>
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_
0?ooO`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon/ooooO`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0[`3oogl2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo[?ooogl4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0:l0oomo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooojcooomo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`2_
0?ooO`;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooo
oooo00Wooooo000:oooook?o000000?oooooo`000?ooool04?ooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:oooookGo0000
4Oooooneo`0000_ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0557921, \
-0.0252998, 0.00554406, 0.00554406}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-0.0676948, -0.0365494, 0.00566279, 0.00566279}, {{10.0625, 190.438}, \
{184.875, 4.5}} -> {-0.0676948, -0.0365494, 0.00566279, 0.00566279}, {{208.5, \
388.938}, {184.875, 4.5}} -> {-1.24073, -0.0521387, 0.00582732, 0.00582732}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Difficult to classify example #2 (normal density)", "Section"],

Cell[CellGroupData[{

Cell["Special data generation functions", "Subsection"],

Cell[BoxData[
    \(\(withinRectangle[p_, \ r_] := \n\t
        Module[{rx1, \ ry1, \ rx2, \ ry2, \ x, 
            y}, \n\t\t{rx1, \ ry1, \ rx2, \ ry2}\  = \ r; \n\t\t{x, y}\  = \ 
            p; \n\t\tIf[
            rx1\  < \ x\  < \ rx2\  && \ 
              ry1\  < \ y\  < \ ry2, \n\t\t\tTrue, \ False]];\)\)], "Input"],

Cell[BoxData[
    \(withinRegion2[p_] := \n\t
      If[\n\t\t\t\ withinRectangle[p, \ {0.2, \ 0.6, \ 0.8, \ 0.8}]\  || \ 
          withinRectangle[p, \ {0.2, \ 0.2, \ 0.8, \ 0.4}]\  || \ 
          withinRectangle[p, \ {0.8, \ 0.0, \ 1.0, \ 1.0}], \n\t\tTrue, \ 
        False]\)], "Input"],

Cell[BoxData[
    \(\(region1Data[n_] := \n\t
        Module[{count, \ xd, p}, \n\t\tcount\  = \ 1; \n\t\txd\  = \ 
            Table[0, \ {n}]; \n\t\tWhile[
            count\  <= \ 
              n, \n\t\t\tp\  = \ {Random[Real, \ {0. , 1. }], \ 
                Random[Real, \ {0. , 1. }]}; \n\t\t\tIf[
              withinRegion2[p] == 
                False, \n\t\t\t\txd[\([\(count++\)]\)]\  = \ p]]; \n\t
          xd];\)\)], "Input"],

Cell[BoxData[
    \(\(region2Data[
          n_] := \n\t\tModule[{count, \ xd, p}, \n\t\tcount\  = \ 
            1; \n\t\txd\  = \ Table[0, \ {n}]; \n\t\tWhile[
            count\  <= \ 
              n, \n\t\t\tp\  = \ {Random[Real, \ {0. , 1. }], \ 
                Random[Real, \ {0. , 1. }]}; \n\t\t\tIf[
              withinRegion2[p] == True, \n\t\t\t\txd[\([\(count++\)]\)]\  = \ 
                p]]; \n\txd];\)\)], "Input"],

Cell[BoxData[
    \(\(RR\  := \ Random[Real, \ {0. , \ 1. }];\)\)], "Input"],

Cell[BoxData[
    \(\(TransformProbabilityVector[prob_] := \n\t
        Module[{s\  = \ 0, \ len}, \n\t\tlen\  = \ 
            Length[prob] - 1; \n\t\tJoin[
            Table[s\  = \ s\  + \ prob[\([i]\)], \ {i, \ 1, \ 
                len}], \ {1}]];\)\)], "Input"],

Cell[BoxData[
    \(\(PickOne[\ priors_] := \n\t
        Module[{r}, \n\t\tr\  = \ 
            RR; \n\t\((Position[\(\((r\  <= \ #)\) &\)\  /@ \ 
                    TransformProbabilityVector[priors], \ True]\  // \ 
                Flatten)\)\  // \ First];\)\)], "Input"],

Cell[BoxData[
    \(\(GenerateFromMixturePDF[{mu_, \ sigma_, \ priors_}] := \n\t
        Module[{k, \ d, \ class}, \n\t\tk\  = \ Length[priors]; \n\t\td\  = \ 
            Length[mu[\([1]\)]]; \n\t\ \ class\  = \ 
            PickOne[priors]; \n\t\ \ Random[
            MultinormalDistribution[mu[\([class]\)], \ 
              sigma[\([class]\)]\ IdentityMatrix[d]]]\ \n\t\t];\)\)], "Input"],

Cell[BoxData[
    \(\(specialClassPlot\  := 
        Show[Graphics[{{class1Color, 
                Rectangle[{0, 0}, {1, 1}]}, \ {class2Color, \ 
                Rectangle[{0.8, 0}, {1, 1}], \ 
                Rectangle[{0.2, 0.6}, {0.8, 0.8}], \ 
                Rectangle[{0.2, 0.2}, \ {0.8, 0.4}]}}], \ 
          AspectRatio -> Automatic, \ Frame \[Rule] True, \ nF];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Idealized data classes", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(idealPlot\  = \ specialClassPlot;\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.78571 .02381 m
.78571 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.21429 .59524 m
.21429 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.21429 .21429 m
.21429 .40476 L
.78571 .40476 L
.78571 .21429 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00
00?o0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?oo
ool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o0000oooo
ooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooK
ooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglg
ogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
oooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooo
oglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omo
ool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
fooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo
=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo
1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_o
oomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo0000
0ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo
00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOo
Oooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o0000
0Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooo
om_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo
00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooo
oooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKoooo
OcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogoo
o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolg
ooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoK
ogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
oolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=ooo
ogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomo
ool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomo
fomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo
1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOo
oomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo0000
0ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo
00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_o
Oooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o0000
0Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooo
ocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo
00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooo
oooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKoooo
OcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogoo
o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooK
ooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglg
ogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
oooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooo
oglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omo
ool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
fooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo
=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo
1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_o
oomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo0000
0ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo
00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_o
Oooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o0000
0Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooo
ocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo
00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooo
oooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgoooo
Om_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogoo
o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolg
ooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoK
ogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
oolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=ooo
ogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomo
ool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomo
fomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?o
oooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooolgooooOm_oOooo
1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooocOooomofomoool6ooooo`7o00000Ooo
ool00003o`000?oooooooooo00?ooooo=oooogoKogooo`Kooooo0Ol00001ooooo`0000?o0000oooo
ooooool00ooooolgooooOm_oOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_o
oomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo
0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo0000
0ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo
00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOo
Oooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o0000
0Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000
ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03oooo
om_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Ko
oooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo
00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooo
oooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKoooo
OcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o
00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o
0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03
ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogoo
o`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007o
oooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oo
oooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooK
ooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6oooo
o`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`00
00?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003ooooooooo
o`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglg
ogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00
007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`00
0?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooo
oooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6
ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001oooo
o`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003ooooo
ooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooo
oglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1
o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003
o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool0
0ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omo
ool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001
ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003o
ooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooo
fooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_oo
ool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool0
0003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol00001ooooo`0000?o0000oooooooo
ool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0003oooooooooo`03ooooom_ooomo
=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo00?ooooofooooglgogooo`Kooooo0Ol0
0001ooooo`0000?o0000ooooooooool00ooooooKooooOcOoOooo1_ooool1o`00007ooooo00000ol0
003oooooooooo`03ooooom_ooomo=omoool6ooooo`7o00000Oooool00003o`000?oooooooooo0?oo
oooo7?ooool1o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`0000?o
0000ooooooooool0oooooolLooooo`7o00000Oooool00003o`000?oooooooooo0?oooooo7?ooool1
o`00007ooooo00000ol0003oooooooooo`3ooooooacooooo0Ol00001ooooo`00ool0000Po`00007o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0254629, -0.0254629, \
0.00366176, 0.00366176}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate data from above distributions", "Subsection"],

Cell[CellGroupData[{

Cell["Number of points in each class", "Subsubsection"],

Cell[BoxData[{
    \(\(n1\  = \ 1000;\)\), "\[IndentingNewLine]", 
    \(\(n2\  = \ 1000;\)\)}], "Input",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate data ", "Subsubsection"],

Cell[BoxData[{
    \(\(data1\  = \ region1Data[n1];\)\), "\n", 
    \(\(data2\  = \ region2Data[n2];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize data", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gd1\  = \ 
        PlotData2D[data1, pr, style1, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd2\  = \ 
        PlotData2D[data2, pr, style2, nS];\)\), "\[IndentingNewLine]", 
    \(\(gd\  = \ Show[gd1, gd2, \ FS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.02 w
.73686 .8607 Mdot
.25226 .84699 Mdot
.45327 .04807 Mdot
.69676 .19829 Mdot
.68815 .15648 Mdot
.05982 .34301 Mdot
.27899 .12262 Mdot
.59227 .06432 Mdot
.14098 .81201 Mdot
.1915 .57292 Mdot
.78014 .84034 Mdot
.73646 .47686 Mdot
.73013 .50713 Mdot
.52519 .1118 Mdot
.10192 .67631 Mdot
.31197 .82617 Mdot
.22314 .18959 Mdot
.74606 .81575 Mdot
.12592 .08033 Mdot
.35567 .41402 Mdot
.01186 .46739 Mdot
.51963 .43878 Mdot
.04266 .46205 Mdot
.1618 .93622 Mdot
.62414 .82931 Mdot
.70042 .87824 Mdot
.35899 .1843 Mdot
.0635 .65298 Mdot
.41141 .07437 Mdot
.03064 .20073 Mdot
.57993 .03495 Mdot
.07251 .7129 Mdot
.02756 .5102 Mdot
.60635 .44564 Mdot
.31108 .52045 Mdot
.03622 .4205 Mdot
.08043 .23447 Mdot
.37954 .55285 Mdot
.16132 .24792 Mdot
.7659 .86396 Mdot
.44378 .16238 Mdot
.1425 .63212 Mdot
.78799 .85584 Mdot
.32071 .80372 Mdot
.1692 .5656 Mdot
.45381 .47232 Mdot
.03305 .74055 Mdot
.20884 .46421 Mdot
.12656 .54076 Mdot
.68386 .95759 Mdot
.63665 .17145 Mdot
.25296 .46981 Mdot
.3145 .05002 Mdot
.30325 .92075 Mdot
.11546 .57601 Mdot
.48624 .03322 Mdot
.69462 .96764 Mdot
.36948 .48266 Mdot
.02056 .01985 Mdot
.67402 .12396 Mdot
.57677 .91636 Mdot
.38058 .19341 Mdot
.04406 .34795 Mdot
.07848 .71316 Mdot
.09511 .87039 Mdot
.56044 .20267 Mdot
.07494 .63741 Mdot
.52842 .0415 Mdot
.56495 .913 Mdot
.14956 .76842 Mdot
.57932 .57556 Mdot
.10485 .56563 Mdot
.50228 .95289 Mdot
.19138 .30358 Mdot
.48977 .43132 Mdot
.39473 .85589 Mdot
.5066 .59667 Mdot
.01412 .63398 Mdot
.32609 .89444 Mdot
.46487 .90046 Mdot
.1389 .36248 Mdot
.04234 .77035 Mdot
.03802 .14617 Mdot
.68725 .10161 Mdot
.21528 .79616 Mdot
.37096 .19737 Mdot
.78183 .14192 Mdot
.10181 .66803 Mdot
.31863 .52256 Mdot
.67318 .9237 Mdot
.05241 .80006 Mdot
.09418 .25581 Mdot
.5502 .88778 Mdot
.5076 .09752 Mdot
.37988 .95432 Mdot
.25663 .41976 Mdot
.6612 .59712 Mdot
.05412 .89813 Mdot
.39035 .52429 Mdot
.40956 .08396 Mdot
.41096 .9844 Mdot
.4147 .4657 Mdot
.04462 .50158 Mdot
.64673 .48673 Mdot
.37362 .89466 Mdot
.79311 .83553 Mdot
.3293 .98672 Mdot
.04346 .44994 Mdot
.0823 .55815 Mdot
.66153 .56394 Mdot
.1245 .92257 Mdot
.08968 .4308 Mdot
.12123 .18052 Mdot
.70626 .52634 Mdot
.38676 .52981 Mdot
.28466 .87545 Mdot
.4478 .06738 Mdot
.77287 .10571 Mdot
.66144 .91538 Mdot
.01756 .76998 Mdot
.35292 .59 Mdot
.07806 .70475 Mdot
.18301 .1924 Mdot
.26461 .5231 Mdot
.54238 .52839 Mdot
.7371 .48986 Mdot
.52802 .023 Mdot
.11816 .4699 Mdot
.59387 .91119 Mdot
.21943 .95843 Mdot
.47252 .47838 Mdot
.32727 .15191 Mdot
.68986 .02089 Mdot
.27364 .91266 Mdot
.02913 .25668 Mdot
.26858 .85745 Mdot
.33718 .80027 Mdot
.59401 .05157 Mdot
.09581 .56003 Mdot
.25981 .4854 Mdot
.12274 .39669 Mdot
.20159 .04874 Mdot
.2806 .85967 Mdot
.02842 .51845 Mdot
.03059 .38407 Mdot
.06876 .35009 Mdot
.57068 .18712 Mdot
.36789 .04899 Mdot
.0901 .44022 Mdot
.3889 .82396 Mdot
.1181 .95449 Mdot
.09731 .58022 Mdot
.51683 .40291 Mdot
.46977 .181 Mdot
.06888 .61248 Mdot
.13006 .18677 Mdot
.53555 .79868 Mdot
.02853 .40558 Mdot
.01183 .56792 Mdot
.10804 .26313 Mdot
.47517 .86461 Mdot
.36494 .79765 Mdot
.13165 .27073 Mdot
.03342 .0174 Mdot
.54844 .14299 Mdot
.33861 .4374 Mdot
.60883 .07706 Mdot
.68793 .4069 Mdot
.01003 .141 Mdot
.72669 .52985 Mdot
.03862 .21017 Mdot
.55847 .50776 Mdot
.01326 .783 Mdot
.04258 .12814 Mdot
.42395 .06088 Mdot
.69096 .58446 Mdot
.39468 .84541 Mdot
.11348 .86653 Mdot
.11002 .09334 Mdot
.77087 .47556 Mdot
.35672 .42448 Mdot
.73438 .02227 Mdot
.05322 .42801 Mdot
.38128 .05372 Mdot
.2363 .80095 Mdot
.2776 .17738 Mdot
.17739 .09385 Mdot
.66474 .53654 Mdot
.05336 .87057 Mdot
.57315 .86172 Mdot
.39423 .85275 Mdot
.13777 .6101 Mdot
.74226 .13104 Mdot
.45682 .8044 Mdot
.3979 .91073 Mdot
.44347 .01491 Mdot
.56497 .43944 Mdot
.53723 .46513 Mdot
.437 .81954 Mdot
.05107 .56536 Mdot
.33815 .52968 Mdot
.33938 .50614 Mdot
.7646 .0765 Mdot
.33866 .08152 Mdot
.64297 .03699 Mdot
.65948 .93632 Mdot
.11351 .87153 Mdot
.3391 .80483 Mdot
.6474 .47304 Mdot
.01151 .56747 Mdot
.11352 .73541 Mdot
.70556 .88567 Mdot
.07239 .85848 Mdot
.23869 .59115 Mdot
.6195 .48082 Mdot
.37675 .50955 Mdot
.39069 .95499 Mdot
.18649 .78486 Mdot
.73349 .49175 Mdot
.18479 .2272 Mdot
.40684 .46344 Mdot
.77753 .97281 Mdot
.13577 .11837 Mdot
.73528 .15358 Mdot
.09485 .58846 Mdot
.01159 .65203 Mdot
.37201 .89569 Mdot
.44063 .04915 Mdot
.0436 .5759 Mdot
.13767 .07813 Mdot
.25626 .59329 Mdot
.0117 .94996 Mdot
.26662 .80619 Mdot
.26484 .16397 Mdot
.26224 .56223 Mdot
.13437 .4939 Mdot
.26872 .0519 Mdot
.13247 .53414 Mdot
.28401 .82213 Mdot
.60101 .56398 Mdot
.39474 .93999 Mdot
.33059 .10312 Mdot
.07167 .06102 Mdot
.34266 .98729 Mdot
.40332 .02865 Mdot
.73184 .43311 Mdot
.01839 .07886 Mdot
.03347 .1276 Mdot
.17263 .34035 Mdot
.24656 .12514 Mdot
.77037 .19582 Mdot
.04787 .40009 Mdot
.69541 .403 Mdot
.58919 .93808 Mdot
.58061 .86903 Mdot
.41778 .53848 Mdot
.37196 .47758 Mdot
.1352 .36225 Mdot
.09714 .95235 Mdot
.39193 .55916 Mdot
.22367 .2006 Mdot
.42837 .58927 Mdot
.12631 .26939 Mdot
.63973 .48204 Mdot
.0411 .23792 Mdot
.09328 .78675 Mdot
.18418 .71555 Mdot
.595 .05939 Mdot
.31917 .46003 Mdot
.48738 .87306 Mdot
.47501 .09322 Mdot
.58361 .92808 Mdot
.44372 .8455 Mdot
.08157 .55206 Mdot
.62628 .80818 Mdot
.45191 .10243 Mdot
.49301 .16037 Mdot
.18364 .69054 Mdot
.42742 .05266 Mdot
.76224 .55291 Mdot
.62882 .93384 Mdot
.18672 .84121 Mdot
.39045 .0915 Mdot
.47565 .16578 Mdot
.51007 .00991 Mdot
.05803 .12293 Mdot
.21422 .01795 Mdot
.44217 .45524 Mdot
.73081 .83671 Mdot
.27778 .57613 Mdot
.0567 .15587 Mdot
.79233 .42015 Mdot
.53682 .15576 Mdot
.18902 .1314 Mdot
.10732 .83384 Mdot
.2715 .43387 Mdot
.43909 .18582 Mdot
.53089 .58735 Mdot
.17111 .59989 Mdot
.48399 .44129 Mdot
.36898 .18954 Mdot
.61507 .8727 Mdot
.2216 .53256 Mdot
.08518 .58363 Mdot
.04238 .41097 Mdot
.76108 .96729 Mdot
.53877 .56397 Mdot
.37746 .95428 Mdot
.7462 .93865 Mdot
.01828 .77455 Mdot
.39341 .89204 Mdot
.58723 .13037 Mdot
.34018 .56843 Mdot
.7916 .01426 Mdot
.42395 .05018 Mdot
.03186 .36399 Mdot
.70402 .05558 Mdot
.37365 .47735 Mdot
.07288 .1785 Mdot
.57224 .47289 Mdot
.5095 .81613 Mdot
.15809 .43251 Mdot
.70213 .42183 Mdot
.73282 .17648 Mdot
.71076 .80269 Mdot
.30211 .06005 Mdot
.01655 .75692 Mdot
.44546 .14905 Mdot
.38239 .96074 Mdot
.07066 .80669 Mdot
.17075 .72279 Mdot
.17975 .2173 Mdot
.45735 .06174 Mdot
.45918 .40481 Mdot
.16505 .0115 Mdot
.70978 .85265 Mdot
.3372 .8821 Mdot
.74868 .54202 Mdot
.30336 .0245 Mdot
.66617 .94074 Mdot
.2168 .54574 Mdot
.68097 .95127 Mdot
.75456 .89785 Mdot
.19634 .01692 Mdot
.17948 .46923 Mdot
.35042 .83927 Mdot
.67445 .88872 Mdot
.03991 .49177 Mdot
.34914 .5307 Mdot
.70309 .44513 Mdot
.37795 .43208 Mdot
.75807 .88619 Mdot
.57154 .87907 Mdot
.23092 .04961 Mdot
.54666 .15108 Mdot
.65828 .80002 Mdot
.08901 .7885 Mdot
.60824 .45718 Mdot
.0465 .56831 Mdot
.63253 .86557 Mdot
.18971 .58892 Mdot
.03575 .64757 Mdot
.20536 .77857 Mdot
.16866 .22007 Mdot
.19639 .16031 Mdot
.25223 .57672 Mdot
.09396 .30435 Mdot
.10045 .46986 Mdot
.15434 .63489 Mdot
.72642 .47122 Mdot
.70573 .89786 Mdot
.299 .48511 Mdot
.73938 .1047 Mdot
.7665 .1258 Mdot
.62196 .48111 Mdot
.6728 .15692 Mdot
.664 .98692 Mdot
.01026 .87256 Mdot
.2189 .98436 Mdot
.6057 .11268 Mdot
.69283 .10141 Mdot
.08067 .6105 Mdot
.22957 .03759 Mdot
.44858 .52472 Mdot
.23948 .53055 Mdot
.02237 .87203 Mdot
.07752 .23134 Mdot
.12 .69712 Mdot
.58999 .98745 Mdot
.15121 .47254 Mdot
.04044 .23106 Mdot
.70668 .54618 Mdot
.15118 .61904 Mdot
.08346 .3975 Mdot
.58392 .95743 Mdot
.08661 .77666 Mdot
.70255 .06763 Mdot
.30176 .83749 Mdot
.70803 .87025 Mdot
.14186 .57167 Mdot
.02435 .58215 Mdot
.30963 .47559 Mdot
.28118 .87651 Mdot
.37475 .98714 Mdot
.56334 .01606 Mdot
.24269 .42528 Mdot
.5488 .4241 Mdot
.27725 .13084 Mdot
.28782 .16723 Mdot
.69845 .87579 Mdot
.41189 .06632 Mdot
.13512 .16179 Mdot
.73199 .83531 Mdot
.34517 .48875 Mdot
.75629 .82868 Mdot
.1148 .721 Mdot
.77704 .41103 Mdot
.65147 .02631 Mdot
.49625 .15162 Mdot
.29972 .58243 Mdot
.47229 .59257 Mdot
.53901 .17013 Mdot
.43401 .43933 Mdot
.1256 .65622 Mdot
.77273 .42282 Mdot
.61954 .5144 Mdot
.06196 .02143 Mdot
.04155 .87171 Mdot
.51314 .8415 Mdot
.1389 .80447 Mdot
.08894 .41197 Mdot
.02311 .15806 Mdot
.3064 .97935 Mdot
.52867 .42596 Mdot
.79266 .11451 Mdot
.78582 .42454 Mdot
.77936 .94665 Mdot
.48922 .43539 Mdot
.52472 .14155 Mdot
.09447 .44211 Mdot
.17921 .08225 Mdot
.046 .50305 Mdot
.39005 .1258 Mdot
.54697 .07747 Mdot
.03205 .92611 Mdot
.13772 .89676 Mdot
.23429 .80062 Mdot
.40899 .80211 Mdot
.09303 .55101 Mdot
.69318 .43502 Mdot
.34613 .91484 Mdot
.62519 .08177 Mdot
.09351 .30118 Mdot
.01029 .74036 Mdot
.03717 .71979 Mdot
.23359 .42432 Mdot
.03816 .93846 Mdot
.68222 .03343 Mdot
.7326 .54088 Mdot
.59803 .97227 Mdot
.63585 .59024 Mdot
.69174 .9836 Mdot
.41206 .17573 Mdot
.66339 .05494 Mdot
.05427 .55308 Mdot
.31186 .022 Mdot
.13223 .42133 Mdot
.48658 .82128 Mdot
.08433 .65536 Mdot
.12898 .60172 Mdot
.03986 .11209 Mdot
.14781 .58021 Mdot
.71819 .09989 Mdot
.32353 .11611 Mdot
.24901 .45095 Mdot
.58484 .08512 Mdot
.44684 .49511 Mdot
.55841 .89005 Mdot
.74829 .95266 Mdot
.21461 .89651 Mdot
.43456 .84635 Mdot
.19535 .4052 Mdot
.48544 .79796 Mdot
.77761 .44489 Mdot
.08623 .21468 Mdot
.17874 .93564 Mdot
.73438 .09909 Mdot
.37083 .08889 Mdot
.45488 .92512 Mdot
.09679 .81978 Mdot
.20815 .83117 Mdot
.16976 .91188 Mdot
.13173 .62629 Mdot
.25664 .87715 Mdot
.698 .20288 Mdot
.13538 .56553 Mdot
.44864 .03766 Mdot
.04839 .73595 Mdot
.25029 .19669 Mdot
.12837 .5606 Mdot
.63097 .95106 Mdot
.10573 .65246 Mdot
.75901 .45651 Mdot
.72708 .89518 Mdot
.01238 .78462 Mdot
.3716 .82375 Mdot
.43863 .07556 Mdot
.34508 .97815 Mdot
.63124 .8635 Mdot
.39371 .8601 Mdot
.65683 .95512 Mdot
.60787 .16619 Mdot
.17904 .10043 Mdot
.66577 .80053 Mdot
.68373 .03578 Mdot
.27339 .47607 Mdot
.70426 .04585 Mdot
.47538 .18326 Mdot
.1062 .86986 Mdot
.56702 .54892 Mdot
.01354 .90253 Mdot
.38916 .56192 Mdot
.74959 .17023 Mdot
.03967 .72561 Mdot
.02043 .5109 Mdot
.22921 .8099 Mdot
.4436 .95218 Mdot
.30205 .04047 Mdot
.43986 .05946 Mdot
.75025 .44823 Mdot
.1993 .70736 Mdot
.01047 .28779 Mdot
.16943 .97195 Mdot
.51466 .59363 Mdot
.50404 .09254 Mdot
.61462 .47249 Mdot
.07024 .13056 Mdot
.32238 .44183 Mdot
.62057 .0809 Mdot
.40949 .96328 Mdot
.06037 .28397 Mdot
.21654 .98198 Mdot
.59211 .51929 Mdot
.78071 .53796 Mdot
.27954 .08727 Mdot
.16995 .46686 Mdot
.29963 .83419 Mdot
.65004 .83866 Mdot
.42998 .49911 Mdot
.59947 .56449 Mdot
.08479 .74785 Mdot
.39273 .57271 Mdot
.23384 .09894 Mdot
.79082 .06322 Mdot
.44332 .55118 Mdot
.52108 .96615 Mdot
.28318 .09412 Mdot
.65104 .86177 Mdot
.01081 .03292 Mdot
.40153 .45863 Mdot
.47858 .98356 Mdot
.0186 .87612 Mdot
.25454 .89442 Mdot
.21798 .8227 Mdot
.68709 .84675 Mdot
.04585 .97518 Mdot
.5445 .02841 Mdot
.04485 .95207 Mdot
.63352 .50325 Mdot
.4564 .03656 Mdot
.71964 .92826 Mdot
.68359 .94328 Mdot
.64855 .98141 Mdot
.39292 .47183 Mdot
.02484 .48796 Mdot
.39031 .86084 Mdot
.61293 .808 Mdot
.16633 .78124 Mdot
.25413 .14776 Mdot
.23797 .03302 Mdot
.56073 .19467 Mdot
.4612 .80217 Mdot
.50684 .83505 Mdot
.5732 .98229 Mdot
.7182 .43622 Mdot
.26769 .89632 Mdot
.70955 .48539 Mdot
.33498 .47798 Mdot
.06581 .62331 Mdot
.34821 .85375 Mdot
.14714 .10605 Mdot
.66116 .5718 Mdot
.7255 .41404 Mdot
.05323 .61633 Mdot
.2665 .1986 Mdot
.70844 .14815 Mdot
.11215 .37847 Mdot
.75413 .51491 Mdot
.20134 .60338 Mdot
.10278 .93331 Mdot
.46603 .19914 Mdot
.15117 .84691 Mdot
.10774 .24038 Mdot
.3528 .50966 Mdot
.38949 .10203 Mdot
.61945 .4773 Mdot
.42792 .86412 Mdot
.28887 .40882 Mdot
.35239 .96652 Mdot
.19094 .17824 Mdot
.79164 .08601 Mdot
.05128 .28973 Mdot
.42203 .80263 Mdot
.56084 .88826 Mdot
.04203 .26373 Mdot
.28177 .48924 Mdot
.10064 .32081 Mdot
.68024 .81095 Mdot
.63876 .53102 Mdot
.7751 .87235 Mdot
.23299 .82049 Mdot
.20021 .52614 Mdot
.19157 .88696 Mdot
.77628 .89348 Mdot
.5422 .85237 Mdot
.04143 .61365 Mdot
.2111 .19567 Mdot
.02933 .2989 Mdot
.0643 .13052 Mdot
.61794 .13929 Mdot
.76989 .87022 Mdot
.05061 .76167 Mdot
.09314 .76854 Mdot
.53697 .08052 Mdot
.68706 .56084 Mdot
.08666 .25643 Mdot
.45892 .12695 Mdot
.15086 .9089 Mdot
.37116 .04848 Mdot
.55945 .57061 Mdot
.09594 .70158 Mdot
.5687 .91997 Mdot
.70239 .97499 Mdot
.11556 .27867 Mdot
.25327 .85785 Mdot
.64321 .52556 Mdot
.09357 .94515 Mdot
.60765 .16269 Mdot
.31561 .89804 Mdot
.12602 .92686 Mdot
.22954 .54345 Mdot
.64182 .94791 Mdot
.14577 .58849 Mdot
.67138 .41852 Mdot
.52832 .43561 Mdot
.78707 .58091 Mdot
.69991 .51415 Mdot
.5837 .57749 Mdot
.28121 .0537 Mdot
.71095 .50849 Mdot
.04586 .76489 Mdot
.49122 .95524 Mdot
.39424 .80718 Mdot
.12702 .42678 Mdot
.44472 .14448 Mdot
.53352 .83949 Mdot
.17332 .10058 Mdot
.13727 .32588 Mdot
.73323 .5089 Mdot
.02998 .12024 Mdot
.15896 .06808 Mdot
.10399 .30269 Mdot
.04174 .63149 Mdot
.64946 .16802 Mdot
.48594 .07724 Mdot
.67586 .4512 Mdot
.35432 .08524 Mdot
.37823 .08603 Mdot
.59528 .13202 Mdot
.22908 .02776 Mdot
.50109 .81952 Mdot
.19714 .38646 Mdot
.68892 .59446 Mdot
.36569 .59387 Mdot
.02286 .15306 Mdot
.01701 .84251 Mdot
.65874 .07762 Mdot
.29031 .98179 Mdot
.78668 .48764 Mdot
.07103 .96384 Mdot
.44376 .9872 Mdot
.18498 .98292 Mdot
.08788 .40313 Mdot
.17192 .83966 Mdot
.08067 .55081 Mdot
.6791 .93116 Mdot
.16165 .80661 Mdot
.16307 .78821 Mdot
.11258 .23652 Mdot
.08499 .39488 Mdot
.01413 .83426 Mdot
.32523 .89331 Mdot
.22421 .81535 Mdot
.43281 .44979 Mdot
.07236 .01854 Mdot
.67272 .85676 Mdot
.67202 .55279 Mdot
.59753 .47168 Mdot
.73136 .17554 Mdot
.30388 .56033 Mdot
.08948 .73518 Mdot
.02692 .72644 Mdot
.01898 .61994 Mdot
.24232 .93714 Mdot
.14573 .65408 Mdot
.44558 .91331 Mdot
.03279 .64506 Mdot
.42846 .19667 Mdot
.02361 .03492 Mdot
.19595 .24972 Mdot
.62565 .84576 Mdot
.28106 .95905 Mdot
.40701 .84908 Mdot
.23019 .45466 Mdot
.28197 .47443 Mdot
.7791 .13626 Mdot
.46967 .15808 Mdot
.50784 .1674 Mdot
.67237 .12166 Mdot
.60397 .01979 Mdot
.06409 .64382 Mdot
.47603 .82892 Mdot
.46887 .88042 Mdot
.20387 .3643 Mdot
.18193 .59637 Mdot
.20888 .45453 Mdot
.49976 .48451 Mdot
.5951 .44454 Mdot
.18012 .57791 Mdot
.22858 .94812 Mdot
.03129 .92392 Mdot
.3496 .84305 Mdot
.6904 .84283 Mdot
.125 .62132 Mdot
.1601 .42134 Mdot
.22195 .42198 Mdot
.37259 .09442 Mdot
.03279 .24157 Mdot
.67021 .52965 Mdot
.49962 .45871 Mdot
.34932 .04717 Mdot
.14453 .70473 Mdot
.323 .97563 Mdot
.12154 .47296 Mdot
.64299 .45578 Mdot
.21375 .85271 Mdot
.27469 .1689 Mdot
.52157 .08414 Mdot
.02405 .28499 Mdot
.75798 .10731 Mdot
.31299 .93952 Mdot
.23658 .53591 Mdot
.78162 .86518 Mdot
.31122 .41417 Mdot
.76737 .58999 Mdot
.07926 .65036 Mdot
.16051 .87197 Mdot
.13967 .91222 Mdot
.38327 .85436 Mdot
.15649 .32826 Mdot
.48122 .85292 Mdot
.73057 .81299 Mdot
.11051 .64415 Mdot
.3571 .94882 Mdot
.35665 .06333 Mdot
.58933 .46236 Mdot
.15988 .21601 Mdot
.05917 .56205 Mdot
.32061 .94253 Mdot
.22184 .80168 Mdot
.72147 .48997 Mdot
.74744 .40956 Mdot
.23536 .06789 Mdot
.51378 .15194 Mdot
.18599 .49604 Mdot
.62742 .83334 Mdot
.10985 .25796 Mdot
.50258 .18218 Mdot
.16196 .32265 Mdot
.27703 .1241 Mdot
.63837 .18052 Mdot
.10084 .61826 Mdot
.02076 .33738 Mdot
.13615 .76802 Mdot
.06929 .17266 Mdot
.03611 .51987 Mdot
.42862 .94068 Mdot
.14809 .08319 Mdot
.6357 .89121 Mdot
.36707 .89562 Mdot
.27744 .16846 Mdot
.15109 .39063 Mdot
.12478 .86096 Mdot
.7006 .06572 Mdot
.34099 .88656 Mdot
.34334 .1603 Mdot
.61464 .42559 Mdot
.69508 .94119 Mdot
.5538 .56036 Mdot
.03843 .51959 Mdot
.46212 .89222 Mdot
.32802 .46367 Mdot
.13094 .01546 Mdot
.15842 .8862 Mdot
.37004 .87778 Mdot
.45354 .93521 Mdot
.46333 .84953 Mdot
.21488 .06555 Mdot
.18626 .53615 Mdot
.71925 .88156 Mdot
.50352 .87172 Mdot
.27551 .93655 Mdot
.04999 .032 Mdot
.37577 .56171 Mdot
.64885 .4303 Mdot
.04816 .30586 Mdot
.31911 .4145 Mdot
.0534 .46815 Mdot
.66782 .89664 Mdot
.75298 .03979 Mdot
.10858 .93042 Mdot
.18173 .35152 Mdot
.37526 .93976 Mdot
.76807 .8516 Mdot
.02489 .82162 Mdot
.17814 .87507 Mdot
.52366 .06695 Mdot
.69644 .82611 Mdot
.6418 .55732 Mdot
.7684 .89311 Mdot
.11352 .43807 Mdot
.23305 .42988 Mdot
.78849 .18954 Mdot
.1414 .79099 Mdot
.1824 .36909 Mdot
.40419 .46618 Mdot
.02614 .56121 Mdot
.45525 .55605 Mdot
.16364 .29699 Mdot
.75134 .04464 Mdot
.69992 .47055 Mdot
.26969 .47907 Mdot
.30553 .01417 Mdot
.25335 .90805 Mdot
.68664 .16113 Mdot
.65135 .10146 Mdot
.76026 .57813 Mdot
.06278 .28666 Mdot
.02038 .85559 Mdot
.35306 .80631 Mdot
.05733 .80194 Mdot
.49734 .46847 Mdot
.16641 .67375 Mdot
.50526 .5821 Mdot
.57532 .09561 Mdot
.73519 .01377 Mdot
.52235 .79915 Mdot
.72462 .14838 Mdot
.17909 .98303 Mdot
.13156 .19089 Mdot
.08933 .03377 Mdot
.35491 .87559 Mdot
.14693 .72776 Mdot
.37118 .13314 Mdot
.02517 .54667 Mdot
.10066 .71921 Mdot
.67697 .11367 Mdot
.73049 .2016 Mdot
.65096 .17763 Mdot
.53199 .84393 Mdot
.39486 .12597 Mdot
.37949 .5695 Mdot
.05969 .32934 Mdot
.28863 .84048 Mdot
.49488 .10962 Mdot
.75459 .89822 Mdot
.75365 .1721 Mdot
.11343 .73039 Mdot
.17828 .77261 Mdot
.32812 .84989 Mdot
.56662 .0458 Mdot
.56372 .94187 Mdot
.5815 .55532 Mdot
.77963 .48448 Mdot
.1291 .9478 Mdot
.55268 .91181 Mdot
.08439 .71361 Mdot
.73971 .05772 Mdot
.61449 .50213 Mdot
.16801 .49259 Mdot
.41332 .13947 Mdot
.18234 .25412 Mdot
.12554 .39944 Mdot
.5678 .06387 Mdot
.44376 .52022 Mdot
.69425 .47231 Mdot
.53604 .96992 Mdot
.13253 .84025 Mdot
.73442 .84559 Mdot
.01679 .45061 Mdot
.52831 .13605 Mdot
.02035 .01858 Mdot
.56679 .48855 Mdot
.58858 .89342 Mdot
.33649 .04633 Mdot
.21377 .19627 Mdot
.40909 .81206 Mdot
.19623 .72708 Mdot
.39269 .11471 Mdot
.42041 .19557 Mdot
.21645 .9895 Mdot
.01947 .26345 Mdot
.37437 .54123 Mdot
.2036 .28803 Mdot
.4467 .06573 Mdot
.03609 .86035 Mdot
.06713 .02383 Mdot
.68296 .47279 Mdot
.31996 .86674 Mdot
.42981 .82257 Mdot
.50032 .01549 Mdot
.37248 .80854 Mdot
.10993 .77631 Mdot
.26409 .89156 Mdot
.75397 .88587 Mdot
.04686 .92591 Mdot
.07343 .4974 Mdot
.35734 .59016 Mdot
.36001 .18978 Mdot
.43478 .91604 Mdot
.33465 .14954 Mdot
.49531 .56311 Mdot
.60121 .98591 Mdot
.09558 .80906 Mdot
.05853 .87335 Mdot
.4236 .42266 Mdot
.12858 .8506 Mdot
.51757 .85488 Mdot
.35067 .83563 Mdot
.30194 .95248 Mdot
.48884 .97207 Mdot
.41238 .09435 Mdot
.37006 .13128 Mdot
.62526 .58463 Mdot
.18217 .50194 Mdot
.72257 .94325 Mdot
.11116 .25023 Mdot
.37466 .54187 Mdot
.05135 .90972 Mdot
.31897 .95667 Mdot
.51648 .15969 Mdot
.46127 .40244 Mdot
.5803 .10045 Mdot
.53876 .18093 Mdot
.05836 .47721 Mdot
.29884 .87928 Mdot
.34395 .13007 Mdot
.38899 .48774 Mdot
.09676 .36247 Mdot
.05016 .02131 Mdot
.04821 .87545 Mdot
.74151 .13223 Mdot
.50632 .55793 Mdot
.40736 .01197 Mdot
.53687 .87347 Mdot
.02817 .51442 Mdot
.03849 .60125 Mdot
.21948 .12714 Mdot
.06259 .97339 Mdot
.16768 .75743 Mdot
.42109 .18734 Mdot
.52247 .13331 Mdot
.50586 .57524 Mdot
.48842 .17609 Mdot
.74554 .81017 Mdot
.6042 .86222 Mdot
.0232 .56933 Mdot
.74867 .17901 Mdot
.49093 .44582 Mdot
.12859 .37029 Mdot
.25428 .87121 Mdot
.21908 .02646 Mdot
.72085 .84056 Mdot
.12645 .96854 Mdot
.36798 .79934 Mdot
.48874 .47065 Mdot
.29348 .96967 Mdot
.0842 .95302 Mdot
.57784 .07998 Mdot
.35355 .12226 Mdot
0 0 1 r
.6051 .6679 Mdot
.85911 .33476 Mdot
.50813 .78635 Mdot
.45165 .25168 Mdot
.92082 .42815 Mdot
.90919 .02628 Mdot
.85244 .10671 Mdot
.67745 .70174 Mdot
.84586 .76396 Mdot
.29542 .70604 Mdot
.82647 .3029 Mdot
.89585 .86495 Mdot
.80611 .17893 Mdot
.71026 .37686 Mdot
.94387 .08203 Mdot
.54309 .227 Mdot
.98477 .42498 Mdot
.31244 .35811 Mdot
.63136 .34602 Mdot
.67768 .27379 Mdot
.6668 .63019 Mdot
.52044 .36499 Mdot
.80121 .52352 Mdot
.5937 .74768 Mdot
.9171 .1273 Mdot
.38533 .77378 Mdot
.95974 .70552 Mdot
.67692 .67141 Mdot
.87569 .71176 Mdot
.89302 .07423 Mdot
.92347 .35891 Mdot
.34345 .2582 Mdot
.96552 .30772 Mdot
.43361 .7686 Mdot
.53591 .359 Mdot
.47286 .25452 Mdot
.94608 .92437 Mdot
.97075 .62646 Mdot
.91185 .25018 Mdot
.69266 .26332 Mdot
.85591 .68991 Mdot
.90002 .75574 Mdot
.91947 .13909 Mdot
.38233 .28123 Mdot
.56746 .63717 Mdot
.96946 .72694 Mdot
.86499 .38366 Mdot
.57764 .67803 Mdot
.69948 .65933 Mdot
.80209 .23238 Mdot
.44361 .71606 Mdot
.87283 .1031 Mdot
.9447 .82871 Mdot
.9336 .40709 Mdot
.80296 .15835 Mdot
.79612 .9492 Mdot
.36231 .24295 Mdot
.50852 .39522 Mdot
.5722 .77921 Mdot
.69576 .24667 Mdot
.35052 .37005 Mdot
.88983 .28767 Mdot
.92113 .18346 Mdot
.83192 .61286 Mdot
.89466 .79528 Mdot
.90919 .4636 Mdot
.97825 .28995 Mdot
.59407 .20957 Mdot
.24654 .40061 Mdot
.22924 .39525 Mdot
.40482 .77795 Mdot
.61922 .3533 Mdot
.23807 .21036 Mdot
.90446 .72567 Mdot
.39746 .60017 Mdot
.68502 .34022 Mdot
.98283 .81242 Mdot
.84752 .85832 Mdot
.6312 .37762 Mdot
.77978 .77412 Mdot
.37865 .74409 Mdot
.71398 .7872 Mdot
.37274 .3583 Mdot
.88032 .50815 Mdot
.48719 .34088 Mdot
.86817 .97644 Mdot
.35697 .59828 Mdot
.96851 .84438 Mdot
.90767 .01564 Mdot
.94132 .80747 Mdot
.57503 .34534 Mdot
.31478 .23893 Mdot
.91263 .94446 Mdot
.3973 .23309 Mdot
.35779 .2135 Mdot
.55697 .64293 Mdot
.40668 .39623 Mdot
.82017 .98427 Mdot
.95227 .60666 Mdot
.25494 .64873 Mdot
.95017 .533 Mdot
.93036 .41961 Mdot
.90954 .92655 Mdot
.38831 .78597 Mdot
.94842 .59251 Mdot
.46627 .64631 Mdot
.23007 .33764 Mdot
.94262 .4883 Mdot
.25682 .75843 Mdot
.64477 .75617 Mdot
.58552 .23194 Mdot
.81259 .69797 Mdot
.59233 .37013 Mdot
.38091 .37468 Mdot
.31011 .25688 Mdot
.38914 .68637 Mdot
.45415 .7658 Mdot
.95733 .442 Mdot
.3906 .71658 Mdot
.49347 .35187 Mdot
.64461 .33578 Mdot
.45003 .27211 Mdot
.80273 .40152 Mdot
.98775 .07147 Mdot
.94832 .14515 Mdot
.9803 .10532 Mdot
.41533 .63357 Mdot
.32179 .62879 Mdot
.69581 .66578 Mdot
.50926 .23707 Mdot
.69826 .60412 Mdot
.91856 .24269 Mdot
.94822 .89501 Mdot
.54269 .27124 Mdot
.83476 .70321 Mdot
.83708 .59566 Mdot
.89343 .25608 Mdot
.96506 .02319 Mdot
.80851 .67159 Mdot
.96395 .95857 Mdot
.87025 .31199 Mdot
.73142 .32044 Mdot
.82048 .26157 Mdot
.80673 .26284 Mdot
.83371 .18483 Mdot
.83298 .29446 Mdot
.95366 .86304 Mdot
.69138 .59813 Mdot
.46642 .71589 Mdot
.93966 .69767 Mdot
.80711 .1782 Mdot
.9762 .82483 Mdot
.61258 .37617 Mdot
.75395 .28223 Mdot
.9114 .76823 Mdot
.81993 .12772 Mdot
.44303 .21761 Mdot
.8867 .76098 Mdot
.50756 .6755 Mdot
.28392 .39461 Mdot
.36272 .61658 Mdot
.92794 .25728 Mdot
.56955 .39649 Mdot
.92291 .38529 Mdot
.23005 .78019 Mdot
.75419 .62272 Mdot
.88921 .23417 Mdot
.89902 .97189 Mdot
.95649 .83907 Mdot
.54114 .21607 Mdot
.39769 .3233 Mdot
.8313 .51506 Mdot
.53238 .25005 Mdot
.50831 .63672 Mdot
.956 .2878 Mdot
.81381 .61425 Mdot
.87394 .47859 Mdot
.63947 .24271 Mdot
.64261 .61573 Mdot
.9608 .2158 Mdot
.97616 .94398 Mdot
.80439 .32922 Mdot
.34649 .71107 Mdot
.67057 .34738 Mdot
.58748 .66375 Mdot
.93507 .05782 Mdot
.91195 .53803 Mdot
.9151 .04657 Mdot
.92599 .58424 Mdot
.44014 .36996 Mdot
.39341 .30588 Mdot
.79612 .63232 Mdot
.85125 .5843 Mdot
.85581 .59422 Mdot
.92949 .05608 Mdot
.93091 .55746 Mdot
.8202 .84011 Mdot
.22467 .65067 Mdot
.83913 .55181 Mdot
.97352 .94779 Mdot
.82274 .08008 Mdot
.97603 .6764 Mdot
.97321 .92946 Mdot
.56219 .3812 Mdot
.41747 .6199 Mdot
.56973 .72579 Mdot
.79876 .70006 Mdot
.40122 .7407 Mdot
.74144 .3718 Mdot
.84621 .43004 Mdot
.72091 .29225 Mdot
.91235 .58238 Mdot
.60506 .61034 Mdot
.85382 .24834 Mdot
.25653 .6004 Mdot
.94628 .58237 Mdot
.92981 .45234 Mdot
.23517 .29992 Mdot
.90082 .89012 Mdot
.31301 .70774 Mdot
.30556 .28959 Mdot
.43282 .24501 Mdot
.47674 .65284 Mdot
.25138 .36272 Mdot
.92856 .64518 Mdot
.71259 .3321 Mdot
.31561 .67315 Mdot
.71537 .20909 Mdot
.23096 .25865 Mdot
.66221 .3625 Mdot
.75441 .32494 Mdot
.72048 .62643 Mdot
.84768 .9076 Mdot
.63937 .62744 Mdot
.25908 .63077 Mdot
.96735 .27475 Mdot
.49487 .31564 Mdot
.66863 .75445 Mdot
.76459 .67941 Mdot
.5075 .65241 Mdot
.27337 .29183 Mdot
.51942 .34542 Mdot
.848 .16905 Mdot
.74503 .65621 Mdot
.39992 .3959 Mdot
.83801 .4512 Mdot
.4617 .25074 Mdot
.46744 .29819 Mdot
.38244 .30502 Mdot
.61489 .37244 Mdot
.68374 .23016 Mdot
.9108 .4886 Mdot
.41096 .69536 Mdot
.44863 .6168 Mdot
.93372 .40697 Mdot
.39308 .68576 Mdot
.92057 .86213 Mdot
.41564 .63085 Mdot
.8213 .79513 Mdot
.32982 .39342 Mdot
.87778 .39796 Mdot
.92693 .69785 Mdot
.32651 .29601 Mdot
.90106 .65536 Mdot
.69087 .33623 Mdot
.30579 .32534 Mdot
.9369 .74457 Mdot
.52734 .31512 Mdot
.27059 .22384 Mdot
.9015 .26527 Mdot
.26423 .38811 Mdot
.81167 .35525 Mdot
.26757 .72653 Mdot
.86496 .60087 Mdot
.74937 .65143 Mdot
.27211 .28549 Mdot
.60962 .24439 Mdot
.91338 .28827 Mdot
.44633 .68794 Mdot
.90362 .19822 Mdot
.70183 .28039 Mdot
.56604 .37274 Mdot
.53782 .64356 Mdot
.88536 .12629 Mdot
.85277 .43391 Mdot
.37786 .25625 Mdot
.80477 .42705 Mdot
.60053 .64319 Mdot
.93811 .46867 Mdot
.66995 .38662 Mdot
.92681 .20687 Mdot
.80738 .94291 Mdot
.46008 .39309 Mdot
.60292 .21491 Mdot
.88516 .88018 Mdot
.65501 .73644 Mdot
.77983 .71474 Mdot
.96366 .65154 Mdot
.88717 .26746 Mdot
.59026 .37574 Mdot
.48915 .70701 Mdot
.43062 .77718 Mdot
.9819 .08888 Mdot
.97475 .42807 Mdot
.86257 .65725 Mdot
.77268 .62935 Mdot
.96559 .39959 Mdot
.48624 .68278 Mdot
.94527 .66372 Mdot
.98037 .77096 Mdot
.71705 .31285 Mdot
.23837 .30433 Mdot
.68973 .74344 Mdot
.65411 .27271 Mdot
.60305 .22025 Mdot
.93409 .96447 Mdot
.94392 .20332 Mdot
.79467 .7633 Mdot
.52604 .33626 Mdot
.53751 .28995 Mdot
.40956 .32761 Mdot
.46567 .35333 Mdot
.89209 .63552 Mdot
.7868 .26083 Mdot
.60321 .35568 Mdot
.91534 .56534 Mdot
.80218 .11022 Mdot
.78795 .2448 Mdot
.90029 .46489 Mdot
.50241 .34591 Mdot
.8894 .98043 Mdot
.62701 .66582 Mdot
.29965 .74769 Mdot
.29672 .65839 Mdot
.80065 .91373 Mdot
.39752 .66815 Mdot
.51047 .34178 Mdot
.95116 .5332 Mdot
.87365 .66616 Mdot
.92461 .74619 Mdot
.9412 .49009 Mdot
.82431 .08477 Mdot
.32365 .73318 Mdot
.30561 .62054 Mdot
.84625 .65695 Mdot
.92032 .47835 Mdot
.98591 .72235 Mdot
.36095 .72385 Mdot
.52683 .64889 Mdot
.24385 .68701 Mdot
.92844 .07627 Mdot
.83287 .37033 Mdot
.96647 .24696 Mdot
.83716 .63818 Mdot
.81155 .56469 Mdot
.32073 .71413 Mdot
.94937 .26544 Mdot
.74619 .34973 Mdot
.97338 .50106 Mdot
.26862 .7395 Mdot
.80755 .57822 Mdot
.93808 .03518 Mdot
.84837 .32259 Mdot
.8612 .98845 Mdot
.96867 .34107 Mdot
.85777 .2703 Mdot
.89741 .96505 Mdot
.77587 .37174 Mdot
.79994 .17179 Mdot
.5238 .70302 Mdot
.20648 .27987 Mdot
.81743 .86248 Mdot
.56221 .62734 Mdot
.42358 .21572 Mdot
.88997 .5029 Mdot
.6933 .23284 Mdot
.86606 .36056 Mdot
.2099 .22616 Mdot
.44763 .751 Mdot
.81019 .60891 Mdot
.57414 .60658 Mdot
.56476 .68239 Mdot
.94085 .2193 Mdot
.90722 .70523 Mdot
.24361 .26677 Mdot
.7458 .35827 Mdot
.96824 .34601 Mdot
.5431 .73822 Mdot
.90185 .82945 Mdot
.92381 .49324 Mdot
.27236 .22297 Mdot
.89643 .36653 Mdot
.57643 .61351 Mdot
.23428 .78882 Mdot
.30066 .30538 Mdot
.36696 .65875 Mdot
.56851 .62277 Mdot
.45484 .22669 Mdot
.55254 .33574 Mdot
.53252 .35785 Mdot
.63297 .30269 Mdot
.36787 .71556 Mdot
.45011 .39886 Mdot
.6694 .75175 Mdot
.98546 .18198 Mdot
.82343 .93261 Mdot
.76139 .64714 Mdot
.76055 .62889 Mdot
.96449 .45132 Mdot
.25949 .3153 Mdot
.94898 .72093 Mdot
.82364 .82566 Mdot
.4501 .6039 Mdot
.87475 .02343 Mdot
.91597 .2927 Mdot
.85029 .13557 Mdot
.90975 .92197 Mdot
.62544 .24826 Mdot
.53311 .78122 Mdot
.48526 .24149 Mdot
.73613 .3405 Mdot
.4266 .59953 Mdot
.61937 .32159 Mdot
.91516 .45797 Mdot
.37817 .63207 Mdot
.63795 .2906 Mdot
.61496 .73719 Mdot
.87467 .87911 Mdot
.34032 .7163 Mdot
.84382 .53013 Mdot
.91563 .54198 Mdot
.65459 .28893 Mdot
.28749 .26119 Mdot
.2689 .29217 Mdot
.83198 .55504 Mdot
.95544 .05434 Mdot
.97835 .03472 Mdot
.33356 .73598 Mdot
.75233 .25117 Mdot
.90061 .1219 Mdot
.83684 .39485 Mdot
.89154 .56082 Mdot
.92629 .51628 Mdot
.88648 .02354 Mdot
.46801 .40157 Mdot
.53213 .25764 Mdot
.63079 .68702 Mdot
.59982 .36183 Mdot
.79841 .1668 Mdot
.90688 .29273 Mdot
.66426 .39443 Mdot
.53825 .76926 Mdot
.49119 .33322 Mdot
.44887 .37078 Mdot
.85059 .6364 Mdot
.82255 .20386 Mdot
.35748 .30867 Mdot
.7678 .77023 Mdot
.6601 .33317 Mdot
.31831 .36355 Mdot
.79513 .58922 Mdot
.87776 .44638 Mdot
.4516 .35161 Mdot
.41241 .27361 Mdot
.2827 .35166 Mdot
.95458 .9783 Mdot
.80197 .10003 Mdot
.88534 .81622 Mdot
.53664 .29574 Mdot
.96052 .78028 Mdot
.24255 .38595 Mdot
.49248 .71739 Mdot
.51534 .71966 Mdot
.3911 .69753 Mdot
.87829 .13002 Mdot
.89973 .39772 Mdot
.41705 .67053 Mdot
.90253 .80895 Mdot
.48001 .30735 Mdot
.78837 .32179 Mdot
.91242 .66287 Mdot
.50102 .38065 Mdot
.80632 .87503 Mdot
.58134 .64047 Mdot
.53793 .26549 Mdot
.55867 .77362 Mdot
.98882 .34203 Mdot
.45487 .7047 Mdot
.41728 .69176 Mdot
.92658 .25527 Mdot
.82747 .49523 Mdot
.3824 .78073 Mdot
.73471 .66979 Mdot
.26364 .65351 Mdot
.79833 .42432 Mdot
.67301 .78198 Mdot
.85639 .08008 Mdot
.81095 .43457 Mdot
.55711 .77126 Mdot
.8743 .97947 Mdot
.88313 .03349 Mdot
.52122 .25834 Mdot
.82995 .36661 Mdot
.78969 .39562 Mdot
.25157 .29409 Mdot
.56799 .32331 Mdot
.5335 .32797 Mdot
.42462 .2806 Mdot
.63698 .37173 Mdot
.6415 .35791 Mdot
.84951 .28396 Mdot
.84201 .95249 Mdot
.768 .62326 Mdot
.52623 .33897 Mdot
.98293 .02081 Mdot
.58093 .2309 Mdot
.84416 .673 Mdot
.21699 .31107 Mdot
.77407 .64583 Mdot
.92226 .68354 Mdot
.35297 .36663 Mdot
.21675 .38087 Mdot
.98996 .0796 Mdot
.63071 .79282 Mdot
.91922 .56767 Mdot
.93787 .52007 Mdot
.81033 .29996 Mdot
.43849 .7773 Mdot
.48275 .66085 Mdot
.80406 .37604 Mdot
.55524 .29878 Mdot
.45553 .34246 Mdot
.9258 .53837 Mdot
.93612 .29371 Mdot
.46317 .62305 Mdot
.98889 .76635 Mdot
.33775 .32474 Mdot
.60481 .21334 Mdot
.5506 .7856 Mdot
.35889 .39968 Mdot
.21708 .6989 Mdot
.68728 .76001 Mdot
.86952 .38396 Mdot
.53187 .76108 Mdot
.4368 .31794 Mdot
.59187 .61274 Mdot
.89479 .84292 Mdot
.27497 .38525 Mdot
.81233 .29625 Mdot
.84366 .21723 Mdot
.96414 .44576 Mdot
.24565 .703 Mdot
.25702 .30659 Mdot
.95696 .77142 Mdot
.65795 .31897 Mdot
.90149 .51792 Mdot
.83401 .83238 Mdot
.29021 .38868 Mdot
.50387 .34999 Mdot
.61963 .31918 Mdot
.37571 .63368 Mdot
.5419 .78296 Mdot
.29474 .62286 Mdot
.6206 .28339 Mdot
.82762 .41931 Mdot
.92612 .75003 Mdot
.94254 .8528 Mdot
.8258 .9194 Mdot
.49311 .77156 Mdot
.88988 .17918 Mdot
.28511 .67143 Mdot
.48661 .28374 Mdot
.4934 .76324 Mdot
.8665 .876 Mdot
.91416 .03301 Mdot
.82779 .14731 Mdot
.34449 .36595 Mdot
.70207 .64088 Mdot
.93618 .85395 Mdot
.26262 .61889 Mdot
.38631 .73309 Mdot
.29426 .75253 Mdot
.46235 .70989 Mdot
.45666 .61502 Mdot
.37399 .61589 Mdot
.65423 .60989 Mdot
.82451 .6886 Mdot
.90331 .24235 Mdot
.98817 .36282 Mdot
.81266 .66174 Mdot
.34902 .61136 Mdot
.63154 .70872 Mdot
.96751 .10863 Mdot
.60754 .25127 Mdot
.92211 .51256 Mdot
.92413 .15955 Mdot
.89348 .03525 Mdot
.63406 .68697 Mdot
.54629 .78897 Mdot
.92895 .54751 Mdot
.40807 .68315 Mdot
.94655 .48179 Mdot
.61637 .28608 Mdot
.92315 .13415 Mdot
.59191 .6112 Mdot
.4158 .70437 Mdot
.75348 .69514 Mdot
.82475 .36378 Mdot
.54683 .68761 Mdot
.94512 .08622 Mdot
.87478 .41052 Mdot
.53913 .37205 Mdot
.77584 .6671 Mdot
.26894 .21099 Mdot
.6488 .37045 Mdot
.78478 .22388 Mdot
.90019 .80355 Mdot
.60792 .23437 Mdot
.80651 .24839 Mdot
.82228 .55746 Mdot
.6937 .37505 Mdot
.44594 .27499 Mdot
.93312 .33158 Mdot
.78606 .72516 Mdot
.74136 .24756 Mdot
.92505 .98937 Mdot
.88105 .05766 Mdot
.44492 .77286 Mdot
.66455 .2417 Mdot
.78376 .72175 Mdot
.86868 .50674 Mdot
.82923 .47519 Mdot
.39411 .69253 Mdot
.41031 .68975 Mdot
.83149 .18667 Mdot
.80468 .61893 Mdot
.88167 .01354 Mdot
.72983 .68748 Mdot
.49736 .3112 Mdot
.88701 .34042 Mdot
.94639 .62805 Mdot
.87829 .84185 Mdot
.27592 .369 Mdot
.90527 .20778 Mdot
.58576 .21005 Mdot
.87194 .71737 Mdot
.78827 .39533 Mdot
.83207 .75748 Mdot
.38249 .25309 Mdot
.49738 .64916 Mdot
.72778 .35784 Mdot
.23126 .28996 Mdot
.8127 .15986 Mdot
.45269 .23217 Mdot
.59679 .7872 Mdot
.37292 .60957 Mdot
.86574 .95061 Mdot
.64429 .67045 Mdot
.98862 .53172 Mdot
.59275 .31164 Mdot
.40163 .73472 Mdot
.22964 .69226 Mdot
.3541 .73185 Mdot
.50841 .61331 Mdot
.87797 .67022 Mdot
.59145 .35081 Mdot
.29501 .36839 Mdot
.50286 .25976 Mdot
.32988 .22116 Mdot
.9036 .60238 Mdot
.8913 .19672 Mdot
.54342 .61056 Mdot
.5798 .77619 Mdot
.53215 .73748 Mdot
.29526 .34401 Mdot
.59079 .77474 Mdot
.81981 .1514 Mdot
.67306 .76699 Mdot
.74423 .78376 Mdot
.798 .6468 Mdot
.71494 .30604 Mdot
.31055 .39826 Mdot
.71965 .30597 Mdot
.22624 .70184 Mdot
.36621 .24545 Mdot
.6347 .74985 Mdot
.71786 .27907 Mdot
.60742 .24986 Mdot
.63763 .27725 Mdot
.70212 .29355 Mdot
.56141 .27441 Mdot
.80947 .17523 Mdot
.91398 .98736 Mdot
.84771 .64779 Mdot
.95871 .10581 Mdot
.49995 .70381 Mdot
.92873 .43921 Mdot
.31896 .30687 Mdot
.9237 .60008 Mdot
.32928 .66511 Mdot
.32303 .23056 Mdot
.54709 .62507 Mdot
.31137 .79054 Mdot
.947 .57684 Mdot
.93451 .30399 Mdot
.49748 .65784 Mdot
.95921 .8221 Mdot
.64599 .60134 Mdot
.62111 .36766 Mdot
.95675 .61054 Mdot
.60394 .63753 Mdot
.94679 .50448 Mdot
.94815 .04599 Mdot
.61354 .23519 Mdot
.64698 .61485 Mdot
.97923 .31227 Mdot
.62473 .30829 Mdot
.24198 .6502 Mdot
.94008 .0187 Mdot
.86653 .92014 Mdot
.22936 .31509 Mdot
.77208 .76051 Mdot
.41512 .61309 Mdot
.88777 .80736 Mdot
.93788 .79846 Mdot
.90483 .56926 Mdot
.97975 .35209 Mdot
.37159 .40131 Mdot
.8066 .3892 Mdot
.90903 .57204 Mdot
.66123 .60379 Mdot
.96135 .76377 Mdot
.92242 .71264 Mdot
.40017 .72081 Mdot
.58376 .34141 Mdot
.86016 .74112 Mdot
.66493 .75956 Mdot
.89938 .94791 Mdot
.84394 .2881 Mdot
.34561 .71098 Mdot
.3391 .79406 Mdot
.86079 .06304 Mdot
.85385 .24186 Mdot
.73838 .22472 Mdot
.6643 .24277 Mdot
.46503 .68799 Mdot
.98576 .2372 Mdot
.42082 .74226 Mdot
.98286 .12063 Mdot
.85694 .2267 Mdot
.86138 .97969 Mdot
.2503 .35141 Mdot
.81967 .59934 Mdot
.37775 .77589 Mdot
.92266 .72626 Mdot
.93923 .48869 Mdot
.76554 .69316 Mdot
.45681 .3935 Mdot
.35644 .23728 Mdot
.2742 .35728 Mdot
.97232 .48652 Mdot
.34173 .62121 Mdot
.57627 .60433 Mdot
.68861 .74397 Mdot
.95694 .40798 Mdot
.42422 .3965 Mdot
.97482 .91165 Mdot
.94173 .91382 Mdot
.37527 .31929 Mdot
.86825 .32276 Mdot
.26699 .6744 Mdot
.87252 .76788 Mdot
.24351 .26556 Mdot
.85388 .44088 Mdot
.84378 .1245 Mdot
.90548 .68577 Mdot
.73079 .77685 Mdot
.33041 .3166 Mdot
.82868 .45941 Mdot
.96499 .02833 Mdot
.47256 .73717 Mdot
.79252 .64855 Mdot
.80293 .55472 Mdot
.87723 .95298 Mdot
.35222 .38307 Mdot
.80908 .97217 Mdot
.46846 .33448 Mdot
.58142 .3717 Mdot
.85522 .44533 Mdot
.36073 .72479 Mdot
.89685 .17458 Mdot
.84437 .74018 Mdot
.39375 .66135 Mdot
.79449 .05361 Mdot
.32128 .39742 Mdot
.59574 .25067 Mdot
.88364 .40023 Mdot
.88141 .37025 Mdot
.65354 .24454 Mdot
.84924 .20074 Mdot
.48973 .3427 Mdot
.48114 .21925 Mdot
.81384 .77171 Mdot
.92263 .41126 Mdot
.88509 .91443 Mdot
.82429 .74389 Mdot
.54611 .3906 Mdot
.92779 .06117 Mdot
.47728 .36213 Mdot
.91904 .20316 Mdot
.95399 .97482 Mdot
.98831 .54563 Mdot
.89993 .62156 Mdot
.97109 .4282 Mdot
.85045 .18664 Mdot
.93713 .15908 Mdot
.88665 .20201 Mdot
.93902 .60365 Mdot
.50793 .26996 Mdot
.46616 .22474 Mdot
.28205 .26589 Mdot
.33323 .65243 Mdot
.94271 .87481 Mdot
.82659 .21362 Mdot
.28887 .29958 Mdot
.71678 .73889 Mdot
.69906 .76678 Mdot
.9798 .92089 Mdot
.84585 .36801 Mdot
.74822 .74651 Mdot
.96727 .71689 Mdot
.61236 .71401 Mdot
.32464 .23366 Mdot
.95343 .14522 Mdot
.96382 .21452 Mdot
.92673 .16844 Mdot
.21124 .68544 Mdot
.53914 .77344 Mdot
.57591 .63802 Mdot
.66574 .27467 Mdot
.73684 .39387 Mdot
.65 .35585 Mdot
.55865 .32254 Mdot
.48487 .78748 Mdot
.8831 .05767 Mdot
.47724 .78183 Mdot
.7468 .3778 Mdot
.38305 .62415 Mdot
.83302 .16907 Mdot
.35795 .37179 Mdot
.8709 .58016 Mdot
.36488 .32238 Mdot
.7689 .36356 Mdot
.24499 .30436 Mdot
.85213 .6704 Mdot
.9155 .95401 Mdot
.63982 .79229 Mdot
.97635 .24652 Mdot
.2254 .72902 Mdot
.84382 .84278 Mdot
.85071 .41645 Mdot
.32051 .31196 Mdot
.90222 .66406 Mdot
.67258 .69383 Mdot
.43118 .65135 Mdot
.83626 .87098 Mdot
.46765 .72988 Mdot
.97742 .45107 Mdot
.84015 .20765 Mdot
.98172 .96327 Mdot
.97288 .08963 Mdot
.69318 .21623 Mdot
.82212 .93183 Mdot
.25954 .22361 Mdot
.97217 .73399 Mdot
.59967 .27583 Mdot
.67949 .3863 Mdot
.69681 .30648 Mdot
.24418 .36075 Mdot
.26221 .61696 Mdot
.5586 .23385 Mdot
.65274 .35094 Mdot
.45016 .70158 Mdot
.76086 .32508 Mdot
.82587 .85642 Mdot
.57346 .24927 Mdot
.91092 .88853 Mdot
.5369 .79139 Mdot
.47285 .7728 Mdot
.31062 .2129 Mdot
.47494 .34667 Mdot
.89167 .1072 Mdot
.97095 .20887 Mdot
.46372 .25924 Mdot
.77243 .61628 Mdot
.30729 .27941 Mdot
.52232 .62742 Mdot
.95154 .7139 Mdot
.62981 .73802 Mdot
.86849 .88472 Mdot
.97072 .04381 Mdot
.28405 .74388 Mdot
.9579 .84369 Mdot
.51091 .21099 Mdot
.90216 .7374 Mdot
.92164 .70339 Mdot
.47325 .30661 Mdot
.84065 .15115 Mdot
.87294 .29766 Mdot
.86658 .16787 Mdot
.62559 .65554 Mdot
.2307 .64554 Mdot
.97342 .48868 Mdot
.86353 .39096 Mdot
.81026 .4304 Mdot
.93559 .52414 Mdot
.88542 .82291 Mdot
.32274 .67746 Mdot
.85373 .73031 Mdot
.87051 .25143 Mdot
.6997 .73748 Mdot
.57469 .27913 Mdot
.61459 .72528 Mdot
.49847 .25683 Mdot
.2206 .24283 Mdot
.88806 .55557 Mdot
.73972 .684 Mdot
.85941 .44238 Mdot
.61533 .67985 Mdot
.43456 .2867 Mdot
.81017 .55161 Mdot
.87465 .64354 Mdot
.32151 .30459 Mdot
.95893 .19647 Mdot
.82583 .73817 Mdot
.78518 .33745 Mdot
.84499 .90598 Mdot
.90072 .68411 Mdot
.53329 .61119 Mdot
.24667 .2834 Mdot
.81503 .73072 Mdot
.84629 .54406 Mdot
.74677 .78997 Mdot
.48858 .2409 Mdot
.86888 .07469 Mdot
.27582 .72105 Mdot
.56683 .27577 Mdot
.94741 .97206 Mdot
.65639 .62329 Mdot
.89547 .10466 Mdot
.89238 .47123 Mdot
.93517 .48937 Mdot
.4818 .36828 Mdot
.68147 .31292 Mdot
.93444 .6008 Mdot
.84804 .73111 Mdot
.94586 .26968 Mdot
.97372 .19076 Mdot
.45716 .60655 Mdot
.2748 .66445 Mdot
.4581 .68586 Mdot
.94657 .86337 Mdot
.9251 .42656 Mdot
.49921 .26663 Mdot
.90235 .16052 Mdot
.43024 .24292 Mdot
.82385 .48549 Mdot
.83436 .6974 Mdot
.93465 .14473 Mdot
.97828 .27155 Mdot
.79017 .37884 Mdot
.81192 .24383 Mdot
.86747 .10891 Mdot
.87939 .82755 Mdot
.80857 .21761 Mdot
.3055 .75219 Mdot
.35659 .71589 Mdot
.42823 .65309 Mdot
.95907 .22674 Mdot
.72034 .2942 Mdot
.70863 .76754 Mdot
.79703 .92268 Mdot
.92512 .2572 Mdot
.94587 .52138 Mdot
.95624 .04027 Mdot
.41663 .69585 Mdot
.2457 .73627 Mdot
.27791 .70274 Mdot
.47108 .77026 Mdot
.42719 .77803 Mdot
.40757 .65932 Mdot
.98902 .781 Mdot
.75736 .72954 Mdot
.89887 .22931 Mdot
.69811 .66197 Mdot
.64515 .31844 Mdot
.46456 .35389 Mdot
.84272 .1468 Mdot
.9832 .53181 Mdot
.93883 .49756 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`00000P00000040oooo00000`000000oooo0?ooo`0[0?ooo`?oo`00@P3oool3ool001/0
oooo0ooo002:0?ooo`4000000@3oool000030000003oool0oooo0240oooo0ooo00060?ooo`Goo`00
903oool3ool001T0oooo1Ooo00060?ooo`?oo`003P3oool7ool003`0oooo0ooo000=0?ooo`?oo`00
5`3oool3o`00o`D0oooo0ol00?lH0?ooo`4000000@3oool000040000003oool0oooo0?ooo`?oo`00
00@0ooooool00?oo003oo`00203oool3ool000d0oooo1Ooo00050?ooo`Goo`001@3oool3ool00080
oooo0ooo000F0?ooo`Goo`00603oool5ool000D0oooo1Ooo000<0?ooo`Soo`002`3oool3ool002d0
oooo1Ooo000;0?ooo`Goo`005@3oool5o`00o`<0oooo1Ol00?l50?ooo`?o003o3`3oool100000040
oooo00000`000000oooo0?ooo`09ool000030?oooooo003oo`0000Soo`00303oool5ool000D0oooo
1Ooo00040?ooo`[oo`005@3oool6ool001L0oooo1Ooo00050?ooo`Goo`00303oool8ool000X0oooo
1Ooo00080?ooo`?oo`005@3oool3ool000T0oooo1Ooo000;0?ooo`Goo`005@3oool5o`00o`<0oooo
1Ol00?l40?ooo`Go003o203oool3o`00o`<0oooo0@0000010?ooo`0000<000000?ooo`3oool05?oo
000<0?ooo`Goo`001P3oool3ool000D0oooo2_oo000E0?ooo`Ooo`005`3oool3ool000H0oooo1Ooo
000<0?ooo`Ooo`000P3oool3ool000H0oooo1Ooo00070?ooo`Goo`002@3oool3ool000L0oooo1Ooo
00080?ooo`Goo`002`3oool5ool001@0oooo1ol00?l20?ooo`Go003o103oool5o`00o`<0oooo0ol0
0?l00`3ooooo003oo`00o`03o`00o`80oooo0@0000010?ooo`0000<000000?ooo`3oool05?oo000=
0?ooo`?oo`003`3oool=ool00140oooo2?oo000F0?ooo`?oo`00203oool3ool000h0oooo0ooo0004
0?ooo`Soo`000P3oool5ool000L0oooo1Ooo00080?ooo`Goo`001P3oool5ool000P0oooo1Ooo000<
0?ooo`?oo`00503oool9o`00o`030?ooool00?oo003o00?o003o103oool5o`00o`80oooo2_l00?l2
0?ooo`4000000@3oool0000300000?oo003oo`0000Soo`0000<0ooooool00?oo00002?oo000Q0?oo
o`?oo`000P3oool:ool000h0oooo2?oo000E0?ooo`Goo`00503oool3ool000P0oooo2Ooo00020?oo
o`?oo`00203oool5ool000P0oooo1Ooo00060?ooo`Goo`00203oool5ool002<0oooo2Ol00?l00`3o
oooo003oo`00o`03o`00o`D0oooo0ol00?l30?ooo`[o003o0P3oool100000040oooo0008ool000@0
oooo2_oo00020?ooo`?oo`008@3oool;ool000d0oooo1ooo000F0?ooo`Goo`002`3oool3ool000D0
oooo1Ooo00070?ooo`Woo`001`3oool3ool000@0oooo0ooo00090?ooo`Goo`001@3oool5ool000X0
oooo0ooo000T0?oooa3o003o0`3oool3o`00o`@0oooo2Ol00?l30?ooo`4000000@3oool000Woo`00
0`3oool5ool000040?oooooo003oo`00ool00080oooo1Ooo000P0?ooo`_oo`003P3oool3ool001T0
oooo1Ooo00090?ooo`Koo`00103oool5ool000P0oooo2?oo00060?ooo`Goo`003P3oool5ool000D0
oooo1Ooo000@0?ooo`?oo`00803oool?o`00o`80oooo1Ol00?l20?ooo`[o003o0`3oool100000040
oooo0009ool000<0oooo1Ooo00060?ooo`Goo`008@3oool:ool000h0oooo0ooo000J0?ooo`?oo`00
2@3oool7ool000@0oooo1Ooo00080?ooo`?oo`0000@0ooooool00?oo003oo`001`3oool5ool000d0
oooo1Ooo00060?ooo`Goo`003`3oool5ool00240oooo3Ol00?l20?ooo`Go003o00<0ooooo`00ool0
0?l02Ol00?l30?ooo`4000000@3oool0000300000?oo003oo`0000Koo`00103oool3ool000L0oooo
1Ooo000S0?ooo`Ooo`003P3oool5ool000H0oooo1_oo000I0?ooo`Ooo`001@3oool3ool000P0oooo
1Ooo00070?ooo`Soo`003@3oool5ool000H0oooo1Ooo00020?ooo`?oo`002P3oool5ool00240oooo
2?l00?l00`3ooooo003oo`00o`02o`00o`80oooo4Ol00?l30?ooo`4000000@3oool000030000003o
ool0oooo0080oooo0ooo000@0?ooo`?oo`007@3oool3ool000@0oooo1Ooo000@0?ooo`Ooo`000`3o
ool8ool00080oooo1?oo000<0?ooo`?oo`000P3oool7ool00140oooo1Ooo00060?ooo`Soo`003P3o
ool5ool000L0oooo0ooo00020?ooo`Goo`002@3oool5ool00280oooo1_l00?l20?ooo`Go003o0P3o
ool?o`00o`@0oooo0@0000010?ooo`0000<000000?ooo`3oool0=03oool5ool000@0oooo1Ooo0006
0?ooo`?oo`0000@0ooooool00?oo003oo`000P3oool8ool00080oooo2?oo00000`3oooooo`00ool0
0006ool000P0oooo3Ooo000A0?ooo`Goo`001P3oool5ool000@0oooo0ooo000;0?ooo`?oo`003@3o
ool5ool000T0oooo1Ooo00080?ooo`?o003o7`3oool5o`00o`@0oooo3?l00?l50?ooo`4000000@3o
ool000030000003oool0oooo03@0oooo1Ooo00040?ooo`Goo`001@3oool9ool00080oooo1ooo0002
0?ooo`Soo`0000<0ooooool00?oo00001ooo00070?ooo`goo`004P3oool3ool000L0oooo1Ooo0003
0?ooo`Goo`00403oool3ool000L0oooo1Ooo00060?ooo`Soo`001`3oool5o`00oaD0oooo1?l00?l5
0?ooo`So003o00<0ooooo`00ool00?l01?l00?l20?ooo`?o003o1P3oool100000040oooo00000`00
0000oooo0?ooo`0@0?ooo`?oo`008@3oool5ool000@0oooo1Ooo00050?ooo`Woo`000P3oool7ool0
00<0oooo1_oo00020?ooo`Woo`001`3oool=ool001d0oooo0ooo00040?ooo`Goo`003`3oool5ool0
00H0oooo1Ooo00050?ooo`Soo`00203oool5o`00oa@0oooo1_l00?l50?ooo`So003o00<0ooooo`00
ool00?l01?l00?l:0?ooo`4000000@3oool000030000003oool0oooo00l0oooo1Ooo000Q0?ooo`?o
o`001P3oool3ool000H0oooo2Ooo00000`3oooooo`00ool00005ool000X0oooo2ooo00070?ooo`go
o`007@3oool3ool000@0oooo1Ooo000?0?ooo`Goo`001P3oool5ool000D0oooo1Ooo000;0?ooo`Go
003o3`3oool3o`00o`80oooo1_l00?l70?ooo`Oo003o00<0ooooo`00ool00?l00ol00?l:0?ooo`40
00000@3oool000030000003oool0oooo00l0oooo1Ooo000E0?ooo`?oo`003@3oool3ool000<0oooo
0ooo00060?ooo`?oo`0000@0ooooool00?oo003oo`000P3oool5ool000/0oooo1Ooo00030?ooo`?o
o`001@3ooolAool000l0oooo0ooo00090?ooo`Goo`000P3oool6ool000l0oooo1Ooo00060?ooo`Go
o`001@3oool5ool000X0oooo0_oo0003o`00o`l0oooo1Ol00?l00`3ooooo003oo`00o`04o`00o`L0
oooo1ol00?l00`3ooooo003oo`00o`03o`00o`X0oooo0@0000010?ooo`0000<000000?ooo`3oool0
3`3oool5ool001@0oooo1Ooo000;0?ooo`Goo`0000<0ooooool00?oo00000ooo000>0?ooo`Goo`00
2`3oool5ool000X0oooo4_oo000>0?ooo`Goo`00203oool5ool00080oooo1_oo000@0?ooo`?oo`00
1P3oool6ool000H0oooo0ooo000;0?ooo`Goo`003`3oool5o`00o`80oooo1?l00?l80?ooo`Oo003o
0P3oool3o`00o`L0oooo0ol00?l10?ooo`4000000@3oool000030000003oool0oooo0100oooo0ooo
000E0?ooo`Goo`002`3oool5ool000030?oooooo003oo`0000?oo`003`3oool3ool000`0oooo1Ooo
000:0?ooo`Soo`0000<0ooooool00?oo00001ooo000>0?ooo`Goo`00203oool5ool00080oooo1Ooo
000J0?ooo`Koo`00503oool5ool000l0oooo1_l00?l40?ooo`?o003o1`3oool5o`00o``0oooo1Ol0
0?l100000040oooo00000`000000oooo0?ooo`0S0?ooo`?oo`000P3oool5ool000/0oooo1Ooo0000
0`3oooooo`00ool00003ool001l0oooo0ooo000;0?ooo`Goo`00103oool8ool000H0oooo0ooo0006
0?ooo`Goo`000`3oool3ool000<0oooo0ooo00040?ooo`?oo`000P3oool3ool000/0oooo0ooo0008
0?ooo`Koo`003P3oool3ool000@0oooo0ooo000A0?ooo`Ko003o0P3oool5o`00o`L0oooo0ol00?l=
0?ooo`Go003o0@0000010?ooo`0000@000000?ooo`3oool0oooo0ooo000K0?ooo`Soo`000P3oool3
ool000d0oooo0ooo00030?ooo`?oo`006P3oool3ool00140oooo1Ooo00030?ooo`Ooo`001`3oool5
ool000H0oooo0ooo00000`3oooooo`00ool00005ool000D0oooo0ooo00050?ooo`Woo`001@3oool5
ool000P0oooo1?oo000>0?ooo`Goo`00303oool3o`00o`L0oooo1ol00?l20?ooo`Go003o1P3oool8
o`00o`T0oooo1Ol00?l100000040oooo00000`000000oooo0?ooo`05ool001T0oooo2ooo00060?oo
o`?oo`00:@3oool5ool000040?oooooo003oo`00ool000`0oooo1Ooo00030?ooo`Goo`002@3oool5
ool000H0oooo2ooo00040?ooo`Koo`000`3oool:ool000@0oooo1Ooo000J0?ooo`Goo`002`3oool5
o`00o`D0oooo2?l00?l20?ooo`Go003o1P3oool9o`00o`P0oooo1Ol00?l100000040oooo00000`00
0000oooo0?ooo`05ool001T0oooo3?oo00040?ooo`Goo`00603oool3ool000d0oooo2_oo00000`3o
ooooo`00ool00003ool000D0oooo1Ooo00030?ooo`Goo`002@3oool5ool000D0oooo3?oo00040?oo
o`Ooo`000P3oool:ool000@0oooo1Ooo000J0?ooo`Goo`000`3oool3ool000D0oooo1_l00?l40?oo
o`Oo003o103oool3o`00o`L0oooo2Ol00?l70?ooo`Ko003o0@0000010?ooo`0000<000000?ooo`3o
ool01Ooo000I0?ooo`coo`00103oool5ool001L0oooo1Ooo000<0?oooa?oo`000P3oool5ool000@0
oooo0ooo000;0?ooo`?oo`000P3oool3ool000030?oooooo003oo`0000Woo`001@3oool7ool000<0
oooo2Ooo00050?ooo`?oo`00703oool3ool000<0oooo1Ooo00040?ooo`Ko003o103oool5o`00oa40
oooo2?l00?l40?ooo`Wo003o0@0000010?ooo`0000@000000?ooo`3oool0oooo0ooo000G0?ooo`?o
o`0000@0ooooool00?oo003oo`000`3oool5ool000@0oooo1Ooo000G0?ooo`Koo`00303oool3ool0
00030?oooooo003oo`0000goo`0000<0ooooool00?oo00000ooo000?0?ooo`?oo`00103oool=ool0
00P0oooo1ooo00060?ooo`Goo`00:`3oool5ool000D0oooo1Ol00?l50?ooo`?o003o5@3oool5o`00
o`<0oooo2Ol00?l10?ooo`4000000@3oool000030000003oool0oooo01X0oooo1Ooo00070?ooo`?o
o`00103oool5ool000`0oooo0ooo00090?ooo`Ooo`00403oool3ool000030?oooooo003oo`0000So
o`000P3oool5ool000d0oooo1Ooo00030?ooo`Goo`0000@0ooooool00?oo003oo`002`3oool7ool0
02P0oooo0ooo000<0?ooo`Goo`001P3oool3o`00oah0oooo1Ol00?l30?ooo`So003o0P3oool10000
0040oooo00000`000000oooo0?ooo`0J0?ooo`Goo`003P3oool5ool000/0oooo1Ooo00090?ooo`Ko
o`00503oool:ool00080oooo1Ooo00070?ooo`?oo`000`3oool5ool000<0oooo1_oo000>0?ooo`Ko
o`004@3oool3ool000L0oooo1Ooo00040?ooo`?oo`0000<0ooooool00?oo00000ooo000<0?ooo`?o
o`000ol00?lV0?ooo`?o003o103oool7o`00o`<0oooo0@0000010?ooo`0000<000000?ooo`3oool0
6P3oool5ool000L0oooo0ooo00030?ooo`Ooo`002P3oool5ool000X0oooo1Ooo00090?ooo`?oo`00
203oool:ool00080oooo1Ooo00060?ooo`Goo`000P3oool5ool000@0oooo1Ooo000>0?ooo`Ooo`00
3`3oool5ool000D0oooo1ooo00020?ooo`[oo`001`3oool3ool000@0oooo1Ol00?lA0?ooo`?o003o
0`3oool3o`00o`l0oooo0ol00?l00`3ooooo003oo`00o`03o`00o`@0oooo0@0000010?ooo`0000<0
00000?ooo`3oool06`3oool3ool000L0oooo1Ooo00020?ooo`Ooo`002P3oool5ool000/0oooo0ooo
00090?ooo`Goo`00203oool3ool000030?oooooo003oo`0000?oo`000`3oool3ool000L0oooo1Ooo
00030?ooo`?oo`000P3oool8ool000l0oooo1_oo000?0?ooo`Goo`001@3oool7ool00080oooo2ooo
00020?ooo`Soo`000`3oool5o`00o`/0oooo0ol00?l00`3ooooo003oo`00o`04o`00o`030?ooool0
0?oo003o00?o003o3@3oool;o`00o`<0oooo0@0000010?ooo`0000<000000?ooo`3oool01`3oool3
ool001/0oooo1Ooo00020?ooo`Ooo`002`3oool3ool001P0oooo1Ooo000<0?ooo`Goo`003@3oool5
ool000L0oooo2?oo00020?ooo`?oo`00303oool5ool000<0oooo0ooo00090?ooo`Goo`001@3oool7
ool00080oooo1Ooo00000`3oooooo`00ool00003ool000030?oooooo003oo`0000Ooo`000`3oool5
o`00o`X0oooo4Ol00?l=0?ooo`_o003o0`3oool100000040oooo00000`000000oooo0?ooo`060?oo
o`Goo`006P3oool5ool000<0oooo1Ooo000V0?ooo`Koo`003@3oool4ool000h0oooo0ooo00080?oo
o`Goo`00103oool5ool000`0oooo0ooo00030?ooo`Goo`002@3oool3ool000@0oooo2?oo00040?oo
o`?oo`000P3oool5ool000030?oooooo003oo`0000Ooo`000P3oool00ooo003o003oo`00o`03o`00
o`X0oooo4Ol00?l=0?ooo`_o003o0`3oool100000040oooo00000`000000oooo0?ooo`040?ooo`Oo
o`005`3oool3ool000040?oooooo003oo`00ool002h0oooo1_oo000>0?ooo`Goo`00603oool5ool0
00@0oooo1Ooo000B0?ooo`Goo`003`3oool5ool000h0oooo0ooo00020?ooo`Soo`000P3oool2ool0
00Go003o2P3oool:o`00o`030?ooool00?oo003o00?o003o3`3oool9o`00o`@0oooo0@0000010?oo
o`0000<000000?ooo`3oool00`3oool8ool000040?oooooo003oo`00ool00180oooo1Ooo000U0?oo
o`?oo`002@3oool5ool000D0oooo0ooo00070?ooo`Goo`006@3oool3ool000D0oooo1Ooo000B0?oo
o`Goo`003`3oool5ool001@0oooo0ooo00060?ooo`;oo`001Ol00?l;0?ooo`?o003o00@0ooooo`00
ool00?oo003o103oool6o`00oa00oooo0ol00?l0103ooooo003oo`00ool00?l30?ooo`4000000@3o
ool000030000003oool0oooo00<0oooo1ooo00000`3oooooo`00ool00003ool00140oooo1Ooo000D
0?ooo`?oo`001@3oool3ool000D0oooo1Ooo00080?ooo`Goo`00103oool5ool000H0oooo1Ooo000?
0?ooo`?oo`00403oool3ool001@0oooo0ooo000?0?ooo`Koo`005P3oool3ool000@0oooo0ooo0003
o`00o`T0oooo0ol00?l90?ooo`?o003o00<0ooooo`00ool00?l01_l00?l?0?ooo`Go003o0P3oool1
00000040oooo00000`000000oooo0?ooo`030?ooo`ooo`003`3oool5ool001<0oooo1Ooo00030?oo
o`Goo`00103oool5ool000T0oooo0ooo00030?ooo`Ooo`001@3oool7ool000d0oooo1Ooo000Q0?oo
o`?oo`00503oool6ool001D0oooo1Ooo00040?ooo`?oo`00103oool3o`00o`<0oooo1Ol00?l60?oo
o`oo003o3P3oool5o`00o`80oooo0@0000010?ooo`0000<000000?ooo`3oool0103oool?ool000l0
oooo0ooo000=0?ooo`?oo`00103oool5ool000<0oooo1Ooo00040?ooo`Goo`003P3oool<ool00003
0?oooooo003oo`0000Goo`003@3oool5ool000h0oooo0ooo000?0?ooo`Koo`004P3oool6ool000l0
oooo0ooo00030?ooo`Goo`002P3oool5o`00o`80oooo1Ol00?l50?oooa7o003o3@3oool5o`00o`80
oooo0@0000010?ooo`0000<000000?ooo`3oool0103oool?ool001h0oooo1Ooo00030?ooo`Goo`00
0`3oool5ool000@0oooo1Ooo000>0?oooaCoo`003@3oool5ool000d0oooo1_oo000=0?ooo`Ooo`00
4P3oool4ool000l0oooo1Ooo00020?ooo`Soo`001`3oool5o`00o`80oooo1_l00?l40?ooo`Oo003o
00<0ooooo`00ool00?l02?l00?l=0?ooo`?o003o0`3oool100000040oooo00001000003oo`00ool0
0?oo00030?ooo`Soo`0000<0ooooool00?oo00001?oo000N0?ooo`Goo`00103oool3ool000D0oooo
0ooo00050?ooo`Goo`003P3oool5ool00080oooo1_oo00000`3oooooo`00ool00003ool00080oooo
0ooo000:0?ooo`?oo`003P3oool7ool000`0oooo1ooo00030?ooo`?oo`007`3oool5ool000<0oooo
2?oo00060?ooo`Go003o0`3oool6o`00o`<0oooo1_l00?l60?ooo`Ko003o4`3oool100000040oooo
0005ool000<0oooo1_oo00030?ooo`Coo`007`3oool5ool001D0oooo0ooo000@0?ooo`?oo`000`3o
ool6ool000L0oooo1Ooo00050?ooo`?oo`004P3oool7ool00080oooo0ooo00080?ooo`Koo`000P3o
ool5ool001h0oooo1Ooo00060?ooo`Goo`001`3oool3o`00o`D0oooo1Ol00?l40?ooo`?o003o203o
ool8o`00oa40oooo0@0000010?ooo`001Ooo00040?ooo`?oo`00:@3oool3ool000l0oooo0ooo000N
0?ooo`Coo`00203oool5ool000@0oooo1Ooo000B0?ooo`Koo`0000<0ooooool00?oo00000ooo0009
0?ooo`?oo`000`3oool5ool001D0oooo0ooo00020?ooo`?oo`000P3oool3ool000L0oooo1_oo0009
0?ooo`?o003o00<0ooooo`00ool00?l01?l00?l?0?ooo`ko003o2`3oool100000040oooo0005ool0
00<0oooo1Ooo000i0?ooo`Goo`004@3oool5ool001<0oooo1Ooo00040?ooo`Goo`002`3oool3ool0
00@0oooo1Ooo00020?ooo`Goo`003`3oool5ool001@0oooo2_oo000<0?ooo`Goo`001P3oool<o`00
oa00oooo3ol00?l:0?ooo`4000000@3oool0000500000?oo003oo`00ool0003oool02?oo000i0?oo
o`Goo`00403oool7ool001<0oooo0ooo00050?ooo`Goo`002P3oool5ool000030?oooooo003oo`00
00Goo`0000<0ooooool00?oo00001?oo000@0?ooo`?oo`005@3oool<ool000X0oooo1Ooo00050?oo
o`co003o4P3oool>o`00o`X0oooo0@0000010?ooo`0000@000000?ooo`3oool0oooo2Ooo00020?oo
o`?oo`00=03oool5ool00100oooo1ooo000K0?ooo`Goo`000`3oool3ool000@0oooo4ooo000P0?oo
o`?oo`000P3oool3ool000030?oooooo003oo`0000_oo`002P3oool3ool000<0oooo3ol00?lF0?oo
o`[o003o2P3oool100000040oooo000010000000oooo0?ooo`3oool8ool00080oooo1Ooo000B0?oo
o`?oo`003`3oool3ool000d0oooo0ooo000A0?ooo`Woo`006@3oool5ool00080oooo1Ooo00030?oo
o`[oo`0000<0ooooool00?oo00001_oo000O0?ooo`[oo`0000@0ooooool00?oo003oo`000P3oool7
ool000l0oooo3ol00?l>0?ooo`?o003o0`3oool3o`00o`030?ooool00?oo003o00Ko003o2`3oool1
00000040oooo000010000000oooo0?ooo`3oool5ool000D0oooo1Ooo000A0?ooo`Goo`003@3oool5
ool000l0oooo0ooo000?0?ooo`Woo`00603oool5ool00080oooo1_oo00000`3oooooo`00ool00003
ool000030?oooooo003oo`0000?oo`0000<0ooooool00?oo00001Ooo000?0?ooo`?oo`003P3oool:
ool000P0oooo1Ooo000?0?ooo`So003o0`3oool3o`00o`h0oooo1Ol00?l00`3ooooo003oo`00o`07
o`00o`l0oooo0@0000010?ooo`0000@000000?ooo`3oool0oooo1Ooo00050?ooo`Goo`004@3oool5
ool000d0oooo1Ooo000>0?ooo`_oo`00303oool5ool001P0oooo1Ooo00020?oooa;oo`0000<0oooo
ool00?oo00000ooo000@0?ooo`Goo`00203oool3ool00080oooo2_oo00090?ooo`?oo`003`3oool8
o`00o`80oooo0ol00?l0103ooooo003oo`00ool00?l30?ooo`?o003o1P3oool5o`00o`030?ooool0
0?oo003o00Oo003o3`3oool100000040oooo00000`000000oooo0?ooo`020?ooo`?oo`001`3oool6
ool000l0oooo1Ooo000=0?ooo`Goo`003P3oool<ool000/0oooo1Ooo000H0?ooo`Goo`000`3ooolA
ool00080oooo1?oo000@0?ooo`Goo`00103oool8ool00080oooo2?oo000>0?ooo`Coo`002@3oool9
o`00o`030?ooool00?oo003o00Oo003o00<0ooooo`00ool00?l00ol00?l50?ooo`Go003o00<0oooo
o`00ool00?l01ol00?l?0?ooo`4000000@3oool000030000003oool0oooo00h0oooo1Ooo000?0?oo
o`?oo`003`3oool3ool000l0oooo3?oo000<0?ooo`?oo`00403oool3ool000L0oooo0ooo00050?oo
o`ooo`000`3oool5ool000l0oooo1Ooo00030?ooo`Woo`001P3oool3ool000X0oooo0ooo00000`3o
ooooo`00ool00004ool000P0oooo2?l00?l20?ooo`Wo003o00<0ooooo`00ool00?l00ol00?l40?oo
o`Go003o0`3oool7o`00oa00oooo0@0000010?ooo`0000<000000?ooo`3oool03P3oool5ool001l0
oooo0ooo000B0?ooo`_oo`007P3oool5ool000l0oooo1ooo00000`3oooooo`00ool00003ool000@0
oooo1Ooo000?0?ooo`Goo`000`3oool9ool00180oooo2ooo00080?ooo`So003o0P3oool9o`00o`03
0?ooool00?oo003o00?o003o0P3oool6o`00o`@0oooo1Ol00?lB0?ooo`4000000@3oool000030000
003oool0oooo00h0oooo1_oo000:0?ooo`?oo`00403oool5ool001@0oooo1ooo000O0?ooo`Goo`00
3@3oool>ool000D0oooo1Ooo000@0?ooo`?oo`00103oool9ool00180oooo2ooo00090?ooo`Oo003o
0`3oool3o`00o`040?ooool00?oo003oo`00o`<0oooo0ol00?l20?ooo`Oo003o1@3oool3o`00o`h0
oooo0ol00?l20?ooo`4000000@3oool000030000003oool0oooo00l0oooo1Ooo00090?ooo`Ooo`00
3@3oool5ool001@0oooo1Ooo000C0?ooo`?oo`002`3oool5ool000@0oooo0ooo00050?ooo`koo`00
1P3oool5ool001L0oooo2Ooo000B0?ooo`[oo`002`3oool6o`00o`<0oooo0ol00?l20?ooo`?o003o
1`3oool7o`00o`<0oooo0ol00?l?0?ooo`Go003o0@3oool100000040oooo00000`000000oooo0?oo
o`0?0?ooo`Goo`002@3oool8ool000`0oooo1Ooo00050?ooo`?oo`00303oool5ool00180oooo1ooo
00090?ooo`Koo`0000<0ooooool00?oo00000ooo00040?ooo`koo`001P3oool5ool000D0oooo0ooo
000?0?ooo`Woo`004P3oool:ool000L0oooo0ooo00000`3ooooo003oo`00o`04o`00o`80oooo2_l0
0?l60?ooo`Ko003o0`3oool5o`00o`h0oooo1Ol00?l10?ooo`4000000@3oool000030000003oool0
oooo0100oooo0ooo000:0?ooo`Soo`002`3oool5ool000D0oooo1Ooo000<0?ooo`?oo`004`3oool:
ool000P0oooo2_oo00040?ooo`Ooo`000P3oool5ool000H0oooo1Ooo00040?ooo`Goo`003P3oool8
ool001@0oooo0ooo00020?ooo`?oo`001`3oool5ool000030?ooool00?oo003o00;o003o0`3oool:
o`00o`L0oooo0ol00?l50?ooo`Go003o303oool7o`00o`40oooo0@0000010?ooo`0000<000000?oo
o`3oool07P3oool7ool000X0oooo1Ooo00040?ooo`Ooo`00103oool3ool001/0oooo2ooo00070?oo
o`[oo`001@3oool5ool000@0oooo0ooo00080?ooo`?oo`000`3oool7ool000l0oooo0ooo000S0?oo
o`?oo`0000<0ooooool00?oo00000ooo00080?ooo`[o003o203oool3o`00o`@0oooo1Ol00?l70?oo
o`?o003o00<0ooooo`00ool00?l01Ol00?l20?ooo`4000000@3oool000030000003oool0oooo00@0
oooo0ooo000I0?ooo`Goo`002P3oool5ool000<0oooo2?oo00030?ooo`Goo`0000@0ooooool00?oo
003oo`005`3oool:ool000L0oooo2Ooo00050?ooo`?oo`005`3oool8ool00200oooo0ooo000A0?oo
o`[oo`002@3oool3o`00o`80oooo0ol00?l80?ooo`Oo003o0P3oool3o`00o`L0oooo2_l00?l40?oo
o`4000000@3oool000030000003oool0oooo00<0oooo1Ooo000H0?ooo`Goo`002P3oool5ool000<0
oooo2?oo00030?ooo`[oo`005`3oool9ool000L0oooo1ooo00060?ooo`Goo`005P3oool7ool00200
oooo1Ooo00060?ooo`?oo`001`3oool5ool000040?oooooo003oo`00ool000L0oooo0ol00?l40?oo
o`Go003o1`3oool8o`00o`040?ooool00?oo003oo`00o`@0oooo3Ol00?l40?ooo`4000000@3oool0
00030000003oool0oooo00<0oooo1Ooo000I0?ooo`?oo`00303oool3ool000@0oooo2?oo00030?oo
o`[oo`006@3oool6ool000P0oooo1ooo00060?ooo`Goo`005P3oool5ool00280oooo1Ooo00050?oo
o`Goo`001P3oool5ool000X0oooo1Ol00?l00`3ooooo003oo`00o`05o`00o`H0oooo3ol00?l00`3o
oooo003oo`00o`07o`00o`040?ooool00?oo003oo`00o`D0oooo0@0000010?ooo`0000<000000?oo
o`3oool00`3oool6ool002l0oooo1ooo0000103ooooo003oo`00ool00?l3ool000030?oooooo003o
003o00;o003o00?oo`000?ooo`3oool05`3oool5ool000X0oooo1Ooo00070?ooo`Goo`002@3oool3
o`00o`X0oooo1Ooo00030?ooo`Ko003o6@3oool5ool000050?ooool00?oo003oo`00o`3oool01Ooo
00070?ooo`?oo`002`3oool=o`00o`H0oooo6?l00?l0103ooooo003oo`00ool00?l60?ooo`400000
0@3oool000030000003oool0oooo00@0oooo1_oo000:0?ooo`?oo`00903oool3ool000030?ooool0
0?oo003o00?o003o0`3oool5o`00o`P0oooo0ol00?l;0?ooo`?o003o00@0ooooool00?oo003oo`00
603oool3ool000T0oooo1Ol00?l90?ooo`Goo`000P3oool:o`00oaH0oooo1Ooo0005o`00o`Goo`00
5@3oool<o`00o`L0oooo5Ol00?l20?ooo`Ko003o1@3oool100000040oooo00000`000000oooo0?oo
o`050?ooo`Goo`002@3oool5ool00140oooo0ooo00030?ooo`?oo`003@3oool5o`00o`<0oooo1Ol0
0?l70?ooo`Go003o2@3oool5o`00o`l0oooo0ol00?l20?ooo`?o003o403oool5o`00o`@0oooo0ol0
0?l30?ooo`?oo`000`3oool;o`00oaD0oooo0ol00?l00ooo0000ooooo`00o`04o`00o`040?oooooo
003oo`00ool001<0oooo0ol00?l00`3ooooo003oo`00o`07o`00o`X0oooo0ol00?l00`3ooooo003o
o`00o`09o`00o`040?ooool00?oo003oo`00o`80oooo1ol00?l50?ooo`4000000@3oool000030000
003oool0oooo00D0oooo1Ooo00090?ooo`Goo`00403oool;ool000`0oooo1Ol00?l30?ooo`Go003o
1`3oool5o`00o`80oooo0ol00?l40?ooo`Go003o3P3oool:o`00o`L0oooo0ol00?l50?ooo`Go003o
0`3oool5o`00o`P0oooo2ol00?lD0?ooo`Go003o00<0ooooo`00ool00?l00ol00?lF0?ooo`oo003o
3@3oool5o`00o`80oooo0ol00?l0103ooooo003oo`00ool00?l20?ooo`So003o1@3oool100000040
oooo00000`000000oooo0?ooo`060?ooo`?oo`002P3oool5ool00100oooo2ooo000=0?ooo`?o003o
0`3oool6o`00o`L0oooo1Ol00?l00`3ooooo003oo`00o`03o`00o`<0oooo1Ol00?l>0?ooo`[o003o
0`3oool8o`00o`D0oooo0ol00?l40?ooo`Go003o2@3oool:o`00oa@0oooo1Ol00?l20?ooo`?o003o
103oool3o`00o`X0oooo0ol00?l30?ooo`oo003o3P3oool3o`00o`H0oooo1Ol00?l00`3ooooo003o
o`00o`05o`00o`H0oooo0@0000010?ooo`0000<000000?ooo`3oool0503oool3ool00140oooo2ooo
00050?ooo`?o003o2P3oool8o`00o`L0oooo0ol00?l20?ooo`Go003o103oool3o`00o`l0oooo5Ol0
0?l<0?ooo`Go003o3@3oool5o`00oaD0oooo1Ol00?l80?ooo`Go003o203oool5o`00o`80oooo1Ol0
0?l01@3ooooo003oo`00ool00?l0oooo00So003o503oool5o`00o`030?ooool00?oo003o00?o003o
203oool100000040oooo00000`000000oooo0?ooo`070?ooo`?oo`00203oool3ool001@0oooo2ooo
00030?ooo`Go003o2@3oool8o`00o`/0oooo1_l00?lG0?ooo`?o003o0P3oool?o`00o`d0oooo1Ol0
0?l70?ooo`Co003o00<0ooooo`00ool00?l00ol00?lC0?ooo`Ko003o2@3oool5o`00o`P0oooo1Ol0
0?l30?ooo`?o003o1`3oool8o`00o`P0oooo0ol00?l80?ooo`[o003o2@3oool100000040oooo0000
0`000000oooo0?ooo`060?ooo`Goo`001P3oool5ool001H0oooo2?oo00030?ooo`Go003o2@3oool8
o`00o`X0oooo1_l00?l@0?ooo`?o003o3@3oool;o`00o`h0oooo2?l00?l30?ooo`Ko003o00<0oooo
o`00ool00?l01?l00?l@0?ooo`Oo003o2@3oool5o`00o`P0oooo1Ol00?l0103ooooo003oo`00ool0
0?l<0?ooo`Go003o1@3oool7o`00o`P0oooo0ol00?l00`3ooooo003oo`00o`03o`00o`T0oooo0@00
00010?ooo`0000<000000?ooo`3oool01P3oool5ool000H0oooo1Ooo00060?ooo`?oo`00403oool5
ool000<0oooo1Ol00?l:0?ooo`Ko003o2P3oool6o`00o`H0oooo0ol00?l70?ooo`Go003o2`3oool8
o`00o`T0oooo0ol00?l60?ooo`Wo003o0P3oool6o`00o`80oooo1_l00?l?0?ooo`So003o2@3oool3
o`00o`X0oooo0ol00?l00`3ooooo003oo`00o`03o`00o`/0oooo1Ol00?l40?ooo`So003o303oool5
o`00o`@0oooo0ol00?l20?ooo`4000000@3oool000030000003oool0oooo00D0oooo1_oo00060?oo
o`Goo`00103oool6ool00100oooo0ooo00050?ooo`?o003o6P3oool7o`00o`D0oooo1Ol00?l60?oo
o`Go003o2`3oool5o`00o`D0oooo1?l00?l20?ooo`Go003o1P3oool8o`00o`80oooo1_l00?l20?oo
o`Ko003o2`3oool3o`00o`030?ooool00?oo003o00Ko003o6P3oool5o`00o`/0oooo1?l00?l50?oo
o`So003o3@3oool3o`00o`@0oooo1Ol00?l10?ooo`4000000@3oool000030000003oool0oooo00@0
oooo1ooo00060?ooo`Goo`000`3oool7ool001/0oooo0ol00?lG0?ooo`Oo003o1@3oool6o`00o`D0
oooo1Ol00?l60?ooo`?o003o0P3oool5o`00o`@0oooo1_l00?l00`3ooooo003oo`00o`03o`00o`T0
oooo1Ol00?l30?ooo`Co003o0`3oool6o`00o`@0oooo0ol00?l00`3ooooo003oo`00o`05o`00o`03
0?ooool00?oo003o00Go003o5`3oool:o`00o`P0oooo1Ol00?l50?ooo`Wo003o00@0ooooo`00ool0
0?oo003o3`3oool5o`00o`40oooo0@0000010?ooo`0000<000000?ooo`3oool0103oool7ool000L0
oooo0ooo00040?ooo`Ooo`002P3oool3ool000d0oooo1Ol00?lF0?ooo`Ko003o1P3oool7o`00o`D0
oooo0ol00?l60?ooo`Go003o0P3oool3o`00o`D0oooo1_l00?l00`3ooooo003oo`00o`03o`00o`X0
oooo0ol00?l20?ooo`?o003o1P3oool5o`00o`030?ooool00?oo003o00go003o103oool4o`00o`X0
oooo0ol00?l90?ooo`co003o1`3oool5o`00o`H0oooo3Ol00?l90?ooo`[o003o0@3oool100000040
oooo00000`000000oooo0?ooo`040?ooo`Koo`003`3oool6ool000X0oooo1Ooo00060?ooo`?oo`00
0`3oool5o`00oaL0oooo0ol00?l90?ooo`Ko003o3P3oool5o`00o`80oooo1_l00?l20?ooo`Ko003o
0P3oool3o`00o`@0oooo0ol00?l80?ooo`Go003o0P3ooolHo`00o`@0oooo1Ol00?l80?ooo`Oo003o
1P3oool5o`00o`030?ooool00?oo003o00Co003o1`3oool5o`00o`040?ooool00?oo003oo`00o`D0
oooo2_l00?l80?ooo`[o003o0P3oool100000040oooo00000`000000oooo0?ooo`050?ooo`?oo`00
303oool5ool000030?oooooo003oo`0000?oo`002P3oool5ool00080oooo2?oo00020?ooo`Go003o
8`3oool:o`00o`X0oooo1Ol00?l00`3ooooo003oo`00o`0<o`00o`T0oooo1Ol00?l70?ooo`Go003o
00<0ooooo`00ool00?l05ol00?l40?ooo`Go003o203oool8o`00o`D0oooo1Ol00?l00`3ooooo003o
o`00o`04o`00o`L0oooo2_l00?l30?ooo`co003o1`3oool8o`00o`@0oooo0@0000010?ooo`0000<0
00000?ooo`3oool0103oool3ool000`0oooo3?oo000:0?ooo`Goo`0000<0ooooool00?oo00001ooo
00030?ooo`Ko003o4`3oool3o`00o`L0oooo0ol00?l20?ooo`[o003o2P3oool3o`00o`80oooo2ol0
0?l30?ooo`Go003o0P3oool7o`00o`L0oooo1Ol00?l00`3ooooo003oo`00o`0?o`00o`030?ooool0
0?oo003o00Co003o1@3oool5o`00o`P0oooo2?l00?l60?ooo`?o003o0P3oool5o`00o`P0oooo2_l0
0?l20?ooo`ko003o1P3oool8o`00o`@0oooo0@0000010?ooo`0000@000000?ooo`3oool0oooo1ooo
000;0?ooo`coo`002`3oool3ool00080oooo2Ooo00050?ooo`Go003o303oool3o`00o`80oooo1Ol0
0?l50?ooo`Go003o1@3oool6o`00o`l0oooo2ol00?l20?ooo`oo003o203oool3o`00o`80oooo2Ol0
0?l0103ooooo003oo`00ool00?l@0?ooo`Co003o2P3oool7o`00o`H0oooo0ol00?l30?ooo`?o003o
00@0ooooo`00ool00?oo003o1P3oool3o`00o`030?ooool00?oo003o00?o003o0P3oool>o`00o`L0
oooo1_l00?l50?ooo`4000000@3oool000030000003oool0oooo00[oo`002@3oool<ool00100oooo
2?oo00060?ooo`Oo003o203oool6o`00o`030?ooool00?oo003o00?o003o1@3oool5o`00o`D0oooo
1_l00?l@0?ooo`[o003o0P3oool@o`00o`d0oooo1ol00?lD0?ooo`Go003o3@3oool3o`00o`H0oooo
1Ol00?l00`3ooooo003oo`00o`07o`00o`X0oooo0ol00?l30?ooo`ko003o0`3oool3o`00o``0oooo
0@0000010?ooo`0000<000000?ooo`3oool02ooo00090?ooo`_oo`0000@0ooooool00?oo003oo`00
3@3oool3ool000X0oooo2?l00?l60?ooo`Oo003o00<0ooooo`00ool00?l00ol00?l50?ooo`Go003o
1P3oool4o`00oa<0oooo1ol00?l30?oooa7o003o9`3oool5o`00oaH0oooo1Ol00?l00`3ooooo003o
o`00o`07o`00o`H0oooo0ol00?l60?ooo`So003o0P3oool5o`00o`80oooo1Ol00?l;0?ooo`400000
0@3oool000030000003oool0oooo00_oo`003P3oool5ool000030?oooooo003oo`0000?oo`006P3o
ool7o`00o`H0oooo1ol00?l20?ooo`?o003o1`3oool3o`00oa40oooo0ol00?l70?ooo`?o003o00@0
ooooo`00ool00?oo003o1P3ooolAo`00oad0oooo0ol00?l40?ooo`So003o5P3oool5o`00o`030?oo
ool00?oo003o00Oo003o1@3oool5o`00o`@0oooo2Ol00?l30?ooo`?o003o0P3oool6o`00o`@0oooo
0ol00?l40?ooo`4000000@3oool000040000003oool0oooo0?ooo`?oo`000P3oool5ool000l0oooo
0ooo00020?ooo`Koo`006`3oool5o`00o`H0oooo1_l00?lP0?ooo`Go003o1@3oool5o`00o`T0oooo
2?l00?l40?ooo`Ko003o00<0ooooo`00ool00?l00ol00?l60?ooo`?o003o203oool3o`00o`030?oo
ool00?oo003o00go003o603oool3o`00o`<0oooo0ol00?l0103ooooo003oo`00ool00?l60?ooo`Go
003o103oool9o`00o`P0oooo1_l00?l00`3ooooo003oo`00o`05o`00o`<0oooo0@0000010?ooo`00
00<000000?ooo`3oool01`3oool3ool00180oooo2Ooo000B0?ooo`?o003o1`3oool3o`00o`P0oooo
0ol00?l40?ooo`?o003o6`3oool7o`00o`80oooo1_l00?l:0?ooo`Oo003o1@3oool=o`00o`<0oooo
1Ol00?l60?oooa7o003o0`3oool3o`00o`040?ooool00?oo003oo`00ob@0oooo1Ol00?l40?ooo`So
003o2@3oool5o`00o`030?ooool00?oo003o00Ko003o0`3oool100000040oooo00000`000000oooo
0?ooo`0=0?ooo`?oo`002`3oool:ool00140oooo1Ol00?l70?ooo`?o003o3@3oool5o`00oa80oooo
0ol00?l50?ooo`So003o00<0ooooo`00ool00?l01?l00?l70?ooo`?o003o0`3oool3o`00o`H0oooo
3_l00?l20?ooo`Go003o0P3oool3o`00o`030?ooool00?oo003o00oo003o0P3oool9o`00o`L0oooo
0ol00?lH0?ooo`Go003o1P3oool3o`00o`h0oooo0ol00?l20?ooo`So003o0`3oool100000040oooo
00001@00003oo`00ool00?oo0000oooo00?oo`001`3oool5ool000X0oooo1Ooo0000103oooooo`00
ool00?oo000B0?ooo`Go003o1P3oool5o`00o`<0oooo0ol00?l60?ooo`Go003o4@3oool5o`00o`D0
oooo3Ol00?l70?ooo`Go003o303oool3o`00o`030?ooool00?oo003o00Oo003o0P3oool5o`00o`03
0?ooool00?oo003o00So003o00<0ooooo`00ool00?l02?l00?l30?ooo`Wo003o1P3oool5o`00oaH0
oooo1Ol00?l70?ooo`?o003o403oool:o`00o`@0oooo0@0000010?ooo`002Ooo00040?ooo`Ooo`00
2P3oool5ool001H0oooo1Ol00?l30?ooo`So003o0P3oool5o`00o`D0oooo1Ol00?lA0?ooo`Go003o
1`3oool:o`00o`P0oooo1Ol00?l:0?ooo`?o003o103oool8o`00o`<0oooo0ol00?l00`3ooooo003o
o`00o`04o`00o`040?ooool00?oo003oo`00o`80oooo1_l00?l70?ooo`Wo003o1P3oool5o`00oaD0
oooo1_l00?l60?ooo`Go003o0`3oool3o`00o`P0oooo2ol00?l40?ooo`4000000@3oool000Woo`00
0`3oool8ool000/0oooo0ooo000F0?ooo`;oo`000ol00?l30?ooo`Wo003o0P3oool5o`00o`D0oooo
1Ol00?lA0?ooo`Go003o203oool7o`00o`X0oooo1Ol00?l90?ooo`Go003o1`3oool3o`00o`P0oooo
4?l00?l:0?ooo`?o003o00<0ooooo`00ool00?l00_l00?l60?ooo`Go003o4P3oool9o`00o`H0oooo
1Ol00?l00`3ooooo003oo`00o`04o`00o`<0oooo0ol00?l00`3ooooo003oo`00o`03o`00o`80oooo
1Ol00?l30?ooo`4000000@3oool000Woo`000`3oool8ool001T0oooo0ooo00080?ooo`Goo`000`3o
oolAo`00o`@0oooo1Ol00?l20?ooo`?o003o3@3oool3o`00o`/0oooo1Ol00?l50?ooo`?o003o0`3o
ool3o`00o`X0oooo1Ol00?lB0?ooo`Go003o00<0ooooo`00ool00?l02?l00?l90?ooo`[o003o1P3o
ool3o`00o`d0oooo0ol00?l20?ooo`Wo003o103oool@o`00o`030?ooool00?oo003o00So003o0P3o
ool5o`00o`<0oooo0@0000010?ooo`0000D00000ool00?oo003oo`000?ooo`05ool00080oooo1ooo
00060?ooo`?oo`00403oool5ool000L0oooo1Ooo00030?oooaCo003o00<0ooooo`00ool00?l00ol0
0?l00`3ooooo003oo`00o`03o`00oa/0oooo0ol00?l50?ooo`Go003o3`3oool5o`00o`80oooo0ol0
0?l>0?ooo`?o003o0P3oool:o`00o`T0oooo2_l00?lE0?ooo`Go003o00<0ooooo`00ool00?l01_l0
0?l40?ooo`So003o00<0ooooo`00ool00?l01_l00?l00`3ooooo003oo`00o`03o`00o`040?ooool0
0?oo003oo`00o`<0oooo1Ol00?l30?ooo`4000000@3oool000030000003oool0oooo00<0oooo1Ooo
00020?ooo`?oo`00203oool7ool000d0oooo1Ooo00040?ooo`?oo`0000@0ooooool00?oo003oo`00
1@3ooolDo`00o`040?ooool00?oo003oo`00o`80oooo1Ol00?l<0?ooo`?o003o503oool5o`00o`l0
oooo1Ol00?l00`3ooooo003oo`00o`03o`00oa80oooo1?l00?l20?ooo`?o003o2P3oool:o`00oaD0
oooo3Ol00?l50?ooo`Go003o103oool8o`00o`030?ooool00?oo003o00?o003o203oool3o`00o`@0
oooo0@0000010?ooo`0000<000000?ooo`3oool00`3oool5ool000040?oooooo003oo`00ool000T0
oooo2?oo000<0?ooo`Goo`000`3oool5ool000P0oooo5ol00?l20?ooo`Ko003o1@3oool3o`00o`<0
oooo1ol00?lA0?ooo`So003o303oool5o`00o`030?ooool00?oo003o00?o003o3`3oool7o`00o`h0
oooo2_l00?lF0?ooo`[o003o203oool5o`00o`D0oooo1_l00?l00`3ooooo003oo`00o`03o`00o`D0
oooo0ol00?l80?ooo`4000000@3oool000030000003oool0oooo00<0oooo2_oo00080?ooo`Soo`00
3@3oool3ool000@0oooo1Ooo00040?ooo`?o003o00<0ooooo`00ool00?l02Ol00?l40?ooo`oo003o
1@3oool5o`00o`80oooo2?l00?lA0?ooo`So003o00@0ooooo`00ool00?oo003o203oool3o`00o`80
oooo1Ol00?l60?ooo`?o003o1@3oool8o`00o`d0oooo3?l00?lE0?ooo`Wo003o2@3oool4o`00o`d0
oooo1Ol00?l40?ooo`So003o103oool100000040oooo00000`000000oooo0?ooo`040?ooo`?oo`00
00<0ooooool00?oo00000ooo00080?ooo`Soo`00503oool5ool000<0oooo4?l00?l50?ooo`ko003o
1@3oool5o`00o`80oooo2?l00?lB0?ooo`co003o1@3oool3o`00o`D0oooo0ol00?l60?ooo`Go003o
103oool8o`00o`X0oooo3ol00?lF0?ooo`So003o203oool5o`00o`d0oooo1Ol00?l40?ooo`Wo003o
0`3oool100000040oooo00000`000000oooo0?ooo`080?ooo`Goo`002@3oool6ool001H0oooo0ooo
00040?oooa7o003o1`3oool<o`00o`@0oooo1Ol00?l00`3ooooo003oo`00o`07o`00o`T0oooo0ol0
0?l60?ooo`co003o103oool5o`00o`d0oooo1Ol00?l40?ooo`[o003o00@0ooooo`00ool00?oo003o
0`3oool@o`00oaX0oooo0ol00?l90?ooo`Go003o3P3oool3o`00o`D0oooo2Ol00?l30?ooo`400000
0@3oool000030000003oool0oooo00T0oooo0ooo000<0?ooo`?oo`003`3oool3ool000`0oooo2?l0
0?l40?ooo`Go003o203oool3o`00o`030?ooool00?oo003o00Ko003o103oool9o`00o`040?ooool0
0?oo003oo`00o`T0oooo1Ol00?l60?ooo`_o003o103oool5o`00o`D0oooo0ol00?l50?ooo`Go003o
0`3oool5o`00o`80oooo2Ol00?l20?ooo`So003o0P3oool8o`00o`d0oooo0ol00?l?0?ooo`?o003o
0P3oool5o`00oaL0oooo2?l00?l30?ooo`4000000@3oool000030000003oool0oooo01L0oooo1Ooo
00070?ooo`?oo`000`3oool5ool000`0oooo1ol00?l40?ooo`Go003o2@3oool3o`00o`030?ooool0
0?oo003o00Ko003o103oool8o`00o`80oooo0ol00?l80?ooo`Go003o2`3oool5o`00o`D0oooo1Ol0
0?l40?ooo`Ko003o103oool3o`00o`@0oooo1Ol00?l20?ooo`Wo003o0P3oool5o`00o`D0oooo2Ol0
0?l30?ooo`Co003o103oool5o`00o`d0oooo2_l00?lL0?ooo`?o003o103oool100000040oooo0000
0`000000oooo0?ooo`0<0?ooo`?oo`00203oool5ool000H0oooo1Ooo00000`3oooooo`00ool00004
ool000l0oooo0ol00?l60?ooo`?o003o2@3oool5o`00o`80oooo1ol00?l30?ooo`So003o00<0oooo
o`00ool00?l01_l00?l40?ooo`Go003o303oool3o`00o`L0oooo1?l00?l40?ooo`Oo003o2P3oool5
o`00o`80oooo2Ol00?l30?ooo`?o003o1`3oool8o`00o`80oooo1_l00?l30?ooo`Go003o00@0oooo
o`00ool00?oo003o2@3oool:o`00ob<0oooo0@0000010?ooo`0000<000000?ooo`3oool02`3oool5
ool000L0oooo1Ooo00060?ooo`coo`00903oool5o`00o`<0oooo1_l00?l30?ooo`Oo003o0P3oool9
o`00o`@0oooo0ol00?l<0?ooo`?o003o203oool5o`00o`<0oooo1ol00?l:0?ooo`Go003o0`3oool3
o`00o`030?ooool00?oo003o00;o003o303oool3o`00o`030?ooool00?oo003o00?o003o0P3oool6
o`00o`<0oooo2_l00?l80?ooo`[o003o3`3oool3o`00oa40oooo0@0000010?ooo`0000<000000?oo
o`3oool02`3oool5ool000P0oooo0ooo00070?ooo`_oo`009@3oool5o`00o`@0oooo1Ol00?l40?oo
o`?o003o1@3oool9o`00o`d0oooo0ol00?l20?ooo`Go003o1P3oool6o`00o`80oooo2?l00?l;0?oo
o`?o003o103oool3o`00o`030?ooool00?oo003o00?o003o103oool3o`00o`<0oooo1Ol00?l0103o
oooo003oo`00ool00?l30?ooo`Ko003o103oool3o`00o`030?ooool00?oo003o00?o003o2@3oool8
o`00o`l0oooo1Ol00?l@0?ooo`4000000@3oool000040000003oool0oooo0?ooo`?oo`001`3oool5
ool001<0oooo0ooo00000`3oooooo`00ool00003ool00140oooo0ol00?lC0?ooo`?o003o1P3oool3
o`00o`h0oooo2?l00?l<0?ooo`Go003o00<0ooooo`00ool00?l00ol00?l50?ooo`Oo003o00<0oooo
o`00ool00?l01_l00?lB0?ooo`[o003o0`3oool5o`00o`80oooo1Ol00?l80?ooo`Co003o103oool3
o`00o`80oooo1Ol00?l;0?ooo`Go003o403oool5o`00oa00oooo0@0000010?ooo`0000<000000?oo
o`3oool01Ooo00070?ooo`?oo`006@3oool3ool00080oooo0ooo000<0?ooo`Go003o<03oool3o`00
o`X0oooo2?l00?l00`3ooooo003oo`00o`03o`00o`80oooo2Ol00?l20?ooo`Go003o1@3oool3o`00
o`d0oooo2_l00?l20?ooo`Ko003o0P3oool5o`00o`80oooo0ol00?l:0?ooo`Go003o0P3oool3o`00
o``0oooo1Ol00?l40?ooo`?o003o2@3oool5o`00o`H0oooo0ol00?l30?ooo`?o003o0@3oool10000
0040oooo00000`000000oooo0?ooo`05ool000H0oooo1Ooo000L0?ooo`Goo`002`3oool5o`00o`l0
oooo0ol00?lZ0?oooaWo003o0`3oool5o`00o`80oooo1ol00?l90?ooo`So003o00@0ooooo`00ool0
0?oo003o0`3oool6o`00o`<0oooo0ol00?l20?ooo`Go003o2@3oool5o`00oa40oooo1Ol00?l30?oo
o`Go003o2@3oool3o`00o`H0oooo1Ol00?l00`3ooooo003oo`00o`03o`00o`4000000@3oool00003
0000003oool0oooo00Goo`000`3oool:ool001X0oooo1Ooo000;0?ooo`Go003o3P3oool5o`00obT0
oooo6Ol00?l40?ooo`?o003o0P3oool8o`00o`P0oooo2?l00?l50?ooo`So003o2@3oool7o`00o`L0
oooo1Ol00?lB0?ooo`?o003o103oool5o`00oa80oooo1Ol00?l00`3ooooo003oo`00o`03o`00o`40
00000@3oool000040000003oool0oooo0?ooo`?oo`000`3oool<ool001T0oooo1_oo000;0?ooo`?o
003o0`3oool3o`00o`H0oooo2?l00?lY0?oooaSo003o2P3oool9o`00o`D0oooo1ol00?l20?ooo`?o
003o0P3oool8o`00o`X0oooo2?l00?l70?ooo`?o003o6P3oool5o`00oa80oooo2ol00?l100000040
oooo00000`000000oooo0?ooo`070?ooo`coo`006P3oool6ool000l0oooo1Ol00?l30?ooo`[o003o
:03ooolHo`00o`/0oooo3?l00?l00`3ooooo003oo`00o`06o`00o`030?ooool00?oo003o00?o003o
00<0ooooo`00ool00?l00ol00?l>0?ooo`Oo003o3`3oool3o`00oa<0oooo0ol00?lC0?ooo`[o003o
0@3oool100000040oooo00000`000000oooo0?ooo`070?ooo`Goo`000P3oool5ool001/0oooo1Ooo
000>0?ooo`Ko003o0P3oool:o`00o`80oooo0ol00?l>0?ooo`?o003o4`3oool;o`00o`030?ooool0
0?oo003o00Wo003o00<0ooooo`00ool00?l00_l00?l80?ooo`?o003o00<0ooooo`00ool00?l05?l0
0?l00`3ooooo003oo`00o`03o`00o``0oooo0ol00?l00`3ooooo003oo`00o`03o`00o`h0oooo1Ol0
0?l<0?ooo`?o003o3@3oool3o`00o`X0oooo1ol00?l30?ooo`4000000@3oool000030000003oool0
oooo00@0oooo0ooo0000103oooooo`00ool00?oo00040?ooo`?oo`001@3oool3ool000P0oooo1?oo
00080?ooo`Goo`000`3oool3ool000L0oooo1ol00?l20?ooo`Oo003o103oool6o`00o`/0oooo1Ol0
0?lB0?ooo`_o003o00<0ooooo`00ool00?l01Ol00?l40?ooo`Ko003o2`3oool=o`00o`030?ooool0
0?oo003o00_o003o303oool:o`00o`<0oooo0ol00?l80?ooo`So003o203oool5o`00o`/0oooo1Ol0
0?l;0?ooo`Oo003o0@3oool100000040oooo00000`000000oooo0?ooo`030?ooo`Goo`003P3oool5
ool000H0oooo1_oo00080?ooo`?oo`000`3oool5ool000H0oooo1ol00?l20?ooo`Ko003o1@3oool7
o`00o`<0oooo1_l00?l00`3ooooo003oo`00o`03o`00oa<0oooo0ol00?l00`3ooooo003oo`00o`05
o`00o`040?ooool00?oo003oo`00o`D0oooo2?l00?l<0?ooo`Oo003o00@0ooooo`00ool00?oo003o
0P3oool;o`00o`h0oooo2_l00?l20?ooo`Go003o1`3oool9o`00o`80oooo0ol00?l20?ooo`Go003o
103oool3o`00o`@0oooo1Ol00?l<0?ooo`Oo003o0@0000010?ooo`0000<000000?ooo`3oool00`3o
ool5ool000h0oooo1Ooo00050?ooo`Ooo`002@3oool3ool00080oooo1Ooo00060?ooo`Oo003o0`3o
ool3o`00o`<0oooo0ol00?l00`3ooooo003oo`00o`05o`00o`80oooo3Ol00?l@0?ooo`Go003o103o
ool5o`00o`P0oooo2Ol00?l<0?ooo`Ko003o00<0ooooo`00ool00?l00ol00?l00`3ooooo003oo`00
o`09o`00o`h0oooo2_l00?l20?ooo`Go003o203oool>o`00o`030?ooool00?oo003o00_o003o0`3o
ool5o`00o`h0oooo1Ol00?l100000040oooo00000`000000oooo0?ooo`030?ooo`Goo`003P3oool5
ool000@0oooo2?oo00080?ooo`Goo`0000<0ooooool00?oo00000ooo00070?ooo`Ko003o0P3oool5
o`00o`030?ooool00?oo003o00?o003o00<0ooooo`00ool00?l01?l00?l20?ooo`So003o00<0oooo
o`00ool00?l01?l00?l=0?ooo`Oo003o0`3oool6o`00o`L0oooo2Ol00?l50?ooo`?o003o00<0oooo
o`00ool00?l01ol00?l00`3ooooo003oo`00o`03o`00o`030?ooool00?oo003o00Wo003o1@3oool3
o`00o`L0oooo0ol00?l00`3ooooo003oo`00o`02o`00o`<0oooo1_l00?l:0?ooo`_o003o0P3oool<
o`00o`@0oooo0ol00?l?0?ooo`Go003o0@0000010?ooo`0000<000000?ooo`3oool0103oool3ool0
0100oooo0ooo00001@3oooooo`00ool00?oo0000oooo00Ooo`002@3oool5ool00080oooo0ooo000:
0?ooo`?o003o0`3oool5o`00o`030?ooool00?oo003o00?o003o0`3oool3o`00o`<0oooo2Ol00?l2
0?ooo`Go003o303oool7o`00o`@0oooo1Ol00?l70?ooo`[o003o0`3oool=o`00o`030?ooool00?oo
003o00oo003o1@3oool5o`00o`040?ooool00?oo003oo`00o`D0oooo1Ol00?l40?ooo`Ko003o103o
ool3o`00o`<0oooo2_l00?l50?ooo`Wo003o5`3oool3o`00o`40oooo0@0000010?ooo`0000<00000
0?ooo`3oool06P3oool:ool000/0oooo1Ooo00050?ooo`?o003o3@3oool5o`00o`030?ooool00?oo
003o00?o003o2P3oool8o`00o`80oooo1Ol00?l<0?ooo`Oo003o103oool5o`00o`80oooo0ol00?l3
0?ooo`?o003o00<0ooooo`00ool00?l00ol00?l30?ooo`co003o00<0ooooo`00ool00?l03Ol00?l8
0?ooo`[o003o103oool6o`00o`@0oooo3Ol00?l30?ooo`So003o1P3oool8o`00oa`0oooo0@000001
0?ooo`0000<000000?ooo`3oool0103oool3ool001<0oooo1Ooo0000103oooooo`00ool00?oo000=
0?ooo`?oo`001@3oool5o`00o`d0oooo0ol00?l30?ooo`?o003o3@3oool6o`00o`80oooo1Ol00?l=
0?ooo`Go003o1P3oool3o`00o`80oooo1Ol00?l60?ooo`Go003o0P3oool=o`00o`030?ooool00?oo
003o00co003o2@3oool:o`00o`@0oooo1_l00?l40?ooo`go003o103oool3o`00o`H0oooo2?l00?l9
0?ooo`?o003o503oool100000040oooo00000`000000oooo0?ooo`030?ooo`Goo`004P3oool5ool0
01D0oooo0ooo00000`3ooooo003oo`00o`03o`00o`@0oooo0ol00?l30?ooo`Oo003o00@0ooooo`00
ool00?oo003o3@3oool6o`00o`@0oooo0ol00?lN0?ooo`Go003o1`3oool3o`00o`<0oooo1Ol00?l0
0`3ooooo003oo`00o`05o`00o`030?ooool00?oo003o00Wo003o1P3oool6o`00o`050?ooool00?oo
003oo`00o`3oool01Ol00?l50?ooo`Go003o1@3oool<o`00o``0oooo1ol00?l:0?ooo`Go003o4`3o
ool100000040oooo00000`000000oooo0?ooo`030?ooo`Goo`004`3oool3ool000T0oooo0ooo0009
0?ooo`Goo`001Ol00?l30?ooo`Go003o00<0ooooo`00ool00?l02ol00?l<0?ooo`Go003o9P3oool5
o`00o`T0oooo0ol00?l00`3ooooo003oo`00o`03o`00o`@0oooo0ol00?l30?ooo`?o003o0P3oool3
o`00o`L0oooo2?l00?l50?ooo`?o003o1`3oool3o`00o`T0oooo2Ol00?l<0?ooo`Oo003o2P3oool5
o`00oa<0oooo0@0000010?ooo`0000<000000?ooo`3oool00`3oool5ool000`0oooo0ooo000?0?oo
o`Goo`00203oool5ool000050?ooool00?oo003oo`00o`3oool02?l00?l00`3ooooo003oo`00o`0;
o`00o`L0oooo0ol00?l20?ooo`Go003o2P3oool3o`00o`d0oooo1?l00?l90?ooo`Go003o1`3oool5
o`00o`040?ooool00?oo003oo`00oaX0oooo2?l00?l=0?ooo`?o003o2`3oool4o`00o`030?ooool0
0?oo003o00?o003o103oool3o`00o`@0oooo1ol00?l:0?ooo`Go003o4`3oool100000040oooo0000
0`000000oooo0?ooo`040?ooo`?oo`00303oool5ool000L0oooo0ooo00040?ooo`Goo`00203oool5
ool000@0oooo2Ol00?l00`3ooooo003oo`00o`0;o`00o`030?ooool00?oo003o00So003o0P3oool3
o`00o`X0oooo1_l00?l20?ooo`?o003o103oool7o`00o`T0oooo1Ol00?l60?ooo`Go003o0`3oool3
o`00oaL0oooo2Ol00?l<0?ooo`Go003o2@3oool;o`00o`<0oooo1Ol00?l30?ooo`So003o0`3oool3
o`00o`@0oooo0ol00?lD0?ooo`4000000@3oool000030000003oool0oooo00T0oooo0ooo00060?oo
o`Koo`001P3oool5ool000<0oooo1Ooo00090?ooo`?oo`001@3oool9o`00o`80oooo0ol00?l20?oo
o`Ko003o00<0ooooo`00ool00?l02Ol00?l40?ooo`?o003o00@0ooooo`00ool00?oo003o103oool<
o`00o`80oooo2_l00?l70?ooo`Go003o0_oo00040?ooo`Go003o0P3oool5o`00oaH0oooo2?l00?l2
0?ooo`?oo`00203oool5o`00o`T0oooo2ol00?l30?ooo`Go003o0`3oool?o`00o`l0oooo0ol00?l8
0?ooo`4000000@3oool000030000003oool0oooo00<0oooo0ooo00020?ooo`Goo`001@3oool6ool0
00H0oooo1Ooo00040?ooo`?oo`002@3oool3ool000H0oooo2_l00?l60?ooo`Go003o0P3oool;o`00
o`<0oooo2Ol00?l30?ooo`co003o0P3oool;o`00o`H0oooo1Ol00?l3ool000@0oooo0ol00?l30?oo
o`Go003o5P3oool5o`00o`@0oooo1Ooo00070?ooo`Go003o2@3oool:o`00o`@0oooo1Ol00?l40?oo
o`ko003o3P3oool5o`00o`L0oooo0@0000010?ooo`0000<000000?ooo`3oool00P3oool5ool00003
0?oooooo003oo`0000?oo`001@3oool7ool000D0oooo1Ooo000?0?ooo`Goo`001P3oool3o`00o`03
0?ooool00?oo003o00?o003o1`3oool3o`00o`03ool0003oool0oooo00[o003o103oool9o`00o`@0
oooo2ol00?l20?ooo`_o003o1`3oool3o`00o`Coo`002P3oool5o`00oaL0oooo0ol00?l40?ooo`Ko
o`00203oool3o`00o`?oo`00203oool8o`00o`H0oooo0ol00?l80?ooo`_o003o1P3oool3o`00o`@0
oooo1_l00?l70?ooo`4000000@3oool000030000003oool0oooo0080oooo2ooo00060?ooo`Koo`00
1P3oool3ool00100oooo1Ooo000:0?ooo`Go003o1`3oool5ool00080oooo1_l00?l70?ooo`Wo003o
1P3oool3o`00o`80oooo0ol00?l40?ooo`?o003o0_oo0005o`00o`T0oooo1Ooo000;0?ooo`?o003o
7P3oool7ool000X0oooo1Ooo00040?ooo`?oo`000`3oool5o`00oa40oooo2_l00?l40?ooo`Oo003o
0P3oool7o`00o`L0oooo0@0000010?ooo`0000<000000?ooo`3oool00P3oool:ool000P0oooo1Ooo
000I0?ooo`Goo`002`3oool3o`00o`P0oooo1Ooo00030?ooo`Goo`001`3oool01Ooo003o003oo`00
ool00?l0oooo00?o003o5@3oool4ool000?o003o2`3oool3ool002d0oooo1_oo00050?ooo`?oo`00
0`3oool5ool000<0oooo1Ooo00030?ooo`?o003o2`3oool3o`00o`<0oooo1ol00?l70?ooo`So003o
0P3oool6o`00o`P0oooo0@0000010?ooo`0000<000000?ooo`3oool00`3oool8ool000T0oooo1Ooo
000J0?ooo`?oo`003`3oool3ool000D0oooo1Ooo00020?ooo`Ooo`001@3oool5ool001X0oooo0ooo
000j0?ooo`?oo`0000<0ooooool00?oo00000ooo00050?ooo`Goo`000P3oool5ool000<0oooo1Ooo
0000103oooooo`00ool00?oo00070?ooo`?o003o0P3oool5o`00o`80oooo1Ol00?l90?ooo`So003o
0P3oool5o`00o`T0oooo0@0000010?ooo`0000<000000?ooo`3oool01P3oool5ool000T0oooo1Ooo
00080?ooo`?oo`001@3oool3ool000l0oooo0ooo00060?ooo`Goo`001@3oool3ool000<0oooo1ooo
00050?ooo`Goo`00403oool3ool004<0oooo1Ooo00001@3oooooo`00ool00?oo0000oooo00?oo`00
0P3oool5ool000<0oooo0ooo00040?ooo`[oo`001@3oool5o`00o`030?ooool00?oo003o00?o003o
0P3oool5o`00o`T0oooo1ol00?l40?ooo`?o003o2P3oool100000040oooo00000`000000oooo0?oo
o`050?ooo`Goo`002`3oool3ool000P0oooo1Ooo00030?ooo`Goo`003@3oool?ool000/0oooo1ooo
00050?ooo`Goo`003`3oool5ool001X0oooo0ooo00030?ooo`?oo`00403oool3ool000`0oooo1Ooo
00040?ooo`Goo`0000<0ooooool00?oo00000ooo00090?ooo`Soo`001Ol00?l30?ooo`Go003o00<0
ooooo`00ool00?l00ol00?l30?ooo`?o003o2`3oool6o`00o``0oooo0ol00?l20?ooo`4000000@3o
ool000030000003oool0oooo00D0oooo1Ooo0000103oooooo`00ool00?oo00070?ooo`?oo`001`3o
ool6ool000<0oooo1Ooo000=0?ooo`ooo`00303oool5ool000L0oooo1Ooo000>0?ooo`Goo`006@3o
ool5ool000030?oooooo003oo`0000?oo`003P3oool5ool000D0oooo0ooo00030?ooo`Goo`00103o
ool5ool00080oooo0ooo000:0?ooo`Ooo`002?l00?l00`3ooooo003oo`00o`03o`00o`030?ooool0
0?oo003o00;o003o4@3oool7o`00o`P0oooo2?l00?l10?ooo`4000000@3oool000030000003oool0
oooo00D0oooo2_oo00050?ooo`Goo`001P3oool6ool000<0oooo1Ooo000=0?ooo`koo`0000@0oooo
ool00?oo003oo`005@3oool5ool00080oooo0ooo00090?ooo`Goo`003`3oool3ool000L0oooo1Ooo
00000`3oooooo`00ool00003ool000h0oooo1Ooo00040?ooo`Goo`000`3oool3ool000D0oooo1Ooo
00040?ooo`?oo`00203oool7ool000Wo003o00D0ooooo`00ool00?oo003o0?ooo`06o`00o`l0oooo
1ol00?l80?ooo`Wo003o0@3oool100000040oooo00000`000000oooo0?ooo`060?ooo`?oo`0000<0
ooooool00?oo00000ooo00050?ooo`Goo`001P3oool5ool000@0oooo1Ooo000>0?ooo`[oo`000`3o
ool5ool000l0oooo0ooo00020?ooo`Goo`0000<0ooooool00?oo00000ooo00090?ooo`?oo`003`3o
ool5ool000H0oooo1Ooo00000`3oooooo`00ool00003ool000h0oooo1Ooo00040?ooo`Goo`002@3o
ool6ool000030?oooooo003oo`0000Koo`00203oool6ool000Wo003o1@3oool7o`00o`h0oooo1ol0
0?l80?ooo`Wo003o0@3oool100000040oooo00000`000000oooo0?ooo`0:0?ooo`Goo`001@3oool5
ool000<0oooo0ooo0000103oooooo`00ool00?oo00050?ooo`Goo`00403oool7ool000@0oooo1Ooo
000>0?ooo`Goo`000P3oool3ool00080oooo1Ooo000<0?ooo`?oo`002`3oool6ool000@0oooo1ooo
00020?ooo`?oo`0000@0ooooool00?oo003oo`00303oool3ool000D0oooo1Ooo00080?ooo`Goo`00
0P3oool9ool000`0oooo0ooo0008o`00o`D0oooo1ol00?l>0?ooo`Oo003o203oool8o`00o`80oooo
0@0000010?ooo`0000<000000?ooo`3oool02`3oool3ool000H0oooo1Ooo00020?ooo`Goo`00203o
ool5ool00140oooo0ooo00070?ooo`Goo`002`3oool8ool000L0oooo1Ooo000;0?ooo`Goo`002@3o
ool7ool000<0oooo2?oo00050?ooo`Goo`001@3oool3ool000`0oooo0ooo00090?ooo`Goo`000P3o
ool9ool00180oooo1Ol00?l60?ooo`Oo003o3P3oool7o`00o`@0oooo0ol00?l00`3ooooo003oo`00
o`02o`00o`D0oooo0@0000010?ooo`0000<000000?ooo`3oool0503oool6ool000030?oooooo003o
o`0000?oo`002@3oool3ool001d0oooo0ooo000;0?ooo`Woo`00203oool3ool000`0oooo1Ooo0009
0?ooo`Ooo`000`3oool8ool000D0oooo1Ooo00040?ooo`Ooo`005@3oool?ool00080oooo0ooo0005
0?ooo`?oo`001P3oool5o`00o`L0oooo1ol00?l0103ooooo003oo`00ool00?l;0?ooo`Go003o0`3o
ool6o`00o`P0oooo0@0000010?ooo`0000<000000?ooo`3oool00ooo00050?ooo`?oo`002@3oool6
ool000030?oooooo003oo`0000?oo`008`3oool3ool00140oooo2?oo000H0?ooo`Goo`002@3oool7
ool000<0oooo1ooo00060?ooo`Goo`00103oool8ool00100oooo0ooo00020?ooo`[oo`001@3oool5
ool000<0oooo1Ooo00060?ooo`?o003o1@3oool?o`00o`X0oooo1Ol00?l30?ooo`[o003o103oool1
00000040oooo00000`000000ooooool00004ool000<0oooo1Ooo00090?ooo`Goo`000P3oool3ool0
01P0oooo0ooo00030?ooo`?oo`000P3oool5ool00100oooo1Ooo000J0?ooo`Ooo`002@3oool6ool0
00@0oooo0ooo000:0?ooo`?oo`001@3oool8ool000l0oooo1Ooo00030?ooo`Goo`00203oool5ool0
00<0oooo1Ooo000=0?oooa3o003o2`3oool3o`00o`@0oooo2ol00?l30?ooo`4000000@3oool00003
0000003oooooo`0000Coo`000`3oool5ool000X0oooo0ooo000M0?ooo`Goo`0000<0ooooool00?oo
00000ooo00000`3oooooo`00ool00003ool00140oooo0ooo000C0?ooo`?oo`001@3oool8ool000T0
oooo1ooo000H0?ooo`Ooo`001`3oool3ool000D0oooo1Ooo00030?ooo`Goo`00203oool7ool00003
0?oooooo003oo`0000?oo`003@3oool:o`00o`030?ooool00?oo003o00?o003o1`3oool8o`00o`@0
oooo2_l00?l30?ooo`4000000@3oool000030000003oooooo`0000Coo`000`3oool5ool002X0oooo
1Ooo00000`3oooooo`00ool00003ool000030?oooooo003oo`0000?oo`00403oool3ool001<0oooo
1Ooo00040?ooo`Soo`002P3oool7ool001X0oooo1Ooo00050?ooo`Goo`00103oool5ool000@0oooo
0ooo000:0?ooo`Ooo`0000@0ooooool00?oo003oo`00303oool7o`00o`040?ooool00?oo003oo`00
o`<0oooo0ol00?l70?ooo`Wo003o1@3oool9o`00o`<0oooo0@0000010?ooo`0000<000000?ooo`3o
ool00ooo00040?ooo`Goo`00:P3oool5ool000030?oooooo003oo`0000?oo`000P3oool3ool00100
oooo1_oo000A0?ooo`Soo`000P3oool7ool000`0oooo1Ooo00060?ooo`?oo`00303oool3ool00080
oooo1Ooo00050?ooo`Goo`001@3oool3ool001@0oooo1Ooo000?0?ooo`Oo003o3P3oool=o`00o`H0
oooo0ol00?l0103ooooo003oo`00ool00?l40?ooo`4000000@3oool000030000003oooooo`0000;o
o`001@3oool7ool001h0oooo1_oo00040?ooo`Goo`000P3oool3ool001H0oooo1ooo000@0?ooo`Wo
o`00103oool3ool000d0oooo1Ooo00050?ooo`Goo`002P3oool5ool000030?oooooo003oo`0000?o
o`001@3oool5ool001`0oooo1Ooo000?0?ooo`Go003o3`3oool?o`00oa00oooo0@0000010?ooo`00
00<00000ool00?oo00000ooo00040?ooo`Soo`002@3oool3ool00080oooo0ooo00070?ooo`?oo`00
00<0ooooool00?oo00001_oo00030?ooo`Goo`002@3oool3ool000l0oooo1ooo000?0?ooo`[oo`00
1`3oool3ool000L0oooo1ooo00060?ooo`Goo`002P3oool<ool000D0oooo0ooo000;0?ooo`Goo`00
1@3oool3ool000H0oooo0ooo000@0?ooo`Go003o3P3oool:o`00o`80oooo1Ol00?l?0?ooo`400000
0@3oool0000300000?oo003oo`0000?oo`001@3oool7ool000P0oooo2_oo00050?ooo`goo`000`3o
ool5ool000P0oooo1Ooo00020?ooo`Goo`001@3oool9ool000h0oooo2ooo00060?ooo`Goo`001@3o
ool8ool000H0oooo1Ooo00060?ooo`?oo`0000<0ooooool00?oo00002ooo00050?ooo`?oo`001`3o
ool9ool000<0oooo1Ooo00080?ooo`?oo`003P3oool3o`00o`h0oooo2_l00?l30?ooo`Go003o3`3o
ool100000040oooo00000`00003oo`00ool00003ool000L0oooo1Ooo00080?ooo`_oo`00103oool=
ool000@0oooo0ooo00090?ooo`Goo`0000<0ooooool00?oo00001Ooo00030?ooo`Goo`0000<0oooo
ool00?oo00000ooo00080?ooo`?oo`000P3oool:ool000L0oooo1Ooo00020?ooo`_oo`001`3oool3
ool000H0oooo1Ooo00000`3oooooo`00ool0000:ool000@0oooo1Ooo00050?ooo`[oo`000`3oool6
ool000H0oooo1Ooo000<0?ooo`Go003o2@3oool3o`00o`030?ooool00?oo003o00[o003o00<0oooo
o`00ool00?l00ol00?l?0?ooo`4000000@3oool000030000003oooooo`0000;oo`002@3oool5ool0
00L0oooo2ooo00040?ooo`Goo`0000<0ooooool00?oo00001?oo000A0?ooo`goo`000`3oool5ool0
0080oooo1Ooo00060?ooo`Goo`0000<0ooooool00?oo00001Ooo000:0?ooo`Goo`0000<0ooooool0
0?oo00002Ooo000A0?ooo`Goo`000`3oool;ool00080oooo1_oo00050?ooo`[oo`000`3oool7ool0
00D0oooo1Ooo000<0?ooo`Go003o203oool:o`00o`<0oooo1Ol00?l00`3ooooo003oo`00o`04o`00
o`d0oooo0@0000010?ooo`0000<000000?ooo`3oool02`3oool5ool000P0oooo0ooo00020?ooo`Go
o`001@3oool3ool001X0oooo3?oo00000`3oooooo`00ool00005ool00080oooo1Ooo00050?ooo`Ko
o`000P3oool3ool000h0oooo0ooo00020?ooo`Soo`0000@0ooooool00?oo003oo`00403oool5ool0
00@0oooo0ooo00020?ooo`goo`001@3oool<ool00080oooo1_oo00050?ooo`Ooo`002P3oool5o`00
o`P0oooo1Ol00?l0103ooooo003oo`00ool00?l40?ooo`Go003o0`3oool5o`00o`<0oooo0ol00?l6
0?ooo`4000000@3oool000030000003oool0oooo0080oooo0ooo00060?ooo`Goo`003P3oool3ool0
02@0oooo2_oo00000`3oooooo`00ool00005ool000<0oooo1ooo00030?ooo`Koo`0000@0ooooool0
0?oo003oo`00503oool5ool000<0oooo1Ooo000?0?ooo`Coo`002P3oool<ool000L0oooo0ooo0004
0?ooo`coo`001P3oool8ool000L0oooo1Ol00?l90?ooo`Go003o1P3oool?o`00o`80oooo1Ol00?l5
0?ooo`4000000@3oool000040000003oool0oooo0?ooo`Goo`0000@0ooooool00?oo003oo`000P3o
ool3ool001`0oooo0ooo000G0?oooa3oo`001P3oool7ool00080oooo1Ooo00000`3oooooo`00ool0
0003ool001@0oooo0ooo00040?ooo`Goo`003P3oool5ool000X0oooo3Ooo000=0?ooo`goo`001`3o
ool7ool000H0oooo1Ol00?l:0?ooo`?o003o1P3oool@o`00o`80oooo1Ol00?l50?ooo`4000000@3o
ool000040000003oool0oooo0?ooo`[oo`005`3oool3ool000D0oooo1Ooo00020?ooo`?oo`004@3o
ool5ool000030?oooooo003oo`0000Soo`00203oool5ool000<0oooo0ooo00020?ooo`Goo`00303o
ool3ool000`0oooo1Ooo000>0?ooo`Goo`002`3oool4ool00080oooo1_oo000=0?ooo`goo`001`3o
ool7ool000H0oooo1Ol00?lC0?ooo`oo003o0`3oool5o`00o`D0oooo0@0000010?ooo`0000@00000
0?ooo`3oool0oooo2_oo00050?ooo`?oo`003P3oool5ool000@0oooo1Ooo00000`3oooooo`00ool0
0003ool00140oooo0ooo00020?ooo`Goo`0000@0ooooool00?oo003oo`002@3oool5ool000P0oooo
1Ooo00080?ooo`Soo`00303oool3ool000l0oooo1Ooo000B0?ooo`Goo`003P3oool<ool000P0oooo
1_oo00070?ooo`Go003o4P3oool?o`00o`<0oooo1Ol00?l50?ooo`4000000@3oool000030000003o
ool0oooo0080oooo0ooo00000`3oooooo`00ool00004ool000<0oooo1Ooo000=0?ooo`Goo`00103o
ool5ool000030?oooooo003oo`0000?oo`005`3oool3ool000l0oooo0ooo000:0?ooo`?oo`00203o
ool9ool001l0oooo0ooo000;0?ooo`?oo`000P3oool3ool000040?oooooo003oo`00ool00180oooo
2?oo000;0?ooo`?oo`00203oool5o`00o`h0oooo0ol00?l20?ooo`go003o1@3oool3o`00o`H0oooo
0@0000010?ooo`0000<000000?ooo`3oool01`3oool6ool00080oooo1Ooo000=0?ooo`Goo`001@3o
ool3ool000030?oooooo003oo`0000Coo`00:03oool3ool001H0oooo2Ooo000/0?ooo`[oo`00603o
ool4ool001L0oooo1Ol00?l70?ooo`?o003o0`3oool5o`00o`D0oooo0ol00?l00`3ooooo003oo`00
o`04o`00o`<0oooo1Ol00?l50?ooo`4000000@3oool000040000003oool0oooo0?ooo`Goo`0000<0
ooooool00?oo00001?oo00020?ooo`Goo`003P3oool3ool000X0oooo1Ooo000X0?ooo`Ooo`00103o
ool3ool000`0oooo2?oo000M0?ooo`?oo`003@3oool:ool00180oooo0ooo00020?ooo`Goo`00603o
ool3o`00o`L0oooo3?l00?l90?ooo`Oo003o0P3oool5o`00o`D0oooo0@0000010?ooo`0000<00000
0?ooo`3oool03Ooo00030?ooo`?oo`00703oool5ool002P0oooo2?oo00020?ooo`Goo`00303oool3
ool00200oooo1Ooo000<0?ooo`[oo`003`3oool7ool000030?oooooo003oo`0000Coo`008@3oool<
o`00o`D0oooo0ol00?l20?ooo`Ko003o0P3oool5o`00o`D0oooo0@0000010?ooo`0000<000000?oo
o`3oool01ooo00000`3oooooo`00ool00002ool002@0oooo0ooo000Y0?ooo`Soo`000P3oool5ool0
02l0oooo1Ooo000=0?ooo`Soo`003`3oool8ool000030?oooooo003oo`0000Coo`000P3oool3ool0
01<0oooo0ol00?l60?ooo`ko003o0P3oool5o`00o`80oooo1Ol00?l30?ooo`?o003o1P3oool10000
0040oooo00000`000000oooo0?ooo`09ool004`0oooo0ooo00050?ooo`Ooo`000P3oool5ool00100
oooo0ooo000L0?ooo`Goo`001P3oool3ool000@0oooo1Ooo000B0?ooo`Soo`000P3oool5ool00003
0?oooooo003oo`0000?oo`004@3oool5o`00o`H0oooo2?l00?l00`3ooooo003oo`00o`03o`00o`03
0?ooool00?oo003o00Wo003o3@3oool100000040oooo000010000000oooo0?ooo`3oool9ool003d0
oooo0ooo000:0?ooo`Koo`001P3oool3ool000@0oooo0ooo0000103oooooo`00ool00?oo000<0?oo
o`Goo`00703oool3ool000H0oooo1Ooo00030?ooo`Goo`004P3oool7ool000@0oooo0ooo00020?oo
o`Goo`002@3oool3o`00o`D0oooo1Ol00?l:0?ooo`?o003o0P3oool5o`00o`030?ooool00?oo003o
00[o003o303oool100000040oooo00000`000000oooo0?ooo`020?ooo`Soo`00:`3oool3ool000h0
oooo1Ooo00090?ooo`Ooo`003`3oool5ool000/0oooo1_oo000G0?ooo`?oo`002P3oool5ool000@0
oooo0ooo00040?ooo`?oo`003@3oool5ool000X0oooo1Ooo00080?ooo`Go003o103oool5o`00o`l0
oooo1Ol00?l20?ooo`_o003o303oool100000040oooo00000`000000oooo0?ooo`020?ooo`Soo`00
:P3oool5ool000L0oooo0ooo00030?ooo`Goo`002@3oool7ool000030?oooooo003oo`0000Coo`00
203oool5ool000/0oooo1_oo000F0?ooo`Goo`002@3oool5ool000T0oooo1_oo00030?ooo`?oo`00
1`3oool5ool00080oooo0ooo00050?ooo`?oo`002@3oool5o`00o`D0oooo1_l00?l>0?ooo`?o003o
103oool:o`00o`H0oooo1Ol00?l10?ooo`4000000@3oool000030000003oool0oooo00<0oooo1_oo
000H0?ooo`?oo`00403oool5ool00080oooo0ooo00000`3oooooo`00ool00003ool00080oooo1Ooo
000:0?ooo`koo`001P3oool6ool000`0oooo1Ooo000F0?ooo`Goo`002P3oool3ool000T0oooo1ooo
00020?ooo`Goo`001P3oool5ool000030?oooooo003oo`0000?oo`00403oool5o`00o`L0oooo1Ol0
0?lF0?ooo`So003o1@3oool7o`00o`4000000@3oool000030000003oool0oooo0200oooo1Ooo000<
0?ooo`Soo`0000<0ooooool00?oo00002?oo00030?ooo`?oo`003@3oool3ool000030?oooooo003o
o`0000Koo`001P3oool5ool000D0oooo0ooo00060?ooo`?oo`005`3oool5ool001H0oooo1ooo0002
0?ooo`Goo`001P3oool5ool000030?oooooo003oo`0000?oo`002`3oool3ool000<0oooo0ol00?l8
0?ooo`Go003o403oool3o`00o`030?ooool00?oo003o00Wo003o103oool7o`00o`4000000@3oool0
00030000003oool0oooo0200oooo1Ooo000;0?ooo`Soo`000P3oool:ool001L0oooo2?oo00040?oo
o`Ooo`00103oool5ool00200oooo0ooo000G0?ooo`Koo`000P3oool6ool000L0oooo0ooo00020?oo
o`Goo`000P3oool3ool000D0oooo1Ooo000=0?ooo`Go003o3`3oool9o`00o`80oooo1Ol00?l40?oo
o`Oo003o0@0000010?ooo`0000<000000?ooo`3oool07`3oool6ool000/0oooo1Ooo00040?ooo`[o
o`006@3oool6ool000@0oooo1ooo00050?ooo`Goo`00>`3oool3ool000@0oooo1Ooo000>0?ooo`[o
o`00103oool5ool000h0oooo1?l00?l?0?ooo`Wo003o0P3oool5o`00o`D0oooo1Ol00?l10?ooo`40
00000@3oool000030000003oool0oooo00<0oooo0ooo000I0?ooo`Goo`00303oool5ool000<0oooo
2ooo000S0?ooo`Goo`001`3oool5ool002L0oooo0ooo000H0?ooo`Goo`00203oool3ool000<0oooo
2_oo00040?ooo`Goo`003P3oool5o`00o`h0oooo2Ol00?l30?ooo`?o003o1`3oool5o`00o`400000
0@3oool000030000003oool0oooo0080oooo1Ooo000;0?ooo`Ooo`001P3oool5ool000d0oooo0ooo
00040?ooo`[oo`00903oool5ool000P0oooo0ooo00040?ooo`?oo`00803oool5ool001P0oooo1Ooo
00060?ooo`Goo`000P3oool=ool00080oooo0ooo00060?ooo`?o003o1@3oool6o`00o`l0oooo2Ol0
0?l<0?ooo`Go003o0@0000010?ooo`0000<000000?ooo`3oool00P3oool5ool000@0oooo0ooo0003
0?ooo`Woo`001P3oool3ool001D0oooo2Ooo000V0?ooo`Goo`003@3oool8ool001`0oooo2?oo000F
0?ooo`Goo`001@3oool5ool000<0oooo0ooo00020?ooo`Soo`00203oool6o`00o`80oooo2?l00?l8
0?ooo`?o003o1@3oool8o`00o``0oooo1Ol00?l100000040oooo00000`000000oooo0?ooo`020?oo
o`Goo`000`3oool5ool00080oooo2Ooo000O0?ooo`?oo`0000@0ooooool00?oo003oo`009`3oool8
ool000X0oooo2Ooo000;0?ooo`?oo`003@3oool9ool000d0oooo0ooo00050?ooo`Goo`001@3oool5
ool000/0oooo1Ooo00070?oooa3o003o203oool5o`00o`L0oooo1Ol00?l=0?ooo`?o003o0@3oool1
00000040oooo00000`000000oooo0?ooo`030?ooo`?oo`00103oool5ool00080oooo2Ooo00060?oo
o`?oo`00903oool3ool000P0oooo0ooo000B0?ooo`Woo`002@3oool9ool000L0oooo2?oo00090?oo
o`?oo`0000<0ooooool00?oo00001_oo000<0?ooo`Goo`00103oool8ool000<0oooo0ooo000<0?oo
o`Goo`001`3oool?o`00o`T0oooo1Ol00?l70?ooo`Go003o4@3oool100000040oooo00000`000000
oooo0?ooo`020?ooo`Goo`000`3oool6ool00080oooo2_oo00030?ooo`Koo`001`3oool3ool001L0
oooo1Ooo00060?ooo`Goo`00403oool:ool000X0oooo2?oo00060?ooo`Woo`001@3oool8ool000<0
oooo1Ooo00000`3oooooo`00ool00002ool000L0oooo1Ooo00020?ooo`_oo`004P3oool3ool000P0
oooo3_l00?l:0?ooo`Ko003o0`3oool8o`00oa40oooo0@0000010?ooo`0000<000000?oooooo0000
1ooo00020?ooo`Ooo`000P3oool;ool00080oooo1ooo00050?ooo`Goo`005P3oool5ool000H0oooo
1Ooo00070?ooo`?oo`001P3oool:ool000h0oooo0ooo00070?ooo`Woo`00103oool9ool000@0oooo
0ooo00000`3oooooo`00ool00004ool000H0oooo1Ooo00000`3oooooo`00ool00003ool00080oooo
1Ooo000N0?ooo`_o003o3@3oool@o`00oa40oooo0@0000010?ooo`0000<00000ool00?oo00001ooo
00000`3oooooo`00ool00006ool000<0oooo2_oo00020?ooo`Soo`00103oool5ool00080oooo0ooo
000A0?ooo`Goo`001P3oool5ool000H0oooo1Ooo00050?ooo`Woo`006@3oool8ool000D0oooo2_oo
00070?ooo`Koo`001`3oool3ool00080oooo1Ooo00020?ooo`Goo`007`3oool7o`00oa00oooo3ol0
0?lB0?ooo`4000000@3oool0000300000?oo003oo`0000Koo`000P3oool7ool000P0oooo2?oo0000
0`3oooooo`00ool00006ool000<0oooo1Ooo00000`3oooooo`00ool00003ool000h0oooo1_oo0000
103oooooo`00ool00?oo00040?ooo`?oo`001`3oool5ool000H0oooo2Ooo000I0?ooo`Koo`001P3o
ool;ool000040?oooooo003oo`00ool00080oooo1_oo000<0?ooo`Goo`000`3oool3ool00200oooo
1Ol00?lC0?ooo`co003o103oool3o`00o`d0oooo0@0000010?ooo`0000<00000ool00?oo00001_oo
00000`3oooooo`00ool00004ool000X0oooo2Ooo00020?ooo`Ooo`000`3oool:ool000d0oooo1Ooo
00020?ooo`Goo`003@3oool5ool000H0oooo2Ooo000K0?ooo`Goo`001P3oool3ool00080oooo2ooo
00000`3oooooo`00ool00002ool000d0oooo1Ooo000H0?ooo`?oo`002`3oool4o`00o`h0oooo0ol0
0?l60?ooo`Wo003o0`3oool5o`00o``0oooo0@0000010?ooo`0000<000000?oooooo00001Ooo0002
0?ooo`Goo`00203oool<ool000<0oooo1ooo00040?ooo`Soo`003@3oool5ool00080oooo1Ooo0002
0?ooo`?oo`002@3oool3ool000P0oooo2?oo000K0?ooo`Goo`002`3oool<ool00140oooo1Ooo000G
0?ooo`Goo`00103oool3ool00080oooo1Ol00?l80?ooo`?o003o0P3oool5o`00o`H0oooo2Ol00?l2
0?ooo`Go003o303oool100000040oooo000010000000oooo0?ooo`3oool5ool000030?oooooo003o
o`0000?oo`001`3oool=ool000@0oooo1_oo00040?ooo`Ooo`003P3oool5ool00080oooo1Ooo0000
0`3oooooo`00ool00003ool001L0oooo0ooo000L0?ooo`Goo`00103oool3ool000D0oooo0ooo0000
0`3oooooo`00ool00005ool000P0oooo0ooo00070?ooo`?oo`001@3oool3ool00100oooo1Ooo0003
0?ooo`Goo`0000<0ooooo`00ool00?l00ol00?l70?ooo`Go003o00<0ooooo`00ool00?l00ol00?l7
0?ooo`Wo003o00<0ooooo`00ool00?l00ol00?l<0?ooo`4000000@3oool000040000003oool0oooo
0?ooo`Goo`000P3oool3ool000P0oooo2?oo0000103oooooo`00ool00?oo00060?ooo`Goo`00103o
ool7ool000/0oooo0ooo0000103oooooo`00ool00?oo00040?ooo`?oo`000P3oool5ool000`0oooo
1?oo000A0?ooo`?oo`004P3oool5ool000<0oooo1Ooo00090?ooo`Koo`001`3oool7ool000/0oooo
1Ooo000?0?ooo`Koo`000P3oool3ool000So003o1`3oool5o`00o`030?ooool00?oo003o00?o003o
1`3oool9o`00o`030?ooool00?oo003o00?o003o303oool100000040oooo000010000000oooo0?oo
o`3oool5ool000d0oooo2?oo00090?ooo`Goo`001P3oool7ool000T0oooo1Ooo0000103oooooo`00
ool00?oo00080?ooo`Goo`002`3oool7ool000h0oooo1Ooo00090?ooo`?oo`001@3oool7ool00003
0?oooooo003oo`0000?oo`002`3oool3ool000P0oooo2?oo000:0?ooo`Goo`00403oool6ool00003
0?oooooo003oo`0000So003o203oool6o`00o`040?ooool00?oo003oo`00o`P0oooo2Ol00?l00`3o
oooo003oo`00o`03o`00o``0oooo0@0000010?ooo`0000<000000?ooo`3oool00P3oool3ool000l0
oooo1ooo00090?ooo`Goo`001P3oool7ool000T0oooo2_oo00080?ooo`?oo`00303oool2ool000?o
003o0ooo000=0?ooo`Goo`00203oool5ool000D0oooo3?oo000F0?ooo`Soo`000`3oool3ool000@0
oooo0_oo0003o`00oa40oooo1Ooo00020?ooo`03ool00?l00?oo003o00?o003o203oool3o`00o`03
0?ooool00?oo003o00Co003o303oool3o`00o`040?ooool00?oo003oo`00o`80oooo1Ol00?l<0?oo
o`4000000@3oool000030000003oool0oooo00H0oooo0ooo000=0?ooo`Goo`001@3oool3ool00003
0?oooooo003oo`0000?oo`000`3oool:ool000T0oooo1_oo0003o`00o`03ool0003oool0oooo01D0
oooo00?oo`00o`00ool00?l00ol00?l2ool000D0oooo0ol00?l50?ooo`05ool00?l00?oo003oo`00
oooo0000203oool5ool000D0oooo1ooo0000103oooooo`00ool00?oo000H0?ooo`Koo`000ol00?l5
ool000<0oooo00?oo`00o`00ool00?l00ol00?l@0?ooo`Goo`000`3oool5o`00o`<0oooo0ol00?l0
0`3ooooo003oo`00o`03o`00o`030?ooool00?oo003o00Co003o3P3oool;o`00o``0oooo0@000001
0?ooo`0000<000000?ooo`3oool01@3oool5ool000d0oooo0ooo00050?ooo`Goo`0000@0ooooool0
0?oo003oo`000`3oool=ool000P0oooo0ooo00000`3ooooo003oo`00o`03o`00oaP0oooo1Ol00?l2
ool000@0oooo1Ol00?l40?ooo`Go003o0P3oool3o`00o`<0oooo1Ooo00050?ooo`Ooo`003P3oool3
o`00o`h0oooo0_oo0008o`00o`05ool0003oool0oooo0?oooooo00001_l00?l@0?ooo`?oo`001@3o
ool3o`00o`<0oooo2_l00?l00`3ooooo003oo`00o`05o`00o`L0oooo0ol00?l20?ooo`co003o303o
ool100000040oooo00000`000000oooo0?ooo`050?ooo`Goo`005@3oool5ool000L0oooo2?oo0000
0`3oooooo`00ool00003ool000/0oooo1Ol00?lH0?ooo`Go003o00?oo`000?ooo`3oool00`3oool5
o`00o`@0oooo1Ol00?l00`3ooooo003oo`00o`04o`00o`80oooo0ooo00060?ooo`Koo`003P3oool5
o`00o`l0oooo2Ol00?l40?ooo`Oo003o7@3oool:o`00o`80oooo1_l00?l60?ooo`Go003o00<0oooo
o`00ool00?l02_l00?l<0?ooo`4000000@3oool000030000003oool0oooo00D0oooo1Ooo00080?oo
o`?oo`002P3oool7ool000D0oooo1ooo00020?ooo`Goo`002`3oool5o`00oaH0oooo1_l00?l0103o
oooo003oo`00ool00?l30?ooo`Go003o103oool5o`00o`030?ooool00?oo003o00Go003o2`3oool3
ool000@0oooo1_l00?l50?ooo`Wo003o00@0ooooo`00ool00?oo003o203oool9o`00o`D0oooo1_l0
0?lL0?ooo`Ko003o00@0ooooo`00ool00?oo003o103oool5o`00o`H0oooo1Ol00?l00`3ooooo003o
o`00o`0<o`00o`X0oooo0@0000010?ooo`0000<000000?ooo`3oool01P3oool4ool000D0oooo1ooo
000:0?ooo`Ooo`001@3oool3ool000D0oooo1Ooo000<0?ooo`?o003o5P3oool5o`00o`80oooo1Ol0
0?l30?ooo`?o003o0P3oool3o`00o`040?ooool00?oo003oo`00o`80oooo1ol00?l;0?ooo`?o003o
0`3oool8o`00o`@0oooo3_l00?l70?ooo`Wo003o1P3oool5o`00oa/0oooo1_l00?l0103ooooo003o
o`00ool00?l60?ooo`?o003o1`3oool5o`00o`80oooo3_l00?l90?ooo`4000000@3oool000030000
003oool0oooo00H0oooo4?oo00020?ooo`?oo`001`3oool8ool000/0oooo0ooo000?0?ooo`?o003o
503oool<o`00o`L0oooo1Ol00?l60?ooo`Ko003o2P3oool5o`00o`80oooo2?l00?l40?ooo`ko003o
1P3oool9o`00o`P0oooo0ol00?lB0?ooo`?o003o1P3oool<o`00oa00oooo0ol00?l80?ooo`Wo003o
2@3oool100000040oooo000010000000oooo0?ooo`3oool3ool00080oooo4?oo00000`3oooooo`00
ool00003ool000<0oooo3?oo000K0?ooo`Go003o203oool3o`00o`L0oooo3_l00?l60?ooo`Go003o
1@3oool7o`00o`X0oooo1Ol00?l20?ooo`So003o1@3oool=o`00o`H0oooo2?l00?lM0?ooo`Go003o
103oool=o`00o`l0oooo0ol00?l<0?ooo`Ko003o2@3oool100000040oooo00000`000000oooo0?oo
o`05ool000030?oooooo003oo`0000goo`000P3oool5ool00080oooo3Ooo000K0?ooo`Go003o1@3o
ool7o`00o`D0oooo4?l00?l50?ooo`Ko003o103oool8o`00o`T0oooo1Ol00?l30?ooo`Oo003o0`3o
ool>o`00o`L0oooo2?l00?lI0?ooo`?o003o00<0ooooo`00ool00?l00ol00?l40?ooo`go003o3P3o
ool5o`00o`d0oooo0ol00?l:0?ooo`4000000@3oool000030000003oool0oooo00Goo`000P3oool;
ool000D0oooo1Ooo00020?ooo`Koo`000P3oool5ool001/0oooo1Ol00?l40?ooo`So003o00D0oooo
o`00ool00?oo003o0?ooo`05o`00o`030?ooool00?oo003o00Wo003o1@3oool5o`00o`@0oooo2Ol0
0?l90?ooo`?o003o00@0ooooo`00ool00?oo003o0`3oool5o`00o`030?ooool00?oo003o00Go003o
00@0ooooo`00ool00?oo003o2`3oool9o`00o`h0oooo0ol00?l60?ooo`[o003o103oool7o`00o`80
oooo0ol00?l?0?ooo`Go003o2P3oool3o`00o`@0oooo0ol00?l60?ooo`4000000@3oool000030000
003oool0oooo00Goo`000P3oool3ool000030?oooooo003oo`0000Goo`001P3oool3ool000<0oooo
3?oo000L0?ooo`Co003o1@3ooolBo`00o`80oooo0ol00?l00`3ooooo003oo`00o`04o`00o`D0oooo
1Ol00?l50?ooo`So003o303oool5o`00o`80oooo2ol00?l@0?ooo`co003o2`3oool5o`00o`D0oooo
2_l00?l30?ooo`Go003o5`3oool5o`00o`T0oooo1Ol00?l20?ooo`Go003o1@3oool100000040oooo
00000`000000ooooool00004ool00080oooo1Ooo00020?ooo`Goo`003@3oool<ool001X0oooo1Ol0
0?l50?ooo`Oo003o00<0ooooo`00ool00?l00ol00?l0103ooooo003oo`00ool00?l70?ooo`Ko003o
103oool5o`00o`T0oooo1Ol00?l<0?ooo`Go003o0P3oool;o`00oa00oooo3Ol00?l:0?ooo`Go003o
1@3oool:o`00o`80oooo1Ol00?l;0?ooo`?o003o2@3oool5o`00o`X0oooo1Ol00?l20?ooo`Go003o
1@3oool100000040oooo00000`00003oo`00ool00003ool000<0oooo1Ooo00030?ooo`Koo`00303o
ool<ool001T0oooo1Ol00?l60?ooo`?o003o103oool5o`00o`X0oooo1_l00?l50?ooo`Go003o2P3o
ool3o`00o`X0oooo2?l00?l30?ooo`?o003o00<0ooooo`00ool00?l01Ol00?l50?ooo`?o003o1`3o
ool5o`00o`030?ooool00?oo003o00Go003o2P3oool5o`00o`H0oooo2Ol00?l20?ooo`Go003o1`3o
ool8o`00o`L0oooo1Ol00?l;0?ooo`Go003o0P3oool5o`00o`D0oooo0@0000010?ooo`0000<00000
ool00?oo00000ooo00030?ooo`Goo`001@3oool5ool000`0oooo2ooo000I0?ooo`Go003o3P3oool3
o`00o`/0oooo1_l00?l50?ooo`Go003o5P3oool8o`00o`80oooo0ol00?l20?ooo`[o003o0P3oool5
o`00o`L0oooo0ol00?l40?ooo`Go003o1P3oool3o`00o`80oooo0ol00?l80?ooo`?o003o00@0oooo
o`00ool00?oo003o0`3oool5o`00o`H0oooo2Ol00?l30?ooo`?o003o00<0ooooo`00ool00?l00ol0
0?l<0?ooo`?o003o103oool3o`00o`H0oooo0@0000010?ooo`0000<00000ool00?oo00000ooo0002
0?ooo`Goo`00103oool7ool000H0oooo0ooo00060?ooo`Soo`004@3oool3o`00o`H0oooo0ol00?lM
0?ooo`Go003o1P3oool5o`00o`/0oooo0ol00?l80?ooo`Go003o103ooolAo`00o`030?ooool00?oo
003o00?o003o3`3oool3o`00o`H0oooo1Ol00?l@0?ooo`?o003o103oool3o`00o`L0oooo2Ol00?l2
0?ooo`[o003o1`3oool3o`00oa80oooo0@0000010?ooo`0000<000000?oooooo00000_oo00020?oo
o`Goo`00103oool8ool000D0oooo1Ooo00090?ooo`?oo`004@3oool;o`00ob00oooo0ol00?l80?oo
o`?o003o2`3oool5o`00o`D0oooo1ol00?l00`3ooooo003oo`00o`0Bo`00o`030?ooool00?oo003o
00?o003o603oool5o`00o`d0oooo1ol00?l20?ooo`Go003o1P3oool8o`00o`<0oooo1Ol00?l0103o
oooo003oo`00ool00?l70?ooo`Go003o4@3oool100000040oooo00000`000000ooooool00002ool0
0080oooo1_oo00030?ooo`Woo`00103oool5ool000H0oooo0ooo000D0?ooo`ko003o4@3oool3o`00
oaP0oooo1?l00?l60?ooo`Oo003o0P3oool7o`00o`030?ooool00?oo003o01?o003o00<0ooooo`00
ool00?l00ol00?lH0?ooo`Go003o2@3oool;o`00o`030?ooool00?oo003o00Co003o1`3oool7o`00
o`<0oooo1Ol00?l;0?ooo`Go003o1P3oool3o`00o`P0oooo0@0000010?ooo`0000<00000ool00?oo
00000ooo00000`3oooooo`00ool00004ool000<0oooo2Ooo00030?ooo`Woo`000P3oool5ool00180
oooo4?l00?l?0?ooo`Go003o5P3oool6o`00o`D0oooo2?l00?l00`3ooooo003oo`00o`0>o`00o`80
oooo0ol00?l40?ooo`?o003o0`3oool3o`00o`@0oooo0ol00?lC0?ooo`?o003o2@3oool<o`00o`03
0?ooool00?oo003o00Co003o2@3oool5o`00o`030?ooool00?oo003o00Co003o1@3oool3o`00o`@0
oooo1Ol00?l50?ooo`Go003o1`3oool100000040oooo00000`00003oo`00ool00003ool00080oooo
1Ooo00030?ooo`[oo`000P3oool:ool000030?oooooo003oo`0000?oo`004P3oool@o`00o`D0oooo
0ol00?l70?ooo`Go003o1P3oool3o`00o`P0oooo0ol00?l20?ooo`Ko003o1P3ooolEo`00oaP0oooo
1Ol00?lA0?ooo`?o003o2@3oool<o`00o`80oooo1Ol00?l:0?ooo`[o003o1P3oool5o`00o`@0oooo
0ol00?l60?ooo`Go003o1`3oool100000040oooo00000`00003oo`00ool00003ool000<0oooo0ooo
00040?ooo`[oo`000P3oool:ool000030?oooooo003oo`0000?oo`004P3oool5o`00o`030?ooool0
0?oo003o00[o003o0P3oool5o`00o`H0oooo1Ol00?l50?ooo`Go003o0`3oool8o`00o`030?ooool0
0?oo003o00Co003o203oool>o`00o`040?ooool00?oo003oo`00o`l0oooo0ol00?l70?ooo`Go003o
403oool5o`00o`P0oooo2Ol00?l60?ooo`?o003o0P3oool3o`00o`H0oooo2_l00?l60?ooo`Oo003o
1P3oool3o`00o`80oooo1Ol00?l70?ooo`4000000@3oool000030000003oooooo`0000;oo`00303o
ool3ool000030?oooooo003oo`0000?oo`000P3oool4ool000030?oooooo003oo`0000?oo`000P3o
ool3ool001@0oooo0ol00?l80?ooo`Oo003o00<0ooooo`00ool00?l00ol00?l60?ooo`Co003o1P3o
ool5o`00o`80oooo2Ol00?l20?ooo`Co003o2P3oool<o`00oa<0oooo1Ol00?l0103ooooo003oo`00
ool00?l20?ooo`Go003o3`3oool6o`00o`P0oooo1Ol00?l50?ooo`?o003o1P3oool5o`00o`D0oooo
3?l00?l40?ooo`So003o103oool5o`00o`80oooo0ol00?l80?ooo`4000000@3oool000030000003o
ool0oooo01<0oooo0ooo00020?ooo`Goo`000P3oool3ool002L0oooo2ol00?l50?ooo`Go003o1P3o
ool5o`00o`80oooo2ol00?l?0?ooo`Wo003o5@3oool:o`00o`030?ooool00?oo003o00?o003o00@0
ooooo`00ool00?oo003o1P3oool3o`00o`80oooo1_l00?l60?ooo`Ko003o1@3oool5o`00o`D0oooo
1Ol00?l60?ooo`co003o0`3oool8o`00o`@0oooo1Ol00?l=0?ooo`4000000@3oool000030000003o
ool0oooo01P0oooo1Ooo000>0?ooo`?oo`006P3oool;o`00o`<0oooo2?l00?l70?ooo`?o003o0`3o
ool<o`00o`l0oooo0ol00?l0103ooooo003oo`00ool00?lF0?ooo`[o003o00<0ooooo`00ool00?l0
2?l00?l40?ooo`Go003o00<0ooooo`00ool00?l00ol00?l60?ooo`Go003o1`3oool5o`00o`D0oooo
1Ol00?l50?ooo`Oo003o00<0ooooo`00ool00?l01?l00?l20?ooo`So003o103oool5o`00o`d0oooo
0@0000010?ooo`0000<000000?ooo`3oool0603oool5ool000d0oooo1Ooo000H0?ooo`[o003o103o
ool9o`00o`h0oooo1Ol00?l00`3ooooo003oo`00o`03o`00oaH0oooo0ol00?lA0?ooo`Ko003o00<0
ooooo`00ool00?l00ol00?l00`3ooooo003oo`00o`08o`00o`@0oooo1Ol00?l00`3ooooo003oo`00
o`03o`00o`H0oooo1Ol00?l70?ooo`Go003o103oool5o`00o`D0oooo2?l00?l00`3ooooo003oo`00
o`04o`00o`<0oooo1_l00?l60?ooo`?o003o1P3oool3o`00o`D0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0603oool5ool000d0oooo1Ooo000H0?ooo`[o003o103oool8o`00o`l0oooo1Ol00?l0
0`3ooooo003oo`00o`03o`00oaD0oooo1Ol00?l?0?ooo`Go003o103oool9o`00o`030?ooool00?oo
003o00?o003o103oool5o`00o`80oooo0ol00?l70?ooo`Go003o1@3oool6o`00o`D0oooo1Ol00?l5
0?ooo`So003o0P3oool5o`00oaL0oooo1Ol00?l40?ooo`4000000@3oool000030000003oool0oooo
01P0oooo1Ooo000=0?ooo`Goo`002@3oool3o`00o``0oooo1Ol00?l0103ooooo003oo`00ool00?l5
0?ooo`Oo003o4@3oool9o`00oa40oooo0ol00?l20?ooo`Go003o303oool8o`00o`H0oooo1Ol00?l4
0?ooo`?o003o1P3oool3o`00o`h0oooo1?l00?l40?ooo`Go003o1`3oool5o`00o`D0oooo1ol00?l4
0?ooo`?o003o103oool3o`00o`<0oooo0ol00?l;0?ooo`Go003o103oool100000040oooo00000`00
0000oooo0?ooo`0H0?ooo`Goo`003P3oool3ool000T0oooo1Ol00?l50?ooo`?o003o103oool3o`00
o`/0oooo1_l00?l?0?ooo`Wo003o1`3oool3o`00o`030?ooool00?oo003o00?o003o0P3oool5o`00
o`030?ooool00?oo003o00?o003o1`3oool3o`00o`030?ooool00?oo003o00Oo003o1P3oool9o`00
oaT0oooo1_l00?l30?ooo`Go003o203oool3o`00o`80oooo0ol00?l20?ooo`?o003o3@3oool5o`00
o`030?ooool00?oo003o00?o003o2P3oool5o`00o`@0oooo0@0000010?ooo`0000<000000?ooo`3o
ool06@3oool3ool001@0oooo0ooo00040?ooo`Go003o00<0ooooo`00ool00?l01_l00?lC0?ooo`?o
003o3`3oool<o`00o`@0oooo2ol00?l00`3ooooo003oo`00o`03o`00o`80oooo0ol00?l70?ooo`go
003o1`3oool:o`00oaL0oooo1ol00?l30?ooo`Go003o303oool5o`00o`D0oooo0ol00?l90?ooo`_o
003o2`3oool3o`00o`D0oooo0@0000010?ooo`0000<000000?ooo`3oool0;`3oool5ool000<0oooo
3_l00?lU0?ooo`go003o0`3oool;o`00o`030?ooool00?oo003o00?o003o303oool:o`00o`/0oooo
2Ol00?l70?ooo`?o003o3@3oool:o`00o`040?ooool00?oo003oo`00o`d0oooo1Ol00?l40?ooo`Go
003o203oool;o`00oa<0oooo0@0000010?ooo`0000<000000?ooo`3oool07P3oool3ool000h0oooo
1Ooo00040?ooo`go003o9@3oool=o`00o`<0oooo2ol00?l20?ooo`?o003o3@3oool5o`00o`040?oo
ool00?oo003oo`00o`l0oooo1_l00?l60?ooo`Go003o303oool?o`00o`T0oooo2_l00?l20?ooo`Go
003o2@3oool5o`00o`030?ooool00?oo003o00;o003o00@0ooooo`00ool00?oo003o3`3oool10000
0040oooo00000`000000oooo0?ooo`0G0?ooo`?oo`000`3oool5ool000d0oooo1Ooo00050?ooo`_o
003o1`3oool3o`00oa`0oooo3Ol00?l40?ooo`Wo003o503oool3o`00oaD0oooo1?l00?l70?ooo`Ko
003o303oool3o`00o`80oooo2Ol00?l50?ooo`oo003o00<0ooooo`00ool00?l00ol00?l:0?ooo`?o
003o0P3oool9o`00o`h0oooo0@0000010?ooo`0000<000000?ooo`3oool04P3oool3ool000030?oo
oooo003oo`0000?oo`000P3oool5ool000<0oooo0ooo00080?ooo`?oo`001P3oool7o`00o`80oooo
0ol00?l50?ooo`Go003o00@0ooooo`00ool00?oo003o5`3oool=o`00o`@0oooo1_l00?l:0?ooo`?o
003o103oool3o`00obH0oooo1ol00?l@0?ooo`Wo003o103oool9o`00o`80oooo1Ol00?l20?ooo`?o
003o2`3oool3o`00o`80oooo2Ol00?l20?ooo`?o003o2@3oool100000040oooo00000`000000oooo
0?ooo`0A0?ooo`[oo`000P3oool5ool00080oooo1Ooo000;0?ooo`?oo`000P3oool7o`00o`030?oo
ool00?oo003o00?o003o103oool:o`00o`040?ooool00?oo003oo`00oa80oooo1Ol00?l20?ooo`Ko
003o103oool8o`00o`D0oooo1ol00?l20?ooo`Go003o6P3oool3o`00o`T0oooo1_l00?lA0?ooo`?o
003o00@0ooooo`00ool00?oo003o1@3oool9o`00o`80oooo1Ol00?l?0?ooo`oo003o00<0ooooo`00
ool00?l00ol00?l80?ooo`4000000@3oool000030000003oool0oooo0100oooo2ooo00030?ooo`?o
o`000`3oool5ool000X0oooo1Ooo00020?ooo`Ko003o00<0ooooo`00ool00?l00ol00?l40?ooo`oo
003o1@3oool4o`00o`T0oooo0ol00?l40?ooo`Go003o103oool9o`00o`<0oooo2?l00?l20?ooo`Go
003o6@3oool5o`00o`T0oooo1Ol00?lM0?ooo`So003o0`3oool5o`00o`L0oooo0ol00?l50?ooo`[o
003o00@0ooooo`00ool00?oo003o0P3oool5o`00o`P0oooo0@0000010?ooo`0000<000000?ooo`3o
ool03`3oool;ool000X0oooo1Ooo00070?ooo`Soo`00103oool3o`00o`80oooo1Ol00?l50?ooo`?o
003o00<0ooooo`00ool00?l02Ol00?l30?ooo`_o003o0`3oool3o`00o`@0oooo1Ol00?l40?ooo`Wo
003o0`3oool8o`00o`80oooo1Ol00?lE0?ooo`?o003o00<0ooooo`00ool00?l00ol00?l:0?ooo`?o
003o6P3oool3o`00o`80oooo0ol00?l70?ooo`Go003o1P3oool5o`00o`@0oooo2_l00?l40?ooo`Oo
003o203oool100000040oooo00000`000000oooo0?ooo`060?ooo`?oo`001P3oool<ool000X0oooo
0ooo00070?ooo`Woo`002P3oool3o`00o`/0oooo0ol00?l00`3ooooo003oo`00o`05o`00o`030?oo
ool00?oo003o00_o003o00<0ooooo`00ool00?l00ol00?l40?ooo`?o003o103oool;o`00o`80oooo
1ol00?l00`3ooooo003oo`00o`04o`00oaD0oooo2_l00?lV0?ooo`Go003o303oool3o`00o`L0oooo
1Ol00?l50?ooo`?o003o00<0ooooo`00ool00?l00ol00?l30?ooo`Wo003o1`3oool100000040oooo
00000`000000oooo0?ooo`050?ooo`Goo`001@3oool@ool000d0oooo2ooo000C0?ooo`?o003o203o
ool6o`00o`030?ooool00?oo003o00_o003o00<0ooooo`00ool00?l01Ol00?l90?ooo`Go003o00<0
ooooo`00ool00?l00ol00?l30?ooo`Go003o00<0ooooo`00ool00?l00ol00?lG0?ooo`Go003o00@0
ooooo`00ool00?oo003o9`3oool5o`00oaD0oooo1_l00?l90?ooo`Go003o0`3oool:o`00o`040?oo
ool00?oo003oo`00o`80oooo0@0000010?ooo`0000<000000?ooo`3oool00`3oool7ool000H0oooo
4?oo000;0?ooo`coo`004@3oool6o`00o`P0oooo1Ol00?l00`3ooooo003oo`00o`0;o`00o`030?oo
ool00?oo003o00Ko003o203oool5o`00o`030?ooool00?oo003o00?o003o0`3oool5o`00o`030?oo
ool00?oo003o00?o003o303oool3o`00o`P0oooo1Ol00?l[0?ooo`Ko003o503oool5o`00o`H0oooo
0ol00?l20?ooo`?o003o0`3oool@o`00o`40oooo0@0000010?ooo`0000<000000?ooo`3oool00P3o
ool9ool000T0oooo3?oo00050?ooo`?oo`000`3oool=ool000@0oooo0ol00?l80?ooo`Oo003o2@3o
ool3o`00o`<0oooo0ol00?l20?ooo`Ko003o0`3oool7o`00o`T0oooo0ol00?l30?ooo`?o003o103o
ool5o`00o`030?ooool00?oo003o00?o003o2`3oool5o`00o`P0oooo1Ol00?lT0?ooo`?o003o103o
ool6o`00o`@0oooo0ol00?l80?ooo`?o003o00<0ooooo`00ool00?l00ol00?l50?ooo`[o003o0P3o
ool5o`00o`030?ooool00?oo003o00So003o0@3oool100000040oooo00000`000000oooo0?ooo`02
0?ooo`Woo`003@3oool8ool000@0oooo1Ooo00020?ooo`Goo`000`3oool5ool000<0oooo1Ol00?l7
0?ooo`Oo003o2P3oool3o`00o`H0oooo1_l00?l30?ooo`So003o3P3oool5o`00o`@0oooo0ol00?l3
0?ooo`?o003o303oool5o`00o`P0oooo1Ol00?lS0?ooo`Go003o0`3oool6o`00o`<0oooo1Ol00?l5
0?ooo`Ko003o00@0ooooo`00ool00?oo003o1P3oool:o`00o`80oooo1Ol00?l00`3ooooo003oo`00
o`08o`00o`40oooo0@0000010?ooo`0000<000000?ooo`3oool00P3oool:ool000T0oooo0ooo0003
0?ooo`Goo`00103oool5ool000<0oooo0ooo00040?ooo`Goo`000`3oool5o`00o`80oooo0ol00?l2
0?ooo`Ko003o2P3oool7o`00o`80oooo1ol00?l20?ooo`So003o3`3oool6o`00o`h0oooo0ol00?l7
0?ooo`Go003o203oool5o`00o`L0oooo0ol00?l:0?ooo`?o003o303oool5o`00o`@0oooo1Ol00?l3
0?ooo`Go003o103oool7o`00o`X0oooo2_l00?l30?ooo`?o003o0P3oool9o`00o`80oooo0@000001
0?ooo`0000@00000ool00?oo003oo`000P3oool:ool000L0oooo1Ooo00020?ooo`Goo`00103oool5
ool000/0oooo0ooo00040?ooo`Go003o00<0ooooo`00ool00?l00ol00?l20?ooo`?o003o303oool8
o`00o`030?ooool00?oo003o00Co003o0`3oool9o`00o`h0oooo1ol00?l<0?ooo`Oo003o1@3oool3
o`00o`T0oooo2?l00?l30?ooo`Go003o203oool5o`00o`040?ooool00?oo003oo`00o`L0oooo1Ol0
0?l50?ooo`?o003o103oool7o`00o`80oooo2?l00?l80?ooo`Go003o0P3oool3o`00o`X0oooo1Ol0
0?l50?ooo`4000000@3oool000Goo`000P3oool9ool000L0oooo1Ooo00020?ooo`Goo`001@3oool3
ool001@0oooo0ol00?l20?ooo`Go003o00<0ooooo`00ool00?l00ol00?l0103ooooo003oo`00ool0
0?l70?ooo`So003o00<0ooooo`00ool00?l00ol00?l30?ooo`[o003o0P3oool3o`00o`X0oooo1_l0
0?l<0?ooo`So003o403oool9o`00o`80oooo1Ol00?l60?ooo`co003o1`3oool3o`00o`h0oooo4Ol0
0?l70?ooo`Go003o1P3oool3o`00o`H0oooo1Ol00?l50?ooo`4000000@3oool000Goo`000P3oool9
ool000L0oooo1Ooo00020?ooo`Goo`008@3oool5o`00o`030?ooool00?oo003o00_o003o103oool7
o`00o`80oooo0ol00?l30?ooo`_o003o00<0ooooo`00ool00?l00ol00?l:0?ooo`Go003o303oool8
o`00o`/0oooo0ol00?l20?ooo`Wo003o0P3oool5o`00o`D0oooo3Ol00?l50?ooo`?o003o4P3oool?
o`00o`L0oooo1Ol00?l20?ooo`So003o1P3oool3o`00o`H0oooo0@0000010?ooo`001Ooo00020?oo
o`Soo`001`3oool5ool000@0oooo0ooo000S0?ooo`?o003o0P3oool>o`00o`H0oooo0ol00?l90?oo
o`Go003o00<0ooooo`00ool00?l00ol00?l00`3ooooo003oo`00o`03o`00o`@0oooo0ol00?l40?oo
o`?o003o3P3oool7o`00o`X0oooo1Ol00?l20?ooo`So003o0`3oool3o`00o`040?ooool00?oo003o
o`00o`80oooo1ol00?l00`3ooooo003oo`00o`03o`00o`@0oooo1Ol00?lA0?ooo`oo003o203oool3
o`00o`80oooo2Ol00?l?0?ooo`4000000@3oool0000400000?oo003oo`00ool000@0oooo0ooo000;
0?ooo`Goo`00<03oool3o`00o`030?ooool00?oo003o00So003o4@3oool5o`00o`80oooo0ol00?l2
0?ooo`Go003o0`3oool5o`00oaL0oooo0ol00?l;0?ooo`Go003o1P3oool5o`00o`D0oooo1Ol00?l0
0`3ooooo003oo`00o`03o`00o`@0oooo0ol00?l50?ooo`Go003o4@3oool5o`00o`040?ooool00?oo
003oo`00o`80oooo0ol00?l>0?ooo`Wo003o3`3oool100000040oooo00000`000000oooo0?ooo`03
ool00100oooo1Ooo000C0?ooo`?oo`005`3oool3o`00o`D0oooo2_l00?lA0?ooo`?o003o2@3oool3
o`00o`@0oooo1Ol00?lU0?ooo`Go003o1P3oool7o`00o`<0oooo1Ol00?l20?ooo`?o003o3@3oool5
o`00oa80oooo1Ol00?l@0?ooo`?o003o0`3oool8o`00oa00oooo0@0000010?ooo`0000<000000?oo
oooo00001?oo00060?ooo`?oo`001`3oool3ool001<0oooo1Ooo000E0?ooo`Go003o1P3oool8o`00
ob@0oooo1Ol00?lD0?ooo`?o003o3`3oool3o`00o`L0oooo2?l00?l20?ooo`Go003o00@0ooooo`00
ool00?oo003o3`3oool3o`00o`@0oooo0ol00?l=0?ooo`Go003o303oool7o`00o`<0oooo1Ol00?lB
0?ooo`4000000@3oool000030000003oooooo`0000Coo`00103oool6ool001`0oooo1Ooo000E0?oo
o`Go003o1P3oool8o`00obD0oooo0ol00?l:0?ooo`?o003o1`3oool5o`00oaT0oooo1ol00?l00`3o
oooo003oo`00o`09o`00oa@0oooo1Ol00?l20?ooo`?o003o1`3oool8o`00o`P0oooo2?l00?l40?oo
o`?o003o1`3oool3o`00o`T0oooo0@0000010?ooo`0000<000000?oooooo00001?oo00030?ooo`Oo
o`00203oool3ool000T0oooo0ooo00001@3oooooo`00ool00?oo0000oooo00Goo`005@3oool5o`00
o`L0oooo1_l00?lR0?ooo`?o003o0`3oool3o`00o`L0oooo1Ol00?l60?ooo`Go003o6`3oool5o`00
o`030?ooool00?oo003o00oo003o3P3oool5o`00o`030?ooool00?oo003o00?o003o1P3oool9o`00
o`@0oooo3_l00?l:0?ooo`Go003o103oool3o`00o`40oooo0@0000010?ooo`0000<000000?ooo`3o
ool00ooo00040?ooo`Ooo`001`3oool5ool000L0oooo2Ooo00000`3oooooo`00ool00004ool001@0
oooo0ol00?l_0?ooo`Go003o00<0ooooo`00ool00?l01_l00?l30?ooo`Go003o1P3oool6o`00o`80
oooo0ol00?lF0?ooo`?o003o0P3ooolBo`00o``0oooo1_l00?l00`3ooooo003oo`00o`03o`00o`80
oooo0ol00?l20?ooo`So003o0`3oool@o`00o`T0oooo1Ol00?l00`3ooooo003oo`00o`05o`00o`40
00000@3oool000030000003oooooo`0000Coo`000P3oool7ool000P0oooo1Ooo00070?ooo`Woo`00
0`3oool5ool003H0oooo1Ol00?l:0?ooo`oo003o0P3oool5o`00o`L0oooo2ol00?l60?ooo`?o003o
4P3ooolAo`00o`/0oooo3Ol00?l00`3ooooo003oo`00o`03o`00o`@0oooo1Ol00?l30?ooo`So003o
0`3oool5o`00o`P0oooo3_l00?l100000040oooo00000`000000ooooool00005ool000030?oooooo
003oo`0000?oo`002@3oool6ool000040?oooooo003oo`00ool000<0oooo2Ooo00030?ooo`Goo`00
103oool3ool002h0oooo1ol00?l0103ooooo003oo`00ool00?l40?oooa7o003o00<0ooooo`00ool0
0?l00ol00?l80?oooaCo003o4P3oool5o`00o`<0oooo2?l00?l20?ooo`?o003o1P3oool<o`00o`80
oooo1Ol00?l50?ooo`?o003o103oool5o`00o`H0oooo1Ol00?l80?ooo`Go003o00<0ooooo`00ool0
0?l01_l00?l100000040oooo00000`000000ooooool00005ool000030?oooooo003oo`0000?oo`00
203oool6ool000030?oooooo003oo`0000?oo`000`3oool3ool000040?oooooo003oo`00ool00080
oooo1ooo00030?ooo`Goo`000`3oool3o`00obL0oooo3?l00?l20?oooa;o003o00<0ooooo`00ool0
0?l00ol00?l70?oooaGo003o4`3oool3o`00o`D0oooo1_l00?l20?ooo`Go003o1@3oool9o`00o`D0
oooo1Ol00?l=0?ooo`?o003o203oool3o`00o`T0oooo1Ol00?l00`3ooooo003oo`00o`05o`00o`40
oooo0@0000010?ooo`0000<00000ool00?oo00001Ooo00020?ooo`?oo`002@3oool5ool00080oooo
1Ooo000;0?ooo`[oo`0000<0ooooool00?oo00000ooo00020?ooo`Go003o9P3oool<o`00o`80oooo
2_l00?l30?ooo`Ko003o00D0ooooo`00ool00?oo003o0?ooo`03o`00o`<0oooo5_l00?lB0?ooo`Go
003o303oool8o`00o`<0oooo2?l00?l60?ooo`?o003o9P3oool5o`00o`030?ooool00?oo003o00Go
003o0@0000010?ooo`0000<00000ool00?oo00001?oo000?0?ooo`Koo`0000<0ooooool00?oo0000
0ooo000;0?ooo`Goo`0000<0ooooool00?oo00002?oo00020?ooo`Go003o9`3oool;o`00o`80oooo
2Ol00?l50?ooo`Ko003o0`3oool5o`00o`80oooo5_l00?lB0?ooo`Go003o203oool3o`00o`030?oo
ool00?oo003o00Oo003o1P3oool3o`00oc00oooo1Ol00?l30?ooo`Go003o0@0000010?ooo`0000<0
0000ool00?oo00000ooo000A0?ooo`Koo`0000@0ooooool00?oo003oo`001P3oool3ool00080oooo
1_oo00000`3oooooo`00ool00003ool000040?oooooo003oo`00ool000<0oooo1_l00?lC0?ooo`?o
003o403oool:o`00o`@0oooo1_l00?l70?ooo`Oo003o0P3oool5o`00o`80oooo2_l00?l20?ooo`_o
003o1P3oool6o`00o`D0oooo1Ol00?l70?ooo`Go003o00<0ooooo`00ool00?l01_l00?li0?ooo`Go
003o0`3oool5o`00o`4000000@3oool0000300000?oo003oo`0000?oo`004@3oool6ool000T0oooo
1Ooo00000`3oooooo`00ool00003ool00080oooo1Ooo00040?ooo`?oo`0000<0ooooo`00ool00?l0
0ol00?lB0?ooo`Go003o103oool3o`00o`T0oooo1_l00?lE0?ooo`Ko003o0P3oool5o`00o`<0oooo
2Ol00?l80?ooo`Go003o1@3oool8o`00o`D0oooo0ol00?l80?ooo`Go003o103oool5o`00oa80oooo
0ol00?lB0?ooo`?o003o403oool3o`00o`D0oooo0ol00?l10?ooo`4000000@3oool000030000003o
ooooo`0000;oo`00203oool3ool000L0oooo1_oo00090?ooo`Goo`0000<0ooooool00?oo00000ooo
00030?ooo`?oo`00103oool5ool000Go003o4P3oool5o`00o`<0oooo1Ol00?l30?ooo`Coo`000`3o
ool3o`00oaL0oooo1Ol00?l30?ooo`?o003o00@0ooooool00?oo003oo`002?l00?l90?ooo`Go003o
1@3oool8o`00o`030?oooooo003oo`0000?oo`002P3oool5o`00o`@0oooo1Ol00?lA0?ooo`Go003o
403oool5o`00o`P0oooo0ol00?l@0?ooo`4000000@3oool000030000003oool0oooo00T0oooo1_oo
00060?ooo`Coo`002P3oool5ool00080oooo0ooo000;0?ooo`Koo`000ol00?l00ooo0000oooo0?oo
o`0@0?ooo`Go003o00?oo`000?oooooo00001Ol00?l20?ooo`Koo`00203oool6ool000T0oooo0ooo
00030?ooo`?o003o0_oo00050?ooo`Coo`001ol00?l;0?ooo`?o003o1P3oool8o`00o`Ooo`002@3o
ool01?oo003o003oo`00ool00?l60?ooo`?o003o4P3oool5o`00oa00oooo1Ol00?l70?ooo`Go003o
3`3oool100000040oooo00000`000000oooo0?ooo`090?ooo`[oo`00403oool4ool000<0oooo0ooo
000;0?ooo`_oo`001@3oool3ool000X0oooo0ol00?l4ool000Go003o2?oo00030?ooo`?oo`0000<0
ooooool00?oo00001_oo00060?ooo`Koo`000P3oool5ool000D0oooo1Ooo0003o`00o`03ool0003o
ool0oooo01D0oooo1_l00?l00`3oooooo`00ool00005ool000P0oooo1Ooo000K0?ooo`Go003o3`3o
ool7o`00o`H0oooo1Ol00?l?0?ooo`4000000@3oool000030000003oool0oooo00T0oooo2ooo0003
0?ooo`?oo`00203oool5ool00080oooo1Ooo000;0?ooo`[oo`00103oool5ool000X0oooo1ooo0003
o`00o`Woo`000P3oool=ool000D0oooo1ooo00020?ooo`Goo`001@3oool9ool00180oooo0ooo0000
103oooooo`00ool00?oo00050?ooo`[oo`001@3oool5ool000H0oooo0ooo000C0?ooo`?o003o3`3o
ool8o`00o`H0oooo1_l00?l>0?ooo`4000000@3oool000030000003oool0oooo00X0oooo2_oo0002
0?ooo`Goo`001`3oool5ool00080oooo1Ooo000<0?ooo`Woo`00103oool5ool000X0oooo1Ooo0000
0`3oooooo`00ool0000<ool000030?oooooo003oo`0000_oo`001@3oool7ool000<0oooo0ooo0007
0?ooo`?oo`0000@0ooooool00?oo003oo`004P3oool9ool000D0oooo2_oo00040?ooo`Goo`000P3o
ool8ool002@0oooo2Ol00?l60?ooo`Go003o203oool3o`00o`<0oooo0@0000010?ooo`0000<00000
0?ooo`3oool0303oool8ool00080oooo1Ooo00070?ooo`Koo`0000<0ooooool00?oo00000ooo000=
0?ooo`Ooo`001@3oool5ool000/0oooo0ooo00020?ooo`koo`0000<0ooooool00?oo00002_oo0006
0?ooo`Koo`002P3oool3ool001X0oooo2Ooo000:0?ooo`Goo`001@3oool3ool00080oooo2Ooo000T
0?ooo`Wo003o1P3oool5o`00o`L0oooo1Ol00?l20?ooo`4000000@3oool000030000003oool0oooo
0100oooo0ooo00030?ooo`Goo`00203oool5ool00080oooo0ooo000>0?ooo`Koo`001`3oool3ool0
0180oooo0ooo00001@3oooooo`00ool00?oo0000oooo00Goo`000P3oool3ool000030?oooooo003o
o`0000?oo`00103oool3ool00080oooo0ooo00060?ooo`?oo`0000<0ooooool00?oo00001?oo000I
0?ooo`Woo`002P3oool5ool000X0oooo2Ooo000S0?ooo`[o003o1`3oool3o`00o`P0oooo1Ol00?l2
0?ooo`4000000@3oool000030000003oool0oooo0080oooo0ooo000A0?ooo`Goo`00203oool5ool0
0180oooo2?oo000;0?ooo`?oo`005P3oool3ool00080oooo0ooo00020?ooo`Goo`000P3oool6ool0
00T0oooo2ooo000J0?ooo`?oo`0000@0ooooool00?oo003oo`00303oool3ool000/0oooo2Ooo000S
0?ooo`Go003o00@0ooooo`00ool00?oo003o3@3oool3o`00o`80oooo1_l00?l20?ooo`4000000@3o
ool000040000003oool0oooo0?ooo`Goo`00403oool5ool000T0oooo0ooo000B0?ooo`Woo`002P3o
ool5ool000@0oooo0ooo000=0?ooo`[oo`000P3oool3ool00080oooo1ooo00090?ooo`_oo`00<P3o
ool3ool000L0oooo2?oo000B0?ooo`?o003o3@3oool6o`00oa00oooo2ol00?l30?ooo`4000000@3o
ool000040000003oool0oooo0?ooo`Goo`00403oool5ool001`0oooo2ooo000:0?ooo`Goo`000`3o
ool5ool000`0oooo2_oo00070?ooo`Ooo`001`3oool<ool001h0oooo0ooo000A0?ooo`Goo`002P3o
ool6ool000l0oooo1Ol00?l;0?ooo`Oo003o00@0ooooo`00ool00?oo003o2@3oool=o`00o`@0oooo
0@0000010?ooo`0000<000000?oooooo00001_oo000A0?ooo`Koo`006@3oool;ool000/0oooo3Ooo
000<0?ooo`[oo`001`3oool6ool000L0oooo1ooo00000`3oooooo`00ool00003ool001d0oooo1Ooo
000@0?ooo`Goo`001P3oool3ool000<0oooo1Ooo000>0?ooo`Oo003o2@3oool<o`00o`L0oooo3_l0
0?l40?ooo`4000000@3oool0000300000?oo003oo`0000Goo`00503oool5ool001P0oooo1ooo000@
0?ooo`coo`001`3oool3ool000<0oooo0ooo00020?ooo`?oo`002@3oool3ool000T0oooo1Ooo0004
0?ooo`Goo`00703oool6ool000<0oooo0ooo00090?ooo`Goo`001@3oool5ool00080oooo1Ooo0007
0?ooo`?oo`00103oool8o`00o`P0oooo1_l00?l00`3ooooo003oo`00o`03o`00o`L0oooo2?l00?l2
0?ooo`?o003o1@3oool100000040oooo00000`00003oo`00ool00003ool001H0oooo1Ooo00030?oo
o`?oo`002@3oool3ool000040?oooooo003oo`00ool00080oooo1Ooo000C0?ooo`[oo`001`3oool5
ool001l0oooo1Ooo00040?ooo`Goo`000`3oool3ool001H0oooo1_oo00020?ooo`Goo`002@3oool3
ool000@0oooo1ooo00020?ooo`Goo`000`3oool8ool000@0oooo1ol00?l90?ooo`?o003o0`3oool5
o`00o`L0oooo2?l00?l:0?ooo`4000000@3oool0000300000?oo003oo`0000?oo`005P3oool5ool0
0080oooo1Ooo00070?ooo`Woo`000P3oool3ool001<0oooo2Ooo00090?ooo`Goo`00203oool3ool0
00`0oooo0ooo00060?ooo`?oo`001@3oool6ool000030?oooooo003oo`0000?oo`005P3oool5ool0
0080oooo1Ooo00070?ooo`?oo`001@3oool8ool000<0oooo0ooo00030?ooo`Woo`000`3oool:o`00
o`H0oooo1Ol00?l00`3ooooo003oo`00o`03o`00o`T0oooo2_l00?l70?ooo`4000000@3oool00003
0000003oooooo`0000Coo`005P3oool3ool000<0oooo1Ooo00020?ooo`?oo`000P3oool9ool000l0
oooo0ooo00060?ooo`Woo`002@3oool5ool000L0oooo2?oo00050?ooo`Ooo`003P3oool5ool00003
0?oooooo003oo`0000?oo`005P3oool5ool00080oooo1Ooo00060?ooo`Goo`00103oool9ool000P0
oooo2Ooo00030?ooo`_o003o1@3oool:o`00o`d0oooo2?l00?l60?ooo`4000000@3oool000030000
003oooooo`0000Coo`00703oool5ool000030?oooooo003oo`0000?oo`0000<0ooooool00?oo0000
1ooo00040?ooo`?oo`001`3oool5ool000D0oooo2?oo00040?ooo`?oo`000`3oool5ool000L0oooo
2Ooo00030?ooo`Soo`0000@0ooooool00?oo003oo`002P3oool5ool000030?oooooo003oo`0000Go
o`00503oool5ool000<0oooo0ooo00060?ooo`Koo`000P3oool;ool000H0oooo2_oo00040?ooo`Go
003o00<0ooooo`00ool00?l00ol00?l50?ooo`[o003o2P3oool;o`00o`H0oooo0@0000010?ooo`00
00<000000?oooooo00001?oo000K0?ooo`Goo`000P3oool5ool00080oooo0ooo0000103oooooo`00
ool00?oo00040?ooo`Goo`001P3oool5ool000H0oooo0ooo00070?ooo`Goo`000P3oool5ool000D0
oooo2ooo00030?ooo`goo`0000@0ooooool00?oo003oo`001P3oool=ool001<0oooo1Ooo000<0?oo
o`Koo`0000<0ooooool00?oo00002_oo00050?ooo`Woo`001`3oool3o`00o`80oooo1Ol00?l60?oo
o`?o003o00<0ooooo`00ool00?l00ol00?l80?ooo`go003o1P3oool100000040oooo00000`000000
oooo0?ooo`05ool000/0oooo0ooo000<0?ooo`Goo`000P3oool5ool000d0oooo1Ooo00060?ooo`So
o`0000@0ooooool00?oo003oo`002@3oool5ool000030?oooooo003oo`0000?oo`001@3oool<ool0
00<0oooo1ooo00000`3oooooo`00ool00008ool000H0oooo3?oo000D0?ooo`?oo`002P3oool8ool0
0080oooo1Ooo00030?ooo`?oo`001P3oool:ool000L0oooo0ol00?l20?ooo`Co003o2`3oool3o`00
o`P0oooo3Ol00?l70?ooo`4000000@3oool000030000003oool0oooo00Goo`0000@0ooooool00?oo
003oo`001P3oool5ool000/0oooo1Ooo00030?ooo`?oo`003P3oool5ool000H0oooo3Ooo00080?oo
o`Goo`0000<0ooooool00?oo00000ooo00050?ooo`_oo`001@3oool3ool000@0oooo2_oo00060?oo
o`Goo`000P3oool5ool000D0oooo0ooo00060?ooo`?oo`002P3oool3ool00080oooo2?oo00030?oo
o`Goo`00103oool3ool000D0oooo2_oo00050?ooo`Ko003o00<0ooooo`00ool00?l00ol00?lA0?oo
o`?o003o00<0ooooo`00ool00?l01ol00?l;0?ooo`4000000@3oool000030000003oool0oooo00[o
o`001@3oool5ool000P0oooo1ooo000F0?ooo`?oo`001`3oool=ool000L0oooo1Ooo00020?ooo`Go
o`001@3oool9ool000D0oooo0ooo00070?ooo`?oo`0000<0ooooool00?oo00000ooo00060?ooo`Go
o`000`3oool3ool000D0oooo1Ooo00040?ooo`Goo`000`3oool4ool000030?oooooo003oo`0000?o
o`0000<0ooooool00?oo00000ooo00070?ooo`?oo`00103oool5ool000@0oooo2_oo00040?ooo`Oo
003o00<0ooooo`00ool00?l00ol00?l:0?ooo`?o003o0`3oool?o`00o`X0oooo0@0000010?ooo`00
00@000000?ooo`3oool0oooo0ooo00000`3oooooo`00ool00003ool000D0oooo1Ooo00060?ooo`Wo
o`00803oool=ool000H0oooo1Ooo00040?ooo`?oo`001`3oool7ool000D0oooo1Ooo00090?ooo`Go
o`00203oool3ool000`0oooo1_oo00030?ooo`Goo`000P3oool;ool000030?oooooo003oo`0000?o
o`001P3oool3ool000D0oooo1Ooo00030?ooo`[oo`001@3oool7o`00o`030?ooool00?oo003o00?o
003o2@3oool5o`00o`80oooo1Ol00?l00`3ooooo003oo`00o`07o`00o`X0oooo0@0000010?ooo`00
00D00000ool00?oo003oo`000?ooo`08ool000030?oooooo003oo`0000;oo`0000@0ooooool00?oo
003oo`00103oool<ool000H0oooo0ooo000H0?ooo`?oo`0000D0ooooool00?oo003oo`000?ooo`03
ool000L0oooo1Ooo000?0?ooo`Koo`001@3oool5ool000T0oooo1ooo00020?ooo`?oo`001P3oool3
ool000L0oooo1ooo00020?oooa;oo`000P3oool3ool000H0oooo1Ooo00040?ooo`Goo`000`3oool9
ool000H0oooo3?l00?l:0?ooo`Go003o0P3oool5o`00o`<0oooo1ol00?l:0?ooo`4000000@3oool0
01?oo`001P3oool<ool000H0oooo1Ooo0000103oooooo`00ool00?oo000B0?ooo`Goo`00103oool4
ool000H0oooo1Ooo00060?ooo`?oo`001`3oool4ool000H0oooo1Ooo00090?ooo`goo`00103oool5
ool000L0oooo1_oo00030?ooo`coo`0000@0ooooool00?oo003oo`002`3oool6ool000D0oooo0ooo
00040?ooo`Woo`00103oool6o`00o`030?ooool00?oo003o00?o003o1@3oool3o`00o`@0oooo1Ol0
0?l30?ooo`?o003o103oool6o`00o`/0oooo0@0000010?ooo`004ooo00060?ooo`[oo`00203oool:
ool00140oooo1_oo00020?ooo`Woo`000`3oool3ool000H0oooo2?oo000>0?ooo`?oo`002@3oool>
ool000@0oooo1Ooo00060?ooo`Ooo`001@3oool9ool000l0oooo1ooo000=0?ooo`Ooo`00103oool5
o`00o`<0oooo1Ol00?l40?ooo`co003o2P3oool5o`00o`d0oooo0@0000010?ooo`004ooo00060?oo
o`[oo`00203oool:ool00140oooo1_oo00020?ooo`[oo`001`3oool3ool000030?oooooo003oo`00
00Ooo`00603oool?ool000@0oooo1Ooo00050?ooo`Ooo`001P3oool5ool001<0oooo1_oo0000103o
ooooo`00ool00?oo000;0?ooo`Koo`00103oool5o`00o`<0oooo1Ol00?l40?ooo`[o003o303oool5
o`00o`d0oooo0@0000010?ooo`0000<00000ool00?oo00001Ooo00020?ooo`Soo`00203oool3ool0
0080oooo0ooo000:0?ooo`?oo`0000<0ooooool00?oo00001_oo000?0?ooo`Goo`000P3oool:ool0
00H0oooo3_oo000H0?ooo`Goo`0000@0ooooool00?oo003oo`000P3oool3ool000H0oooo0ooo0006
0?ooo`Goo`002@3oool3ool001@0oooo2ooo00060?ooo`Coo`000P3oool3ool000D0oooo1Ol00?l4
0?ooo`?o003o1@3oool:o`00o``0oooo1Ol00?l=0?ooo`4000000@3oool000040000003oool0oooo
0?ooo`?oo`001@3oool3ool001`0oooo1Ooo00000`3oooooo`00ool00006ool000l0oooo0ooo0004
0?ooo`Woo`001P3oool>ool001P0oooo1Ooo000C0?ooo`[oo`003`3oool3ool000P0oooo0ooo0003
0?ooo`_oo`001@3oool6ool000X0oooo0ol00?l=0?ooo`[o003o00<0ooooo`00ool00?l01?l00?l6
0?ooo`?o003o3P3oool100000040oooo00000`000000oooo0?ooo`0X0?ooo`Goo`00103oool5ool0
00h0oooo1_oo00070?ooo`?oo`001@3oool8ool000@0oooo1?oo00030?ooo`?oo`004@3oool5ool0
01<0oooo2_oo00020?ooo`?oo`002P3oool5ool000H0oooo1Ooo00030?ooo`[oo`001@3oool:ool0
01H0oooo2Ol00?l00`3ooooo003oo`00o`06o`00oaH0oooo0@0000010?ooo`0000<000000?ooo`3o
ool02`3oool3ool001D0oooo0ooo00020?ooo`Goo`00103oool5ool000<0oooo0ooo00070?ooo`So
o`002`3oool;ool000@0oooo1Ooo00000`3oooooo`00ool00003ool000l0oooo1Ooo000D0?ooo`So
o`000`3oool5ool000T0oooo1Ooo00050?ooo`Koo`00103oool:ool000@0oooo2ooo000E0?ooo`Go
003o1@3oool8o`00o`H0oooo0ol00?l=0?ooo`4000000@3oool000030000003oool0oooo00X0oooo
1Ooo000C0?ooo`Goo`000P3oool3ool000H0oooo0ooo00030?ooo`Goo`001P3oool9ool000T0oooo
2ooo00040?ooo`Koo`0000<0ooooool00?oo00000ooo000?0?ooo`Goo`00503oool8ool000<0oooo
1Ooo00090?ooo`Goo`00103oool7ool000@0oooo1Ooo00000`3oooooo`00ool00003ool000<0oooo
2ooo000F0?ooo`?o003o1P3oool8o`00o`D0oooo1Ol00?l<0?ooo`4000000@3oool000030000003o
ooooo`0000;oo`00203oool5ool001<0oooo1Ooo000A0?ooo`Goo`001P3oool9ool000T0oooo2?oo
00070?ooo`Koo`0000<0ooooool00?oo00000ooo000?0?ooo`Koo`00503oool6ool000@0oooo1Ooo
000:0?ooo`?oo`001@3oool6ool000D0oooo1Ooo00000`3oooooo`00ool00003ool000<0oooo2ooo
000P0?ooo`Ko003o1P3oool5o`00o``0oooo0@0000010?ooo`0000<00000ool00?oo00000ooo0007
0?ooo`Goo`004`3oool5ool00140oooo1Ooo00070?ooo`Soo`002@3oool7ool000P0oooo1_oo0002
0?ooo`?oo`004@3oool5ool001l0oooo0ooo000C0?ooo`Goo`001P3oool5ool000030?oooooo003o
o`0000?oo`000`3oool:ool00140oooo0ol00?lI0?ooo`Go003o303oool100000040oooo00000`00
003oo`00ool00003ool000L0oooo1?oo000E0?ooo`?oo`0000@0ooooool00?oo003oo`000P3oool3
ool000X0oooo0ooo00070?ooo`Soo`002`3oool3ool000`0oooo1?oo00040?ooo`?oo`00403oool5
ool001D0oooo0ooo00090?ooo`?oo`004P3oool3ool000P0oooo0ooo00030?ooo`?oo`001@3oool3
ool001H0oooo1Ol00?lI0?ooo`?o003o1@3oool3o`00o`D0oooo0@0000010?ooo`0000<00000ool0
0?oo00000ooo00060?ooo`Goo`005@3oool=ool001<0oooo1Ooo00020?ooo`?oo`004P3oool3ool0
00X0oooo1Ooo000:0?ooo`?oo`000`3oool3ool001D0oooo1ooo00050?ooo`Goo`003`3oool3ool0
02D0oooo0ol00?l90?ooo`Go003o1`3oool3o`00o`d0oooo0ol00?l60?ooo`Go003o103oool10000
0040oooo00000`000000ooooool00002ool000L0oooo1Ooo000D0?ooo`koo`004`3oool5ool00003
0?oooooo003oo`0000?oo`00403oool5ool000T0oooo1Ooo00070?ooo`Ooo`006P3oool;ool00003
0?oooooo003oo`0000?oo`003P3oool5ool002<0oooo1Ol00?l80?ooo`Go003o1P3oool5o`00o`/0
oooo1Ol00?l50?ooo`Go003o103oool100000040oooo00000`000000oooo0?ooo`090?ooo`Goo`00
4@3ooolAool001@0oooo0ooo00020?ooo`Goo`00103oool3ool000T0oooo1Ooo00090?ooo`Goo`00
1P3oool8ool001X0oooo4Ooo000>0?ooo`Goo`008`3oool5o`00o`<0oooo0ol00?l30?ooo`?o003o
0`3oool3o`00o`030?ooool00?oo003o00?o003o0`3oool3o`00o`D0oooo1Ol00?l50?ooo`Go003o
103oool100000040oooo00000`000000oooo0?ooo`040?ooo`Coo`0000<0ooooool00?oo00000_oo
000A0?ooo`coo`000P3oool3ool001X0oooo1Ooo00030?ooo`Goo`00203oool5ool000X0oooo0ooo
00070?ooo`[oo`006@3oool;ool000040?oooooo003oo`00ool000l0oooo1ooo000Q0?ooo`Go003o
0P3oool5o`00o`L0oooo2_l00?l20?ooo`Go003o103oool6o`00o`D0oooo1Ol00?l30?ooo`400000
0@3oool000030000003oool0oooo00<0oooo2_oo000A0?ooo`Soo`00903oool3ool000@0oooo1Ooo
00090?ooo`?oo`005@3oool;ool001/0oooo2Ooo000C0?ooo`Ooo`002P3oool3ool00180oooo1Ol0
0?l30?ooo`Go003o1`3oool5o`00o`040?ooool00?oo003oo`00o`<0oooo1Ol00?l50?ooo`Ko003o
0`3oool6o`00o`<0oooo0@0000010?ooo`0000<000000?ooo`3oool00`3oool:ool000d0oooo0ooo
00000`3oooooo`00ool00003ool002h0oooo1Ooo000R0?ooo`?oo`000P3oool5ool001/0oooo2_oo
000D0?ooo`Koo`00203oool5ool00140oooo1Ol00?l30?ooo`Go003o1`3oool5o`00o`L0oooo1Ol0
0?l60?ooo`Go003o0P3oool7o`00o`<0oooo0@0000010?ooo`0000<000000?ooo`3oool00`3oool:
ool000`0oooo2_oo00070?ooo`?oo`000P3oool3ool001P0oooo0ooo00050?ooo`?oo`00:03oool5
ool001`0oooo0ooo00000`3oooooo`00ool00003ool000T0oooo0ooo00050?ooo`[oo`001`3oool5
ool00140oooo1Ol00?l20?ooo`Go003o2@3oool3o`00o`P0oooo1Ol00?l60?ooo`Go003o0P3oool6
o`00o`@0oooo0@0000010?ooo`0000<000000?ooo`3oool0103oool8ool000`0oooo2ooo00060?oo
o`[oo`003P3oool3ool000D0oooo1Ooo00070?ooo`?oo`003`3oool3ool000<0oooo0ooo000<0?oo
o`Goo`008@3oool5ool000P0oooo1Ooo00030?ooo`_oo`001`3oool5ool000<0oooo0ooo000<0?oo
o`?o003o0`3oool5o`00oa@0oooo1Ol00?l70?ooo`?o003o0`3oool5o`00o`D0oooo0@0000010?oo
o`0000<000000?ooo`3oool01@3oool5ool000h0oooo1_oo0000103oooooo`00ool00?oo00070?oo
o`[oo`003@3oool5ool000@0oooo1Ooo00060?ooo`Koo`00303oool5ool000030?oooooo003oo`00
00?oo`001@3oool3ool000<0oooo1Ooo000L0?ooo`?oo`000`3oool5ool000L0oooo1Ooo00030?oo
o`_oo`0000@0ooooool00?oo003oo`00103oool4ool00080oooo1Ooo000>0?ooo`So003o5@3oool3
o`00o`l0oooo0ol00?l60?ooo`4000000@3oool000030000003oool0oooo00D0oooo1Ooo000<0?oo
o`Ooo`00303oool:ool000d0oooo1Ooo00040?ooo`Goo`001P3oool7ool000/0oooo1Ooo00000`3o
ooooo`00ool00003ool000@0oooo1Ooo00020?ooo`Goo`006`3oool5ool00080oooo1Ooo00070?oo
o`Goo`000`3oool@ool000<0oooo1Ooo00000`3oooooo`00ool00003ool000H0oooo0ooo00040?oo
o`So003o5`3oool3o`00o`l0oooo0ol00?l50?ooo`4000000@3oool000030000003oooooo`0000;o
o`000`3oool5ool000/0oooo1ooo00040?ooo`?oo`001`3oool3ool00080oooo0ooo000;0?ooo`So
o`001@3oool3ool000L0oooo1ooo00070?ooo`?oo`0000<0ooooool00?oo00000ooo00000`3ooooo
o`00ool00003ool000@0oooo1Ooo00030?ooo`?oo`00703oool5ool00080oooo1Ooo00080?ooo`Ko
o`000P3oool?ool000<0oooo1Ooo00000`3oooooo`00ool00003ool000D0oooo1Ooo00000`3ooooo
003oo`00o`05o`00oaH0oooo2?l00?l=0?ooo`Go003o103oool100000040oooo00000`00003oo`00
ool00003ool000<0oooo1Ooo00080?ooo`Ooo`001@3oool5ool001P0oooo2?oo000>0?ooo`Woo`00
1P3oool5ool000040?oooooo003oo`00ool000<0oooo0ooo00050?ooo`Goo`0000@0ooooool00?oo
003oo`003@3oool3ool000h0oooo1Ooo00030?ooo`?oo`002@3oool7ool00080oooo3_oo00030?oo
o`Goo`000P3oool4ool000D0oooo1Ooo0008o`00o`H0oooo0ol00?l40?ooo`Ko003o0P3oool9o`00
o``0oooo1_l00?l40?ooo`4000000@3oool0000300000?oo003oo`0000?oo`00103oool5ool000H0
oooo2Ooo00020?ooo`Ooo`00603oool5ool00100oooo1Ooo0000103oooooo`00ool00?oo00070?oo
o`Goo`000P3oool6ool000P0oooo0ooo00000`3oooooo`00ool00003ool000T0oooo1ooo000>0?oo
o`?oo`000`3oool3ool000T0oooo2?oo00000`3oooooo`00ool00003ool000030?oooooo003oo`00
00Koo`001@3oool3ool000<0oooo1Ooo00040?ooo`Goo`001ol00?l60?ooo`Go003o0P3oool8o`00
o`030?ooool00?oo003o00So003o2`3oool6o`00o`@0oooo0@0000010?ooo`0000<00000ool00?oo
00000ooo00040?ooo`Goo`001P3oool9ool000030?oooooo003oo`0000Koo`005P3oool7ool000/0
oooo0ooo00020?ooo`[oo`001P3oool5ool000030?oooooo003oo`0000Koo`002`3oool5ool000P0
oooo2?oo000C0?ooo`Goo`00203oool=ool00080oooo1Ooo000>0?ooo`Goo`001@3oool3ool00003
0?ooool00?oo003o00?o003o203oool5o`00o`80oooo2?l00?l00`3ooooo003oo`00o`08o`00o`X0
oooo1_l00?l50?ooo`4000000@3oool000030000003oooooo`0000;oo`001@3oool5ool000@0oooo
2ooo00000`3oooooo`00ool00005ool001H0oooo1ooo000;0?ooo`Goo`0000<0ooooool00?oo0000
2?oo00070?ooo`?oo`000P3oool8ool00080oooo0ooo00060?ooo`Goo`00203oool8ool001<0oooo
1Ooo00080?ooo`Ooo`0000<0ooooool00?oo00000ooo00020?ooo`Goo`003P3oool5ool000X0oooo
0ol00?l90?ooo`Go003o0P3oool8o`00o`80oooo0ol00?l00`3ooooo003oo`00o`03o`00o`040?oo
ool00?oo003oo`00o`D0oooo2Ol00?l30?ooo`4000000@3oool000030000003oool0oooo00P0oooo
0ooo00040?ooo`Ooo`0000@0ooooool00?oo003oo`000P3oool5ool001P0oooo1Ooo000=0?ooo`Go
o`000P3oool3ool000030?oooooo003oo`0000?oo`001@3oool3ool000@0oooo2?oo00000`3ooooo
o`00ool00003ool000H0oooo0ooo00090?ooo`Ooo`000`3oool3ool000h0oooo1Ooo00090?ooo`?o
o`00103oool5ool00080oooo1ooo000=0?ooo`?oo`0000@0ooooool00?oo003oo`00503oool3o`00
o`@0oooo1_l00?l30?ooo`?o003o0P3oool3o`00o`030?ooool00?oo003o00?o003o103oool:o`00
o`80oooo0@0000010?ooo`0000<000000?ooo`3oool03`3oool5ool000T0oooo1_oo000F0?ooo`Go
o`003@3oool7ool000D0oooo0ooo00050?ooo`Goo`00103oool6ool00080oooo1Ooo000C0?ooo`?o
o`001@3oool8ool000/0oooo0ooo000B0?ooo`?oo`000`3oool8ool000l0oooo1Ooo000R0?ooo`Go
003o1@3oool5o`00o`@0oooo2_l00?l20?ooo`4000000@3oool000030000003oool0oooo00d0oooo
1ooo000;0?ooo`Goo`00203oool3ool000/0oooo0ooo000?0?ooo`Ooo`00303oool5ool000D0oooo
0ooo00040?ooo`Goo`004P3oool3ool000H0oooo2Ooo000>0?ooo`?oo`005@3oool7ool000l0oooo
2?oo00060?ooo`?o003o5P3oool5o`00o`D0oooo3Ol00?l00`3ooooo003oo`00o`03o`00o`80oooo
0@0000010?ooo`0000<000000?ooo`3oool0203oool3ool000030?oooooo003oo`0000Goo`00303o
ool5ool000L0oooo1Ooo000N0?ooo`Goo`001@3oool3ool000<0oooo1_oo000=0?ooo`?oo`004P3o
ool5ool000D0oooo2Ooo000=0?ooo`Goo`005P3oool7ool000d0oooo2Ooo00040?ooo`Go003o3@3o
ool3o`00o`D0oooo1Ol00?l60?ooo`[o003o103oool3o`00o`<0oooo0@0000010?ooo`0000<00000
0?ooo`3oool01`3oool:ool000h0oooo1Ooo00070?ooo`Goo`007P3oool8ool000030?oooooo003o
o`0000?oo`0000<0ooooool00?oo00001?oo000S0?ooo`Goo`001P3oool8ool000d0oooo1Ooo000:
0?ooo`?oo`002P3oool7ool000d0oooo2?oo00040?ooo`Go003o2`3oool7o`00o`030?ooool00?oo
003o00Go003o2@3oool7o`00o`X0oooo0@0000010?ooo`0000<000000?ooo`3oool01`3oool:ool0
00l0oooo0ooo00080?ooo`Soo`001P3oool4ool00140oooo3_oo00000`3oooooo`00ool00003ool0
00l0oooo0ooo000A0?ooo`Koo`002P3oool3ool000P0oooo0ooo00030?ooo`Goo`002@3oool5ool0
00T0oooo1ooo000@0?ooo`Goo`00103oool7o`00o`P0oooo4?l00?l90?ooo`Oo003o2P3oool10000
0040oooo00000`000000oooo0?ooo`070?ooo`Goo`0000@0ooooool00?oo003oo`00703oool8ool0
00@0oooo1_oo000@0?oooaCoo`001@3oool3ool000H0oooo1Ooo00060?ooo`?oo`001P3oool6ool0
01D0oooo3?oo00090?ooo`Goo`0000@0ooooool00?oo003oo`00103oool8ool00140oooo0ooo0006
0?ooo`Oo003o1`3oool?o`00o`040?ooool00?oo003oo`00o`L0oooo1_l00?l:0?ooo`4000000@3o
ool000030000003oool0oooo00P0oooo0ooo000S0?ooo`Koo`00103oool6ool00100oooo2Ooo0000
0`3oooooo`00ool00008ool000@0oooo1Ooo00050?ooo`Goo`001@3oool5ool000D0oooo1Ooo000F
0?ooo`goo`00203oool:ool000<0oooo1ooo000M0?ooo`Go003o1`3oool=o`00o`80oooo2?l00?l5
0?ooo`?o003o2`3oool100000040oooo00000`000000oooo0?ooo`0^0?ooo`Koo`00103oool6ool0
0140oooo0ooo0000103oooooo`00ool00?oo00030?ooo`Woo`00103oool5ool000D0oooo1Ooo0005
0?ooo`Goo`001@3oool5ool001H0oooo3Ooo00090?ooo`?oo`0000<0ooooool00?oo00000ooo0003
0?ooo`Goo`007`3oool5o`00o`L0oooo2?l00?l0103ooooo003oo`00ool00?l30?ooo`Wo003o4P3o
ool100000040oooo00000`000000oooo0?ooo`0_0?ooo`Coo`001@3oool5ool001`0oooo2Ooo0004
0?ooo`Goo`001P3oool3ool000H0oooo1Ooo00060?ooo`?oo`00603oool<ool000d0oooo1Ooo0004
0?ooo`?oo`008@3oool3o`00o`P0oooo1Ol00?l:0?ooo`Wo003o4P3oool100000040oooo00000`00
0000oooo0?ooo`0h0?ooo`Goo`007@3oool3ool000040?oooooo003oo`00ool000H0oooo0ooo000A
0?ooo`?oo`009P3oool3ool000040?oooooo003oo`00ool000l0oooo0ooo000e0?ooo`?o003o303o
ool8o`00oa80oooo0@0000010?ooo`00?0000003ool00<T000000ol00?lD00000040oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0104497, -0.0104497, \
0.00355714, 0.00355714}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gaussian probability density functions", "Subsection"],

Cell[CellGroupData[{

Cell["Compute Gaussian pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[data1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[data2, {x, y}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["View Gaussian pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.2 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.3 g
.01923 .32533 m
.02289 .31509 L
.03262 .29043 L
.04371 .26578 L
.04389 .26542 L
.05631 .24112 L
.06854 .2198 L
.07058 .21647 L
.08678 .19181 L
.0932 .18287 L
.10524 .16716 L
.11785 .15209 L
.12647 .1425 L
.1425 .12609 L
.15124 .11785 L
.16716 .10402 L
.18088 .0932 L
.19181 .08528 L
.21647 .0695 L
.21812 .06854 L
.24112 .0564 L
.26578 .04575 L
.27066 .04389 L
.29043 .03741 L
.31509 .03127 L
.33974 .02728 L
.3644 .02538 L
.38905 .02555 L
.41371 .02782 L
.43836 .03223 L
.46302 .03884 L
.47785 .04389 L
.48767 .04776 L
.51233 .05914 L
.52939 .06854 L
.53698 .07318 L
.56164 .09016 L
.56561 .0932 L
.58629 .11049 L
.59426 .11785 L
.61095 .13471 L
.61803 .1425 L
.6356 .16369 L
.63827 .16716 L
.65574 .19181 L
.66026 .1988 L
.67094 .21647 L
.68422 .24112 L
.68491 .24251 L
.69581 .26578 L
.7059 .29043 L
.70957 .30032 L
.71463 .31509 L
.7221 .33974 L
.7284 .3644 L
.7336 .38905 L
.73422 .39235 L
.73773 .41371 L
.74084 .43836 L
.74297 .46302 L
.74413 .48767 L
.74433 .51233 L
.74358 .53698 L
.74189 .56164 L
.73923 .58629 L
.7356 .61095 L
.73422 .61893 L
.73096 .6356 L
.72528 .66026 L
.71852 .68491 L
.71063 .70957 L
.70957 .71263 L
.70151 .73422 L
.69109 .75888 L
.68491 .77212 L
.67924 .78353 L
.66579 .80819 L
.66026 .81751 L
.65055 .83284 L
.6356 .85429 L
.63322 .8575 L
.61338 .88215 L
.61095 .88495 L
.59043 .9068 L
.58629 .91086 L
.56333 .93146 L
.56164 .93286 L
.53698 .95152 L
.53023 .95611 L
.51233 .96724 L
.48767 .9803 L
.48668 .98077 L
.01923 .98077 L
F
0 g
.01923 .32533 m
.02289 .31509 L
.03262 .29043 L
.04371 .26578 L
.04389 .26542 L
.05631 .24112 L
.06854 .2198 L
.07058 .21647 L
.08678 .19181 L
.0932 .18287 L
.10524 .16716 L
.11785 .15209 L
.12647 .1425 L
.1425 .12609 L
.15124 .11785 L
.16716 .10402 L
.18088 .0932 L
.19181 .08528 L
.21647 .0695 L
.21812 .06854 L
.24112 .0564 L
.26578 .04575 L
.27066 .04389 L
.29043 .03741 L
.31509 .03127 L
.33974 .02728 L
.3644 .02538 L
.38905 .02555 L
.41371 .02782 L
.43836 .03223 L
.46302 .03884 L
.47785 .04389 L
.48767 .04776 L
.51233 .05914 L
.52939 .06854 L
.53698 .07318 L
.56164 .09016 L
.56561 .0932 L
.58629 .11049 L
.59426 .11785 L
.61095 .13471 L
.61803 .1425 L
.6356 .16369 L
.63827 .16716 L
.65574 .19181 L
.66026 .1988 L
.67094 .21647 L
.68422 .24112 L
.68491 .24251 L
.69581 .26578 L
Mistroke
.7059 .29043 L
.70957 .30032 L
.71463 .31509 L
.7221 .33974 L
.7284 .3644 L
.7336 .38905 L
.73422 .39235 L
.73773 .41371 L
.74084 .43836 L
.74297 .46302 L
.74413 .48767 L
.74433 .51233 L
.74358 .53698 L
.74189 .56164 L
.73923 .58629 L
.7356 .61095 L
.73422 .61893 L
.73096 .6356 L
.72528 .66026 L
.71852 .68491 L
.71063 .70957 L
.70957 .71263 L
.70151 .73422 L
.69109 .75888 L
.68491 .77212 L
.67924 .78353 L
.66579 .80819 L
.66026 .81751 L
.65055 .83284 L
.6356 .85429 L
.63322 .8575 L
.61338 .88215 L
.61095 .88495 L
.59043 .9068 L
.58629 .91086 L
.56333 .93146 L
.56164 .93286 L
.53698 .95152 L
.53023 .95611 L
.51233 .96724 L
.48767 .9803 L
.48668 .98077 L
Mfstroke
.2 g
.01923 .73461 m
.02851 .75888 L
.03938 .78353 L
.04389 .79285 L
.05183 .80819 L
.06607 .83284 L
.06854 .83679 L
.08241 .8575 L
.0932 .87205 L
.10125 .88215 L
.11785 .90114 L
.12321 .9068 L
.1425 .92546 L
.14931 .93146 L
.16716 .94586 L
.18142 .95611 L
.19181 .96292 L
.21647 .97702 L
.22394 .98077 L
.01923 .98077 L
F
0 g
.01923 .73461 m
.02851 .75888 L
.03938 .78353 L
.04389 .79285 L
.05183 .80819 L
.06607 .83284 L
.06854 .83679 L
.08241 .8575 L
.0932 .87205 L
.10125 .88215 L
.11785 .90114 L
.12321 .9068 L
.1425 .92546 L
.14931 .93146 L
.16716 .94586 L
.18142 .95611 L
.19181 .96292 L
.21647 .97702 L
.22394 .98077 L
s
.1 g
.01923 .18038 m
.02724 .16716 L
.04352 .1425 L
.04389 .14198 L
.06175 .11785 L
.06854 .10936 L
.08229 .0932 L
.0932 .08127 L
.10565 .06854 L
.11785 .05693 L
.13264 .04389 L
.1425 .03578 L
.16463 .01923 L
.01923 .01923 L
F
0 g
.01923 .18038 m
.02724 .16716 L
.04352 .1425 L
.04389 .14198 L
.06175 .11785 L
.06854 .10936 L
.08229 .0932 L
.0932 .08127 L
.10565 .06854 L
.11785 .05693 L
.13264 .04389 L
.1425 .03578 L
.16463 .01923 L
s
.1 g
.01923 .87957 m
.02082 .88215 L
.03708 .9068 L
.04389 .91629 L
.05547 .93146 L
.06854 .94723 L
.07641 .95611 L
.0932 .97365 L
.10055 .98077 L
.01923 .98077 L
F
0 g
.01923 .87957 m
.02082 .88215 L
.03708 .9068 L
.04389 .91629 L
.05547 .93146 L
.06854 .94723 L
.07641 .95611 L
.0932 .97365 L
.10055 .98077 L
s
.4 g
.31509 .09214 m
.33974 .0877 L
.3644 .08565 L
.38905 .08597 L
.41371 .08868 L
.43626 .0932 L
.43836 .09384 L
.46302 .10156 L
.48767 .11199 L
.49922 .11785 L
.51233 .12539 L
.53698 .14208 L
.53755 .1425 L
.56164 .16256 L
.56656 .16716 L
.58629 .18759 L
.59 .19181 L
.60956 .21647 L
.61095 .21838 L
.62617 .24112 L
.6356 .25707 L
.64037 .26578 L
.65254 .29043 L
.66026 .30832 L
.66295 .31509 L
.67178 .33974 L
.67918 .3644 L
.68491 .3875 L
.68525 .38905 L
.69008 .41371 L
.69372 .43836 L
.69622 .46302 L
.69761 .48767 L
.69792 .51233 L
.69714 .53698 L
.69527 .56164 L
.69231 .58629 L
.68822 .61095 L
.68491 .62719 L
.68297 .6356 L
.6765 .66026 L
.66875 .68491 L
.66026 .70799 L
.65963 .70957 L
.64899 .73422 L
.6367 .75888 L
.6356 .76091 L
.62251 .78353 L
.61095 .80128 L
.60611 .80819 L
.58705 .83284 L
.58629 .83375 L
.56461 .8575 L
.56164 .86046 L
.53756 .88215 L
.53698 .88262 L
.51233 .90099 L
.50344 .9068 L
.48767 .91606 L
.46302 .92818 L
.45529 .93146 L
.43836 .93757 L
.41371 .94441 L
.38905 .9488 L
.3644 .9508 L
.33974 .95043 L
.31509 .94767 L
.29043 .94245 L
.26578 .93468 L
.25739 .93146 L
.24112 .92418 L
.21647 .91072 L
.21021 .9068 L
.19181 .89395 L
.17706 .88215 L
.16716 .87338 L
.15101 .8575 L
.1425 .84823 L
.12957 .83284 L
.11785 .81731 L
.11151 .80819 L
.09611 .78353 L
.0932 .7784 L
.08292 .75888 L
.07161 .73422 L
.06854 .72679 L
.06198 .70957 L
.05385 .68491 L
.04709 .66026 L
.04389 .64657 L
.04162 .6356 L
.03736 .61095 L
.03427 .58629 L
.0323 .56164 L
.03143 .53698 L
.03164 .51233 L
.03294 .48767 L
.03533 .46302 L
.03883 .43836 L
.04347 .41371 L
.04389 .41175 L
.0493 .38905 L
.05637 .3644 L
.06476 .33974 L
.06854 .3298 L
.07459 .31509 L
.08599 .29043 L
.0932 .27651 L
.09916 .26578 L
.11436 .24112 L
.11785 .23593 L
.13195 .21647 L
.1425 .20332 L
.15251 .19181 L
.16716 .1765 L
.17695 .16716 L
.19181 .15425 L
.20694 .1425 L
.21647 .1358 L
.24112 .12066 L
.24629 .11785 L
.26578 .10848 L
.29043 .09903 L
.31044 .0932 L
F
0 g
.31509 .09214 m
.33974 .0877 L
.3644 .08565 L
.38905 .08597 L
.41371 .08868 L
.43626 .0932 L
.43836 .09384 L
.46302 .10156 L
.48767 .11199 L
.49922 .11785 L
.51233 .12539 L
.53698 .14208 L
.53755 .1425 L
.56164 .16256 L
.56656 .16716 L
.58629 .18759 L
.59 .19181 L
.60956 .21647 L
.61095 .21838 L
.62617 .24112 L
.6356 .25707 L
.64037 .26578 L
.65254 .29043 L
.66026 .30832 L
.66295 .31509 L
.67178 .33974 L
.67918 .3644 L
.68491 .3875 L
.68525 .38905 L
.69008 .41371 L
.69372 .43836 L
.69622 .46302 L
.69761 .48767 L
.69792 .51233 L
.69714 .53698 L
.69527 .56164 L
.69231 .58629 L
.68822 .61095 L
.68491 .62719 L
.68297 .6356 L
.6765 .66026 L
.66875 .68491 L
.66026 .70799 L
.65963 .70957 L
.64899 .73422 L
.6367 .75888 L
.6356 .76091 L
.62251 .78353 L
.61095 .80128 L
.60611 .80819 L
Mistroke
.58705 .83284 L
.58629 .83375 L
.56461 .8575 L
.56164 .86046 L
.53756 .88215 L
.53698 .88262 L
.51233 .90099 L
.50344 .9068 L
.48767 .91606 L
.46302 .92818 L
.45529 .93146 L
.43836 .93757 L
.41371 .94441 L
.38905 .9488 L
.3644 .9508 L
.33974 .95043 L
.31509 .94767 L
.29043 .94245 L
.26578 .93468 L
.25739 .93146 L
.24112 .92418 L
.21647 .91072 L
.21021 .9068 L
.19181 .89395 L
.17706 .88215 L
.16716 .87338 L
.15101 .8575 L
.1425 .84823 L
.12957 .83284 L
.11785 .81731 L
.11151 .80819 L
.09611 .78353 L
.0932 .7784 L
.08292 .75888 L
.07161 .73422 L
.06854 .72679 L
.06198 .70957 L
.05385 .68491 L
.04709 .66026 L
.04389 .64657 L
.04162 .6356 L
.03736 .61095 L
.03427 .58629 L
.0323 .56164 L
.03143 .53698 L
.03164 .51233 L
.03294 .48767 L
.03533 .46302 L
.03883 .43836 L
.04347 .41371 L
Mistroke
.04389 .41175 L
.0493 .38905 L
.05637 .3644 L
.06476 .33974 L
.06854 .3298 L
.07459 .31509 L
.08599 .29043 L
.0932 .27651 L
.09916 .26578 L
.11436 .24112 L
.11785 .23593 L
.13195 .21647 L
.1425 .20332 L
.15251 .19181 L
.16716 .1765 L
.17695 .16716 L
.19181 .15425 L
.20694 .1425 L
.21647 .1358 L
.24112 .12066 L
.24629 .11785 L
.26578 .10848 L
.29043 .09903 L
.31044 .0932 L
.31509 .09214 L
Mfstroke
.5 g
.33974 .14049 m
.3644 .13827 L
.38905 .13875 L
.41371 .14196 L
.41688 .1425 L
.43836 .14799 L
.46302 .157 L
.48397 .16716 L
.48767 .16924 L
.51233 .18511 L
.52122 .19181 L
.53698 .20519 L
.54871 .21647 L
.56164 .23043 L
.57057 .24112 L
.58629 .26244 L
.58854 .26578 L
.60353 .29043 L
.61095 .30443 L
.61611 .31509 L
.62664 .33974 L
.63538 .3644 L
.6356 .3651 L
.64249 .38905 L
.64813 .41371 L
.65238 .43836 L
.65531 .46302 L
.65697 .48767 L
.65739 .51233 L
.65657 .53698 L
.65451 .56164 L
.65119 .58629 L
.64659 .61095 L
.64063 .6356 L
.6356 .65291 L
.63323 .66026 L
.62429 .68491 L
.61365 .70957 L
.61095 .71523 L
.60109 .73422 L
.58631 .75888 L
.58629 .7589 L
.56886 .78353 L
.56164 .79259 L
.54801 .80819 L
.53698 .8195 L
.52252 .83284 L
.51233 .84126 L
.48974 .8575 L
.48767 .85881 L
.46302 .87274 L
.44178 .88215 L
.43836 .88342 L
.41371 .89113 L
.38905 .89602 L
.3644 .89818 L
.33974 .89764 L
.31509 .89437 L
.29043 .88828 L
.27271 .88215 L
.26578 .8792 L
.24112 .86688 L
.22586 .8575 L
.21647 .85093 L
.19412 .83284 L
.19181 .83075 L
.16962 .80819 L
.16716 .80539 L
.14976 .78353 L
.1425 .77321 L
.1333 .75888 L
.11952 .73422 L
.11785 .73093 L
.10796 .70957 L
.09831 .68491 L
.0932 .66966 L
.09036 .66026 L
.08397 .6356 L
.079 .61095 L
.07539 .58629 L
.07307 .56164 L
.07201 .53698 L
.07218 .51233 L
.07359 .48767 L
.07625 .46302 L
.08017 .43836 L
.08542 .41371 L
.09205 .38905 L
.0932 .38527 L
.10017 .3644 L
.1099 .33974 L
.11785 .3223 L
.12143 .31509 L
.135 .29043 L
.1425 .27835 L
.15099 .26578 L
.16716 .24449 L
.16995 .24112 L
.19181 .21745 L
.19282 .21647 L
.21647 .19559 L
.2213 .19181 L
.24112 .17796 L
.25954 .16716 L
.26578 .16396 L
.29043 .15321 L
.31509 .14544 L
.32593 .1425 L
F
0 g
.33974 .14049 m
.3644 .13827 L
.38905 .13875 L
.41371 .14196 L
.41688 .1425 L
.43836 .14799 L
.46302 .157 L
.48397 .16716 L
.48767 .16924 L
.51233 .18511 L
.52122 .19181 L
.53698 .20519 L
.54871 .21647 L
.56164 .23043 L
.57057 .24112 L
.58629 .26244 L
.58854 .26578 L
.60353 .29043 L
.61095 .30443 L
.61611 .31509 L
.62664 .33974 L
.63538 .3644 L
.6356 .3651 L
.64249 .38905 L
.64813 .41371 L
.65238 .43836 L
.65531 .46302 L
.65697 .48767 L
.65739 .51233 L
.65657 .53698 L
.65451 .56164 L
.65119 .58629 L
.64659 .61095 L
.64063 .6356 L
.6356 .65291 L
.63323 .66026 L
.62429 .68491 L
.61365 .70957 L
.61095 .71523 L
.60109 .73422 L
.58631 .75888 L
.58629 .7589 L
.56886 .78353 L
.56164 .79259 L
.54801 .80819 L
.53698 .8195 L
.52252 .83284 L
.51233 .84126 L
.48974 .8575 L
.48767 .85881 L
Mistroke
.46302 .87274 L
.44178 .88215 L
.43836 .88342 L
.41371 .89113 L
.38905 .89602 L
.3644 .89818 L
.33974 .89764 L
.31509 .89437 L
.29043 .88828 L
.27271 .88215 L
.26578 .8792 L
.24112 .86688 L
.22586 .8575 L
.21647 .85093 L
.19412 .83284 L
.19181 .83075 L
.16962 .80819 L
.16716 .80539 L
.14976 .78353 L
.1425 .77321 L
.1333 .75888 L
.11952 .73422 L
.11785 .73093 L
.10796 .70957 L
.09831 .68491 L
.0932 .66966 L
.09036 .66026 L
.08397 .6356 L
.079 .61095 L
.07539 .58629 L
.07307 .56164 L
.07201 .53698 L
.07218 .51233 L
.07359 .48767 L
.07625 .46302 L
.08017 .43836 L
.08542 .41371 L
.09205 .38905 L
.0932 .38527 L
.10017 .3644 L
.1099 .33974 L
.11785 .3223 L
.12143 .31509 L
.135 .29043 L
.1425 .27835 L
.15099 .26578 L
.16716 .24449 L
.16995 .24112 L
.19181 .21745 L
.19282 .21647 L
Mistroke
.21647 .19559 L
.2213 .19181 L
.24112 .17796 L
.25954 .16716 L
.26578 .16396 L
.29043 .15321 L
.31509 .14544 L
.32593 .1425 L
.33974 .14049 L
Mfstroke
.6 g
.33974 .18947 m
.3644 .18704 L
.38905 .18772 L
.41371 .19154 L
.41509 .19181 L
.43836 .19864 L
.46302 .20928 L
.47616 .21647 L
.48767 .22387 L
.51009 .24112 L
.51233 .2431 L
.53496 .26578 L
.53698 .2681 L
.55449 .29043 L
.56164 .30098 L
.57028 .31509 L
.58317 .33974 L
.58629 .34653 L
.59369 .3644 L
.60216 .38905 L
.60883 .41371 L
.61095 .42301 L
.61383 .43836 L
.61729 .46302 L
.61927 .48767 L
.61982 .51233 L
.61895 .53698 L
.61666 .56164 L
.61292 .58629 L
.61095 .59662 L
.60767 .61095 L
.60082 .6356 L
.59224 .66026 L
.58629 .67481 L
.58173 .68491 L
.56903 .70957 L
.56164 .72204 L
.55371 .73422 L
.53698 .7566 L
.53511 .75888 L
.51233 .78328 L
.51207 .78353 L
.48767 .80419 L
.48222 .80819 L
.46302 .82046 L
.43836 .83277 L
.43822 .83284 L
.41371 .84155 L
.38905 .84705 L
.3644 .84941 L
.33974 .84866 L
.31509 .84477 L
.29043 .8376 L
.27818 .83284 L
.26578 .82688 L
.24112 .8122 L
.23542 .80819 L
.21647 .79286 L
.20653 .78353 L
.19181 .76772 L
.1845 .75888 L
.16716 .73462 L
.1669 .73422 L
.15257 .70957 L
.1425 .68868 L
.14087 .68491 L
.13136 .66026 L
.12377 .6356 L
.11792 .61095 L
.11785 .61064 L
.11366 .58629 L
.11092 .56164 L
.10962 .53698 L
.10975 .51233 L
.1113 .48767 L
.11427 .46302 L
.11785 .44244 L
.11873 .43836 L
.12473 .41371 L
.13238 .38905 L
.14186 .3644 L
.1425 .36288 L
.15337 .33974 L
.16716 .31526 L
.16726 .31509 L
.18404 .29043 L
.19181 .28048 L
.20456 .26578 L
.21647 .25366 L
.23042 .24112 L
.24112 .23265 L
.26545 .21647 L
.26578 .21628 L
.29043 .20389 L
.31509 .19503 L
.32531 .19181 L
F
0 g
.33974 .18947 m
.3644 .18704 L
.38905 .18772 L
.41371 .19154 L
.41509 .19181 L
.43836 .19864 L
.46302 .20928 L
.47616 .21647 L
.48767 .22387 L
.51009 .24112 L
.51233 .2431 L
.53496 .26578 L
.53698 .2681 L
.55449 .29043 L
.56164 .30098 L
.57028 .31509 L
.58317 .33974 L
.58629 .34653 L
.59369 .3644 L
.60216 .38905 L
.60883 .41371 L
.61095 .42301 L
.61383 .43836 L
.61729 .46302 L
.61927 .48767 L
.61982 .51233 L
.61895 .53698 L
.61666 .56164 L
.61292 .58629 L
.61095 .59662 L
.60767 .61095 L
.60082 .6356 L
.59224 .66026 L
.58629 .67481 L
.58173 .68491 L
.56903 .70957 L
.56164 .72204 L
.55371 .73422 L
.53698 .7566 L
.53511 .75888 L
.51233 .78328 L
.51207 .78353 L
.48767 .80419 L
.48222 .80819 L
.46302 .82046 L
.43836 .83277 L
.43822 .83284 L
.41371 .84155 L
.38905 .84705 L
.3644 .84941 L
Mistroke
.33974 .84866 L
.31509 .84477 L
.29043 .8376 L
.27818 .83284 L
.26578 .82688 L
.24112 .8122 L
.23542 .80819 L
.21647 .79286 L
.20653 .78353 L
.19181 .76772 L
.1845 .75888 L
.16716 .73462 L
.1669 .73422 L
.15257 .70957 L
.1425 .68868 L
.14087 .68491 L
.13136 .66026 L
.12377 .6356 L
.11792 .61095 L
.11785 .61064 L
.11366 .58629 L
.11092 .56164 L
.10962 .53698 L
.10975 .51233 L
.1113 .48767 L
.11427 .46302 L
.11785 .44244 L
.11873 .43836 L
.12473 .41371 L
.13238 .38905 L
.14186 .3644 L
.1425 .36288 L
.15337 .33974 L
.16716 .31526 L
.16726 .31509 L
.18404 .29043 L
.19181 .28048 L
.20456 .26578 L
.21647 .25366 L
.23042 .24112 L
.24112 .23265 L
.26545 .21647 L
.26578 .21628 L
.29043 .20389 L
.31509 .19503 L
.32531 .19181 L
.33974 .18947 L
Mfstroke
.7 g
.33974 .23719 m
.3644 .2345 L
.38905 .23543 L
.41371 .24005 L
.41799 .24112 L
.43836 .24859 L
.46302 .26148 L
.46972 .26578 L
.48767 .27948 L
.49968 .29043 L
.51233 .30397 L
.52141 .31509 L
.53698 .33776 L
.53819 .33974 L
.55143 .3644 L
.56164 .38846 L
.56186 .38905 L
.56995 .41371 L
.57598 .43836 L
.58013 .46302 L
.58254 .48767 L
.58326 .51233 L
.58233 .53698 L
.57974 .56164 L
.57544 .58629 L
.56933 .61095 L
.56164 .63457 L
.56125 .6356 L
.55099 .66026 L
.53816 .68491 L
.53698 .68693 L
.52221 .70957 L
.51233 .72241 L
.50209 .73422 L
.48767 .74858 L
.47572 .75888 L
.46302 .76826 L
.43836 .78282 L
.43703 .78353 L
.41371 .79304 L
.38905 .79934 L
.3644 .80195 L
.33974 .80094 L
.31509 .79624 L
.29043 .78761 L
.28148 .78353 L
.26578 .77462 L
.24393 .75888 L
.24112 .75649 L
.21854 .73422 L
.21647 .73183 L
.19939 .70957 L
.19181 .6978 L
.18443 .68491 L
.1726 .66026 L
.16716 .64659 L
.16334 .6356 L
.15626 .61095 L
.15114 .58629 L
.14784 .56164 L
.14624 .53698 L
.14631 .51233 L
.14803 .48767 L
.15143 .46302 L
.15658 .43836 L
.1636 .41371 L
.16716 .40329 L
.17269 .38905 L
.18412 .3644 L
.19181 .35039 L
.19834 .33974 L
.21614 .31509 L
.21647 .31469 L
.23889 .29043 L
.24112 .28835 L
.26578 .26855 L
.26979 .26578 L
.29043 .25387 L
.31509 .24357 L
.32069 .24112 L
F
0 g
.33974 .23719 m
.3644 .2345 L
.38905 .23543 L
.41371 .24005 L
.41799 .24112 L
.43836 .24859 L
.46302 .26148 L
.46972 .26578 L
.48767 .27948 L
.49968 .29043 L
.51233 .30397 L
.52141 .31509 L
.53698 .33776 L
.53819 .33974 L
.55143 .3644 L
.56164 .38846 L
.56186 .38905 L
.56995 .41371 L
.57598 .43836 L
.58013 .46302 L
.58254 .48767 L
.58326 .51233 L
.58233 .53698 L
.57974 .56164 L
.57544 .58629 L
.56933 .61095 L
.56164 .63457 L
.56125 .6356 L
.55099 .66026 L
.53816 .68491 L
.53698 .68693 L
.52221 .70957 L
.51233 .72241 L
.50209 .73422 L
.48767 .74858 L
.47572 .75888 L
.46302 .76826 L
.43836 .78282 L
.43703 .78353 L
.41371 .79304 L
.38905 .79934 L
.3644 .80195 L
.33974 .80094 L
.31509 .79624 L
.29043 .78761 L
.28148 .78353 L
.26578 .77462 L
.24393 .75888 L
.24112 .75649 L
.21854 .73422 L
Mistroke
.21647 .73183 L
.19939 .70957 L
.19181 .6978 L
.18443 .68491 L
.1726 .66026 L
.16716 .64659 L
.16334 .6356 L
.15626 .61095 L
.15114 .58629 L
.14784 .56164 L
.14624 .53698 L
.14631 .51233 L
.14803 .48767 L
.15143 .46302 L
.15658 .43836 L
.1636 .41371 L
.16716 .40329 L
.17269 .38905 L
.18412 .3644 L
.19181 .35039 L
.19834 .33974 L
.21614 .31509 L
.21647 .31469 L
.23889 .29043 L
.24112 .28835 L
.26578 .26855 L
.26979 .26578 L
.29043 .25387 L
.31509 .24357 L
.32069 .24112 L
.33974 .23719 L
Mfstroke
.8 g
.33974 .28611 m
.3644 .28303 L
.38905 .28433 L
.41371 .29014 L
.41469 .29043 L
.43836 .30084 L
.46025 .31509 L
.46302 .31733 L
.48631 .33974 L
.48767 .34133 L
.50487 .3644 L
.51233 .37683 L
.51869 .38905 L
.52908 .41371 L
.53667 .43836 L
.53698 .43948 L
.54187 .46302 L
.5449 .48767 L
.54588 .51233 L
.54486 .53698 L
.54182 .56164 L
.53698 .58521 L
.53668 .58629 L
.52928 .61095 L
.51929 .6356 L
.51233 .64955 L
.50622 .66026 L
.48913 .68491 L
.48767 .68673 L
.46622 .70957 L
.46302 .7124 L
.43836 .73057 L
.43247 .73422 L
.41371 .74296 L
.38905 .75044 L
.3644 .75342 L
.33974 .75202 L
.31509 .74612 L
.29043 .73529 L
.28846 .73422 L
.26578 .71867 L
.25533 .70957 L
.24112 .69449 L
.23344 .68491 L
.21739 .66026 L
.21647 .65861 L
.2053 .6356 L
.19631 .61095 L
.19181 .59496 L
.1899 .58629 L
.18575 .56164 L
.18372 .53698 L
.18369 .51233 L
.18567 .48767 L
.18969 .46302 L
.19181 .4532 L
.19588 .43836 L
.20447 .41371 L
.21587 .38905 L
.21647 .38792 L
.23068 .3644 L
.24112 .35035 L
.25018 .33974 L
.26578 .32449 L
.27721 .31509 L
.29043 .30619 L
.31509 .29369 L
.3213 .29043 L
F
0 g
.33974 .28611 m
.3644 .28303 L
.38905 .28433 L
.41371 .29014 L
.41469 .29043 L
.43836 .30084 L
.46025 .31509 L
.46302 .31733 L
.48631 .33974 L
.48767 .34133 L
.50487 .3644 L
.51233 .37683 L
.51869 .38905 L
.52908 .41371 L
.53667 .43836 L
.53698 .43948 L
.54187 .46302 L
.5449 .48767 L
.54588 .51233 L
.54486 .53698 L
.54182 .56164 L
.53698 .58521 L
.53668 .58629 L
.52928 .61095 L
.51929 .6356 L
.51233 .64955 L
.50622 .66026 L
.48913 .68491 L
.48767 .68673 L
.46622 .70957 L
.46302 .7124 L
.43836 .73057 L
.43247 .73422 L
.41371 .74296 L
.38905 .75044 L
.3644 .75342 L
.33974 .75202 L
.31509 .74612 L
.29043 .73529 L
.28846 .73422 L
.26578 .71867 L
.25533 .70957 L
.24112 .69449 L
.23344 .68491 L
.21739 .66026 L
.21647 .65861 L
.2053 .6356 L
.19631 .61095 L
.19181 .59496 L
.1899 .58629 L
Mistroke
.18575 .56164 L
.18372 .53698 L
.18369 .51233 L
.18567 .48767 L
.18969 .46302 L
.19181 .4532 L
.19588 .43836 L
.20447 .41371 L
.21587 .38905 L
.21647 .38792 L
.23068 .3644 L
.24112 .35035 L
.25018 .33974 L
.26578 .32449 L
.27721 .31509 L
.29043 .30619 L
.31509 .29369 L
.3213 .29043 L
.33974 .28611 L
Mfstroke
.9 g
.3644 .33613 m
.38905 .33806 L
.39632 .33974 L
.41371 .34593 L
.43836 .36075 L
.44302 .3644 L
.46302 .38499 L
.4662 .38905 L
.4817 .41371 L
.48767 .42627 L
.49235 .43836 L
.49947 .46302 L
.50358 .48767 L
.50499 .51233 L
.50382 .53698 L
.50003 .56164 L
.4934 .58629 L
.48767 .6018 L
.48355 .61095 L
.46959 .6356 L
.46302 .64476 L
.44977 .66026 L
.43836 .67068 L
.4181 .68491 L
.41371 .68715 L
.38905 .69672 L
.3644 .70033 L
.33974 .69827 L
.31509 .69026 L
.30404 .68491 L
.29043 .67528 L
.27381 .66026 L
.26578 .6508 L
.25497 .6356 L
.24207 .61095 L
.24112 .60881 L
.23318 .58629 L
.22755 .56164 L
.22476 .53698 L
.22458 .51233 L
.22699 .48767 L
.2321 .46302 L
.24022 .43836 L
.24112 .43609 L
.25184 .41371 L
.26578 .39238 L
.26832 .38905 L
.29043 .36622 L
.29248 .3644 L
.31509 .34954 L
.33974 .33987 L
.34021 .33974 L
F
0 g
.3644 .33613 m
.38905 .33806 L
.39632 .33974 L
.41371 .34593 L
.43836 .36075 L
.44302 .3644 L
.46302 .38499 L
.4662 .38905 L
.4817 .41371 L
.48767 .42627 L
.49235 .43836 L
.49947 .46302 L
.50358 .48767 L
.50499 .51233 L
.50382 .53698 L
.50003 .56164 L
.4934 .58629 L
.48767 .6018 L
.48355 .61095 L
.46959 .6356 L
.46302 .64476 L
.44977 .66026 L
.43836 .67068 L
.4181 .68491 L
.41371 .68715 L
.38905 .69672 L
.3644 .70033 L
.33974 .69827 L
.31509 .69026 L
.30404 .68491 L
.29043 .67528 L
.27381 .66026 L
.26578 .6508 L
.25497 .6356 L
.24207 .61095 L
.24112 .60881 L
.23318 .58629 L
.22755 .56164 L
.22476 .53698 L
.22458 .51233 L
.22699 .48767 L
.2321 .46302 L
.24022 .43836 L
.24112 .43609 L
.25184 .41371 L
.26578 .39238 L
.26832 .38905 L
.29043 .36622 L
.29248 .3644 L
.31509 .34954 L
Mistroke
.33974 .33987 L
.34021 .33974 L
.3644 .33613 L
Mfstroke
1 g
.33974 .40795 m
.3644 .40248 L
.38905 .40606 L
.40502 .41371 L
.41371 .41983 L
.43137 .43836 L
.43836 .45012 L
.44422 .46302 L
.45141 .48767 L
.45395 .51233 L
.45239 .53698 L
.44653 .56164 L
.43836 .58132 L
.43559 .58629 L
.41626 .61095 L
.41371 .61316 L
.38905 .62873 L
.3644 .63393 L
.33974 .6302 L
.31509 .6161 L
.30906 .61095 L
.29116 .58629 L
.29043 .58502 L
.28103 .56164 L
.27619 .53698 L
.27563 .51233 L
.27917 .48767 L
.28741 .46302 L
.29043 .45643 L
.30124 .43836 L
.31509 .42363 L
.32502 .41371 L
F
0 g
.33974 .40795 m
.3644 .40248 L
.38905 .40606 L
.40502 .41371 L
.41371 .41983 L
.43137 .43836 L
.43836 .45012 L
.44422 .46302 L
.45141 .48767 L
.45395 .51233 L
.45239 .53698 L
.44653 .56164 L
.43836 .58132 L
.43559 .58629 L
.41626 .61095 L
.41371 .61316 L
.38905 .62873 L
.3644 .63393 L
.33974 .6302 L
.31509 .6161 L
.30906 .61095 L
.29116 .58629 L
.29043 .58502 L
.28103 .56164 L
.27619 .53698 L
.27563 .51233 L
.27917 .48767 L
.28741 .46302 L
.29043 .45643 L
.30124 .43836 L
.31509 .42363 L
.32502 .41371 L
.33974 .40795 L
s
.1 g
.6101 .98077 m
.61095 .98 L
.63524 .95611 L
.6356 .95573 L
.65717 .93146 L
.66026 .92773 L
.67655 .9068 L
.68491 .89521 L
.69381 .88215 L
.70925 .8575 L
.70957 .85696 L
.72308 .83284 L
.73422 .81087 L
.7355 .80819 L
.74661 .78353 L
.75655 .75888 L
.75888 .75268 L
.76537 .73422 L
.77314 .70957 L
.77995 .68491 L
.78353 .67033 L
.7858 .66026 L
.79074 .6356 L
.7948 .61095 L
.79801 .58629 L
.80038 .56164 L
.80192 .53698 L
.80263 .51233 L
.80252 .48767 L
.80159 .46302 L
.79981 .43836 L
.79719 .41371 L
.7937 .38905 L
.78933 .3644 L
.78403 .33974 L
.78353 .3376 L
.77776 .31509 L
.77048 .29043 L
.76214 .26578 L
.75888 .25691 L
.75265 .24112 L
.74192 .21647 L
.73422 .2004 L
.72985 .19181 L
.71626 .16716 L
.70957 .15599 L
.70098 .1425 L
.68491 .11941 L
.68375 .11785 L
.66421 .0932 L
.66026 .08858 L
.64184 .06854 L
.6356 .06226 L
.61585 .04389 L
.61095 .03966 L
.58629 .02027 L
.58486 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.6101 .98077 m
.61095 .98 L
.63524 .95611 L
.6356 .95573 L
.65717 .93146 L
.66026 .92773 L
.67655 .9068 L
.68491 .89521 L
.69381 .88215 L
.70925 .8575 L
.70957 .85696 L
.72308 .83284 L
.73422 .81087 L
.7355 .80819 L
.74661 .78353 L
.75655 .75888 L
.75888 .75268 L
.76537 .73422 L
.77314 .70957 L
.77995 .68491 L
.78353 .67033 L
.7858 .66026 L
.79074 .6356 L
.7948 .61095 L
.79801 .58629 L
.80038 .56164 L
.80192 .53698 L
.80263 .51233 L
.80252 .48767 L
.80159 .46302 L
.79981 .43836 L
.79719 .41371 L
.7937 .38905 L
.78933 .3644 L
.78403 .33974 L
.78353 .3376 L
.77776 .31509 L
.77048 .29043 L
.76214 .26578 L
.75888 .25691 L
.75265 .24112 L
.74192 .21647 L
.73422 .2004 L
.72985 .19181 L
.71626 .16716 L
.70957 .15599 L
.70098 .1425 L
.68491 .11941 L
.68375 .11785 L
.66421 .0932 L
Mistroke
.66026 .08858 L
.64184 .06854 L
.6356 .06226 L
.61585 .04389 L
.61095 .03966 L
.58629 .02027 L
.58486 .01923 L
Mfstroke
.74431 .98077 m
.75888 .95989 L
.76138 .95611 L
.77693 .93146 L
.78353 .92029 L
.79113 .9068 L
.80412 .88215 L
.80819 .87395 L
.81596 .8575 L
.82678 .83284 L
.83284 .81796 L
.83661 .80819 L
.84552 .78353 L
.85357 .75888 L
.8575 .74586 L
.86078 .73422 L
.86718 .70957 L
.87282 .68491 L
.87772 .66026 L
.88189 .6356 L
.88215 .63394 L
.88532 .61095 L
.88805 .58629 L
.8901 .56164 L
.89146 .53698 L
.89213 .51233 L
.89212 .48767 L
.89143 .46302 L
.89005 .43836 L
.88798 .41371 L
.8852 .38905 L
.88215 .36725 L
.8817 .3644 L
.87744 .33974 L
.87242 .31509 L
.86663 .29043 L
.86003 .26578 L
.8575 .25702 L
.85257 .24112 L
.84421 .21647 L
.83493 .19181 L
.83284 .1866 L
.82461 .16716 L
.81323 .1425 L
.80819 .13228 L
.80068 .11785 L
.78684 .0932 L
.78353 .08762 L
.77158 .06854 L
.75888 .04971 L
.75474 .04389 L
.73606 .01923 L
.98077 .01923 L
.98077 .98077 L
F
.74431 .98077 m
.75888 .95989 L
.76138 .95611 L
.77693 .93146 L
.78353 .92029 L
.79113 .9068 L
.80412 .88215 L
.80819 .87395 L
.81596 .8575 L
.82678 .83284 L
.83284 .81796 L
.83661 .80819 L
.84552 .78353 L
.85357 .75888 L
.8575 .74586 L
.86078 .73422 L
.86718 .70957 L
.87282 .68491 L
.87772 .66026 L
.88189 .6356 L
.88215 .63394 L
.88532 .61095 L
.88805 .58629 L
.8901 .56164 L
.89146 .53698 L
.89213 .51233 L
.89212 .48767 L
.89143 .46302 L
.89005 .43836 L
.88798 .41371 L
.8852 .38905 L
.88215 .36725 L
.8817 .3644 L
.87744 .33974 L
.87242 .31509 L
.86663 .29043 L
.86003 .26578 L
.8575 .25702 L
.85257 .24112 L
.84421 .21647 L
.83493 .19181 L
.83284 .1866 L
.82461 .16716 L
.81323 .1425 L
.80819 .13228 L
.80068 .11785 L
.78684 .0932 L
.78353 .08762 L
.77158 .06854 L
.75888 .04971 L
Mistroke
.75474 .04389 L
.73606 .01923 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.44897 .98077 m
.43836 .97536 L
.41371 .96148 L
.40497 .95611 L
.38905 .94571 L
.36907 .93146 L
.3644 .92791 L
.33974 .90776 L
.33865 .9068 L
.31509 .88489 L
.31233 .88215 L
.29043 .85882 L
.28927 .8575 L
.26891 .83284 L
.26578 .82877 L
.25088 .80819 L
.24112 .79356 L
.23485 .78353 L
.22063 .75888 L
.21647 .75107 L
.20807 .73422 L
.19701 .70957 L
.19181 .69677 L
.18737 .68491 L
.17906 .66026 L
.17199 .6356 L
.16716 .61575 L
.16612 .61095 L
.16146 .58629 L
.15792 .56164 L
.15548 .53698 L
.15413 .51233 L
.15387 .48767 L
.1547 .46302 L
.1566 .43836 L
.15961 .41371 L
.16372 .38905 L
.16716 .37222 L
.16898 .3644 L
.17545 .33974 L
.18313 .31509 L
.19181 .29105 L
.19206 .29043 L
.2024 .26578 L
.21414 .24112 L
.21647 .23657 L
.22747 .21647 L
.24112 .1939 L
.24246 .19181 L
.25937 .16716 L
.26578 .15851 L
.27839 .1425 L
.29043 .12828 L
.29984 .11785 L
.31509 .10202 L
.32416 .0932 L
.33974 .07898 L
.35201 .06854 L
.3644 .05865 L
.38437 .04389 L
.38905 .04063 L
.41371 .02469 L
.42296 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.44897 .98077 m
.43836 .97536 L
.41371 .96148 L
.40497 .95611 L
.38905 .94571 L
.36907 .93146 L
.3644 .92791 L
.33974 .90776 L
.33865 .9068 L
.31509 .88489 L
.31233 .88215 L
.29043 .85882 L
.28927 .8575 L
.26891 .83284 L
.26578 .82877 L
.25088 .80819 L
.24112 .79356 L
.23485 .78353 L
.22063 .75888 L
.21647 .75107 L
.20807 .73422 L
.19701 .70957 L
.19181 .69677 L
.18737 .68491 L
.17906 .66026 L
.17199 .6356 L
.16716 .61575 L
.16612 .61095 L
.16146 .58629 L
.15792 .56164 L
.15548 .53698 L
.15413 .51233 L
.15387 .48767 L
.1547 .46302 L
.1566 .43836 L
.15961 .41371 L
.16372 .38905 L
.16716 .37222 L
.16898 .3644 L
.17545 .33974 L
.18313 .31509 L
.19181 .29105 L
.19206 .29043 L
.2024 .26578 L
.21414 .24112 L
.21647 .23657 L
.22747 .21647 L
.24112 .1939 L
.24246 .19181 L
.25937 .16716 L
Mistroke
.26578 .15851 L
.27839 .1425 L
.29043 .12828 L
.29984 .11785 L
.31509 .10202 L
.32416 .0932 L
.33974 .07898 L
.35201 .06854 L
.3644 .05865 L
.38437 .04389 L
.38905 .04063 L
.41371 .02469 L
.42296 .01923 L
Mfstroke
.2 g
.98077 .80754 m
.98015 .80819 L
.95611 .83119 L
.95424 .83284 L
.93146 .85149 L
.92341 .8575 L
.9068 .86899 L
.88552 .88215 L
.88215 .88407 L
.8575 .89698 L
.83564 .9068 L
.83284 .90795 L
.80819 .91709 L
.78353 .92455 L
.75888 .93041 L
.75383 .93146 L
.73422 .9347 L
.70957 .93749 L
.68491 .93881 L
.66026 .93866 L
.6356 .93706 L
.61095 .93397 L
.5962 .93146 L
.58629 .92936 L
.56164 .92318 L
.53698 .91537 L
.51459 .9068 L
.51233 .90585 L
.48767 .89445 L
.46489 .88215 L
.46302 .88106 L
.43836 .86541 L
.42716 .8575 L
.41371 .84723 L
.3965 .83284 L
.38905 .82611 L
.37077 .80819 L
.3644 .80143 L
.34878 .78353 L
.33974 .77223 L
.32982 .75888 L
.31509 .73691 L
.31341 .73422 L
.29923 .70957 L
.29043 .69222 L
.28702 .68491 L
.2766 .66026 L
.26782 .6356 L
.26578 .62917 L
.26061 .61095 L
.25486 .58629 L
.25051 .56164 L
.24752 .53698 L
.24586 .51233 L
.24553 .48767 L
.24651 .46302 L
.24881 .43836 L
.25246 .41371 L
.25748 .38905 L
.26391 .3644 L
.26578 .35812 L
.27186 .33974 L
.28138 .31509 L
.29043 .29487 L
.29259 .29043 L
.30567 .26578 L
.31509 .25 L
.32079 .24112 L
.33824 .21647 L
.33974 .21449 L
.3584 .19181 L
.3644 .18512 L
.38181 .16716 L
.38905 .16026 L
.40932 .1425 L
.41371 .13895 L
.43836 .12059 L
.44237 .11785 L
.46302 .10477 L
.48375 .0932 L
.48767 .09118 L
.51233 .07962 L
.53698 .06989 L
.54077 .06854 L
.56164 .06191 L
.58629 .05556 L
.61095 .05076 L
.6356 .04748 L
.66026 .04569 L
.68491 .04536 L
.70957 .0465 L
.73422 .04912 L
.75888 .05324 L
.78353 .05891 L
.80819 .06617 L
.81522 .06854 L
.83284 .07514 L
.8575 .08592 L
.87208 .0932 L
.88215 .09866 L
.9068 .11355 L
.91328 .11785 L
.93146 .13088 L
.94616 .1425 L
.95611 .151 L
.97352 .16716 L
.98077 .17446 L
F
0 g
.98077 .80754 m
.98015 .80819 L
.95611 .83119 L
.95424 .83284 L
.93146 .85149 L
.92341 .8575 L
.9068 .86899 L
.88552 .88215 L
.88215 .88407 L
.8575 .89698 L
.83564 .9068 L
.83284 .90795 L
.80819 .91709 L
.78353 .92455 L
.75888 .93041 L
.75383 .93146 L
.73422 .9347 L
.70957 .93749 L
.68491 .93881 L
.66026 .93866 L
.6356 .93706 L
.61095 .93397 L
.5962 .93146 L
.58629 .92936 L
.56164 .92318 L
.53698 .91537 L
.51459 .9068 L
.51233 .90585 L
.48767 .89445 L
.46489 .88215 L
.46302 .88106 L
.43836 .86541 L
.42716 .8575 L
.41371 .84723 L
.3965 .83284 L
.38905 .82611 L
.37077 .80819 L
.3644 .80143 L
.34878 .78353 L
.33974 .77223 L
.32982 .75888 L
.31509 .73691 L
.31341 .73422 L
.29923 .70957 L
.29043 .69222 L
.28702 .68491 L
.2766 .66026 L
.26782 .6356 L
.26578 .62917 L
.26061 .61095 L
Mistroke
.25486 .58629 L
.25051 .56164 L
.24752 .53698 L
.24586 .51233 L
.24553 .48767 L
.24651 .46302 L
.24881 .43836 L
.25246 .41371 L
.25748 .38905 L
.26391 .3644 L
.26578 .35812 L
.27186 .33974 L
.28138 .31509 L
.29043 .29487 L
.29259 .29043 L
.30567 .26578 L
.31509 .25 L
.32079 .24112 L
.33824 .21647 L
.33974 .21449 L
.3584 .19181 L
.3644 .18512 L
.38181 .16716 L
.38905 .16026 L
.40932 .1425 L
.41371 .13895 L
.43836 .12059 L
.44237 .11785 L
.46302 .10477 L
.48375 .0932 L
.48767 .09118 L
.51233 .07962 L
.53698 .06989 L
.54077 .06854 L
.56164 .06191 L
.58629 .05556 L
.61095 .05076 L
.6356 .04748 L
.66026 .04569 L
.68491 .04536 L
.70957 .0465 L
.73422 .04912 L
.75888 .05324 L
.78353 .05891 L
.80819 .06617 L
.81522 .06854 L
.83284 .07514 L
.8575 .08592 L
.87208 .0932 L
.88215 .09866 L
Mistroke
.9068 .11355 L
.91328 .11785 L
.93146 .13088 L
.94616 .1425 L
.95611 .151 L
.97352 .16716 L
.98077 .17446 L
Mfstroke
.3 g
.98077 .7144 m
.96632 .73422 L
.95611 .74677 L
.94539 .75888 L
.93146 .77319 L
.92043 .78353 L
.9068 .79522 L
.89 .80819 L
.88215 .81374 L
.8575 .82934 L
.85133 .83284 L
.83284 .8424 L
.80819 .8532 L
.79682 .8575 L
.78353 .86193 L
.75888 .86873 L
.73422 .87371 L
.70957 .87694 L
.68491 .87845 L
.66026 .87827 L
.6356 .87639 L
.61095 .87279 L
.58629 .86741 L
.56164 .86019 L
.55377 .8575 L
.53698 .851 L
.51233 .83968 L
.49941 .83284 L
.48767 .82602 L
.46302 .80971 L
.46091 .80819 L
.43836 .79032 L
.43065 .78353 L
.41371 .76719 L
.40586 .75888 L
.38905 .73925 L
.3851 .73422 L
.36758 .70957 L
.3644 .70462 L
.35276 .68491 L
.34027 .66026 L
.33974 .65913 L
.32987 .6356 L
.32137 .61095 L
.31509 .58824 L
.31463 .58629 L
.30956 .56164 L
.30609 .53698 L
.30416 .51233 L
.30376 .48767 L
.30488 .46302 L
.30753 .43836 L
.31174 .41371 L
.31509 .39855 L
.31757 .38905 L
.32511 .3644 L
.33444 .33974 L
.33974 .32759 L
.34574 .31509 L
.35921 .29043 L
.3644 .28193 L
.37513 .26578 L
.38905 .24711 L
.39391 .24112 L
.41371 .219 L
.41617 .21647 L
.43836 .19568 L
.4429 .19181 L
.46302 .17611 L
.47586 .16716 L
.48767 .15962 L
.51233 .14577 L
.51885 .1425 L
.53698 .13428 L
.56164 .1249 L
.5849 .11785 L
.58629 .11749 L
.61095 .11194 L
.6356 .10816 L
.66026 .1061 L
.68491 .10574 L
.70957 .10707 L
.73422 .11011 L
.75888 .1149 L
.77088 .11785 L
.78353 .12152 L
.80819 .13008 L
.83284 .14068 L
.83663 .1425 L
.8575 .15357 L
.87946 .16716 L
.88215 .16898 L
.9068 .18733 L
.91224 .19181 L
.93146 .20917 L
.9388 .21647 L
.95611 .23541 L
.9609 .24112 L
.97952 .26578 L
.98077 .2676 L
F
0 g
.98077 .7144 m
.96632 .73422 L
.95611 .74677 L
.94539 .75888 L
.93146 .77319 L
.92043 .78353 L
.9068 .79522 L
.89 .80819 L
.88215 .81374 L
.8575 .82934 L
.85133 .83284 L
.83284 .8424 L
.80819 .8532 L
.79682 .8575 L
.78353 .86193 L
.75888 .86873 L
.73422 .87371 L
.70957 .87694 L
.68491 .87845 L
.66026 .87827 L
.6356 .87639 L
.61095 .87279 L
.58629 .86741 L
.56164 .86019 L
.55377 .8575 L
.53698 .851 L
.51233 .83968 L
.49941 .83284 L
.48767 .82602 L
.46302 .80971 L
.46091 .80819 L
.43836 .79032 L
.43065 .78353 L
.41371 .76719 L
.40586 .75888 L
.38905 .73925 L
.3851 .73422 L
.36758 .70957 L
.3644 .70462 L
.35276 .68491 L
.34027 .66026 L
.33974 .65913 L
.32987 .6356 L
.32137 .61095 L
.31509 .58824 L
.31463 .58629 L
.30956 .56164 L
.30609 .53698 L
.30416 .51233 L
.30376 .48767 L
Mistroke
.30488 .46302 L
.30753 .43836 L
.31174 .41371 L
.31509 .39855 L
.31757 .38905 L
.32511 .3644 L
.33444 .33974 L
.33974 .32759 L
.34574 .31509 L
.35921 .29043 L
.3644 .28193 L
.37513 .26578 L
.38905 .24711 L
.39391 .24112 L
.41371 .219 L
.41617 .21647 L
.43836 .19568 L
.4429 .19181 L
.46302 .17611 L
.47586 .16716 L
.48767 .15962 L
.51233 .14577 L
.51885 .1425 L
.53698 .13428 L
.56164 .1249 L
.5849 .11785 L
.58629 .11749 L
.61095 .11194 L
.6356 .10816 L
.66026 .1061 L
.68491 .10574 L
.70957 .10707 L
.73422 .11011 L
.75888 .1149 L
.77088 .11785 L
.78353 .12152 L
.80819 .13008 L
.83284 .14068 L
.83663 .1425 L
.8575 .15357 L
.87946 .16716 L
.88215 .16898 L
.9068 .18733 L
.91224 .19181 L
.93146 .20917 L
.9388 .21647 L
.95611 .23541 L
.9609 .24112 L
.97952 .26578 L
.98077 .2676 L
Mistroke
Mfstroke
.4 g
.98077 .61494 m
.97217 .6356 L
.95975 .66026 L
.95611 .66666 L
.94468 .68491 L
.93146 .70327 L
.92647 .70957 L
.9068 .73176 L
.90439 .73422 L
.88215 .75476 L
.87717 .75888 L
.8575 .77362 L
.84232 .78353 L
.83284 .78912 L
.80819 .80176 L
.79329 .80819 L
.78353 .81188 L
.75888 .81971 L
.73422 .82541 L
.70957 .82909 L
.68491 .8308 L
.66026 .83058 L
.6356 .82842 L
.61095 .82429 L
.58629 .8181 L
.56164 .80974 L
.55765 .80819 L
.53698 .79902 L
.51233 .78569 L
.50877 .78353 L
.48767 .76936 L
.47408 .75888 L
.46302 .74945 L
.44703 .73422 L
.43836 .72506 L
.42511 .70957 L
.41371 .69453 L
.40708 .68491 L
.39218 .66026 L
.38905 .65444 L
.37993 .6356 L
.37002 .61095 L
.3644 .59392 L
.36223 .58629 L
.35639 .56164 L
.3524 .53698 L
.35019 .51233 L
.34972 .48767 L
.35098 .46302 L
.354 .43836 L
.35882 .41371 L
.3644 .39263 L
.36551 .38905 L
.37423 .3644 L
.38512 .33974 L
.38905 .33193 L
.39845 .31509 L
.41371 .29165 L
.41458 .29043 L
.43408 .26578 L
.43836 .26095 L
.45783 .24112 L
.46302 .23637 L
.48742 .21647 L
.48767 .21628 L
.51233 .19977 L
.52619 .19181 L
.53698 .18625 L
.56164 .17535 L
.5851 .16716 L
.58629 .1668 L
.61095 .16044 L
.6356 .15612 L
.66026 .15379 L
.68491 .15339 L
.70957 .15492 L
.73422 .15841 L
.75888 .16392 L
.77034 .16716 L
.78353 .17157 L
.80819 .18151 L
.82895 .19181 L
.83284 .19397 L
.8575 .20929 L
.86757 .21647 L
.88215 .22797 L
.89698 .24112 L
.9068 .25079 L
.92056 .26578 L
.93146 .27909 L
.93989 .29043 L
.95586 .31509 L
.95611 .31553 L
.96902 .33974 L
.97974 .3644 L
.98077 .36705 L
F
0 g
.98077 .61494 m
.97217 .6356 L
.95975 .66026 L
.95611 .66666 L
.94468 .68491 L
.93146 .70327 L
.92647 .70957 L
.9068 .73176 L
.90439 .73422 L
.88215 .75476 L
.87717 .75888 L
.8575 .77362 L
.84232 .78353 L
.83284 .78912 L
.80819 .80176 L
.79329 .80819 L
.78353 .81188 L
.75888 .81971 L
.73422 .82541 L
.70957 .82909 L
.68491 .8308 L
.66026 .83058 L
.6356 .82842 L
.61095 .82429 L
.58629 .8181 L
.56164 .80974 L
.55765 .80819 L
.53698 .79902 L
.51233 .78569 L
.50877 .78353 L
.48767 .76936 L
.47408 .75888 L
.46302 .74945 L
.44703 .73422 L
.43836 .72506 L
.42511 .70957 L
.41371 .69453 L
.40708 .68491 L
.39218 .66026 L
.38905 .65444 L
.37993 .6356 L
.37002 .61095 L
.3644 .59392 L
.36223 .58629 L
.35639 .56164 L
.3524 .53698 L
.35019 .51233 L
.34972 .48767 L
.35098 .46302 L
.354 .43836 L
Mistroke
.35882 .41371 L
.3644 .39263 L
.36551 .38905 L
.37423 .3644 L
.38512 .33974 L
.38905 .33193 L
.39845 .31509 L
.41371 .29165 L
.41458 .29043 L
.43408 .26578 L
.43836 .26095 L
.45783 .24112 L
.46302 .23637 L
.48742 .21647 L
.48767 .21628 L
.51233 .19977 L
.52619 .19181 L
.53698 .18625 L
.56164 .17535 L
.5851 .16716 L
.58629 .1668 L
.61095 .16044 L
.6356 .15612 L
.66026 .15379 L
.68491 .15339 L
.70957 .15492 L
.73422 .15841 L
.75888 .16392 L
.77034 .16716 L
.78353 .17157 L
.80819 .18151 L
.82895 .19181 L
.83284 .19397 L
.8575 .20929 L
.86757 .21647 L
.88215 .22797 L
.89698 .24112 L
.9068 .25079 L
.92056 .26578 L
.93146 .27909 L
.93989 .29043 L
.95586 .31509 L
.95611 .31553 L
.96902 .33974 L
.97974 .3644 L
.98077 .36705 L
Mfstroke
.5 g
.58629 .21014 m
.61095 .20284 L
.6356 .19791 L
.66026 .19526 L
.68491 .19481 L
.70957 .19657 L
.73422 .20058 L
.75888 .20692 L
.78353 .21577 L
.78522 .21647 L
.80819 .22738 L
.83132 .24112 L
.83284 .24214 L
.8575 .26065 L
.86345 .26578 L
.88215 .28392 L
.8881 .29043 L
.9068 .31384 L
.9077 .31509 L
.92346 .33974 L
.93146 .35466 L
.93609 .3644 L
.94603 .38905 L
.95358 .41371 L
.95611 .42371 L
.95892 .43836 L
.96218 .46302 L
.96345 .48767 L
.96273 .51233 L
.96002 .53698 L
.95611 .55836 L
.95527 .56164 L
.94837 .58629 L
.93916 .61095 L
.93146 .62771 L
.92737 .6356 L
.91263 .66026 L
.9068 .66872 L
.89435 .68491 L
.88215 .6988 L
.87155 .70957 L
.8575 .72226 L
.84237 .73422 L
.83284 .74095 L
.80819 .75589 L
.80253 .75888 L
.78353 .76768 L
.75888 .77672 L
.73422 .78324 L
.73327 .78353 L
.70957 .78743 L
.68491 .78937 L
.66026 .78911 L
.6356 .78664 L
.61722 .78353 L
.61095 .78189 L
.58629 .77476 L
.56164 .76506 L
.54871 .75888 L
.53698 .75249 L
.51233 .73661 L
.50905 .73422 L
.48767 .71671 L
.48004 .70957 L
.46302 .69157 L
.45741 .68491 L
.43929 .66026 L
.43836 .65883 L
.42473 .6356 L
.41371 .61238 L
.41311 .61095 L
.40406 .58629 L
.39733 .56164 L
.39275 .53698 L
.39022 .51233 L
.38967 .48767 L
.3911 .46302 L
.39454 .43836 L
.40005 .41371 L
.40776 .38905 L
.41371 .37375 L
.41787 .3644 L
.43067 .33974 L
.43836 .32715 L
.4466 .31509 L
.46302 .29425 L
.46637 .29043 L
.48767 .26893 L
.49119 .26578 L
.51233 .24885 L
.52347 .24112 L
.53698 .23278 L
.56164 .22003 L
.56968 .21647 L
F
0 g
.58629 .21014 m
.61095 .20284 L
.6356 .19791 L
.66026 .19526 L
.68491 .19481 L
.70957 .19657 L
.73422 .20058 L
.75888 .20692 L
.78353 .21577 L
.78522 .21647 L
.80819 .22738 L
.83132 .24112 L
.83284 .24214 L
.8575 .26065 L
.86345 .26578 L
.88215 .28392 L
.8881 .29043 L
.9068 .31384 L
.9077 .31509 L
.92346 .33974 L
.93146 .35466 L
.93609 .3644 L
.94603 .38905 L
.95358 .41371 L
.95611 .42371 L
.95892 .43836 L
.96218 .46302 L
.96345 .48767 L
.96273 .51233 L
.96002 .53698 L
.95611 .55836 L
.95527 .56164 L
.94837 .58629 L
.93916 .61095 L
.93146 .62771 L
.92737 .6356 L
.91263 .66026 L
.9068 .66872 L
.89435 .68491 L
.88215 .6988 L
.87155 .70957 L
.8575 .72226 L
.84237 .73422 L
.83284 .74095 L
.80819 .75589 L
.80253 .75888 L
.78353 .76768 L
.75888 .77672 L
.73422 .78324 L
.73327 .78353 L
Mistroke
.70957 .78743 L
.68491 .78937 L
.66026 .78911 L
.6356 .78664 L
.61722 .78353 L
.61095 .78189 L
.58629 .77476 L
.56164 .76506 L
.54871 .75888 L
.53698 .75249 L
.51233 .73661 L
.50905 .73422 L
.48767 .71671 L
.48004 .70957 L
.46302 .69157 L
.45741 .68491 L
.43929 .66026 L
.43836 .65883 L
.42473 .6356 L
.41371 .61238 L
.41311 .61095 L
.40406 .58629 L
.39733 .56164 L
.39275 .53698 L
.39022 .51233 L
.38967 .48767 L
.3911 .46302 L
.39454 .43836 L
.40005 .41371 L
.40776 .38905 L
.41371 .37375 L
.41787 .3644 L
.43067 .33974 L
.43836 .32715 L
.4466 .31509 L
.46302 .29425 L
.46637 .29043 L
.48767 .26893 L
.49119 .26578 L
.51233 .24885 L
.52347 .24112 L
.53698 .23278 L
.56164 .22003 L
.56968 .21647 L
.58629 .21014 L
Mfstroke
.6 g
.6356 .23664 m
.66026 .23361 L
.68491 .23311 L
.70957 .23514 L
.73422 .23977 L
.7398 .24112 L
.75888 .24715 L
.78353 .25753 L
.79909 .26578 L
.80819 .27134 L
.83284 .28931 L
.83419 .29043 L
.8575 .31266 L
.85971 .31509 L
.87927 .33974 L
.88215 .34395 L
.8945 .3644 L
.90626 .38905 L
.9068 .39035 L
.91508 .41371 L
.92128 .43836 L
.92505 .46302 L
.92651 .48767 L
.9257 .51233 L
.9226 .53698 L
.91713 .56164 L
.90911 .58629 L
.9068 .59222 L
.89829 .61095 L
.88422 .6356 L
.88215 .63877 L
.86619 .66026 L
.8575 .67025 L
.84293 .68491 L
.83284 .69379 L
.81178 .70957 L
.80819 .71193 L
.78353 .72593 L
.76493 .73422 L
.75888 .73649 L
.73422 .74404 L
.70957 .74886 L
.68491 .75107 L
.66026 .75076 L
.6356 .7479 L
.61095 .74241 L
.58657 .73422 L
.58629 .73411 L
.56164 .72268 L
.5398 .70957 L
.53698 .70763 L
.51233 .68811 L
.50883 .68491 L
.48767 .66259 L
.48574 .66026 L
.46788 .6356 L
.46302 .62771 L
.45397 .61095 L
.44332 .58629 L
.43836 .57194 L
.43548 .56164 L
.43017 .53698 L
.42724 .51233 L
.42661 .48767 L
.42823 .46302 L
.43218 .43836 L
.43836 .41425 L
.43854 .41371 L
.44753 .38905 L
.45947 .3644 L
.46302 .35812 L
.47486 .33974 L
.48767 .32304 L
.49459 .31509 L
.51233 .29734 L
.52026 .29043 L
.53698 .27764 L
.55557 .26578 L
.56164 .26241 L
.58629 .2508 L
.61095 .24232 L
.61467 .24112 L
F
0 g
.6356 .23664 m
.66026 .23361 L
.68491 .23311 L
.70957 .23514 L
.73422 .23977 L
.7398 .24112 L
.75888 .24715 L
.78353 .25753 L
.79909 .26578 L
.80819 .27134 L
.83284 .28931 L
.83419 .29043 L
.8575 .31266 L
.85971 .31509 L
.87927 .33974 L
.88215 .34395 L
.8945 .3644 L
.90626 .38905 L
.9068 .39035 L
.91508 .41371 L
.92128 .43836 L
.92505 .46302 L
.92651 .48767 L
.9257 .51233 L
.9226 .53698 L
.91713 .56164 L
.90911 .58629 L
.9068 .59222 L
.89829 .61095 L
.88422 .6356 L
.88215 .63877 L
.86619 .66026 L
.8575 .67025 L
.84293 .68491 L
.83284 .69379 L
.81178 .70957 L
.80819 .71193 L
.78353 .72593 L
.76493 .73422 L
.75888 .73649 L
.73422 .74404 L
.70957 .74886 L
.68491 .75107 L
.66026 .75076 L
.6356 .7479 L
.61095 .74241 L
.58657 .73422 L
.58629 .73411 L
.56164 .72268 L
.5398 .70957 L
Mistroke
.53698 .70763 L
.51233 .68811 L
.50883 .68491 L
.48767 .66259 L
.48574 .66026 L
.46788 .6356 L
.46302 .62771 L
.45397 .61095 L
.44332 .58629 L
.43836 .57194 L
.43548 .56164 L
.43017 .53698 L
.42724 .51233 L
.42661 .48767 L
.42823 .46302 L
.43218 .43836 L
.43836 .41425 L
.43854 .41371 L
.44753 .38905 L
.45947 .3644 L
.46302 .35812 L
.47486 .33974 L
.48767 .32304 L
.49459 .31509 L
.51233 .29734 L
.52026 .29043 L
.53698 .27764 L
.55557 .26578 L
.56164 .26241 L
.58629 .2508 L
.61095 .24232 L
.61467 .24112 L
.6356 .23664 L
Mfstroke
.7 g
.61095 .28108 m
.6356 .27441 L
.66026 .27087 L
.68491 .2703 L
.70957 .2727 L
.73422 .27816 L
.75888 .28693 L
.76674 .29043 L
.78353 .29946 L
.80632 .31509 L
.80819 .31658 L
.83276 .33974 L
.83284 .33984 L
.85211 .3644 L
.8575 .37273 L
.86654 .38905 L
.87713 .41371 L
.88215 .42893 L
.88448 .43836 L
.88892 .46302 L
.89064 .48767 L
.88971 .51233 L
.8861 .53698 L
.88215 .55406 L
.87966 .56164 L
.87012 .58629 L
.8575 .61013 L
.85699 .61095 L
.83943 .6356 L
.83284 .64327 L
.81577 .66026 L
.80819 .6667 L
.78353 .68399 L
.78201 .68491 L
.75888 .69671 L
.73422 .70566 L
.7204 .70957 L
.70957 .7113 L
.68491 .71388 L
.66026 .71349 L
.6356 .71013 L
.63247 .70957 L
.61095 .70365 L
.58629 .69374 L
.56968 .68491 L
.56164 .67984 L
.53698 .66097 L
.53618 .66026 L
.51268 .6356 L
.51233 .63517 L
.49527 .61095 L
.48767 .59749 L
.48232 .58629 L
.47294 .56164 L
.46668 .53698 L
.46323 .51233 L
.46302 .50956 L
.46247 .48767 L
.46302 .47628 L
.46436 .46302 L
.46897 .43836 L
.47649 .41371 L
.48726 .38905 L
.48767 .38823 L
.50185 .3644 L
.51233 .35025 L
.52135 .33974 L
.53698 .32429 L
.54795 .31509 L
.56164 .30525 L
.58629 .29118 L
.58778 .29043 L
F
0 g
.61095 .28108 m
.6356 .27441 L
.66026 .27087 L
.68491 .2703 L
.70957 .2727 L
.73422 .27816 L
.75888 .28693 L
.76674 .29043 L
.78353 .29946 L
.80632 .31509 L
.80819 .31658 L
.83276 .33974 L
.83284 .33984 L
.85211 .3644 L
.8575 .37273 L
.86654 .38905 L
.87713 .41371 L
.88215 .42893 L
.88448 .43836 L
.88892 .46302 L
.89064 .48767 L
.88971 .51233 L
.8861 .53698 L
.88215 .55406 L
.87966 .56164 L
.87012 .58629 L
.8575 .61013 L
.85699 .61095 L
.83943 .6356 L
.83284 .64327 L
.81577 .66026 L
.80819 .6667 L
.78353 .68399 L
.78201 .68491 L
.75888 .69671 L
.73422 .70566 L
.7204 .70957 L
.70957 .7113 L
.68491 .71388 L
.66026 .71349 L
.6356 .71013 L
.63247 .70957 L
.61095 .70365 L
.58629 .69374 L
.56968 .68491 L
.56164 .67984 L
.53698 .66097 L
.53618 .66026 L
.51268 .6356 L
.51233 .63517 L
Mistroke
.49527 .61095 L
.48767 .59749 L
.48232 .58629 L
.47294 .56164 L
.46668 .53698 L
.46323 .51233 L
.46302 .50956 L
.46247 .48767 L
.46302 .47628 L
.46436 .46302 L
.46897 .43836 L
.47649 .41371 L
.48726 .38905 L
.48767 .38823 L
.50185 .3644 L
.51233 .35025 L
.52135 .33974 L
.53698 .32429 L
.54795 .31509 L
.56164 .30525 L
.58629 .29118 L
.58778 .29043 L
.61095 .28108 L
Mfstroke
.8 g
.6356 .31324 m
.66026 .30896 L
.68491 .3083 L
.70957 .31122 L
.72748 .31509 L
.73422 .3179 L
.75888 .3288 L
.77666 .33974 L
.78353 .34489 L
.80477 .3644 L
.80819 .36818 L
.82396 .38905 L
.83284 .40419 L
.83739 .41371 L
.8465 .43836 L
.85192 .46302 L
.85401 .48767 L
.85291 .51233 L
.84854 .53698 L
.84066 .56164 L
.83284 .57894 L
.82872 .58629 L
.81167 .61095 L
.80819 .61508 L
.78719 .6356 L
.78353 .63855 L
.75888 .65483 L
.74843 .66026 L
.73422 .66592 L
.70957 .67279 L
.68491 .67589 L
.66026 .67541 L
.6356 .67131 L
.61095 .66333 L
.60366 .66026 L
.58629 .65091 L
.56489 .6356 L
.56164 .6328 L
.54059 .61095 L
.53698 .60638 L
.52371 .58629 L
.51233 .56261 L
.51196 .56164 L
.50423 .53698 L
.50003 .51233 L
.4991 .48767 L
.50136 .46302 L
.50696 .43836 L
.51233 .42243 L
.51623 .41371 L
.52984 .38905 L
.53698 .37888 L
.54917 .3644 L
.56164 .35228 L
.57749 .33974 L
.58629 .33401 L
.61095 .32139 L
.62804 .31509 L
F
0 g
.6356 .31324 m
.66026 .30896 L
.68491 .3083 L
.70957 .31122 L
.72748 .31509 L
.73422 .3179 L
.75888 .3288 L
.77666 .33974 L
.78353 .34489 L
.80477 .3644 L
.80819 .36818 L
.82396 .38905 L
.83284 .40419 L
.83739 .41371 L
.8465 .43836 L
.85192 .46302 L
.85401 .48767 L
.85291 .51233 L
.84854 .53698 L
.84066 .56164 L
.83284 .57894 L
.82872 .58629 L
.81167 .61095 L
.80819 .61508 L
.78719 .6356 L
.78353 .63855 L
.75888 .65483 L
.74843 .66026 L
.73422 .66592 L
.70957 .67279 L
.68491 .67589 L
.66026 .67541 L
.6356 .67131 L
.61095 .66333 L
.60366 .66026 L
.58629 .65091 L
.56489 .6356 L
.56164 .6328 L
.54059 .61095 L
.53698 .60638 L
.52371 .58629 L
.51233 .56261 L
.51196 .56164 L
.50423 .53698 L
.50003 .51233 L
.4991 .48767 L
.50136 .46302 L
.50696 .43836 L
.51233 .42243 L
.51623 .41371 L
Mistroke
.52984 .38905 L
.53698 .37888 L
.54917 .3644 L
.56164 .35228 L
.57749 .33974 L
.58629 .33401 L
.61095 .32139 L
.62804 .31509 L
.6356 .31324 L
Mfstroke
.9 g
.6356 .35619 m
.66026 .35063 L
.68491 .3498 L
.70957 .35362 L
.73422 .36253 L
.73818 .3644 L
.75888 .37761 L
.772 .38905 L
.78353 .40205 L
.79168 .41371 L
.8041 .43836 L
.80819 .44747 L
.81125 .46302 L
.814 .48767 L
.81259 .51233 L
.80819 .53277 L
.8069 .53698 L
.79639 .56164 L
.78353 .58139 L
.7795 .58629 L
.75888 .60602 L
.75237 .61095 L
.73422 .62132 L
.70957 .63038 L
.68491 .63435 L
.66026 .63371 L
.6356 .62836 L
.61095 .61765 L
.59994 .61095 L
.58629 .60007 L
.57291 .58629 L
.56164 .57103 L
.55624 .56164 L
.54584 .53698 L
.54035 .51233 L
.53912 .48767 L
.54202 .46302 L
.54934 .43836 L
.56164 .41423 L
.56199 .41371 L
.58188 .38905 L
.58629 .3849 L
.61095 .36708 L
.61528 .3644 L
F
0 g
.6356 .35619 m
.66026 .35063 L
.68491 .3498 L
.70957 .35362 L
.73422 .36253 L
.73818 .3644 L
.75888 .37761 L
.772 .38905 L
.78353 .40205 L
.79168 .41371 L
.8041 .43836 L
.80819 .44747 L
.81125 .46302 L
.814 .48767 L
.81259 .51233 L
.80819 .53277 L
.8069 .53698 L
.79639 .56164 L
.78353 .58139 L
.7795 .58629 L
.75888 .60602 L
.75237 .61095 L
.73422 .62132 L
.70957 .63038 L
.68491 .63435 L
.66026 .63371 L
.6356 .62836 L
.61095 .61765 L
.59994 .61095 L
.58629 .60007 L
.57291 .58629 L
.56164 .57103 L
.55624 .56164 L
.54584 .53698 L
.54035 .51233 L
.53912 .48767 L
.54202 .46302 L
.54934 .43836 L
.56164 .41423 L
.56199 .41371 L
.58188 .38905 L
.58629 .3849 L
.61095 .36708 L
.61528 .3644 L
.6356 .35619 L
s
1 g
.6356 .41201 m
.66026 .40285 L
.68491 .40158 L
.70957 .40783 L
.72289 .41371 L
.73422 .42314 L
.74767 .43836 L
.75888 .4602 L
.75959 .46302 L
.7641 .48767 L
.76189 .51233 L
.75888 .52269 L
.75281 .53698 L
.73422 .56038 L
.73309 .56164 L
.70957 .57628 L
.68491 .58256 L
.66026 .58151 L
.6356 .57273 L
.61898 .56164 L
.61095 .55328 L
.6 .53698 L
.59094 .51233 L
.58899 .48767 L
.59348 .46302 L
.60602 .43836 L
.61095 .43191 L
.63235 .41371 L
F
0 g
.6356 .41201 m
.66026 .40285 L
.68491 .40158 L
.70957 .40783 L
.72289 .41371 L
.73422 .42314 L
.74767 .43836 L
.75888 .4602 L
.75959 .46302 L
.7641 .48767 L
.76189 .51233 L
.75888 .52269 L
.75281 .53698 L
.73422 .56038 L
.73309 .56164 L
.70957 .57628 L
.68491 .58256 L
.66026 .58151 L
.6356 .57273 L
.61898 .56164 L
.61095 .55328 L
.6 .53698 L
.59094 .51233 L
.58899 .48767 L
.59348 .46302 L
.60602 .43836 L
.61095 .43191 L
.63235 .41371 L
.6356 .41201 L
s
.98077 .93163 m
.95611 .94892 L
.94492 .95611 L
.93146 .96426 L
.9068 .97774 L
.90076 .98077 L
.98077 .98077 L
F
.98077 .93163 m
.95611 .94892 L
.94492 .95611 L
.93146 .96426 L
.9068 .97774 L
.90076 .98077 L
s
.98077 .05038 m
.97179 .04389 L
.95611 .03322 L
.93337 .01923 L
.98077 .01923 L
F
.98077 .05038 m
.97179 .04389 L
.95611 .03322 L
.93337 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.421 .746 .994 r
.39644 .6191 .40443 .62363 .41753 .62314 .40958 .61902 Mtetra
.376 .74 .99 r
.40958 .61902 .41753 .62314 .43073 .62286 .4228 .61919 Mtetra
.327 .731 .981 r
.4228 .61919 .43073 .62286 .44401 .62274 .43612 .61955 Mtetra
.278 .719 .963 r
.43612 .61955 .44401 .62274 .45739 .62272 .44954 .62002 Mtetra
.231 .705 .939 r
.44954 .62002 .45739 .62272 .47086 .6227 .46305 .62051 Mtetra
.191 .693 .911 r
.46305 .62051 .47086 .6227 .48444 .62261 .47668 .62091 Mtetra
.162 .683 .882 r
.47668 .62091 .48444 .62261 .49811 .62234 .4904 .62112 Mtetra
.146 .679 .854 r
.4904 .62112 .49811 .62234 .51189 .62179 .50424 .62101 Mtetra
.145 .684 .833 r
.50424 .62101 .51189 .62179 .52576 .62085 .51817 .62048 Mtetra
.159 .698 .82 r
.51817 .62048 .52576 .62085 .53972 .61943 .53221 .6194 Mtetra
.189 .72 .816 r
.53221 .6194 .53972 .61943 .55377 .61745 .54634 .61768 Mtetra
.233 .752 .821 r
.54634 .61768 .55377 .61745 .56791 .61483 .56055 .61525 Mtetra
.29 .789 .833 r
.56055 .61525 .56791 .61483 .58212 .61152 .57484 .61203 Mtetra
.354 .829 .852 r
.57484 .61203 .58212 .61152 .59639 .60749 .5892 .608 Mtetra
.424 .868 .872 r
.5892 .608 .59639 .60749 .61072 .60273 .60361 .60315 Mtetra
.493 .903 .893 r
.60361 .60315 .61072 .60273 .62509 .59726 .61807 .59749 Mtetra
.558 .931 .911 r
.61807 .59749 .62509 .59726 .63951 .59113 .63257 .59108 Mtetra
.616 .951 .926 r
.63257 .59108 .63951 .59113 .65397 .58439 .6471 .58398 Mtetra
.664 .961 .935 r
.6471 .58398 .65397 .58439 .66846 .57713 .66167 .57629 Mtetra
.702 .963 .941 r
.66167 .57629 .66846 .57713 .68298 .56943 .67626 .5681 Mtetra
.73 .959 .944 r
.67626 .5681 .68298 .56943 .69753 .56139 .69087 .55953 Mtetra
.749 .95 .943 r
.69087 .55953 .69753 .56139 .71211 .55312 .70551 .5507 Mtetra
.761 .937 .942 r
.70551 .5507 .71211 .55312 .72672 .54473 .72018 .54173 Mtetra
.767 .922 .939 r
.72018 .54173 .72672 .54473 .74138 .5363 .73489 .53272 Mtetra
.768 .906 .936 r
.73489 .53272 .74138 .5363 .75608 .52792 .74964 .52377 Mtetra
.766 .89 .933 r
.74964 .52377 .75608 .52792 .77084 .51966 .76445 .51496 Mtetra
.761 .874 .929 r
.76445 .51496 .77084 .51966 .78566 .51159 .7793 .50637 Mtetra
.754 .858 .926 r
.7793 .50637 .78566 .51159 .80054 .50375 .79423 .49804 Mtetra
.747 .843 .923 r
.79423 .49804 .80054 .50375 .8155 .49617 .80923 .49001 Mtetra
.738 .829 .921 r
.80923 .49001 .8155 .49617 .83054 .48887 .8243 .4823 Mtetra
.73 .816 .919 r
.8243 .4823 .83054 .48887 .84566 .48186 .83947 .47491 Mtetra
.721 .805 .917 r
.83947 .47491 .84566 .48186 .86087 .47513 .85472 .46785 Mtetra
.713 .794 .915 r
.85472 .46785 .86087 .47513 .87617 .46867 .87007 .4611 Mtetra
.705 .785 .913 r
.87007 .4611 .87617 .46867 .89157 .46246 .88551 .45463 Mtetra
.699 .777 .912 r
.88551 .45463 .89157 .46246 .90707 .45647 .90105 .44842 Mtetra
.692 .77 .911 r
.90105 .44842 .90707 .45647 .92266 .45068 .91669 .44244 Mtetra
.687 .764 .91 r
.91669 .44244 .92266 .45068 .93835 .44506 .93244 .43666 Mtetra
.682 .76 .91 r
.93244 .43666 .93835 .44506 .95414 .43959 .94828 .43105 Mtetra
.679 .756 .909 r
.94828 .43105 .95414 .43959 .97003 .43424 .96423 .42557 Mtetra
.374 .73 .99 r
.38837 .61468 .39644 .6191 .40958 .61902 .40153 .61505 Mtetra
.318 .717 .98 r
.40153 .61505 .40958 .61902 .4228 .61919 .41478 .6157 Mtetra
.259 .7 .961 r
.41478 .6157 .4228 .61919 .43612 .61955 .42813 .61657 Mtetra
.199 .679 .932 r
.42813 .61657 .43612 .61955 .44954 .62002 .44158 .61757 Mtetra
.144 .656 .897 r
.44158 .61757 .44954 .62002 .46305 .62051 .45514 .61859 Mtetra
.099 .636 .857 r
.45514 .61859 .46305 .62051 .47668 .62091 .46881 .61953 Mtetra
.066 .621 .818 r
.46881 .61953 .47668 .62091 .4904 .62112 .48259 .62026 Mtetra
.05 .614 .785 r
.48259 .62026 .4904 .62112 .50424 .62101 .49648 .62063 Mtetra
.052 .618 .761 r
.49648 .62063 .50424 .62101 .51817 .62048 .51049 .62053 Mtetra
.07 .633 .747 r
.51049 .62053 .51817 .62048 .53221 .6194 .52459 .61983 Mtetra
.106 .661 .745 r
.52459 .61983 .53221 .6194 .54634 .61768 .5388 .6184 Mtetra
.158 .699 .755 r
.5388 .6184 .54634 .61768 .56055 .61525 .55309 .61618 Mtetra
.223 .744 .774 r
.55309 .61618 .56055 .61525 .57484 .61203 .56746 .61307 Mtetra
.299 .794 .8 r
.56746 .61307 .57484 .61203 .5892 .608 .58191 .60904 Mtetra
.38 .844 .829 r
.58191 .60904 .5892 .608 .60361 .60315 .59641 .60409 Mtetra
.461 .889 .857 r
.59641 .60409 .60361 .60315 .61807 .59749 .61096 .59824 Mtetra
.537 .925 .883 r
.61096 .59824 .61807 .59749 .63257 .59108 .62554 .59153 Mtetra
.605 .951 .903 r
.62554 .59153 .63257 .59108 .6471 .58398 .64016 .58405 Mtetra
.661 .966 .918 r
.64016 .58405 .6471 .58398 .66167 .57629 .6548 .57589 Mtetra
.704 .972 .927 r
.6548 .57589 .66167 .57629 .67626 .5681 .66946 .56718 Mtetra
.736 .969 .933 r
.66946 .56718 .67626 .5681 .69087 .55953 .68414 .55805 Mtetra
.758 .961 .934 r
.68414 .55805 .69087 .55953 .70551 .5507 .69885 .54862 Mtetra
.772 .948 .934 r
.69885 .54862 .70551 .5507 .72018 .54173 .71358 .53903 Mtetra
.779 .933 .933 r
.71358 .53903 .72018 .54173 .73489 .53272 .72834 .5294 Mtetra
.78 .917 .931 r
.72834 .5294 .73489 .53272 .74964 .52377 .74314 .51984 Mtetra
.778 .9 .928 r
.74314 .51984 .74964 .52377 .76445 .51496 .75799 .51045 Mtetra
.772 .883 .926 r
.75799 .51045 .76445 .51496 .7793 .50637 .77289 .50129 Mtetra
.765 .866 .923 r
.77289 .50129 .7793 .50637 .79423 .49804 .78786 .49244 Mtetra
.756 .85 .921 r
.78786 .49244 .79423 .49804 .80923 .49001 .8029 .48393 Mtetra
.747 .836 .919 r
.8029 .48393 .80923 .49001 .8243 .4823 .81801 .47578 Mtetra
.738 .822 .917 r
.81801 .47578 .8243 .4823 .83947 .47491 .83322 .468 Mtetra
.728 .81 .915 r
.83322 .468 .83947 .47491 .85472 .46785 .84851 .46059 Mtetra
.719 .799 .914 r
.84851 .46059 .85472 .46785 .87007 .4611 .8639 .45353 Mtetra
.711 .789 .913 r
.8639 .45353 .87007 .4611 .88551 .45463 .87939 .44679 Mtetra
.703 .78 .912 r
.87939 .44679 .88551 .45463 .90105 .44842 .89498 .44034 Mtetra
.696 .773 .911 r
.89498 .44034 .90105 .44842 .91669 .44244 .91067 .43416 Mtetra
.69 .767 .91 r
.91067 .43416 .91669 .44244 .93244 .43666 .92647 .4282 Mtetra
.685 .761 .91 r
.92647 .4282 .93244 .43666 .94828 .43105 .94236 .42244 Mtetra
.68 .757 .909 r
.94236 .42244 .94828 .43105 .96423 .42557 .95836 .41683 Mtetra
.321 .708 .981 r
.3802 .61034 .38837 .61468 .40153 .61505 .39339 .61119 Mtetra
.254 .687 .962 r
.39339 .61119 .40153 .61505 .41478 .6157 .40666 .61235 Mtetra
.183 .66 .932 r
.40666 .61235 .41478 .6157 .42813 .61657 .42004 .61376 Mtetra
.114 .629 .891 r
.42004 .61376 .42813 .61657 .44158 .61757 .43353 .61533 Mtetra
.053 .598 .843 r
.43353 .61533 .44158 .61757 .45514 .61859 .44712 .61693 Mtetra
.004 .57 .793 r
.44712 .61693 .45514 .61859 .46881 .61953 .46084 .61844 Mtetra
0 .55 .747 r
.46084 .61844 .46881 .61953 .48259 .62026 .47467 .61971 Mtetra
0 .542 .71 r
.47467 .61971 .48259 .62026 .49648 .62063 .48862 .62061 Mtetra
.037 0 0 r
.48862 .62061 .49648 .62063 .51049 .62053 .50269 .62097 Mtetra
.013 0 0 r
.50269 .62097 .51049 .62053 .52459 .61983 .51687 .62067 Mtetra
0 0 0 r
.51687 .62067 .52459 .61983 .5388 .6184 .53115 .61957 Mtetra
.53115 .61957 .5388 .6184 .55309 .61618 .54552 .61756 Mtetra
.162 .698 .714 r
.54552 .61756 .55309 .61618 .56746 .61307 .55999 .61457 Mtetra
.247 .758 .748 r
.55999 .61457 .56746 .61307 .58191 .60904 .57452 .61056 Mtetra
.339 .818 .785 r
.57452 .61056 .58191 .60904 .59641 .60409 .58911 .60551 Mtetra
.432 .872 .822 r
.58911 .60551 .59641 .60409 .61096 .59824 .60375 .59945 Mtetra
.519 .917 .855 r
.60375 .59945 .61096 .59824 .62554 .59153 .61842 .59243 Mtetra
.596 .95 .881 r
.61842 .59243 .62554 .59153 .64016 .58405 .63313 .58454 Mtetra
.659 .97 .9 r
.63313 .58454 .64016 .58405 .6548 .57589 .64785 .5759 Mtetra
.709 .978 .913 r
.64785 .5759 .6548 .57589 .66946 .56718 .66259 .56665 Mtetra
.744 .977 .92 r
.66259 .56665 .66946 .56718 .68414 .55805 .67734 .55691 Mtetra
.769 .969 .924 r
.67734 .55691 .68414 .55805 .69885 .54862 .69211 .54685 Mtetra
.784 .957 .925 r
.69211 .54685 .69885 .54862 .71358 .53903 .70691 .53661 Mtetra
.791 .942 .925 r
.70691 .53661 .71358 .53903 .72834 .5294 .72173 .52632 Mtetra
.793 .925 .924 r
.72173 .52632 .72834 .5294 .74314 .51984 .73658 .51611 Mtetra
.79 .908 .922 r
.73658 .51611 .74314 .51984 .75799 .51045 .75147 .50609 Mtetra
.784 .89 .921 r
.75147 .50609 .75799 .51045 .77289 .50129 .76642 .49635 Mtetra
.776 .873 .919 r
.76642 .49635 .77289 .50129 .78786 .49244 .78143 .48694 Mtetra
.767 .857 .917 r
.78143 .48694 .78786 .49244 .8029 .48393 .79651 .47792 Mtetra
.756 .842 .916 r
.79651 .47792 .8029 .48393 .81801 .47578 .81167 .4693 Mtetra
.746 .827 .915 r
.81167 .4693 .81801 .47578 .83322 .468 .82691 .46111 Mtetra
.735 .814 .913 r
.82691 .46111 .83322 .468 .84851 .46059 .84225 .45333 Mtetra
.725 .803 .912 r
.84225 .45333 .84851 .46059 .8639 .45353 .85768 .44594 Mtetra
.716 .792 .912 r
.85768 .44594 .8639 .45353 .87939 .44679 .87321 .43891 Mtetra
.707 .783 .911 r
.87321 .43891 .87939 .44679 .89498 .44034 .88885 .43222 Mtetra
.7 .775 .91 r
.88885 .43222 .89498 .44034 .91067 .43416 .90459 .42582 Mtetra
.693 .769 .91 r
.90459 .42582 .91067 .43416 .92647 .4282 .92044 .41968 Mtetra
.687 .763 .909 r
.92044 .41968 .92647 .4282 .94236 .42244 .93639 .41376 Mtetra
.682 .758 .909 r
.93639 .41376 .94236 .42244 .95836 .41683 .95245 .40801 Mtetra
.264 .681 .967 r
.37194 .60607 .3802 .61034 .39339 .61119 .38514 .60741 Mtetra
.185 .65 .938 r
.38514 .60741 .39339 .61119 .40666 .61235 .39844 .60912 Mtetra
.104 .612 .895 r
.39844 .60912 .40666 .61235 .42004 .61376 .41185 .6111 Mtetra
.028 .572 .841 r
.41185 .6111 .42004 .61376 .43353 .61533 .42536 .61326 Mtetra
0 .532 .782 r
.42536 .61326 .43353 .61533 .44712 .61693 .439 .61546 Mtetra
0 .5 .724 r
.439 .61546 .44712 .61693 .46084 .61844 .45275 .61758 Mtetra
.116 0 0 r
.45275 .61758 .46084 .61844 .47467 .61971 .46663 .61944 Mtetra
.126 0 0 r
.46663 .61944 .47467 .61971 .48862 .62061 .48064 .62088 Mtetra
.117 0 0 r
.48064 .62088 .48862 .62061 .50269 .62097 .49477 .62174 Mtetra
.088 0 0 r
.49477 .62174 .50269 .62097 .51687 .62067 .50902 .62186 Mtetra
.04 0 0 r
.50902 .62186 .51687 .62067 .53115 .61957 .52338 .6211 Mtetra
0 0 0 r
.52338 .6211 .53115 .61957 .54552 .61756 .53785 .61934 Mtetra
.53785 .61934 .54552 .61756 .55999 .61457 .5524 .61648 Mtetra
.203 .723 .702 r
.5524 .61648 .55999 .61457 .57452 .61056 .56702 .61249 Mtetra
.306 .793 .747 r
.56702 .61249 .57452 .61056 .58911 .60551 .58171 .60734 Mtetra
.41 .858 .791 r
.58171 .60734 .58911 .60551 .60375 .59945 .59644 .60106 Mtetra
.507 .91 .83 r
.59644 .60106 .60375 .59945 .61842 .59243 .61121 .59372 Mtetra
.592 .949 .861 r
.61121 .59372 .61842 .59243 .63313 .58454 .626 .58541 Mtetra
.662 .972 .884 r
.626 .58541 .63313 .58454 .64785 .5759 .64081 .57627 Mtetra
.716 .983 .899 r
.64081 .57627 .64785 .5759 .66259 .56665 .65563 .56643 Mtetra
.754 .983 .908 r
.65563 .56643 .66259 .56665 .67734 .55691 .67046 .55606 Mtetra
.78 .976 .913 r
.67046 .55606 .67734 .55691 .69211 .54685 .6853 .54534 Mtetra
.796 .964 .915 r
.6853 .54534 .69211 .54685 .70691 .53661 .70016 .53441 Mtetra
.804 .949 .916 r
.70016 .53441 .70691 .53661 .72173 .52632 .71504 .52343 Mtetra
.805 .932 .916 r
.71504 .52343 .72173 .52632 .73658 .51611 .72994 .51255 Mtetra
.802 .914 .915 r
.72994 .51255 .73658 .51611 .75147 .50609 .74489 .50187 Mtetra
.796 .897 .915 r
.74489 .50187 .75147 .50609 .76642 .49635 .75988 .49151 Mtetra
.787 .879 .914 r
.75988 .49151 .76642 .49635 .78143 .48694 .77493 .48152 Mtetra
.777 .863 .913 r
.77493 .48152 .78143 .48694 .79651 .47792 .79006 .47196 Mtetra
.766 .847 .912 r
.79006 .47196 .79651 .47792 .81167 .4693 .80525 .46286 Mtetra
.754 .832 .912 r
.80525 .46286 .81167 .4693 .82691 .46111 .82054 .45423 Mtetra
.743 .819 .911 r
.82054 .45423 .82691 .46111 .84225 .45333 .83592 .44605 Mtetra
.732 .807 .911 r
.83592 .44605 .84225 .45333 .85768 .44594 .8514 .43832 Mtetra
.722 .796 .91 r
.8514 .43832 .85768 .44594 .87321 .43891 .86697 .431 Mtetra
.712 .786 .91 r
.86697 .431 .87321 .43891 .88885 .43222 .88266 .42405 Mtetra
.704 .778 .909 r
.88266 .42405 .88885 .43222 .90459 .42582 .89845 .41743 Mtetra
.696 .771 .909 r
.89845 .41743 .90459 .42582 .92044 .41968 .91435 .4111 Mtetra
.69 .765 .909 r
.91435 .4111 .92044 .41968 .93639 .41376 .93035 .40501 Mtetra
.685 .76 .908 r
.93035 .40501 .93639 .41376 .95245 .40801 .94647 .39912 Mtetra
.203 .648 .948 r
.36358 .60182 .37194 .60607 .38514 .60741 .3768 .60368 Mtetra
.114 .607 .907 r
.3768 .60368 .38514 .60741 .39844 .60912 .39012 .60595 Mtetra
.025 .559 .852 r
.39012 .60595 .39844 .60912 .41185 .6111 .40355 .60852 Mtetra
0 .51 .787 r
.40355 .60852 .41185 .6111 .42536 .61326 .41709 .6113 Mtetra
0 .465 .719 r
.41709 .6113 .42536 .61326 .439 .61546 .43076 .61414 Mtetra
.168 0 0 r
.43076 .61414 .439 .61546 .45275 .61758 .44455 .61689 Mtetra
.194 0 0 r
.44455 .61689 .45275 .61758 .46663 .61944 .45848 .61936 Mtetra
.2 0 0 r
.45848 .61936 .46663 .61944 .48064 .62088 .47255 .62138 Mtetra
.185 0 0 r
.47255 .62138 .48064 .62088 .49477 .62174 .48674 .62276 Mtetra
.151 0 0 r
.48674 .62276 .49477 .62174 .50902 .62186 .50106 .62333 Mtetra
.098 0 0 r
.50106 .62333 .50902 .62186 .52338 .6211 .5155 .62293 Mtetra
.026 0 0 r
.5155 .62293 .52338 .6211 .53785 .61934 .53005 .62142 Mtetra
0 0 0 r
.53005 .62142 .53785 .61934 .5524 .61648 .54469 .61871 Mtetra
.54469 .61871 .5524 .61648 .56702 .61249 .55941 .61474 Mtetra
.282 .774 .717 r
.55941 .61474 .56702 .61249 .58171 .60734 .57419 .60949 Mtetra
.396 .847 .768 r
.57419 .60949 .58171 .60734 .59644 .60106 .58902 .603 Mtetra
.503 .906 .812 r
.58902 .603 .59644 .60106 .61121 .59372 .60389 .59532 Mtetra
.595 .949 .846 r
.60389 .59532 .61121 .59372 .626 .58541 .61877 .58658 Mtetra
.669 .975 .871 r
.61877 .58658 .626 .58541 .64081 .57627 .63367 .57691 Mtetra
.726 .987 .887 r
.63367 .57691 .64081 .57627 .65563 .56643 .64858 .56647 Mtetra
.766 .988 .897 r
.64858 .56647 .65563 .56643 .67046 .55606 .66349 .55545 Mtetra
.793 .981 .902 r
.66349 .55545 .67046 .55606 .6853 .54534 .6784 .54402 Mtetra
.809 .969 .905 r
.6784 .54402 .6853 .54534 .70016 .53441 .69333 .53238 Mtetra
.816 .953 .907 r
.69333 .53238 .70016 .53441 .71504 .52343 .70827 .52069 Mtetra
.818 .937 .907 r
.70827 .52069 .71504 .52343 .72994 .51255 .72323 .5091 Mtetra
.814 .919 .908 r
.72323 .5091 .72994 .51255 .74489 .50187 .73823 .49775 Mtetra
.807 .901 .908 r
.73823 .49775 .74489 .50187 .75988 .49151 .75327 .48674 Mtetra
.798 .884 .908 r
.75327 .48674 .75988 .49151 .77493 .48152 .76837 .47614 Mtetra
.787 .867 .908 r
.76837 .47614 .77493 .48152 .79006 .47196 .78353 .46603 Mtetra
.775 .851 .908 r
.78353 .46603 .79006 .47196 .80525 .46286 .79878 .45642 Mtetra
.763 .836 .908 r
.79878 .45642 .80525 .46286 .82054 .45423 .81411 .44734 Mtetra
.75 .823 .908 r
.81411 .44734 .82054 .45423 .83592 .44605 .82953 .43876 Mtetra
.738 .81 .908 r
.82953 .43876 .83592 .44605 .8514 .43832 .84505 .43067 Mtetra
.727 .799 .908 r
.84505 .43067 .8514 .43832 .86697 .431 .86067 .42304 Mtetra
.717 .789 .908 r
.86067 .42304 .86697 .431 .88266 .42405 .8764 .41582 Mtetra
.708 .78 .908 r
.8764 .41582 .88266 .42405 .89845 .41743 .89225 .40897 Mtetra
.7 .772 .908 r
.89225 .40897 .89845 .41743 .91435 .4111 .9082 .40244 Mtetra
.693 .766 .908 r
.9082 .40244 .91435 .4111 .93035 .40501 .92426 .39618 Mtetra
.687 .761 .908 r
.92426 .39618 .93035 .40501 .94647 .39912 .94043 .39015 Mtetra
.142 .612 .924 r
.35512 .59757 .36358 .60182 .3768 .60368 .36836 .59996 Mtetra
.044 .56 .872 r
.36836 .59996 .3768 .60368 .39012 .60595 .3817 .6028 Mtetra
0 .504 .805 r
.3817 .6028 .39012 .60595 .40355 .60852 .39514 .60599 Mtetra
0 .448 .731 r
.39514 .60599 .40355 .60852 .41709 .6113 .40871 .6094 Mtetra
.196 0 0 r
.40871 .6094 .41709 .6113 .43076 .61414 .42241 .61289 Mtetra
.239 0 0 r
.42241 .61289 .43076 .61414 .44455 .61689 .43624 .61629 Mtetra
.261 0 0 r
.43624 .61629 .44455 .61689 .45848 .61936 .45022 .61939 Mtetra
.262 0 0 r
.45022 .61939 .45848 .61936 .47255 .62138 .46433 .62201 Mtetra
.243 0 0 r
.46433 .62201 .47255 .62138 .48674 .62276 .47859 .62393 Mtetra
.204 0 0 r
.47859 .62393 .48674 .62276 .50106 .62333 .49298 .62497 Mtetra
.145 0 0 r
.49298 .62497 .50106 .62333 .5155 .62293 .5075 .62495 Mtetra
.066 0 0 r
.5075 .62495 .5155 .62293 .53005 .62142 .52213 .62371 Mtetra
0 0 0 r
.52213 .62371 .53005 .62142 .54469 .61871 .53686 .62116 Mtetra
.53686 .62116 .54469 .61871 .55941 .61474 .55168 .61722 Mtetra
.269 .763 .699 r
.55168 .61722 .55941 .61474 .57419 .60949 .56656 .61187 Mtetra
.393 .843 .755 r
.56656 .61187 .57419 .60949 .58902 .603 .58149 .60515 Mtetra
.507 .907 .802 r
.58149 .60515 .58902 .603 .60389 .59532 .59645 .59714 Mtetra
.605 .953 .838 r
.59645 .59714 .60389 .59532 .61877 .58658 .61144 .58795 Mtetra
.682 .979 .862 r
.61144 .58795 .61877 .58658 .63367 .57691 .62643 .57773 Mtetra
.74 .99 .878 r
.62643 .57773 .63367 .57691 .64858 .56647 .64143 .56668 Mtetra
.78 .991 .887 r
.64143 .56668 .64858 .56647 .66349 .55545 .65642 .55498 Mtetra
.807 .983 .892 r
.65642 .55498 .66349 .55545 .6784 .54402 .67141 .54285 Mtetra
.822 .971 .895 r
.67141 .54285 .6784 .54402 .69333 .53238 .68641 .53047 Mtetra
.829 .956 .897 r
.68641 .53047 .69333 .53238 .70827 .52069 .70141 .51804 Mtetra
.83 .939 .898 r
.70141 .51804 .70827 .52069 .72323 .5091 .71644 .50573 Mtetra
.826 .922 .899 r
.71644 .50573 .72323 .5091 .73823 .49775 .73149 .49367 Mtetra
.818 .904 .9 r
.73149 .49367 .73823 .49775 .75327 .48674 .74658 .482 Mtetra
.808 .887 .901 r
.74658 .482 .75327 .48674 .76837 .47614 .76173 .47078 Mtetra
.797 .87 .902 r
.76173 .47078 .76837 .47614 .78353 .46603 .77694 .4601 Mtetra
.784 .855 .903 r
.77694 .4601 .78353 .46603 .79878 .45642 .79223 .44997 Mtetra
.771 .84 .904 r
.79223 .44997 .79878 .45642 .81411 .44734 .8076 .44042 Mtetra
.758 .826 .905 r
.8076 .44042 .81411 .44734 .82953 .43876 .82307 .43143 Mtetra
.745 .813 .906 r
.82307 .43143 .82953 .43876 .84505 .43067 .83863 .42298 Mtetra
.733 .801 .906 r
.83863 .42298 .84505 .43067 .86067 .42304 .85431 .41503 Mtetra
.722 .791 .907 r
.85431 .41503 .86067 .42304 .8764 .41582 .87009 .40753 Mtetra
.712 .782 .907 r
.87009 .40753 .8764 .41582 .89225 .40897 .88598 .40044 Mtetra
.703 .774 .907 r
.88598 .40044 .89225 .40897 .9082 .40244 .90198 .39371 Mtetra
.695 .768 .907 r
.90198 .39371 .9082 .40244 .92426 .39618 .9181 .38727 Mtetra
.689 .762 .907 r
.9181 .38727 .92426 .39618 .94043 .39015 .93433 .38109 Mtetra
.082 .572 .898 r
.34657 .59327 .35512 .59757 .36836 .59996 .35982 .5962 Mtetra
0 .512 .835 r
.35982 .5962 .36836 .59996 .3817 .6028 .37317 .59961 Mtetra
0 .449 .76 r
.37317 .59961 .3817 .6028 .39514 .60599 .38663 .60342 Mtetra
0 .389 .68 r
.38663 .60342 .39514 .60599 .40871 .6094 .40022 .60748 Mtetra
.261 0 0 r
.40022 .60748 .40871 .6094 .42241 .61289 .41395 .61164 Mtetra
.3 0 0 r
.41395 .61164 .42241 .61289 .43624 .61629 .42781 .6157 Mtetra
.317 0 0 r
.42781 .6157 .43624 .61629 .45022 .61939 .44183 .61945 Mtetra
.313 0 0 r
.44183 .61945 .45022 .61939 .46433 .62201 .456 .62268 Mtetra
.289 0 0 r
.456 .62268 .46433 .62201 .47859 .62393 .47031 .62516 Mtetra
.246 0 0 r
.47031 .62516 .47859 .62393 .49298 .62497 .48477 .62668 Mtetra
.181 0 0 r
.48477 .62668 .49298 .62497 .5075 .62495 .49937 .62704 Mtetra
.096 0 0 r
.49937 .62704 .5075 .62495 .52213 .62371 .51409 .62609 Mtetra
0 0 0 r
.51409 .62609 .52213 .62371 .53686 .62116 .52891 .6237 Mtetra
.52891 .6237 .53686 .62116 .55168 .61722 .54382 .61979 Mtetra
.268 .762 .695 r
.54382 .61979 .55168 .61722 .56656 .61187 .55881 .61435 Mtetra
.401 .847 .754 r
.55881 .61435 .56656 .61187 .58149 .60515 .57384 .60741 Mtetra
.521 .914 .802 r
.57384 .60741 .58149 .60515 .59645 .59714 .58891 .59905 Mtetra
.622 .959 .836 r
.58891 .59905 .59645 .59714 .61144 .58795 .60399 .58941 Mtetra
.7 .984 .859 r
.60399 .58941 .61144 .58795 .62643 .57773 .61908 .57865 Mtetra
.757 .993 .872 r
.61908 .57865 .62643 .57773 .64143 .56668 .63417 .56696 Mtetra
.796 .992 .879 r
.63417 .56696 .64143 .56668 .65642 .55498 .64925 .55458 Mtetra
.821 .983 .883 r
.64925 .55458 .65642 .55498 .67141 .54285 .66432 .54172 Mtetra
.835 .971 .886 r
.66432 .54172 .67141 .54285 .68641 .53047 .6794 .5286 Mtetra
.841 .955 .887 r
.6794 .5286 .68641 .53047 .70141 .51804 .69447 .51541 Mtetra
.841 .939 .889 r
.69447 .51541 .70141 .51804 .71644 .50573 .70956 .50236 Mtetra
.837 .922 .89 r
.70956 .50236 .71644 .50573 .73149 .49367 .72467 .4896 Mtetra
.829 .905 .892 r
.72467 .4896 .73149 .49367 .74658 .482 .73982 .47724 Mtetra
.818 .889 .894 r
.73982 .47724 .74658 .482 .76173 .47078 .75501 .4654 Mtetra
.806 .872 .896 r
.75501 .4654 .76173 .47078 .77694 .4601 .77027 .45413 Mtetra
.792 .857 .898 r
.77027 .45413 .77694 .4601 .79223 .44997 .78561 .44347 Mtetra
.779 .842 .9 r
.78561 .44347 .79223 .44997 .8076 .44042 .80103 .43345 Mtetra
.765 .828 .901 r
.80103 .43345 .8076 .44042 .82307 .43143 .81654 .42403 Mtetra
.751 .815 .903 r
.81654 .42403 .82307 .43143 .83863 .42298 .83215 .41521 Mtetra
.738 .803 .904 r
.83215 .41521 .83863 .42298 .85431 .41503 .84787 .40694 Mtetra
.727 .793 .905 r
.84787 .40694 .85431 .41503 .87009 .40753 .8637 .39916 Mtetra
.716 .784 .905 r
.8637 .39916 .87009 .40753 .88598 .40044 .87965 .39183 Mtetra
.706 .776 .906 r
.87965 .39183 .88598 .40044 .90198 .39371 .8957 .38489 Mtetra
.698 .769 .906 r
.8957 .38489 .90198 .39371 .9181 .38727 .91187 .37828 Mtetra
.691 .763 .907 r
.91187 .37828 .9181 .38727 .93433 .38109 .92816 .37194 Mtetra
.025 .532 .871 r
.33793 .58888 .34657 .59327 .35982 .5962 .35118 .59233 Mtetra
0 .465 .799 r
.35118 .59233 .35982 .5962 .37317 .59961 .36454 .59633 Mtetra
0 .397 .717 r
.36454 .59633 .37317 .59961 .38663 .60342 .37802 .60076 Mtetra
.259 0 0 r
.37802 .60076 .38663 .60342 .40022 .60748 .39163 .60547 Mtetra
.315 0 0 r
.39163 .60547 .40022 .60748 .41395 .61164 .40537 .61029 Mtetra
.349 0 0 r
.40537 .61029 .41395 .61164 .42781 .6157 .41927 .61502 Mtetra
.361 0 0 r
.41927 .61502 .42781 .6157 .44183 .61945 .43333 .61942 Mtetra
.354 0 0 r
.43333 .61942 .44183 .61945 .456 .62268 .44754 .62327 Mtetra
.326 0 0 r
.44754 .62327 .456 .62268 .47031 .62516 .46191 .62631 Mtetra
.277 0 0 r
.46191 .62631 .47031 .62516 .48477 .62668 .47644 .62832 Mtetra
.207 0 0 r
.47644 .62832 .48477 .62668 .49937 .62704 .49111 .62908 Mtetra
.114 0 0 r
.49111 .62908 .49937 .62704 .51409 .62609 .50591 .62842 Mtetra
0 0 0 r
.50591 .62842 .51409 .62609 .52891 .6237 .52083 .62619 Mtetra
.52083 .62619 .52891 .6237 .54382 .61979 .53584 .62233 Mtetra
.281 .771 .706 r
.53584 .62233 .54382 .61979 .55881 .61435 .55092 .6168 Mtetra
.421 .86 .766 r
.55092 .6168 .55881 .61435 .57384 .60741 .56606 .60964 Mtetra
.546 .926 .812 r
.56606 .60964 .57384 .60741 .58891 .59905 .58123 .60094 Mtetra
.647 .968 .842 r
.58123 .60094 .58891 .59905 .60399 .58941 .59642 .59084 Mtetra
.723 .989 .86 r
.59642 .59084 .60399 .58941 .61908 .57865 .61161 .57952 Mtetra
.777 .995 .869 r
.61161 .57952 .61908 .57865 .63417 .56696 .6268 .56721 Mtetra
.813 .991 .874 r
.6268 .56721 .63417 .56696 .64925 .55458 .64197 .55414 Mtetra
.836 .981 .876 r
.64197 .55414 .64925 .55458 .66432 .54172 .65713 .54055 Mtetra
.848 .968 .877 r
.65713 .54055 .66432 .54172 .6794 .5286 .67228 .52667 Mtetra
.853 .953 .878 r
.67228 .52667 .6794 .5286 .69447 .51541 .68743 .51273 Mtetra
.852 .937 .879 r
.68743 .51273 .69447 .51541 .70956 .50236 .70258 .49894 Mtetra
.847 .92 .881 r
.70258 .49894 .70956 .50236 .72467 .4896 .71776 .48546 Mtetra
.838 .904 .884 r
.71776 .48546 .72467 .4896 .73982 .47724 .73296 .47242 Mtetra
.827 .888 .886 r
.73296 .47242 .73982 .47724 .75501 .4654 .74821 .45994 Mtetra
.814 .873 .889 r
.74821 .45994 .75501 .4654 .77027 .45413 .76353 .44809 Mtetra
.8 .857 .892 r
.76353 .44809 .77027 .45413 .78561 .44347 .77891 .4369 Mtetra
.786 .843 .895 r
.77891 .4369 .78561 .44347 .80103 .43345 .79438 .42639 Mtetra
.771 .829 .897 r
.79438 .42639 .80103 .43345 .81654 .42403 .80994 .41656 Mtetra
.757 .817 .899 r
.80994 .41656 .81654 .42403 .83215 .41521 .8256 .40736 Mtetra
.744 .805 .901 r
.8256 .40736 .83215 .41521 .84787 .40694 .84137 .39876 Mtetra
.731 .794 .902 r
.84137 .39876 .84787 .40694 .8637 .39916 .85725 .3907 Mtetra
.72 .785 .904 r
.85725 .3907 .8637 .39916 .87965 .39183 .87325 .38313 Mtetra
.71 .777 .905 r
.87325 .38313 .87965 .39183 .8957 .38489 .88936 .37598 Mtetra
.701 .77 .905 r
.88936 .37598 .8957 .38489 .91187 .37828 .90559 .36919 Mtetra
.693 .764 .906 r
.90559 .36919 .91187 .37828 .92816 .37194 .92193 .3627 Mtetra
0 .494 .844 r
.32919 .58433 .33793 .58888 .35118 .59233 .34245 .58831 Mtetra
0 .421 .767 r
.34245 .58831 .35118 .59233 .36454 .59633 .35582 .59288 Mtetra
0 .35 .681 r
.35582 .59288 .36454 .59633 .37802 .60076 .3693 .59792 Mtetra
.306 0 0 r
.3693 .59792 .37802 .60076 .39163 .60547 .38292 .60327 Mtetra
.359 0 0 r
.38292 .60327 .39163 .60547 .40537 .61029 .39669 .60875 Mtetra
.388 0 0 r
.39669 .60875 .40537 .61029 .41927 .61502 .41062 .61414 Mtetra
.397 0 0 r
.41062 .61414 .41927 .61502 .43333 .61942 .42471 .6192 Mtetra
.385 0 0 r
.42471 .6192 .43333 .61942 .44754 .62327 .43896 .62366 Mtetra
.353 0 0 r
.43896 .62366 .44754 .62327 .46191 .62631 .45339 .62726 Mtetra
.3 0 0 r
.45339 .62726 .46191 .62631 .47644 .62832 .46798 .62976 Mtetra
.223 0 0 r
.46798 .62976 .47644 .62832 .49111 .62908 .48273 .63092 Mtetra
.121 0 0 r
.48273 .63092 .49111 .62908 .50591 .62842 .49761 .63054 Mtetra
0 0 0 r
.49761 .63054 .50591 .62842 .52083 .62619 .51262 .62849 Mtetra
.51262 .62849 .52083 .62619 .53584 .62233 .52773 .62467 Mtetra
.307 .791 .732 r
.52773 .62467 .53584 .62233 .55092 .6168 .54291 .61906 Mtetra
.454 .88 .79 r
.54291 .61906 .55092 .6168 .56606 .60964 .55816 .61168 Mtetra
.579 .942 .83 r
.55816 .61168 .56606 .60964 .58123 .60094 .57344 .60264 Mtetra
.677 .978 .854 r
.57344 .60264 .58123 .60094 .59642 .59084 .58873 .5921 Mtetra
.749 .993 .865 r
.58873 .5921 .59642 .59084 .61161 .57952 .60403 .58024 Mtetra
.798 .995 .869 r
.60403 .58024 .61161 .57952 .6268 .56721 .61931 .5673 Mtetra
.83 .988 .869 r
.61931 .5673 .6268 .56721 .64197 .55414 .63458 .55354 Mtetra
.85 .976 .869 r
.63458 .55354 .64197 .55414 .65713 .54055 .64983 .53922 Mtetra
.86 .963 .868 r
.64983 .53922 .65713 .54055 .67228 .52667 .66506 .5246 Mtetra
.863 .948 .869 r
.66506 .5246 .67228 .52667 .68743 .51273 .68029 .50992 Mtetra
.861 .932 .87 r
.68029 .50992 .68743 .51273 .70258 .49894 .69551 .49538 Mtetra
.855 .917 .872 r
.69551 .49538 .70258 .49894 .71776 .48546 .71075 .48119 Mtetra
.846 .901 .875 r
.71075 .48119 .71776 .48546 .73296 .47242 .72602 .46748 Mtetra
.835 .886 .878 r
.72602 .46748 .73296 .47242 .74821 .45994 .74133 .45437 Mtetra
.822 .871 .882 r
.74133 .45437 .74821 .45994 .76353 .44809 .75669 .44193 Mtetra
.808 .857 .886 r
.75669 .44193 .76353 .44809 .77891 .4369 .77213 .43022 Mtetra
.793 .843 .889 r
.77213 .43022 .77891 .4369 .79438 .42639 .78765 .41923 Mtetra
.778 .83 .893 r
.78765 .41923 .79438 .42639 .80994 .41656 .80326 .40898 Mtetra
.763 .817 .895 r
.80326 .40898 .80994 .41656 .8256 .40736 .81897 .39941 Mtetra
.749 .806 .898 r
.81897 .39941 .8256 .40736 .84137 .39876 .83479 .39048 Mtetra
.736 .795 .9 r
.83479 .39048 .84137 .39876 .85725 .3907 .85073 .38215 Mtetra
.724 .786 .902 r
.85073 .38215 .85725 .3907 .87325 .38313 .86678 .37433 Mtetra
.713 .778 .903 r
.86678 .37433 .87325 .38313 .88936 .37598 .88294 .36697 Mtetra
.704 .771 .904 r
.88294 .36697 .88936 .37598 .90559 .36919 .89923 .36 Mtetra
.696 .765 .905 r
.89923 .36 .90559 .36919 .92193 .3627 .91563 .35335 Mtetra
0 .458 .821 r
.32036 .57959 .32919 .58433 .34245 .58831 .33362 .58408 Mtetra
0 .382 .739 r
.33362 .58408 .34245 .58831 .35582 .59288 .34699 .5892 Mtetra
0 .311 .653 r
.34699 .5892 .35582 .59288 .3693 .59792 .36049 .59483 Mtetra
.344 0 0 r
.36049 .59483 .3693 .59792 .38292 .60327 .37412 .6008 Mtetra
.392 0 0 r
.37412 .6008 .38292 .60327 .39669 .60875 .3879 .60693 Mtetra
.418 0 0 r
.3879 .60693 .39669 .60875 .41062 .61414 .40185 .61296 Mtetra
.423 0 0 r
.40185 .61296 .41062 .61414 .42471 .6192 .41597 .61865 Mtetra
.408 0 0 r
.41597 .61865 .42471 .6192 .43896 .62366 .43027 .62371 Mtetra
.372 0 0 r
.43027 .62371 .43896 .62366 .45339 .62726 .44475 .62786 Mtetra
.313 0 0 r
.44475 .62786 .45339 .62726 .46798 .62976 .4594 .63084 Mtetra
.229 0 0 r
.4594 .63084 .46798 .62976 .48273 .63092 .47421 .63239 Mtetra
.117 0 0 r
.47421 .63239 .48273 .63092 .49761 .63054 .48918 .63231 Mtetra
0 0 0 r
.48918 .63231 .49761 .63054 .51262 .62849 .50427 .63043 Mtetra
.182 .709 .7 r
.50427 .63043 .51262 .62849 .52773 .62467 .51948 .62666 Mtetra
.346 .82 .771 r
.51948 .62666 .52773 .62467 .54291 .61906 .53477 .62097 Mtetra
.496 .905 .823 r
.53477 .62097 .54291 .61906 .55816 .61168 .55012 .61338 Mtetra
.619 .959 .854 r
.55012 .61338 .55816 .61168 .57344 .60264 .56551 .60402 Mtetra
.711 .986 .869 r
.56551 .60402 .57344 .60264 .58873 .5921 .58091 .59303 Mtetra
.776 .995 .872 r
.58091 .59303 .58873 .5921 .60403 .58024 .59631 .58064 Mtetra
.819 .991 .87 r
.59631 .58064 .60403 .58024 .61931 .5673 .6117 .5671 Mtetra
.847 .982 .866 r
.6117 .5671 .61931 .5673 .63458 .55354 .62707 .55267 Mtetra
.863 .969 .863 r
.62707 .55267 .63458 .55354 .64983 .53922 .64241 .53764 Mtetra
.87 .954 .86 r
.64241 .53764 .64983 .53922 .66506 .5246 .65773 .52229 Mtetra
.872 .94 .86 r
.65773 .52229 .66506 .5246 .68029 .50992 .67304 .50687 Mtetra
.869 .925 .861 r
.67304 .50687 .68029 .50992 .69551 .49538 .68834 .49161 Mtetra
.863 .911 .863 r
.68834 .49161 .69551 .49538 .71075 .48119 .70365 .47672 Mtetra
.853 .896 .866 r
.70365 .47672 .71075 .48119 .72602 .46748 .71898 .46235 Mtetra
.842 .882 .87 r
.71898 .46235 .72602 .46748 .74133 .45437 .73435 .44862 Mtetra
.829 .869 .875 r
.73435 .44862 .74133 .45437 .75669 .44193 .74977 .43561 Mtetra
.814 .855 .879 r
.74977 .43561 .75669 .44193 .77213 .43022 .76526 .42338 Mtetra
.799 .842 .884 r
.76526 .42338 .77213 .43022 .78765 .41923 .78084 .41193 Mtetra
.783 .829 .888 r
.78084 .41193 .78765 .41923 .80326 .40898 .7965 .40126 Mtetra
.768 .817 .891 r
.7965 .40126 .80326 .40898 .81897 .39941 .81226 .39133 Mtetra
.754 .806 .895 r
.81226 .39133 .81897 .39941 .83479 .39048 .82814 .38208 Mtetra
.74 .796 .897 r
.82814 .38208 .83479 .39048 .85073 .38215 .84413 .37347 Mtetra
.727 .787 .9 r
.84413 .37347 .85073 .38215 .86678 .37433 .86023 .36541 Mtetra
.716 .778 .901 r
.86023 .36541 .86678 .37433 .88294 .36697 .87646 .35785 Mtetra
.706 .771 .903 r
.87646 .35785 .88294 .36697 .89923 .36 .8928 .3507 Mtetra
.698 .765 .904 r
.8928 .3507 .89923 .36 .91563 .35335 .90927 .3439 Mtetra
0 .427 .802 r
.31144 .5746 .32036 .57959 .33362 .58408 .3247 .57956 Mtetra
0 .349 .719 r
.3247 .57956 .33362 .58408 .34699 .5892 .33808 .5852 Mtetra
.303 0 0 r
.33808 .5852 .34699 .5892 .36049 .59483 .35157 .5914 Mtetra
.371 0 0 r
.35157 .5914 .36049 .59483 .37412 .6008 .36521 .59797 Mtetra
.416 0 0 r
.36521 .59797 .37412 .6008 .3879 .60693 .37901 .6047 Mtetra
.438 0 0 r
.37901 .6047 .3879 .60693 .40185 .61296 .39298 .61135 Mtetra
.44 0 0 r
.39298 .61135 .40185 .61296 .41597 .61865 .40712 .61764 Mtetra
.422 0 0 r
.40712 .61764 .41597 .61865 .43027 .62371 .42146 .62328 Mtetra
.381 0 0 r
.42146 .62328 .43027 .62371 .44475 .62786 .43598 .62797 Mtetra
.316 0 0 r
.43598 .62797 .44475 .62786 .4594 .63084 .45069 .63141 Mtetra
.223 0 0 r
.45069 .63141 .4594 .63084 .47421 .63239 .46557 .63334 Mtetra
.099 0 0 r
.46557 .63334 .47421 .63239 .48918 .63231 .48062 .63354 Mtetra
0 0 0 r
.48062 .63354 .48918 .63231 .50427 .63043 .4958 .63184 Mtetra
.227 .745 .755 r
.4958 .63184 .50427 .63043 .51948 .62666 .5111 .62812 Mtetra
.397 .853 .821 r
.5111 .62812 .51948 .62666 .53477 .62097 .52649 .62235 Mtetra
.546 .93 .863 r
.52649 .62235 .53477 .62097 .55012 .61338 .54195 .61457 Mtetra
.662 .973 .881 r
.54195 .61457 .55012 .61338 .56551 .60402 .55745 .6049 Mtetra
.745 .99 .884 r
.55745 .6049 .56551 .60402 .58091 .59303 .57296 .59349 Mtetra
.801 .991 .879 r
.57296 .59349 .58091 .59303 .59631 .58064 .58847 .58059 Mtetra
.838 .984 .871 r
.58847 .58059 .59631 .58064 .6117 .5671 .60397 .56646 Mtetra
.86 .972 .863 r
.60397 .56646 .6117 .5671 .62707 .55267 .61943 .55139 Mtetra
.873 .958 .857 r
.61943 .55139 .62707 .55267 .64241 .53764 .63487 .53568 Mtetra
.879 .944 .853 r
.63487 .53568 .64241 .53764 .65773 .52229 .65028 .51962 Mtetra
.879 .93 .851 r
.65028 .51962 .65773 .52229 .67304 .50687 .66568 .5035 Mtetra
.875 .916 .852 r
.66568 .5035 .67304 .50687 .68834 .49161 .68106 .48755 Mtetra
.868 .903 .854 r
.68106 .48755 .68834 .49161 .70365 .47672 .69644 .47198 Mtetra
.859 .89 .858 r
.69644 .47198 .70365 .47672 .71898 .46235 .71184 .45697 Mtetra
.847 .877 .862 r
.71184 .45697 .71898 .46235 .73435 .44862 .72727 .44265 Mtetra
.834 .864 .867 r
.72727 .44265 .73435 .44862 .74977 .43561 .74276 .42909 Mtetra
.819 .852 .873 r
.74276 .42909 .74977 .43561 .76526 .42338 .75831 .41636 Mtetra
.804 .84 .878 r
.75831 .41636 .76526 .42338 .78084 .41193 .77394 .40446 Mtetra
.788 .828 .883 r
.77394 .40446 .78084 .41193 .7965 .40126 .78966 .39339 Mtetra
.773 .816 .887 r
.78966 .39339 .7965 .40126 .81226 .39133 .80548 .3831 Mtetra
.758 .806 .891 r
.80548 .3831 .81226 .39133 .82814 .38208 .82141 .37355 Mtetra
.744 .796 .895 r
.82141 .37355 .82814 .38208 .84413 .37347 .83745 .36466 Mtetra
.731 .787 .897 r
.83745 .36466 .84413 .37347 .86023 .36541 .85362 .35637 Mtetra
.719 .779 .9 r
.85362 .35637 .86023 .36541 .87646 .35785 .8699 .3486 Mtetra
.708 .772 .901 r
.8699 .3486 .87646 .35785 .8928 .3507 .88631 .34128 Mtetra
.7 .766 .903 r
.88631 .34128 .8928 .3507 .90927 .3439 .90284 .33433 Mtetra
0 .401 .788 r
.30243 .5693 .31144 .5746 .3247 .57956 .3157 .57471 Mtetra
0 .323 .706 r
.3157 .57471 .3247 .57956 .33808 .5852 .32907 .58083 Mtetra
.323 0 0 r
.32907 .58083 .33808 .5852 .35157 .5914 .34257 .58755 Mtetra
.388 0 0 r
.34257 .58755 .35157 .5914 .36521 .59797 .35621 .59467 Mtetra
.43 0 0 r
.35621 .59467 .36521 .59797 .37901 .6047 .37002 .60197 Mtetra
.45 0 0 r
.37002 .60197 .37901 .6047 .39298 .61135 .384 .6092 Mtetra
.449 0 0 r
.384 .6092 .39298 .61135 .40712 .61764 .39817 .61606 Mtetra
.427 0 0 r
.39817 .61606 .40712 .61764 .42146 .62328 .41254 .62224 Mtetra
.381 0 0 r
.41254 .62224 .42146 .62328 .43598 .62797 .42711 .62743 Mtetra
.309 0 0 r
.42711 .62743 .43598 .62797 .45069 .63141 .44187 .63131 Mtetra
.205 0 0 r
.44187 .63131 .45069 .63141 .46557 .63334 .45682 .63361 Mtetra
.067 0 0 r
.45682 .63361 .46557 .63334 .48062 .63354 .47193 .63408 Mtetra
.101 .657 .74 r
.47193 .63408 .48062 .63354 .4958 .63184 .4872 .63254 Mtetra
.284 .786 .82 r
.4872 .63254 .4958 .63184 .5111 .62812 .50259 .62887 Mtetra
.456 .886 .875 r
.50259 .62887 .5111 .62812 .52649 .62235 .51809 .62304 Mtetra
.598 .949 .901 r
.51809 .62304 .52649 .62235 .54195 .61457 .53365 .61508 Mtetra
.703 .979 .905 r
.53365 .61508 .54195 .61457 .55745 .6049 .54925 .60511 Mtetra
.775 .987 .897 r
.54925 .60511 .55745 .6049 .57296 .59349 .56488 .59331 Mtetra
.823 .982 .883 r
.56488 .59331 .57296 .59349 .58847 .58059 .5805 .57993 Mtetra
.853 .971 .87 r
.5805 .57993 .58847 .58059 .60397 .56646 .5961 .56525 Mtetra
.871 .958 .859 r
.5961 .56525 .60397 .56646 .61943 .55139 .61167 .54957 Mtetra
.881 .944 .851 r
.61167 .54957 .61943 .55139 .63487 .53568 .62721 .53322 Mtetra
.884 .931 .845 r
.62721 .53322 .63487 .53568 .65028 .51962 .64272 .5165 Mtetra
.884 .918 .843 r
.64272 .5165 .65028 .51962 .66568 .5035 .6582 .4997 Mtetra
.88 .905 .843 r
.6582 .4997 .66568 .5035 .68106 .48755 .67366 .48309 Mtetra
.872 .893 .845 r
.67366 .48309 .68106 .48755 .69644 .47198 .68912 .46689 Mtetra
.863 .882 .849 r
.68912 .46689 .69644 .47198 .71184 .45697 .7046 .45128 Mtetra
.851 .87 .854 r
.7046 .45128 .71184 .45697 .72727 .44265 .7201 .43639 Mtetra
.838 .859 .86 r
.7201 .43639 .72727 .44265 .74276 .42909 .73565 .42231 Mtetra
.824 .848 .866 r
.73565 .42231 .74276 .42909 .75831 .41636 .75126 .40911 Mtetra
.808 .837 .872 r
.75126 .40911 .75831 .41636 .77394 .40446 .76695 .39678 Mtetra
.793 .826 .878 r
.76695 .39678 .77394 .40446 .78966 .39339 .78273 .38532 Mtetra
.777 .815 .883 r
.78273 .38532 .78966 .39339 .80548 .3831 .79861 .3747 Mtetra
.762 .805 .888 r
.79861 .3747 .80548 .3831 .82141 .37355 .8146 .36485 Mtetra
.747 .795 .892 r
.8146 .36485 .82141 .37355 .83745 .36466 .8307 .35571 Mtetra
.734 .787 .895 r
.8307 .35571 .83745 .36466 .85362 .35637 .84693 .3472 Mtetra
.721 .779 .898 r
.84693 .3472 .85362 .35637 .8699 .3486 .86327 .33923 Mtetra
.711 .772 .9 r
.86327 .33923 .8699 .3486 .88631 .34128 .87974 .33174 Mtetra
.701 .766 .902 r
.87974 .33174 .88631 .34128 .90284 .33433 .89633 .32464 Mtetra
0 .381 .78 r
.29335 .56365 .30243 .5693 .3157 .57471 .30661 .56945 Mtetra
0 .304 .701 r
.30661 .56945 .3157 .57471 .32907 .58083 .31998 .57601 Mtetra
.334 0 0 r
.31998 .57601 .32907 .58083 .34257 .58755 .33348 .5832 Mtetra
.396 0 0 r
.33348 .5832 .34257 .58755 .35621 .59467 .34713 .59082 Mtetra
.435 0 0 r
.34713 .59082 .35621 .59467 .37002 .60197 .36094 .59864 Mtetra
.452 0 0 r
.36094 .59864 .37002 .60197 .384 .6092 .37493 .6064 Mtetra
.448 0 0 r
.37493 .6064 .384 .6092 .39817 .61606 .38913 .61378 Mtetra
.421 0 0 r
.38913 .61378 .39817 .61606 .41254 .62224 .40352 .62046 Mtetra
.37 0 0 r
.40352 .62046 .41254 .62224 .42711 .62743 .41813 .6261 Mtetra
.289 0 0 r
.41813 .6261 .42711 .62743 .44187 .63131 .43294 .63039 Mtetra
.172 0 0 r
.43294 .63039 .44187 .63131 .45682 .63361 .44794 .63302 Mtetra
0 .561 .724 r
.44794 .63302 .45682 .63361 .47193 .63408 .46313 .63374 Mtetra
.163 .701 .815 r
.46313 .63374 .47193 .63408 .4872 .63254 .47848 .63235 Mtetra
.351 .823 .886 r
.47848 .63235 .4872 .63254 .50259 .62887 .49396 .62873 Mtetra
.518 .91 .925 r
.49396 .62873 .50259 .62887 .51809 .62304 .50955 .62284 Mtetra
.647 .958 .933 r
.50955 .62284 .51809 .62304 .53365 .61508 .52521 .61472 Mtetra
.739 .976 .923 r
.52521 .61472 .53365 .61508 .54925 .60511 .54093 .60449 Mtetra
.8 .976 .904 r
.54093 .60449 .54925 .60511 .56488 .59331 .55666 .59233 Mtetra
.839 .967 .885 r
.55666 .59233 .56488 .59331 .5805 .57993 .57239 .57851 Mtetra
.863 .955 .868 r
.57239 .57851 .5805 .57993 .5961 .56525 .5881 .56332 Mtetra
.878 .941 .854 r
.5881 .56332 .5961 .56525 .61167 .54957 .60378 .54708 Mtetra
.885 .928 .844 r
.60378 .54708 .61167 .54957 .62721 .53322 .61942 .53014 Mtetra
.888 .915 .838 r
.61942 .53014 .62721 .53322 .64272 .5165 .63503 .5128 Mtetra
.886 .904 .835 r
.63503 .5128 .64272 .5165 .6582 .4997 .6506 .49539 Mtetra
.882 .893 .835 r
.6506 .49539 .6582 .4997 .67366 .48309 .66615 .47817 Mtetra
.875 .882 .837 r
.66615 .47817 .67366 .48309 .68912 .46689 .68169 .46138 Mtetra
.865 .872 .841 r
.68169 .46138 .68912 .46689 .7046 .45128 .69724 .44521 Mtetra
.854 .862 .846 r
.69724 .44521 .7046 .45128 .7201 .43639 .71282 .4298 Mtetra
.841 .852 .853 r
.71282 .4298 .7201 .43639 .73565 .42231 .72844 .41524 Mtetra
.827 .842 .859 r
.72844 .41524 .73565 .42231 .75126 .40911 .74412 .40158 Mtetra
.812 .832 .866 r
.74412 .40158 .75126 .40911 .76695 .39678 .75987 .38886 Mtetra
.796 .822 .873 r
.75987 .38886 .76695 .39678 .78273 .38532 .77571 .37705 Mtetra
.78 .813 .879 r
.77571 .37705 .78273 .38532 .79861 .3747 .79165 .36611 Mtetra
.765 .803 .884 r
.79165 .36611 .79861 .3747 .8146 .36485 .8077 .35598 Mtetra
.75 .794 .889 r
.8077 .35598 .8146 .36485 .8307 .35571 .82387 .34659 Mtetra
.736 .786 .893 r
.82387 .34659 .8307 .35571 .84693 .3472 .84015 .33787 Mtetra
.724 .778 .896 r
.84015 .33787 .84693 .3472 .86327 .33923 .85656 .32972 Mtetra
.713 .772 .899 r
.85656 .32972 .86327 .33923 .87974 .33174 .8731 .32207 Mtetra
.703 .766 .901 r
.8731 .32207 .87974 .33174 .89633 .32464 .88975 .31483 Mtetra
0 .367 .778 r
.28419 .55759 .29335 .56365 .30661 .56945 .29745 .56373 Mtetra
0 .293 .703 r
.29745 .56373 .30661 .56945 .31998 .57601 .31081 .57068 Mtetra
0 .228 .63 r
.31081 .57068 .31998 .57601 .33348 .5832 .32431 .57828 Mtetra
.393 0 0 r
.32431 .57828 .33348 .5832 .34713 .59082 .33796 .58633 Mtetra
.43 0 0 r
.33796 .58633 .34713 .59082 .36094 .59864 .35178 .59461 Mtetra
.444 0 0 r
.35178 .59461 .36094 .59864 .37493 .6064 .36578 .60283 Mtetra
.436 0 0 r
.36578 .60283 .37493 .6064 .38913 .61378 .37999 .61067 Mtetra
.405 0 0 r
.37999 .61067 .38913 .61378 .40352 .62046 .39441 .61779 Mtetra
.346 0 0 r
.39441 .61779 .40352 .62046 .41813 .6261 .40905 .62384 Mtetra
.254 0 0 r
.40905 .62384 .41813 .6261 .43294 .63039 .4239 .62849 Mtetra
0 .465 .708 r
.4239 .62849 .43294 .63039 .44794 .63302 .43896 .63142 Mtetra
.044 .604 .804 r
.43896 .63142 .44794 .63302 .46313 .63374 .45421 .63236 Mtetra
.234 .74 .889 r
.45421 .63236 .46313 .63374 .47848 .63235 .46964 .63111 Mtetra
.419 .85 .944 r
.46964 .63111 .47848 .63235 .49396 .62873 .4852 .62755 Mtetra
.574 .92 .962 r
.4852 .62755 .49396 .62873 .50955 .62284 .50089 .62161 Mtetra
.688 .953 .954 r
.50089 .62161 .50955 .62284 .52521 .61472 .51665 .61334 Mtetra
.765 .961 .932 r
.51665 .61334 .52521 .61472 .54093 .60449 .53247 .60287 Mtetra
.816 .957 .906 r
.53247 .60287 .54093 .60449 .55666 .59233 .54831 .5904 Mtetra
.848 .946 .882 r
.54831 .5904 .55666 .59233 .57239 .57851 .56415 .57618 Mtetra
.869 .934 .863 r
.56415 .57618 .57239 .57851 .5881 .56332 .57997 .56054 Mtetra
.88 .921 .848 r
.57997 .56054 .5881 .56332 .60378 .54708 .59576 .5438 Mtetra
.886 .909 .837 r
.59576 .5438 .60378 .54708 .61942 .53014 .61151 .52632 Mtetra
.888 .898 .83 r
.61151 .52632 .61942 .53014 .63503 .5128 .62721 .50844 Mtetra
.886 .888 .827 r
.62721 .50844 .63503 .5128 .6506 .49539 .64288 .49047 Mtetra
.882 .879 .827 r
.64288 .49047 .6506 .49539 .66615 .47817 .65852 .4727 Mtetra
.875 .87 .829 r
.65852 .4727 .66615 .47817 .68169 .46138 .67415 .45538 Mtetra
.866 .862 .833 r
.67415 .45538 .68169 .46138 .69724 .44521 .68978 .4387 Mtetra
.855 .853 .839 r
.68978 .4387 .69724 .44521 .71282 .4298 .70543 .42281 Mtetra
.843 .845 .846 r
.70543 .42281 .71282 .4298 .72844 .41524 .72113 .40781 Mtetra
.829 .836 .853 r
.72113 .40781 .72844 .41524 .74412 .40158 .73688 .39376 Mtetra
.814 .827 .86 r
.73688 .39376 .74412 .40158 .75987 .38886 .7527 .38067 Mtetra
.798 .819 .868 r
.7527 .38067 .75987 .38886 .77571 .37705 .7686 .36853 Mtetra
.783 .81 .874 r
.7686 .36853 .77571 .37705 .79165 .36611 .78461 .3573 Mtetra
.767 .801 .88 r
.78461 .3573 .79165 .36611 .8077 .35598 .80073 .34691 Mtetra
.752 .793 .886 r
.80073 .34691 .8077 .35598 .82387 .34659 .81695 .3373 Mtetra
.738 .785 .89 r
.81695 .3373 .82387 .34659 .84015 .33787 .8333 .32838 Mtetra
.726 .778 .894 r
.8333 .32838 .84015 .33787 .85656 .32972 .84978 .32006 Mtetra
.714 .771 .897 r
.84978 .32006 .85656 .32972 .8731 .32207 .86638 .31226 Mtetra
.704 .765 .9 r
.86638 .31226 .8731 .32207 .88975 .31483 .8831 .30489 Mtetra
0 .36 .782 r
.27495 .55109 .28419 .55759 .29745 .56373 .28821 .55751 Mtetra
0 .288 .712 r
.28821 .55751 .29745 .56373 .31081 .57068 .30157 .56477 Mtetra
0 .227 .646 r
.30157 .56477 .31081 .57068 .32431 .57828 .31507 .57271 Mtetra
.381 0 0 r
.31507 .57271 .32431 .57828 .33796 .58633 .32872 .58113 Mtetra
.414 0 0 r
.32872 .58113 .33796 .58633 .35178 .59461 .34254 .58979 Mtetra
.425 0 0 r
.34254 .58979 .35178 .59461 .36578 .60283 .35655 .5984 Mtetra
.413 0 0 r
.35655 .5984 .36578 .60283 .37999 .61067 .37077 .60662 Mtetra
.375 0 0 r
.37077 .60662 .37999 .61067 .39441 .61779 .38521 .61411 Mtetra
.307 0 0 r
.38521 .61411 .39441 .61779 .40905 .62384 .39988 .62051 Mtetra
0 .38 .695 r
.39988 .62051 .40905 .62384 .4239 .62849 .41477 .62547 Mtetra
0 .505 .787 r
.41477 .62547 .4239 .62849 .43896 .63142 .42988 .62866 Mtetra
.118 .642 .879 r
.42988 .62866 .43896 .63142 .45421 .63236 .44519 .6298 Mtetra
.308 .767 .949 r
.44519 .6298 .45421 .63236 .46964 .63111 .46069 .62867 Mtetra
.481 .859 .982 r
.46069 .62867 .46964 .63111 .4852 .62755 .47634 .62515 Mtetra
.619 .912 .982 r
.47634 .62515 .4852 .62755 .50089 .62161 .49211 .61917 Mtetra
.716 .933 .96 r
.49211 .61917 .50089 .62161 .51665 .61334 .50797 .61079 Mtetra
.782 .937 .931 r
.50797 .61079 .51665 .61334 .53247 .60287 .52389 .60012 Mtetra
.824 .931 .902 r
.52389 .60012 .53247 .60287 .54831 .5904 .53984 .58737 Mtetra
.852 .921 .876 r
.53984 .58737 .54831 .5904 .56415 .57618 .55579 .57281 Mtetra
.869 .91 .856 r
.55579 .57281 .56415 .57618 .57997 .56054 .57172 .55678 Mtetra
.879 .899 .841 r
.57172 .55678 .57997 .56054 .59576 .5438 .58761 .5396 Mtetra
.884 .889 .83 r
.58761 .5396 .59576 .5438 .61151 .52632 .60346 .52166 Mtetra
.886 .88 .823 r
.60346 .52166 .61151 .52632 .62721 .50844 .61927 .5033 Mtetra
.884 .872 .82 r
.61927 .5033 .62721 .50844 .64288 .49047 .63503 .48484 Mtetra
.88 .864 .819 r
.63503 .48484 .64288 .49047 .65852 .4727 .65077 .4666 Mtetra
.874 .857 .822 r
.65077 .4666 .65852 .4727 .67415 .45538 .66649 .44881 Mtetra
.865 .85 .826 r
.66649 .44881 .67415 .45538 .68978 .4387 .68221 .43169 Mtetra
.855 .843 .832 r
.68221 .43169 .68978 .4387 .70543 .42281 .69794 .41538 Mtetra
.843 .836 .839 r
.69794 .41538 .70543 .42281 .72113 .40781 .71371 .39999 Mtetra
.83 .829 .847 r
.71371 .39999 .72113 .40781 .73688 .39376 .72953 .38558 Mtetra
.815 .822 .855 r
.72953 .38558 .73688 .39376 .7527 .38067 .74543 .37217 Mtetra
.8 .814 .863 r
.74543 .37217 .7527 .38067 .7686 .36853 .7614 .35974 Mtetra
.784 .806 .87 r
.7614 .35974 .7686 .36853 .78461 .3573 .77748 .34825 Mtetra
.769 .798 .877 r
.77748 .34825 .78461 .3573 .80073 .34691 .79366 .33764 Mtetra
.754 .791 .883 r
.79366 .33764 .80073 .34691 .81695 .3373 .80996 .32782 Mtetra
.74 .783 .888 r
.80996 .32782 .81695 .3373 .8333 .32838 .82637 .31872 Mtetra
.727 .777 .892 r
.82637 .31872 .8333 .32838 .84978 .32006 .84291 .31024 Mtetra
.716 .77 .896 r
.84291 .31024 .84978 .32006 .86638 .31226 .85958 .3023 Mtetra
.706 .765 .898 r
.85958 .3023 .86638 .31226 .8831 .30489 .87637 .2948 Mtetra
0 .358 .79 r
.26564 .5441 .27495 .55109 .28821 .55751 .2789 .55074 Mtetra
0 .29 .726 r
.2789 .55074 .28821 .55751 .30157 .56477 .29227 .55824 Mtetra
0 .232 .667 r
.29227 .55824 .30157 .56477 .31507 .57271 .30576 .56644 Mtetra
0 .191 .62 r
.30576 .56644 .31507 .57271 .32872 .58113 .31941 .57515 Mtetra
.388 0 0 r
.31941 .57515 .32872 .58113 .34254 .58979 .33323 .5841 Mtetra
.394 0 0 r
.33323 .5841 .34254 .58979 .35655 .5984 .34725 .59302 Mtetra
.376 0 0 r
.34725 .59302 .35655 .5984 .37077 .60662 .36148 .60155 Mtetra
0 .238 .628 r
.36148 .60155 .37077 .60662 .38521 .61411 .37594 .60934 Mtetra
0 .313 .688 r
.37594 .60934 .38521 .61411 .39988 .62051 .39063 .61602 Mtetra
0 .417 .768 r
.39063 .61602 .39988 .62051 .41477 .62547 .40556 .62122 Mtetra
.017 .541 .858 r
.40556 .62122 .41477 .62547 .42988 .62866 .42071 .62462 Mtetra
.196 .668 .936 r
.42071 .62462 .42988 .62866 .44519 .6298 .43608 .62591 Mtetra
.376 .776 .985 r
.43608 .62591 .44519 .6298 .46069 .62867 .45164 .62489 Mtetra
.531 .849 .998 r
.45164 .62489 .46069 .62867 .47634 .62515 .46736 .6214 Mtetra
.65 .888 .983 r
.46736 .6214 .47634 .62515 .49211 .61917 .48322 .6154 Mtetra
.733 .904 .955 r
.48322 .6154 .49211 .61917 .50797 .61079 .49917 .60692 Mtetra
.789 .905 .922 r
.49917 .60692 .50797 .61079 .52389 .60012 .51519 .59608 Mtetra
.826 .9 .893 r
.51519 .59608 .52389 .60012 .53984 .58737 .53124 .58311 Mtetra
.85 .892 .868 r
.53124 .58311 .53984 .58737 .55579 .57281 .5473 .56828 Mtetra
.866 .884 .847 r
.5473 .56828 .55579 .57281 .57172 .55678 .56333 .55192 Mtetra
.875 .875 .832 r
.56333 .55192 .57172 .55678 .58761 .5396 .57933 .53439 Mtetra
.88 .868 .822 r
.57933 .53439 .58761 .5396 .60346 .52166 .59529 .51606 Mtetra
.882 .861 .815 r
.59529 .51606 .60346 .52166 .61927 .5033 .6112 .4973 Mtetra
.88 .855 .812 r
.6112 .4973 .61927 .5033 .63503 .48484 .62707 .47845 Mtetra
.877 .849 .812 r
.62707 .47845 .63503 .48484 .65077 .4666 .6429 .4598 Mtetra
.871 .844 .815 r
.6429 .4598 .65077 .4666 .66649 .44881 .65871 .44163 Mtetra
.863 .838 .82 r
.65871 .44163 .66649 .44881 .68221 .43169 .67452 .42413 Mtetra
.854 .833 .826 r
.67452 .42413 .68221 .43169 .69794 .41538 .69034 .40747 Mtetra
.842 .828 .833 r
.69034 .40747 .69794 .41538 .71371 .39999 .70619 .39175 Mtetra
.829 .822 .841 r
.70619 .39175 .71371 .39999 .72953 .38558 .72209 .37704 Mtetra
.815 .816 .85 r
.72209 .37704 .72953 .38558 .74543 .37217 .73806 .36335 Mtetra
.801 .809 .858 r
.73806 .36335 .74543 .37217 .7614 .35974 .75411 .35067 Mtetra
.785 .802 .866 r
.75411 .35067 .7614 .35974 .77748 .34825 .77025 .33895 Mtetra
.77 .795 .873 r
.77025 .33895 .77748 .34825 .79366 .33764 .7865 .32814 Mtetra
.755 .788 .88 r
.7865 .32814 .79366 .33764 .80996 .32782 .80287 .31814 Mtetra
.741 .782 .885 r
.80287 .31814 .80996 .32782 .82637 .31872 .81936 .30888 Mtetra
.728 .775 .89 r
.81936 .30888 .82637 .31872 .84291 .31024 .83597 .30025 Mtetra
.717 .769 .894 r
.83597 .30025 .84291 .31024 .85958 .3023 .8527 .29218 Mtetra
.706 .764 .897 r
.8527 .29218 .85958 .3023 .87637 .2948 .86956 .28457 Mtetra
0 .362 .802 r
.25627 .5366 .26564 .5441 .2789 .55074 .26953 .54338 Mtetra
0 .297 .745 r
.26953 .54338 .2789 .55074 .29227 .55824 .2829 .55104 Mtetra
0 .244 .694 r
.2829 .55104 .29227 .55824 .30576 .56644 .29639 .55942 Mtetra
0 .206 .654 r
.29639 .55942 .30576 .56644 .31941 .57515 .31004 .56832 Mtetra
0 .188 .632 r
.31004 .56832 .31941 .57515 .33323 .5841 .32386 .57749 Mtetra
0 .191 .629 r
.32386 .57749 .33323 .5841 .34725 .59302 .33788 .58662 Mtetra
0 .217 .648 r
.33788 .58662 .34725 .59302 .36148 .60155 .35213 .59536 Mtetra
0 .269 .69 r
.35213 .59536 .36148 .60155 .37594 .60934 .3666 .60337 Mtetra
0 .348 .754 r
.3666 .60337 .37594 .60934 .39063 .61602 .38131 .61025 Mtetra
0 .451 .831 r
.38131 .61025 .39063 .61602 .40556 .62122 .39627 .61564 Mtetra
.097 .567 .909 r
.39627 .61564 .40556 .62122 .42071 .62462 .41147 .61918 Mtetra
.269 .678 .969 r
.41147 .61918 .42071 .62462 .43608 .62591 .42689 .6206 Mtetra
.432 .767 .997 r
.42689 .6206 .43608 .62591 .45164 .62489 .4425 .61965 Mtetra
.567 .824 .994 r
.4425 .61965 .45164 .62489 .46736 .6214 .4583 .6162 Mtetra
.668 .855 .971 r
.4583 .6162 .46736 .6214 .48322 .6154 .47423 .61017 Mtetra
.739 .868 .94 r
.47423 .61017 .48322 .6154 .49917 .60692 .49027 .60161 Mtetra
.788 .871 .909 r
.49027 .60161 .49917 .60692 .51519 .59608 .50638 .59066 Mtetra
.822 .868 .88 r
.50638 .59066 .51519 .59608 .53124 .58311 .52253 .57752 Mtetra
.844 .863 .857 r
.52253 .57752 .53124 .58311 .5473 .56828 .53869 .56248 Mtetra
.859 .857 .838 r
.53869 .56248 .5473 .56828 .56333 .55192 .55483 .54587 Mtetra
.868 .851 .824 r
.55483 .54587 .56333 .55192 .57933 .53439 .57093 .52807 Mtetra
.873 .846 .814 r
.57093 .52807 .57933 .53439 .59529 .51606 .587 .50944 Mtetra
.875 .841 .808 r
.587 .50944 .59529 .51606 .6112 .4973 .60301 .49037 Mtetra
.875 .837 .805 r
.60301 .49037 .6112 .4973 .62707 .47845 .61898 .4712 Mtetra
.872 .833 .806 r
.61898 .4712 .62707 .47845 .6429 .4598 .63491 .45225 Mtetra
.867 .83 .809 r
.63491 .45225 .6429 .4598 .65871 .44163 .65082 .43376 Mtetra
.86 .826 .813 r
.65082 .43376 .65871 .44163 .67452 .42413 .66671 .41597 Mtetra
.851 .822 .82 r
.66671 .41597 .67452 .42413 .69034 .40747 .68262 .39903 Mtetra
.84 .818 .828 r
.68262 .39903 .69034 .40747 .70619 .39175 .69856 .38305 Mtetra
.828 .814 .836 r
.69856 .38305 .70619 .39175 .72209 .37704 .71454 .36809 Mtetra
.815 .809 .845 r
.71454 .36809 .72209 .37704 .73806 .36335 .73059 .35417 Mtetra
.8 .804 .854 r
.73059 .35417 .73806 .36335 .75411 .35067 .74671 .34128 Mtetra
.786 .798 .862 r
.74671 .34128 .75411 .35067 .77025 .33895 .76293 .32938 Mtetra
.771 .792 .87 r
.76293 .32938 .77025 .33895 .7865 .32814 .77926 .31839 Mtetra
.756 .786 .877 r
.77926 .31839 .7865 .32814 .80287 .31814 .7957 .30824 Mtetra
.742 .779 .883 r
.7957 .30824 .80287 .31814 .81936 .30888 .81225 .29884 Mtetra
.729 .774 .888 r
.81225 .29884 .81936 .30888 .83597 .30025 .82894 .29009 Mtetra
.717 .768 .893 r
.82894 .29009 .83597 .30025 .8527 .29218 .84574 .2819 Mtetra
.707 .763 .896 r
.84574 .2819 .8527 .29218 .86956 .28457 .86268 .27419 Mtetra
0 .37 .816 r
.24684 .52857 .25627 .5366 .26953 .54338 .26011 .53541 Mtetra
0 .31 .767 r
.26011 .53541 .26953 .54338 .2829 .55104 .27348 .54315 Mtetra
0 .261 .723 r
.27348 .54315 .2829 .55104 .29639 .55942 .28697 .55162 Mtetra
0 .227 .691 r
.28697 .55162 .29639 .55942 .31004 .56832 .30062 .56062 Mtetra
0 .212 .675 r
.30062 .56062 .31004 .56832 .32386 .57749 .31444 .5699 Mtetra
0 .219 .678 r
.31444 .5699 .32386 .57749 .33788 .58662 .32847 .57915 Mtetra
0 .249 .703 r
.32847 .57915 .33788 .58662 .35213 .59536 .34272 .58802 Mtetra
0 .303 .747 r
.34272 .58802 .35213 .59536 .3666 .60337 .35721 .59615 Mtetra
0 .381 .808 r
.35721 .59615 .3666 .60337 .38131 .61025 .37194 .60315 Mtetra
.023 .477 .877 r
.37194 .60315 .38131 .61025 .39627 .61564 .38693 .60864 Mtetra
.175 .58 .937 r
.38693 .60864 .39627 .61564 .41147 .61918 .40216 .61228 Mtetra
.332 .673 .977 r
.40216 .61228 .41147 .61918 .42689 .6206 .41762 .61377 Mtetra
.474 .745 .988 r
.41762 .61377 .42689 .6206 .4425 .61965 .43329 .61287 Mtetra
.59 .792 .976 r
.43329 .61287 .4425 .61965 .4583 .6162 .44915 .60944 Mtetra
.677 .818 .951 r
.44915 .60944 .4583 .6162 .47423 .61017 .46515 .6034 Mtetra
.739 .831 .921 r
.46515 .6034 .47423 .61017 .49027 .60161 .48127 .59479 Mtetra
.783 .835 .892 r
.48127 .59479 .49027 .60161 .50638 .59066 .49747 .58376 Mtetra
.814 .835 .866 r
.49747 .58376 .50638 .59066 .52253 .57752 .51371 .57051 Mtetra
.835 .833 .845 r
.51371 .57051 .52253 .57752 .53869 .56248 .52997 .55533 Mtetra
.85 .83 .828 r
.52997 .55533 .53869 .56248 .55483 .54587 .54621 .53856 Mtetra
.859 .827 .815 r
.54621 .53856 .55483 .54587 .57093 .52807 .56242 .52057 Mtetra
.865 .825 .806 r
.56242 .52057 .57093 .52807 .587 .50944 .57858 .50174 Mtetra
.868 .822 .801 r
.57858 .50174 .587 .50944 .60301 .49037 .5947 .48246 Mtetra
.868 .82 .799 r
.5947 .48246 .60301 .49037 .61898 .4712 .61077 .46307 Mtetra
.866 .818 .8 r
.61077 .46307 .61898 .4712 .63491 .45225 .6268 .44389 Mtetra
.862 .816 .803 r
.6268 .44389 .63491 .45225 .65082 .43376 .6428 .42519 Mtetra
.855 .814 .808 r
.6428 .42519 .65082 .43376 .66671 .41597 .6588 .40718 Mtetra
.847 .811 .815 r
.6588 .40718 .66671 .41597 .68262 .39903 .67479 .39003 Mtetra
.837 .809 .823 r
.67479 .39003 .68262 .39903 .69856 .38305 .69082 .37385 Mtetra
.826 .806 .832 r
.69082 .37385 .69856 .38305 .71454 .36809 .70688 .35871 Mtetra
.813 .802 .841 r
.70688 .35871 .71454 .36809 .73059 .35417 .72301 .34462 Mtetra
.8 .798 .85 r
.72301 .34462 .73059 .35417 .74671 .34128 .73922 .33157 Mtetra
.785 .793 .859 r
.73922 .33157 .74671 .34128 .76293 .32938 .75552 .31952 Mtetra
.77 .788 .867 r
.75552 .31952 .76293 .32938 .77926 .31839 .77192 .3084 Mtetra
.756 .782 .875 r
.77192 .3084 .77926 .31839 .7957 .30824 .78843 .29812 Mtetra
.742 .777 .881 r
.78843 .29812 .7957 .30824 .81225 .29884 .80507 .2886 Mtetra
.729 .772 .887 r
.80507 .2886 .81225 .29884 .82894 .29009 .82182 .27975 Mtetra
.718 .767 .891 r
.82182 .27975 .82894 .29009 .84574 .2819 .8387 .27146 Mtetra
.707 .762 .895 r
.8387 .27146 .84574 .2819 .86268 .27419 .85571 .26366 Mtetra
0 .382 .831 r
.23736 .51999 .24684 .52857 .26011 .53541 .25063 .52682 Mtetra
0 .326 .789 r
.25063 .52682 .26011 .53541 .27348 .54315 .264 .53454 Mtetra
0 .282 .753 r
.264 .53454 .27348 .54315 .28697 .55162 .2775 .54301 Mtetra
0 .252 .728 r
.2775 .54301 .28697 .55162 .30062 .56062 .29115 .55202 Mtetra
0 .241 .717 r
.29115 .55202 .30062 .56062 .31444 .5699 .30498 .56131 Mtetra
0 .25 .725 r
.30498 .56131 .31444 .5699 .32847 .57915 .31902 .57057 Mtetra
0 .282 .751 r
.31902 .57057 .32847 .57915 .34272 .58802 .33327 .57947 Mtetra
0 .335 .794 r
.33327 .57947 .34272 .58802 .35721 .59615 .34777 .58763 Mtetra
0 .409 .848 r
.34777 .58763 .35721 .59615 .37194 .60315 .36253 .59466 Mtetra
.102 .495 .902 r
.36253 .59466 .37194 .60315 .38693 .60864 .37753 .60019 Mtetra
.242 .582 .945 r
.37753 .60019 .38693 .60864 .40216 .61228 .39279 .60386 Mtetra
.381 .659 .967 r
.39279 .60386 .40216 .61228 .41762 .61377 .40829 .60538 Mtetra
.504 .718 .968 r
.40829 .60538 .41762 .61377 .43329 .61287 .42401 .6045 Mtetra
.603 .757 .952 r
.42401 .6045 .43329 .61287 .44915 .60944 .43992 .60107 Mtetra
.678 .781 .927 r
.43992 .60107 .44915 .60944 .46515 .6034 .45599 .59502 Mtetra
.734 .794 .9 r
.45599 .59502 .46515 .6034 .48127 .59479 .47219 .5864 Mtetra
.774 .801 .874 r
.47219 .5864 .48127 .59479 .49747 .58376 .48846 .57533 Mtetra
.803 .804 .852 r
.48846 .57533 .49747 .58376 .51371 .57051 .50479 .56203 Mtetra
.824 .805 .833 r
.50479 .56203 .51371 .57051 .52997 .55533 .52114 .54678 Mtetra
.839 .805 .818 r
.52114 .54678 .52997 .55533 .54621 .53856 .53748 .52993 Mtetra
.849 .804 .807 r
.53748 .52993 .54621 .53856 .56242 .52057 .55379 .51184 Mtetra
.856 .804 .799 r
.55379 .51184 .56242 .52057 .57858 .50174 .57006 .49291 Mtetra
.859 .803 .794 r
.57006 .49291 .57858 .50174 .5947 .48246 .58628 .47351 Mtetra
.86 .803 .793 r
.58628 .47351 .5947 .48246 .61077 .46307 .60245 .454 Mtetra
.859 .803 .794 r
.60245 .454 .61077 .46307 .6268 .44389 .61858 .4347 Mtetra
.856 .802 .797 r
.61858 .4347 .6268 .44389 .6428 .42519 .63468 .41587 Mtetra
.85 .802 .803 r
.63468 .41587 .6428 .42519 .6588 .40718 .65077 .39773 Mtetra
.843 .801 .81 r
.65077 .39773 .6588 .40718 .67479 .39003 .66686 .38046 Mtetra
.834 .799 .818 r
.66686 .38046 .67479 .39003 .69082 .37385 .68297 .36416 Mtetra
.823 .797 .827 r
.68297 .36416 .69082 .37385 .70688 .35871 .69913 .34889 Mtetra
.811 .795 .837 r
.69913 .34889 .70688 .35871 .72301 .34462 .71534 .33469 Mtetra
.798 .792 .847 r
.71534 .33469 .72301 .34462 .73922 .33157 .73163 .32153 Mtetra
.784 .788 .856 r
.73163 .32153 .73922 .33157 .75552 .31952 .74801 .30937 Mtetra
.77 .784 .865 r
.74801 .30937 .75552 .31952 .77192 .3084 .76449 .29815 Mtetra
.756 .779 .872 r
.76449 .29815 .77192 .3084 .78843 .29812 .78108 .28777 Mtetra
.742 .774 .879 r
.78108 .28777 .78843 .29812 .80507 .2886 .79779 .27816 Mtetra
.729 .77 .885 r
.79779 .27816 .80507 .2886 .82182 .27975 .81462 .26922 Mtetra
.718 .765 .89 r
.81462 .26922 .82182 .27975 .8387 .27146 .83158 .26085 Mtetra
.708 .761 .894 r
.83158 .26085 .8387 .27146 .85571 .26366 .84867 .25296 Mtetra
0 .397 .846 r
.22782 .51086 .23736 .51999 .25063 .52682 .2411 .51759 Mtetra
0 .346 .811 r
.2411 .51759 .25063 .52682 .264 .53454 .25448 .52522 Mtetra
0 .306 .781 r
.25448 .52522 .264 .53454 .2775 .54301 .26799 .53359 Mtetra
0 .28 .762 r
.26799 .53359 .2775 .54301 .29115 .55202 .28165 .54251 Mtetra
0 .271 .756 r
.28165 .54251 .29115 .55202 .30498 .56131 .29549 .55171 Mtetra
0 .282 .766 r
.29549 .55171 .30498 .56131 .31902 .57057 .30953 .56089 Mtetra
0 .314 .791 r
.30953 .56089 .31902 .57057 .33327 .57947 .32379 .56972 Mtetra
0 .364 .828 r
.32379 .56972 .33327 .57947 .34777 .58763 .3383 .57781 Mtetra
.055 .43 .871 r
.3383 .57781 .34777 .58763 .36253 .59466 .35307 .58478 Mtetra
.173 .505 .91 r
.35307 .58478 .36253 .59466 .37753 .60019 .3681 .59027 Mtetra
.299 .578 .938 r
.3681 .59027 .37753 .60019 .39279 .60386 .38339 .5939 Mtetra
.419 .641 .948 r
.38339 .5939 .39279 .60386 .40829 .60538 .39892 .59539 Mtetra
.525 .689 .943 r
.39892 .59539 .40829 .60538 .42401 .6045 .41468 .5945 Mtetra
.61 .724 .926 r
.41468 .5945 .42401 .6045 .43992 .60107 .43064 .59106 Mtetra
.676 .746 .903 r
.43064 .59106 .43992 .60107 .45599 .59502 .44677 .58502 Mtetra
.727 .76 .88 r
.44677 .58502 .45599 .59502 .47219 .5864 .46302 .5764 Mtetra
.764 .769 .857 r
.46302 .5764 .47219 .5864 .48846 .57533 .47938 .56534 Mtetra
.792 .775 .837 r
.47938 .56534 .48846 .57533 .50479 .56203 .49579 .55205 Mtetra
.812 .778 .821 r
.49579 .55205 .50479 .56203 .52114 .54678 .51222 .5368 Mtetra
.827 .781 .808 r
.51222 .5368 .52114 .54678 .53748 .52993 .52865 .51995 Mtetra
.838 .783 .798 r
.52865 .51995 .53748 .52993 .55379 .51184 .54506 .50187 Mtetra
.845 .784 .792 r
.54506 .50187 .55379 .51184 .57006 .49291 .56142 .48293 Mtetra
.85 .785 .788 r
.56142 .48293 .57006 .49291 .58628 .47351 .57774 .46352 Mtetra
.852 .787 .787 r
.57774 .46352 .58628 .47351 .60245 .454 .59401 .44399 Mtetra
.851 .788 .789 r
.59401 .44399 .60245 .454 .61858 .4347 .61024 .42465 Mtetra
.849 .789 .793 r
.61024 .42465 .61858 .4347 .63468 .41587 .62644 .40579 Mtetra
.844 .79 .799 r
.62644 .40579 .63468 .41587 .65077 .39773 .64263 .38761 Mtetra
.838 .79 .806 r
.64263 .38761 .65077 .39773 .66686 .38046 .65881 .37029 Mtetra
.829 .79 .814 r
.65881 .37029 .66686 .38046 .68297 .36416 .67502 .35394 Mtetra
.819 .789 .824 r
.67502 .35394 .68297 .36416 .69913 .34889 .69126 .33862 Mtetra
.808 .788 .834 r
.69126 .33862 .69913 .34889 .71534 .33469 .70757 .32436 Mtetra
.795 .786 .844 r
.70757 .32436 .71534 .33469 .73163 .32153 .72394 .31114 Mtetra
.782 .783 .853 r
.72394 .31114 .73163 .32153 .74801 .30937 .7404 .29892 Mtetra
.768 .78 .862 r
.7404 .29892 .74801 .30937 .76449 .29815 .75697 .28763 Mtetra
.755 .776 .87 r
.75697 .28763 .76449 .29815 .78108 .28777 .77364 .27719 Mtetra
.741 .772 .878 r
.77364 .27719 .78108 .28777 .79779 .27816 .79043 .26751 Mtetra
.729 .768 .884 r
.79043 .26751 .79779 .27816 .81462 .26922 .80734 .2585 Mtetra
.717 .764 .889 r
.80734 .2585 .81462 .26922 .83158 .26085 .82437 .25006 Mtetra
.707 .76 .893 r
.82437 .25006 .83158 .26085 .84867 .25296 .84154 .24211 Mtetra
.029 .414 .861 r
.21823 .50119 .22782 .51086 .2411 .51759 .23153 .50775 Mtetra
0 .367 .831 r
.23153 .50775 .2411 .51759 .25448 .52522 .24492 .51519 Mtetra
0 .331 .807 r
.24492 .51519 .25448 .52522 .26799 .53359 .25845 .52338 Mtetra
0 .308 .792 r
.25845 .52338 .26799 .53359 .28165 .54251 .27212 .5321 Mtetra
0 .302 .788 r
.27212 .5321 .28165 .54251 .29549 .55171 .28596 .54111 Mtetra
0 .314 .798 r
.28596 .54111 .29549 .55171 .30953 .56089 .30001 .55011 Mtetra
0 .343 .819 r
.30001 .55011 .30953 .56089 .32379 .56972 .31429 .55876 Mtetra
.032 .389 .849 r
.31429 .55876 .32379 .56972 .3383 .57781 .32881 .56669 Mtetra
.126 .446 .881 r
.32881 .56669 .3383 .57781 .35307 .58478 .34359 .57352 Mtetra
.233 .509 .907 r
.34359 .57352 .35307 .58478 .3681 .59027 .35864 .57888 Mtetra
.344 .569 .923 r
.35864 .57888 .3681 .59027 .38339 .5939 .37395 .58242 Mtetra
.448 .621 .925 r
.37395 .58242 .38339 .5939 .39892 .59539 .38951 .58384 Mtetra
.539 .663 .917 r
.38951 .58384 .39892 .59539 .41468 .5945 .4053 .5829 Mtetra
.613 .693 .901 r
.4053 .5829 .41468 .5945 .43064 .59106 .42131 .57944 Mtetra
.672 .715 .881 r
.42131 .57944 .43064 .59106 .44677 .58502 .43748 .5734 Mtetra
.718 .73 .86 r
.43748 .5734 .44677 .58502 .46302 .5764 .4538 .56481 Mtetra
.753 .741 .841 r
.4538 .56481 .46302 .5764 .47938 .56534 .47022 .5538 Mtetra
.78 .748 .824 r
.47022 .5538 .47938 .56534 .49579 .55205 .4867 .54057 Mtetra
.8 .754 .81 r
.4867 .54057 .49579 .55205 .51222 .5368 .50321 .52541 Mtetra
.816 .759 .799 r
.50321 .52541 .51222 .5368 .52865 .51995 .51973 .50865 Mtetra
.827 .762 .791 r
.51973 .50865 .52865 .51995 .54506 .50187 .53622 .49065 Mtetra
.835 .766 .786 r
.53622 .49065 .54506 .50187 .56142 .48293 .55268 .4718 Mtetra
.84 .768 .783 r
.55268 .4718 .56142 .48293 .57774 .46352 .5691 .45247 Mtetra
.843 .771 .783 r
.5691 .45247 .57774 .46352 .59401 .44399 .58547 .43302 Mtetra
.843 .774 .785 r
.58547 .43302 .59401 .44399 .61024 .42465 .6018 .41376 Mtetra
.841 .776 .789 r
.6018 .41376 .61024 .42465 .62644 .40579 .6181 .39495 Mtetra
.838 .778 .795 r
.6181 .39495 .62644 .40579 .64263 .38761 .63438 .37682 Mtetra
.832 .78 .803 r
.63438 .37682 .64263 .38761 .65881 .37029 .65066 .35954 Mtetra
.824 .781 .811 r
.65066 .35954 .65881 .37029 .67502 .35394 .66696 .3432 Mtetra
.815 .781 .821 r
.66696 .3432 .67502 .35394 .69126 .33862 .6833 .3279 Mtetra
.804 .781 .831 r
.6833 .3279 .69126 .33862 .70757 .32436 .69969 .31363 Mtetra
.792 .78 .841 r
.69969 .31363 .70757 .32436 .72394 .31114 .71615 .3004 Mtetra
.78 .778 .851 r
.71615 .3004 .72394 .31114 .7404 .29892 .7327 .28816 Mtetra
.766 .775 .86 r
.7327 .28816 .7404 .29892 .75697 .28763 .74935 .27684 Mtetra
.753 .772 .869 r
.74935 .27684 .75697 .28763 .77364 .27719 .7661 .26637 Mtetra
.74 .769 .876 r
.7661 .26637 .77364 .27719 .79043 .26751 .78297 .25665 Mtetra
.728 .765 .883 r
.78297 .25665 .79043 .26751 .80734 .2585 .79997 .24759 Mtetra
.717 .762 .888 r
.79997 .24759 .80734 .2585 .82437 .25006 .81708 .2391 Mtetra
.707 .758 .892 r
.81708 .2391 .82437 .25006 .84154 .24211 .83432 .23109 Mtetra
.075 .432 .873 r
.20858 .491 .21823 .50119 .23153 .50775 .22191 .4973 Mtetra
.02 .39 .849 r
.22191 .4973 .23153 .50775 .24492 .51519 .23532 .50448 Mtetra
0 .357 .829 r
.23532 .50448 .24492 .51519 .25845 .52338 .24886 .51239 Mtetra
0 .337 .816 r
.24886 .51239 .25845 .52338 .27212 .5321 .26255 .52083 Mtetra
0 .332 .814 r
.26255 .52083 .27212 .5321 .28596 .54111 .27641 .52955 Mtetra
0 .343 .822 r
.27641 .52955 .28596 .54111 .30001 .55011 .29047 .53827 Mtetra
.033 .369 .838 r
.29047 .53827 .30001 .55011 .31429 .55876 .30476 .54665 Mtetra
.102 .409 .86 r
.30476 .54665 .31429 .55876 .32881 .56669 .3193 .55432 Mtetra
.188 .458 .881 r
.3193 .55432 .32881 .56669 .34359 .57352 .33409 .56092 Mtetra
.284 .51 .897 r
.33409 .56092 .34359 .57352 .35864 .57888 .34915 .56608 Mtetra
.38 .56 .905 r
.34915 .56608 .35864 .57888 .37395 .58242 .36448 .56946 Mtetra
.47 .604 .902 r
.36448 .56946 .37395 .58242 .38951 .58384 .38007 .57075 Mtetra
.548 .639 .893 r
.38007 .57075 .38951 .58384 .4053 .5829 .39589 .56973 Mtetra
.614 .667 .878 r
.39589 .56973 .4053 .5829 .42131 .57944 .41193 .56624 Mtetra
.667 .688 .86 r
.41193 .56624 .42131 .57944 .43748 .5734 .42815 .56021 Mtetra
.709 .704 .843 r
.42815 .56021 .43748 .5734 .4538 .56481 .44452 .55167 Mtetra
.742 .715 .826 r
.44452 .55167 .4538 .56481 .47022 .5538 .46099 .54075 Mtetra
.768 .725 .812 r
.46099 .54075 .47022 .5538 .4867 .54057 .47754 .52764 Mtetra
.788 .732 .8 r
.47754 .52764 .4867 .54057 .50321 .52541 .49413 .51263 Mtetra
.804 .738 .791 r
.49413 .51263 .50321 .52541 .51973 .50865 .51072 .49603 Mtetra
.816 .744 .784 r
.51072 .49603 .51973 .50865 .53622 .49065 .5273 .47821 Mtetra
.824 .748 .78 r
.5273 .47821 .53622 .49065 .55268 .4718 .54385 .45955 Mtetra
.83 .753 .778 r
.54385 .45955 .55268 .4718 .5691 .45247 .56036 .4404 Mtetra
.833 .757 .779 r
.56036 .4404 .5691 .45247 .58547 .43302 .57682 .42112 Mtetra
.834 .761 .781 r
.57682 .42112 .58547 .43302 .6018 .41376 .59325 .40202 Mtetra
.833 .764 .786 r
.59325 .40202 .6018 .41376 .6181 .39495 .60965 .38337 Mtetra
.83 .767 .792 r
.60965 .38337 .6181 .39495 .63438 .37682 .62602 .36537 Mtetra
.826 .77 .8 r
.62602 .36537 .63438 .37682 .65066 .35954 .6424 .34819 Mtetra
.819 .772 .809 r
.6424 .34819 .65066 .35954 .66696 .3432 .6588 .33196 Mtetra
.81 .773 .819 r
.6588 .33196 .66696 .3432 .6833 .3279 .67523 .31672 Mtetra
.8 .774 .829 r
.67523 .31672 .6833 .3279 .69969 .31363 .69171 .30251 Mtetra
.789 .774 .839 r
.69171 .30251 .69969 .31363 .71615 .3004 .70827 .28932 Mtetra
.777 .773 .849 r
.70827 .28932 .71615 .3004 .7327 .28816 .7249 .2771 Mtetra
.764 .771 .859 r
.7249 .2771 .7327 .28816 .74935 .27684 .74164 .26579 Mtetra
.751 .769 .867 r
.74164 .26579 .74935 .27684 .7661 .26637 .75848 .25531 Mtetra
.739 .766 .875 r
.75848 .25531 .7661 .26637 .78297 .25665 .77543 .24557 Mtetra
.727 .763 .882 r
.77543 .24557 .78297 .25665 .79997 .24759 .79251 .23648 Mtetra
.716 .76 .887 r
.79251 .23648 .79997 .24759 .81708 .2391 .8097 .22796 Mtetra
.706 .757 .892 r
.8097 .22796 .81708 .2391 .83432 .23109 .82703 .2199 Mtetra
.121 .45 .883 r
.19889 .4803 .20858 .491 .22191 .4973 .21224 .48628 Mtetra
.073 .412 .863 r
.21224 .48628 .22191 .4973 .23532 .50448 .22569 .49311 Mtetra
.039 .383 .846 r
.22569 .49311 .23532 .50448 .24886 .51239 .23925 .50066 Mtetra
.023 .365 .835 r
.23925 .50066 .24886 .51239 .26255 .52083 .25296 .50873 Mtetra
.028 .36 .833 r
.25296 .50873 .26255 .52083 .27641 .52955 .26684 .51707 Mtetra
.054 .369 .838 r
.26684 .51707 .27641 .52955 .29047 .53827 .28092 .52542 Mtetra
.1 .392 .849 r
.28092 .52542 .29047 .53827 .30476 .54665 .29522 .53343 Mtetra
.164 .426 .863 r
.29522 .53343 .30476 .54665 .3193 .55432 .30977 .54076 Mtetra
.242 .466 .876 r
.30977 .54076 .3193 .55432 .33409 .56092 .32458 .54705 Mtetra
.326 .51 .884 r
.32458 .54705 .33409 .56092 .34915 .56608 .33966 .55194 Mtetra
.409 .551 .886 r
.33966 .55194 .34915 .56608 .36448 .56946 .355 .55509 Mtetra
.487 .588 .881 r
.355 .55509 .36448 .56946 .38007 .57075 .37061 .55621 Mtetra
.555 .619 .871 r
.37061 .55621 .38007 .57075 .39589 .56973 .38646 .55507 Mtetra
.614 .645 .857 r
.38646 .55507 .39589 .56973 .41193 .56624 .40253 .55153 Mtetra
.662 .665 .842 r
.40253 .55153 .41193 .56624 .42815 .56021 .41878 .54552 Mtetra
.701 .681 .828 r
.41878 .54552 .42815 .56021 .44452 .55167 .43519 .53705 Mtetra
.732 .693 .814 r
.43519 .53705 .44452 .55167 .46099 .54075 .45172 .52625 Mtetra
.757 .704 .802 r
.45172 .52625 .46099 .54075 .47754 .52764 .46832 .51332 Mtetra
.777 .712 .792 r
.46832 .51332 .47754 .52764 .49413 .51263 .48498 .49852 Mtetra
.792 .72 .784 r
.48498 .49852 .49413 .51263 .51072 .49603 .50164 .48216 Mtetra
.805 .727 .778 r
.50164 .48216 .51072 .49603 .5273 .47821 .5183 .4646 Mtetra
.814 .733 .775 r
.5183 .4646 .5273 .47821 .54385 .45955 .53493 .44621 Mtetra
.82 .738 .774 r
.53493 .44621 .54385 .45955 .56036 .4404 .55153 .42734 Mtetra
.824 .743 .775 r
.55153 .42734 .56036 .4404 .57682 .42112 .56808 .40833 Mtetra
.826 .748 .778 r
.56808 .40833 .57682 .42112 .59325 .40202 .5846 .38948 Mtetra
.825 .753 .783 r
.5846 .38948 .59325 .40202 .60965 .38337 .60109 .37105 Mtetra
.823 .757 .79 r
.60109 .37105 .60965 .38337 .62602 .36537 .61757 .35327 Mtetra
.819 .76 .798 r
.61757 .35327 .62602 .36537 .6424 .34819 .63404 .33628 Mtetra
.813 .763 .807 r
.63404 .33628 .6424 .34819 .6588 .33196 .65054 .32021 Mtetra
.805 .766 .817 r
.65054 .32021 .6588 .33196 .67523 .31672 .66706 .30511 Mtetra
.796 .767 .827 r
.66706 .30511 .67523 .31672 .69171 .30251 .68364 .29101 Mtetra
.785 .768 .838 r
.68364 .29101 .69171 .30251 .70827 .28932 .70028 .2779 Mtetra
.773 .768 .848 r
.70028 .2779 .70827 .28932 .7249 .2771 .71701 .26574 Mtetra
.761 .767 .857 r
.71701 .26574 .7249 .2771 .74164 .26579 .73383 .25447 Mtetra
.749 .765 .866 r
.73383 .25447 .74164 .26579 .75848 .25531 .75076 .24401 Mtetra
.737 .763 .874 r
.75076 .24401 .75848 .25531 .77543 .24557 .7678 .23428 Mtetra
.725 .761 .881 r
.7678 .23428 .77543 .24557 .79251 .23648 .78496 .22518 Mtetra
.715 .758 .886 r
.78496 .22518 .79251 .23648 .8097 .22796 .80224 .21664 Mtetra
.705 .755 .891 r
.80224 .21664 .8097 .22796 .82703 .2199 .81964 .20855 Mtetra
.167 .469 .891 r
.18915 .46914 .19889 .4803 .21224 .48628 .20253 .47473 Mtetra
.125 .434 .874 r
.20253 .47473 .21224 .48628 .22569 .49311 .21601 .48114 Mtetra
.096 .408 .859 r
.21601 .48114 .22569 .49311 .23925 .50066 .2296 .48825 Mtetra
.084 .391 .849 r
.2296 .48825 .23925 .50066 .25296 .50873 .24334 .49586 Mtetra
.091 .386 .846 r
.24334 .49586 .25296 .50873 .26684 .51707 .25724 .50374 Mtetra
.117 .393 .848 r
.25724 .50374 .26684 .51707 .28092 .52542 .27134 .51163 Mtetra
.16 .412 .854 r
.27134 .51163 .28092 .52542 .29522 .53343 .28567 .51919 Mtetra
.219 .44 .861 r
.28567 .51919 .29522 .53343 .30977 .54076 .30023 .5261 Mtetra
.287 .473 .868 r
.30023 .5261 .30977 .54076 .32458 .54705 .31506 .532 Mtetra
.36 .509 .871 r
.31506 .532 .32458 .54705 .33966 .55194 .33015 .53654 Mtetra
.433 .544 .869 r
.33015 .53654 .33966 .55194 .355 .55509 .34551 .53941 Mtetra
.501 .575 .863 r
.34551 .53941 .355 .55509 .37061 .55621 .36114 .54032 Mtetra
.561 .603 .853 r
.36114 .54032 .37061 .55621 .38646 .55507 .37701 .53904 Mtetra
.613 .626 .84 r
.37701 .53904 .38646 .55507 .40253 .55153 .3931 .53543 Mtetra
.656 .645 .827 r
.3931 .53543 .40253 .55153 .41878 .54552 .40939 .52943 Mtetra
.692 .661 .815 r
.40939 .52943 .41878 .54552 .43519 .53705 .42583 .52105 Mtetra
.722 .674 .803 r
.42583 .52105 .43519 .53705 .45172 .52625 .4424 .51041 Mtetra
.746 .686 .793 r
.4424 .51041 .45172 .52625 .46832 .51332 .45905 .4977 Mtetra
.766 .695 .784 r
.45905 .4977 .46832 .51332 .48498 .49852 .47576 .48316 Mtetra
.781 .704 .778 r
.47576 .48316 .48498 .49852 .50164 .48216 .49249 .46712 Mtetra
.794 .711 .774 r
.49249 .46712 .50164 .48216 .5183 .4646 .50922 .4499 Mtetra
.803 .718 .771 r
.50922 .4499 .5183 .4646 .53493 .44621 .52593 .43186 Mtetra
.81 .725 .771 r
.52593 .43186 .53493 .44621 .55153 .42734 .54261 .41334 Mtetra
.815 .731 .773 r
.54261 .41334 .55153 .42734 .56808 .40833 .55925 .39468 Mtetra
.817 .737 .776 r
.55925 .39468 .56808 .40833 .5846 .38948 .57586 .37617 Mtetra
.817 .742 .781 r
.57586 .37617 .5846 .38948 .60109 .37105 .59245 .35806 Mtetra
.816 .747 .788 r
.59245 .35806 .60109 .37105 .61757 .35327 .60902 .34056 Mtetra
.812 .752 .796 r
.60902 .34056 .61757 .35327 .63404 .33628 .62559 .32383 Mtetra
.806 .756 .806 r
.62559 .32383 .63404 .33628 .65054 .32021 .64218 .30798 Mtetra
.799 .759 .816 r
.64218 .30798 .65054 .32021 .66706 .30511 .6588 .29307 Mtetra
.79 .761 .826 r
.6588 .29307 .66706 .30511 .68364 .29101 .67547 .27913 Mtetra
.78 .762 .837 r
.67547 .27913 .68364 .29101 .70028 .2779 .6922 .26615 Mtetra
.769 .763 .847 r
.6922 .26615 .70028 .2779 .71701 .26574 .70902 .25409 Mtetra
.758 .763 .857 r
.70902 .25409 .71701 .26574 .73383 .25447 .72593 .24289 Mtetra
.746 .762 .866 r
.72593 .24289 .73383 .25447 .75076 .24401 .74295 .23248 Mtetra
.734 .76 .873 r
.74295 .23248 .75076 .24401 .7678 .23428 .76007 .22278 Mtetra
.723 .758 .88 r
.76007 .22278 .7678 .23428 .78496 .22518 .77732 .21369 Mtetra
.713 .756 .886 r
.77732 .21369 .78496 .22518 .80224 .21664 .79468 .20514 Mtetra
.704 .754 .891 r
.79468 .20514 .80224 .21664 .81964 .20855 .81217 .19703 Mtetra
.212 .487 .897 r
.17935 .45755 .18915 .46914 .20253 .47473 .19278 .46268 Mtetra
.175 .456 .882 r
.19278 .46268 .20253 .47473 .21601 .48114 .20629 .46861 Mtetra
.151 .431 .869 r
.20629 .46861 .21601 .48114 .2296 .48825 .21992 .47521 Mtetra
.142 .415 .859 r
.21992 .47521 .2296 .48825 .24334 .49586 .23369 .48229 Mtetra
.149 .41 .854 r
.23369 .48229 .24334 .49586 .25724 .50374 .24762 .48964 Mtetra
.174 .415 .853 r
.24762 .48964 .25724 .50374 .27134 .51163 .26175 .49698 Mtetra
.213 .429 .855 r
.26175 .49698 .27134 .51163 .28567 .51919 .2761 .50402 Mtetra
.265 .452 .858 r
.2761 .50402 .28567 .51919 .30023 .5261 .29069 .51044 Mtetra
.326 .479 .859 r
.29069 .51044 .30023 .5261 .31506 .532 .30553 .51588 Mtetra
.389 .509 .858 r
.30553 .51588 .31506 .532 .33015 .53654 .32064 .52002 Mtetra
.452 .538 .854 r
.32064 .52002 .33015 .53654 .34551 .53941 .33602 .52255 Mtetra
.512 .565 .847 r
.33602 .52255 .34551 .53941 .36114 .54032 .35165 .5232 Mtetra
.565 .59 .837 r
.35165 .5232 .36114 .54032 .37701 .53904 .36754 .52176 Mtetra
.612 .611 .826 r
.36754 .52176 .37701 .53904 .3931 .53543 .38365 .51807 Mtetra
.651 .629 .815 r
.38365 .51807 .3931 .53543 .40939 .52943 .39996 .51208 Mtetra
.685 .645 .804 r
.39996 .51208 .40939 .52943 .42583 .52105 .41644 .5038 Mtetra
.713 .658 .794 r
.41644 .5038 .42583 .52105 .4424 .51041 .43304 .49335 Mtetra
.736 .67 .785 r
.43304 .49335 .4424 .51041 .45905 .4977 .44974 .48089 Mtetra
.755 .68 .778 r
.44974 .48089 .45905 .4977 .47576 .48316 .46649 .46668 Mtetra
.771 .689 .773 r
.46649 .46668 .47576 .48316 .49249 .46712 .48328 .451 Mtetra
.783 .698 .77 r
.48328 .451 .49249 .46712 .50922 .4499 .50007 .43419 Mtetra
.793 .706 .768 r
.50007 .43419 .50922 .4499 .52593 .43186 .51685 .41657 Mtetra
.8 .713 .769 r
.51685 .41657 .52593 .43186 .54261 .41334 .53361 .39848 Mtetra
.805 .72 .771 r
.53361 .39848 .54261 .41334 .55925 .39468 .55034 .38025 Mtetra
.808 .727 .775 r
.55034 .38025 .55925 .39468 .57586 .37617 .56703 .36214 Mtetra
.809 .733 .78 r
.56703 .36214 .57586 .37617 .59245 .35806 .58371 .34442 Mtetra
.808 .739 .787 r
.58371 .34442 .59245 .35806 .60902 .34056 .60037 .32728 Mtetra
.805 .744 .796 r
.60037 .32728 .60902 .34056 .62559 .32383 .61704 .31087 Mtetra
.8 .748 .805 r
.61704 .31087 .62559 .32383 .64218 .30798 .63372 .2953 Mtetra
.793 .752 .815 r
.63372 .2953 .64218 .30798 .6588 .29307 .65043 .28064 Mtetra
.785 .755 .826 r
.65043 .28064 .6588 .29307 .67547 .27913 .6672 .2669 Mtetra
.776 .757 .836 r
.6672 .2669 .67547 .27913 .6922 .26615 .68403 .25409 Mtetra
.765 .758 .847 r
.68403 .25409 .6922 .26615 .70902 .25409 .70094 .24216 Mtetra
.754 .759 .856 r
.70094 .24216 .70902 .25409 .72593 .24289 .71794 .23107 Mtetra
.743 .758 .865 r
.71794 .23107 .72593 .24289 .74295 .23248 .73504 .22073 Mtetra
.732 .757 .873 r
.73504 .22073 .74295 .23248 .76007 .22278 .75226 .21108 Mtetra
.721 .756 .88 r
.75226 .21108 .76007 .22278 .77732 .21369 .76959 .20201 Mtetra
.711 .754 .886 r
.76959 .20201 .77732 .21369 .79468 .20514 .78704 .19347 Mtetra
.703 .752 .891 r
.78704 .19347 .79468 .20514 .81217 .19703 .80461 .18535 Mtetra
.254 .505 .9 r
.1695 .44557 .17935 .45755 .19278 .46268 .18297 .4502 Mtetra
.222 .476 .887 r
.18297 .4502 .19278 .46268 .20629 .46861 .19654 .45559 Mtetra
.202 .453 .875 r
.19654 .45559 .20629 .46861 .21992 .47521 .21021 .46162 Mtetra
.195 .438 .866 r
.21021 .46162 .21992 .47521 .23369 .48229 .22401 .46811 Mtetra
.202 .431 .859 r
.22401 .46811 .23369 .48229 .24762 .48964 .23798 .47485 Mtetra
.225 .434 .855 r
.23798 .47485 .24762 .48964 .26175 .49698 .25214 .48159 Mtetra
.26 .445 .854 r
.25214 .48159 .26175 .49698 .2761 .50402 .26652 .48804 Mtetra
.306 .463 .853 r
.26652 .48804 .2761 .50402 .29069 .51044 .28113 .49389 Mtetra
.358 .485 .851 r
.28113 .49389 .29069 .51044 .30553 .51588 .29599 .49882 Mtetra
.414 .51 .847 r
.29599 .49882 .30553 .51588 .32064 .52002 .31112 .50251 Mtetra
.469 .534 .841 r
.31112 .50251 .32064 .52002 .33602 .52255 .32651 .50466 Mtetra
.521 .558 .834 r
.32651 .50466 .33602 .52255 .35165 .5232 .34216 .50502 Mtetra
.569 .579 .824 r
.34216 .50502 .35165 .5232 .36754 .52176 .35806 .50337 Mtetra
.611 .599 .814 r
.35806 .50337 .36754 .52176 .38365 .51807 .37419 .49959 Mtetra
.647 .616 .804 r
.37419 .49959 .38365 .51807 .39996 .51208 .39052 .49361 Mtetra
.678 .631 .795 r
.39052 .49361 .39996 .51208 .41644 .5038 .40701 .48545 Mtetra
.705 .644 .786 r
.40701 .48545 .41644 .5038 .43304 .49335 .42365 .4752 Mtetra
.727 .656 .779 r
.42365 .4752 .43304 .49335 .44974 .48089 .44038 .46304 Mtetra
.746 .667 .773 r
.44038 .46304 .44974 .48089 .46649 .46668 .45718 .44919 Mtetra
.761 .677 .769 r
.45718 .44919 .46649 .46668 .48328 .451 .47401 .43393 Mtetra
.774 .686 .767 r
.47401 .43393 .48328 .451 .50007 .43419 .49086 .41757 Mtetra
.783 .695 .766 r
.49086 .41757 .50007 .43419 .51685 .41657 .50771 .40044 Mtetra
.791 .703 .767 r
.50771 .40044 .51685 .41657 .53361 .39848 .52454 .38285 Mtetra
.796 .71 .77 r
.52454 .38285 .53361 .39848 .55034 .38025 .54134 .36511 Mtetra
.8 .717 .774 r
.54134 .36511 .55034 .38025 .56703 .36214 .55812 .34748 Mtetra
.801 .724 .78 r
.55812 .34748 .56703 .36214 .58371 .34442 .57488 .3302 Mtetra
.8 .731 .787 r
.57488 .3302 .58371 .34442 .60037 .32728 .59163 .31347 Mtetra
.798 .736 .796 r
.59163 .31347 .60037 .32728 .61704 .31087 .60839 .29744 Mtetra
.793 .742 .805 r
.60839 .29744 .61704 .31087 .63372 .2953 .62517 .2822 Mtetra
.787 .746 .815 r
.62517 .2822 .63372 .2953 .65043 .28064 .64198 .26783 Mtetra
.779 .75 .826 r
.64198 .26783 .65043 .28064 .6672 .2669 .65884 .25434 Mtetra
.771 .752 .836 r
.65884 .25434 .6672 .2669 .68403 .25409 .67576 .24173 Mtetra
.761 .754 .847 r
.67576 .24173 .68403 .25409 .70094 .24216 .69276 .22997 Mtetra
.75 .755 .856 r
.69276 .22997 .70094 .24216 .71794 .23107 .70985 .219 Mtetra
.739 .755 .865 r
.70985 .219 .71794 .23107 .73504 .22073 .72705 .20876 Mtetra
.729 .755 .873 r
.72705 .20876 .73504 .22073 .75226 .21108 .74435 .19917 Mtetra
.719 .754 .88 r
.74435 .19917 .75226 .21108 .76959 .20201 .76177 .19015 Mtetra
.709 .752 .886 r
.76177 .19015 .76959 .20201 .78704 .19347 .77931 .18162 Mtetra
.701 .751 .891 r
.77931 .18162 .78704 .19347 .80461 .18535 .79697 .1735 Mtetra
.294 .521 .903 r
.15959 .43325 .1695 .44557 .18297 .4502 .17312 .43734 Mtetra
.266 .495 .891 r
.17312 .43734 .18297 .4502 .19654 .45559 .18673 .44214 Mtetra
.249 .473 .879 r
.18673 .44214 .19654 .45559 .21021 .46162 .20045 .44755 Mtetra
.243 .458 .87 r
.20045 .44755 .21021 .46162 .22401 .46811 .2143 .45339 Mtetra
.25 .451 .862 r
.2143 .45339 .22401 .46811 .23798 .47485 .22832 .45948 Mtetra
.27 .452 .856 r
.22832 .45948 .23798 .47485 .25214 .48159 .24251 .46556 Mtetra
.301 .46 .852 r
.24251 .46556 .25214 .48159 .26652 .48804 .25692 .47136 Mtetra
.341 .473 .848 r
.25692 .47136 .26652 .48804 .28113 .49389 .27156 .4766 Mtetra
.387 .491 .844 r
.27156 .4766 .28113 .49389 .29599 .49882 .28645 .48096 Mtetra
.435 .511 .838 r
.28645 .48096 .29599 .49882 .31112 .50251 .30159 .48415 Mtetra
.483 .532 .831 r
.30159 .48415 .31112 .50251 .32651 .50466 .317 .48588 Mtetra
.529 .552 .823 r
.317 .48588 .32651 .50466 .34216 .50502 .33266 .48591 Mtetra
.572 .572 .814 r
.33266 .48591 .34216 .50502 .35806 .50337 .34857 .48405 Mtetra
.61 .589 .805 r
.34857 .48405 .35806 .50337 .37419 .49959 .36471 .48016 Mtetra
.643 .605 .796 r
.36471 .48016 .37419 .49959 .39052 .49361 .38105 .47419 Mtetra
.673 .62 .788 r
.38105 .47419 .39052 .49361 .40701 .48545 .39757 .46615 Mtetra
.698 .633 .781 r
.39757 .46615 .40701 .48545 .42365 .4752 .41422 .45612 Mtetra
.719 .645 .774 r
.41422 .45612 .42365 .4752 .44038 .46304 .43098 .44428 Mtetra
.737 .656 .77 r
.43098 .44428 .44038 .46304 .45718 .44919 .44781 .43082 Mtetra
.752 .666 .766 r
.44781 .43082 .45718 .44919 .47401 .43393 .46469 .41603 Mtetra
.764 .676 .765 r
.46469 .41603 .47401 .43393 .49086 .41757 .4816 .40018 Mtetra
.774 .685 .765 r
.4816 .40018 .49086 .41757 .50771 .40044 .4985 .38358 Mtetra
.782 .693 .766 r
.4985 .38358 .50771 .40044 .52454 .38285 .51539 .36654 Mtetra
.788 .701 .769 r
.51539 .36654 .52454 .38285 .54134 .36511 .53227 .34934 Mtetra
.791 .709 .774 r
.53227 .34934 .54134 .36511 .55812 .34748 .54913 .33224 Mtetra
.793 .717 .78 r
.54913 .33224 .55812 .34748 .57488 .3302 .56597 .31546 Mtetra
.792 .723 .788 r
.56597 .31546 .57488 .3302 .59163 .31347 .58281 .2992 Mtetra
.79 .73 .796 r
.58281 .2992 .59163 .31347 .60839 .29744 .59966 .28359 Mtetra
.786 .735 .806 r
.59966 .28359 .60839 .29744 .62517 .2822 .61652 .26873 Mtetra
.781 .74 .816 r
.61652 .26873 .62517 .2822 .64198 .26783 .63343 .25468 Mtetra
.774 .745 .826 r
.63343 .25468 .64198 .26783 .65884 .25434 .65038 .24147 Mtetra
.765 .748 .837 r
.65038 .24147 .65884 .25434 .67576 .24173 .6674 .2291 Mtetra
.756 .75 .847 r
.6674 .2291 .67576 .24173 .69276 .22997 .68449 .21753 Mtetra
.746 .752 .857 r
.68449 .21753 .69276 .22997 .70985 .219 .70168 .20671 Mtetra
.736 .752 .865 r
.70168 .20671 .70985 .219 .72705 .20876 .71896 .19659 Mtetra
.726 .752 .873 r
.71896 .19659 .72705 .20876 .74435 .19917 .73635 .18708 Mtetra
.716 .752 .88 r
.73635 .18708 .74435 .19917 .76177 .19015 .75386 .17811 Mtetra
.707 .751 .886 r
.75386 .17811 .76177 .19015 .77931 .18162 .77149 .1696 Mtetra
.699 .75 .891 r
.77149 .1696 .77931 .18162 .79697 .1735 .78923 .16149 Mtetra
.331 .537 .904 r
.14961 .42064 .15959 .43325 .17312 .43734 .1632 .42415 Mtetra
.307 .513 .893 r
.1632 .42415 .17312 .43734 .18673 .44214 .17687 .42833 Mtetra
.292 .493 .882 r
.17687 .42833 .18673 .44214 .20045 .44755 .19065 .43308 Mtetra
.287 .478 .872 r
.19065 .43308 .20045 .44755 .2143 .45339 .20455 .43824 Mtetra
.293 .47 .863 r
.20455 .43824 .2143 .45339 .22832 .45948 .21861 .44362 Mtetra
.31 .469 .856 r
.21861 .44362 .22832 .45948 .24251 .46556 .23285 .44899 Mtetra
.337 .474 .85 r
.23285 .44899 .24251 .46556 .25692 .47136 .2473 .45411 Mtetra
.372 .484 .844 r
.2473 .45411 .25692 .47136 .27156 .4766 .26197 .45869 Mtetra
.412 .498 .837 r
.26197 .45869 .27156 .4766 .28645 .48096 .27688 .46245 Mtetra
.454 .514 .831 r
.27688 .46245 .28645 .48096 .30159 .48415 .29205 .4651 Mtetra
.496 .532 .823 r
.29205 .4651 .30159 .48415 .317 .48588 .30747 .46638 Mtetra
.537 .549 .815 r
.30747 .46638 .317 .48588 .33266 .48591 .32315 .46606 Mtetra
.575 .566 .806 r
.32315 .46606 .33266 .48591 .34857 .48405 .33907 .46396 Mtetra
.61 .582 .798 r
.33907 .46396 .34857 .48405 .36471 .48016 .35522 .45996 Mtetra
.64 .597 .79 r
.35522 .45996 .36471 .48016 .38105 .47419 .37157 .45399 Mtetra
.667 .611 .783 r
.37157 .45399 .38105 .47419 .39757 .46615 .3881 .44607 Mtetra
.691 .624 .776 r
.3881 .44607 .39757 .46615 .41422 .45612 .40477 .43628 Mtetra
.711 .636 .771 r
.40477 .43628 .41422 .45612 .43098 .44428 .42155 .42477 Mtetra
.729 .647 .767 r
.42155 .42477 .43098 .44428 .44781 .43082 .43841 .41174 Mtetra
.743 .657 .765 r
.43841 .41174 .44781 .43082 .46469 .41603 .45533 .39744 Mtetra
.756 .667 .764 r
.45533 .39744 .46469 .41603 .4816 .40018 .47227 .38213 Mtetra
.766 .676 .764 r
.47227 .38213 .4816 .40018 .4985 .38358 .48923 .36611 Mtetra
.773 .685 .766 r
.48923 .36611 .4985 .38358 .51539 .36654 .50618 .34966 Mtetra
.779 .694 .77 r
.50618 .34966 .51539 .36654 .53227 .34934 .52312 .33304 Mtetra
.783 .702 .775 r
.52312 .33304 .53227 .34934 .54913 .33224 .54005 .31651 Mtetra
.785 .71 .781 r
.54005 .31651 .54913 .33224 .56597 .31546 .55698 .30028 Mtetra
.785 .717 .789 r
.55698 .30028 .56597 .31546 .58281 .2992 .5739 .28452 Mtetra
.783 .724 .797 r
.5739 .28452 .58281 .2992 .59966 .28359 .59083 .26936 Mtetra
.779 .73 .807 r
.59083 .26936 .59966 .28359 .61652 .26873 .60779 .25492 Mtetra
.774 .736 .817 r
.60779 .25492 .61652 .26873 .63343 .25468 .62478 .24123 Mtetra
.768 .74 .828 r
.62478 .24123 .63343 .25468 .65038 .24147 .64183 .22833 Mtetra
.76 .744 .838 r
.64183 .22833 .65038 .24147 .6674 .2291 .65894 .21622 Mtetra
.751 .746 .848 r
.65894 .21622 .6674 .2291 .68449 .21753 .67613 .20486 Mtetra
.742 .748 .858 r
.67613 .20486 .68449 .21753 .70168 .20671 .6934 .19421 Mtetra
.732 .749 .866 r
.6934 .19421 .70168 .20671 .71896 .19659 .71078 .18421 Mtetra
.722 .75 .874 r
.71078 .18421 .71896 .19659 .73635 .18708 .72826 .17479 Mtetra
.713 .75 .88 r
.72826 .17479 .73635 .18708 .75386 .17811 .74586 .16589 Mtetra
.705 .749 .886 r
.74586 .16589 .75386 .17811 .77149 .1696 .76357 .15742 Mtetra
.697 .748 .891 r
.76357 .15742 .77149 .1696 .78923 .16149 .78141 .14932 Mtetra
.365 .553 .904 r
.13957 .4078 .14961 .42064 .1632 .42415 .15322 .4107 Mtetra
.344 .53 .894 r
.15322 .4107 .1632 .42415 .17687 .42833 .16696 .41424 Mtetra
.331 .511 .883 r
.16696 .41424 .17687 .42833 .19065 .43308 .18079 .41829 Mtetra
.326 .496 .873 r
.18079 .41829 .19065 .43308 .20455 .43824 .19476 .42273 Mtetra
.332 .487 .864 r
.19476 .42273 .20455 .43824 .21861 .44362 .20887 .42738 Mtetra
.346 .484 .855 r
.20887 .42738 .21861 .44362 .23285 .44899 .22316 .43202 Mtetra
.37 .487 .848 r
.22316 .43202 .23285 .44899 .2473 .45411 .23765 .43641 Mtetra
.399 .494 .84 r
.23765 .43641 .2473 .45411 .26197 .45869 .25235 .4403 Mtetra
.434 .505 .833 r
.25235 .4403 .26197 .45869 .27688 .46245 .2673 .44343 Mtetra
.471 .518 .825 r
.2673 .44343 .27688 .46245 .29205 .4651 .28249 .44551 Mtetra
.508 .533 .817 r
.28249 .44551 .29205 .4651 .30747 .46638 .29793 .44632 Mtetra
.544 .548 .809 r
.29793 .44632 .30747 .46638 .32315 .46606 .31362 .44564 Mtetra
.578 .563 .801 r
.31362 .44564 .32315 .46606 .33907 .46396 .32955 .44328 Mtetra
.609 .578 .793 r
.32955 .44328 .33907 .46396 .35522 .45996 .34571 .43915 Mtetra
.638 .591 .786 r
.34571 .43915 .35522 .45996 .37157 .45399 .36207 .43318 Mtetra
.663 .604 .779 r
.36207 .43318 .37157 .45399 .3881 .44607 .3786 .42538 Mtetra
.685 .617 .774 r
.3786 .42538 .3881 .44607 .40477 .43628 .39528 .41583 Mtetra
.705 .628 .769 r
.39528 .41583 .40477 .43628 .42155 .42477 .41208 .40467 Mtetra
.721 .639 .766 r
.41208 .40467 .42155 .42477 .43841 .41174 .42897 .39208 Mtetra
.736 .65 .764 r
.42897 .39208 .43841 .41174 .45533 .39744 .44591 .37829 Mtetra
.747 .66 .764 r
.44591 .37829 .45533 .39744 .47227 .38213 .46289 .36355 Mtetra
.757 .669 .765 r
.46289 .36355 .47227 .38213 .48923 .36611 .4799 .34813 Mtetra
.765 .679 .767 r
.4799 .34813 .48923 .36611 .50618 .34966 .4969 .3323 Mtetra
.771 .687 .771 r
.4969 .3323 .50618 .34966 .52312 .33304 .51391 .3163 Mtetra
.775 .696 .776 r
.51391 .3163 .52312 .33304 .54005 .31651 .53091 .30037 Mtetra
.777 .704 .783 r
.53091 .30037 .54005 .31651 .55698 .30028 .54791 .28471 Mtetra
.777 .712 .791 r
.54791 .28471 .55698 .30028 .5739 .28452 .56491 .26949 Mtetra
.776 .719 .799 r
.56491 .26949 .5739 .28452 .59083 .26936 .58193 .25482 Mtetra
.773 .725 .809 r
.58193 .25482 .59083 .26936 .60779 .25492 .59897 .24081 Mtetra
.768 .731 .819 r
.59897 .24081 .60779 .25492 .62478 .24123 .61605 .22751 Mtetra
.762 .736 .829 r
.61605 .22751 .62478 .24123 .64183 .22833 .63319 .21494 Mtetra
.754 .74 .84 r
.63319 .21494 .64183 .22833 .65894 .21622 .65039 .20311 Mtetra
.746 .743 .849 r
.65039 .20311 .65894 .21622 .67613 .20486 .66767 .19198 Mtetra
.737 .745 .859 r
.66767 .19198 .67613 .20486 .6934 .19421 .68504 .18151 Mtetra
.728 .747 .867 r
.68504 .18151 .6934 .19421 .71078 .18421 .7025 .17165 Mtetra
.719 .748 .875 r
.7025 .17165 .71078 .18421 .72826 .17479 .72008 .16234 Mtetra
.71 .748 .881 r
.72008 .16234 .72826 .17479 .74586 .16589 .73776 .1535 Mtetra
.703 .748 .887 r
.73776 .1535 .74586 .16589 .76357 .15742 .75557 .14507 Mtetra
.695 .747 .891 r
.75557 .14507 .76357 .15742 .78141 .14932 .77349 .13699 Mtetra
.397 .567 .904 r
.12945 .39478 .13957 .4078 .15322 .4107 .14318 .39705 Mtetra
.378 .546 .894 r
.14318 .39705 .15322 .4107 .16696 .41424 .15698 .39992 Mtetra
.366 .528 .884 r
.15698 .39992 .16696 .41424 .18079 .41829 .17088 .40326 Mtetra
.362 .513 .874 r
.17088 .40326 .18079 .41829 .19476 .42273 .18491 .40697 Mtetra
.366 .504 .864 r
.18491 .40697 .19476 .42273 .20887 .42738 .19908 .41086 Mtetra
.379 .499 .855 r
.19908 .41086 .20887 .42738 .22316 .43202 .21342 .41474 Mtetra
.398 .5 .846 r
.21342 .41474 .22316 .43202 .23765 .43641 .22796 .41839 Mtetra
.424 .505 .838 r
.22796 .41839 .23765 .43641 .25235 .4403 .24271 .42158 Mtetra
.454 .513 .829 r
.24271 .42158 .25235 .4403 .2673 .44343 .25768 .42404 Mtetra
.486 .523 .821 r
.25768 .42404 .2673 .44343 .28249 .44551 .2729 .42555 Mtetra
.518 .535 .813 r
.2729 .42555 .28249 .44551 .29793 .44632 .28836 .42587 Mtetra
.551 .548 .805 r
.28836 .42587 .29793 .44632 .31362 .44564 .30407 .4248 Mtetra
.581 .561 .797 r
.30407 .4248 .31362 .44564 .32955 .44328 .32001 .42218 Mtetra
.61 .575 .79 r
.32001 .42218 .32955 .44328 .34571 .43915 .33617 .41791 Mtetra
.636 .587 .783 r
.33617 .41791 .34571 .43915 .36207 .43318 .35253 .41194 Mtetra
.659 .6 .777 r
.35253 .41194 .36207 .43318 .3786 .42538 .36907 .40426 Mtetra
.68 .611 .772 r
.36907 .40426 .3786 .42538 .39528 .41583 .38576 .39496 Mtetra
.698 .623 .768 r
.38576 .39496 .39528 .41583 .41208 .40467 .40257 .38415 Mtetra
.714 .634 .766 r
.40257 .38415 .41208 .40467 .42897 .39208 .41948 .372 Mtetra
.728 .644 .765 r
.41948 .372 .42897 .39208 .44591 .37829 .43645 .35874 Mtetra
.74 .654 .765 r
.43645 .35874 .44591 .37829 .46289 .36355 .45346 .34458 Mtetra
.75 .664 .766 r
.45346 .34458 .46289 .36355 .4799 .34813 .4705 .32978 Mtetra
.757 .673 .769 r
.4705 .32978 .4799 .34813 .4969 .3323 .48756 .31458 Mtetra
.763 .682 .773 r
.48756 .31458 .4969 .3323 .51391 .3163 .50462 .29922 Mtetra
.767 .691 .779 r
.50462 .29922 .51391 .3163 .53091 .30037 .52169 .28391 Mtetra
.769 .699 .785 r
.52169 .28391 .53091 .30037 .54791 .28471 .53876 .26884 Mtetra
.77 .707 .793 r
.53876 .26884 .54791 .28471 .56491 .26949 .55584 .25417 Mtetra
.769 .715 .802 r
.55584 .25417 .56491 .26949 .58193 .25482 .57293 .24001 Mtetra
.766 .721 .811 r
.57293 .24001 .58193 .25482 .59897 .24081 .59006 .22646 Mtetra
.761 .727 .821 r
.59006 .22646 .59897 .24081 .61605 .22751 .60723 .21355 Mtetra
.755 .733 .831 r
.60723 .21355 .61605 .22751 .63319 .21494 .62446 .20133 Mtetra
.749 .737 .841 r
.62446 .20133 .63319 .21494 .65039 .20311 .64175 .18979 Mtetra
.741 .74 .851 r
.64175 .18979 .65039 .20311 .66767 .19198 .65912 .1789 Mtetra
.732 .743 .86 r
.65912 .1789 .66767 .19198 .68504 .18151 .67658 .16862 Mtetra
.724 .745 .868 r
.67658 .16862 .68504 .18151 .7025 .17165 .69414 .15892 Mtetra
.716 .746 .876 r
.69414 .15892 .7025 .17165 .72008 .16234 .7118 .14971 Mtetra
.707 .746 .882 r
.7118 .14971 .72008 .16234 .73776 .1535 .72958 .14095 Mtetra
.7 .746 .887 r
.72958 .14095 .73776 .1535 .75557 .14507 .74747 .13257 Mtetra
.693 .746 .892 r
.74747 .13257 .75557 .14507 .77349 .13699 .76548 .12451 Mtetra
.425 .581 .903 r
.11925 .38161 .12945 .39478 .14318 .39705 .13305 .38326 Mtetra
.409 .561 .894 r
.13305 .38326 .14318 .39705 .15698 .39992 .14693 .38544 Mtetra
.398 .544 .885 r
.14693 .38544 .15698 .39992 .17088 .40326 .1609 .38807 Mtetra
.394 .53 .875 r
.1609 .38807 .17088 .40326 .18491 .40697 .175 .39103 Mtetra
.397 .52 .865 r
.175 .39103 .18491 .40697 .19908 .41086 .18923 .39416 Mtetra
.407 .514 .855 r
.18923 .39416 .19908 .41086 .21342 .41474 .20363 .39727 Mtetra
.424 .513 .845 r
.20363 .39727 .21342 .41474 .22796 .41839 .21822 .40017 Mtetra
.446 .515 .836 r
.21822 .40017 .22796 .41839 .24271 .42158 .23301 .40264 Mtetra
.472 .521 .827 r
.23301 .40264 .24271 .42158 .25768 .42404 .24803 .40444 Mtetra
.499 .529 .819 r
.24803 .40444 .25768 .42404 .2729 .42555 .26327 .40536 Mtetra
.528 .539 .81 r
.26327 .40536 .2729 .42555 .28836 .42587 .27876 .40518 Mtetra
.557 .55 .802 r
.27876 .40518 .28836 .42587 .30407 .4248 .29448 .40372 Mtetra
.585 .562 .795 r
.29448 .40372 .30407 .4248 .32001 .42218 .31043 .40083 Mtetra
.61 .573 .788 r
.31043 .40083 .32001 .42218 .33617 .41791 .3266 .39642 Mtetra
.634 .585 .782 r
.3266 .39642 .33617 .41791 .35253 .41194 .34297 .39043 Mtetra
.656 .597 .776 r
.34297 .39043 .35253 .41194 .36907 .40426 .35951 .38287 Mtetra
.676 .608 .772 r
.35951 .38287 .36907 .40426 .38576 .39496 .3762 .3738 Mtetra
.693 .619 .769 r
.3762 .3738 .38576 .39496 .40257 .38415 .39302 .36334 Mtetra
.708 .629 .767 r
.39302 .36334 .40257 .38415 .41948 .372 .40994 .35165 Mtetra
.722 .64 .766 r
.40994 .35165 .41948 .372 .43645 .35874 .42693 .3389 Mtetra
.733 .65 .766 r
.42693 .3389 .43645 .35874 .45346 .34458 .44398 .32533 Mtetra
.742 .659 .768 r
.44398 .32533 .45346 .34458 .4705 .32978 .46105 .31115 Mtetra
.75 .669 .771 r
.46105 .31115 .4705 .32978 .48756 .31458 .47815 .2966 Mtetra
.756 .678 .776 r
.47815 .2966 .48756 .31458 .50462 .29922 .49527 .28188 Mtetra
.76 .687 .782 r
.49527 .28188 .50462 .29922 .52169 .28391 .51239 .26721 Mtetra
.762 .695 .788 r
.51239 .26721 .52169 .28391 .53876 .26884 .52953 .25274 Mtetra
.763 .704 .796 r
.52953 .25274 .53876 .26884 .55584 .25417 .54668 .23863 Mtetra
.761 .711 .805 r
.54668 .23863 .55584 .25417 .57293 .24001 .56386 .22499 Mtetra
.759 .718 .814 r
.56386 .22499 .57293 .24001 .59006 .22646 .58107 .2119 Mtetra
.755 .724 .824 r
.58107 .2119 .59006 .22646 .60723 .21355 .59832 .1994 Mtetra
.749 .73 .834 r
.59832 .1994 .60723 .21355 .62446 .20133 .61564 .18754 Mtetra
.743 .734 .844 r
.61564 .18754 .62446 .20133 .64175 .18979 .63302 .17629 Mtetra
.736 .738 .853 r
.63302 .17629 .64175 .18979 .65912 .1789 .65048 .16565 Mtetra
.728 .741 .862 r
.65048 .16565 .65912 .1789 .67658 .16862 .66803 .15557 Mtetra
.72 .743 .87 r
.66803 .15557 .67658 .16862 .69414 .15892 .68568 .14602 Mtetra
.712 .744 .877 r
.68568 .14602 .69414 .15892 .7118 .14971 .70343 .13693 Mtetra
.704 .745 .883 r
.70343 .13693 .7118 .14971 .72958 .14095 .7213 .12824 Mtetra
.697 .745 .888 r
.7213 .12824 .72958 .14095 .74747 .13257 .73928 .11991 Mtetra
.691 .745 .892 r
.73928 .11991 .74747 .13257 .76548 .12451 .75738 .11187 Mtetra
.452 .594 .903 r
.10896 .36835 .11925 .38161 .13305 .38326 .12284 .36937 Mtetra
.437 .576 .894 r
.12284 .36937 .13305 .38326 .14693 .38544 .13679 .37088 Mtetra
.427 .559 .885 r
.13679 .37088 .14693 .38544 .1609 .38807 .15084 .37279 Mtetra
.423 .545 .875 r
.15084 .37279 .1609 .38807 .175 .39103 .16501 .375 Mtetra
.425 .535 .865 r
.16501 .375 .175 .39103 .18923 .39416 .17932 .37736 Mtetra
.434 .529 .855 r
.17932 .37736 .18923 .39416 .20363 .39727 .19378 .37971 Mtetra
.448 .526 .845 r
.19378 .37971 .20363 .39727 .21822 .40017 .20842 .38186 Mtetra
.466 .526 .836 r
.20842 .38186 .21822 .40017 .23301 .40264 .22327 .38361 Mtetra
.488 .53 .827 r
.22327 .38361 .23301 .40264 .24803 .40444 .23832 .38475 Mtetra
.512 .536 .818 r
.23832 .38475 .24803 .40444 .26327 .40536 .2536 .38508 Mtetra
.538 .544 .809 r
.2536 .38508 .26327 .40536 .27876 .40518 .26911 .3844 Mtetra
.563 .553 .801 r
.26911 .3844 .27876 .40518 .29448 .40372 .28485 .38254 Mtetra
.588 .563 .794 r
.28485 .38254 .29448 .40372 .31043 .40083 .30081 .37938 Mtetra
.612 .574 .787 r
.30081 .37938 .31043 .40083 .3266 .39642 .31699 .37481 Mtetra
.633 .585 .782 r
.31699 .37481 .3266 .39642 .34297 .39043 .33336 .3688 Mtetra
.654 .595 .777 r
.33336 .3688 .34297 .39043 .35951 .38287 .3499 .36135 Mtetra
.672 .606 .773 r
.3499 .36135 .35951 .38287 .3762 .3738 .3666 .35252 Mtetra
.688 .616 .77 r
.3666 .35252 .3762 .3738 .39302 .36334 .38343 .34241 Mtetra
.703 .627 .769 r
.38343 .34241 .39302 .36334 .40994 .35165 .40036 .33115 Mtetra
.715 .637 .768 r
.40036 .33115 .40994 .35165 .42693 .3389 .41737 .31893 Mtetra
.726 .646 .769 r
.41737 .31893 .42693 .3389 .44398 .32533 .43443 .30593 Mtetra
.735 .656 .771 r
.43443 .30593 .44398 .32533 .46105 .31115 .45154 .29237 Mtetra
.743 .666 .775 r
.45154 .29237 .46105 .31115 .47815 .2966 .46868 .27846 Mtetra
.748 .675 .779 r
.46868 .27846 .47815 .2966 .49527 .28188 .48585 .26438 Mtetra
.752 .684 .785 r
.48585 .26438 .49527 .28188 .51239 .26721 .50303 .25033 Mtetra
.755 .693 .792 r
.50303 .25033 .51239 .26721 .52953 .25274 .52023 .23647 Mtetra
.755 .701 .8 r
.52023 .23647 .52953 .25274 .54668 .23863 .53745 .22292 Mtetra
.755 .708 .809 r
.53745 .22292 .54668 .23863 .56386 .22499 .5547 .2098 Mtetra
.752 .715 .818 r
.5547 .2098 .56386 .22499 .58107 .2119 .57199 .19717 Mtetra
.748 .722 .827 r
.57199 .19717 .58107 .2119 .59832 .1994 .58933 .18509 Mtetra
.743 .727 .837 r
.58933 .18509 .59832 .1994 .61564 .18754 .60673 .17358 Mtetra
.737 .732 .846 r
.60673 .17358 .61564 .18754 .63302 .17629 .62419 .16263 Mtetra
.73 .736 .855 r
.62419 .16263 .63302 .17629 .65048 .16565 .64174 .15224 Mtetra
.723 .739 .864 r
.64174 .15224 .65048 .16565 .66803 .15557 .65938 .14236 Mtetra
.716 .741 .871 r
.65938 .14236 .66803 .15557 .68568 .14602 .67712 .13296 Mtetra
.708 .742 .878 r
.67712 .13296 .68568 .14602 .70343 .13693 .69497 .12399 Mtetra
.701 .743 .884 r
.69497 .12399 .70343 .13693 .7213 .12824 .71292 .11538 Mtetra
.695 .744 .889 r
.71292 .11538 .7213 .12824 .73928 .11991 .73099 .1071 Mtetra
.689 .744 .893 r
.73099 .1071 .73928 .11991 .75738 .11187 .74919 .09908 Mtetra
.476 .606 .902 r
.09858 .35504 .10896 .36835 .12284 .36937 .11254 .35544 Mtetra
.462 .589 .894 r
.11254 .35544 .12284 .36937 .13679 .37088 .12657 .35628 Mtetra
.454 .574 .885 r
.12657 .35628 .13679 .37088 .15084 .37279 .1407 .35748 Mtetra
.449 .56 .876 r
.1407 .35748 .15084 .37279 .16501 .375 .15495 .35895 Mtetra
.451 .55 .866 r
.15495 .35895 .16501 .375 .17932 .37736 .16932 .36056 Mtetra
.457 .543 .856 r
.16932 .36056 .17932 .37736 .19378 .37971 .18385 .36215 Mtetra
.469 .539 .846 r
.18385 .36215 .19378 .37971 .20842 .38186 .19856 .36356 Mtetra
.485 .538 .836 r
.19856 .36356 .20842 .38186 .22327 .38361 .21345 .3646 Mtetra
.503 .54 .827 r
.21345 .3646 .22327 .38361 .23832 .38475 .22855 .36509 Mtetra
.525 .544 .818 r
.22855 .36509 .23832 .38475 .2536 .38508 .24387 .36483 Mtetra
.547 .551 .81 r
.24387 .36483 .2536 .38508 .26911 .3844 .2594 .36365 Mtetra
.569 .558 .802 r
.2594 .36365 .26911 .3844 .28485 .38254 .27516 .3614 Mtetra
.592 .567 .795 r
.27516 .3614 .28485 .38254 .30081 .37938 .29114 .35796 Mtetra
.613 .576 .788 r
.29114 .35796 .30081 .37938 .31699 .37481 .30732 .35324 Mtetra
.633 .586 .783 r
.30732 .35324 .31699 .37481 .33336 .3688 .3237 .34721 Mtetra
.652 .595 .779 r
.3237 .34721 .33336 .3688 .3499 .36135 .34025 .33986 Mtetra
.669 .605 .775 r
.34025 .33986 .3499 .36135 .3666 .35252 .35695 .33125 Mtetra
.684 .615 .773 r
.35695 .33125 .3666 .35252 .38343 .34241 .37378 .32146 Mtetra
.698 .625 .772 r
.37378 .32146 .38343 .34241 .40036 .33115 .39072 .31063 Mtetra
.71 .635 .772 r
.39072 .31063 .40036 .33115 .41737 .31893 .40774 .29891 Mtetra
.72 .645 .773 r
.40774 .29891 .41737 .31893 .43443 .30593 .42483 .28648 Mtetra
.729 .654 .775 r
.42483 .28648 .43443 .30593 .45154 .29237 .44197 .27353 Mtetra
.736 .664 .779 r
.44197 .27353 .45154 .29237 .46868 .27846 .45914 .26024 Mtetra
.742 .673 .784 r
.45914 .26024 .46868 .27846 .48585 .26438 .47635 .2468 Mtetra
.745 .682 .79 r
.47635 .2468 .48585 .26438 .50303 .25033 .49358 .23337 Mtetra
.748 .69 .796 r
.49358 .23337 .50303 .25033 .52023 .23647 .51084 .22009 Mtetra
.748 .699 .804 r
.51084 .22009 .52023 .23647 .53745 .22292 .52813 .2071 Mtetra
.748 .706 .813 r
.52813 .2071 .53745 .22292 .5547 .2098 .54545 .19449 Mtetra
.745 .714 .822 r
.54545 .19449 .5547 .2098 .57199 .19717 .56282 .18232 Mtetra
.742 .72 .831 r
.56282 .18232 .57199 .19717 .58933 .18509 .58024 .17065 Mtetra
.737 .725 .84 r
.58024 .17065 .58933 .18509 .60673 .17358 .59772 .15949 Mtetra
.732 .73 .849 r
.59772 .15949 .60673 .17358 .62419 .16263 .61528 .14884 Mtetra
.725 .734 .858 r
.61528 .14884 .62419 .16263 .64174 .15224 .63291 .13869 Mtetra
.718 .737 .866 r
.63291 .13869 .64174 .15224 .65938 .14236 .65064 .12902 Mtetra
.712 .739 .873 r
.65064 .12902 .65938 .14236 .67712 .13296 .66847 .11977 Mtetra
.705 .741 .88 r
.66847 .11977 .67712 .13296 .69497 .12399 .6864 .11091 Mtetra
.698 .742 .885 r
.6864 .11091 .69497 .12399 .71292 .11538 .70445 .10238 Mtetra
.692 .743 .89 r
.70445 .10238 .71292 .11538 .73099 .1071 .72261 .09414 Mtetra
.687 .743 .894 r
.72261 .09414 .73099 .1071 .74919 .09908 .7409 .08614 Mtetra
.497 .618 .901 r
.08809 .34171 .09858 .35504 .11254 .35544 .10213 .3415 Mtetra
.486 .602 .894 r
.10213 .3415 .11254 .35544 .12657 .35628 .11625 .34169 Mtetra
.477 .588 .886 r
.11625 .34169 .12657 .35628 .1407 .35748 .13047 .3422 Mtetra
.473 .575 .877 r
.13047 .3422 .1407 .35748 .15495 .35895 .14479 .34295 Mtetra
.474 .564 .867 r
.14479 .34295 .15495 .35895 .16932 .36056 .15924 .34383 Mtetra
.479 .557 .857 r
.15924 .34383 .16932 .36056 .18385 .36215 .17384 .34468 Mtetra
.488 .552 .847 r
.17384 .34468 .18385 .36215 .19856 .36356 .18861 .34536 Mtetra
.502 .55 .838 r
.18861 .34536 .19856 .36356 .21345 .3646 .20356 .34571 Mtetra
.518 .55 .828 r
.20356 .34571 .21345 .3646 .22855 .36509 .21871 .34555 Mtetra
.536 .553 .82 r
.21871 .34555 .22855 .36509 .24387 .36483 .23406 .34472 Mtetra
.555 .558 .811 r
.23406 .34472 .24387 .36483 .2594 .36365 .24963 .34305 Mtetra
.575 .564 .804 r
.24963 .34305 .2594 .36365 .27516 .3614 .26541 .34042 Mtetra
.595 .571 .797 r
.26541 .34042 .27516 .3614 .29114 .35796 .2814 .3367 Mtetra
.615 .579 .791 r
.2814 .3367 .29114 .35796 .30732 .35324 .2976 .33183 Mtetra
.633 .588 .786 r
.2976 .33183 .30732 .35324 .3237 .34721 .31398 .32577 Mtetra
.65 .597 .781 r
.31398 .32577 .3237 .34721 .34025 .33986 .33053 .31851 Mtetra
.666 .606 .778 r
.33053 .31851 .34025 .33986 .35695 .33125 .34724 .3101 Mtetra
.68 .616 .776 r
.34724 .3101 .35695 .33125 .37378 .32146 .36407 .30063 Mtetra
.693 .625 .775 r
.36407 .30063 .37378 .32146 .39072 .31063 .38102 .29021 Mtetra
.705 .634 .776 r
.38102 .29021 .39072 .31063 .40774 .29891 .39805 .27897 Mtetra
.715 .644 .777 r
.39805 .27897 .40774 .29891 .42483 .28648 .41516 .26709 Mtetra
.723 .653 .78 r
.41516 .26709 .42483 .28648 .44197 .27353 .43232 .25472 Mtetra
.73 .663 .784 r
.43232 .25472 .44197 .27353 .45914 .26024 .44953 .24203 Mtetra
.735 .672 .788 r
.44953 .24203 .45914 .26024 .47635 .2468 .46678 .2292 Mtetra
.739 .681 .794 r
.46678 .2292 .47635 .2468 .49358 .23337 .48406 .21637 Mtetra
.741 .689 .801 r
.48406 .21637 .49358 .23337 .51084 .22009 .50138 .20367 Mtetra
.742 .697 .809 r
.50138 .20367 .51084 .22009 .52813 .2071 .51873 .19122 Mtetra
.741 .705 .817 r
.51873 .19122 .52813 .2071 .54545 .19449 .53612 .1791 Mtetra
.739 .712 .826 r
.53612 .1791 .54545 .19449 .56282 .18232 .55357 .16738 Mtetra
.736 .719 .835 r
.55357 .16738 .56282 .18232 .58024 .17065 .57106 .15611 Mtetra
.731 .724 .844 r
.57106 .15611 .58024 .17065 .59772 .15949 .58863 .14529 Mtetra
.726 .729 .853 r
.58863 .14529 .59772 .15949 .61528 .14884 .60627 .13493 Mtetra
.72 .733 .861 r
.60627 .13493 .61528 .14884 .63291 .13869 .62399 .12503 Mtetra
.714 .736 .868 r
.62399 .12503 .63291 .13869 .65064 .12902 .64181 .11554 Mtetra
.707 .738 .875 r
.64181 .11554 .65064 .12902 .66847 .11977 .65972 .10644 Mtetra
.701 .74 .881 r
.65972 .10644 .66847 .11977 .6864 .11091 .67775 .09769 Mtetra
.695 .741 .887 r
.67775 .09769 .6864 .11091 .70445 .10238 .69588 .08923 Mtetra
.69 .742 .891 r
.69588 .08923 .70445 .10238 .72261 .09414 .71413 .08104 Mtetra
.685 .742 .895 r
.71413 .08104 .72261 .09414 .7409 .08614 .73251 .07306 Mtetra
.517 .629 .901 r
.0775 .3284 .08809 .34171 .10213 .3415 .09162 .3276 Mtetra
.507 .615 .894 r
.09162 .3276 .10213 .3415 .11625 .34169 .10583 .32716 Mtetra
.499 .601 .886 r
.10583 .32716 .11625 .34169 .13047 .3422 .12013 .327 Mtetra
.495 .589 .878 r
.12013 .327 .13047 .3422 .14479 .34295 .13453 .32706 Mtetra
.495 .578 .868 r
.13453 .32706 .14479 .34295 .15924 .34383 .14906 .32722 Mtetra
.499 .57 .859 r
.14906 .32722 .15924 .34383 .17384 .34468 .16373 .32736 Mtetra
.506 .565 .849 r
.16373 .32736 .17384 .34468 .18861 .34536 .17857 .32734 Mtetra
.517 .562 .84 r
.17857 .32734 .18861 .34536 .20356 .34571 .19358 .32702 Mtetra
.531 .561 .831 r
.19358 .32702 .20356 .34571 .21871 .34555 .20878 .32624 Mtetra
.547 .563 .822 r
.20878 .32624 .21871 .34555 .23406 .34472 .22417 .32485 Mtetra
.564 .566 .814 r
.22417 .32485 .23406 .34472 .24963 .34305 .23977 .32271 Mtetra
.582 .571 .807 r
.23977 .32271 .24963 .34305 .26541 .34042 .25558 .3197 Mtetra
.599 .577 .8 r
.25558 .3197 .26541 .34042 .2814 .3367 .27159 .31571 Mtetra
.617 .584 .794 r
.27159 .31571 .2814 .3367 .2976 .33183 .2878 .31068 Mtetra
.634 .592 .789 r
.2878 .31068 .2976 .33183 .31398 .32577 .30419 .30458 Mtetra
.649 .6 .785 r
.30419 .30458 .31398 .32577 .33053 .31851 .32074 .2974 Mtetra
.664 .608 .783 r
.32074 .2974 .33053 .31851 .34724 .3101 .33745 .28919 Mtetra
.677 .617 .781 r
.33745 .28919 .34724 .3101 .36407 .30063 .35429 .28001 Mtetra
.689 .626 .78 r
.35429 .28001 .36407 .30063 .38102 .29021 .37125 .26997 Mtetra
.7 .635 .781 r
.37125 .26997 .38102 .29021 .39805 .27897 .38829 .2592 Mtetra
.709 .644 .782 r
.38829 .2592 .39805 .27897 .41516 .26709 .40542 .24783 Mtetra
.717 .654 .785 r
.40542 .24783 .41516 .26709 .43232 .25472 .42261 .23601 Mtetra
.724 .663 .789 r
.42261 .23601 .43232 .25472 .44953 .24203 .43985 .2239 Mtetra
.729 .672 .794 r
.43985 .2239 .44953 .24203 .46678 .2292 .45714 .21165 Mtetra
.732 .68 .8 r
.45714 .21165 .46678 .2292 .48406 .21637 .47447 .19939 Mtetra
.735 .689 .807 r
.47447 .19939 .48406 .21637 .50138 .20367 .49184 .18725 Mtetra
.735 .697 .814 r
.49184 .18725 .50138 .20367 .51873 .19122 .50925 .17531 Mtetra
.735 .704 .822 r
.50925 .17531 .51873 .19122 .53612 .1791 .52671 .16368 Mtetra
.733 .711 .831 r
.52671 .16368 .53612 .1791 .55357 .16738 .54422 .15239 Mtetra
.73 .718 .839 r
.54422 .15239 .55357 .16738 .57106 .15611 .5618 .14149 Mtetra
.725 .723 .848 r
.5618 .14149 .57106 .15611 .58863 .14529 .57944 .131 Mtetra
.721 .728 .856 r
.57944 .131 .58863 .14529 .60627 .13493 .59716 .12092 Mtetra
.715 .732 .864 r
.59716 .12092 .60627 .13493 .62399 .12503 .61497 .11125 Mtetra
.709 .735 .871 r
.61497 .11125 .62399 .12503 .64181 .11554 .63287 .10194 Mtetra
.703 .737 .877 r
.63287 .10194 .64181 .11554 .65972 .10644 .65088 .09298 Mtetra
.698 .739 .883 r
.65088 .09298 .65972 .10644 .67775 .09769 .66899 .08433 Mtetra
.692 .74 .888 r
.66899 .08433 .67775 .09769 .69588 .08923 .68722 .07595 Mtetra
.687 .741 .892 r
.68722 .07595 .69588 .08923 .71413 .08104 .70556 .06779 Mtetra
.683 .742 .895 r
.70556 .06779 .71413 .08104 .73251 .07306 .72402 .05983 Mtetra
.535 .64 .9 r
.06679 .31513 .0775 .3284 .09162 .3276 .081 .31377 Mtetra
.525 .627 .894 r
.081 .31377 .09162 .3276 .10583 .32716 .09529 .31271 Mtetra
.519 .614 .887 r
.09529 .31271 .10583 .32716 .12013 .327 .10967 .31192 Mtetra
.515 .602 .879 r
.10967 .31192 .12013 .327 .13453 .32706 .12416 .31131 Mtetra
.514 .592 .87 r
.12416 .31131 .13453 .32706 .14906 .32722 .13877 .31079 Mtetra
.517 .584 .861 r
.13877 .31079 .14906 .32722 .16373 .32736 .15352 .31024 Mtetra
.523 .578 .852 r
.15352 .31024 .16373 .32736 .17857 .32734 .16842 .30956 Mtetra
.532 .574 .843 r
.16842 .30956 .17857 .32734 .19358 .32702 .1835 .30859 Mtetra
.544 .572 .834 r
.1835 .30859 .19358 .32702 .20878 .32624 .19875 .30722 Mtetra
.557 .573 .825 r
.19875 .30722 .20878 .32624 .22417 .32485 .21419 .30529 Mtetra
.572 .575 .817 r
.21419 .30529 .22417 .32485 .23977 .32271 .22983 .3027 Mtetra
.588 .579 .81 r
.22983 .3027 .23977 .32271 .25558 .3197 .24566 .29932 Mtetra
.603 .584 .804 r
.24566 .29932 .25558 .3197 .27159 .31571 .2617 .29507 Mtetra
.619 .59 .798 r
.2617 .29507 .27159 .31571 .2878 .31068 .27792 .28989 Mtetra
.634 .596 .794 r
.27792 .28989 .2878 .31068 .30419 .30458 .29431 .28374 Mtetra
.649 .604 .79 r
.29431 .28374 .30419 .30458 .32074 .2974 .31088 .27663 Mtetra
.662 .612 .788 r
.31088 .27663 .32074 .2974 .33745 .28919 .32759 .26859 Mtetra
.675 .62 .786 r
.32759 .26859 .33745 .28919 .35429 .28001 .34444 .25969 Mtetra
.686 .628 .786 r
.34444 .25969 .35429 .28001 .37125 .26997 .3614 .25 Mtetra
.696 .637 .786 r
.3614 .25 .37125 .26997 .38829 .2592 .37846 .23966 Mtetra
.705 .646 .788 r
.37846 .23966 .38829 .2592 .40542 .24783 .3956 .22877 Mtetra
.712 .655 .791 r
.3956 .22877 .40542 .24783 .42261 .23601 .41281 .21747 Mtetra
.718 .664 .795 r
.41281 .21747 .42261 .23601 .43985 .2239 .43008 .20591 Mtetra
.723 .672 .8 r
.43008 .20591 .43985 .2239 .45714 .21165 .44741 .19421 Mtetra
.726 .681 .806 r
.44741 .19421 .45714 .21165 .47447 .19939 .46478 .18249 Mtetra
.728 .689 .812 r
.46478 .18249 .47447 .19939 .49184 .18725 .48221 .17087 Mtetra
.729 .697 .82 r
.48221 .17087 .49184 .18725 .50925 .17531 .49968 .15943 Mtetra
.728 .704 .828 r
.49968 .15943 .50925 .17531 .52671 .16368 .5172 .14824 Mtetra
.727 .711 .836 r
.5172 .14824 .52671 .16368 .54422 .15239 .53479 .13736 Mtetra
.724 .717 .844 r
.53479 .13736 .54422 .15239 .5618 .14149 .55244 .12682 Mtetra
.72 .723 .852 r
.55244 .12682 .5618 .14149 .57944 .131 .57016 .11664 Mtetra
.715 .727 .86 r
.57016 .11664 .57944 .131 .59716 .12092 .58796 .10683 Mtetra
.71 .731 .867 r
.58796 .10683 .59716 .12092 .61497 .11125 .60585 .09737 Mtetra
.705 .734 .874 r
.60585 .09737 .61497 .11125 .63287 .10194 .62384 .08823 Mtetra
.7 .737 .88 r
.62384 .08823 .63287 .10194 .65088 .09298 .64194 .07941 Mtetra
.694 .738 .885 r
.64194 .07941 .65088 .09298 .66899 .08433 .66014 .07085 Mtetra
.69 .74 .889 r
.66014 .07085 .66899 .08433 .68722 .07595 .67845 .06253 Mtetra
.685 .741 .893 r
.67845 .06253 .68722 .07595 .70556 .06779 .69688 .05441 Mtetra
.681 .741 .896 r
.69688 .05441 .70556 .06779 .72402 .05983 .71543 .04645 Mtetra
.551 .65 .9 r
.05595 .30192 .06679 .31513 .081 .31377 .07025 .30002 Mtetra
.543 .638 .895 r
.07025 .30002 .081 .31377 .09529 .31271 .08463 .29839 Mtetra
.536 .626 .888 r
.08463 .29839 .09529 .31271 .10967 .31192 .0991 .29699 Mtetra
.532 .615 .88 r
.0991 .29699 .10967 .31192 .12416 .31131 .11367 .29574 Mtetra
.532 .605 .872 r
.11367 .29574 .12416 .31131 .13877 .31079 .12836 .29457 Mtetra
.533 .597 .864 r
.12836 .29457 .13877 .31079 .15352 .31024 .14319 .29338 Mtetra
.538 .591 .855 r
.14319 .29338 .15352 .31024 .16842 .30956 .15816 .29206 Mtetra
.546 .586 .846 r
.15816 .29206 .16842 .30956 .1835 .30859 .1733 .29049 Mtetra
.556 .584 .838 r
.1733 .29049 .1835 .30859 .19875 .30722 .18861 .28854 Mtetra
.567 .583 .829 r
.18861 .28854 .19875 .30722 .21419 .30529 .2041 .28611 Mtetra
.58 .585 .822 r
.2041 .28611 .21419 .30529 .22983 .3027 .21978 .28308 Mtetra
.594 .587 .815 r
.21978 .28308 .22983 .3027 .24566 .29932 .23565 .27935 Mtetra
.608 .591 .809 r
.23565 .27935 .24566 .29932 .2617 .29507 .2517 .27485 Mtetra
.622 .596 .804 r
.2517 .27485 .2617 .29507 .27792 .28989 .26794 .26951 Mtetra
.636 .602 .799 r
.26794 .26951 .27792 .28989 .29431 .28374 .28435 .26331 Mtetra
.649 .609 .796 r
.28435 .26331 .29431 .28374 .31088 .27663 .30092 .25626 Mtetra
.661 .616 .793 r
.30092 .25626 .31088 .27663 .32759 .26859 .31764 .24838 Mtetra
.672 .624 .792 r
.31764 .24838 .32759 .26859 .34444 .25969 .3345 .23972 Mtetra
.683 .632 .792 r
.3345 .23972 .34444 .25969 .3614 .25 .35147 .23036 Mtetra
.692 .64 .793 r
.35147 .23036 .3614 .25 .37846 .23966 .36854 .22041 Mtetra
.7 .648 .795 r
.36854 .22041 .37846 .23966 .3956 .22877 .3857 .20997 Mtetra
.707 .657 .798 r
.3857 .20997 .3956 .22877 .41281 .21747 .40293 .19916 Mtetra
.713 .665 .802 r
.40293 .19916 .41281 .21747 .43008 .20591 .42023 .1881 Mtetra
.717 .674 .806 r
.42023 .1881 .43008 .20591 .44741 .19421 .4376 .17692 Mtetra
.721 .682 .812 r
.4376 .17692 .44741 .19421 .46478 .18249 .45501 .1657 Mtetra
.722 .69 .819 r
.45501 .1657 .46478 .18249 .48221 .17087 .47249 .15457 Mtetra
.723 .698 .826 r
.47249 .15457 .48221 .17087 .49968 .15943 .49001 .14358 Mtetra
.722 .705 .833 r
.49001 .14358 .49968 .15943 .5172 .14824 .5076 .13282 Mtetra
.721 .711 .841 r
.5076 .13282 .5172 .14824 .53479 .13736 .52526 .12232 Mtetra
.718 .717 .849 r
.52526 .12232 .53479 .13736 .55244 .12682 .54298 .11212 Mtetra
.714 .722 .856 r
.54298 .11212 .55244 .12682 .57016 .11664 .56078 .10223 Mtetra
.71 .727 .863 r
.56078 .10223 .57016 .11664 .58796 .10683 .57866 .09266 Mtetra
.706 .731 .87 r
.57866 .09266 .58796 .10683 .60585 .09737 .59664 .0834 Mtetra
.701 .734 .876 r
.59664 .0834 .60585 .09737 .62384 .08823 .61471 .07442 Mtetra
.696 .736 .882 r
.61471 .07442 .62384 .08823 .64194 .07941 .63289 .06572 Mtetra
.691 .738 .887 r
.63289 .06572 .64194 .07941 .66014 .07085 .65118 .05724 Mtetra
.687 .739 .891 r
.65118 .05724 .66014 .07085 .67845 .06253 .66958 .04898 Mtetra
.683 .74 .894 r
.66958 .04898 .67845 .06253 .69688 .05441 .6881 .04088 Mtetra
.679 .741 .897 r
.6881 .04088 .69688 .05441 .71543 .04645 .70674 .03293 Mtetra
.565 .659 .9 r
.04499 .28878 .05595 .30192 .07025 .30002 .05938 .28637 Mtetra
.558 .648 .895 r
.05938 .28637 .07025 .30002 .08463 .29839 .07384 .2842 Mtetra
.552 .637 .889 r
.07384 .2842 .08463 .29839 .0991 .29699 .0884 .28223 Mtetra
.549 .627 .882 r
.0884 .28223 .0991 .29699 .11367 .29574 .10306 .28039 Mtetra
.547 .618 .874 r
.10306 .28039 .11367 .29574 .12836 .29457 .11783 .27861 Mtetra
.549 .61 .866 r
.11783 .27861 .12836 .29457 .14319 .29338 .13273 .27681 Mtetra
.552 .603 .858 r
.13273 .27681 .14319 .29338 .15816 .29206 .14778 .27488 Mtetra
.559 .599 .85 r
.14778 .27488 .15816 .29206 .1733 .29049 .16298 .27274 Mtetra
.567 .596 .842 r
.16298 .27274 .1733 .29049 .18861 .28854 .17835 .27026 Mtetra
.577 .595 .834 r
.17835 .27026 .18861 .28854 .2041 .28611 .19389 .26735 Mtetra
.588 .595 .827 r
.19389 .26735 .2041 .28611 .21978 .28308 .20961 .2639 Mtetra
.6 .597 .82 r
.20961 .2639 .21978 .28308 .23565 .27935 .22551 .25984 Mtetra
.612 .6 .814 r
.22551 .25984 .23565 .27935 .2517 .27485 .2416 .25509 Mtetra
.625 .604 .809 r
.2416 .25509 .2517 .27485 .26794 .26951 .25786 .2496 Mtetra
.637 .609 .805 r
.25786 .2496 .26794 .26951 .28435 .26331 .27428 .24335 Mtetra
.649 .615 .802 r
.27428 .24335 .28435 .26331 .30092 .25626 .29087 .23634 Mtetra
.66 .622 .8 r
.29087 .23634 .30092 .25626 .31764 .24838 .3076 .22859 Mtetra
.671 .629 .799 r
.3076 .22859 .31764 .24838 .3345 .23972 .32446 .22015 Mtetra
.68 .636 .799 r
.32446 .22015 .3345 .23972 .35147 .23036 .34144 .2111 Mtetra
.689 .644 .8 r
.34144 .2111 .35147 .23036 .36854 .22041 .35853 .2015 Mtetra
.696 .652 .802 r
.35853 .2015 .36854 .22041 .3857 .20997 .3757 .19147 Mtetra
.703 .66 .805 r
.3757 .19147 .3857 .20997 .40293 .19916 .39296 .18111 Mtetra
.708 .668 .808 r
.39296 .18111 .40293 .19916 .42023 .1881 .41029 .17052 Mtetra
.712 .676 .813 r
.41029 .17052 .42023 .1881 .4376 .17692 .42769 .1598 Mtetra
.715 .684 .819 r
.42769 .1598 .4376 .17692 .45501 .1657 .44515 .14906 Mtetra
.717 .692 .825 r
.44515 .14906 .45501 .1657 .47249 .15457 .46267 .13837 Mtetra
.717 .699 .832 r
.46267 .13837 .47249 .15457 .49001 .14358 .48026 .12781 Mtetra
.717 .706 .839 r
.48026 .12781 .49001 .14358 .5076 .13282 .49791 .11743 Mtetra
.715 .712 .846 r
.49791 .11743 .5076 .13282 .52526 .12232 .51563 .10728 Mtetra
.712 .718 .853 r
.51563 .10728 .52526 .12232 .54298 .11212 .53342 .09739 Mtetra
.709 .723 .86 r
.53342 .09739 .54298 .11212 .56078 .10223 .5513 .08777 Mtetra
.705 .727 .867 r
.5513 .08777 .56078 .10223 .57866 .09266 .56926 .07843 Mtetra
.701 .73 .873 r
.56926 .07843 .57866 .09266 .59664 .0834 .58732 .06934 Mtetra
.697 .733 .879 r
.58732 .06934 .59664 .0834 .61471 .07442 .60548 .06051 Mtetra
.692 .736 .884 r
.60548 .06051 .61471 .07442 .63289 .06572 .62374 .05191 Mtetra
.688 .737 .888 r
.62374 .05191 .63289 .06572 .65118 .05724 .64212 .04351 Mtetra
.684 .739 .892 r
.64212 .04351 .65118 .05724 .66958 .04898 .66061 .03529 Mtetra
.681 .74 .895 r
.66061 .03529 .66958 .04898 .6881 .04088 .67922 .02722 Mtetra
.677 .74 .898 r
.67922 .02722 .6881 .04088 .70674 .03293 .69795 .01926 Mtetra
.578 .668 .9 r
.0339 .27572 .04499 .28878 .05938 .28637 .04837 .27284 Mtetra
.572 .658 .896 r
.04837 .27284 .05938 .28637 .07384 .2842 .06292 .27017 Mtetra
.567 .648 .89 r
.06292 .27017 .07384 .2842 .0884 .28223 .07756 .26766 Mtetra
.563 .639 .884 r
.07756 .26766 .0884 .28223 .10306 .28039 .09231 .26526 Mtetra
.562 .63 .877 r
.09231 .26526 .10306 .28039 .11783 .27861 .10716 .26291 Mtetra
.563 .622 .869 r
.10716 .26291 .11783 .27861 .13273 .27681 .12214 .26054 Mtetra
.565 .616 .862 r
.12214 .26054 .13273 .27681 .14778 .27488 .13726 .25805 Mtetra
.57 .611 .854 r
.13726 .25805 .14778 .27488 .16298 .27274 .15253 .25537 Mtetra
.577 .608 .846 r
.15253 .25537 .16298 .27274 .17835 .27026 .16796 .25239 Mtetra
.586 .606 .839 r
.16796 .25239 .17835 .27026 .19389 .26735 .18355 .24903 Mtetra
.595 .606 .832 r
.18355 .24903 .19389 .26735 .20961 .2639 .19932 .24519 Mtetra
.606 .607 .826 r
.19932 .24519 .20961 .2639 .22551 .25984 .21526 .24081 Mtetra
.616 .609 .821 r
.21526 .24081 .22551 .25984 .2416 .25509 .23137 .23582 Mtetra
.628 .612 .816 r
.23137 .23582 .2416 .25509 .25786 .2496 .24766 .23019 Mtetra
.639 .617 .812 r
.24766 .23019 .25786 .2496 .27428 .24335 .2641 .22388 Mtetra
.649 .622 .809 r
.2641 .22388 .27428 .24335 .29087 .23634 .2807 .2169 Mtetra
.66 .628 .807 r
.2807 .2169 .29087 .23634 .3076 .22859 .29744 .20927 Mtetra
.669 .634 .806 r
.29744 .20927 .3076 .22859 .32446 .22015 .31432 .20103 Mtetra
.678 .641 .806 r
.31432 .20103 .32446 .22015 .34144 .2111 .33131 .19223 Mtetra
.686 .648 .807 r
.33131 .19223 .34144 .2111 .35853 .2015 .34841 .18296 Mtetra
.693 .656 .809 r
.34841 .18296 .35853 .2015 .3757 .19147 .36561 .1733 Mtetra
.699 .664 .812 r
.36561 .1733 .3757 .19147 .39296 .18111 .38289 .16334 Mtetra
.703 .671 .816 r
.38289 .16334 .39296 .18111 .41029 .17052 .40025 .15317 Mtetra
.707 .679 .82 r
.40025 .15317 .41029 .17052 .42769 .1598 .41769 .14289 Mtetra
.71 .686 .826 r
.41769 .14289 .42769 .1598 .44515 .14906 .43519 .13257 Mtetra
.711 .694 .832 r
.43519 .13257 .44515 .14906 .46267 .13837 .45276 .12229 Mtetra
.712 .701 .838 r
.45276 .12229 .46267 .13837 .48026 .12781 .4704 .11211 Mtetra
.711 .707 .845 r
.4704 .11211 .48026 .12781 .49791 .11743 .48812 .10209 Mtetra
.71 .713 .851 r
.48812 .10209 .49791 .11743 .51563 .10728 .5059 .09226 Mtetra
.707 .718 .858 r
.5059 .09226 .51563 .10728 .53342 .09739 .52377 .08265 Mtetra
.704 .723 .864 r
.52377 .08265 .53342 .09739 .5513 .08777 .54172 .07327 Mtetra
.701 .727 .871 r
.54172 .07327 .5513 .08777 .56926 .07843 .55976 .06413 Mtetra
.697 .731 .876 r
.55976 .06413 .56926 .07843 .58732 .06934 .5779 .05521 Mtetra
.693 .733 .882 r
.5779 .05521 .58732 .06934 .60548 .06051 .59614 .04651 Mtetra
.689 .736 .886 r
.59614 .04651 .60548 .06051 .62374 .05191 .61449 .038 Mtetra
.685 .737 .89 r
.61449 .038 .62374 .05191 .64212 .04351 .63295 .02966 Mtetra
.682 .739 .894 r
.63295 .02966 .64212 .04351 .66061 .03529 .65153 .02147 Mtetra
.679 .739 .897 r
.65153 .02147 .66061 .03529 .67922 .02722 .67023 .01341 Mtetra
.676 .74 .899 r
.67023 .01341 .67922 .02722 .69795 .01926 .68905 .00544 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.659 .742 .912 r
.39729 .5965 .40512 .60371 .41826 .5999 .41046 .59269 Mtetra
.658 .743 .913 r
.41046 .59269 .41826 .5999 .43146 .59611 .4237 .5889 Mtetra
.656 .743 .914 r
.4237 .5889 .43146 .59611 .44472 .59234 .43701 .58514 Mtetra
.654 .744 .916 r
.43701 .58514 .44472 .59234 .45806 .58861 .45038 .58144 Mtetra
.651 .745 .919 r
.45038 .58144 .45806 .58861 .47145 .58493 .46382 .57781 Mtetra
.648 .747 .921 r
.46382 .57781 .47145 .58493 .48492 .58131 .47733 .57425 Mtetra
.644 .748 .925 r
.47733 .57425 .48492 .58131 .49846 .57776 .49091 .57078 Mtetra
.64 .75 .929 r
.49091 .57078 .49846 .57776 .51206 .57428 .50456 .56741 Mtetra
.635 .753 .933 r
.50456 .56741 .51206 .57428 .52574 .5709 .51828 .56416 Mtetra
.629 .756 .939 r
.51828 .56416 .52574 .5709 .5395 .56761 .53208 .56103 Mtetra
.622 .76 .944 r
.53208 .56103 .5395 .56761 .55333 .56442 .54597 .55803 Mtetra
.615 .764 .951 r
.54597 .55803 .55333 .56442 .56724 .56134 .55993 .55516 Mtetra
.607 .769 .958 r
.55993 .55516 .56724 .56134 .58123 .55835 .57397 .55242 Mtetra
.598 .775 .965 r
.57397 .55242 .58123 .55835 .5953 .55545 .5881 .54979 Mtetra
.588 .782 .972 r
.5881 .54979 .5953 .55545 .60946 .55263 .60232 .54726 Mtetra
.578 .789 .979 r
.60232 .54726 .60946 .55263 .62371 .54986 .61663 .5448 Mtetra
.568 .797 .985 r
.61663 .5448 .62371 .54986 .63804 .54711 .63103 .54238 Mtetra
.558 .805 .991 r
.63103 .54238 .63804 .54711 .65245 .54436 .64553 .53996 Mtetra
.549 .814 .995 r
.64553 .53996 .65245 .54436 .66696 .54157 .66011 .5375 Mtetra
.541 .823 .998 r
.66011 .5375 .66696 .54157 .68154 .5387 .67478 .53494 Mtetra
.536 .832 .999 r
.67478 .53494 .68154 .5387 .69622 .53571 .68953 .53223 Mtetra
.533 .842 .999 r
.68953 .53223 .69622 .53571 .71097 .53255 .70437 .52933 Mtetra
.534 .851 .998 r
.70437 .52933 .71097 .53255 .72579 .5292 .71928 .52618 Mtetra
.539 .861 .996 r
.71928 .52618 .72579 .5292 .74069 .5256 .73427 .52275 Mtetra
.547 .87 .994 r
.73427 .52275 .74069 .5256 .75566 .52175 .74932 .51899 Mtetra
.56 .879 .992 r
.74932 .51899 .75566 .52175 .77069 .5176 .76444 .51488 Mtetra
.575 .887 .99 r
.76444 .51488 .77069 .5176 .78578 .51316 .77961 .51042 Mtetra
.593 .894 .988 r
.77961 .51042 .78578 .51316 .80093 .50843 .79484 .50558 Mtetra
.612 .899 .987 r
.79484 .50558 .80093 .50843 .81613 .5034 .81012 .50039 Mtetra
.63 .902 .985 r
.81012 .50039 .81613 .5034 .83139 .49809 .82544 .49487 Mtetra
.648 .902 .983 r
.82544 .49487 .83139 .49809 .84669 .49254 .84081 .48904 Mtetra
.664 .9 .98 r
.84081 .48904 .84669 .49254 .86205 .48677 .85623 .48294 Mtetra
.677 .895 .976 r
.85623 .48294 .86205 .48677 .87747 .48081 .8717 .47663 Mtetra
.687 .887 .971 r
.8717 .47663 .87747 .48081 .89294 .47472 .88722 .47015 Mtetra
.695 .878 .966 r
.88722 .47015 .89294 .47472 .90847 .46853 .90279 .46355 Mtetra
.7 .868 .961 r
.90279 .46355 .90847 .46853 .92407 .46228 .91843 .45688 Mtetra
.703 .856 .956 r
.91843 .45688 .92407 .46228 .93974 .456 .93413 .45019 Mtetra
.704 .845 .95 r
.93413 .45019 .93974 .456 .95548 .44974 .94991 .44352 Mtetra
.703 .833 .945 r
.94991 .44352 .95548 .44974 .9713 .44352 .96576 .43691 Mtetra
.658 .742 .912 r
.38938 .58924 .39729 .5965 .41046 .59269 .40259 .58542 Mtetra
.656 .743 .914 r
.40259 .58542 .41046 .59269 .4237 .5889 .41587 .58164 Mtetra
.654 .744 .916 r
.41587 .58164 .4237 .5889 .43701 .58514 .42922 .57791 Mtetra
.651 .745 .918 r
.42922 .57791 .43701 .58514 .45038 .58144 .44263 .57425 Mtetra
.648 .746 .921 r
.44263 .57425 .45038 .58144 .46382 .57781 .45611 .57067 Mtetra
.644 .747 .924 r
.45611 .57067 .46382 .57781 .47733 .57425 .46966 .56719 Mtetra
.639 .749 .928 r
.46966 .56719 .47733 .57425 .49091 .57078 .48328 .56382 Mtetra
.634 .751 .933 r
.48328 .56382 .49091 .57078 .50456 .56741 .49698 .56058 Mtetra
.627 .754 .938 r
.49698 .56058 .50456 .56741 .51828 .56416 .51075 .55749 Mtetra
.62 .757 .944 r
.51075 .55749 .51828 .56416 .53208 .56103 .5246 .55456 Mtetra
.611 .761 .951 r
.5246 .55456 .53208 .56103 .54597 .55803 .53853 .55178 Mtetra
.601 .766 .958 r
.53853 .55178 .54597 .55803 .55993 .55516 .55254 .54918 Mtetra
.59 .772 .966 r
.55254 .54918 .55993 .55516 .57397 .55242 .56664 .54673 Mtetra
.578 .778 .974 r
.56664 .54673 .57397 .55242 .5881 .54979 .58083 .54442 Mtetra
.564 .785 .982 r
.58083 .54442 .5881 .54979 .60232 .54726 .59512 .54224 Mtetra
.549 .792 .989 r
.59512 .54224 .60232 .54726 .61663 .5448 .60949 .54016 Mtetra
.534 .8 .994 r
.60949 .54016 .61663 .5448 .63103 .54238 .62397 .53812 Mtetra
.518 .808 .998 r
.62397 .53812 .63103 .54238 .64553 .53996 .63854 .53609 Mtetra
.504 .816 1 r
.63854 .53609 .64553 .53996 .66011 .5375 .6532 .53401 Mtetra
.491 .824 .999 r
.6532 .53401 .66011 .5375 .67478 .53494 .66795 .53182 Mtetra
.481 .832 .996 r
.66795 .53182 .67478 .53494 .68953 .53223 .6828 .52946 Mtetra
.475 .84 .992 r
.6828 .52946 .68953 .53223 .70437 .52933 .69773 .52686 Mtetra
.474 .849 .986 r
.69773 .52686 .70437 .52933 .71928 .52618 .71274 .52397 Mtetra
.479 .859 .981 r
.71274 .52397 .71928 .52618 .73427 .52275 .72782 .52073 Mtetra
.49 .87 .977 r
.72782 .52073 .73427 .52275 .74932 .51899 .74296 .5171 Mtetra
.506 .881 .974 r
.74296 .5171 .74932 .51899 .76444 .51488 .75817 .51304 Mtetra
.528 .892 .973 r
.75817 .51304 .76444 .51488 .77961 .51042 .77344 .50855 Mtetra
.552 .903 .973 r
.77344 .50855 .77961 .51042 .79484 .50558 .78875 .50361 Mtetra
.579 .912 .974 r
.78875 .50361 .79484 .50558 .81012 .50039 .8041 .49824 Mtetra
.606 .919 .975 r
.8041 .49824 .81012 .50039 .82544 .49487 .8195 .49246 Mtetra
.631 .922 .976 r
.8195 .49246 .82544 .49487 .84081 .48904 .83493 .48631 Mtetra
.654 .922 .976 r
.83493 .48631 .84081 .48904 .85623 .48294 .85041 .47984 Mtetra
.673 .918 .975 r
.85041 .47984 .85623 .48294 .8717 .47663 .86593 .47312 Mtetra
.688 .911 .972 r
.86593 .47312 .8717 .47663 .88722 .47015 .88149 .46619 Mtetra
.699 .901 .968 r
.88149 .46619 .88722 .47015 .90279 .46355 .89711 .45912 Mtetra
.707 .89 .964 r
.89711 .45912 .90279 .46355 .91843 .45688 .91278 .45197 Mtetra
.711 .877 .959 r
.91278 .45197 .91843 .45688 .93413 .45019 .92852 .4448 Mtetra
.713 .863 .953 r
.92852 .4448 .93413 .45019 .94991 .44352 .94432 .43766 Mtetra
.712 .85 .948 r
.94432 .43766 .94991 .44352 .96576 .43691 .96021 .4306 Mtetra
.657 .743 .913 r
.3814 .58193 .38938 .58924 .40259 .58542 .39465 .57812 Mtetra
.655 .743 .915 r
.39465 .57812 .40259 .58542 .41587 .58164 .40797 .57435 Mtetra
.652 .744 .917 r
.40797 .57435 .41587 .58164 .42922 .57791 .42136 .57065 Mtetra
.649 .745 .92 r
.42136 .57065 .42922 .57791 .44263 .57425 .43481 .56704 Mtetra
.645 .746 .923 r
.43481 .56704 .44263 .57425 .45611 .57067 .44833 .56353 Mtetra
.64 .747 .927 r
.44833 .56353 .45611 .57067 .46966 .56719 .46192 .56014 Mtetra
.634 .749 .931 r
.46192 .56014 .46966 .56719 .48328 .56382 .47559 .5569 Mtetra
.627 .752 .937 r
.47559 .5569 .48328 .56382 .49698 .56058 .48932 .55381 Mtetra
.619 .755 .943 r
.48932 .55381 .49698 .56058 .51075 .55749 .50314 .55091 Mtetra
.609 .758 .95 r
.50314 .55091 .51075 .55749 .5246 .55456 .51703 .5482 Mtetra
.597 .763 .958 r
.51703 .5482 .5246 .55456 .53853 .55178 .53101 .54569 Mtetra
.584 .767 .966 r
.53101 .54569 .53853 .55178 .55254 .54918 .54508 .54339 Mtetra
.569 .773 .975 r
.54508 .54339 .55254 .54918 .56664 .54673 .55924 .54129 Mtetra
.552 .779 .983 r
.55924 .54129 .56664 .54673 .58083 .54442 .57349 .53936 Mtetra
.532 .785 .99 r
.57349 .53936 .58083 .54442 .59512 .54224 .58784 .53759 Mtetra
.511 .791 .996 r
.58784 .53759 .59512 .54224 .60949 .54016 .60228 .53594 Mtetra
.488 .797 .999 r
.60228 .53594 .60949 .54016 .62397 .53812 .61683 .53436 Mtetra
.464 .803 .999 r
.61683 .53436 .62397 .53812 .63854 .53609 .63148 .53279 Mtetra
.442 .807 .995 r
.63148 .53279 .63854 .53609 .6532 .53401 .64623 .53116 Mtetra
.421 .812 .987 r
.64623 .53116 .6532 .53401 .66795 .53182 .66108 .52941 Mtetra
.405 .816 .977 r
.66108 .52941 .66795 .53182 .6828 .52946 .67601 .52745 Mtetra
.394 .821 .964 r
.67601 .52745 .6828 .52946 .69773 .52686 .69104 .52521 Mtetra
.391 .828 .952 r
.69104 .52521 .69773 .52686 .71274 .52397 .70615 .52262 Mtetra
.396 .837 .941 r
.70615 .52262 .71274 .52397 .72782 .52073 .72133 .51961 Mtetra
.41 .848 .934 r
.72133 .51961 .72782 .52073 .74296 .5171 .73658 .51613 Mtetra
.432 .863 .931 r
.73658 .51613 .74296 .5171 .75817 .51304 .75189 .51214 Mtetra
.46 .879 .931 r
.75189 .51214 .75817 .51304 .77344 .50855 .76724 .50763 Mtetra
.495 .896 .935 r
.76724 .50763 .77344 .50855 .78875 .50361 .78264 .50257 Mtetra
.532 .912 .942 r
.78264 .50257 .78875 .50361 .8041 .49824 .79808 .49699 Mtetra
.569 .925 .949 r
.79808 .49699 .8041 .49824 .8195 .49246 .81355 .49093 Mtetra
.605 .934 .956 r
.81355 .49093 .8195 .49246 .83493 .48631 .82905 .48442 Mtetra
.638 .939 .962 r
.82905 .48442 .83493 .48631 .85041 .47984 .84459 .47753 Mtetra
.665 .939 .966 r
.84459 .47753 .85041 .47984 .86593 .47312 .86016 .47032 Mtetra
.687 .934 .967 r
.86016 .47032 .86593 .47312 .88149 .46619 .87577 .46288 Mtetra
.703 .924 .966 r
.87577 .46288 .88149 .46619 .89711 .45912 .89143 .45527 Mtetra
.714 .912 .964 r
.89143 .45527 .89711 .45912 .91278 .45197 .90713 .44758 Mtetra
.72 .898 .96 r
.90713 .44758 .91278 .45197 .92852 .4448 .9229 .43986 Mtetra
.722 .883 .955 r
.9229 .43986 .92852 .4448 .94432 .43766 .93873 .43219 Mtetra
.722 .867 .95 r
.93873 .43219 .94432 .43766 .96021 .4306 .95464 .42461 Mtetra
.655 .743 .914 r
.37334 .57456 .3814 .58193 .39465 .57812 .38664 .57076 Mtetra
.653 .743 .916 r
.38664 .57076 .39465 .57812 .40797 .57435 .39999 .56702 Mtetra
.65 .744 .918 r
.39999 .56702 .40797 .57435 .42136 .57065 .41342 .56336 Mtetra
.646 .745 .921 r
.41342 .56336 .42136 .57065 .43481 .56704 .42691 .5598 Mtetra
.641 .746 .925 r
.42691 .5598 .43481 .56704 .44833 .56353 .44047 .55638 Mtetra
.635 .748 .93 r
.44047 .55638 .44833 .56353 .46192 .56014 .4541 .5531 Mtetra
.627 .75 .935 r
.4541 .5531 .46192 .56014 .47559 .5569 .46781 .55 Mtetra
.619 .752 .941 r
.46781 .55 .47559 .5569 .48932 .55381 .48159 .5471 Mtetra
.608 .755 .949 r
.48159 .5471 .48932 .55381 .50314 .55091 .49545 .54442 Mtetra
.596 .759 .956 r
.49545 .54442 .50314 .55091 .51703 .5482 .50939 .54197 Mtetra
.581 .763 .965 r
.50939 .54197 .51703 .5482 .53101 .54569 .52342 .53977 Mtetra
.563 .767 .974 r
.52342 .53977 .53101 .54569 .54508 .54339 .53754 .53782 Mtetra
.542 .772 .983 r
.53754 .53782 .54508 .54339 .55924 .54129 .55175 .53611 Mtetra
.519 .777 .991 r
.55175 .53611 .55924 .54129 .57349 .53936 .56607 .53462 Mtetra
.491 .781 .996 r
.56607 .53462 .57349 .53936 .58784 .53759 .58048 .53332 Mtetra
.461 .784 .999 r
.58048 .53332 .58784 .53759 .60228 .53594 .595 .53217 Mtetra
.427 .786 .996 r
.595 .53217 .60228 .53594 .61683 .53436 .60962 .53111 Mtetra
.393 .786 .988 r
.60962 .53111 .61683 .53436 .63148 .53279 .62436 .53007 Mtetra
.359 .784 .974 r
.62436 .53007 .63148 .53279 .64623 .53116 .6392 .52897 Mtetra
.329 .78 .954 r
.6392 .52897 .64623 .53116 .66108 .52941 .65414 .52772 Mtetra
.305 .777 .931 r
.65414 .52772 .66108 .52941 .67601 .52745 .66917 .52623 Mtetra
.289 .776 .907 r
.66917 .52623 .67601 .52745 .69104 .52521 .6843 .52441 Mtetra
.284 .779 .886 r
.6843 .52441 .69104 .52521 .70615 .52262 .69952 .52217 Mtetra
.29 .786 .869 r
.69952 .52217 .70615 .52262 .72133 .51961 .71481 .51943 Mtetra
.308 .799 .859 r
.71481 .51943 .72133 .51961 .73658 .51613 .73016 .51613 Mtetra
.336 .818 .856 r
.73016 .51613 .73658 .51613 .75189 .51214 .74557 .51223 Mtetra
.374 .841 .861 r
.74557 .51223 .75189 .51214 .76724 .50763 .76103 .50768 Mtetra
.42 .866 .871 r
.76103 .50768 .76724 .50763 .78264 .50257 .77652 .5025 Mtetra
.47 .892 .886 r
.77652 .5025 .78264 .50257 .79808 .49699 .79205 .4967 Mtetra
.521 .916 .903 r
.79205 .4967 .79808 .49699 .81355 .49093 .8076 .49031 Mtetra
.57 .935 .92 r
.8076 .49031 .81355 .49093 .82905 .48442 .82317 .4834 Mtetra
.614 .947 .934 r
.82317 .4834 .82905 .48442 .84459 .47753 .83877 .47603 Mtetra
.652 .953 .946 r
.83877 .47603 .84459 .47753 .86016 .47032 .8544 .46828 Mtetra
.682 .952 .954 r
.8544 .46828 .86016 .47032 .87577 .46288 .87005 .46026 Mtetra
.705 .945 .958 r
.87005 .46026 .87577 .46288 .89143 .45527 .88574 .45204 Mtetra
.72 .934 .959 r
.88574 .45204 .89143 .45527 .90713 .44758 .90148 .44373 Mtetra
.729 .92 .957 r
.90148 .44373 .90713 .44758 .9229 .43986 .91727 .4354 Mtetra
.733 .903 .954 r
.91727 .4354 .9229 .43986 .93873 .43219 .93313 .42712 Mtetra
.734 .886 .95 r
.93313 .42712 .93873 .43219 .95464 .42461 .94906 .41896 Mtetra
.654 .743 .915 r
.36521 .56714 .37334 .57456 .38664 .57076 .37854 .56335 Mtetra
.651 .743 .917 r
.37854 .56335 .38664 .57076 .39999 .56702 .39194 .55964 Mtetra
.647 .744 .92 r
.39194 .55964 .39999 .56702 .41342 .56336 .4054 .55603 Mtetra
.642 .745 .924 r
.4054 .55603 .41342 .56336 .42691 .5598 .41894 .55255 Mtetra
.636 .746 .928 r
.41894 .55255 .42691 .5598 .44047 .55638 .43254 .54922 Mtetra
.629 .748 .933 r
.43254 .54922 .44047 .55638 .4541 .5531 .44621 .54607 Mtetra
.62 .75 .939 r
.44621 .54607 .4541 .5531 .46781 .55 .45995 .54314 Mtetra
.609 .752 .946 r
.45995 .54314 .46781 .55 .48159 .5471 .47378 .54044 Mtetra
.596 .755 .954 r
.47378 .54044 .48159 .5471 .49545 .54442 .48768 .53801 Mtetra
.58 .758 .963 r
.48768 .53801 .49545 .54442 .50939 .54197 .50167 .53586 Mtetra
.561 .762 .972 r
.50167 .53586 .50939 .54197 .52342 .53977 .51575 .53401 Mtetra
.537 .765 .981 r
.51575 .53401 .52342 .53977 .53754 .53782 .52992 .53245 Mtetra
.51 .768 .989 r
.52992 .53245 .53754 .53782 .55175 .53611 .54419 .53119 Mtetra
.477 .77 .995 r
.54419 .53119 .55175 .53611 .56607 .53462 .55856 .5302 Mtetra
.439 .771 .997 r
.55856 .5302 .56607 .53462 .58048 .53332 .57304 .52944 Mtetra
.397 .768 .993 r
.57304 .52944 .58048 .53332 .595 .53217 .58763 .52886 Mtetra
.35 .762 .98 r
.58763 .52886 .595 .53217 .60962 .53111 .60234 .52839 Mtetra
.302 .752 .959 r
.60234 .52839 .60962 .53111 .62436 .53007 .61716 .52795 Mtetra
.256 .739 .929 r
.61716 .52795 .62436 .53007 .6392 .52897 .63209 .52744 Mtetra
.216 .724 .893 r
.63209 .52744 .6392 .52897 .65414 .52772 .64713 .52676 Mtetra
.185 .712 .855 r
.64713 .52676 .65414 .52772 .66917 .52623 .66227 .52581 Mtetra
.166 .703 .819 r
.66227 .52581 .66917 .52623 .6843 .52441 .67751 .52446 Mtetra
.161 .701 .789 r
.67751 .52446 .6843 .52441 .69952 .52217 .69284 .52262 Mtetra
.17 .708 .767 r
.69284 .52262 .69952 .52217 .71481 .51943 .70824 .5202 Mtetra
.193 .723 .756 r
.70824 .5202 .71481 .51943 .73016 .51613 .72371 .51711 Mtetra
.229 .747 .755 r
.72371 .51711 .73016 .51613 .74557 .51223 .73923 .5133 Mtetra
.277 .778 .765 r
.73923 .5133 .74557 .51223 .76103 .50768 .75479 .50874 Mtetra
.334 .814 .784 r
.75479 .50874 .76103 .50768 .77652 .5025 .77038 .50342 Mtetra
.397 .852 .809 r
.77038 .50342 .77652 .5025 .79205 .4967 .786 .49737 Mtetra
.462 .889 .837 r
.786 .49737 .79205 .4967 .8076 .49031 .80163 .49062 Mtetra
.526 .921 .866 r
.80163 .49062 .8076 .49031 .82317 .4834 .81728 .48325 Mtetra
.585 .945 .893 r
.81728 .48325 .82317 .4834 .83877 .47603 .83294 .47535 Mtetra
.635 .96 .915 r
.83294 .47535 .83877 .47603 .8544 .46828 .84862 .467 Mtetra
.676 .965 .931 r
.84862 .467 .8544 .46828 .87005 .46026 .86432 .45833 Mtetra
.706 .963 .942 r
.86432 .45833 .87005 .46026 .88574 .45204 .88005 .44943 Mtetra
.727 .953 .948 r
.88005 .44943 .88574 .45204 .90148 .44373 .89582 .44042 Mtetra
.739 .939 .951 r
.89582 .44042 .90148 .44373 .91727 .4354 .91164 .4314 Mtetra
.745 .922 .95 r
.91164 .4314 .91727 .4354 .93313 .42712 .92752 .42245 Mtetra
.746 .904 .948 r
.92752 .42245 .93313 .42712 .94906 .41896 .94347 .41365 Mtetra
.652 .743 .916 r
.35701 .55967 .36521 .56714 .37854 .56335 .37038 .5559 Mtetra
.649 .743 .918 r
.37038 .5559 .37854 .56335 .39194 .55964 .38381 .55222 Mtetra
.644 .744 .922 r
.38381 .55222 .39194 .55964 .4054 .55603 .39731 .54867 Mtetra
.638 .745 .926 r
.39731 .54867 .4054 .55603 .41894 .55255 .41088 .54526 Mtetra
.631 .746 .93 r
.41088 .54526 .41894 .55255 .43254 .54922 .42452 .54205 Mtetra
.622 .747 .936 r
.42452 .54205 .43254 .54922 .44621 .54607 .43823 .53904 Mtetra
.612 .749 .943 r
.43823 .53904 .44621 .54607 .45995 .54314 .45202 .5363 Mtetra
.598 .751 .951 r
.45202 .5363 .45995 .54314 .47378 .54044 .46588 .53383 Mtetra
.582 .754 .96 r
.46588 .53383 .47378 .54044 .48768 .53801 .47983 .53168 Mtetra
.561 .756 .969 r
.47983 .53168 .48768 .53801 .50167 .53586 .49386 .52986 Mtetra
.537 .759 .978 r
.49386 .52986 .50167 .53586 .51575 .53401 .50799 .5284 Mtetra
.507 .76 .987 r
.50799 .5284 .51575 .53401 .52992 .53245 .52221 .52729 Mtetra
.47 .76 .994 r
.52221 .52729 .52992 .53245 .54419 .53119 .53653 .52652 Mtetra
.427 .758 .995 r
.53653 .52652 .54419 .53119 .55856 .5302 .55097 .52608 Mtetra
.376 .751 .99 r
.55097 .52608 .55856 .5302 .57304 .52944 .56552 .52592 Mtetra
.318 .739 .975 r
.56552 .52592 .57304 .52944 .58763 .52886 .58018 .52597 Mtetra
.257 .721 .948 r
.58018 .52597 .58763 .52886 .60234 .52839 .59497 .52616 Mtetra
.195 .698 .909 r
.59497 .52616 .60234 .52839 .61716 .52795 .60988 .52639 Mtetra
.138 .671 .86 r
.60988 .52639 .61716 .52795 .63209 .52744 .6249 .52655 Mtetra
.091 .645 .807 r
.6249 .52655 .63209 .52744 .64713 .52676 .64004 .52652 Mtetra
.057 .623 .754 r
.64004 .52652 .64713 .52676 .66227 .52581 .6553 .52616 Mtetra
.039 .608 .708 r
.6553 .52616 .66227 .52581 .67751 .52446 .67065 .52535 Mtetra
0 0 0 r
.67065 .52535 .67751 .52446 .69284 .52262 .68609 .52396 Mtetra
.68609 .52396 .69284 .52262 .70824 .5202 .70162 .52189 Mtetra
.70162 .52189 .70824 .5202 .72371 .51711 .7172 .51904 Mtetra
.7172 .51904 .72371 .51711 .73923 .5133 .73284 .51534 Mtetra
.73284 .51534 .73923 .5133 .75479 .50874 .74851 .51077 Mtetra
.248 .748 .685 r
.74851 .51077 .75479 .50874 .77038 .50342 .76421 .50531 Mtetra
.322 .798 .72 r
.76421 .50531 .77038 .50342 .786 .49737 .77993 .49898 Mtetra
.401 .849 .76 r
.77993 .49898 .786 .49737 .80163 .49062 .79565 .49184 Mtetra
.479 .894 .802 r
.79565 .49184 .80163 .49062 .81728 .48325 .81138 .48397 Mtetra
.552 .931 .841 r
.81138 .48397 .81728 .48325 .83294 .47535 .8271 .47547 Mtetra
.616 .958 .874 r
.8271 .47547 .83294 .47535 .84862 .467 .84284 .46646 Mtetra
.667 .972 .901 r
.84284 .46646 .84862 .467 .86432 .45833 .85858 .45707 Mtetra
.706 .975 .92 r
.85858 .45707 .86432 .45833 .88005 .44943 .87435 .44742 Mtetra
.733 .969 .933 r
.87435 .44742 .88005 .44943 .89582 .44042 .89015 .43765 Mtetra
.749 .956 .94 r
.89015 .43765 .89582 .44042 .91164 .4314 .90599 .42786 Mtetra
.758 .94 .943 r
.90599 .42786 .91164 .4314 .92752 .42245 .92188 .41817 Mtetra
.759 .92 .943 r
.92188 .41817 .92752 .42245 .94347 .41365 .93785 .40866 Mtetra
.65 .742 .917 r
.34872 .55214 .35701 .55967 .37038 .5559 .36213 .54839 Mtetra
.646 .743 .92 r
.36213 .54839 .37038 .5559 .38381 .55222 .3756 .54475 Mtetra
.641 .744 .923 r
.3756 .54475 .38381 .55222 .39731 .54867 .38914 .54126 Mtetra
.634 .744 .928 r
.38914 .54126 .39731 .54867 .41088 .54526 .40275 .53795 Mtetra
.626 .745 .933 r
.40275 .53795 .41088 .54526 .42452 .54205 .41643 .53485 Mtetra
.615 .747 .939 r
.41643 .53485 .42452 .54205 .43823 .53904 .43018 .53201 Mtetra
.602 .748 .947 r
.43018 .53201 .43823 .53904 .45202 .5363 .444 .52947 Mtetra
.586 .75 .955 r
.444 .52947 .45202 .5363 .46588 .53383 .45791 .52726 Mtetra
.565 .751 .965 r
.45791 .52726 .46588 .53383 .47983 .53168 .47189 .52541 Mtetra
.54 .753 .974 r
.47189 .52541 .47983 .53168 .49386 .52986 .48597 .52396 Mtetra
.509 .753 .984 r
.48597 .52396 .49386 .52986 .50799 .5284 .50014 .52292 Mtetra
.47 .751 .991 r
.50014 .52292 .50799 .5284 .52221 .52729 .51441 .5223 Mtetra
.423 .747 .994 r
.51441 .5223 .52221 .52729 .53653 .52652 .52879 .52208 Mtetra
.367 .737 .989 r
.52879 .52208 .53653 .52652 .55097 .52608 .54329 .52224 Mtetra
.301 .721 .973 r
.54329 .52224 .55097 .52608 .56552 .52592 .5579 .52273 Mtetra
.228 .696 .943 r
.5579 .52273 .56552 .52592 .58018 .52597 .57264 .52348 Mtetra
.151 .663 .897 r
.57264 .52348 .58018 .52597 .59497 .52616 .58751 .52439 Mtetra
.079 .625 .838 r
.58751 .52439 .59497 .52616 .60988 .52639 .60251 .52536 Mtetra
.015 .585 .771 r
.60251 .52536 .60988 .52639 .6249 .52655 .61763 .52625 Mtetra
.033 0 0 r
.61763 .52625 .6249 .52655 .64004 .52652 .63288 .52692 Mtetra
.064 0 0 r
.63288 .52692 .64004 .52652 .6553 .52616 .64824 .52723 Mtetra
.078 0 0 r
.64824 .52723 .6553 .52616 .67065 .52535 .66371 .527 Mtetra
.074 0 0 r
.66371 .527 .67065 .52535 .68609 .52396 .67928 .52612 Mtetra
.053 0 0 r
.67928 .52612 .68609 .52396 .70162 .52189 .69493 .52444 Mtetra
.018 0 0 r
.69493 .52444 .70162 .52189 .7172 .51904 .71064 .52186 Mtetra
0 0 0 r
.71064 .52186 .7172 .51904 .73284 .51534 .7264 .51829 Mtetra
.7264 .51829 .73284 .51534 .74851 .51077 .74219 .51371 Mtetra
.74219 .51371 .74851 .51077 .76421 .50531 .758 .50809 Mtetra
.758 .50809 .76421 .50531 .77993 .49898 .77382 .50146 Mtetra
.346 .804 .683 r
.77382 .50146 .77993 .49898 .79565 .49184 .78963 .49389 Mtetra
.437 .862 .735 r
.78963 .49389 .79565 .49184 .81138 .48397 .80544 .48548 Mtetra
.523 .912 .785 r
.80544 .48548 .81138 .48397 .8271 .47547 .82124 .47633 Mtetra
.598 .949 .83 r
.82124 .47633 .8271 .47547 .84284 .46646 .83703 .4666 Mtetra
.66 .973 .867 r
.83703 .4666 .84284 .46646 .85858 .45707 .85282 .45642 Mtetra
.708 .982 .894 r
.85282 .45642 .85858 .45707 .87435 .44742 .86862 .44596 Mtetra
.74 .981 .914 r
.86862 .44596 .87435 .44742 .89015 .43765 .88445 .43535 Mtetra
.761 .97 .926 r
.88445 .43535 .89015 .43765 .90599 .42786 .90031 .42474 Mtetra
.771 .954 .933 r
.90031 .42474 .90599 .42786 .92188 .41817 .91622 .41424 Mtetra
.774 .935 .935 r
.91622 .41424 .92188 .41817 .93785 .40866 .9322 .40396 Mtetra
.648 .742 .918 r
.34036 .54454 .34872 .55214 .36213 .54839 .3538 .54082 Mtetra
.644 .743 .921 r
.3538 .54082 .36213 .54839 .3756 .54475 .36731 .53723 Mtetra
.637 .743 .925 r
.36731 .53723 .3756 .54475 .38914 .54126 .38089 .53381 Mtetra
.63 .744 .93 r
.38089 .53381 .38914 .54126 .40275 .53795 .39454 .5306 Mtetra
.62 .745 .936 r
.39454 .5306 .40275 .53795 .41643 .53485 .40825 .52764 Mtetra
.607 .745 .943 r
.40825 .52764 .41643 .53485 .43018 .53201 .42204 .52497 Mtetra
.592 .746 .951 r
.42204 .52497 .43018 .53201 .444 .52947 .4359 .52265 Mtetra
.572 .747 .96 r
.4359 .52265 .444 .52947 .45791 .52726 .44984 .52071 Mtetra
.547 .748 .969 r
.44984 .52071 .45791 .52726 .47189 .52541 .46387 .51919 Mtetra
.516 .747 .979 r
.46387 .51919 .47189 .52541 .48597 .52396 .47799 .51813 Mtetra
.478 .744 .987 r
.47799 .51813 .48597 .52396 .50014 .52292 .4922 .51754 Mtetra
.429 .738 .991 r
.4922 .51754 .50014 .52292 .51441 .5223 .50652 .51744 Mtetra
.37 .727 .989 r
.50652 .51744 .51441 .5223 .52879 .52208 .52096 .51782 Mtetra
.299 .708 .975 r
.52096 .51782 .52879 .52208 .54329 .52224 .53551 .51863 Mtetra
.217 .679 .945 r
.53551 .51863 .54329 .52224 .5579 .52273 .55019 .51982 Mtetra
.129 .64 .897 r
.55019 .51982 .5579 .52273 .57264 .52348 .565 .52132 Mtetra
.042 .592 .832 r
.565 .52132 .57264 .52348 .58751 .52439 .57995 .52302 Mtetra
0 .541 .755 r
.57995 .52302 .58751 .52439 .60251 .52536 .59504 .52478 Mtetra
.1 0 0 r
.59504 .52478 .60251 .52536 .61763 .52625 .61026 .52646 Mtetra
.144 0 0 r
.61026 .52646 .61763 .52625 .63288 .52692 .62562 .5279 Mtetra
.169 0 0 r
.62562 .5279 .63288 .52692 .64824 .52723 .6411 .52891 Mtetra
.176 0 0 r
.6411 .52891 .64824 .52723 .66371 .527 .65669 .52934 Mtetra
.165 0 0 r
.65669 .52934 .66371 .527 .67928 .52612 .67238 .529 Mtetra
.138 0 0 r
.67238 .529 .67928 .52612 .69493 .52444 .68816 .52774 Mtetra
.096 0 0 r
.68816 .52774 .69493 .52444 .71064 .52186 .704 .52546 Mtetra
.04 0 0 r
.704 .52546 .71064 .52186 .7264 .51829 .71989 .52204 Mtetra
0 0 0 r
.71989 .52204 .7264 .51829 .74219 .51371 .73581 .51744 Mtetra
.73581 .51744 .74219 .51371 .758 .50809 .75173 .51166 Mtetra
.75173 .51166 .758 .50809 .77382 .50146 .76766 .50471 Mtetra
.76766 .50471 .77382 .50146 .78963 .49389 .78357 .49668 Mtetra
.406 .834 .677 r
.78357 .49668 .78963 .49389 .80544 .48548 .79946 .48768 Mtetra
.502 .894 .736 r
.79946 .48768 .80544 .48548 .82124 .47633 .81533 .47784 Mtetra
.588 .94 .789 r
.81533 .47784 .82124 .47633 .83703 .4666 .83118 .46733 Mtetra
.658 .971 .833 r
.83118 .46733 .83703 .4666 .85282 .45642 .84702 .45631 Mtetra
.712 .986 .867 r
.84702 .45631 .85282 .45642 .86862 .44596 .86286 .44497 Mtetra
.75 .989 .892 r
.86286 .44497 .86862 .44596 .88445 .43535 .87872 .43347 Mtetra
.773 .981 .909 r
.87872 .43347 .88445 .43535 .90031 .42474 .8946 .42197 Mtetra
.785 .966 .92 r
.8946 .42197 .90031 .42474 .91622 .41424 .91053 .4106 Mtetra
.789 .947 .926 r
.91053 .4106 .91622 .41424 .9322 .40396 .92652 .39949 Mtetra
.646 .742 .919 r
.33191 .53688 .34036 .54454 .3538 .54082 .3454 .53319 Mtetra
.641 .742 .922 r
.3454 .53319 .3538 .54082 .36731 .53723 .35895 .52965 Mtetra
.634 .742 .927 r
.35895 .52965 .36731 .53723 .38089 .53381 .37256 .5263 Mtetra
.625 .743 .932 r
.37256 .5263 .38089 .53381 .39454 .5306 .38624 .5232 Mtetra
.613 .743 .938 r
.38624 .5232 .39454 .5306 .40825 .52764 .39999 .52038 Mtetra
.599 .744 .946 r
.39999 .52038 .40825 .52764 .42204 .52497 .41382 .5179 Mtetra
.58 .744 .954 r
.41382 .5179 .42204 .52497 .4359 .52265 .42771 .5158 Mtetra
.557 .744 .964 r
.42771 .5158 .4359 .52265 .44984 .52071 .44169 .51415 Mtetra
.528 .742 .973 r
.44169 .51415 .44984 .52071 .46387 .51919 .45576 .51298 Mtetra
.49 .739 .982 r
.45576 .51298 .46387 .51919 .47799 .51813 .46992 .51234 Mtetra
.443 .732 .988 r
.46992 .51234 .47799 .51813 .4922 .51754 .48418 .51223 Mtetra
.384 .721 .989 r
.48418 .51223 .4922 .51754 .50652 .51744 .49854 .51268 Mtetra
.312 .701 .979 r
.49854 .51268 .50652 .51744 .52096 .51782 .51303 .51368 Mtetra
.226 .671 .953 r
.51303 .51368 .52096 .51782 .53551 .51863 .52764 .51517 Mtetra
.13 .628 .908 r
.52764 .51517 .53551 .51863 .55019 .51982 .54238 .51711 Mtetra
.031 .574 .842 r
.54238 .51711 .55019 .51982 .565 .52132 .55726 .51941 Mtetra
0 .514 .761 r
.55726 .51941 .565 .52132 .57995 .52302 .57229 .52193 Mtetra
.14 0 0 r
.57229 .52193 .57995 .52302 .59504 .52478 .58747 .52454 Mtetra
.199 0 0 r
.58747 .52454 .59504 .52478 .61026 .52646 .60279 .52706 Mtetra
.236 0 0 r
.60279 .52706 .61026 .52646 .62562 .5279 .61825 .52931 Mtetra
.254 0 0 r
.61825 .52931 .62562 .5279 .6411 .52891 .63385 .53109 Mtetra
.253 0 0 r
.63385 .53109 .6411 .52891 .65669 .52934 .64957 .5322 Mtetra
.235 0 0 r
.64957 .5322 .65669 .52934 .67238 .529 .66539 .53244 Mtetra
.202 0 0 r
.66539 .53244 .67238 .529 .68816 .52774 .6813 .53165 Mtetra
.154 0 0 r
.6813 .53165 .68816 .52774 .704 .52546 .69728 .52967 Mtetra
.092 0 0 r
.69728 .52967 .704 .52546 .71989 .52204 .7133 .52642 Mtetra
.015 0 0 r
.7133 .52642 .71989 .52204 .73581 .51744 .72934 .52181 Mtetra
0 0 0 r
.72934 .52181 .73581 .51744 .75173 .51166 .74539 .51585 Mtetra
.74539 .51585 .75173 .51166 .76766 .50471 .76143 .50857 Mtetra
.76143 .50857 .76766 .50471 .78357 .49668 .77744 .50006 Mtetra
.392 .815 .635 r
.77744 .50006 .78357 .49668 .79946 .48768 .79342 .49044 Mtetra
.497 .882 .699 r
.79342 .49044 .79946 .48768 .81533 .47784 .80936 .47986 Mtetra
.589 .935 .757 r
.80936 .47986 .81533 .47784 .83118 .46733 .82528 .46853 Mtetra
.665 .97 .805 r
.82528 .46853 .83118 .46733 .84702 .45631 .84117 .45662 Mtetra
.723 .989 .844 r
.84117 .45662 .84702 .45631 .86286 .44497 .85705 .44435 Mtetra
.763 .994 .872 r
.85705 .44435 .86286 .44497 .87872 .43347 .87293 .4319 Mtetra
.788 .988 .892 r
.87293 .4319 .87872 .43347 .8946 .42197 .88884 .41946 Mtetra
.801 .974 .906 r
.88884 .41946 .8946 .42197 .91053 .4106 .90478 .40718 Mtetra
.804 .955 .914 r
.90478 .40718 .91053 .4106 .92652 .39949 .92078 .3952 Mtetra
.644 .741 .92 r
.32339 .52916 .33191 .53688 .3454 .53319 .33691 .52549 Mtetra
.638 .742 .923 r
.33691 .52549 .3454 .53319 .35895 .52965 .3505 .52201 Mtetra
.63 .742 .928 r
.3505 .52201 .35895 .52965 .37256 .5263 .36415 .51874 Mtetra
.62 .742 .934 r
.36415 .51874 .37256 .5263 .38624 .5232 .37786 .51574 Mtetra
.606 .742 .94 r
.37786 .51574 .38624 .5232 .39999 .52038 .39165 .51307 Mtetra
.59 .741 .948 r
.39165 .51307 .39999 .52038 .41382 .5179 .40551 .51077 Mtetra
.568 .74 .957 r
.40551 .51077 .41382 .5179 .42771 .5158 .41944 .50892 Mtetra
.541 .739 .967 r
.41944 .50892 .42771 .5158 .44169 .51415 .43346 .50757 Mtetra
.507 .735 .976 r
.43346 .50757 .44169 .51415 .45576 .51298 .44756 .50676 Mtetra
.463 .729 .984 r
.44756 .50676 .45576 .51298 .46992 .51234 .46175 .50654 Mtetra
.406 .717 .987 r
.46175 .50654 .46992 .51234 .48418 .51223 .47605 .50693 Mtetra
.336 .699 .982 r
.47605 .50693 .48418 .51223 .49854 .51268 .49046 .50795 Mtetra
.251 .669 .964 r
.49046 .50795 .49854 .51268 .51303 .51368 .505 .50959 Mtetra
.152 .627 .926 r
.505 .50959 .51303 .51368 .52764 .51517 .51966 .5118 Mtetra
.046 .571 .865 r
.51966 .5118 .52764 .51517 .54238 .51711 .53446 .51451 Mtetra
0 .506 .785 r
.53446 .51451 .54238 .51711 .55726 .51941 .54942 .51763 Mtetra
0 .439 .692 r
.54942 .51763 .55726 .51941 .57229 .52193 .56452 .52101 Mtetra
.227 0 0 r
.56452 .52101 .57229 .52193 .58747 .52454 .57979 .5245 Mtetra
.279 0 0 r
.57979 .5245 .58747 .52454 .60279 .52706 .59521 .5279 Mtetra
.309 0 0 r
.59521 .5279 .60279 .52706 .61825 .52931 .61078 .531 Mtetra
.319 0 0 r
.61078 .531 .61825 .52931 .63385 .53109 .62649 .53358 Mtetra
.311 0 0 r
.62649 .53358 .63385 .53109 .64957 .5322 .64233 .5354 Mtetra
.288 0 0 r
.64233 .5354 .64957 .5322 .66539 .53244 .65829 .53625 Mtetra
.249 0 0 r
.65829 .53625 .66539 .53244 .6813 .53165 .67433 .53594 Mtetra
.194 0 0 r
.67433 .53594 .6813 .53165 .69728 .52967 .69044 .5343 Mtetra
.125 0 0 r
.69044 .5343 .69728 .52967 .7133 .52642 .7066 .53121 Mtetra
.041 0 0 r
.7066 .53121 .7133 .52642 .72934 .52181 .72278 .52661 Mtetra
0 0 0 r
.72278 .52661 .72934 .52181 .74539 .51585 .73895 .52047 Mtetra
.73895 .52047 .74539 .51585 .76143 .50857 .7551 .51284 Mtetra
.7551 .51284 .76143 .50857 .77744 .50006 .77122 .50382 Mtetra
.399 .812 .615 r
.77122 .50382 .77744 .50006 .79342 .49044 .78729 .49355 Mtetra
.508 .883 .68 r
.78729 .49355 .79342 .49044 .80936 .47986 .80332 .48221 Mtetra
.604 .937 .739 r
.80332 .48221 .80936 .47986 .82528 .46853 .8193 .47001 Mtetra
.682 .973 .788 r
.8193 .47001 .82528 .46853 .84117 .45662 .83525 .45718 Mtetra
.741 .992 .826 r
.83525 .45718 .84117 .45662 .85705 .44435 .85117 .44394 Mtetra
.781 .997 .856 r
.85117 .44394 .85705 .44435 .87293 .4319 .86708 .43051 Mtetra
.806 .991 .877 r
.86708 .43051 .87293 .4319 .88884 .41946 .88301 .4171 Mtetra
.818 .978 .892 r
.88301 .4171 .88884 .41946 .90478 .40718 .89897 .40388 Mtetra
.82 .96 .902 r
.89897 .40388 .90478 .40718 .92078 .3952 .91499 .39099 Mtetra
.642 .741 .921 r
.31478 .52136 .32339 .52916 .33691 .52549 .32834 .51772 Mtetra
.635 .741 .925 r
.32834 .51772 .33691 .52549 .3505 .52201 .34196 .51429 Mtetra
.626 .741 .929 r
.34196 .51429 .3505 .52201 .36415 .51874 .35565 .5111 Mtetra
.614 .74 .935 r
.35565 .5111 .36415 .51874 .37786 .51574 .3694 .50821 Mtetra
.6 .74 .942 r
.3694 .50821 .37786 .51574 .39165 .51307 .38322 .50568 Mtetra
.581 .738 .951 r
.38322 .50568 .39165 .51307 .40551 .51077 .39712 .50358 Mtetra
.556 .736 .96 r
.39712 .50358 .40551 .51077 .41944 .50892 .41108 .50197 Mtetra
.525 .733 .969 r
.41108 .50197 .41944 .50892 .43346 .50757 .42513 .50092 Mtetra
.485 .727 .978 r
.42513 .50092 .43346 .50757 .44756 .50676 .43927 .50047 Mtetra
.434 .716 .984 r
.43927 .50047 .44756 .50676 .46175 .50654 .4535 .50068 Mtetra
.369 .699 .984 r
.4535 .50068 .46175 .50654 .47605 .50693 .46784 .50158 Mtetra
.289 .673 .973 r
.46784 .50158 .47605 .50693 .49046 .50795 .48229 .50318 Mtetra
.192 .634 .945 r
.48229 .50318 .49046 .50795 .505 .50959 .49687 .50547 Mtetra
.083 .581 .895 r
.49687 .50547 .505 .50959 .51966 .5118 .51158 .5084 Mtetra
0 .515 .823 r
.51158 .5084 .51966 .5118 .53446 .51451 .52644 .5119 Mtetra
0 .442 .732 r
.52644 .5119 .53446 .51451 .54942 .51763 .54146 .51585 Mtetra
.228 0 0 r
.54146 .51585 .54942 .51763 .56452 .52101 .55664 .52011 Mtetra
.296 0 0 r
.55664 .52011 .56452 .52101 .57979 .5245 .57199 .5245 Mtetra
.34 0 0 r
.57199 .5245 .57979 .5245 .59521 .5279 .5875 .52879 Mtetra
.363 0 0 r
.5875 .52879 .59521 .5279 .61078 .531 .60318 .53276 Mtetra
.367 0 0 r
.60318 .53276 .61078 .531 .62649 .53358 .61901 .53615 Mtetra
.354 0 0 r
.61901 .53615 .62649 .53358 .64233 .5354 .63497 .53871 Mtetra
.324 0 0 r
.63497 .53871 .64233 .5354 .65829 .53625 .65106 .5402 Mtetra
.279 0 0 r
.65106 .5402 .65829 .53625 .67433 .53594 .66724 .54038 Mtetra
.218 0 0 r
.66724 .54038 .67433 .53594 .69044 .5343 .68349 .53908 Mtetra
.141 0 0 r
.68349 .53908 .69044 .5343 .7066 .53121 .69978 .53617 Mtetra
.048 0 0 r
.69978 .53617 .7066 .53121 .72278 .52661 .71609 .53156 Mtetra
0 0 0 r
.71609 .53156 .72278 .52661 .73895 .52047 .73239 .52524 Mtetra
.73239 .52524 .73895 .52047 .7551 .51284 .74867 .51726 Mtetra
.74867 .51726 .7551 .51284 .77122 .50382 .76489 .50772 Mtetra
.428 .827 .619 r
.76489 .50772 .77122 .50382 .78729 .49355 .78106 .49678 Mtetra
.54 .897 .682 r
.78106 .49678 .78729 .49355 .80332 .48221 .79717 .48466 Mtetra
.635 .947 .737 r
.79717 .48466 .80332 .48221 .8193 .47001 .81322 .47159 Mtetra
.71 .98 .782 r
.81322 .47159 .8193 .47001 .83525 .45718 .82923 .45781 Mtetra
.766 .996 .817 r
.82923 .45781 .83525 .45718 .85117 .44394 .84519 .44358 Mtetra
.803 .999 .844 r
.84519 .44358 .85117 .44394 .86708 .43051 .86114 .42915 Mtetra
.825 .992 .864 r
.86114 .42915 .86708 .43051 .88301 .4171 .8771 .41474 Mtetra
.835 .979 .879 r
.8771 .41474 .88301 .4171 .89897 .40388 .89308 .40056 Mtetra
.836 .961 .89 r
.89308 .40056 .89897 .40388 .91499 .39099 .90911 .38676 Mtetra
.64 .74 .921 r
.3061 .51348 .31478 .52136 .32834 .51772 .31969 .50987 Mtetra
.632 .74 .926 r
.31969 .50987 .32834 .51772 .34196 .51429 .33335 .50649 Mtetra
.622 .739 .931 r
.33335 .50649 .34196 .51429 .35565 .5111 .34707 .50337 Mtetra
.609 .738 .937 r
.34707 .50337 .35565 .5111 .3694 .50821 .36086 .50059 Mtetra
.593 .737 .944 r
.36086 .50059 .3694 .50821 .38322 .50568 .37471 .49821 Mtetra
.572 .735 .952 r
.37471 .49821 .38322 .50568 .39712 .50358 .38864 .4963 Mtetra
.544 .731 .961 r
.38864 .4963 .39712 .50358 .41108 .50197 .40264 .49492 Mtetra
.509 .726 .971 r
.40264 .49492 .41108 .50197 .42513 .50092 .41672 .49416 Mtetra
.464 .717 .978 r
.41672 .49416 .42513 .50092 .43927 .50047 .43089 .49407 Mtetra
.407 .702 .982 r
.43089 .49407 .43927 .50047 .4535 .50068 .44515 .49471 Mtetra
.334 .68 .978 r
.44515 .49471 .4535 .50068 .46784 .50158 .45952 .49611 Mtetra
.244 .646 .961 r
.45952 .49611 .46784 .50158 .48229 .50318 .47401 .49828 Mtetra
.138 .598 .925 r
.47401 .49828 .48229 .50318 .49687 .50547 .48863 .50121 Mtetra
.022 .535 .867 r
.48863 .50121 .49687 .50547 .51158 .5084 .50339 .50486 Mtetra
0 .462 .786 r
.50339 .50486 .51158 .5084 .52644 .5119 .51831 .50913 Mtetra
0 .386 .691 r
.51831 .50913 .52644 .5119 .54146 .51585 .53339 .51392 Mtetra
.285 0 0 r
.53339 .51392 .54146 .51585 .55664 .52011 .54864 .51906 Mtetra
.347 0 0 r
.54864 .51906 .55664 .52011 .57199 .5245 .56407 .52434 Mtetra
.385 0 0 r
.56407 .52434 .57199 .5245 .5875 .52879 .57967 .52953 Mtetra
.403 0 0 r
.57967 .52953 .5875 .52879 .60318 .53276 .59545 .53436 Mtetra
.401 0 0 r
.59545 .53436 .60318 .53276 .61901 .53615 .61139 .53857 Mtetra
.382 0 0 r
.61139 .53857 .61901 .53615 .63497 .53871 .62747 .54187 Mtetra
.347 0 0 r
.62747 .54187 .63497 .53871 .65106 .5402 .64369 .54398 Mtetra
.295 0 0 r
.64369 .54398 .65106 .5402 .66724 .54038 .66 .54466 Mtetra
.226 0 0 r
.66 .54466 .66724 .54038 .68349 .53908 .67639 .54371 Mtetra
.138 0 0 r
.67639 .54371 .68349 .53908 .69978 .53617 .69282 .54097 Mtetra
.033 0 0 r
.69282 .54097 .69978 .53617 .71609 .53156 .70927 .53636 Mtetra
0 0 0 r
.70927 .53636 .71609 .53156 .73239 .52524 .7257 .52986 Mtetra
.7257 .52986 .73239 .52524 .74867 .51726 .74209 .52152 Mtetra
.74209 .52152 .74867 .51726 .76489 .50772 .75843 .51146 Mtetra
.479 .86 .647 r
.75843 .51146 .76489 .50772 .78106 .49678 .7747 .49986 Mtetra
.59 .922 .703 r
.7747 .49986 .78106 .49678 .79717 .48466 .7909 .48696 Mtetra
.68 .965 .75 r
.7909 .48696 .79717 .48466 .81322 .47159 .80703 .473 Mtetra
.748 .989 .787 r
.80703 .473 .81322 .47159 .82923 .45781 .82309 .45827 Mtetra
.796 .999 .815 r
.82309 .45827 .82923 .45781 .84519 .44358 .83911 .44306 Mtetra
.828 .998 .837 r
.83911 .44306 .84519 .44358 .86114 .42915 .8551 .42763 Mtetra
.845 .989 .854 r
.8551 .42763 .86114 .42915 .8771 .41474 .87108 .41223 Mtetra
.852 .975 .868 r
.87108 .41223 .8771 .41474 .89308 .40056 .88709 .39708 Mtetra
.851 .958 .878 r
.88709 .39708 .89308 .40056 .90911 .38676 .90314 .38237 Mtetra
.638 .739 .922 r
.29732 .50552 .3061 .51348 .31969 .50987 .31095 .50194 Mtetra
.629 .739 .926 r
.31095 .50194 .31969 .50987 .33335 .50649 .32465 .4986 Mtetra
.619 .738 .932 r
.32465 .4986 .33335 .50649 .34707 .50337 .33841 .49555 Mtetra
.605 .736 .938 r
.33841 .49555 .34707 .50337 .36086 .50059 .35223 .49287 Mtetra
.586 .734 .945 r
.35223 .49287 .36086 .50059 .37471 .49821 .36612 .49062 Mtetra
.563 .731 .954 r
.36612 .49062 .37471 .49821 .38864 .4963 .38007 .48889 Mtetra
.533 .726 .962 r
.38007 .48889 .38864 .4963 .40264 .49492 .3941 .48775 Mtetra
.494 .718 .971 r
.3941 .48775 .40264 .49492 .41672 .49416 .40822 .48727 Mtetra
.445 .706 .977 r
.40822 .48727 .41672 .49416 .43089 .49407 .42242 .48752 Mtetra
.381 .687 .979 r
.42242 .48752 .43089 .49407 .44515 .49471 .43671 .48856 Mtetra
.302 .659 .972 r
.43671 .48856 .44515 .49471 .45952 .49611 .45112 .49044 Mtetra
.205 .618 .95 r
.45112 .49044 .45952 .49611 .47401 .49828 .46564 .49316 Mtetra
.093 .563 .907 r
.46564 .49316 .47401 .49828 .48863 .50121 .4803 .49671 Mtetra
0 .495 .843 r
.4803 .49671 .48863 .50121 .50339 .50486 .4951 .50105 Mtetra
0 .418 .758 r
.4951 .50105 .50339 .50486 .51831 .50913 .51007 .50608 Mtetra
0 .342 .664 r
.51007 .50608 .51831 .50913 .53339 .51392 .5252 .51168 Mtetra
.325 0 0 r
.5252 .51168 .53339 .51392 .54864 .51906 .54052 .51766 Mtetra
.382 0 0 r
.54052 .51766 .54864 .51906 .56407 .52434 .55602 .5238 Mtetra
.415 0 0 r
.55602 .5238 .56407 .52434 .57967 .52953 .57171 .52986 Mtetra
.428 0 0 r
.57171 .52986 .57967 .52953 .59545 .53436 .58758 .53555 Mtetra
.422 0 0 r
.58758 .53555 .59545 .53436 .61139 .53857 .60363 .54055 Mtetra
.398 0 0 r
.60363 .54055 .61139 .53857 .62747 .54187 .61983 .54456 Mtetra
.357 0 0 r
.61983 .54456 .62747 .54187 .64369 .54398 .63616 .54729 Mtetra
.297 0 0 r
.63616 .54729 .64369 .54398 .66 .54466 .65261 .54846 Mtetra
.216 0 0 r
.65261 .54846 .66 .54466 .67639 .54371 .66913 .54785 Mtetra
.115 0 0 r
.66913 .54785 .67639 .54371 .69282 .54097 .6857 .54528 Mtetra
0 0 0 r
.6857 .54528 .69282 .54097 .70927 .53636 .70228 .54067 Mtetra
.70228 .54067 .70927 .53636 .7257 .52986 .71884 .53398 Mtetra
.71884 .53398 .7257 .52986 .74209 .52152 .73536 .52529 Mtetra
.426 .834 .642 r
.73536 .52529 .74209 .52152 .75843 .51146 .75181 .51473 Mtetra
.551 .905 .696 r
.75181 .51473 .75843 .51146 .7747 .49986 .76818 .50248 Mtetra
.654 .955 .74 r
.76818 .50248 .7747 .49986 .7909 .48696 .78447 .4888 Mtetra
.733 .984 .774 r
.78447 .4888 .7909 .48696 .80703 .473 .80068 .47398 Mtetra
.79 .998 .799 r
.80068 .47398 .80703 .473 .82309 .45827 .81681 .45833 Mtetra
.829 1 .819 r
.81681 .45833 .82309 .45827 .83911 .44306 .83288 .44215 Mtetra
.853 .994 .834 r
.83288 .44215 .83911 .44306 .8551 .42763 .84892 .42574 Mtetra
.865 .982 .847 r
.84892 .42574 .8551 .42763 .87108 .41223 .86494 .40938 Mtetra
.868 .968 .858 r
.86494 .40938 .87108 .41223 .88709 .39708 .88098 .3933 Mtetra
.864 .951 .867 r
.88098 .3933 .88709 .39708 .90314 .38237 .89706 .37769 Mtetra
.636 .739 .922 r
.28847 .49746 .29732 .50552 .31095 .50194 .30214 .4939 Mtetra
.627 .738 .927 r
.30214 .4939 .31095 .50194 .32465 .4986 .31587 .4906 Mtetra
.615 .736 .932 r
.31587 .4906 .32465 .4986 .33841 .49555 .32966 .48762 Mtetra
.6 .734 .939 r
.32966 .48762 .33841 .49555 .35223 .49287 .34351 .48503 Mtetra
.58 .731 .946 r
.34351 .48503 .35223 .49287 .36612 .49062 .35743 .48291 Mtetra
.555 .727 .954 r
.35743 .48291 .36612 .49062 .38007 .48889 .37142 .48134 Mtetra
.523 .72 .963 r
.37142 .48134 .38007 .48889 .3941 .48775 .38549 .4804 Mtetra
.481 .71 .971 r
.38549 .4804 .3941 .48775 .40822 .48727 .39963 .48018 Mtetra
.427 .695 .976 r
.39963 .48018 .40822 .48727 .42242 .48752 .41385 .48075 Mtetra
.359 .672 .975 r
.41385 .48075 .42242 .48752 .43671 .48856 .42818 .48217 Mtetra
.275 .639 .965 r
.42818 .48217 .43671 .48856 .45112 .49044 .44262 .48449 Mtetra
.174 .593 .939 r
.44262 .48449 .45112 .49044 .46564 .49316 .45717 .48773 Mtetra
.059 .533 .893 r
.45717 .48773 .46564 .49316 .4803 .49671 .47186 .49186 Mtetra
0 .461 .826 r
.47186 .49186 .4803 .49671 .4951 .50105 .48671 .49685 Mtetra
0 .384 .743 r
.48671 .49685 .4951 .50105 .51007 .50608 .50172 .50258 Mtetra
0 .31 .653 r
.50172 .50258 .51007 .50608 .5252 .51168 .5169 .50893 Mtetra
.348 0 0 r
.5169 .50893 .5252 .51168 .54052 .51766 .53228 .51571 Mtetra
.401 0 0 r
.53228 .51571 .54052 .51766 .55602 .5238 .54785 .52267 Mtetra
.43 0 0 r
.54785 .52267 .55602 .5238 .57171 .52986 .56361 .52955 Mtetra
.44 0 0 r
.56361 .52955 .57171 .52986 .58758 .53555 .57957 .53603 Mtetra
.43 0 0 r
.57957 .53603 .58758 .53555 .60363 .54055 .59572 .54179 Mtetra
.401 0 0 r
.59572 .54179 .60363 .54055 .61983 .54456 .61203 .54648 Mtetra
.352 0 0 r
.61203 .54648 .61983 .54456 .63616 .54729 .62848 .54979 Mtetra
.281 0 0 r
.62848 .54979 .63616 .54729 .65261 .54846 .64505 .55142 Mtetra
.186 0 0 r
.64505 .55142 .65261 .54846 .66913 .54785 .6617 .55113 Mtetra
.067 0 0 r
.6617 .55113 .66913 .54785 .6857 .54528 .6784 .54872 Mtetra
0 0 0 r
.6784 .54872 .6857 .54528 .70228 .54067 .69511 .5441 Mtetra
.69511 .5441 .70228 .54067 .71884 .53398 .7118 .53725 Mtetra
.382 .819 .67 r
.7118 .53725 .71884 .53398 .73536 .52529 .72844 .52822 Mtetra
.521 .899 .721 r
.72844 .52822 .73536 .52529 .75181 .51473 .74501 .51717 Mtetra
.636 .953 .759 r
.74501 .51717 .75181 .51473 .76818 .50248 .76149 .5043 Mtetra
.725 .984 .785 r
.76149 .5043 .76818 .50248 .78447 .4888 .77787 .48989 Mtetra
.788 .998 .802 r
.77787 .48989 .78447 .4888 .80068 .47398 .79416 .47425 Mtetra
.831 1 .814 r
.79416 .47425 .80068 .47398 .81681 .45833 .81037 .45772 Mtetra
.859 .994 .824 r
.81037 .45772 .81681 .45833 .83288 .44215 .8265 .44062 Mtetra
.875 .984 .832 r
.8265 .44062 .83288 .44215 .84892 .42574 .84259 .42328 Mtetra
.881 .971 .841 r
.84259 .42328 .84892 .42574 .86494 .40938 .85866 .406 Mtetra
.881 .956 .849 r
.85866 .406 .86494 .40938 .88098 .3933 .87474 .38903 Mtetra
.875 .94 .857 r
.87474 .38903 .88098 .3933 .89706 .37769 .89085 .37258 Mtetra
.634 .738 .923 r
.27953 .48931 .28847 .49746 .30214 .4939 .29323 .48576 Mtetra
.625 .736 .927 r
.29323 .48576 .30214 .4939 .31587 .4906 .307 .48249 Mtetra
.612 .734 .933 r
.307 .48249 .31587 .4906 .32966 .48762 .32083 .47956 Mtetra
.596 .732 .939 r
.32083 .47956 .32966 .48762 .34351 .48503 .33471 .47705 Mtetra
.575 .728 .946 r
.33471 .47705 .34351 .48503 .35743 .48291 .34867 .47503 Mtetra
.548 .722 .954 r
.34867 .47503 .35743 .48291 .37142 .48134 .36269 .47361 Mtetra
.514 .714 .962 r
.36269 .47361 .37142 .48134 .38549 .4804 .37678 .47285 Mtetra
.47 .701 .969 r
.37678 .47285 .38549 .4804 .39963 .48018 .39095 .47286 Mtetra
.413 .683 .973 r
.39095 .47286 .39963 .48018 .41385 .48075 .40521 .47372 Mtetra
.342 .657 .971 r
.40521 .47372 .41385 .48075 .42818 .48217 .41956 .47548 Mtetra
.255 .621 .958 r
.41956 .47548 .42818 .48217 .44262 .48449 .43402 .4782 Mtetra
.152 .571 .931 r
.43402 .4782 .44262 .48449 .45717 .48773 .44861 .48189 Mtetra
.038 .509 .884 r
.44861 .48189 .45717 .48773 .47186 .49186 .46333 .48655 Mtetra
0 .437 .819 r
.46333 .48655 .47186 .49186 .48671 .49685 .47821 .49211 Mtetra
0 .362 .741 r
.47821 .49211 .48671 .49685 .50172 .50258 .49326 .49849 Mtetra
0 .292 .658 r
.49326 .49849 .50172 .50258 .5169 .50893 .50849 .50552 Mtetra
.354 0 0 r
.50849 .50552 .5169 .50893 .53228 .51571 .52392 .51301 Mtetra
.403 0 0 r
.52392 .51301 .53228 .51571 .54785 .52267 .53955 .52072 Mtetra
.43 0 0 r
.53955 .52072 .54785 .52267 .56361 .52955 .55538 .52834 Mtetra
.436 0 0 r
.55538 .52834 .56361 .52955 .57957 .53603 .57142 .53554 Mtetra
.421 0 0 r
.57142 .53554 .57957 .53603 .59572 .54179 .58765 .54198 Mtetra
.386 0 0 r
.58765 .54198 .59572 .54179 .61203 .54648 .60406 .5473 Mtetra
.327 0 0 r
.60406 .5473 .61203 .54648 .62848 .54979 .62062 .55113 Mtetra
.242 0 0 r
.62062 .55113 .62848 .54979 .64505 .55142 .63731 .55318 Mtetra
.128 0 0 r
.63731 .55318 .64505 .55142 .6617 .55113 .65408 .55318 Mtetra
0 0 0 r
.65408 .55318 .6617 .55113 .6784 .54872 .67091 .55092 Mtetra
.67091 .55092 .6784 .54872 .69511 .5441 .68775 .54629 Mtetra
.344 .813 .732 r
.68775 .54629 .69511 .5441 .7118 .53725 .70456 .53928 Mtetra
.498 .9 .779 r
.70456 .53928 .7118 .53725 .72844 .52822 .72132 .52994 Mtetra
.625 .957 .807 r
.72132 .52994 .72844 .52822 .74501 .51717 .73801 .51843 Mtetra
.721 .988 .821 r
.73801 .51843 .74501 .51717 .76149 .5043 .75459 .50499 Mtetra
.789 .999 .826 r
.75459 .50499 .76149 .5043 .77787 .48989 .77108 .4899 Mtetra
.835 .998 .827 r
.77108 .4899 .77787 .48989 .79416 .47425 .78746 .47351 Mtetra
.865 .991 .827 r
.78746 .47351 .79416 .47425 .81037 .45772 .80374 .45616 Mtetra
.882 .98 .828 r
.80374 .45616 .81037 .45772 .8265 .44062 .81995 .43822 Mtetra
.891 .967 .831 r
.81995 .43822 .8265 .44062 .84259 .42328 .8361 .42003 Mtetra
.893 .954 .835 r
.8361 .42003 .84259 .42328 .85866 .406 .85222 .40191 Mtetra
.89 .94 .84 r
.85222 .40191 .85866 .406 .87474 .38903 .86834 .38412 Mtetra
.882 .925 .847 r
.86834 .38412 .87474 .38903 .89085 .37258 .8845 .3669 Mtetra
.633 .737 .923 r
.2705 .48106 .27953 .48931 .29323 .48576 .28424 .47752 Mtetra
.623 .735 .927 r
.28424 .47752 .29323 .48576 .307 .48249 .29804 .47426 Mtetra
.61 .733 .933 r
.29804 .47426 .307 .48249 .32083 .47956 .31191 .47137 Mtetra
.593 .729 .939 r
.31191 .47137 .32083 .47956 .33471 .47705 .32583 .46892 Mtetra
.571 .724 .946 r
.32583 .46892 .33471 .47705 .34867 .47503 .33982 .46699 Mtetra
.543 .717 .954 r
.33982 .46699 .34867 .47503 .36269 .47361 .35387 .46568 Mtetra
.507 .708 .961 r
.35387 .46568 .36269 .47361 .37678 .47285 .36799 .46507 Mtetra
.461 .693 .967 r
.36799 .46507 .37678 .47285 .39095 .47286 .38219 .46528 Mtetra
.403 .673 .97 r
.38219 .46528 .39095 .47286 .40521 .47372 .39647 .46637 Mtetra
.331 .644 .967 r
.39647 .46637 .40521 .47372 .41956 .47548 .41085 .46841 Mtetra
.243 .605 .953 r
.41085 .46841 .41956 .47548 .43402 .4782 .42534 .47147 Mtetra
.141 .554 .925 r
.42534 .47147 .43402 .4782 .44861 .48189 .43995 .47555 Mtetra
.03 .491 .881 r
.43995 .47555 .44861 .48189 .46333 .48655 .45471 .48066 Mtetra
0 .421 .82 r
.45471 .48066 .46333 .48655 .47821 .49211 .46961 .48672 Mtetra
0 .35 .75 r
.46961 .48672 .47821 .49211 .49326 .49849 .4847 .49364 Mtetra
0 .285 .677 r
.4847 .49364 .49326 .49849 .50849 .50552 .49997 .50126 Mtetra
.342 0 0 r
.49997 .50126 .50849 .50552 .52392 .51301 .51544 .50937 Mtetra
.388 0 0 r
.51544 .50937 .52392 .51301 .53955 .52072 .53112 .51772 Mtetra
.411 0 0 r
.53112 .51772 .53955 .52072 .55538 .52834 .54702 .52598 Mtetra
.412 0 0 r
.54702 .52598 .55538 .52834 .57142 .53554 .56313 .53381 Mtetra
.392 0 0 r
.56313 .53381 .57142 .53554 .58765 .54198 .57944 .54084 Mtetra
.347 0 0 r
.57944 .54084 .58765 .54198 .60406 .5473 .59594 .54669 Mtetra
.275 0 0 r
.59594 .54669 .60406 .5473 .62062 .55113 .6126 .55098 Mtetra
.172 0 0 r
.6126 .55098 .62062 .55113 .63731 .55318 .62939 .55339 Mtetra
.035 0 0 r
.62939 .55339 .63731 .55318 .65408 .55318 .64627 .55363 Mtetra
.131 .679 .751 r
.64627 .55363 .65408 .55318 .67091 .55092 .66321 .5515 Mtetra
.308 .801 .816 r
.66321 .5515 .67091 .55092 .68775 .54629 .68017 .54686 Mtetra
.475 .896 .859 r
.68017 .54686 .68775 .54629 .70456 .53928 .69711 .53969 Mtetra
.613 .957 .877 r
.69711 .53969 .70456 .53928 .72132 .52994 .71399 .53008 Mtetra
.717 .987 .877 r
.71399 .53008 .72132 .52994 .73801 .51843 .73079 .51817 Mtetra
.789 .996 .867 r
.73079 .51817 .73801 .51843 .75459 .50499 .74748 .50422 Mtetra
.837 .992 .854 r
.74748 .50422 .75459 .50499 .77108 .4899 .76407 .48853 Mtetra
.868 .983 .843 r
.76407 .48853 .77108 .4899 .78746 .47351 .78054 .47147 Mtetra
.886 .971 .834 r
.78054 .47147 .78746 .47351 .80374 .45616 .79691 .45341 Mtetra
.896 .958 .829 r
.79691 .45341 .80374 .45616 .81995 .43822 .81319 .43472 Mtetra
.9 .945 .827 r
.81319 .43472 .81995 .43822 .8361 .42003 .82941 .41578 Mtetra
.899 .932 .828 r
.82941 .41578 .8361 .42003 .85222 .40191 .84559 .39691 Mtetra
.894 .92 .832 r
.84559 .39691 .85222 .40191 .86834 .38412 .86178 .3784 Mtetra
.885 .907 .838 r
.86178 .3784 .86834 .38412 .8845 .3669 .87799 .3605 Mtetra
.632 .736 .923 r
.26138 .47269 .2705 .48106 .28424 .47752 .27517 .46915 Mtetra
.621 .734 .927 r
.27517 .46915 .28424 .47752 .29804 .47426 .28901 .4659 Mtetra
.608 .731 .932 r
.28901 .4659 .29804 .47426 .31191 .47137 .3029 .46303 Mtetra
.59 .727 .938 r
.3029 .46303 .31191 .47137 .32583 .46892 .31686 .46062 Mtetra
.568 .721 .945 r
.31686 .46062 .32583 .46892 .33982 .46699 .33088 .45875 Mtetra
.539 .713 .952 r
.33088 .45875 .33982 .46699 .35387 .46568 .34497 .45752 Mtetra
.502 .702 .959 r
.34497 .45752 .35387 .46568 .36799 .46507 .35912 .45703 Mtetra
.456 .686 .965 r
.35912 .45703 .36799 .46507 .38219 .46528 .37334 .45738 Mtetra
.397 .664 .967 r
.37334 .45738 .38219 .46528 .39647 .46637 .38765 .45865 Mtetra
.325 .633 .962 r
.38765 .45865 .39647 .46637 .41085 .46841 .40206 .46092 Mtetra
.239 .593 .949 r
.40206 .46092 .41085 .46841 .42534 .47147 .41657 .46424 Mtetra
.141 .541 .922 r
.41657 .46424 .42534 .47147 .43995 .47555 .43121 .46864 Mtetra
.035 .48 .882 r
.43121 .46864 .43995 .47555 .45471 .48066 .44599 .47409 Mtetra
0 .414 .828 r
.44599 .47409 .45471 .48066 .46961 .48672 .46092 .48055 Mtetra
0 .349 .768 r
.46092 .48055 .46961 .48672 .4847 .49364 .47603 .48791 Mtetra
0 .29 .707 r
.47603 .48791 .4847 .49364 .49997 .50126 .49134 .496 Mtetra
0 .245 .653 r
.49134 .496 .49997 .50126 .51544 .50937 .50685 .50461 Mtetra
.352 0 0 r
.50685 .50461 .51544 .50937 .53112 .51772 .52257 .51346 Mtetra
.37 0 0 r
.52257 .51346 .53112 .51772 .54702 .52598 .53852 .52224 Mtetra
.365 0 0 r
.53852 .52224 .54702 .52598 .56313 .53381 .55469 .53058 Mtetra
.335 0 0 r
.55469 .53058 .56313 .53381 .57944 .54084 .57107 .53809 Mtetra
.278 0 0 r
.57107 .53809 .57944 .54084 .59594 .54669 .58765 .54437 Mtetra
0 .402 .682 r
.58765 .54437 .59594 .54669 .6126 .55098 .60439 .54903 Mtetra
0 .514 .754 r
.60439 .54903 .6126 .55098 .62939 .55339 .62128 .55173 Mtetra
.094 .641 .831 r
.62128 .55173 .62939 .55339 .64627 .55363 .63827 .55216 Mtetra
.271 .766 .897 r
.63827 .55216 .64627 .55363 .66321 .5515 .65531 .55012 Mtetra
.444 .868 .937 r
.65531 .55012 .66321 .5515 .68017 .54686 .67238 .54546 Mtetra
.59 .934 .948 r
.67238 .54546 .68017 .54686 .69711 .53969 .68943 .53817 Mtetra
.701 .967 .936 r
.68943 .53817 .69711 .53969 .71399 .53008 .70643 .52831 Mtetra
.778 .977 .913 r
.70643 .52831 .71399 .53008 .73079 .51817 .72333 .51607 Mtetra
.829 .974 .888 r
.72333 .51607 .73079 .51817 .74748 .50422 .74014 .50169 Mtetra
.862 .964 .865 r
.74014 .50169 .74748 .50422 .76407 .48853 .75682 .4855 Mtetra
.883 .952 .847 r
.75682 .4855 .76407 .48853 .78054 .47147 .77339 .46787 Mtetra
.895 .94 .834 r
.77339 .46787 .78054 .47147 .79691 .45341 .78985 .44921 Mtetra
.901 .928 .825 r
.78985 .44921 .79691 .45341 .81319 .43472 .80622 .4299 Mtetra
.902 .917 .821 r
.80622 .4299 .81319 .43472 .82941 .41578 .82252 .41033 Mtetra
.899 .906 .821 r
.82252 .41033 .82941 .41578 .84559 .39691 .83878 .39084 Mtetra
.893 .896 .823 r
.83878 .39084 .84559 .39691 .86178 .3784 .85503 .37173 Mtetra
.885 .887 .828 r
.85503 .37173 .86178 .3784 .87799 .3605 .8713 .35325 Mtetra
.631 .735 .922 r
.25218 .46422 .26138 .47269 .27517 .46915 .266 .46066 Mtetra
.62 .732 .927 r
.266 .46066 .27517 .46915 .28901 .4659 .27988 .45741 Mtetra
.607 .729 .932 r
.27988 .45741 .28901 .4659 .3029 .46303 .29382 .45454 Mtetra
.589 .724 .937 r
.29382 .45454 .3029 .46303 .31686 .46062 .30781 .45214 Mtetra
.566 .718 .944 r
.30781 .45214 .31686 .46062 .33088 .45875 .32186 .4503 Mtetra
.537 .709 .951 r
.32186 .4503 .33088 .45875 .34497 .45752 .33598 .44912 Mtetra
.5 .696 .957 r
.33598 .44912 .34497 .45752 .35912 .45703 .35016 .4487 Mtetra
.454 .679 .961 r
.35016 .4487 .35912 .45703 .37334 .45738 .36442 .44915 Mtetra
.396 .656 .963 r
.36442 .44915 .37334 .45738 .38765 .45865 .37876 .45054 Mtetra
.326 .624 .958 r
.37876 .45054 .38765 .45865 .40206 .46092 .39319 .45296 Mtetra
.244 .584 .945 r
.39319 .45296 .40206 .46092 .41657 .46424 .40773 .45646 Mtetra
.151 .534 .922 r
.40773 .45646 .41657 .46424 .43121 .46864 .42239 .46107 Mtetra
.052 .476 .886 r
.42239 .46107 .43121 .46864 .44599 .47409 .43719 .46677 Mtetra
0 .415 .841 r
.43719 .46677 .44599 .47409 .46092 .48055 .45215 .47351 Mtetra
0 .356 .792 r
.45215 .47351 .46092 .48055 .47603 .48791 .46728 .48118 Mtetra
0 .305 .743 r
.46728 .48118 .47603 .48791 .49134 .496 .48261 .48961 Mtetra
0 .267 .702 r
.48261 .48961 .49134 .496 .50685 .50461 .49816 .49857 Mtetra
0 .246 .674 r
.49816 .49857 .50685 .50461 .52257 .51346 .51392 .5078 Mtetra
0 .244 .663 r
.51392 .5078 .52257 .51346 .53852 .52224 .52991 .51694 Mtetra
0 .264 .67 r
.52991 .51694 .53852 .52224 .55469 .53058 .54613 .52565 Mtetra
0 .309 .698 r
.54613 .52565 .55469 .53058 .57107 .53809 .56256 .5335 Mtetra
0 .378 .746 r
.56256 .5335 .57107 .53809 .58765 .54437 .5792 .54008 Mtetra
0 .473 .811 r
.5792 .54008 .58765 .54437 .60439 .54903 .59602 .54501 Mtetra
.071 .585 .882 r
.59602 .54501 .60439 .54903 .62128 .55173 .61299 .54791 Mtetra
.234 .701 .944 r
.61299 .54791 .62128 .55173 .63827 .55216 .63006 .54848 Mtetra
.4 .802 .983 r
.63006 .54848 .63827 .55216 .65531 .55012 .64721 .54649 Mtetra
.548 .874 .992 r
.64721 .54649 .65531 .55012 .67238 .54546 .66438 .54181 Mtetra
.663 .915 .977 r
.66438 .54181 .67238 .54546 .68943 .53817 .68153 .53441 Mtetra
.747 .932 .949 r
.68153 .53441 .68943 .53817 .70643 .52831 .69863 .52436 Mtetra
.804 .935 .917 r
.69863 .52436 .70643 .52831 .72333 .51607 .71565 .51184 Mtetra
.843 .93 .887 r
.71565 .51184 .72333 .51607 .74014 .50169 .73255 .49713 Mtetra
.867 .922 .862 r
.73255 .49713 .74014 .50169 .75682 .4855 .74934 .48055 Mtetra
.883 .912 .842 r
.74934 .48055 .75682 .4855 .77339 .46787 .76601 .46249 Mtetra
.892 .903 .828 r
.76601 .46249 .77339 .46787 .78985 .44921 .78257 .44336 Mtetra
.896 .894 .818 r
.78257 .44336 .78985 .44921 .80622 .4299 .79903 .42358 Mtetra
.897 .886 .814 r
.79903 .42358 .80622 .4299 .82252 .41033 .81542 .40352 Mtetra
.894 .879 .812 r
.81542 .40352 .82252 .41033 .83878 .39084 .83176 .38355 Mtetra
.888 .871 .815 r
.83176 .38355 .83878 .39084 .85503 .37173 .84809 .36398 Mtetra
.88 .864 .819 r
.84809 .36398 .85503 .37173 .8713 .35325 .86444 .34505 Mtetra
.631 .734 .922 r
.24289 .45563 .25218 .46422 .266 .46066 .25675 .45204 Mtetra
.62 .731 .926 r
.25675 .45204 .266 .46066 .27988 .45741 .27067 .44876 Mtetra
.606 .727 .931 r
.27067 .44876 .27988 .45741 .29382 .45454 .28464 .44588 Mtetra
.588 .722 .936 r
.28464 .44588 .29382 .45454 .30781 .45214 .29867 .44347 Mtetra
.565 .715 .942 r
.29867 .44347 .30781 .45214 .32186 .4503 .31276 .44163 Mtetra
.537 .705 .948 r
.31276 .44163 .32186 .4503 .33598 .44912 .32691 .44046 Mtetra
.5 .692 .954 r
.32691 .44046 .33598 .44912 .35016 .4487 .34113 .44007 Mtetra
.455 .674 .958 r
.34113 .44007 .35016 .4487 .36442 .44915 .35541 .44055 Mtetra
.399 .65 .959 r
.35541 .44055 .36442 .44915 .37876 .45054 .36978 .442 Mtetra
.333 .618 .954 r
.36978 .442 .37876 .45054 .39319 .45296 .38424 .44449 Mtetra
.255 .578 .943 r
.38424 .44449 .39319 .45296 .40773 .45646 .3988 .44808 Mtetra
.169 .531 .922 r
.3988 .44808 .40773 .45646 .42239 .46107 .41348 .4528 Mtetra
.08 .477 .893 r
.41348 .4528 .42239 .46107 .43719 .46677 .42831 .45864 Mtetra
0 .422 .856 r
.42831 .45864 .43719 .46677 .45215 .47351 .44329 .46553 Mtetra
0 .369 .817 r
.44329 .46553 .45215 .47351 .46728 .48118 .45845 .47336 Mtetra
0 .326 .78 r
.45845 .47336 .46728 .48118 .48261 .48961 .4738 .48198 Mtetra
0 .295 .752 r
.4738 .48198 .48261 .48961 .49816 .49857 .48937 .49114 Mtetra
0 .281 .736 r
.48937 .49114 .49816 .49857 .51392 .5078 .50516 .50058 Mtetra
0 .286 .737 r
.50516 .50058 .51392 .5078 .52991 .51694 .52118 .50994 Mtetra
0 .313 .754 r
.52118 .50994 .52991 .51694 .54613 .52565 .53744 .51884 Mtetra
0 .362 .79 r
.53744 .51884 .54613 .52565 .56256 .5335 .55392 .52689 Mtetra
0 .433 .839 r
.55392 .52689 .56256 .5335 .5792 .54008 .57061 .53365 Mtetra
.064 .522 .896 r
.57061 .53365 .5792 .54008 .59602 .54501 .58749 .53872 Mtetra
.203 .619 .949 r
.58749 .53872 .59602 .54501 .61299 .54791 .60452 .54173 Mtetra
.351 .711 .985 r
.60452 .54173 .61299 .54791 .63006 .54848 .62167 .54236 Mtetra
.489 .784 .997 r
.62167 .54236 .63006 .54848 .64721 .54649 .6389 .54039 Mtetra
.606 .833 .987 r
.6389 .54039 .64721 .54649 .66438 .54181 .65616 .53567 Mtetra
.695 .862 .961 r
.65616 .53567 .66438 .54181 .68153 .53441 .6734 .52818 Mtetra
.76 .875 .93 r
.6734 .52818 .68153 .53441 .69863 .52436 .6906 .51799 Mtetra
.806 .878 .899 r
.6906 .51799 .69863 .52436 .71565 .51184 .70772 .50529 Mtetra
.837 .877 .871 r
.70772 .50529 .71565 .51184 .73255 .49713 .72473 .49035 Mtetra
.859 .873 .848 r
.72473 .49035 .73255 .49713 .74934 .48055 .74162 .4735 Mtetra
.873 .868 .83 r
.74162 .4735 .74934 .48055 .76601 .46249 .7584 .45516 Mtetra
.881 .863 .817 r
.7584 .45516 .76601 .46249 .78257 .44336 .77505 .43572 Mtetra
.886 .858 .809 r
.77505 .43572 .78257 .44336 .79903 .42358 .79161 .4156 Mtetra
.887 .854 .804 r
.79161 .4156 .79903 .42358 .81542 .40352 .80809 .39522 Mtetra
.885 .85 .804 r
.80809 .39522 .81542 .40352 .83176 .38355 .82453 .37493 Mtetra
.88 .846 .806 r
.82453 .37493 .83176 .38355 .84809 .36398 .84095 .35504 Mtetra
.873 .842 .811 r
.84095 .35504 .84809 .36398 .86444 .34505 .85739 .33582 Mtetra
.631 .733 .921 r
.23352 .44692 .24289 .45563 .25675 .45204 .24741 .44329 Mtetra
.62 .73 .925 r
.24741 .44329 .25675 .45204 .27067 .44876 .26137 .43997 Mtetra
.606 .726 .93 r
.26137 .43997 .27067 .44876 .28464 .44588 .27538 .43705 Mtetra
.589 .72 .935 r
.27538 .43705 .28464 .44588 .29867 .44347 .28945 .4346 Mtetra
.566 .713 .94 r
.28945 .4346 .29867 .44347 .31276 .44163 .30358 .43273 Mtetra
.538 .702 .946 r
.30358 .43273 .31276 .44163 .32691 .44046 .31776 .43153 Mtetra
.503 .688 .951 r
.31776 .43153 .32691 .44046 .34113 .44007 .33201 .43111 Mtetra
.459 .67 .954 r
.33201 .43111 .34113 .44007 .35541 .44055 .34633 .43157 Mtetra
.406 .645 .955 r
.34633 .43157 .35541 .44055 .36978 .442 .36073 .433 Mtetra
.344 .614 .95 r
.36073 .433 .36978 .442 .38424 .44449 .37521 .43549 Mtetra
.273 .576 .94 r
.37521 .43549 .38424 .44449 .3988 .44808 .3898 .43908 Mtetra
.195 .531 .923 r
.3898 .43908 .3988 .44808 .41348 .4528 .40451 .4438 Mtetra
.115 .482 .899 r
.40451 .4438 .41348 .4528 .42831 .45864 .41935 .44964 Mtetra
.039 .433 .87 r
.41935 .44964 .42831 .45864 .44329 .46553 .43435 .45655 Mtetra
0 .387 .84 r
.43435 .45655 .44329 .46553 .45845 .47336 .44953 .46441 Mtetra
0 .35 .813 r
.44953 .46441 .45845 .47336 .4738 .48198 .46491 .47305 Mtetra
0 .326 .795 r
.46491 .47305 .4738 .48198 .48937 .49114 .48049 .48225 Mtetra
0 .318 .788 r
.48049 .48225 .48937 .49114 .50516 .50058 .49631 .49172 Mtetra
0 .327 .795 r
.49631 .49172 .50516 .50058 .52118 .50994 .51235 .50112 Mtetra
0 .356 .816 r
.51235 .50112 .52118 .50994 .53744 .51884 .52864 .51007 Mtetra
0 .404 .848 r
.52864 .51007 .53744 .51884 .55392 .52689 .54515 .51815 Mtetra
.073 .468 .888 r
.54515 .51815 .55392 .52689 .57061 .53365 .56189 .52494 Mtetra
.184 .543 .928 r
.56189 .52494 .57061 .53365 .58749 .53872 .57881 .53003 Mtetra
.307 .618 .957 r
.57881 .53003 .58749 .53872 .60452 .54173 .5959 .53304 Mtetra
.429 .686 .971 r
.5959 .53304 .60452 .54173 .62167 .54236 .61311 .53367 Mtetra
.539 .739 .968 r
.61311 .53367 .62167 .54236 .6389 .54039 .6304 .53167 Mtetra
.63 .776 .951 r
.6304 .53167 .6389 .54039 .65616 .53567 .64773 .52691 Mtetra
.701 .8 .926 r
.64773 .52691 .65616 .53567 .6734 .52818 .66506 .51935 Mtetra
.755 .814 .899 r
.66506 .51935 .6734 .52818 .6906 .51799 .68235 .50908 Mtetra
.794 .821 .873 r
.68235 .50908 .6906 .51799 .70772 .50529 .69956 .49628 Mtetra
.822 .824 .85 r
.69956 .49628 .70772 .50529 .72473 .49035 .71667 .48121 Mtetra
.843 .825 .831 r
.71667 .48121 .72473 .49035 .74162 .4735 .73367 .46424 Mtetra
.857 .825 .816 r
.73367 .46424 .74162 .4735 .7584 .45516 .75054 .44575 Mtetra
.866 .824 .805 r
.75054 .44575 .7584 .45516 .77505 .43572 .7673 .42616 Mtetra
.871 .823 .798 r
.7673 .42616 .77505 .43572 .79161 .4156 .78397 .40589 Mtetra
.873 .822 .795 r
.78397 .40589 .79161 .4156 .80809 .39522 .80055 .38536 Mtetra
.873 .821 .795 r
.80055 .38536 .80809 .39522 .82453 .37493 .81709 .36491 Mtetra
.869 .82 .798 r
.81709 .36491 .82453 .37493 .84095 .35504 .83361 .34487 Mtetra
.864 .819 .803 r
.83361 .34487 .84095 .35504 .85739 .33582 .85015 .3255 Mtetra
.631 .732 .921 r
.22405 .43809 .23352 .44692 .24741 .44329 .23799 .4344 Mtetra
.621 .729 .924 r
.23799 .4344 .24741 .44329 .26137 .43997 .25198 .43103 Mtetra
.607 .725 .928 r
.25198 .43103 .26137 .43997 .27538 .43705 .26604 .42805 Mtetra
.59 .719 .933 r
.26604 .42805 .27538 .43705 .28945 .4346 .28014 .42554 Mtetra
.568 .71 .938 r
.28014 .42554 .28945 .4346 .30358 .43273 .29431 .4236 Mtetra
.541 .7 .943 r
.29431 .4236 .30358 .43273 .31776 .43153 .30853 .42233 Mtetra
.507 .685 .947 r
.30853 .42233 .31776 .43153 .33201 .43111 .32282 .42184 Mtetra
.466 .667 .95 r
.32282 .42184 .33201 .43111 .34633 .43157 .33717 .42221 Mtetra
.417 .642 .95 r
.33717 .42221 .34633 .43157 .36073 .433 .3516 .42356 Mtetra
.359 .612 .946 r
.3516 .42356 .36073 .433 .37521 .43549 .36611 .42594 Mtetra
.295 .576 .938 r
.36611 .42594 .37521 .43549 .3898 .43908 .38073 .42943 Mtetra
.225 .535 .923 r
.38073 .42943 .3898 .43908 .40451 .4438 .39546 .43405 Mtetra
.156 .49 .904 r
.39546 .43405 .40451 .4438 .41935 .44964 .41033 .43978 Mtetra
.09 .446 .881 r
.41033 .43978 .41935 .44964 .43435 .45655 .42535 .44656 Mtetra
.034 .407 .858 r
.42535 .44656 .43435 .45655 .44953 .46441 .44055 .4543 Mtetra
0 .376 .839 r
.44055 .4543 .44953 .46441 .46491 .47305 .45594 .46281 Mtetra
0 .357 .827 r
.45594 .46281 .46491 .47305 .48049 .48225 .47154 .47187 Mtetra
0 .352 .824 r
.47154 .47187 .48049 .48225 .49631 .49172 .48737 .48121 Mtetra
0 .363 .832 r
.48737 .48121 .49631 .49172 .51235 .50112 .50344 .49047 Mtetra
.029 .391 .85 r
.50344 .49047 .51235 .50112 .52864 .51007 .51974 .49929 Mtetra
.094 .432 .874 r
.51974 .49929 .52864 .51007 .54515 .51815 .53628 .50724 Mtetra
.179 .485 .899 r
.53628 .50724 .54515 .51815 .56189 .52494 .55304 .51391 Mtetra
.277 .543 .921 r
.55304 .51391 .56189 .52494 .57881 .53003 .57 .51889 Mtetra
.379 .6 .933 r
.57 .51889 .57881 .53003 .5959 .53304 .58712 .5218 Mtetra
.477 .65 .935 r
.58712 .5218 .5959 .53304 .61311 .53367 .60438 .52235 Mtetra
.564 .691 .925 r
.60438 .52235 .61311 .53367 .6304 .53167 .62173 .52028 Mtetra
.637 .721 .908 r
.62173 .52028 .6304 .53167 .64773 .52691 .63912 .51546 Mtetra
.696 .743 .888 r
.63912 .51546 .64773 .52691 .66506 .51935 .65652 .50786 Mtetra
.742 .758 .866 r
.65652 .50786 .66506 .51935 .68235 .50908 .67389 .49756 Mtetra
.777 .769 .846 r
.67389 .49756 .68235 .50908 .69956 .49628 .69118 .48475 Mtetra
.803 .776 .828 r
.69118 .48475 .69956 .49628 .71667 .48121 .70839 .46968 Mtetra
.823 .781 .813 r
.70839 .46968 .71667 .48121 .73367 .46424 .72548 .45271 Mtetra
.838 .785 .801 r
.72548 .45271 .73367 .46424 .75054 .44575 .74246 .43423 Mtetra
.848 .788 .793 r
.74246 .43423 .75054 .44575 .7673 .42616 .75933 .41466 Mtetra
.854 .79 .788 r
.75933 .41466 .7673 .42616 .78397 .40589 .7761 .39441 Mtetra
.858 .792 .786 r
.7761 .39441 .78397 .40589 .80055 .38536 .7928 .37389 Mtetra
.859 .794 .787 r
.7928 .37389 .80055 .38536 .81709 .36491 .80945 .35346 Mtetra
.857 .796 .79 r
.80945 .35346 .81709 .36491 .83361 .34487 .82608 .33343 Mtetra
.853 .797 .796 r
.82608 .33343 .83361 .34487 .85015 .3255 .84273 .31406 Mtetra
.632 .732 .92 r
.21449 .42914 .22405 .43809 .23799 .4344 .22847 .42539 Mtetra
.622 .728 .923 r
.22847 .42539 .23799 .4344 .25198 .43103 .24251 .42194 Mtetra
.608 .724 .927 r
.24251 .42194 .25198 .43103 .26604 .42805 .2566 .41887 Mtetra
.592 .717 .931 r
.2566 .41887 .26604 .42805 .28014 .42554 .27075 .41628 Mtetra
.571 .709 .935 r
.27075 .41628 .28014 .42554 .29431 .4236 .28496 .41424 Mtetra
.545 .698 .94 r
.28496 .41424 .29431 .4236 .30853 .42233 .29922 .41286 Mtetra
.513 .683 .943 r
.29922 .41286 .30853 .42233 .32282 .42184 .31354 .41224 Mtetra
.475 .665 .946 r
.31354 .41224 .32282 .42184 .33717 .42221 .32793 .41247 Mtetra
.429 .641 .946 r
.32793 .41247 .33717 .42221 .3516 .42356 .3424 .41366 Mtetra
.377 .613 .942 r
.3424 .41366 .3516 .42356 .36611 .42594 .35694 .41587 Mtetra
.32 .579 .935 r
.35694 .41587 .36611 .42594 .38073 .42943 .37159 .41916 Mtetra
.259 .541 .922 r
.37159 .41916 .38073 .42943 .39546 .43405 .38635 .42356 Mtetra
.199 .5 .906 r
.38635 .42356 .39546 .43405 .41033 .43978 .40124 .42905 Mtetra
.144 .461 .888 r
.40124 .42905 .41033 .43978 .42535 .44656 .41629 .43558 Mtetra
.098 .427 .87 r
.41629 .43558 .42535 .44656 .44055 .4543 .4315 .44304 Mtetra
.067 .4 .856 r
.4315 .44304 .44055 .4543 .45594 .46281 .44691 .45126 Mtetra
.052 .385 .847 r
.44691 .45126 .45594 .46281 .47154 .47187 .46253 .46003 Mtetra
.056 .382 .845 r
.46253 .46003 .47154 .47187 .48737 .48121 .47837 .46906 Mtetra
.081 .392 .85 r
.47837 .46906 .48737 .48121 .50344 .49047 .49445 .47801 Mtetra
.125 .415 .861 r
.49445 .47801 .50344 .49047 .51974 .49929 .51076 .48653 Mtetra
.187 .449 .875 r
.51076 .48653 .51974 .49929 .53628 .50724 .52731 .49419 Mtetra
.262 .49 .888 r
.52731 .49419 .53628 .50724 .55304 .51391 .54409 .50059 Mtetra
.344 .534 .897 r
.54409 .50059 .55304 .51391 .57 .51889 .56107 .50534 Mtetra
.428 .578 .9 r
.56107 .50534 .57 .51889 .58712 .5218 .57822 .50805 Mtetra
.506 .616 .895 r
.57822 .50805 .58712 .5218 .60438 .52235 .59551 .50843 Mtetra
.577 .649 .885 r
.59551 .50843 .60438 .52235 .62173 .52028 .61289 .50625 Mtetra
.637 .675 .87 r
.61289 .50625 .62173 .52028 .63912 .51546 .63034 .50136 Mtetra
.686 .696 .853 r
.63034 .50136 .63912 .51546 .65652 .50786 .6478 .49375 Mtetra
.726 .712 .837 r
.6478 .49375 .65652 .50786 .67389 .49756 .66523 .48348 Mtetra
.758 .725 .821 r
.66523 .48348 .67389 .49756 .69118 .48475 .68261 .47074 Mtetra
.784 .734 .807 r
.68261 .47074 .69118 .48475 .70839 .46968 .6999 .45578 Mtetra
.803 .743 .796 r
.6999 .45578 .70839 .46968 .72548 .45271 .71709 .43895 Mtetra
.818 .749 .787 r
.71709 .43895 .72548 .45271 .74246 .43423 .73417 .42064 Mtetra
.829 .755 .781 r
.73417 .42064 .74246 .43423 .75933 .41466 .75115 .40124 Mtetra
.837 .76 .778 r
.75115 .40124 .75933 .41466 .7761 .39441 .76803 .38118 Mtetra
.842 .765 .778 r
.76803 .38118 .7761 .39441 .7928 .37389 .78485 .36085 Mtetra
.844 .77 .779 r
.78485 .36085 .7928 .37389 .80945 .35346 .80161 .3406 Mtetra
.844 .773 .784 r
.80161 .3406 .80945 .35346 .82608 .33343 .81837 .32074 Mtetra
.841 .777 .79 r
.81837 .32074 .82608 .33343 .84273 .31406 .83513 .30153 Mtetra
.633 .731 .919 r
.20484 .42007 .21449 .42914 .22847 .42539 .21886 .41623 Mtetra
.623 .728 .922 r
.21886 .41623 .22847 .42539 .24251 .42194 .23294 .4127 Mtetra
.611 .723 .925 r
.23294 .4127 .24251 .42194 .2566 .41887 .24708 .40953 Mtetra
.595 .716 .929 r
.24708 .40953 .2566 .41887 .27075 .41628 .26127 .40682 Mtetra
.575 .708 .933 r
.26127 .40682 .27075 .41628 .28496 .41424 .27552 .40465 Mtetra
.551 .697 .936 r
.27552 .40465 .28496 .41424 .29922 .41286 .28983 .40312 Mtetra
.521 .683 .939 r
.28983 .40312 .29922 .41286 .31354 .41224 .30419 .40233 Mtetra
.486 .664 .941 r
.30419 .40233 .31354 .41224 .32793 .41247 .31862 .40236 Mtetra
.444 .642 .941 r
.31862 .40236 .32793 .41247 .3424 .41366 .33312 .40332 Mtetra
.398 .614 .938 r
.33312 .40332 .3424 .41366 .35694 .41587 .34771 .40528 Mtetra
.347 .583 .931 r
.34771 .40528 .35694 .41587 .37159 .41916 .36239 .40828 Mtetra
.294 .548 .921 r
.36239 .40828 .37159 .41916 .38635 .42356 .37718 .41236 Mtetra
.243 .512 .907 r
.37718 .41236 .38635 .42356 .40124 .42905 .3921 .4175 Mtetra
.197 .477 .892 r
.3921 .4175 .40124 .42905 .41629 .43558 .40717 .42365 Mtetra
.16 .446 .877 r
.40717 .42365 .41629 .43558 .4315 .44304 .4224 .43069 Mtetra
.137 .423 .865 r
.4224 .43069 .4315 .44304 .44691 .45126 .43783 .43848 Mtetra
.129 .409 .857 r
.43783 .43848 .44691 .45126 .46253 .46003 .45346 .44679 Mtetra
.137 .406 .854 r
.45346 .44679 .46253 .46003 .47837 .46906 .46931 .45535 Mtetra
.163 .414 .855 r
.46931 .45535 .47837 .46906 .49445 .47801 .48539 .46384 Mtetra
.205 .432 .859 r
.48539 .46384 .49445 .47801 .51076 .48653 .50171 .47189 Mtetra
.26 .459 .865 r
.50171 .47189 .51076 .48653 .52731 .49419 .51827 .47911 Mtetra
.324 .49 .869 r
.51827 .47911 .52731 .49419 .54409 .50059 .53505 .48511 Mtetra
.392 .524 .871 r
.53505 .48511 .54409 .50059 .56107 .50534 .55204 .4895 Mtetra
.46 .558 .868 r
.55204 .4895 .56107 .50534 .57822 .50805 .5692 .49192 Mtetra
.525 .588 .861 r
.5692 .49192 .57822 .50805 .59551 .50843 .58651 .49206 Mtetra
.583 .616 .85 r
.58651 .49206 .59551 .50843 .61289 .50625 .60393 .48972 Mtetra
.633 .639 .838 r
.60393 .48972 .61289 .50625 .63034 .50136 .62141 .48476 Mtetra
.676 .658 .825 r
.62141 .48476 .63034 .50136 .6478 .49375 .63891 .47715 Mtetra
.712 .675 .812 r
.63891 .47715 .6478 .49375 .66523 .48348 .6564 .46696 Mtetra
.741 .688 .8 r
.6564 .46696 .66523 .48348 .68261 .47074 .67385 .45437 Mtetra
.765 .7 .79 r
.67385 .45437 .68261 .47074 .6999 .45578 .69122 .43963 Mtetra
.785 .71 .781 r
.69122 .43963 .6999 .45578 .71709 .43895 .7085 .42307 Mtetra
.8 .719 .775 r
.7085 .42307 .71709 .43895 .73417 .42064 .72568 .40506 Mtetra
.811 .727 .771 r
.72568 .40506 .73417 .42064 .75115 .40124 .74276 .386 Mtetra
.82 .734 .77 r
.74276 .386 .75115 .40124 .76803 .38118 .75977 .36628 Mtetra
.826 .741 .77 r
.75977 .36628 .76803 .38118 .78485 .36085 .7767 .3463 Mtetra
.829 .747 .773 r
.7767 .3463 .78485 .36085 .80161 .3406 .79359 .32639 Mtetra
.83 .753 .778 r
.79359 .32639 .80161 .3406 .81837 .32074 .81047 .30685 Mtetra
.828 .758 .785 r
.81047 .30685 .81837 .32074 .83513 .30153 .82736 .28795 Mtetra
.634 .731 .918 r
.19509 .41087 .20484 .42007 .21886 .41623 .20916 .40695 Mtetra
.625 .727 .921 r
.20916 .40695 .21886 .41623 .23294 .4127 .22329 .40331 Mtetra
.613 .723 .923 r
.22329 .40331 .23294 .4127 .24708 .40953 .23747 .40003 Mtetra
.598 .716 .927 r
.23747 .40003 .24708 .40953 .26127 .40682 .25171 .39718 Mtetra
.58 .708 .93 r
.25171 .39718 .26127 .40682 .27552 .40465 .266 .39485 Mtetra
.557 .696 .933 r
.266 .39485 .27552 .40465 .28983 .40312 .28035 .39313 Mtetra
.53 .682 .936 r
.28035 .39313 .28983 .40312 .30419 .40233 .29476 .39212 Mtetra
.498 .665 .937 r
.29476 .39212 .30419 .40233 .31862 .40236 .30923 .39191 Mtetra
.46 .643 .936 r
.30923 .39191 .31862 .40236 .33312 .40332 .32378 .39259 Mtetra
.419 .618 .933 r
.32378 .39259 .33312 .40332 .34771 .40528 .3384 .39421 Mtetra
.374 .588 .927 r
.3384 .39421 .34771 .40528 .36239 .40828 .35312 .39685 Mtetra
.329 .556 .918 r
.35312 .39685 .36239 .40828 .37718 .41236 .36795 .40051 Mtetra
.285 .523 .906 r
.36795 .40051 .37718 .41236 .3921 .4175 .3829 .40519 Mtetra
.247 .492 .893 r
.3829 .40519 .3921 .4175 .40717 .42365 .39799 .41084 Mtetra
.218 .464 .88 r
.39799 .41084 .40717 .42365 .4224 .43069 .41325 .41734 Mtetra
.2 .443 .869 r
.41325 .41734 .4224 .43069 .43783 .43848 .42869 .42456 Mtetra
.197 .431 .86 r
.42869 .42456 .43783 .43848 .45346 .44679 .44433 .43226 Mtetra
.207 .427 .854 r
.44433 .43226 .45346 .44679 .46931 .45535 .46019 .44021 Mtetra
.232 .432 .852 r
.46019 .44021 .46931 .45535 .48539 .46384 .47628 .44808 Mtetra
.27 .445 .851 r
.47628 .44808 .48539 .46384 .50171 .47189 .49261 .45553 Mtetra
.317 .465 .851 r
.49261 .45553 .50171 .47189 .51827 .47911 .50916 .46218 Mtetra
.371 .489 .849 r
.50916 .46218 .51827 .47911 .53505 .48511 .52594 .46765 Mtetra
.427 .516 .846 r
.52594 .46765 .53505 .48511 .55204 .4895 .54293 .47157 Mtetra
.484 .542 .841 r
.54293 .47157 .55204 .4895 .5692 .49192 .5601 .4736 Mtetra
.537 .567 .833 r
.5601 .4736 .5692 .49192 .58651 .49206 .57741 .47345 Mtetra
.586 .59 .823 r
.57741 .47345 .58651 .49206 .60393 .48972 .59484 .47092 Mtetra
.629 .611 .813 r
.59484 .47092 .60393 .48972 .62141 .48476 .61235 .46587 Mtetra
.667 .629 .802 r
.61235 .46587 .62141 .48476 .63891 .47715 .62989 .45828 Mtetra
.699 .645 .792 r
.62989 .45828 .63891 .47715 .6564 .46696 .64743 .44822 Mtetra
.726 .659 .783 r
.64743 .44822 .6564 .46696 .67385 .45437 .66493 .43585 Mtetra
.749 .672 .776 r
.66493 .43585 .67385 .45437 .69122 .43963 .68238 .42142 Mtetra
.767 .683 .77 r
.68238 .42142 .69122 .43963 .7085 .42307 .69974 .40524 Mtetra
.783 .693 .765 r
.69974 .40524 .7085 .42307 .72568 .40506 .71702 .38766 Mtetra
.795 .703 .763 r
.71702 .38766 .72568 .40506 .74276 .386 .73421 .36907 Mtetra
.804 .711 .763 r
.73421 .36907 .74276 .386 .75977 .36628 .75133 .34985 Mtetra
.81 .72 .765 r
.75133 .34985 .75977 .36628 .7767 .3463 .76838 .33036 Mtetra
.815 .727 .768 r
.76838 .33036 .7767 .3463 .79359 .32639 .7854 .31093 Mtetra
.816 .735 .774 r
.7854 .31093 .79359 .32639 .81047 .30685 .80241 .29186 Mtetra
.816 .741 .782 r
.80241 .29186 .81047 .30685 .82736 .28795 .81944 .27339 Mtetra
.636 .731 .917 r
.18525 .40156 .19509 .41087 .20916 .40695 .19936 .39754 Mtetra
.627 .727 .919 r
.19936 .39754 .20916 .40695 .22329 .40331 .21354 .39378 Mtetra
.616 .722 .922 r
.21354 .39378 .22329 .40331 .23747 .40003 .22777 .39037 Mtetra
.602 .716 .925 r
.22777 .39037 .23747 .40003 .25171 .39718 .24205 .38736 Mtetra
.585 .708 .927 r
.24205 .38736 .25171 .39718 .266 .39485 .2564 .38484 Mtetra
.564 .697 .93 r
.2564 .38484 .266 .39485 .28035 .39313 .27079 .38291 Mtetra
.539 .683 .932 r
.27079 .38291 .28035 .39313 .29476 .39212 .28525 .38165 Mtetra
.51 .666 .933 r
.28525 .38165 .29476 .39212 .30923 .39191 .29977 .38114 Mtetra
.477 .646 .932 r
.29977 .38114 .30923 .39191 .32378 .39259 .31436 .38147 Mtetra
.44 .622 .929 r
.31436 .38147 .32378 .39259 .3384 .39421 .32903 .38271 Mtetra
.402 .595 .923 r
.32903 .38271 .3384 .39421 .35312 .39685 .34379 .38491 Mtetra
.362 .565 .915 r
.34379 .38491 .35312 .39685 .36795 .40051 .35865 .38807 Mtetra
.326 .535 .904 r
.35865 .38807 .36795 .40051 .3829 .40519 .37364 .3922 Mtetra
.294 .507 .892 r
.37364 .3922 .3829 .40519 .39799 .41084 .38876 .39724 Mtetra
.27 .482 .88 r
.38876 .39724 .39799 .41084 .41325 .41734 .40404 .4031 Mtetra
.257 .462 .868 r
.40404 .4031 .41325 .41734 .42869 .42456 .41951 .40962 Mtetra
.256 .449 .859 r
.41951 .40962 .42869 .42456 .44433 .43226 .43516 .4166 Mtetra
.267 .444 .851 r
.43516 .4166 .44433 .43226 .46019 .44021 .45103 .42381 Mtetra
.289 .447 .845 r
.45103 .42381 .46019 .44021 .47628 .44808 .46713 .43093 Mtetra
.322 .456 .841 r
.46713 .43093 .47628 .44808 .49261 .45553 .48345 .43765 Mtetra
.362 .471 .836 r
.48345 .43765 .49261 .45553 .50916 .46218 .5 .44361 Mtetra
.407 .489 .832 r
.5 .44361 .50916 .46218 .52594 .46765 .51678 .44844 Mtetra
.454 .509 .826 r
.51678 .44844 .52594 .46765 .54293 .47157 .53375 .45181 Mtetra
.501 .531 .819 r
.53375 .45181 .54293 .47157 .5601 .4736 .55092 .45337 Mtetra
.546 .551 .811 r
.55092 .45337 .5601 .4736 .57741 .47345 .56823 .45288 Mtetra
.588 .571 .802 r
.56823 .45288 .57741 .47345 .59484 .47092 .58567 .45011 Mtetra
.625 .59 .794 r
.58567 .45011 .59484 .47092 .61235 .46587 .60319 .44497 Mtetra
.659 .606 .785 r
.60319 .44497 .61235 .46587 .62989 .45828 .62076 .43742 Mtetra
.688 .622 .777 r
.62076 .43742 .62989 .45828 .64743 .44822 .63833 .42753 Mtetra
.713 .636 .77 r
.63833 .42753 .64743 .44822 .66493 .43585 .65589 .41545 Mtetra
.734 .649 .764 r
.65589 .41545 .66493 .43585 .68238 .42142 .67339 .40141 Mtetra
.752 .661 .76 r
.67339 .40141 .68238 .42142 .69974 .40524 .69084 .3857 Mtetra
.767 .672 .758 r
.69084 .3857 .69974 .40524 .71702 .38766 .70821 .36867 Mtetra
.779 .682 .757 r
.70821 .36867 .71702 .38766 .73421 .36907 .7255 .35067 Mtetra
.789 .692 .758 r
.7255 .35067 .73421 .36907 .75133 .34985 .74273 .33206 Mtetra
.796 .701 .76 r
.74273 .33206 .75133 .34985 .76838 .33036 .75991 .31319 Mtetra
.801 .71 .765 r
.75991 .31319 .76838 .33036 .7854 .31093 .77706 .29437 Mtetra
.803 .719 .771 r
.77706 .29437 .7854 .31093 .80241 .29186 .7942 .27588 Mtetra
.803 .726 .779 r
.7942 .27588 .80241 .29186 .81944 .27339 .81137 .25795 Mtetra
.638 .731 .916 r
.17531 .39214 .18525 .40156 .19936 .39754 .18947 .38801 Mtetra
.63 .727 .918 r
.18947 .38801 .19936 .39754 .21354 .39378 .20369 .38412 Mtetra
.619 .723 .92 r
.20369 .38412 .21354 .39378 .22777 .39037 .21797 .38056 Mtetra
.606 .716 .922 r
.21797 .38056 .22777 .39037 .24205 .38736 .23231 .37737 Mtetra
.591 .708 .925 r
.23231 .37737 .24205 .38736 .2564 .38484 .2467 .37465 Mtetra
.572 .698 .927 r
.2467 .37465 .2564 .38484 .27079 .38291 .26115 .37247 Mtetra
.55 .685 .928 r
.26115 .37247 .27079 .38291 .28525 .38165 .27566 .37093 Mtetra
.523 .669 .928 r
.27566 .37093 .28525 .38165 .29977 .38114 .29023 .37009 Mtetra
.494 .649 .927 r
.29023 .37009 .29977 .38114 .31436 .38147 .30487 .37004 Mtetra
.462 .627 .924 r
.30487 .37004 .31436 .38147 .32903 .38271 .31958 .37083 Mtetra
.428 .602 .919 r
.31958 .37083 .32903 .38271 .34379 .38491 .33439 .37252 Mtetra
.394 .575 .911 r
.33439 .37252 .34379 .38491 .35865 .38807 .3493 .37513 Mtetra
.363 .547 .901 r
.3493 .37513 .35865 .38807 .37364 .3922 .36432 .37863 Mtetra
.337 .521 .89 r
.36432 .37863 .37364 .3922 .38876 .39724 .37948 .38298 Mtetra
.317 .498 .878 r
.37948 .38298 .38876 .39724 .40404 .4031 .39479 .38809 Mtetra
.307 .479 .866 r
.39479 .38809 .40404 .4031 .41951 .40962 .41028 .39382 Mtetra
.307 .467 .856 r
.41028 .39382 .41951 .40962 .43516 .4166 .42595 .39998 Mtetra
.317 .46 .846 r
.42595 .39998 .43516 .4166 .45103 .42381 .44184 .40634 Mtetra
.336 .46 .838 r
.44184 .40634 .45103 .42381 .46713 .43093 .45793 .41262 Mtetra
.364 .466 .831 r
.45793 .41262 .46713 .43093 .48345 .43765 .47425 .41851 Mtetra
.398 .476 .824 r
.47425 .41851 .48345 .43765 .5 .44361 .4908 .42368 Mtetra
.436 .49 .817 r
.4908 .42368 .5 .44361 .51678 .44844 .50756 .42779 Mtetra
.476 .506 .81 r
.50756 .42779 .51678 .44844 .53375 .45181 .52453 .43052 Mtetra
.515 .523 .802 r
.52453 .43052 .53375 .45181 .55092 .45337 .54168 .43156 Mtetra
.554 .541 .795 r
.54168 .43156 .55092 .45337 .56823 .45288 .55899 .43067 Mtetra
.589 .558 .787 r
.55899 .43067 .56823 .45288 .58567 .45011 .57643 .42765 Mtetra
.622 .574 .779 r
.57643 .42765 .58567 .45011 .60319 .44497 .59395 .42241 Mtetra
.652 .59 .772 r
.59395 .42241 .60319 .44497 .62076 .43742 .61154 .41491 Mtetra
.678 .604 .766 r
.61154 .41491 .62076 .43742 .63833 .42753 .62914 .40521 Mtetra
.701 .618 .76 r
.62914 .40521 .63833 .42753 .65589 .41545 .64674 .39346 Mtetra
.721 .631 .756 r
.64674 .39346 .65589 .41545 .67339 .40141 .6643 .37988 Mtetra
.738 .643 .753 r
.6643 .37988 .67339 .40141 .69084 .3857 .68181 .36473 Mtetra
.753 .654 .752 r
.68181 .36473 .69084 .3857 .70821 .36867 .69927 .34833 Mtetra
.765 .665 .752 r
.69927 .34833 .70821 .36867 .7255 .35067 .71667 .33101 Mtetra
.775 .676 .754 r
.71667 .33101 .7255 .35067 .74273 .33206 .73401 .31312 Mtetra
.782 .686 .758 r
.73401 .31312 .74273 .33206 .75991 .31319 .75131 .29497 Mtetra
.787 .696 .763 r
.75131 .29497 .75991 .31319 .77706 .29437 .76859 .27686 Mtetra
.791 .705 .77 r
.76859 .27686 .77706 .29437 .7942 .27588 .78587 .25906 Mtetra
.792 .714 .778 r
.78587 .25906 .7942 .27588 .81137 .25795 .80317 .24177 Mtetra
.64 .731 .915 r
.16527 .3826 .17531 .39214 .18947 .38801 .17948 .37835 Mtetra
.632 .728 .917 r
.17948 .37835 .18947 .38801 .20369 .38412 .19375 .37434 Mtetra
.623 .723 .918 r
.19375 .37434 .20369 .38412 .21797 .38056 .20808 .37061 Mtetra
.611 .717 .92 r
.20808 .37061 .21797 .38056 .23231 .37737 .22247 .36724 Mtetra
.597 .709 .922 r
.22247 .36724 .23231 .37737 .2467 .37465 .23692 .36429 Mtetra
.58 .699 .924 r
.23692 .36429 .2467 .37465 .26115 .37247 .25142 .36185 Mtetra
.56 .687 .925 r
.25142 .36185 .26115 .37247 .27566 .37093 .26598 .35999 Mtetra
.537 .672 .925 r
.26598 .35999 .27566 .37093 .29023 .37009 .2806 .35879 Mtetra
.511 .654 .923 r
.2806 .35879 .29023 .37009 .30487 .37004 .2953 .35832 Mtetra
.483 .633 .92 r
.2953 .35832 .30487 .37004 .31958 .37083 .31007 .35863 Mtetra
.453 .61 .915 r
.31007 .35863 .31958 .37083 .33439 .37252 .32492 .35977 Mtetra
.424 .585 .907 r
.32492 .35977 .33439 .37252 .3493 .37513 .33988 .36176 Mtetra
.398 .56 .898 r
.33988 .36176 .3493 .37513 .36432 .37863 .35495 .36457 Mtetra
.376 .536 .887 r
.35495 .36457 .36432 .37863 .37948 .38298 .37014 .36818 Mtetra
.359 .514 .875 r
.37014 .36818 .37948 .38298 .39479 .38809 .38549 .37247 Mtetra
.351 .496 .864 r
.38549 .37247 .39479 .38809 .41028 .39382 .40101 .37734 Mtetra
.351 .483 .852 r
.40101 .37734 .41028 .39382 .42595 .39998 .4167 .3826 Mtetra
.36 .475 .842 r
.4167 .3826 .42595 .39998 .44184 .40634 .4326 .38803 Mtetra
.376 .473 .832 r
.4326 .38803 .44184 .40634 .45793 .41262 .4487 .39338 Mtetra
.399 .476 .823 r
.4487 .39338 .45793 .41262 .47425 .41851 .46502 .39836 Mtetra
.428 .483 .814 r
.46502 .39836 .47425 .41851 .4908 .42368 .48156 .40267 Mtetra
.46 .493 .806 r
.48156 .40267 .4908 .42368 .50756 .42779 .49831 .406 Mtetra
.493 .505 .798 r
.49831 .406 .50756 .42779 .52453 .43052 .51527 .40803 Mtetra
.527 .519 .79 r
.51527 .40803 .52453 .43052 .54168 .43156 .53241 .4085 Mtetra
.56 .534 .783 r
.53241 .4085 .54168 .43156 .55899 .43067 .5497 .40718 Mtetra
.591 .549 .776 r
.5497 .40718 .55899 .43067 .57643 .42765 .56713 .4039 Mtetra
.62 .563 .769 r
.56713 .4039 .57643 .42765 .59395 .42241 .58465 .39854 Mtetra
.646 .577 .763 r
.58465 .39854 .59395 .42241 .61154 .41491 .60225 .3911 Mtetra
.67 .591 .758 r
.60225 .3911 .61154 .41491 .62914 .40521 .61987 .38163 Mtetra
.691 .604 .754 r
.61987 .38163 .62914 .40521 .64674 .39346 .6375 .37025 Mtetra
.71 .617 .751 r
.6375 .37025 .64674 .39346 .6643 .37988 .65512 .35717 Mtetra
.727 .629 .749 r
.65512 .35717 .6643 .37988 .68181 .36473 .6727 .34263 Mtetra
.741 .64 .749 r
.6727 .34263 .68181 .36473 .69927 .34833 .69023 .32693 Mtetra
.752 .652 .75 r
.69023 .32693 .69927 .34833 .71667 .33101 .70772 .31037 Mtetra
.762 .663 .752 r
.70772 .31037 .71667 .33101 .73401 .31312 .72517 .29326 Mtetra
.77 .673 .757 r
.72517 .29326 .73401 .31312 .75131 .29497 .74259 .27591 Mtetra
.775 .684 .763 r
.74259 .27591 .75131 .29497 .76859 .27686 .76 .25859 Mtetra
.779 .694 .77 r
.76 .25859 .76859 .27686 .78587 .25906 .77741 .24154 Mtetra
.78 .703 .778 r
.77741 .24154 .78587 .25906 .80317 .24177 .79486 .22496 Mtetra
.642 .732 .914 r
.15513 .37296 .16527 .3826 .17948 .37835 .16939 .36859 Mtetra
.635 .728 .915 r
.16939 .36859 .17948 .37835 .19375 .37434 .18371 .36443 Mtetra
.626 .724 .917 r
.18371 .36443 .19375 .37434 .20808 .37061 .1981 .36053 Mtetra
.616 .718 .918 r
.1981 .36053 .20808 .37061 .22247 .36724 .21254 .35696 Mtetra
.603 .71 .92 r
.21254 .35696 .22247 .36724 .23692 .36429 .22704 .35378 Mtetra
.588 .701 .921 r
.22704 .35378 .23692 .36429 .25142 .36185 .2416 .35106 Mtetra
.57 .689 .921 r
.2416 .35106 .25142 .36185 .26598 .35999 .25621 .34888 Mtetra
.55 .675 .921 r
.25621 .34888 .26598 .35999 .2806 .35879 .2709 .34729 Mtetra
.527 .659 .919 r
.2709 .34729 .2806 .35879 .2953 .35832 .28565 .34638 Mtetra
.502 .64 .916 r
.28565 .34638 .2953 .35832 .31007 .35863 .30047 .34618 Mtetra
.477 .618 .911 r
.30047 .34618 .31007 .35863 .32492 .35977 .31538 .34673 Mtetra
.452 .595 .904 r
.31538 .34673 .32492 .35977 .33988 .36176 .33039 .34806 Mtetra
.429 .572 .895 r
.33039 .34806 .33988 .36176 .35495 .36457 .34551 .35015 Mtetra
.41 .55 .884 r
.34551 .35015 .35495 .36457 .37014 .36818 .36075 .35295 Mtetra
.397 .529 .873 r
.36075 .35295 .37014 .36818 .38549 .37247 .37614 .35639 Mtetra
.389 .512 .861 r
.37614 .35639 .38549 .37247 .40101 .37734 .39168 .36034 Mtetra
.389 .499 .849 r
.39168 .36034 .40101 .37734 .4167 .3826 .40741 .36464 Mtetra
.396 .49 .838 r
.40741 .36464 .4167 .3826 .4326 .38803 .42332 .3691 Mtetra
.41 .486 .827 r
.42332 .3691 .4326 .38803 .4487 .39338 .43943 .37347 Mtetra
.429 .486 .817 r
.43943 .37347 .4487 .39338 .46502 .39836 .45576 .3775 Mtetra
.453 .491 .808 r
.45576 .3775 .46502 .39836 .48156 .40267 .47229 .3809 Mtetra
.48 .498 .799 r
.47229 .3809 .48156 .40267 .49831 .406 .48903 .38339 Mtetra
.508 .507 .79 r
.48903 .38339 .49831 .406 .51527 .40803 .50597 .3847 Mtetra
.537 .518 .782 r
.50597 .3847 .51527 .40803 .53241 .4085 .52309 .38457 Mtetra
.566 .53 .775 r
.52309 .38457 .53241 .4085 .5497 .40718 .54037 .3828 Mtetra
.593 .543 .768 r
.54037 .3828 .5497 .40718 .56713 .4039 .55779 .37923 Mtetra
.618 .556 .762 r
.55779 .37923 .56713 .4039 .58465 .39854 .57531 .37376 Mtetra
.642 .569 .757 r
.57531 .37376 .58465 .39854 .60225 .3911 .5929 .36638 Mtetra
.664 .581 .753 r
.5929 .36638 .60225 .3911 .61987 .38163 .61055 .35714 Mtetra
.683 .594 .749 r
.61055 .35714 .61987 .38163 .6375 .37025 .62821 .34615 Mtetra
.701 .606 .747 r
.62821 .34615 .6375 .37025 .65512 .35717 .64586 .3336 Mtetra
.716 .618 .747 r
.64586 .3336 .65512 .35717 .6727 .34263 .6635 .31971 Mtetra
.73 .63 .747 r
.6635 .31971 .6727 .34263 .69023 .32693 .68112 .30475 Mtetra
.741 .641 .749 r
.68112 .30475 .69023 .32693 .70772 .31037 .6987 .289 Mtetra
.751 .652 .752 r
.6987 .289 .70772 .31037 .72517 .29326 .71625 .27273 Mtetra
.758 .663 .757 r
.71625 .27273 .72517 .29326 .74259 .27591 .73379 .25623 Mtetra
.764 .674 .763 r
.73379 .25623 .74259 .27591 .76 .25859 .75132 .23975 Mtetra
.767 .684 .771 r
.75132 .23975 .76 .25859 .77741 .24154 .76887 .22351 Mtetra
.769 .694 .78 r
.76887 .22351 .77741 .24154 .79486 .22496 .78645 .20768 Mtetra
.644 .732 .913 r
.14489 .36321 .15513 .37296 .16939 .36859 .1592 .35871 Mtetra
.638 .729 .914 r
.1592 .35871 .16939 .36859 .18371 .36443 .17357 .35441 Mtetra
.63 .724 .915 r
.17357 .35441 .18371 .36443 .1981 .36053 .18801 .35034 Mtetra
.62 .719 .917 r
.18801 .35034 .1981 .36053 .21254 .35696 .20251 .34656 Mtetra
.609 .712 .918 r
.20251 .34656 .21254 .35696 .22704 .35378 .21706 .34314 Mtetra
.596 .703 .918 r
.21706 .34314 .22704 .35378 .2416 .35106 .23168 .34013 Mtetra
.58 .692 .919 r
.23168 .34013 .2416 .35106 .25621 .34888 .24636 .33761 Mtetra
.562 .679 .918 r
.24636 .33761 .25621 .34888 .2709 .34729 .2611 .33563 Mtetra
.542 .664 .916 r
.2611 .33563 .2709 .34729 .28565 .34638 .27591 .33425 Mtetra
.521 .646 .913 r
.27591 .33425 .28565 .34638 .30047 .34618 .29079 .33352 Mtetra
.499 .627 .908 r
.29079 .33352 .30047 .34618 .31538 .34673 .30576 .33348 Mtetra
.478 .606 .901 r
.30576 .33348 .31538 .34673 .33039 .34806 .32083 .33413 Mtetra
.458 .585 .892 r
.32083 .33413 .33039 .34806 .34551 .35015 .336 .33547 Mtetra
.442 .564 .882 r
.336 .33547 .34551 .35015 .36075 .35295 .35129 .33745 Mtetra
.43 .544 .871 r
.35129 .33745 .36075 .35295 .37614 .35639 .36673 .34 Mtetra
.423 .527 .859 r
.36673 .34 .37614 .35639 .39168 .36034 .38231 .343 Mtetra
.423 .514 .847 r
.38231 .343 .39168 .36034 .40741 .36464 .39806 .34632 Mtetra
.428 .505 .835 r
.39806 .34632 .40741 .36464 .42332 .3691 .414 .34977 Mtetra
.439 .499 .824 r
.414 .34977 .42332 .3691 .43943 .37347 .43013 .35314 Mtetra
.455 .498 .813 r
.43013 .35314 .43943 .37347 .45576 .3775 .44646 .35618 Mtetra
.475 .499 .803 r
.44646 .35618 .45576 .3775 .47229 .3809 .46299 .35866 Mtetra
.498 .504 .794 r
.46299 .35866 .47229 .3809 .48903 .38339 .47972 .3603 Mtetra
.522 .511 .785 r
.47972 .3603 .48903 .38339 .50597 .3847 .49665 .36086 Mtetra
.546 .52 .777 r
.49665 .36086 .50597 .3847 .52309 .38457 .51375 .36011 Mtetra
.571 .53 .77 r
.51375 .36011 .52309 .38457 .54037 .3828 .53102 .35788 Mtetra
.595 .541 .764 r
.53102 .35788 .54037 .3828 .55779 .37923 .54842 .35401 Mtetra
.618 .552 .758 r
.54842 .35401 .55779 .37923 .57531 .37376 .56593 .34843 Mtetra
.639 .564 .754 r
.56593 .34843 .57531 .37376 .5929 .36638 .58353 .34112 Mtetra
.659 .575 .75 r
.58353 .34112 .5929 .36638 .61055 .35714 .60118 .33211 Mtetra
.677 .587 .748 r
.60118 .33211 .61055 .35714 .62821 .34615 .61886 .32153 Mtetra
.693 .599 .746 r
.61886 .32153 .62821 .34615 .64586 .3336 .63656 .30952 Mtetra
.707 .61 .746 r
.63656 .30952 .64586 .3336 .6635 .31971 .65426 .2963 Mtetra
.72 .622 .747 r
.65426 .2963 .6635 .31971 .68112 .30475 .67194 .28209 Mtetra
.731 .633 .75 r
.67194 .28209 .68112 .30475 .6987 .289 .6896 .26716 Mtetra
.74 .645 .754 r
.6896 .26716 .6987 .289 .71625 .27273 .70726 .25176 Mtetra
.748 .656 .759 r
.70726 .25176 .71625 .27273 .73379 .25623 .7249 .23614 Mtetra
.753 .667 .766 r
.7249 .23614 .73379 .25623 .75132 .23975 .74256 .22052 Mtetra
.757 .677 .774 r
.74256 .22052 .75132 .23975 .76887 .22351 .76023 .20511 Mtetra
.759 .688 .783 r
.76023 .20511 .76887 .22351 .78645 .20768 .77795 .19007 Mtetra
.646 .733 .912 r
.13454 .35336 .14489 .36321 .1592 .35871 .1489 .34874 Mtetra
.64 .729 .913 r
.1489 .34874 .1592 .35871 .17357 .35441 .16333 .34428 Mtetra
.633 .725 .914 r
.16333 .34428 .17357 .35441 .18801 .35034 .17782 .34004 Mtetra
.625 .72 .915 r
.17782 .34004 .18801 .35034 .20251 .34656 .19237 .33606 Mtetra
.615 .714 .916 r
.19237 .33606 .20251 .34656 .21706 .34314 .20699 .33239 Mtetra
.603 .706 .916 r
.20699 .33239 .21706 .34314 .23168 .34013 .22166 .32909 Mtetra
.589 .696 .916 r
.22166 .32909 .23168 .34013 .24636 .33761 .2364 .32622 Mtetra
.574 .684 .915 r
.2364 .32622 .24636 .33761 .2611 .33563 .25121 .32384 Mtetra
.557 .67 .913 r
.25121 .32384 .2611 .33563 .27591 .33425 .26608 .322 Mtetra
.538 .654 .91 r
.26608 .322 .27591 .33425 .29079 .33352 .28103 .32074 Mtetra
.519 .636 .905 r
.28103 .32074 .29079 .33352 .30576 .33348 .29606 .32008 Mtetra
.501 .617 .898 r
.29606 .32008 .30576 .33348 .32083 .33413 .31119 .32005 Mtetra
.484 .597 .89 r
.31119 .32005 .32083 .33413 .336 .33547 .32642 .32063 Mtetra
.47 .577 .881 r
.32642 .32063 .336 .33547 .35129 .33745 .34177 .32178 Mtetra
.459 .559 .87 r
.34177 .32178 .35129 .33745 .36673 .34 .35725 .32344 Mtetra
.453 .543 .858 r
.35725 .32344 .36673 .34 .38231 .343 .37288 .32549 Mtetra
.452 .53 .846 r
.37288 .32549 .38231 .343 .39806 .34632 .38866 .32783 Mtetra
.456 .519 .834 r
.38866 .32783 .39806 .34632 .414 .34977 .40463 .33026 Mtetra
.465 .513 .823 r
.40463 .33026 .414 .34977 .43013 .35314 .42078 .33262 Mtetra
.478 .51 .812 r
.42078 .33262 .43013 .35314 .44646 .35618 .43712 .33468 Mtetra
.495 .51 .802 r
.43712 .33468 .44646 .35618 .46299 .35866 .45365 .33622 Mtetra
.513 .512 .792 r
.45365 .33622 .46299 .35866 .47972 .3603 .47038 .33701 Mtetra
.534 .517 .783 r
.47038 .33701 .47972 .3603 .49665 .36086 .4873 .33682 Mtetra
.555 .524 .775 r
.4873 .33682 .49665 .36086 .51375 .36011 .50439 .33546 Mtetra
.577 .532 .768 r
.50439 .33546 .51375 .36011 .53102 .35788 .52164 .33276 Mtetra
.598 .541 .762 r
.52164 .33276 .53102 .35788 .54842 .35401 .53902 .3286 Mtetra
.618 .551 .757 r
.53902 .3286 .54842 .35401 .56593 .34843 .55653 .3229 Mtetra
.637 .562 .753 r
.55653 .3229 .56593 .34843 .58353 .34112 .57412 .31565 Mtetra
.655 .572 .75 r
.57412 .31565 .58353 .34112 .60118 .33211 .59178 .30688 Mtetra
.671 .583 .748 r
.59178 .30688 .60118 .33211 .61886 .32153 .60949 .2967 Mtetra
.686 .594 .747 r
.60949 .2967 .61886 .32153 .63656 .30952 .62722 .28523 Mtetra
.7 .606 .748 r
.62722 .28523 .63656 .30952 .65426 .2963 .64497 .27267 Mtetra
.712 .617 .75 r
.64497 .27267 .65426 .2963 .67194 .28209 .66271 .25922 Mtetra
.722 .628 .753 r
.66271 .25922 .67194 .28209 .6896 .26716 .68046 .24512 Mtetra
.731 .639 .757 r
.68046 .24512 .6896 .26716 .70726 .25176 .69821 .23058 Mtetra
.738 .651 .763 r
.69821 .23058 .70726 .25176 .7249 .23614 .71596 .21583 Mtetra
.743 .662 .77 r
.71596 .21583 .7249 .23614 .74256 .22052 .73373 .20108 Mtetra
.747 .672 .778 r
.73373 .20108 .74256 .22052 .76023 .20511 .75153 .1865 Mtetra
.749 .683 .787 r
.75153 .1865 .76023 .20511 .77795 .19007 .76938 .17225 Mtetra
.648 .733 .911 r
.12409 .34341 .13454 .35336 .1489 .34874 .1385 .33866 Mtetra
.643 .73 .912 r
.1385 .33866 .1489 .34874 .16333 .34428 .15298 .33406 Mtetra
.637 .727 .913 r
.15298 .33406 .16333 .34428 .17782 .34004 .16753 .32964 Mtetra
.63 .722 .914 r
.16753 .32964 .17782 .34004 .19237 .33606 .18214 .32545 Mtetra
.621 .716 .914 r
.18214 .32545 .19237 .33606 .20699 .33239 .19681 .32154 Mtetra
.61 .708 .914 r
.19681 .32154 .20699 .33239 .22166 .32909 .21155 .31795 Mtetra
.598 .699 .914 r
.21155 .31795 .22166 .32909 .2364 .32622 .22635 .31474 Mtetra
.585 .688 .913 r
.22635 .31474 .2364 .32622 .25121 .32384 .24122 .31196 Mtetra
.57 .676 .911 r
.24122 .31196 .25121 .32384 .26608 .322 .25616 .30966 Mtetra
.554 .661 .908 r
.25616 .30966 .26608 .322 .28103 .32074 .27117 .30787 Mtetra
.538 .645 .903 r
.27117 .30787 .28103 .32074 .29606 .32008 .28627 .30661 Mtetra
.522 .627 .897 r
.28627 .30661 .29606 .32008 .31119 .32005 .30146 .3059 Mtetra
.508 .609 .889 r
.30146 .3059 .31119 .32005 .32642 .32063 .31676 .30573 Mtetra
.495 .591 .88 r
.31676 .30573 .32642 .32063 .34177 .32178 .33216 .30606 Mtetra
.486 .574 .869 r
.33216 .30606 .34177 .32178 .35725 .32344 .3477 .30684 Mtetra
.48 .558 .858 r
.3477 .30684 .35725 .32344 .37288 .32549 .36337 .30796 Mtetra
.479 .545 .847 r
.36337 .30796 .37288 .32549 .38866 .32783 .3792 .30932 Mtetra
.481 .535 .835 r
.3792 .30932 .38866 .32783 .40463 .33026 .3952 .31076 Mtetra
.488 .527 .823 r
.3952 .31076 .40463 .33026 .42078 .33262 .41137 .31213 Mtetra
.499 .523 .812 r
.41137 .31213 .42078 .33262 .43712 .33468 .42773 .31322 Mtetra
.512 .521 .802 r
.42773 .31322 .43712 .33468 .45365 .33622 .44427 .31384 Mtetra
.528 .522 .793 r
.44427 .31384 .45365 .33622 .47038 .33701 .461 .31379 Mtetra
.545 .525 .784 r
.461 .31379 .47038 .33701 .4873 .33682 .47791 .31287 Mtetra
.564 .53 .776 r
.47791 .31287 .4873 .33682 .50439 .33546 .49499 .31091 Mtetra
.582 .537 .769 r
.49499 .31091 .50439 .33546 .52164 .33276 .51223 .30776 Mtetra
.601 .544 .763 r
.51223 .30776 .52164 .33276 .53902 .3286 .52961 .30331 Mtetra
.619 .553 .759 r
.52961 .30331 .53902 .3286 .55653 .3229 .5471 .29749 Mtetra
.636 .562 .755 r
.5471 .29749 .55653 .3229 .57412 .31565 .56469 .29029 Mtetra
.652 .572 .752 r
.56469 .29029 .57412 .31565 .59178 .30688 .58236 .28175 Mtetra
.667 .582 .751 r
.58236 .28175 .59178 .30688 .60949 .2967 .60009 .27195 Mtetra
.681 .593 .75 r
.60009 .27195 .60949 .2967 .62722 .28523 .61785 .26101 Mtetra
.693 .604 .751 r
.61785 .26101 .62722 .28523 .64497 .27267 .63564 .24909 Mtetra
.704 .614 .754 r
.63564 .24909 .64497 .27267 .66271 .25922 .65345 .23638 Mtetra
.714 .625 .757 r
.65345 .23638 .66271 .25922 .68046 .24512 .67127 .22308 Mtetra
.723 .637 .762 r
.67127 .22308 .68046 .24512 .69821 .23058 .68911 .20939 Mtetra
.729 .648 .768 r
.68911 .20939 .69821 .23058 .71596 .21583 .70696 .1955 Mtetra
.735 .659 .775 r
.70696 .1955 .71596 .21583 .73373 .20108 .72485 .18159 Mtetra
.738 .669 .783 r
.72485 .18159 .73373 .20108 .75153 .1865 .74277 .16784 Mtetra
.74 .68 .792 r
.74277 .16784 .75153 .1865 .76938 .17225 .76075 .15436 Mtetra
.65 .734 .911 r
.11352 .33336 .12409 .34341 .1385 .33866 .12799 .32849 Mtetra
.645 .731 .911 r
.12799 .32849 .1385 .33866 .15298 .33406 .14252 .32374 Mtetra
.64 .728 .912 r
.14252 .32374 .15298 .33406 .16753 .32964 .15712 .31915 Mtetra
.634 .723 .912 r
.15712 .31915 .16753 .32964 .18214 .32545 .17179 .31476 Mtetra
.626 .718 .913 r
.17179 .31476 .18214 .32545 .19681 .32154 .18653 .3106 Mtetra
.617 .711 .913 r
.18653 .3106 .19681 .32154 .21155 .31795 .20133 .30673 Mtetra
.607 .703 .912 r
.20133 .30673 .21155 .31795 .22635 .31474 .21619 .30319 Mtetra
.595 .693 .911 r
.21619 .30319 .22635 .31474 .24122 .31196 .23113 .30003 Mtetra
.582 .682 .909 r
.23113 .30003 .24122 .31196 .25616 .30966 .24614 .29727 Mtetra
.569 .669 .906 r
.24614 .29727 .25616 .30966 .27117 .30787 .26122 .29496 Mtetra
.555 .654 .901 r
.26122 .29496 .27117 .30787 .28627 .30661 .27639 .29312 Mtetra
.541 .638 .895 r
.27639 .29312 .28627 .30661 .30146 .3059 .29165 .29176 Mtetra
.529 .621 .888 r
.29165 .29176 .30146 .3059 .31676 .30573 .307 .29086 Mtetra
.518 .605 .88 r
.307 .29086 .31676 .30573 .33216 .30606 .32247 .2904 Mtetra
.509 .589 .87 r
.32247 .2904 .33216 .30606 .3477 .30684 .33807 .29031 Mtetra
.504 .574 .859 r
.33807 .29031 .3477 .30684 .36337 .30796 .3538 .29053 Mtetra
.502 .561 .848 r
.3538 .29053 .36337 .30796 .3792 .30932 .36967 .29095 Mtetra
.504 .55 .837 r
.36967 .29095 .3792 .30932 .3952 .31076 .38571 .29143 Mtetra
.509 .542 .826 r
.38571 .29143 .3952 .31076 .41137 .31213 .40191 .29184 Mtetra
.517 .536 .815 r
.40191 .29184 .41137 .31213 .42773 .31322 .41829 .292 Mtetra
.528 .534 .804 r
.41829 .292 .42773 .31322 .44427 .31384 .43484 .29174 Mtetra
.542 .533 .795 r
.43484 .29174 .44427 .31384 .461 .31379 .45158 .29088 Mtetra
.556 .535 .786 r
.45158 .29088 .461 .31379 .47791 .31287 .46849 .28926 Mtetra
.572 .538 .779 r
.46849 .28926 .47791 .31287 .49499 .31091 .48556 .28671 Mtetra
.588 .543 .772 r
.48556 .28671 .49499 .31091 .51223 .30776 .50279 .28312 Mtetra
.604 .55 .767 r
.50279 .28312 .51223 .30776 .52961 .30331 .52016 .27839 Mtetra
.62 .557 .762 r
.52016 .27839 .52961 .30331 .5471 .29749 .53765 .27245 Mtetra
.635 .565 .759 r
.53765 .27245 .5471 .29749 .56469 .29029 .55524 .2653 Mtetra
.65 .574 .756 r
.55524 .2653 .56469 .29029 .58236 .28175 .57292 .25698 Mtetra
.664 .584 .755 r
.57292 .25698 .58236 .28175 .60009 .27195 .59067 .24754 Mtetra
.676 .593 .755 r
.59067 .24754 .60009 .27195 .61785 .26101 .60846 .23709 Mtetra
.688 .604 .757 r
.60846 .23709 .61785 .26101 .63564 .24909 .62629 .22579 Mtetra
.698 .614 .759 r
.62629 .22579 .63564 .24909 .65345 .23638 .64416 .21378 Mtetra
.707 .625 .763 r
.64416 .21378 .65345 .23638 .67127 .22308 .66205 .20125 Mtetra
.715 .636 .768 r
.66205 .20125 .67127 .22308 .68911 .20939 .67997 .18836 Mtetra
.721 .647 .774 r
.67997 .18836 .68911 .20939 .70696 .1955 .69793 .17529 Mtetra
.726 .657 .781 r
.69793 .17529 .70696 .1955 .72485 .18159 .71592 .1622 Mtetra
.73 .668 .789 r
.71592 .1622 .72485 .18159 .74277 .16784 .73396 .14923 Mtetra
.732 .678 .798 r
.73396 .14923 .74277 .16784 .76075 .15436 .75206 .13649 Mtetra
.651 .734 .91 r
.10285 .32322 .11352 .33336 .12799 .32849 .11737 .31822 Mtetra
.648 .732 .911 r
.11737 .31822 .12799 .32849 .14252 .32374 .13195 .31333 Mtetra
.643 .729 .911 r
.13195 .31333 .14252 .32374 .15712 .31915 .14661 .30858 Mtetra
.638 .725 .911 r
.14661 .30858 .15712 .31915 .17179 .31476 .16134 .30399 Mtetra
.631 .72 .911 r
.16134 .30399 .17179 .31476 .18653 .3106 .17613 .2996 Mtetra
.624 .714 .911 r
.17613 .2996 .18653 .3106 .20133 .30673 .191 .29546 Mtetra
.615 .707 .911 r
.191 .29546 .20133 .30673 .21619 .30319 .20593 .29159 Mtetra
.605 .698 .909 r
.20593 .29159 .21619 .30319 .23113 .30003 .22093 .28805 Mtetra
.594 .688 .907 r
.22093 .28805 .23113 .30003 .24614 .29727 .23601 .28487 Mtetra
.582 .676 .904 r
.23601 .28487 .24614 .29727 .26122 .29496 .25116 .28206 Mtetra
.57 .663 .9 r
.25116 .28206 .26122 .29496 .27639 .29312 .2664 .27966 Mtetra
.559 .648 .895 r
.2664 .27966 .27639 .29312 .29165 .29176 .28173 .27767 Mtetra
.548 .633 .888 r
.28173 .27767 .29165 .29176 .307 .29086 .29716 .27608 Mtetra
.538 .618 .88 r
.29716 .27608 .307 .29086 .32247 .2904 .31269 .27486 Mtetra
.531 .603 .871 r
.31269 .27486 .32247 .2904 .33807 .29031 .32835 .27396 Mtetra
.526 .589 .861 r
.32835 .27396 .33807 .29031 .3538 .29053 .34413 .27332 Mtetra
.523 .577 .851 r
.34413 .27332 .3538 .29053 .36967 .29095 .36006 .27284 Mtetra
.524 .566 .84 r
.36006 .27284 .36967 .29095 .38571 .29143 .37614 .27241 Mtetra
.528 .557 .829 r
.37614 .27241 .38571 .29143 .40191 .29184 .39238 .27191 Mtetra
.535 .551 .818 r
.39238 .27191 .40191 .29184 .41829 .292 .40878 .27118 Mtetra
.543 .547 .809 r
.40878 .27118 .41829 .292 .43484 .29174 .42536 .27009 Mtetra
.554 .546 .799 r
.42536 .27009 .43484 .29174 .45158 .29088 .4421 .26846 Mtetra
.567 .546 .791 r
.4421 .26846 .45158 .29088 .46849 .28926 .45902 .26617 Mtetra
.58 .548 .783 r
.45902 .26617 .46849 .28926 .48556 .28671 .47609 .26307 Mtetra
.594 .552 .777 r
.47609 .26307 .48556 .28671 .50279 .28312 .49332 .25906 Mtetra
.608 .557 .772 r
.49332 .25906 .50279 .28312 .52016 .27839 .51069 .25406 Mtetra
.622 .563 .767 r
.51069 .25406 .52016 .27839 .53765 .27245 .52817 .248 Mtetra
.636 .57 .764 r
.52817 .248 .53765 .27245 .55524 .2653 .54577 .2409 Mtetra
.649 .578 .762 r
.54577 .2409 .55524 .2653 .57292 .25698 .56346 .23276 Mtetra
.661 .587 .761 r
.56346 .23276 .57292 .25698 .59067 .24754 .58122 .22366 Mtetra
.673 .596 .762 r
.58122 .22366 .59067 .24754 .60846 .23709 .59905 .21368 Mtetra
.683 .606 .763 r
.59905 .21368 .60846 .23709 .62629 .22579 .61692 .20294 Mtetra
.693 .616 .766 r
.61692 .20294 .62629 .22579 .64416 .21378 .63484 .19159 Mtetra
.701 .626 .77 r
.63484 .19159 .64416 .21378 .66205 .20125 .65281 .17978 Mtetra
.709 .637 .775 r
.65281 .17978 .66205 .20125 .67997 .18836 .67081 .16764 Mtetra
.714 .647 .781 r
.67081 .16764 .67997 .18836 .69793 .17529 .68885 .15534 Mtetra
.719 .658 .788 r
.68885 .15534 .69793 .17529 .71592 .1622 .70694 .14301 Mtetra
.722 .668 .797 r
.70694 .14301 .71592 .1622 .73396 .14923 .7251 .13078 Mtetra
.724 .678 .805 r
.7251 .13078 .73396 .14923 .75206 .13649 .74332 .11874 Mtetra
.653 .735 .91 r
.09206 .31298 .10285 .32322 .11737 .31822 .10663 .30787 Mtetra
.65 .733 .91 r
.10663 .30787 .11737 .31822 .13195 .31333 .12127 .30284 Mtetra
.646 .73 .91 r
.12127 .30284 .13195 .31333 .14661 .30858 .13598 .29792 Mtetra
.641 .727 .91 r
.13598 .29792 .14661 .30858 .16134 .30399 .15077 .29314 Mtetra
.636 .722 .91 r
.15077 .29314 .16134 .30399 .17613 .2996 .16563 .28853 Mtetra
.629 .717 .91 r
.16563 .28853 .17613 .2996 .191 .29546 .18055 .28413 Mtetra
.622 .711 .909 r
.18055 .28413 .191 .29546 .20593 .29159 .19555 .27996 Mtetra
.613 .703 .908 r
.19555 .27996 .20593 .29159 .22093 .28805 .21062 .27607 Mtetra
.604 .694 .906 r
.21062 .27607 .22093 .28805 .23601 .28487 .22577 .27247 Mtetra
.594 .683 .903 r
.22577 .27247 .23601 .28487 .25116 .28206 .241 .2692 Mtetra
.584 .671 .899 r
.241 .2692 .25116 .28206 .2664 .27966 .25631 .26627 Mtetra
.574 .659 .895 r
.25631 .26627 .2664 .27966 .28173 .27767 .27171 .26369 Mtetra
.565 .645 .888 r
.27171 .26369 .28173 .27767 .29716 .27608 .2872 .26144 Mtetra
.556 .631 .881 r
.2872 .26144 .29716 .27608 .31269 .27486 .30281 .25951 Mtetra
.55 .617 .873 r
.30281 .25951 .31269 .27486 .32835 .27396 .31853 .25785 Mtetra
.545 .604 .864 r
.31853 .25785 .32835 .27396 .34413 .27332 .33437 .2564 Mtetra
.543 .592 .854 r
.33437 .2564 .34413 .27332 .36006 .27284 .35036 .25508 Mtetra
.543 .582 .844 r
.35036 .25508 .36006 .27284 .37614 .27241 .36648 .2538 Mtetra
.545 .573 .833 r
.36648 .2538 .37614 .27241 .39238 .27191 .38276 .25245 Mtetra
.55 .566 .823 r
.38276 .25245 .39238 .27191 .40878 .27118 .3992 .2509 Mtetra
.558 .562 .814 r
.3992 .2509 .40878 .27118 .42536 .27009 .4158 .24902 Mtetra
.566 .559 .805 r
.4158 .24902 .42536 .27009 .4421 .26846 .43257 .24668 Mtetra
.577 .558 .797 r
.43257 .24668 .4421 .26846 .45902 .26617 .44949 .24376 Mtetra
.588 .56 .79 r
.44949 .24376 .45902 .26617 .47609 .26307 .46657 .24015 Mtetra
.6 .562 .784 r
.46657 .24015 .47609 .26307 .49332 .25906 .4838 .23574 Mtetra
.612 .566 .778 r
.4838 .23574 .49332 .25906 .51069 .25406 .50117 .23048 Mtetra
.625 .571 .774 r
.50117 .23048 .51069 .25406 .52817 .248 .51866 .22431 Mtetra
.637 .578 .771 r
.51866 .22431 .52817 .248 .54577 .2409 .53627 .21723 Mtetra
.648 .585 .77 r
.53627 .21723 .54577 .2409 .56346 .23276 .55397 .20927 Mtetra
.66 .593 .769 r
.55397 .20927 .56346 .23276 .58122 .22366 .57175 .20047 Mtetra
.67 .601 .77 r
.57175 .20047 .58122 .22366 .59905 .21368 .58961 .19091 Mtetra
.68 .61 .771 r
.58961 .19091 .59905 .21368 .61692 .20294 .60753 .1807 Mtetra
.688 .62 .774 r
.60753 .1807 .61692 .20294 .63484 .19159 .6255 .16994 Mtetra
.696 .63 .778 r
.6255 .16994 .63484 .19159 .65281 .17978 .64353 .15878 Mtetra
.703 .64 .783 r
.64353 .15878 .65281 .17978 .67081 .16764 .66161 .14734 Mtetra
.708 .65 .79 r
.66161 .14734 .67081 .16764 .68885 .15534 .67974 .13575 Mtetra
.712 .66 .797 r
.67974 .13575 .68885 .15534 .70694 .14301 .69793 .12413 Mtetra
.715 .67 .805 r
.69793 .12413 .70694 .14301 .7251 .13078 .71619 .11257 Mtetra
.717 .68 .813 r
.71619 .11257 .7251 .13078 .74332 .11874 .73452 .10118 Mtetra
.655 .736 .909 r
.08115 .30265 .09206 .31298 .10663 .30787 .09578 .29742 Mtetra
.652 .734 .909 r
.09578 .29742 .10663 .30787 .12127 .30284 .11047 .29226 Mtetra
.649 .732 .91 r
.11047 .29226 .12127 .30284 .13598 .29792 .12524 .28719 Mtetra
.645 .729 .91 r
.12524 .28719 .13598 .29792 .15077 .29314 .14009 .28223 Mtetra
.64 .725 .91 r
.14009 .28223 .15077 .29314 .16563 .28853 .155 .27741 Mtetra
.634 .72 .909 r
.155 .27741 .16563 .28853 .18055 .28413 .16999 .27276 Mtetra
.628 .714 .908 r
.16999 .27276 .18055 .28413 .19555 .27996 .18506 .26831 Mtetra
.621 .707 .907 r
.18506 .26831 .19555 .27996 .21062 .27607 .2002 .26408 Mtetra
.613 .699 .905 r
.2002 .26408 .21062 .27607 .22577 .27247 .21542 .2601 Mtetra
.605 .69 .903 r
.21542 .2601 .22577 .27247 .241 .2692 .23071 .2564 Mtetra
.596 .68 .899 r
.23071 .2564 .241 .2692 .25631 .26627 .2461 .25298 Mtetra
.588 .668 .895 r
.2461 .25298 .25631 .26627 .27171 .26369 .26157 .24984 Mtetra
.58 .656 .889 r
.26157 .24984 .27171 .26369 .2872 .26144 .27714 .24699 Mtetra
.572 .644 .883 r
.27714 .24699 .2872 .26144 .30281 .25951 .29281 .2444 Mtetra
.567 .631 .875 r
.29281 .2444 .30281 .25951 .31853 .25785 .3086 .24203 Mtetra
.562 .619 .867 r
.3086 .24203 .31853 .25785 .33437 .2564 .32451 .23983 Mtetra
.56 .608 .858 r
.32451 .23983 .33437 .2564 .35036 .25508 .34055 .23774 Mtetra
.56 .598 .848 r
.34055 .23774 .35036 .25508 .36648 .2538 .35673 .23567 Mtetra
.561 .589 .839 r
.35673 .23567 .36648 .2538 .38276 .25245 .37306 .23354 Mtetra
.565 .582 .83 r
.37306 .23354 .38276 .25245 .3992 .2509 .38953 .23122 Mtetra
.571 .577 .821 r
.38953 .23122 .3992 .2509 .4158 .24902 .40617 .22863 Mtetra
.578 .574 .812 r
.40617 .22863 .4158 .24902 .43257 .24668 .42295 .22563 Mtetra
.587 .572 .804 r
.42295 .22563 .43257 .24668 .44949 .24376 .4399 .22213 Mtetra
.596 .572 .797 r
.4399 .22213 .44949 .24376 .46657 .24015 .45699 .21804 Mtetra
.606 .574 .792 r
.45699 .21804 .46657 .24015 .4838 .23574 .47423 .21327 Mtetra
.617 .577 .787 r
.47423 .21327 .4838 .23574 .50117 .23048 .49161 .20776 Mtetra
.628 .581 .783 r
.49161 .20776 .50117 .23048 .51866 .22431 .50911 .20148 Mtetra
.638 .587 .78 r
.50911 .20148 .51866 .22431 .53627 .21723 .52673 .19442 Mtetra
.649 .593 .779 r
.52673 .19442 .53627 .21723 .55397 .20927 .54444 .18661 Mtetra
.659 .6 .778 r
.54444 .18661 .55397 .20927 .57175 .20047 .56225 .17807 Mtetra
.668 .608 .779 r
.56225 .17807 .57175 .20047 .58961 .19091 .58014 .16889 Mtetra
.677 .617 .781 r
.58014 .16889 .58961 .19091 .60753 .1807 .5981 .15914 Mtetra
.685 .625 .784 r
.5981 .15914 .60753 .1807 .6255 .16994 .61613 .14893 Mtetra
.692 .635 .788 r
.61613 .14893 .6255 .16994 .64353 .15878 .63422 .13836 Mtetra
.697 .644 .793 r
.63422 .13836 .64353 .15878 .66161 .14734 .65237 .12754 Mtetra
.702 .654 .799 r
.65237 .12754 .66161 .14734 .67974 .13575 .67059 .11659 Mtetra
.706 .664 .806 r
.67059 .11659 .67974 .13575 .69793 .12413 .68888 .10559 Mtetra
.709 .673 .813 r
.68888 .10559 .69793 .12413 .71619 .11257 .70724 .09465 Mtetra
.71 .682 .822 r
.70724 .09465 .71619 .11257 .73452 .10118 .72568 .08384 Mtetra
.656 .737 .909 r
.07013 .29223 .08115 .30265 .09578 .29742 .0848 .28689 Mtetra
.654 .735 .909 r
.0848 .28689 .09578 .29742 .11047 .29226 .09955 .2816 Mtetra
.651 .733 .909 r
.09955 .2816 .11047 .29226 .12524 .28719 .11438 .27638 Mtetra
.648 .73 .909 r
.11438 .27638 .12524 .28719 .14009 .28223 .12928 .27125 Mtetra
.644 .727 .909 r
.12928 .27125 .14009 .28223 .155 .27741 .14426 .26623 Mtetra
.639 .723 .908 r
.14426 .26623 .155 .27741 .16999 .27276 .15932 .26135 Mtetra
.634 .718 .908 r
.15932 .26135 .16999 .27276 .18506 .26831 .17445 .25664 Mtetra
.628 .712 .907 r
.17445 .25664 .18506 .26831 .2002 .26408 .18965 .2521 Mtetra
.621 .705 .905 r
.18965 .2521 .2002 .26408 .21542 .2601 .20494 .24777 Mtetra
.614 .697 .902 r
.20494 .24777 .21542 .2601 .23071 .2564 .22031 .24366 Mtetra
.607 .687 .899 r
.22031 .24366 .23071 .2564 .2461 .25298 .23577 .23979 Mtetra
.6 .677 .895 r
.23577 .23979 .2461 .25298 .26157 .24984 .25131 .23615 Mtetra
.593 .667 .89 r
.25131 .23615 .26157 .24984 .27714 .24699 .26696 .23274 Mtetra
.587 .656 .885 r
.26696 .23274 .27714 .24699 .29281 .2444 .2827 .22954 Mtetra
.582 .644 .878 r
.2827 .22954 .29281 .2444 .3086 .24203 .29856 .22653 Mtetra
.578 .633 .87 r
.29856 .22653 .3086 .24203 .32451 .23983 .31454 .22365 Mtetra
.575 .623 .862 r
.31454 .22365 .32451 .23983 .34055 .23774 .33064 .22086 Mtetra
.575 .613 .854 r
.33064 .22086 .34055 .23774 .35673 .23567 .34687 .21807 Mtetra
.576 .605 .845 r
.34687 .21807 .35673 .23567 .37306 .23354 .36325 .21522 Mtetra
.579 .598 .836 r
.36325 .21522 .37306 .23354 .38953 .23122 .37977 .21222 Mtetra
.583 .593 .828 r
.37977 .21222 .38953 .23122 .40617 .22863 .39644 .20896 Mtetra
.589 .589 .82 r
.39644 .20896 .40617 .22863 .42295 .22563 .41326 .20537 Mtetra
.596 .587 .813 r
.41326 .20537 .42295 .22563 .4399 .22213 .43023 .20134 Mtetra
.604 .586 .806 r
.43023 .20134 .4399 .22213 .45699 .21804 .44734 .19681 Mtetra
.613 .587 .801 r
.44734 .19681 .45699 .21804 .47423 .21327 .4646 .1917 Mtetra
.622 .589 .796 r
.4646 .1917 .47423 .21327 .49161 .20776 .48199 .18596 Mtetra
.631 .593 .793 r
.48199 .18596 .49161 .20776 .50911 .20148 .49951 .17958 Mtetra
.64 .597 .79 r
.49951 .17958 .50911 .20148 .52673 .19442 .51714 .17253 Mtetra
.649 .603 .789 r
.51714 .17253 .52673 .19442 .54444 .18661 .53488 .16483 Mtetra
.658 .609 .788 r
.53488 .16483 .54444 .18661 .56225 .17807 .55271 .15653 Mtetra
.667 .616 .789 r
.55271 .15653 .56225 .17807 .58014 .16889 .57064 .14767 Mtetra
.674 .624 .791 r
.57064 .14767 .58014 .16889 .5981 .15914 .58864 .13833 Mtetra
.681 .633 .794 r
.58864 .13833 .5981 .15914 .61613 .14893 .60672 .12859 Mtetra
.688 .641 .798 r
.60672 .12859 .61613 .14893 .63422 .13836 .62487 .11854 Mtetra
.693 .65 .803 r
.62487 .11854 .63422 .13836 .65237 .12754 .6431 .10828 Mtetra
.697 .659 .809 r
.6431 .10828 .65237 .12754 .67059 .11659 .6614 .09789 Mtetra
.7 .668 .815 r
.6614 .09789 .67059 .11659 .68888 .10559 .67978 .08746 Mtetra
.703 .677 .823 r
.67978 .08746 .68888 .10559 .70724 .09465 .69823 .07706 Mtetra
.704 .686 .83 r
.69823 .07706 .70724 .09465 .72568 .08384 .71678 .06676 Mtetra
.657 .737 .909 r
.05899 .28171 .07013 .29223 .0848 .28689 .07371 .27626 Mtetra
.655 .736 .909 r
.07371 .27626 .0848 .28689 .09955 .2816 .08852 .27085 Mtetra
.653 .734 .909 r
.08852 .27085 .09955 .2816 .11438 .27638 .1034 .2655 Mtetra
.65 .732 .909 r
.1034 .2655 .11438 .27638 .12928 .27125 .11836 .26021 Mtetra
.647 .729 .908 r
.11836 .26021 .12928 .27125 .14426 .26623 .1334 .25501 Mtetra
.643 .725 .908 r
.1334 .25501 .14426 .26623 .15932 .26135 .14852 .24991 Mtetra
.639 .721 .907 r
.14852 .24991 .15932 .26135 .17445 .25664 .16371 .24495 Mtetra
.634 .716 .906 r
.16371 .24495 .17445 .25664 .18965 .2521 .17899 .24013 Mtetra
.628 .71 .905 r
.17899 .24013 .18965 .2521 .20494 .24777 .19434 .23548 Mtetra
.623 .703 .902 r
.19434 .23548 .20494 .24777 .22031 .24366 .20979 .231 Mtetra
.617 .695 .9 r
.20979 .231 .22031 .24366 .23577 .23979 .22532 .22672 Mtetra
.611 .686 .896 r
.22532 .22672 .23577 .23979 .25131 .23615 .24094 .22262 Mtetra
.605 .677 .892 r
.24094 .22262 .25131 .23615 .26696 .23274 .25665 .21871 Mtetra
.599 .667 .887 r
.25665 .21871 .26696 .23274 .2827 .22954 .27247 .21496 Mtetra
.595 .657 .881 r
.27247 .21496 .2827 .22954 .29856 .22653 .2884 .21137 Mtetra
.591 .647 .874 r
.2884 .21137 .29856 .22653 .31454 .22365 .30444 .20788 Mtetra
.589 .638 .867 r
.30444 .20788 .31454 .22365 .33064 .22086 .32061 .20444 Mtetra
.588 .629 .859 r
.32061 .20444 .33064 .22086 .34687 .21807 .3369 .20102 Mtetra
.589 .621 .851 r
.3369 .20102 .34687 .21807 .36325 .21522 .35333 .19752 Mtetra
.591 .614 .843 r
.35333 .19752 .36325 .21522 .37977 .21222 .3699 .19389 Mtetra
.594 .609 .836 r
.3699 .19389 .37977 .21222 .39644 .20896 .38661 .19005 Mtetra
.599 .605 .829 r
.38661 .19005 .39644 .20896 .41326 .20537 .40347 .18591 Mtetra
.605 .602 .822 r
.40347 .18591 .41326 .20537 .43023 .20134 .42047 .18141 Mtetra
.611 .601 .816 r
.42047 .18141 .43023 .20134 .44734 .19681 .43761 .17648 Mtetra
.619 .601 .811 r
.43761 .17648 .44734 .19681 .4646 .1917 .45489 .17106 Mtetra
.627 .603 .806 r
.45489 .17106 .4646 .1917 .48199 .18596 .4723 .16511 Mtetra
.635 .605 .803 r
.4723 .16511 .48199 .18596 .49951 .17958 .48984 .15862 Mtetra
.643 .609 .801 r
.48984 .15862 .49951 .17958 .51714 .17253 .50749 .15156 Mtetra
.651 .614 .8 r
.50749 .15156 .51714 .17253 .53488 .16483 .52526 .14397 Mtetra
.658 .62 .799 r
.52526 .14397 .53488 .16483 .55271 .15653 .54312 .13586 Mtetra
.666 .626 .8 r
.54312 .13586 .55271 .15653 .57064 .14767 .56109 .12728 Mtetra
.672 .633 .802 r
.56109 .12728 .57064 .14767 .58864 .13833 .57914 .11829 Mtetra
.679 .641 .805 r
.57914 .11829 .58864 .13833 .60672 .12859 .59727 .10896 Mtetra
.684 .649 .809 r
.59727 .10896 .60672 .12859 .62487 .11854 .61549 .09936 Mtetra
.689 .657 .814 r
.61549 .09936 .62487 .11854 .6431 .10828 .63378 .08958 Mtetra
.692 .666 .819 r
.63378 .08958 .6431 .10828 .6614 .09789 .65216 .07968 Mtetra
.695 .674 .825 r
.65216 .07968 .6614 .09789 .67978 .08746 .67063 .06974 Mtetra
.697 .682 .832 r
.67063 .06974 .67978 .08746 .69823 .07706 .68918 .05981 Mtetra
.698 .69 .839 r
.68918 .05981 .69823 .07706 .71678 .06676 .70783 .04996 Mtetra
.658 .738 .908 r
.04772 .27109 .05899 .28171 .07371 .27626 .0625 .26554 Mtetra
.657 .737 .908 r
.0625 .26554 .07371 .27626 .08852 .27085 .07735 .26002 Mtetra
.655 .735 .908 r
.07735 .26002 .08852 .27085 .1034 .2655 .09229 .25453 Mtetra
.653 .733 .908 r
.09229 .25453 .1034 .2655 .11836 .26021 .10731 .24909 Mtetra
.65 .731 .908 r
.10731 .24909 .11836 .26021 .1334 .25501 .12241 .24372 Mtetra
.647 .727 .908 r
.12241 .24372 .1334 .25501 .14852 .24991 .13759 .23843 Mtetra
.643 .724 .907 r
.13759 .23843 .14852 .24991 .16371 .24495 .15285 .23324 Mtetra
.639 .719 .906 r
.15285 .23324 .16371 .24495 .17899 .24013 .16819 .22817 Mtetra
.635 .714 .905 r
.16819 .22817 .17899 .24013 .19434 .23548 .18362 .22322 Mtetra
.63 .708 .903 r
.18362 .22322 .19434 .23548 .20979 .231 .19913 .21841 Mtetra
.625 .702 .9 r
.19913 .21841 .20979 .231 .22532 .22672 .21473 .21376 Mtetra
.62 .694 .897 r
.21473 .21376 .22532 .22672 .24094 .22262 .23043 .20925 Mtetra
.615 .686 .893 r
.23043 .20925 .24094 .22262 .25665 .21871 .24622 .20488 Mtetra
.611 .677 .889 r
.24622 .20488 .25665 .21871 .27247 .21496 .26211 .20065 Mtetra
.607 .669 .884 r
.26211 .20065 .27247 .21496 .2884 .21137 .27811 .19653 Mtetra
.604 .66 .878 r
.27811 .19653 .2884 .21137 .30444 .20788 .29422 .19249 Mtetra
.602 .651 .872 r
.29422 .19249 .30444 .20788 .32061 .20444 .31045 .1885 Mtetra
.601 .643 .865 r
.31045 .1885 .32061 .20444 .3369 .20102 .32681 .18449 Mtetra
.601 .636 .858 r
.32681 .18449 .3369 .20102 .35333 .19752 .34329 .18043 Mtetra
.602 .63 .851 r
.34329 .18043 .35333 .19752 .3699 .19389 .35991 .17624 Mtetra
.605 .624 .844 r
.35991 .17624 .3699 .19389 .38661 .19005 .37667 .17187 Mtetra
.609 .62 .837 r
.37667 .17187 .38661 .19005 .40347 .18591 .39357 .16725 Mtetra
.613 .617 .831 r
.39357 .16725 .40347 .18591 .42047 .18141 .41061 .16232 Mtetra
.619 .616 .826 r
.41061 .16232 .42047 .18141 .43761 .17648 .42778 .15703 Mtetra
.625 .616 .821 r
.42778 .15703 .43761 .17648 .45489 .17106 .44509 .15133 Mtetra
.631 .616 .817 r
.44509 .15133 .45489 .17106 .4723 .16511 .46253 .14519 Mtetra
.638 .619 .814 r
.46253 .14519 .4723 .16511 .48984 .15862 .4801 .13859 Mtetra
.645 .622 .812 r
.4801 .13859 .48984 .15862 .50749 .15156 .49778 .13152 Mtetra
.652 .626 .811 r
.49778 .13152 .50749 .15156 .52526 .14397 .51558 .124 Mtetra
.659 .631 .811 r
.51558 .124 .52526 .14397 .54312 .13586 .53348 .11604 Mtetra
.665 .637 .812 r
.53348 .11604 .54312 .13586 .56109 .12728 .55148 .10769 Mtetra
.671 .643 .814 r
.55148 .10769 .56109 .12728 .57914 .11829 .56958 .099 Mtetra
.676 .65 .816 r
.56958 .099 .57914 .11829 .59727 .10896 .58777 .09002 Mtetra
.681 .657 .82 r
.58777 .09002 .59727 .10896 .61549 .09936 .60605 .0808 Mtetra
.685 .665 .824 r
.60605 .0808 .61549 .09936 .63378 .08958 .62441 .07143 Mtetra
.688 .673 .829 r
.62441 .07143 .63378 .08958 .65216 .07968 .64287 .06194 Mtetra
.691 .68 .835 r
.64287 .06194 .65216 .07968 .67063 .06974 .66142 .05242 Mtetra
.692 .688 .841 r
.66142 .05242 .67063 .06974 .68918 .05981 .68007 .0429 Mtetra
.693 .695 .848 r
.68007 .0429 .68918 .05981 .70783 .04996 .69881 .03342 Mtetra
.659 .738 .908 r
.03633 .26037 .04772 .27109 .0625 .26554 .05116 .25473 Mtetra
.658 .737 .908 r
.05116 .25473 .0625 .26554 .07735 .26002 .06607 .24909 Mtetra
.657 .736 .908 r
.06607 .24909 .07735 .26002 .09229 .25453 .08106 .24348 Mtetra
.655 .734 .908 r
.08106 .24348 .09229 .25453 .10731 .24909 .09614 .23791 Mtetra
.652 .732 .908 r
.09614 .23791 .10731 .24909 .12241 .24372 .1113 .23238 Mtetra
.65 .73 .907 r
.1113 .23238 .12241 .24372 .13759 .23843 .12654 .22691 Mtetra
.647 .727 .907 r
.12654 .22691 .13759 .23843 .15285 .23324 .14186 .22151 Mtetra
.644 .723 .906 r
.14186 .22151 .15285 .23324 .16819 .22817 .15727 .21621 Mtetra
.64 .718 .905 r
.15727 .21621 .16819 .22817 .18362 .22322 .17277 .211 Mtetra
.636 .713 .903 r
.17277 .211 .18362 .22322 .19913 .21841 .18835 .20589 Mtetra
.632 .708 .901 r
.18835 .20589 .19913 .21841 .21473 .21376 .20402 .2009 Mtetra
.628 .701 .898 r
.20402 .2009 .21473 .21376 .23043 .20925 .21979 .19603 Mtetra
.624 .694 .895 r
.21979 .19603 .23043 .20925 .24622 .20488 .23565 .19126 Mtetra
.62 .687 .891 r
.23565 .19126 .24622 .20488 .26211 .20065 .25161 .1866 Mtetra
.617 .679 .887 r
.25161 .1866 .26211 .20065 .27811 .19653 .26768 .18201 Mtetra
.614 .672 .882 r
.26768 .18201 .27811 .19653 .29422 .19249 .28387 .17749 Mtetra
.612 .664 .876 r
.28387 .17749 .29422 .19249 .31045 .1885 .30017 .17299 Mtetra
.611 .657 .87 r
.30017 .17299 .31045 .1885 .32681 .18449 .31658 .16848 Mtetra
.611 .65 .864 r
.31658 .16848 .32681 .18449 .34329 .18043 .33313 .16391 Mtetra
.612 .644 .858 r
.33313 .16391 .34329 .18043 .35991 .17624 .34981 .15923 Mtetra
.614 .639 .852 r
.34981 .15923 .35991 .17624 .37667 .17187 .36662 .15439 Mtetra
.617 .635 .846 r
.36662 .15439 .37667 .17187 .39357 .16725 .38356 .14934 Mtetra
.621 .633 .841 r
.38356 .14934 .39357 .16725 .41061 .16232 .40064 .14403 Mtetra
.625 .631 .836 r
.40064 .14403 .41061 .16232 .42778 .15703 .41785 .13842 Mtetra
.631 .63 .832 r
.41785 .13842 .42778 .15703 .44509 .15133 .4352 .13247 Mtetra
.636 .631 .828 r
.4352 .13247 .44509 .15133 .46253 .14519 .45267 .12615 Mtetra
.642 .632 .825 r
.45267 .12615 .46253 .14519 .4801 .13859 .47027 .11944 Mtetra
.648 .635 .823 r
.47027 .11944 .4801 .13859 .49778 .13152 .48799 .11235 Mtetra
.654 .638 .823 r
.48799 .11235 .49778 .13152 .51558 .124 .50582 .10488 Mtetra
.659 .643 .822 r
.50582 .10488 .51558 .124 .53348 .11604 .52376 .09705 Mtetra
.665 .648 .823 r
.52376 .09705 .53348 .11604 .55148 .10769 .54181 .08888 Mtetra
.67 .653 .825 r
.54181 .08888 .55148 .10769 .56958 .099 .55996 .08043 Mtetra
.674 .66 .828 r
.55996 .08043 .56958 .099 .58777 .09002 .5782 .07173 Mtetra
.678 .666 .831 r
.5782 .07173 .58777 .09002 .60605 .0808 .59655 .06284 Mtetra
.682 .673 .835 r
.59655 .06284 .60605 .0808 .62441 .07143 .61499 .0538 Mtetra
.684 .68 .84 r
.61499 .0538 .62441 .07143 .64287 .06194 .63352 .04466 Mtetra
.686 .687 .845 r
.63352 .04466 .64287 .06194 .66142 .05242 .65215 .03548 Mtetra
.687 .694 .85 r
.65215 .03548 .66142 .05242 .68007 .0429 .67089 .02629 Mtetra
.688 .7 .856 r
.67089 .02629 .68007 .0429 .69881 .03342 .68973 .01714 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonD000003?oooooU?l0000Kooooo`006_oo
ool00`00003oooooooooo`2@ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2@ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`0Dooooo`;o0000?Oooool00ol000000000ooooo`0Cooooo`0300000?oooooooooo
02Cooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0iooooo`0300000?l0003o0000
04[ooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01<0
6ATI00?o000003<c<`0c<c<0500c<c<C000001P0<c<c00<0000001TI6@0I6AT04P0I6ATS000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0ho`0000030000000I6AT06ATI04d0
6ATI00?o00000000000000000P000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`030000
0?oooooooooo01806ATI00?o000003<c<`0c<c<04P0c<c<3000001<0C4a<0`00000F03<c<`030000
000I6AT06ATI01806ATI8P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
=ol000000`0000006ATI01TI6@1?01TI6@?o000000D00000ooooooooooooooooo`00000Kooooo`00
6_ooool00`00003oooooooooo`0@01TI6@;o00004`0c<c<2000001T0C4a<1@00000B03<c<`030000
0?l000006ATI01806ATI8@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
=_l000000`0000006ATI01TI6@0W01TI6@Go00009`0I6AT01Ol0003ooooooooooooooooo000001_o
oooo000Jooooo`0300000?oooooooooo00l06ATI00?o000003<c<`0c<c<04@0c<c<00`00003o0000
04a<C00O04a<C0<00000400c<c<00`0000006ATI01TI6@0B01TI6@03o`0000000000000001d00000
0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03Co000000<0000001TI6@0I6AT0
7P0I6AT;o`0000D0<c<c1ol0000Q01TI6@04o`000?ooooooooooo`0001_ooooo000Jooooo`030000
0?oooooooooo00h06ATI00?o000003<c<`0c<c<03`0c<c<3000002D0C4a<0P00000?03<c<`030000
000I6AT06ATI01406ATI80000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
<ol000000`0000006ATI01TI6@0K01TI6@Co00005`0c<c<6o`0001/06ATI0oooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`0>01TI6@03o`00000c<c<0<c<c00d0<c<c0P00
000Z04a<C0030000000c<c<0<c<c00d0<c<c00<0000001TI6@0I6AT04@0I6ATO000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0bo`0000030000000I6AT06ATI01T06ATI0ol0
000Q03<c<`;o00006@0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo00d06ATI00?o000003<c<`0c<c<0300c<c<2000002d0C4a<00?o000003<c<`0c<c<03@0c<c<0
0ol000006ATI01TI6@0@01TI6Al000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo033o00000P00000H01TI6@Co00009P0c<c<3o`0001H06ATI0oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0<01TI6@03o`00000c<c<0<c<c00/0<c<c0P00000`04a<
C08000003P0c<c<00`0000006ATI01TI6@0?01TI6Al000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo02oo000000<0000001TI6@0I6AT05@0I6AT3o`0002d0<c<c0ol0000C01TI
6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool02P0I6AT2o`0000d0
<c<c00<0000004a<C01<C4`05@1<C4`8000001D0C4a<0P00000=03<c<`030000000I6AT06ATI00l0
6ATI7P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0;_l000000`000000
6ATI01TI6@0E01TI6@03o`00000c<c<0<c<c0340<c<c0ol0000@01TI6@?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool02@0I6AT00ol00000<c<c03<c<`0<03<c<`03o`00
001<C4`0C4a<00l0C4a<00<00000o`00000000001000000806IVIP@0000000?o000004a<C01<C4`0
401<C4`00`000000<c<c03<c<`0;03<c<`0300000?l000006ATI00l06ATI00<00000o`0000000000
6P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0;Ol000000`0000006ATI
01TI6@0C01TI6@?o0000=`0c<c<00ol000006ATI01TI6@0=01TI6@?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool02@0I6AT00ol00000<c<c03<c<`0;03<c<`030000001<
C4`0C4a<00d0C4a<0`00000C06IVIP<000004@1<C4`00`000000<c<c03<c<`0;03<c<`030000000I
6AT06ATI00l06ATI70000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0;?l0
00000`0000006ATI01TI6@0C01TI6@03o`00000c<c<0<c<c03T0<c<c0P00000=01TI6@?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0200I6AT00ol00000<c<c03<c<`0:
03<c<`8000003P1<C4`2000001T0IVIV1000000>04a<C0030000000c<c<0<c<c00/0<c<c00<00000
01TI6@0I6AT03`0I6ATK000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0[
o`0000030000000I6AT06ATI01806ATI0_l0000J03<c<`T000006`0c<c<2000000/06ATI0oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0701TI6@03o`00000c<c<0<c<c
00X0<c<c00<0000004a<C01<C4`0301<C4`2000001l0IVIV00<00000o`00001<C4`0301<C4`00ol0
0000<c<c03<c<`0:03<c<`030000000I6AT06ATI00l06ATI6`000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool0:_l000000`0000006ATI01TI6@0B01TI6@03o`00000c<c<0<c<c
01<0<c<c1`00000904a<C0L000005P0c<c<00ol000006ATI01TI6@0801TI6@?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool01P0I6AT00ol00000<c<c03<c<`0:03<c<`03
0000001<C4`0C4a<00/0C4a<0P00000S06IVIP800000301<C4`00`000000<c<c03<c<`0:03<c<`03
00000?l000006ATI00l06ATI6P000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool0:Ol000000`0000006ATI01TI6@0B01TI6@03o`00000c<c<0<c<c0100<c<c1000000G04a<C0@0
00004`0c<c<2000000P06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`0601TI6@03o`00000c<c<0<c<c00T0<c<c00?o000004a<C01<C4`02`1<C4`00`00003o0000
06IVIP0U06IVIP8000002`1<C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI00h06ATI
6P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0:Ol000000`0000006ATI
01TI6@0@01TI6@;o0000400c<c<3000001l0C4a<0`00000B03<c<`030000000I6AT06ATI00D06ATI
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0501TI6@03o`00000c
<c<0<c<c00X0<c<c00<0000004a<C01<C4`02@1<C4`2000002X0IVIV00<0000004a<C01<C4`02@1<
C4`00`000000<c<c03<c<`0:03<c<`030000000I6AT06ATI00h06ATI6@000003ooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool0:?l000000`0000006ATI01TI6@0@01TI6@03o`00000c
<c<0<c<c00l0<c<c00<0000004a<C01<C4`08`1<C4`4000000l0<c<c00<0000001TI6@0I6AT0100I
6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00D06ATI00?o0000
03<c<`0c<c<02@0c<c<00`000000C4a<04a<C00904a<C0030000001VIVH0IVIV00h0IVIV2`00000B
06IVIP030000001<C4`0C4a<00T0C4a<00?o000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0>
01TI6AT000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo02Oo000000<00000
01TI6@0I6AT0400I6AT00ol00000<c<c03<c<`0>03<c<`800000:P1<C4`00ol00000<c<c03<c<`0=
03<c<`030000000I6AT06ATI00<06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`0401TI6@03o`00000c<c<0<c<c00P0<c<c0P00000:04a<C00300000?l00000IVIV
00`0IVIV1000000;07moO`@000003`1VIVH2000000X0C4a<00<0000003<c<`0c<c<02@0c<c<00`00
00006ATI01TI6@0=01TI6AT000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
02Ko000000<0000001TI6@0I6AT03`0I6AT2o`0000d0<c<c00@00000o`00000000000000;@1<C4`3
000000d0<c<c00?o000001TI6@0I6AT00P0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0300000?oooooooooo00<06ATI00?o000003<c<`0c<c<0200c<c<00`000000C4a<04a<C00804a<
C0800000301VIVH3000001<0Ogmo0`00000>06IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c
<`0c<c<02@0c<c<00`0000006ATI01TI6@0=01TI6AT000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo02Go000000<0000001TI6@0I6AT03`0I6AT00ol00000<c<c03<c<`0<03<c
<`030000001<C4`0C4a<01<0C4a<2@00000F04a<C0800000300c<c<2000000806ATI0oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0201TI6@03o`00000c<c<0<c<c00T0
<c<c00<0000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0:06IVIP8000006@1oOgl4000000/0
IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0903<c<`030000000I6AT06ATI00d0
6ATI60000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool09?l000000`000000
6ATI01TI6@0?01TI6@03o`00000c<c<0<c<c00/0<c<c0P00000?04a<C0L000002@1VIVH700000140
C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATIooooo`02ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0500000?oooooooooo01TI6Ol000002`0c<c<00`000000C4a<04a<C00704a<C003
0000001VIVH0IVIV00T0IVIV00?o00000000001oOgl07P1oOgl00ol00000IVIV06IVIP0906IVIP03
0000001<C4`0C4a<00L0C4a<00?o00000000000c<c<02@0c<c<00ol000006ATI01TI6@0=01TI6AL0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo02Co00004@0I6AT00ol00000
<c<c03<c<`0;03<c<`030000001<C4`0C4a<00`0C4a<0`00000G06IVIP@000003P1<C4`00ol00000
<c<c03<c<`0;03<c<`05o`000?ooooooooooooooool000006oooool001[ooooo00D00000oooooooo
ool06ATIo`00000;03<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH0201VIVH00`00
0000Ogmo07moO`0P07moO`8000002P1VIVH00`000000C4a<04a<C00704a<C0030000000c<c<0<c<c
00P0<c<c00<0000001TI6@0I6AT03@0I6ATG000000?ooooo00<00000ooooooooool0<Oooool00ol0
003oooooooooo`0So`0000030000000I6AT06ATI00l06ATI00?o000003<c<`0c<c<02P0c<c<00`00
0000C4a<04a<C00;04a<C08000007P1VIVH3000000/0C4a<0P00000=03<c<`04o`000?oooooooooo
o`0001_ooooo000Jooooo`0400000?ooooooooooo`0000/0<c<c00<0000004a<C01<C4`01`1<C4`0
0`000000IVIV06IVIP0706IVIP8000009@1oOgl00`000000IVIV06IVIP0806IVIP030000001<C4`0
C4a<00L0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0=01TI6AH000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo02;o000000<0000001TI6@0I6AT03`0I6AT0
0ol00000<c<c03<c<`0903<c<`800000301<C4`2000002<0IVIV0`00000:04a<C08000002`0c<c<3
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00/0<c<c00<0000004a<
C01<C4`01`1<C4`00`000000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00l0Ogmo2000000?07mo
O`8000002@1VIVH00ol00000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI
6@0I6AT03@0I6ATF000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Ro`00
00030000000I6AT06ATI00h06ATI00?o000003<c<`0c<c<02@0c<c<00`000000C4a<04a<C00904a<
C0<00000:01VIVH00`000000C4a<04a<C00904a<C003o`00000c<c<0<c<c00P0<c<c0oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0:03<c<`03o`00001<C4`0C4a<00L0
C4a<00<0000006IVIP1VIVH01`1VIVH00`000000Ogmo07moO`0907moO`L00000202IVIT4000000d0
Ogmo00<0000006IVIP1VIVH01`1VIVH00`000000C4a<04a<C00604a<C003o`00000c<c<0<c<c00P0
<c<c00<0000001TI6@0I6AT03@0I6AT00ol0000000000000000B000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0Qo`0000030000000I6AT06ATI00h06ATI00?o000003<c<`0c
<c<02@0c<c<00`000000C4a<04a<C00804a<C08000004@1VIVH900000180IVIV0P00000:04a<C080
0000200c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00X0<c<c
00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0606IVIP0300000?l00000Ogmo00X0Ogmo
00<0000009VIV@2IVIT04@2IVIT2000000`0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<
04a<C00704a<C0030000000c<c<0<c<c00P0<c<c00?o000001TI6@0I6AT0300I6ATE000000?ooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Po`0000030000000I6AT06ATI00h06ATI
00?o000003<c<`0c<c<02@0c<c<00ol00000C4a<04a<C00804a<C0030000001VIVH0IVIV00h0IVIV
0`00000907moO`L000003@1VIVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00D0<c<c
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0903<c<`030000001<
C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0907moO`8000005P2I
VIT2000000/0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C0030000000c
<c<0<c<c00P0<c<c00<0000001TI6@0I6AT0300I6ATE000000?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Oo`0000030000000I6AT06ATI00h06ATI00?o000003<c<`0c<c<02@0c
<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV00/0IVIV1000000C07moO`<000002`1V
IVH00`000000C4a<04a<C00904a<C0030000000c<c<0<c<c00@0<c<c0oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`0903<c<`030000001<C4`0C4a<00H0C4a<00<00000
06IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0807moO`8000006P2IVIT2000000X0Ogmo00<00000
06IVIP1VIVH01P1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<00000
01TI6@0I6AT0300I6ATD000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0O
o`0000030000000I6AT06ATI00d06ATI00?o000003<c<`0c<c<02@0c<c<00`000000C4a<04a<C008
04a<C0030000001VIVH0IVIV00T0IVIV0`00000J07moO`0300000?l00000IVIV00T0IVIV00?o0000
04a<C01<C4`0201<C4`00`000000<c<c03<c<`0403<c<`?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool01`0c<c<00ol00000000004a<C00604a<C08000001`1VIVH00`00
0000Ogmo07moO`0707moO`8000007P2IVIT2000000T0Ogmo00<0000006IVIP1VIVH01P1VIVH00`00
0000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT0300I6ATD0000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0No`0000030000000I6AT06ATI
00h06ATI00?o000003<c<`0c<c<0200c<c<00`000000C4a<04a<C00704a<C0800000201VIVH40000
01h0Ogmo0`00000906IVIP8000002@1<C4`00`000000<c<c03<c<`0303<c<`?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool01`0c<c<00`000000C4a<04a<C00504a<C003
0000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI09VIV@0P09VIV@80
0000201oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c
<c<01`0c<c<00`0000006ATI01TI6@0<01TI6A@000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo01ko000000<0000001TI6@0I6AT03@0I6AT00ol00000<c<c03<c<`0803<c<`03
0000001<C4`0C4a<00H0C4a<0P00000906IVIP030000001oOgl0Ogmo02<0Ogmo0`00000806IVIP80
0000201<C4`00`000000<c<c03<c<`0203<c<`?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool01P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00H0IVIV
00<0000007moO`1oOgl01P1oOgl2000000l0VIVI2000000>09VIV@030000001oOgl0Ogmo00H0Ogmo
00?o000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c
00<0000001TI6@0I6AT0300I6ATC000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Mo`0000030000000I6AT06ATI00d06ATI00?o000003<c<`0c<c<0200c<c<00`000000C4a<
04a<C00604a<C0030000001VIVH0IVIV00L0IVIV0P00000?07moO``000003P1oOgl00`000000IVIV
06IVIP0706IVIP030000001<C4`0C4a<00H0C4a<00Co000003<c<`0c<c<0<c<c0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0503<c<`030000001<C4`0C4a<00H0C4a<
00?o000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0607moO`030000002IVIT0VIVI00X0VIVI
1@0000080;>c/`0400000?l000000000000000/0VIVI00<0000007moO`1oOgl01P1oOgl00`000000
IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<00`000000
6ATI01TI6@0;01TI6A<000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01go
000000<0000001TI6@0I6AT0300I6AT00ol00000<c<c03<c<`0803<c<`030000001<C4`0C4a<00H0
C4a<00?o000006IVIP1VIVH01P1VIVH2000000/0Ogmo1P00000<09VIV@0400000?l0000000000000
00/0Ogmo0P00000806IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<00oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0503<c<`030000001<C4`0C4a<00H0
C4a<00<0000006IVIP1VIVH01@1VIVH00ol00000Ogmo07moO`0507moO`030000002IVIT0VIVI00T0
VIVI00<00000o`00002c/k<0402c/k<2000000X0VIVI00<0000007moO`1oOgl01@1oOgl00`000000
IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<01`0c<c<00`000000
6ATI01TI6@0;01TI6A<000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01go
000000<0000001TI6@0I6AT02`0I6AT00ol00000<c<c03<c<`0803<c<`03o`00001<C4`0C4a<00H0
C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0907moO`8000005P2IVIT2000000/0
Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool01@0c<c<00`000000C4a<
04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI
09VIV@0709VIV@<000005@2c/k<2000000T0VIVI00<0000007moO`1oOgl01@1oOgl00`000000IVIV
06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<0200c<c<00`0000006ATI
01TI6@0;01TI6A8000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01co0000
00<0000001TI6@0I6AT0300I6AT00ol00000<c<c03<c<`0803<c<`030000001<C4`0C4a<00D0C4a<
00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0707moO`<000006P2IVIT2000000X0Ogmo
00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c?ooooo00;ooooo
00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0100c<c<00`000000C4a<04a<
C00604a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VI
V@0709VIV@030000002c/k<0/k>c01P0/k>c00?o000009VIV@2IVIT01`2IVIT00`000000Ogmo07mo
O`0507moO`03o`00001VIVH0IVIV00@0IVIV00?o000004a<C01<C4`01P1<C4`00`000000<c<c03<c
<`0703<c<`030000000I6AT06ATI00/06ATI4P000003ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool07?l000000`0000006ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00P0<c<c00<0
000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0606IVIP030000001oOgl0Ogmo00H0Ogmo0P00
000O09VIV@8000002@1oOgl00ol00000IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00D0
0000ooooooooooooooooo`00000Kooooo`006_ooool00`00003oooooooooo`0403<c<`030000001<
C4`0C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0507moO`030000002I
VIT0VIVI00H0VIVI00?o00000000002c/k<06`2c/k<2000000P0VIVI00<0000007moO`1oOgl01@1o
Ogl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01`0c
<c<00`0000006ATI01TI6@0;01TI6@03o`0000000000000000l000000oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo01_o000000<0000001TI6@0I6AT0300I6AT00ol00000<c<c03<c
<`0703<c<`030000001<C4`0C4a<00H0C4a<00?o000006IVIP1VIVH01@1VIVH00`000000Ogmo07mo
O`0607moO`0300000?l00000VIVI00l0VIVI1@00000=09VIV@800000201oOgl00`000000IVIV06IV
IP0506IVIP030000001<C4`0C4a<00H0C4a<00Co0000oooooooooooo00006oooool001[ooooo00<0
0000ooooooooool0100c<c<00`000000C4a<04a<C00404a<C003o`00001VIVH0IVIV00D0IVIV00<0
000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VIV@030000002c/k<0/k>c01h0/k>c00<0
000009VIV@2IVIT01P2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00/06ATI4P00
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool06ol000000`0000006ATI01TI
6@0<01TI6@03o`00000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IV
IP0506IVIP030000001oOgl0Ogmo00H0Ogmo00<0000009VIV@2IVIT02@2IVIT7000000D0/k>c0`00
000<09VIV@8000001`1oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<0ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0303<c<`030000001<C4`0
C4a<00D0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0
VIVI00H0VIVI00<000000;>c/`2c/k<0302c/k<5000000l0/k>c00?o000009VIV@2IVIT01P2IVIT0
0`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`0
0`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00/06ATI4@000003ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool06_l000000`0000006ATI01TI6@0<01TI6@03o`00000c<c<0
<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0506IVIP030000001oOgl0
Ogmo00D0Ogmo0P00000809VIV@@000003`2c/k<4000000X0VIVI00<0000007moO`1oOgl01@1oOgl0
0ol00000IVIV06IVIP0506IVIP03o`00001<C4`0C4a<00@0C4a<0oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0203<c<`030000001<C4`0C4a<00D0C4a<00<0000006IV
IP1VIVH0101VIVH00ol00000Ogmo07moO`0407moO`03o`00002IVIT0VIVI00D0VIVI00?o00000000
002c/k<02@2c/k<5000000D0c<c<1P00000:0;>c/`030000002IVIT0VIVI00H0VIVI00<0000007mo
O`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c
<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6A4000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo01Wo000000<0000001TI6@0I6AT0300I6AT00ol00000<c<c03<c<`0703<c
<`03o`00001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0407mo
O`800000202IVIT2000001L0/k>c0`00000809VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IV
IP1VIVH01@1VIVH00`000000C4a<04a<C00304a<C0?ooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool00P0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0
IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0
/k>c00<00000o`00003<c<`03`3<c<`00`000000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00D0
VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0
C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6A4000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo01[o00003P0I6AT00ol00000<c<c03<c<`0703<c<`03
0000001<C4`0C4a<00D0C4a<00?o000006IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0407moO`03
o`00002IVIT0VIVI00L0VIVI00<00000o`00002c/k<06P2c/k<00`000000VIVI09VIV@0609VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00304a<C0?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool00P0c<c<00`000000C4a<
04a<C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI
09VIV@0509VIV@030000002c/k<0/k>c00L0/k>c00<000000<c<c03<c<`04@3<c<`2000000T0/k>c
00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV
00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI
4@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool06Ol000000`0000006ATI
01TI6@0<01TI6@03o`00000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01P1<C4`00`000000IVIV
06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01@2IVIT2000001h0/k>c
0P00000709VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<
04a<C00204a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00D00000ooooooooool0<c<c
0000000704a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI
09VIV@0409VIV@030000002c/k<0/k>c00H0/k>c0P00000F0<c<c0800000202c/k<00`000000VIVI
09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00ol00000C4a<
04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02`0I6AT@000000?ooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Ho`0000030000000I6AT06ATI00`06ATI
00?o000003<c<`0c<c<01`0c<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00@0IVIV
00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@800000302c/k<<000000X0/k>c
00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV
00<0000004a<C01<C4`00P1<C4`3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0500000?oo
oooooooo03<c<`0000001P1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo
00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`8000006P3<c<`00`000000/k>c
0;>c/`060;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV
06IVIP0306IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI
01TI6@0;01TI6A0000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01So0000
00<0000001TI6@0I6AT02`0I6AT00ol00000<c<c03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<
00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00@0VIVI
00<000000;>c/`2c/k<0202c/k<01000003o0000o`000000000<0<c<c003o`0000000000000000P0
/k>c00?o00000000002IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0
IVIV00@0000004a<C01<C4`0C4a<0oooool00ol0003oooooooooo`0Iooooo`006_ooool01@00003o
ooooooooo`0c<c<0000000H0C4a<00<0000006IVIP1VIVH00`1VIVH00ol00000Ogmo07moO`0507mo
O`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c00K0<c<
c0030000002c/k<0/k>c00D0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0407mo
O`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c
<`030000000I6AT06ATI00/06ATI40000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool06?l000000`0000006ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00L0<c<c00<0000004a<
C01<C4`01@1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo00?o000009VI
V@2IVIT0102IVIT00ol00000/k>c0;>c/`070;>c/`8000004`3<c<`00`000000/k>c0;>c/`060;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IV
IP040000001<C4`0C4a<04a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00@00000oooo
ooooool000001P1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<00000
09VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`030000003<c<`0c<c<01`0c<c<00<00000
0;>c/`2c/k<01@2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<00000
06IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00L0<c<c00<00000
01TI6@0I6AT02P0I6AT@000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0H
o`0000030000000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C005
04a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@04
09VIV@030000002c/k<0/k>c00D0/k>c0P00000F0<c<c08000001`2c/k<00`000000VIVI09VIV@04
09VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00L0C4a<00<0000006IV
IP1VIVH00`1VIVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00<0VIVI00<000000;>c
/`2c/k<01@2c/k<00`000000c<c<0<c<c00;0<c<c0D0000000?o00000<c<c03<c<`02`3<c<`00`00
0000/k>c0;>c/`050;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0101oOgl00`00
0000IVIV06IVIP0306IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`00
00006ATI01TI6@0;01TI6@l000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
01Oo000000<0000001TI6@0I6AT02`0I6AT00ol00000<c<c03<c<`0703<c<`030000001<C4`0C4a<
00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI
00@0VIVI00<000000;>c/`2c/k<01@2c/k<00`000000c<c<0<c<c00H0<c<c0030000002c/k<0/k>c
00D0/k>c00<0000009VIVOl00000102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV
00<0IVIV00<0000004a<C01<C4`00oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`0704a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000
VIVI09VIV@0309VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<c<`0203<c<`4000000H0
i^KV0`00000;0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00ol00000
Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000
<c<c03<c<`0603<c<`03o`00000I6AT06ATI00/06ATI3`000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool05ol000000`0000006ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00H0
<c<c00<0000004a<C01<C4`01@1<C4`00ol00000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0
Ogmo00<0000009VIV@2IVIT00`2IVIT2000000H0/k>c00<00000o`00003<c<`06`3<c<`00ol00000
00000;>c/`050;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000
IVIV06IVIP0306IVIP030000001<C4cooooo00;ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool01`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo
00<0000009VIV@2IVIT00P2IVIT00ol00000/k>c0;>c/`050;>c/`03o`00003<c<`0c<c<00H0c<c<
0`00000=0>KViP8000002@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00@0VIVI
00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@l000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo01Oo000000<0000001TI6@0I6AT02`0I6AT00ol00000<c<c
03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo
07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<2000000/0c<c<
2Ol0000<0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo
07moO`0407moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C?ooool00_ooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`0604a<C0030000001VIVH0IVIV00<0IVIV00<0
000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<0
00000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0@0>KViP030000003<c<`0c<c<00L0c<c<00<0
00000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00@0Ogmo00<0
000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0
000001TI6@0I6AT02`0I6AT>000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0Fo`0000030000000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<
C00504a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VI
V@0409VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01`3<c<`3o`0000T0i^KV0ol0
000:0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07mo
O`0407moO`03o`00001VIVH0IVIV00<0IVIV00D00000ooooooooooooooooo`00000Kooooo`006_oo
ool00`00003oooooooooo`0504a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl00`1o
Ogl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<000000<c<c03<c<`01P3<
c<`00`000000i^KV0>KViP0B0>KViP03o`0000000000c<c<00L0c<c<00<000000;>c/`2c/k<0102c
/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101V
IVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I
6AT>000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Fo`0000030000000I
6AT06ATI00/06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00ol00000VIVI09VIV@0409VIV@030000002c
/k<0/k>c00@0/k>c00<000000<c<c03<c<`01P3<c<`2o`0000l0i^KV0ol000080<c<c003o`00002c
/k<0/k>c00@0/k>c00?o000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001V
IVH0IVIV00@0IVIV00Co0000oooooooooooo00006oooool001[ooooo00<00000ooooooooool01@1<
C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2I
VIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00H0c<c<00?o00000>KViP3Vi^H0503V
i^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2I
VIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<
C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00/06ATI00?o00000000000000002`00
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool05ol0000=01TI6@03o`00000c
<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001o
Ogl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`030;>c/`030000003<
c<`0c<c<00H0c<c<0_l0000C0>KViP03o`00003<c<`0c<c<00H0c<c<00<000000;>c/`2c/k<0102c
/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101V
IVH01?l0003oooooooooool0000Kooooo`006_ooool00`00003oooooooooo`0504a<C0030000001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0309VIV@030000002c
/k<0/k>c00<0/k>c00<000000<c<c03<c<`01P3<c<`00`000000i^KV0>KViP0F0>KViP030000003<
c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000001o
Ogl0Ogmo0080Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c
<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT>000000?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Fo`0000030000000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01P0c
<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1o
Ogl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<
c<`2o`0001H0i^KV00?o00000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c/`030000002I
VIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0101<C4`00`000000IVIV06IVIP04
06IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`04
0;>c/`030000003<c<`0c<c<00D0c<c<00<000000>KViP3Vi^H0603Vi^H00ol00000c<c<0<c<c004
0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`03
07moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`06
03<c<`030000000I6AT06ATI00X06ATI3P000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool05Ol000000`0000006ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00H0<c<c00<00000
04a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo0080Ogmo00<00000
09VIV@2IVIT0102IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00@0c<c<00?o0000
0>KViP3Vi^H05`3Vi^H00ol00000c<c<0<c<c0050<c<c0030000002c/k<0/k>c00@0/k>c00<00000
09VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV0oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0404a<C0030000001VIVH0IVIV
00@0IVIV00?o000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c
00<0/k>c00<000000<c<c03<c<`0103<c<`00ol0000000000>KViP0K0>KViP030000003<c<`0c<c<
00@0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo
0080Ogmo00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c
00H0<c<c00<0000001TI6@0I6AT02P0I6AT>000000?ooooo00<00000ooooooooool0<Oooool00ol0
003oooooooooo`0Eo`0000030000000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01P0c<c<00`00
0000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`00
0000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`00ol0
0000i^KV0>KViP0I0>KViP03o`00003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<00`2c/k<00`00
0000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH3oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00@0C4a<00<0000006IVIP1V
IVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c
/k<00`2c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV01/0i^KV00<000000<c<c03<
c<`0103<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@h000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo01Go000000<0000001TI6@0I6AT02`0I6AT00ol00000<c<c03<c<`0503<c<`03
o`00001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`03
0000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<c003
o`00003Vi^H0i^KV01X0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`03
0000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0206IVIP?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0101<C4`00`000000IVIV
06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`030;>c/`030000003<c<`0c<c<00@0c<c<00<000000>KViP3Vi^H02`3Vi^H8o`0000X0i^KV
00<000000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI0080VIVI
00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@h000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo01Go000000<0000001TI6@0I6AT02P0I6AT00ol00000<c<c
03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo
07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<
0<c<c0040<c<c003o`00003Vi^H0i^KV00P0i^KV2Ol0000;0>KViP03o`00003<c<`0c<c<00@0c<c<
00?o00000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo00<0Ogmo
00@0000006IVIP1VIVH0IVIV0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`0404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI
09VIV@0309VIV@03o`00002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV
0>KViP080>KViPCo0000203oool00ol00000i^KV0>KViP080>KViP030000003<c<`0c<c<00@0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT02P0I6AT>000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Eo`0000030000000I6AT06ATI00X06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<
04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI
09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV
0>KViP070>KViP;o00002@3oool3o`0000T0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c
0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl010000000IVIV
06IVIP1VIVH3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00@0C4a<
00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI
00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00L0i^KV
00?o00000?ooo`3oool02`3oool00ol00000i^KV0>KViP070>KViP030000003<c<`0c<c<00@0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT02P0I6AT>000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Eo`0000030000000I6AT06ATI00X06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<
04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00ol00000VIVI
09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV
0>KViP070>KViP03o`00003oool0oooo00`0oooo00?o00000>KViP3Vi^H01P3Vi^H00ol00000c<c<
0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo
07moO`0307moO`040000001VIVH0IVIV06IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo
00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00@0c<c<
00<000000>KViP3Vi^H01P3Vi^H00ol00000oooo0?ooo`0<0?ooo`03o`00003Vi^H0i^KV00P0i^KV
00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI
00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<
00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@h000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo01Go000000<0000001TI6@0I6AT02P0I6AT00ol00000<c<c
03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo
07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<
0<c<c0040<c<c003o`00003Vi^H0i^KV00H0i^KV00?o00000?ooo`3oool03P3oool00ol00000i^KV
0>KViP060>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI
09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00@0000006IVIP1VIVH0IVIV0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0304a<C0030000001VIVH0IVIV00<0IVIV
00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c
00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP060>KViP03o`00003oool0oooo00h0oooo
00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c
00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV
00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI
3@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool05?l000000`0000006ATI
01TI6@0;01TI6@03o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV
06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`030;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H01P3Vi^H00ol00000oooo
0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00D0i^KV00?o00000<c<c03<c<`0103<c<`00`000000/k>c
0;>c/`020;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl010000000IVIV
06IVIP1VIVH3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00<0C4a<
00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI
00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c003o`0000000000i^KV00H0i^KV
00?o00000?ooo`3oool0403oool00ol00000i^KV0>KViP060>KViP030000003<c<`0c<c<00@0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT02P0I6AT=000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Do`0000030000000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01@0c<c<00`000000C4a<
04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI
09VIV@0309VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV
0>KViP050>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H01@3Vi^H00ol00000c<c<
0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo
07moO`0307moO`030000001VIVH0IVIV00?ooooo00?o0000ooooooooool06Oooool001[ooooo00<0
0000ooooooooool00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00?o
000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00<0c<c<00<0
00000>KViP3Vi^H01P3Vi^H00ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00H0i^KV00<0
00000<c<c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0
000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0
000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@d000000oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo01Co000000<0000001TI6@0I6AT02`0I6AT00ol00000<c<c03<c
<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<
c0040<c<c003o`00003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool04P3oool00ol00000i^KV0>KV
iP060>KViP03o`00003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VI
V@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00oooool00ol0003ooooooooo
o`0Iooooo`006_ooool00`00003oooooooooo`0304a<C0030000001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c0080/k>c00<00000
0<c<c03<c<`0103<c<`00`000000i^KV0>KViP050>KViP03o`00003oool0oooo0180oooo00?o0000
0>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c00<0/k>c00<00000
09VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<00000
04a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI3@000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool05?l000000`0000006ATI01TI6@0;
01TI6@03o`00000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP03
06IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`02
0;>c/`030000003<c<`0c<c<00@0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0D
0?ooo`03o`00003Vi^H0i^KV00D0i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`03
0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP03
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo0080C4a<00<0000006IV
IP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00H0i^KV00?o00000?oo
o`3oool04P3oool00ol00000i^KV0>KViP060>KViP030000003<c<`0c<c<00@0c<c<00<000000;>c
/`2c/k<00P2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI
6@0I6AT02P0I6AT=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Do`00
00030000000I6AT06ATI00X06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<
C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VI
V@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP050>KV
iP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H01@3Vi^H00ol00000c<c<0<c<c0030<c<
c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207mo
O`030000001VIVH0IVIV00?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool00P1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3V
i^H01@3Vi^H00ol00000oooo0?ooo`0D0?ooo`03o`00003Vi^H0i^KV00D0i^KV00<000000<c<c03<
c<`0103<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1o
Ogl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c
<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@d000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo01Co000000<0000001TI6@0I6AT02P0I6AT00ol00000<c<c03<c<`0603<c<`03
0000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`03
0000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<c003
o`00003Vi^H0i^KV00@0i^KV00?o00000?ooo`3oool05P3oool00ol00000i^KV0>KViP040>KViP03
o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0309VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`0204a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0
0`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0
0`3<c<`00`000000i^KV0>KViP050>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H0
1@3Vi^H00`000000c<c<0<c<c0040<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT0
0`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0
101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI3@000003ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool05?l000000`0000006ATI01TI6@0:01TI6@03o`00
000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0206IVIP030000
001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000
003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0F0?ooo`03o`00
003Vi^H0i^KV00@0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000
002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP03ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo0080C4a<00<0000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c
/k<00`000000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool05P3o
ool00ol00000i^KV0>KViP050>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c
/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1V
IVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I
6AT=000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Do`0000030000000I
6AT06ATI00X06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001V
IVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c
/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP040>KViP03o`00003o
ool0oooo01L0oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c
/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001V
IVH0IVIV00?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool00P1<C4`0
0`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H01@3Vi^H0
0ol00000oooo0?ooo`0F0?ooo`03o`00003Vi^H0i^KV00D0i^KV00<000000<c<c03<c<`00`3<c<`0
0`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl0
0`000000IVIV06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01P0c<c<0
0`0000006ATI01TI6@0:01TI6@d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo01Co000000<0000001TI6@0I6AT02P0I6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0
VIVI0080VIVI00?o00000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0
i^KV00@0i^KV00?o00000?ooo`3oool05`3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0
c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0
Ogmo0080Ogmo00<0000006IVIP1VIVH00oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`0204a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`00
0000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`00
0000i^KV0>KViP050>KViP03o`00003oool0oooo01H0oooo00?o00000>KViP3Vi^H01@3Vi^H00`00
0000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`00
0000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`00
0000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI3@000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool05?l000000`0000006ATI01TI6@0:01TI6@03o`00000c<c<0<c<c
00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo
00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<
00<0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0G0?ooo`03o`00003Vi^H0i^KV
00@0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI
0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP03ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`0300000?oooooooooo0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000
Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`000000
c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool05P3oool00ol00000
i^KV0>KViP050>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000
C4a<04a<C00304a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT=000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Do`0000030000000I6AT06ATI00X0
6ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0
IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080
/k>c00<000000<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP040>KViP03o`00003oool0oooo01L0
oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0
/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool00P1<C4`00`000000IVIV
06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H01@3Vi^H00ol00000oooo
0?ooo`0G0?ooo`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c
0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV
06IVIP0306IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI
01TI6@0:01TI6@d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01Co0000
00<0000001TI6@0I6AT02P0I6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<
00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI
00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00D0i^KV
00?o00000?ooo`3oool05P3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<00<0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo
00<0000006IVIP1VIVH00oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0204a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VI
V@0309VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV0>KV
iP050>KViP03o`00003oool0oooo01L0oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<
c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07mo
O`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0603<c<`030000000I6AT06ATI00X06ATI3@000003ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool05?l000000`0000006ATI01TI6@0:01TI6@03o`00000c<c<0<c<c00H0<c<c00<0
000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0
000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o
00000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0F0?ooo`03o`00003Vi^H0i^KV00@0i^KV00?o
00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<0
000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP03ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`0300000?oooooooooo0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`02
07moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c003
0<c<c0030000003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool05`3oool00ol00000i^KV0>KViP04
0>KViP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@02
09VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C003
04a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT=000000?ooooo00<00000
ooooooooool0<Oooool00ol0003oooooooooo`0Do`0000030000000I6AT06ATI00X06ATI00?o0000
03<c<`0c<c<01P0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00`1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080/k>c00<00000
0<c<c03<c<`00`3<c<`00ol00000i^KV0>KViP050>KViP03o`00003oool0oooo01D0oooo00?o0000
0>KViP3Vi^H01@3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<00000
09VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00?ooooo00?o0000
ooooooooool06Oooool001[ooooo00<00000ooooooooool00P1<C4`00`000000IVIV06IVIP0306IV
IP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`020;>c
/`030000003<c<`0c<c<00<0c<c<00<000000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0G0?oo
o`03o`00003Vi^H0i^KV00@0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c
/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IV
IP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI
6@d000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01Co000000<0000001TI
6@0I6AT02P0I6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<00P2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00D0i^KV00?o00000?oo
o`3oool05@3oool00ol00000i^KV0>KViP050>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c
/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IV
IP1VIVH00oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0204a<C003
0000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@03
0000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00`3<c<`00`000000i^KV0>KViP050>KViP03
o`00003oool0oooo01L0oooo00?o00000>KViP3Vi^H0103Vi^H00`000000c<c<0<c<c0030<c<c003
0000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207moO`03
0000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`03
0000000I6AT06ATI00X06ATI3@000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool05?l000000`0000006ATI01TI6@0:01TI6@03o`00000c<c<0<c<c00H0<c<c00<0000004a<C01<
C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3V
i^H01@3Vi^H00ol00000oooo0?ooo`0D0?ooo`03o`00003Vi^H0i^KV00D0i^KV00?o00000<c<c03<
c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1o
Ogl00`1oOgl00`000000IVIV06IVIP03ooooo`03o`000?oooooooooo01Wooooo000Jooooo`030000
0?oooooooooo0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000
002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0030<c<c0030000
003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool05`3oool00ol00000i^KV0>KViP040>KViP030000
003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000
001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000
000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT=000000?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`0Do`0000030000000I6AT06ATI00X06ATI00?o000003<c<`0c<c<0
1P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0
0P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0
0`3<c<`00ol00000i^KV0>KViP050>KViP03o`00003oool0oooo01@0oooo00?o00000>KViP3Vi^H0
103Vi^H00ol00000c<c<0<c<c0040<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT0
0P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool00P1<C4`00`000000IVIV06IVIP0306IVIP030000001o
Ogl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<
c<`0c<c<00<0c<c<00<000000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0G0?ooo`03o`00003V
i^H0i^KV00@0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002I
VIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<
C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@d000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01Co000000<0000001TI6@0I6AT02P0I
6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1V
IVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00P2c
/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00H0i^KV00?o00000?ooo`3oool04P3o
ool00ol00000i^KV0>KViP050>KViP03o`00003<c<`0c<c<00@0c<c<00<000000;>c/`2c/k<00P2c
/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0204a<C0030000001VIVH0
IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0
/k>c0080/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KViP040>KViP03o`00003oool0
oooo01H0oooo00?o00000>KViP3Vi^H01@3Vi^H00`000000c<c<0<c<c0030<c<c0030000002c/k<0
/k>c0080/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0
IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT0
6ATI00X06ATI3@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool05?l00000
0`0000006ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`0
0`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3Vi^H01P3Vi^H0
0ol00000oooo0?ooo`0@0?ooo`03o`00003Vi^H0i^KV00D0i^KV00?o00000<c<c03<c<`0103<c<`0
0`000000/k>c0;>c/`020;>c/`03o`00002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl0
10000000IVIV06IVIP1VIVH3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0
VIVI00<0VIVI00<000000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0
i^KV00@0i^KV00?o00000?ooo`3oool05P3oool00ol00000i^KV0>KViP050>KViP030000003<c<`0
c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0
Ogmo0080Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0
<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT=000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0Do`0000030000000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01P0c<c<0
0`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl0
0`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`0
0ol00000i^KV0>KViP060>KViP03o`00003oool0oooo00d0oooo0_l000080>KViP03o`00003<c<`0
c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0
Ogmo0080Ogmo00@0000006IVIP1VIVH0IVIV0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`0204a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00P1oOgl0
0`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0103<c<`0
0`000000i^KV0>KViP040>KViP03o`00003oool0oooo01H0oooo00?o00000>KViP3Vi^H01@3Vi^H0
0`000000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00`2IVIT0
0`000000Ogmo07moO`0207moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`0
0`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI3@000003ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool05?l000000`0000006ATI01TI6@0;01TI6@03o`00000c<c<0
<c<c00H0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00@0c<c<00?o00000>KViP3Vi^H01`3Vi^H00ol00000oooo0?ooo`0:0?ooo`;o00002P3Vi^H0
0ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00`2IVIT0
0`000000Ogmo07moO`0207moO`040000001VIVH0IVIV06IVIP?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool00P1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0
c<c<00@0c<c<00<000000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0D0?ooo`03o`00003Vi^H0
i^KV00H0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0
VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0
C4a<00@0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0:01TI6@d000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo01Co000000<0000001TI6@0I6AT02`0I6AT0
0ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH0
0`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<0
0`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00P0i^KV0ol000070?ooo`;o00002`3Vi^H0
0ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00P2IVIT0
0`000000Ogmo07moO`0307moO`040000001VIVH0IVIV06IVIP?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool00P1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo00<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00<0c<c<00<000000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0C0?ooo`03o`00003Vi^H0
i^KV00H0i^KV00<000000<c<c03<c<`00`3<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0
VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP030000001<C4`0
C4a<00@0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0:01TI6@h000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo01Go000000<0000001TI6@0I6AT02P0I6AT0
0ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH0
0`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<0
0`000000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV00X0i^KV1ol0000<0>KViP03o`00003<c<`0
c<c<00@0c<c<00?o00000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0
Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH3ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0300000?oooooooooo0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307mo
O`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0030<c<
c0030000003Vi^H0i^KV00H0i^KV00?o00000?ooo`3oool04P3oool00ol00000i^KV0>KViP060>KV
iP030000003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VI
V@03o`00001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<
C0030000000c<c<0<c<c00D0<c<c00<0000001TI6@0I6AT02P0I6AT>000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`0Eo`0000030000000I6AT06ATI00X06ATI00?o000003<c
<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007mo
O`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<
c03<c<`0103<c<`00ol00000i^KV0>KViP0K0>KViP03o`00003<c<`0c<c<00D0c<c<00<000000;>c
/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@03o`00001oOgl0Ogmo00<0Ogmo00<0000006IV
IP1VIVH00P1VIVH3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo0080
C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI0080
VIVI00<000000;>c/`2c/k<00`2c/k<00ol00000c<c<0<c<c0030<c<c0030000003Vi^H0i^KV00L0
i^KV00?o00000?ooo`3oool0403oool00ol00000i^KV0>KViP070>KViP030000003<c<`0c<c<00<0
c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0
Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0
<c<c00<0000001TI6@0I6AT02P0I6AT>000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`0Eo`0000030000000I6AT06ATI00X06ATI00?o000003<c<`0c<c<01P0c<c<00`000000
C4a<04a<C00504a<C003o`00001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00`1oOgl00`000000
VIVI09VIV@0409VIV@03o`00002c/k<0/k>c0080/k>c00<000000<c<c03<c<`01@3<c<`00ol00000
i^KV0>KViP0I0>KViP03o`00003<c<`0c<c<00D0c<c<00<000000;>c/`2c/k<0102c/k<00`000000
VIVI09VIV@0209VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH00P1VIVH3ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00<0C4a<00<0000006IVIP1VIVH0
0`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0
0P2c/k<00`000000c<c<0<c<c0040<c<c0030000003Vi^H0i^KV00L0i^KV00?o00000?ooo`3oool0
3P3oool00ol00000i^KV0>KViP070>KViP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<0
0`2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH0
0`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00H0<c<c00<0000001TI6@0I6AT0
2P0I6AT>000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0Eo`0000030000
000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000
001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000
002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`01@3<c<`2o`0001P0i^KV00?o00000<c<c03<c<`0
1@3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl0
0P1oOgl00`000000IVIV06IVIP0306IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00<0
0000ooooooooool00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo0P00
000409VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0103<c<`00`000000i^KV0>KV
iP070>KViP03o`00003oool0oooo00`0oooo00?o00000>KViP3Vi^H01`3Vi^H00`000000c<c<0<c<
c0040<c<c0030000002c/k<0/k>c00<0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07mo
O`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c
<`0603<c<`030000000I6AT06ATI00X06ATI3P000003ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool05Ol000000`0000006ATI01TI6@0;01TI6@03o`00000c<c<0<c<c00H0<c<c00<0
000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo00<0
000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00H0c<c<0_l0
000D0>KViP;o00001`3<c<`00ol00000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<0
000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool00`1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00@0c<c<00<000000>KViP3Vi^H01`3Vi^H2o`0000`0oooo0_l000090>KViP030000003<c<`0
c<c<00@0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0
Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0
<c<c00H0<c<c00<0000001TI6@0I6AT02P0I6AT>000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0Go`0000`06ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C004
04a<C0030000001VIVH0IVIV00@0IVIV00?o000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@03
09VIV@030000002c/k<0/k>c00<0/k>c00<000000<c<c03<c<`0203<c<`2o`000140i^KV00?o0000
0<c<c03<c<`01`3<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<00000
07moO`1oOgl00`1oOgl00`000000IVIV06IVIP0306IVIP0400000?ooooooooooo`0001_ooooo000J
ooooo`0300000?oooooooooo00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`02
07moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c005
0<c<c0030000003Vi^H0i^KV00P0i^KV0_l000080?ooo`;o00002P3Vi^H00`000000c<c<0<c<c004
0<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`03
07moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`06
03<c<`030000000I6AT06ATI00X06ATI3P000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool05_l000000`0000006ATI01TI6@0;01TI6@030000000c<c<0<c<c00D0<c<c00<00000
04a<C01<C4`01@1<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo00<00000
09VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00T0c<c<00?o0000
0>KViP3Vi^H02`3Vi^H3o`0000T0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@03
09VIV@030000001oOgl0Ogmo00<0Ogmo00<0000006IVIP1VIVH0101VIVH01000003oooooooooool0
000Kooooo`006_ooool00`00003oooooooooo`0304a<C0030000001VIVH0IVIV00@0IVIV00<00000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00<0/k>c00<00000
0<c<c03<c<`0103<c<`00`000000i^KV0>KViP0:0>KViP?o00000`3oool2o`0000`0i^KV00<00000
0<c<c03<c<`0103<c<`00`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI0080VIVI00<00000
07moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP03o`00001<C4`0C4a<00@0C4a<00<00000
03<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0;01TI6@h000000oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo01Ko000000<0000001TI6@0I6AT02`0I6AT00`000000<c<c03<c<`06
03<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`03
07moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c009
0<c<c0?o00001`3Vi^H3o`0000/0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@04
09VIV@030000001oOgl0Ogmo00<0Ogmo00?o000006IVIP1VIVH00`1VIVH01@00003ooooooooooooo
oooo000001_ooooo000Jooooo`0300000?oooooooooo00<0C4a<00<0000006IVIP1VIVH0101VIVH0
0`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00`2c/k<0
0`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV00`0i^KV0ol0000=0>KViP03o`00003<c<`0
c<c<00@0c<c<00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0
Ogmo00<0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0
<c<c00H0<c<c00<0000001TI6@0I6AT02`0I6AT>000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0Fo`0000030000000I6AT06ATI00/06ATI00?o000003<c<`0c<c<01P0c<c<0
0`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl0
0ol00000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0/k>c00<00000o`00000000002`3<c<`7
o`0000/0c<c<0P0000000ol00000/k>c0;>c/`040;>c/`03o`00002IVIT0VIVI00@0VIVI00?o0000
07moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP0500000?ooooooooooooooool000006ooo
ool001[ooooo00<00000ooooooooool00`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0
Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0
c<c<00D0c<c<00<000000>KViP3Vi^H06`3Vi^H00`000000c<c<0<c<c0050<c<c0030000002c/k<0
/k>c00@0/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0
IVIV00<0IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT0
6ATI00/06ATI3P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool05_l00000
0`0000006ATI01TI6@0;01TI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`0
0`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT0102IVIT0
0`000000/k>c0;>c/`060;>c/`030000003<c<`0c<c<01T0c<c<00<000000;>c/`2c/k<01P2c/k<0
0`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH0
1@00003ooooooooooooooooo000001_ooooo000Jooooo`0300000?oooooooooo00@0C4a<00<00000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00@0VIVI00<00000
0;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0050<c<c0030000003Vi^H0i^KV01X0i^KV00<00000
0<c<c03<c<`0103<c<`00`000000/k>c0;>c/`040;>c/`030000002IVIT0VIVI00<0VIVI00<00000
07moO`1oOgl00P1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0C4a<00<00000
03<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI6@h000000oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo01Ko000000<0000001TI6@0I6AT0300I6AT00`000000<c<c03<c<`06
03<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`04
07moO`030000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<01P2c/k<2000001P0c<c<00<00000
0;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo00<00000
06IVIP1VIVH0101VIVH00`000000C4a<ooooo`02ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0300000?oooooooooo00@0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307mo
O`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0040<c<
c0030000003Vi^H0i^KV01T0i^KV00<000000<c<c03<c<`01@3<c<`00`000000/k>c0;>c/`040;>c
/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00`1oOgl00ol00000IVIV06IVIP0306IV
IP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0;01TI
6@l000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01Oo000000<0000001TI
6@0I6AT02`0I6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00@0C4a<00<0000006IV
IP1VIVH0101VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI00D0VIVI00<000000;>c
/`2c/k<01`2c/k<00`000000c<c<0<c<c00D0<c<c003o`00002c/k<0/k>c00L0/k>c00<0000009VI
V@2IVIT0102IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<
C?ooool00_ooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0404a<C003
0000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@03
0000002c/k<0/k>c00<0/k>c00?o00000<c<c03<c<`01@3<c<`2000001L0i^KV0P0000070<c<c003
0000002c/k<0/k>c00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0307moO`03
0000001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0503<c<`03
0000000I6AT06ATI00/06ATI3`000003ooooo`0300000?oooooooooo037ooooo00?o0000oooooooo
ool05ol000000`0000006ATI01TI6@0<01TI6@030000000c<c<0<c<c00H0<c<c00?o000004a<C01<
C4`01@1<C4`00ol00000IVIV06IVIP0406IVIP03o`00001oOgl0Ogmo00<0Ogmo00<00000o`00002I
VIT01@2IVIT00`000000/k>c0;>c/`070;>c/`0400000?l000000000000000h0c<c<100000090;>c
/`03o`00002IVIT0VIVI00@0VIVI00?o000007moO`1oOgl0101oOgl00ol00000IVIV06IVIP0406IV
IP03o`00001<C4`0C4a<00?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool0101<C4`00`000000IVIV06IVIP0406IVIP03o`00001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT0102IVIT00`000000/k>c0;>c/`030;>c/`030000003<c<`0c<c<00L0c<c<00<000000>KViP3V
i^H04`3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2I
VIT00`2IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`01@1<C4`00`000000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00/06ATI3`000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool05ol000000`0000006ATI01TI6@0<01TI6@03
0000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP03
0000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`0:0;>c/`<0
00002@3<c<`2000000/0/k>c0P00000609VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1V
IVH0101VIVH010000000C4a<04a<C01<C4`3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo00D0C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0307moO`03
0000002IVIT0VIVI00@0VIVI00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0070<c<c080
00004P3Vi^H00`000000c<c<0<c<c0070<c<c0030000002c/k<0/k>c00@0/k>c00<0000009VIV@2I
VIT00`2IVIT00ol00000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI40000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool06?l000000`0000006ATI01TI6@0<01TI6@03
0000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP03
0000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`0<0;>c/`T0
00002`2c/k<2000000L0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0506IVIP04
0000001<C4`0C4a<04a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool01@1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2I
VIT00`2IVIT00`000000/k>c0;>c/`040;>c/`030000003<c<`0c<c<00P0c<c<00<000000>KViP3V
i^H03P3Vi^H00ol00000c<c<0<c<c0070<c<c003o`00002c/k<0/k>c00@0/k>c00?o000009VIV@2I
VIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<0000004a<C01<
C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI40000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool06Ol000000`0000006ATI01TI6@0;01TI6@03
0000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0406IVIP03
0000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0102IVIT3000001d0/k>c0P00000809VIV@03
0000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00204a<C0?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool01@1<C4`00`000000IVIV
06IVIP0406IVIP030000001oOgl0Ogmo00<0Ogmo00?o000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`050;>c/`030000003<c<`0c<c<00P0c<c<00?o00000000000000002P3Vi^H3000000X0c<c<
00<000000;>c/`2c/k<0102c/k<00`000000VIVI09VIV@0409VIV@030000001oOgl0Ogmo00<0Ogmo
00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT02P0I6AT@000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Io`0000030000000I6AT06ATI00`06ATI00?o000003<c<`0c<c<01P0c<c<00`000000C4a<
04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00?o000007moO`1oOgl0101oOgl00ol000000000
09VIV@0709VIV@030000002c/k<0/k>c01P0/k>c0P00000909VIV@030000001oOgl0Ogmo00@0Ogmo
00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00204a<C0?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool01@1<C4`00`000000IVIV06IVIP0406IVIP030000001o
Ogl0Ogmo00<0Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`050;>c/`030000003<
c<`0c<c<00X0c<c<100000030>KViP<00000303<c<`00`000000/k>c0;>c/`050;>c/`030000002I
VIT0VIVI00<0VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<
C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6A0000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01Wo000000<0000001TI6@0I6AT0300I
6AT00`000000<c<c03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1V
IVH00`000000Ogmo07moO`0507moO`030000002IVIT0VIVI00H0VIVI0`00000E0;>c/`8000002@2I
VIT2000000H0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<C00304a<C0?ooooo00?o
0000ooooooooool06Oooool001[ooooo00<00000ooooooooool01P1<C4`00`000000IVIV06IVIP04
06IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`06
0;>c/`030000003<c<`0c<c<00d0c<c<0`00000>0<c<c0030000002c/k<0/k>c00D0/k>c00<00000
09VIV@2IVIT0102IVIT00`000000Ogmo07moO`0307moO`030000001VIVH0IVIV00<0IVIV00<00000
04a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT06ATI00X06ATI4@000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool06Ol000000`0000006ATI01TI6@0=
01TI6@030000000c<c<0<c<c00L0<c<c00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP06
06IVIP030000001oOgl0Ogmo00D0Ogmo00<0000009VIV@2IVIT0202IVIT4000000h0/k>c0`00000:
09VIV@030000001oOgl0Ogmo00H0Ogmo00<0000006IVIP1VIVH01@1VIVH00ol00000C4a<04a<C004
04a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool01P1<C4`00`00
0000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT00`2IVIT00`00
0000/k>c0;>c/`060;>c/`030000003<c<`0c<c<01X0c<c<0P0000000ol00000/k>c0;>c/`050;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl00ol00000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00@0C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI
6A4000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01[o000000<0000001TI
6@0I6AT0300I6AT00`000000<c<c03<c<`0703<c<`03o`00001<C4`0C4a<00D0C4a<00<0000006IV
IP1VIVH01P1VIVH00`000000Ogmo07moO`0507moO`800000302IVIT7000000<0/k>c1000000;09VI
V@800000201oOgl00`000000IVIV06IVIP0506IVIP030000001<C4`0C4a<00D0C4a<0oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0604a<C0030000001VIVH0IVIV00@0
IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00H0
/k>c00?o00000000003<c<`0603<c<`00`000000/k>c0;>c/`070;>c/`030000002IVIT0VIVI00D0
VIVI00<0000007moO`1oOgl00`1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6A4000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo01[o000000<0000001TI6@0I6AT0300I6AT00`000000
<c<c03<c<`0703<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01P1VIVH00ol00000
Ogmo07moO`0607moO`030000002IVIT0VIVI0100VIVI0`00000=09VIV@8000002@1oOgl00`000000
IVIV06IVIP0506IVIP030000001<C4`0C4a<00H0C4a<00@00000oooooooooooo00006oooool001[o
oooo00<00000ooooooooool01`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0
Ogmo00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`070;>c/`030000003<c<`0c<c<01D0
c<c<00<000000;>c/`2c/k<01`2c/k<00`000000VIVI09VIV@0509VIV@030000001oOgl0Ogmo00@0
Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00H0
<c<c00<0000001TI6@0I6AT02`0I6ATA000000?ooooo00<00000ooooooooool0<Oooool00ol0003o
ooooooooo`0Ko`0000030000000I6AT06ATI00`06ATI00<0000003<c<`0c<c<01`0c<c<00`000000
C4a<04a<C00604a<C0030000001VIVH0IVIV00H0IVIV00<0000007moO`1oOgl01P1oOgl3000001d0
VIVI0P00000:07moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01`1<C4`01000003o
ooooooooool0000Kooooo`006_ooool00`00003oooooooooo`0704a<C0030000001VIVH0IVIV00@0
IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0509VIV@030000002c/k<0/k>c00L0
/k>c00<000000<c<c03<c<`04`3<c<`00ol00000/k>c0;>c/`080;>c/`030000002IVIT0VIVI00@0
VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00@0
C4a<00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0:01TI6A8000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo01_o000000<0000001TI6@0I6AT0300I6AT00`000000
<c<c03<c<`0803<c<`030000001<C4`0C4a<00H0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000
Ogmo07moO`0807moO`8000006P2IVIT00`000000Ogmo07moO`0907moO`030000001VIVH0IVIV00D0
IVIV00?o000004a<C01<C4`01`1<C4`01@00003ooooooooooooooooo000001_ooooo000Jooooo`04
00000?ooooooooooo`0000L0C4a<00<0000006IVIP1VIVH0101VIVH00ol00000Ogmo07moO`0407mo
O`030000002IVIT0VIVI00@0VIVI00?o00000000002c/k<0202c/k<300000140c<c<0P0000090;>c
/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IVIP0406IV
IP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI6@0;01TI
6A8000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01co000000<0000001TI
6@0I6AT0300I6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<00H0C4a<00<0000006IV
IP1VIVH01P1VIVH2000000T0Ogmo00?o00000000000000005@2IVIT200000003o`00001oOgl0Ogmo
00L0Ogmo0`00000706IVIP8000001`1<C4`20000000503<c<oooooooooooooooool000006oooool0
01[ooooo00@00000oooooooooooo00001`1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0
Ogmo00@0Ogmo00<0000009VIV@2IVIT01P2IVIT00`000000/k>c0;>c/`090;>c/`<000002P3<c<`4
000000X0/k>c00<0000009VIV@2IVIT01@2IVIT00`000000Ogmo07moO`0407moO`030000001VIVH0
IVIV00@0IVIV00<0000004a<C01<C4`01@1<C4`00`000000<c<c03<c<`0603<c<`030000000I6AT0
6ATI00/06ATI00?o00000000000000003`000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool07?l000000`0000006ATI01TI6@0<01TI6@030000000c<c<0<c<c00T0<c<c00<00000
04a<C01<C4`01P1<C4`00`000000IVIV06IVIP0706IVIP8000002P1oOgl4000000d0VIVI1000000;
07moO`030000001VIVH0IVIV00L0IVIV00<0000004a<C01<C4`01P1<C4`010000000<c<c03<c<`0c
<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0500000?oooooooooo03<c<ol000001`1<
C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00@0Ogmo00<0000009VIV@2IVIT01P2I
VIT00`000000/k>c0;>c/`0;0;>c/`X00000302c/k<2000000L0VIVI00<0000007moO`1oOgl0101o
Ogl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00D0C4a<00<0000003<c<`0c<c<01`0c
<c<00`0000006ATI01TI6@0;01TI6A8000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo01go000000<0000001TI6@0I6AT0300I6AT00`000000<c<c03<c<`0903<c<`030000001<
C4`0C4a<00H0C4a<0P00000906IVIP800000301oOgl=000000h0Ogmo00<0000006IVIP1VIVH01`1V
IVH00`000000C4a<04a<C00704a<C0040000000c<c<0<c<c03<c<`?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00D00000ooooooooool0<c<co`00000704a<C0030000001VIVH0IVIV00D0IVIV
00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0609VIV@800000802c/k<00`000000VIVI
09VIV@0609VIV@030000001oOgl0Ogmo00@0Ogmo00<0000006IVIP1VIVH0101VIVH00`00003o0000
04a<C00604a<C0030000000c<c<0<c<c00H0<c<c00?o000001TI6@0I6AT02`0I6ATC000000?ooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`0No`0000l06ATI00<0000003<c<`0c<c<0
2@0c<c<00`000000C4a<04a<C00704a<C0030000001VIVH0IVIV00P0IVIV00<0000007moO`1oOgl0
8@1oOgl200000003o`00001VIVH0IVIV00H0IVIV0P00000904a<C0030000000c<c<0<c<c0080<c<c
0oooool00ol0003oooooooooo`0Iooooo`006_ooool01@00003oooooooooo`0c<c?o000000L0C4a<
00<0000006IVIP1VIVH01@1VIVH00`000000Ogmo07moO`0507moO`03o`00002IVIT0VIVI00L0VIVI
00<000000;>c/`2c/k<0702c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00D0Ogmo
00<0000006IVIP1VIVH0101VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00H0<c<c
00<0000001TI6@0I6AT02`0I6ATC000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Mo`0000030000000I6AT06ATI00h06ATI00<0000003<c<`0c<c<02@0c<c<00ol00000C4a<
04a<C00704a<C0030000001VIVH0IVIV00P0IVIV00?o00000000000000007@1oOgl3000000X0IVIV
00<0000004a<C01<C4`0201<C4`00`000000<c<c03<c<`0303<c<`?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool00P0c<c<00ol00000C4a<04a<C00504a<C0030000001V
IVH0IVIV00D0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI09VIV@0809VIV@030000002c
/k<0/k>c01T0/k>c0P00000809VIV@030000001oOgl0Ogmo00D0Ogmo00<0000006IVIP1VIVH01@1V
IVH00`000000C4a<04a<C00504a<C0030000000c<c<0<c<c00L0<c<c00<0000001TI6@0I6AT02`0I
6ATC000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0No`0000030000000I
6AT06ATI00h06ATI00<0000003<c<`0c<c<0200c<c<00`000000C4a<04a<C00804a<C08000002`1V
IVH3000001P0Ogmo0P00000<06IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<0100c
<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo0080<c<c00?o0000
04a<C01<C4`01P1<C4`00`000000IVIV06IVIP0406IVIP030000001oOgl0Ogmo00D0Ogmo00<00000
09VIV@2IVIT0202IVIT00`000000/k>c0;>c/`0F0;>c/`8000002@2IVIT00`000000Ogmo07moO`06
07moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`06
03<c<`030000000I6AT06ATI00/06ATI50000003ooooo`0300000?oooooooooo037ooooo00?o0000
ooooooooool07ol000000`0000006ATI01TI6@0=01TI6@030000000c<c<0<c<c00T0<c<c00<00000
04a<C01<C4`02@1<C4`00`000000IVIV06IVIP0;06IVIP800000501oOgl2000000d0IVIV00<00000
04a<C01<C4`0201<C4`00`000000<c<c03<c<`0503<c<`?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool00`0c<c<00ol00000C4a<04a<C00504a<C003o`00001VIVH0IVIV
00D0IVIV00<0000007moO`1oOgl01@1oOgl2000000T0VIVI1000000B0;>c/`8000002P2IVIT00`00
0000Ogmo07moO`0607moO`03o`00001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01@1<C4`00`00
0000<c<c03<c<`0703<c<`030000000I6AT06ATI00/06ATI50000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool08?l000000`0000006ATI01TI6@0=01TI6@8000002P0c<c<00`00
0000C4a<04a<C00904a<C08000003@1VIVH00`00003o000000000003000000L0Ogmo1`00000=06IV
IP8000002@1<C4`2000000P0<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`0403<c<`03o`00001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`000000
Ogmo07moO`0607moO`8000002`2IVIT00`000000/k>c0;>c/`0;0;>c/`@000002`2IVIT00`000000
Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV00<0000004a<C01<C4`01P1<C4`00`000000
<c<c03<c<`0703<c<`030000000I6AT06ATI00/06ATI50000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool08Ol0000A01TI6@030000000c<c<0<c<c00P0<c<c00?o00000000001<
C4`02P1<C4`200000140IVIV1`00000B06IVIP8000002P1<C4`00`000000<c<c03<c<`0803<c<`?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0100c<c<00ol00000C4a<
04a<C00604a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01`1oOgl00`000000VIVI
09VIV@0909VIV@d000003P2IVIT00`000000Ogmo07moO`0607moO`030000001VIVH0IVIV00D0IVIV
00?o000004a<C01<C4`01P1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT06ATI00/06ATI
5@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool08Ol000000`0000006ATI
01TI6@0?01TI6@030000000c<c<0<c<c00T0<c<c0P00000;04a<C0<00000901VIVH3000000/0C4a<
00<0000003<c<`0c<c<02@0c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oo
oooooooo00D0<c<c00?o000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0506IVIP030000001o
Ogl0Ogmo00L0Ogmo00<0000009VIV@2IVIT0802IVIT200000003o`00001oOgl0Ogmo00H0Ogmo00<0
000006IVIP1VIVH01@1VIVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00L0<c<c00<0
000001TI6@0I6AT0300I6ATE000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0Ro`0000030000000I6AT06ATI00h06ATI00?o000003<c<`0c<c<02`0c<c<00`000000C4a<04a<
C00;04a<C0030000001VIVH0IVIV01l0IVIV00?o00000000001<C4`02`1<C4`2000000`0<c<c00@0
0000oooooooooooo00006oooool001[ooooo00<00000ooooooooool01@0c<c<00ol00000C4a<04a<
C00604a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl0201oOgl00ol00000000009VI
V@0N09VIV@030000001oOgl0Ogmo00P0Ogmo00<0000006IVIP1VIVH01P1VIVH00`000000C4a<04a<
C00604a<C0030000000c<c<0<c<c00L0<c<c00?o000001TI6@0I6AT0300I6ATE000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0Ro`0000030000000I6AT06ATI00l06ATI00<0
000003<c<`0c<c<02P0c<c<00ol00000000004a<C00;04a<C003o`0000000000000001`0IVIV0`00
000<04a<C08000003@0c<c<01@00003ooooooooooooooooo000001_ooooo000Jooooo`0300000?oo
oooooooo00H0<c<c00?o000004a<C01<C4`01@1<C4`00`000000IVIV06IVIP0606IVIP030000001o
Ogl0Ogmo00T0Ogmo00<0000009VIV@2IVIT06P2IVIT2000000X0Ogmo00<0000006IVIP1VIVH01P1V
IVH00`000000C4a<04a<C00604a<C0030000000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT02`0I
6ATF000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0So`0000030000000I
6AT06ATI00l06ATI00<0000003<c<`0c<c<02`0c<c<2000000d0C4a<1000000E06IVIP<000003P1<
C4`00`000000<c<c03<c<`0<03<c<`030000000I6AWooooo00;ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool01P0c<c<00ol00000C4a<04a<C00604a<C0030000001VIVH0
IVIV00H0IVIV00<0000007moO`1oOgl02@1oOgl2000001P0VIVI0P00000;07moO`030000001VIVH0
IVIV00H0IVIV00<0000004a<C01<C4`01`1<C4`00`000000<c<c03<c<`0703<c<`030000000I6AT0
6ATI00`06ATI5P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool09?l00000
0`0000006ATI01TI6@0?01TI6@030000000c<c<0<c<c00`0<c<c00<0000004a<C01<C4`03P1<C4`7
000000L0IVIV1`00000@04a<C003o`00000c<c<0<c<c00`0<c<c00<0000001TI6@0I6AT00oooool0
0ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0703<c<`03o`00001<C4`0C4a<
00H0C4a<00<0000006IVIP1VIVH01P1VIVH00`00003o000007moO`0:07moO`800000502IVIT20000
0003o`00001oOgl0Ogmo00P0Ogmo0P00000806IVIP030000001<C4`0C4a<00L0C4a<00<0000003<c
<`0c<c<01`0c<c<00`0000006ATI01TI6@0<01TI6AL000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo02Ko00004@0I6AT00ol00000000003<c<`0<03<c<`03o`0000000000C4a<
01@0C4a<1`00000E04a<C08000003P0c<c<0100000006ATI01TI6@0I6AT3ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo00L0<c<c00?o000004a<C01<C4`01`1<C4`00`00
0000IVIV06IVIP0706IVIP030000001oOgl0Ogmo00X0Ogmo0`00000=09VIV@@00000301oOgl00`00
0000IVIV06IVIP0806IVIP030000001<C4`0C4a<00H0C4a<00<0000003<c<`0c<c<0200c<c<00`00
00006ATI01TI6@0<01TI6AL000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
02Go000000<0000001TI6@0I6AT04@0I6AT00`000000<c<c03<c<`0<03<c<`800000;01<C4`30000
00l0<c<c00<0000001TI6@0I6AT00P0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo00L0<c<c00?o000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0706IVIP03
0000001oOgl0Ogmo00`0Ogmo3@00000?07moO`030000001VIVH0IVIV00P0IVIV00<0000004a<C01<
C4`01P1<C4`00`000000<c<c03<c<`0803<c<`030000000I6AT06ATI00d06ATI5`000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool09_l000000`0000006ATI01TI6@0A01TI6@03
0000000c<c<0<c<c00d0<c<c0P00000Y04a<C0030000000c<c<0<c<c00l0<c<c00<0000001TI6@0I
6AT00`0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00P0<c<c
00?o000004a<C01<C4`01`1<C4`00`000000IVIV06IVIP0806IVIP030000001oOgl0Ogmo02H0Ogmo
00<0000006IVIP1VIVH0201VIVH00`000000C4a<04a<C00604a<C003o`00000c<c<0<c<c00T0<c<c
00<0000001TI6@0I6AT0300I6ATH000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Wo`0000030000000I6AT06ATI01406ATI00<0000003<c<`0c<c<03P0c<c<2000002D0C4a<
0P00000A03<c<`03o`00000I6AT06ATI00@06ATI0oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`0903<c<`03o`00001<C4`0C4a<00L0C4a<0P00000906IVIP03o`000000
0000000002<0Ogmo0P00000906IVIP8000002@1<C4`00`000000<c<c03<c<`0803<c<`030000000I
6AT06ATI00d06ATI60000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0:?l0
00000`0000006ATI01TI6@0A01TI6@030000000c<c<0<c<c00l0<c<c00@00000o`00000000000000
701<C4`500000140<c<c0P00000701TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00<0
0000ooooooooool02P0c<c<00ol00000C4a<04a<C00804a<C0030000001VIVH0IVIV00T0IVIV0P00
000O07moO`8000002P1VIVH00`000000C4a<04a<C00804a<C0030000000c<c<0<c<c00T0<c<c00<0
000001TI6@0I6AT03@0I6ATH000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0Yo`0000030000000I6AT06ATI01406ATI00?o00000000000c<c<04P0c<c<4000001D0C4a<0`00
000C03<c<`<000002@0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo00/0<c<c00?o000004a<C01<C4`0201<C4`00`000000IVIV06IVIP0:06IVIP030000001oOgl0
Ogmo01X0Ogmo0P00000;06IVIP030000001<C4`0C4a<00P0C4a<00<0000003<c<`0c<c<02@0c<c<0
0`0000006ATI01TI6@0=01TI6AT000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo02[o000000<0000001TI6@0I6AT04P0I6AT2000001D0<c<c1`00000704a<C0L000005@0c<c<0
0`0000006ATI01TI6@0:01TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00@00000oooo
oooooooo00002`0c<c<00ol00000C4a<04a<C00804a<C003o`00001VIVH0IVIV00X0IVIV00@00000
o`00000000000000501oOgl200000003o`0000000000IVIV00X0IVIV0P00000:04a<C003o`00000c
<c<0<c<c00T0<c<c00<0000001TI6@0I6AT03@0I6AT00ol0000000000000000G000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0[o`0000030000000I6AT06ATI01<06ATI0P00
000J03<c<`L000006@0c<c<200000003o`00000I6AT06ATI00/06ATI0oooool00ol0003ooooooooo
o`0Iooooo`006_ooool01000003oooooooooool0000;03<c<`03o`00001<C4`0C4a<00T0C4a<00<0
000006IVIP1VIVH03@1VIVH300000100Ogmo00<0000006IVIP1VIVH0301VIVH00`000000C4a<04a<
C00:04a<C0030000000c<c<0<c<c00T0<c<c00<0000001TI6@0I6AT03@0I6ATJ000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`0/o`0000030000000I6AT06ATI01@06ATI0P00
000g03<c<`030000000I6AT06ATI00h06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
1@00003oooooooooo`0I6AWo000000/0<c<c00?o000004a<C01<C4`02@1<C4`200000100IVIV1`00
000307moO`H000003P1VIVH00`000000C4a<04a<C00:04a<C0030000000c<c<0<c<c00T0<c<c00<0
000001TI6@0I6AT03@0I6ATK000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0]o`0000030000000I6AT06ATI01D06ATI0P00000c03<c<`8000004@0I6AT3ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0300000?oooooooooo00806ATI00?o000003<c<`0c<c<02@0c<c<0
0ol00000C4a<04a<C00:04a<C0030000001VIVH0IVIV01@0IVIV0`00000C06IVIP03o`00001<C4`0
C4a<00X0C4a<00<0000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0>01TI6A/000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo02ko000000<0000001TI6@0I6AT05P0I6AT0
0`000000<c<c03<c<`0_03<c<`030000000I6AT06ATI01406ATI0oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0301TI6@03o`00000c<c<0<c<c00T0<c<c00?o000004a<
C01<C4`02P1<C4`00`00003o00000000000W06IVIP8000002`1<C4`00`00003o000003<c<`0:03<c
<`030000000I6AT06ATI00h06ATI70000003ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool0;ol00002000001L06ATI00@00000o`00000000000000:P0c<c<200000003o`00000I6AT0
6ATI01806ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0401TI
6@03o`00000c<c<0<c<c00T0<c<c00?o000004a<C01<C4`0301<C4`2000002<0IVIV0P00000<04a<
C0030000000c<c<0<c<c00/0<c<c00<0000001TI6@0I6AT03P0I6ATL000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`0ao`0000030000000I6AT06ATI01P06ATI0`00000S03<c
<`@000005`0I6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00@0
6ATI00?o000003<c<`0c<c<02P0c<c<00ol00000C4a<04a<C00=04a<C08000007`1VIVH2000000d0
C4a<00<0000003<c<`0c<c<02`0c<c<00`0000006ATI01TI6@0>01TI6Ad000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo03;o000000<0000001TI6@0I6AT06P0I6AT3000001`0
<c<c1000000K01TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
1@0I6AT00ol00000<c<c03<c<`0:03<c<`;o00003`1<C4`00`000000IVIV06IVIP0I06IVIP800000
00?o000004a<C01<C4`0301<C4`00ol00000<c<c03<c<`0;03<c<`030000000I6AT06ATI00h06ATI
00?o00000000000000006`000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
<ol000000`0000006ATI01TI6@0L01TI6@D00000500c<c<3000001h06ATI0_l00002ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo00D06ATI00?o000003<c<`0c<c<0300c
<c<00ol00000C4a<04a<C00=04a<C003o`0000000000000001D0IVIV0`00000@04a<C0800000300c
<c<00`0000006ATI01TI6@0?01TI6Ah000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo03Co000000<0000001TI6@0I6AT0800I6AT:000000<0<c<c1`00000P01TI6@03o`000000
003ooooo00;ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool01P0I6AT0
0ol00000<c<c03<c<`0<03<c<`03o`00001<C4`0C4a<00l0C4a<1000000=06IVIP@000004@1<C4`2
000000d0<c<c00<0000001TI6@0I6AT03`0I6ATO000000?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`0eo`0000030000000I6AT06ATI02T06ATI0`00000V01TI6@03o`0000000000
000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool01`0I6AT00ol0
0000<c<c03<c<`0<03<c<`;o00004`1<C4`=000001@0C4a<00?o000003<c<`0c<c<0300c<c<00`00
00006ATI01TI6@0@01TI6Al000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
03Ko00000P00001A01TI6@04o`00000000000000000000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool0200I6AT00ol00000<c<c03<c<`0=03<c<`03o`00001<C4`0C4a<
02l0C4a<0P00000>03<c<`030000000I6AT06ATI01006ATI80000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool0>?l00002000004d06ATI0_l00004000000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool02@0I6AT00ol00000<c<c03<c<`0=03<c<`;o
0000;P1<C4`00`000000<c<c03<c<`0>03<c<`030000000I6AT06ATI01006ATI00?o000000000000
00007@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0>_l00002000004T0
6ATI0_l00006000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
2P0I6AT00ol00000<c<c03<c<`0>03<c<`;o0000:P1<C4`200000100<c<c00<0000001TI6@0I6AT0
400I6ATQ000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0lo`0000030000
000I6AT06ATI04@06ATI0_l00008000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<0
0000ooooooooool02`0I6AT00ol00000<c<c03<c<`0?03<c<`03o`00001<C4`0C4a<02H0C4a<00<0
000003<c<`0c<c<03`0c<c<00`0000006ATI01TI6@0@01TI6B8000000oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo03go00000P00001301TI6@03o`0000000000000000P000000ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0<01TI6@03o`00000c<c<0
<c<c00l0<c<c00?o000004a<C01<C4`0901<C4`00ol00000<c<c03<c<`0?03<c<`030000000I6AT0
6ATI01006ATI8`000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0?ol00000
0`0000006ATI01TI6@0o01TI6@03o`0000000000000000T000000oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`2@ooooo`0300000?oooooooooo037ooooo00?o0000oooo
ooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_oooonD000003?oooooU?l0000Kooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00
oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00QOooool2o`000<Go
oooo0_l00012ooooo`00P_ooool3o`000003ooooool0003ooooo0<7ooooo0ol000000ooooooo0000
ooooo`11ooooo`00P?ooool2o`0000?ooooo00?o[KgVo`000?l00000_oooool2o`0000Cooooo0_l0
0011ooooo`00OOooool3o`0000?ooooo0on]_NH00ol0003oooooo`00002kooooo`?o00001_ooool0
0ol0003oooooo`000010ooooo`00N_ooool3o`0000Cooooo0_n]_ND3ojfmiP03o`000?oooooo0000
0;Sooooo0ol00008ooooo`04ok2cfol0003oooooo`00043ooooo001hooooo`;o00001?ooool00on^
_NCo[KgUojfmi@03ojfmi@;o[KgV00Co0000ojfmiOoooooo0000]Oooool2o`0000Wooooo0on`/m/0
1?l0003oooooooooool0000oooooo`00MOooool3o`0000?ooooo00?o[kcSojjmi?n^_N@00_n^_N@3
ojfmi@04ojjmiOn]_NGo[KgUo`0000;o[KgU00?oooooo`000?ooool0/?ooool3o`0000Wooooo00?o
[k7Iok2cfon`/m/00_n`/m/01Ol0003ooooooooooooooooo000003kooooo001cooooo`;o00001?oo
ool4ojnlh`Co[[gT00Ko[KgUojjmiOn^_NGo[[gUojfmiOl00002ojfmi@03ooooool0003ooooo0:ko
oooo0_l0000;ooooo`?o[k7I0on`/m/01Ol0003ooooooooooooooooo000003kooooo001`ooooo`?o
00001?ooool00on`_>;o[kcSojnlh`03ojnlh`;o[[gT0_n__N@5ojjmi@06o`000?n]_NGo[KgUojfm
iOoooooo0000Zoooool3o`0000_ooooo00?o[joHojnafOn_/MT00on_/MT01?n`/m_o/K7Io`000?na
/MT3ooooo`03o`000?oooooooooo03_ooooo001^ooooo`;o00001_ooool3ok2lhP?o[kcS0_n`_><4
ojnmi0;o[[gU0_n^_N@01_l0003o[KgUojfmiOn]_NGoooooo`000:Wooooo0_l0000;ooooo`03ojn^
eon_[mSo[joH00;o[joH0on_/MT01?na/=Oo/K7Iok6afOl00002ok6af@;ooooo00?o0000oooooooo
ool0>oooool006_ooooo0ol00006ooooo`;o/K_Q1?n`_>800on__>?o/;cSok2lh`02ok2lh`Co[kgT
0on^_N@00ol0003o[KgUojfmi@02ojjmi@03ooooool0003ooooo0:Cooooo0ol0000;ooooo`Co[jkG
1?n_[mP02?n_/MWo/K3Gok6`eona/=Oo/K7Io`000?na/MWo/[3F0oooool00ol0003oooooooooo`0j
ooooo`00J?ooool3o`0000Kooooo00?o/[_Pok6khOna^n400ona^n42ok2lhP;o/KcR1?n`_><5ojnm
i0;o[[gT00?o0000ojnmi?n^_ND00on^_ND00ooooooo0000ooooo`2Pooooo`?o00003?ooool00on^
[=Go[jkGojn^e`03ojn^e`;o[joH0_n`[]D5ok6`e`04o`000?nb/=Ko/[3Fok:`eP?ooooo00?o0000
ooooooooool0>Oooool006Kooooo0_l00007ooooo`Co/[_P0ona^n400onb^n7o/KcRok6lhP03ok6l
hPCo/;cS0on__N@01_n`_N?o[kgTojnmi?n__NCo0000ojnmi0Co[[gU00?o0000ooooooooool0WOoo
ool2o`0000cooooo00?o[J[Dojj/eOn^[=D00_n^[=D3ojn^e`03ok2/e?n`[]Go/:kE00?o/:kE0ona
/=L00onb[]Co/[3Fo`000003ok:`eP;ooooo00?o0000ooooooooool0>Oooool006?ooooo0ol00007
ooooo`;o/k[N1?nb^n000ona^n7o/[_Qok:kh@02ok:kh@?o/KcR00?o/[cQok2lhon`_><00_n`_><0
0on__NCo/;gSok2mh`02ok2mh`;o[kgT00?o0000ojnmi?n^_ND01?n^_ND00ol0003oooooooooo`2I
ooooo`?o00003Oooool3ojfZe0Co[ZcE00Co[jkGok2/e?n`[=Co/:cD1?n`[]D00ona/=Oo/ZkDok:^
e002ok:^e004o`000?nb/=Ko/[3FokB_e0?ooooo00?o0000ooooooooool0>?ooool0067ooooo0_l0
0007ooooo`03okBigOnc^]ko/k[N00?o/k[N0_nb^n02ok>jg`Co/[_Q00?o/KcRok:lhOnb_>400_nb
_>42ok2lh`;o/KcR1?n`_N<2ojnmi003o`000?n__NCo[kgT00?o[[gU00?o[kgUooooool00000V?oo
ool2o`0000kooooo00?o[:SCojfZe?n]Z]@00_n]Z]@3ojj/e@03ojnZd_n`[=Co/:cD00;o/:cD0on`
[]D00ona[=?o/ZkDok:^e003ok:^e003o`000?nd[mCo]:oD00;o]:oD0oooool00ol0003ooooooooo
o`0gooooo`00G_ooool3o`0000Sooooo0ond^Md3ok>jgP03okBjgOnc^]oo/k[O00?o/k[O0_nb^n42
ok>kh0?o/[cQ00?o/kcQok6lh_na_>800ona_>82ok2mh`;o/KgS00Go[kgTo`000?n__NCo[kgTojjm
i@04ojnmi@03o`000?oooooooooo09?ooooo0ol0000>ooooo`Co[:SC1?n]Z]@01?n^[=Go[j[BojnZ
d_n_Z]84ok2/e004ok2^eOna[=?o/JcCok6/d`?o/ZkD00?o/jgBo`000?nd[m@00ond[m@3ooooo`03
o`000?oooooooooo03Oooooo001Looooo`;o00002Oooool00ond]m_o];WMokBig@03okBig@04ok>j
g_nd^]go];[MokBjg@?o/k[O00?o];_Nok>kh?nc^n000onc^n001?nb_>7o/kcQok>lhOnc_>43ok6l
hP03ok:mh_na_N?o/KgS00?o/KgS00Co0000ojnmi?n`_NCo/;gT1?n__ND00ooooooo0000ooooo`2A
ooooo`;o00003oooool00on[Ym?o[:SCojbXd`03ojbXd`;o[J[D0_n^Z=45ojnZdP;o/:cD00?o/J[A
ok6/dona[=<00ona[=<01?nb[]Co/jgBok>]d_l00003okB_e003okF^d_oooooooooo00;ooooo00?o
0000ooooooooool0=_ooool005Wooooo0ol0000:ooooo`?o];OK0ond^Md00one^Mco];[MokBjg@03
okBjg@04ok>jgond^mko];_NokBkgP?o/k_P00?o];_Ook>lhOnc_>400onc_>401?na_>;o/[gRok:m
h_nb_N84ok6mh`03o`000?n`_NCo/;gT00;o/;gT0_n__ND2ojnni003ooooool0003ooooo08gooooo
0ol0000>ooooo`03ojZUd_n[Ym?oZjOC00;oZjOC0on/Z=<00on]Y]3o[ZSAojjXd@03ojjXd@?o[j[B
00?o/:S@ok6ZdOnaZ]400_naZ]43ok6/d`07ok>[d?nc[M;o/jgBok>]d_l0003o/jgBokB_e003okF^
dPCooooo00?o0000ooooooooool0=Oooool005Oooooo0_l0000;ooooo`03okFffOnd]m_o];OK00?o
];OK00Co];WMokFig?ne^Mco]KWL0ond^]d00one^]co];_NokBkgP03okBkgP04ok>kh?nd^moo];_O
okBkg`?o/kcQ00?o/kcPok:mh_nb_N800onb_N83ok6mh`05o`000?n`_NCo/;gTok2mi?na_^<01On_
_^@00ol0003oooooooooo`2:ooooo`;o00004?ooool3ojZUdPCoZjOC00Co[:SCojfVd?n]Y]3o[JK@
1?n^Z=401?n_Z];o/:S@ok2Xd?n`Z=05ok6Zd@04ok6/doncZm3o/j_@ok>[d0;o/jgB00?o0000okF/
d?ne[]801?ne[]83ooooo`03o`000?oooooooooo03Gooooo001Dooooo`?o00002oooool4okFff@?o
];OK00?o][OJokFig?ne^M`00one^M`01?nd^]go]K[LokFjg?ne^]`2okBkgP;o]K_M1Ond^ml01?nc
_>7o/kcPok>lh?nc_>02ok:mhP;o/kgQ0ona_N<00ol0003o/;gTok6nh`03ok6nh`?o[kkT00?o/;kT
ooooool00000R?ooool3o`0000oooooo0_nXY=84ojZUdP?oZjOC00?oZjC@ojfVd?n]Y]000_n]Y]03
ojjXd@03ojnVcon`Z=3o/:S@00?o/:S@0onaZ]400onbZ<oo/j_@ok>[d003ok>[d004ok>]d_l0003o
]Jc@okF/d0?o]JkB00?o]jk@ooooooooool00_ooool00ol0003oooooooooo`0dooooo`00DOooool3
o`0000cooooo0_nf]=P4okFff@03okBgfonf]m[o][OJ00;o][OJ0_ne^M`2okJhf`?o]K[L00?o]k[L
okFkgOne^md00one^md2okBkg`;o]KcN0onc_>000ond_=oo/kgQok>mh@03ok>mh@;o/KgS00?o0000
ok:mh_na_^<00ona_^<00on__^Co/;kTok2ni002ok2ni003ooooool0003ooooo08?ooooo0ol0000?
ooooo`03ojNSd_nXY=;oZ:CB00?oZ:CB1?nZYM801?n[Ym?oZjC@oj^Td?n[Y=04ojfVd004ojjXdOn_
Y/oo[jK?ojnVc`Co/:S@00?o/J[Aok:XconbZ<l00_nbZ<l3ok>[d003okBYc_ne[=3o000000?o]Jc@
00?o]JkBokN^d?ng[]001Oooool00ol0003oooooooooo`0cooooo`00Coooool2o`0000cooooo00?o
][?FokJdf?nf]=P00onf]=P2okFff@;o]kKH0onf]mX00ong]mWo][SKokJhf`03okJhf`04okFjg?ng
^]co]k[LokNjg0?o]K_M00?o]k_MokFlg_ne_=h00one_=h01?nc_>3o];cOokBlgond_=l3ok>mh@04
okBmhOnb_N;o/[gRo`0000;o/[gR1?na_^<4ok2ni003ooooool0003ooooo087ooooo0_l0000?oooo
o`03ojFRd_nWXm;oYj?B00;oYj?B1?nXY=82ojZUdP;oZZ??1?n[Y=03ojfVd003ojfTc_n_Y/oo[jK?
00;o[jK?0on`Z=000onaY/go/ZS?ok:Xc`03ok:Xc`06ok>[d?ndZLko]:W>okBYc_ne[=3o00000_ne
[=000ongZlko]jk@okN^d002okN^d0Cooooo00?o0000ooooooooool0<oooool004cooooo0ol0000=
ooooo`?o][?F0onf]=P00ong]=Ko]kKHokNff003okNff004okJgf_ng]mWo]kOIokNgf@?o][SK00?o
^;WJokNjg?ng^]`00ong^]`01?ne^mgo]k_MokNkgOng^md3okFlgP;o][cN1?nd_=l01onc_N7o];gQ
okBmhOnd_N7o/[gRo`000?nb_N800_nc_^84ok6nh`Co/;kT00?oooooo`000?ooool0OOooool3o`00
013ooooo0onUX]83ojNSdP?oZ:CB00?oZ:7?ojZSconZXll00onZXll4oj^Td004ojfVd?n]Y<ko[JC>
ojfTcPCo[jK?00Co/:S@ok6VcOnaY/go/JK=0onbZ<l00oncYlco]:W>okBYcP03okBYcP04o`000?ne
[=3o]j_>okN[cPCo]jk@1Oooool00ol0003oooooooooo`0booooo`00B_ooool2o`0000kooooo00?o
][7DokJce_nf/mH00onf/mH01?nf]=So]kCFokNde_ng]=H3okNff003okRfeong]mWo]kOI00?o]kOI
00Co][SKokRif_nh^M[o^;WJ0ong^]`00onh^]_o]k_MokNkg@03okNkg@03okFlg_nf_=ko][cN00;o
][cN0_nd_=l2okJmg`Co];gQ00?o0000ok>nh_nc_^800_nc_^82ok6nh`03ok:nhon`_^Co/;kT00?o
/;kT00?o0000ooooooooool0N_ooool2o`00017ooooo00?oY:7CojFRd_nUX]800_nUX]84ojNSdP04
ojRTd_nXXLooZ:7?ojRQc`CoZZ??0_n[Y=02ojbRc@Go[JC>0_n_Y/l00on`Y<co/JK=ok6Vc@03ok6V
c@04ok:XconcYlco/jO<ok>Wc0Co]:W>00?o0000okN[c_ngZlh00_ngZlh2okN^d003okV]c_oooooo
oooo00?ooooo00?o0000ooooooooool0<_ooool004Oooooo0ol0000?ooooo`?o][7D0onf/mH00ong
/]Co]kCFokNdeP03okNdeP04okNff?nh]]Oo^;KGokRfe`?o]kOI00?o^KOHokRif_nh^MX00onh^MX0
1?ng^]co^;[KokRjfonh^]/3okNkg@;o^;_L0onf_=h00ong_=go][gOokJmg`03okJmg`;o];gQ00?o
]KgPo`000?nc_^800_nc_^800ond_^;o/[kSok:nh`02ok:nh`;o/;kT0_na_^@00ooooooo0000oooo
o`1gooooo`?o00004?ooool00onRXM?oY:7CojBQd`02ojBQd`CoYJ;B0_nWXm800onVX<ooZ:7?ojRQ
c`02ojRQc`?oZZ??00?oZZ3<ojbRcOn/X/d00on/X/d3ojfTcP03ojjRbon`Y<co/:C<00;o/:C<0ona
Y/d00onbY<_o/jO<ok>Wc002ok>Wc0?o]:W>00?o]ZS<o`000?ngZlh00ongZlh01?ng[]3o^Jg>okV]
c_ni[Lh5ooooo`03o`000?oooooooooo037ooooo0015ooooo`;o00004?ooool00one[m?o][7DokJa
e003okJae004okJce_ng/]Co]k;DokNbe0?o]kCF00?o^;CEokRfeonh]]L00onh]]L01?ng]mWo^KOH
okVgf?ni]mP3okRifP;o^KWI1?nh^]/00ong^mgo^;_LokRkg002okRkg004okJlg_ng_=go]kcMokNl
g@?o][gO00Ko]kgNokFmh?ne_N3o]KgPo`000?nc_^84okBnhP;o/[kS0_nc_^<4ok6ni003ooooool0
003ooooo07Cooooo0_l0000@ooooo`03oj6Qe?nRXM?oXZ7C00;oXZ7C1?nTXM<2ojFRdP03ojFOconV
X<ooYZ3?00;oYZ3?1?nXXLl01?nZXlooZZ3<ojZPc?nZX<`4ojbRc@04ojfTc_n^X/_o[Z;;ojjRb`Go
/:C<00Co/JK=ok:TbonbY<_o/ZC;1?ncYl`01?ndZLko]ZS<okJXc?l00003okN[cP03okR[c?ni[Lko
^Jg>00?o^Jg>1Oooool00ol0003oooooooooo`0`ooooo`00@_ooool3o`00017ooooo0one[m<3okJa
e003okNadong/]Co]k;D00?o]k;D00Co]kCFokRdeOnh]=Go^;CE0onh]]L00onj]]Ko^KOHokVgf003
okVgf003okRif_ni^MWo^KWI00;o^KWI0_nh^]/00oni^][o^;_LokRkg002okRkg003okVkfong_=go
]kcM00;o]kcM00?o][gOokNmg_ng_Mh00_ng_Mh2okFmh003o`000?nf_^3o];kR00?o];kR00?o/[kS
ok>nhonc_^<00_nc_^<2ok6ni003ok6oi?oooooo000007;ooooo0ol0000>ooooo`;oWj7F1?nQXM@4
oj:Qd`;oY:7C00?oXik@ojFOconUWll00_nUWll4ojJPc`;oZ:7?00?oZ9k<ojZPc?nZX<`00_nZX<`3
ojbRc@03ojbOb_n^X/_o[Z;;00?o[Z;;0on`Y<`00onaX/Wo/ZC;ok:Tb`02ok:Tb`?o/jO<00Oo]JK:
okJXc?nfZ<co]ZS<o`000?nfZ<co]j_>00?o^:_<0oni[Lh00onk[Lcoooooooooo`03ooooo`03o`00
0?oooooooooo033ooooo000oooooo`?o00004_ooool00ond[M7o]JoCokF_d`03okF_d`04okJae?ng
/M?o]k7CokNad`?o]k;D00?o^K;CokRdeOnh]=D00onh]=D01?nh]]Oo^[KFokZfe_nj]]H3okVgf003
okZge_ni^MWo^KWI00;o^KWI00?o^kWHokVjf_ni^]X00_ni^]X00onh^mco^K_KokVkf`02okVkf`;o
]kcM0_ni_Md4okNmgP03okFmh?nf_^3o000000;o][kP0_nd_^82okBnh@?o/kkS00?o/koSok6oi?na
_n@00_na_n@00ooooooo0000ooooo`1]ooooo`?o00003_ooool00onNX]OoWj7FoinQeP02oinQePGo
XJ7D0_nRXM<00onQWM7oXik@oj>Nd002oj>Nd0?oYIo?0onVX<l00onVWLcoZ9k<ojRNc002ojRNc0Co
ZZ3<00Co[:;=ojbOb_n/Wl[o[9o:1?n^X//01?n`Y<co/J;9ok6RbOnaX/T5ok:Tb`04ok>Wc?neY/[o
]JK:okFVbP;o]ZS<00?o0000okRXbOnhZl`01?nhZl`01?ni[Lko^jg<ok^]c?nk[L`5ooooo`03o`00
0?oooooooooo02oooooo000mooooo`;o00004oooool4okB]d@?o]JoC00?o]joAokNadong/M<00ong
/M<01?ng/]Co^K;CokVbdoni/]<3okRde@03okZddonj]]Ko^[KF00?o^[KF00Go^KOHokZge_nj]mKo
^[OFokVif@04ok^if0;o^K[J00?o^k[IokVkfoni^m/00oni^m/00ong_=go^KgMokVmg@02okVmg@;o
]kgN0_nh_]h01?nf_^3o0000okJnh?ng_^05okBnh@04ok>nhonc_n?o/koSok>oh`;o/KoT0_nb_n@0
0ooooooo0000ooooo`1Zooooo`;o00003_ooool00onMX]SoWZ;GoijRe`02oijRe`CoWj7F0onQXM@0
1?nOWM;oXIgAoj6MdOnQWM44oj>Nd0CoYIo?00CoYZ3?ojJMc?nVWLcoYYg<1?nXW/`2ojZPc003ojZM
bOn/Wl[o[9o:00;o[9o:0on^X//00on_WlSo/J;9ok6Rb@03ok6Rb@?o/ZC;00?o/j?8okFVb_neY/X0
0oneY/X01?nfZ<co0000okRXbOnhZ<T3okR[c003okZ[bOnk[Lco^jg<00?o^jg<1Oooool00ol0003o
ooooooooo`0^ooooo`00>_ooool3o`0001?ooooo00?o/j_@okB]dOnd[M400ond[M400one[m?o]joA
okN_d@02okN_d@?o]k7C00?o^;3AokVbdoni/]<00_ni/]<00onh]=Go^[CCokZdd`02okZdd`?o^[KF
00Go^kKDokZge_nj]mKo^[OFokbhe@05ok^if004okVjf_nk^]Wo^k[Iok^jf@?o^K_K0_nj_=X3okVm
g@03okZmg?nh_]ko^;kN00?o^;kN00Co0000okNnh?ng_^3o]kkP0_nd_^42okFoh@Co/koS00?o/KoT
ok:oi?nb_n@00_nb_n@00ol0003oooooooooo`1Vooooo`?o00003Oooool00onMXm[oWJ;HoifRf002
oifRf0CoWZ;G0onOXMH01?nQXMCoWigBoinMd_nOWM84oj6Md@CoXik@0_nUWll00onTVlgoYYg<ojJM
c002ojJMc0?oZ9k<00?oZ9_9ojZMbOnZWLT00_nZWLT4ojbObP04ojjRbon_WlSo[io8ojnOb0Co/J;9
00?o/ZC;ok>Sb?ncXlP00_ncXlP3okFVbP03okJUaonhZ<Wo000000;o^:S900?o^:_<okZ[bOnjZlT0
0_njZlT3ok^]c003okf^b_oooooooooo00?ooooo00?o0000ooooooooool0;_ooool003Sooooo0_l0
000Eooooo`?o/j_@0ond[M400onf[M3o]joAokN_d@03okN_d@03okNadonh/=7o^;3A00;o^;3A0_ni
/]<00onj/]7o^[CCokZdd`03okZdd`03okZfe_nk]]Co^kKD00;o^kKD00Co^[OFokbheOnl^=Go_;SE
0onk^MP00onl^MOo^k[Iok^jf@03ok^jf@03okVkfonj_=[o^[cJ00;o^[cJ00Co^KgMokZmg?nj_Mco
^[gL0onh_]h01Oni_]ko0000okNnh?ng_^3o^;oO00Go]KoQ0_nc_n<2okBohPCo/[oT00?oooooo`00
0?ooool0I?ooool2o`0000gooooo00?oW:CKoifSf_nMXmX00_nMXmX4oifRf0;oWZ;G00CoW9gDoijM
donNWM?oWYgC1OnOWM83oj6Md@;oXik@0_nRV/d4ojBKc@CoYYg<00CoZ9k<ojRKbOnXVlWoZ9_90onZ
WLT3ojbObP03ojfMaon_WlSo[io800;o[io80onaX/T00onbXLOo/j?8ok>Sb003ok>Sb006okFVb_nf
YLOo]ZG7okJUaonhZ<Wo00000_nhZ<T5okZ[b@03ok^]c?nm[/[o_Jk:00;o_Jk:1Oooool00ol0003o
ooooooooo`0]ooooo`00=Oooool3o`0001Gooooo00?o/ZW?ok>[d?ncZm000oncZm001?nd[M7o]Zg@
okJ]d?nf[M03okN_d@03okR^conh/=7o^;3A00?o^;3A00Co^K;CokZbdOnj/]7o^[;A0onj]=<00onl
]=;o^kKDok^fe003ok^fe0Go_;SE00Co^kWHokbieonl^MOo_;WG0onk^]T2okbkf0?o^[cJ00?o_;cJ
okZmg?nj_M`00_nj_M`01_nh_]ko^KkNokVng_ni_]ko0000okNnh0?o^;oO0one_n400onf_n7o];oR
okBohP03okBohPCo/[oT00?oooooo`000?ooool0H?ooool3o`0000cooooo00?oW:KMoibTfonLY=/0
0_nLY=/4oifSfP;oWJ;H00?oVikFoibMe?nLWM@00_nLWM@3oijMd`CoWigB0_nQWM400onPV/koXY[=
oj:Jc@02oj:Jc@GoY9_=0_nVWL`00onVV/WoZ9_9ojRKb@02ojRKb@CoZYg900Co[9o:ojfMaon]WLOo
[Ig71?n_WlP01?naX/Wo/Z77ok:QaonbXLL4ok>Sb0Go]ZG700Co0000okRXbOniZ<Oo^JS71?njZlT5
okf^bPKooooo00?o0000ooooooooool0;?ooool003?ooooo0_l0000Eooooo`03ok6WconbZLoo/ZW?
00;o/ZW?0oncZm000oneZlko]Zg@okJ]d003okJ]d004okN_dOnh[/oo^:k?okR^c`?o^;3A00?o^[3?
okZbdOnj/]400onj/]401?nj]=?o_;CBokbdd_nl]=83ok^fe0;o_KKC0onl^=D00onm^=Co_;WGokbi
e`03okbie`03ok^jfOnl^mSo_;_H00;o_;_H00Co^[cJokblf_nl_=[o_;cJ0_nj_M`2ok^ng0?o^KkN
00?o0000okZogOnh_ml00onh_ml01?ne_n7o][oQokJohOnf_n42okBohP;o]<3R1?nb_n@00ooooooo
0000ooooo`1Nooooo`;o00002Oooool00onLZN3oW:SNoibXgP02oibXgP?oW:KM1?nLY=/2oifSfP03
oiZOf?nKW]KoVikF00;oVikF0onLWM@4oijMd`;oWigB00?oWYW?oj2Jc_nPV/h00_nPV/h4oj:Jc@?o
Y9_=00CoXiS:ojJJbOnVV/WoYY[91OnXVlT2ojZMb@03oj^Kaon]WLOo[Ig700;o[Ig70on_WlP00on`
W/Ko/Z77ok:Qa`02ok:Qa`?o/j?80_neXlH4okJUa`04o`000?niZ<Oo^JS7okVXa`?o^Z_90_nlZlP4
okf^bPKooooo00?o0000ooooooooool0;?ooool0033ooooo0ol0000Fooooo`?o/JO?1?nbZLl01?nc
Zm3o]J_>okF[c_neZlh3okJ]d003okN/c_nh[/oo^:k?00?o^:k?00Co^;3AokZ`conj/<oo^[3?0onj
/]400onl/]3o_;CBokbddP03okbddP03ok^fe?nm]]?o_KKC00;o_KKC00Co_;SEokfhe?nm^=Co_KSD
0onl^ML00onn^]Ko_;_Hokbkf002okbkf005okjkf?nl_=[o_;cJokblf_nm_MT01Onk_]`00oni_]ko
^[oMo`000002okZog@?o^;oO0onf_n400ong`>7o]<3RokC0hP03okC0hP;o/[oT0_nc`>@00ooooooo
0000ooooo`1Jooooo`?o00002?ooool00onM[>7oW:WPoibYh002oibYh0CoW:SN0onLY]d2oibTf`03
oiZQfOnJWmSoVYoH00;oVYoH0onKW]H4oibMe0;oWYgC00?oW9W@oijIconNVLl00_nNVLl3oj2JcPCo
XY[=00CoY9_=oj>Hb_nSV<[oXiS:1?nVV/T3ojRKb@03ojRIaon[VlOoZi_700;oZi_71?n]WLL01?n_
WlSo/9k6ok2Na_n`W/H4ok:Qa`04ok>Sb?neXlKo]J?6okFSaP?o]ZG700?o^:G6o`000?niZ<L00oni
Z<L01?njZlWo_:_8okb[b?nlZlP3okf^bP;o_jk91_ooool00ol0003oooooooooo`0[ooooo`00;Ooo
ool3o`0001Oooooo00?o[jG>ok6WconaYll00_naYll3ok:Yc`03ok>Xc_neZlko]J_>00?o]J_>00Co
]Zg@okN/c_ng[<ko]jc>0onh[/l00oni[/ko^[3?okZ`c`03okZ`c`04okZbdOnl/]3o_;;@okbbd0?o
_;CB0_nm]=43okffd`03okjfd_nm^=Co_KSD00?o_KSD00Go_;WGokjje_nn^]Ko_[[Fokbkf004okjk
f004okblf_nm_MWo_KgIokfmf@?o^kkL0_nl_]/01?nj_mgo0000okZogOnk_md4okRog`04okJohOng
`>7o]l3QokO0h@?o]<3R00?o]L3Rok?0i?nc`>@00onc`>@00ol0003oooooooooo`1Fooooo`?o0000
2?ooool00onM[N?oWJcQoif/h@02oif/h@CoW:WP0_nLZ=h01?nIY=goVJ;KoiVRfonIX]/4oiZQf@Co
VYoH0onKW]H2oibMe003oiZJd_nLVM3oW9W@00;oW9W@0onNVLl4oj2JcP;oXY[=00?oXIO;oj>Hb_nS
V<X00onSV<X3ojJJb@04ojRKbOnXVLOoZ9W7ojRIa`CoZi_70on]WLL00on^W<Go/9k6ok2NaP02ok2N
aP?o/Z7700?o/j35okFSa_neXlH00oneXlH01?nfYLOo^:G6okRUa_l00003okVXa`03okbXa_nlZlSo
_:_800?o_:_800?o_Jk:okn^bOno[/T00_no[/T5ooooo`03o`000?oooooooooo02_ooooo000[oooo
o`;o00006Oooool3ojnUcPCo/JO?00Co/ZW?ok>Xc_ncZ<ko/jS>0oneZlh00onfZ/go]jc>okN/cP03
okN/cP04okR^coni[/ko^Jk>okV^cP?o^[3?00?o_;3>okbbd?nl/]000onl/]000onl]=;o_KCAokfd
d@02okfdd@04okffdonn]];o_[KBokjfdP?o_KSD00Go_kSCokjje_nn^]Ko_[[Foknje@05okjkf0Go
_KgI00?o^kkLokbnfonl_]/00_nl_]/01?nj_mgo0000ok^ogOnk_md2okRog`;o^L3O1?ng`>401?nd
`>;o]L3RokG0h_ne`>84ok?0i003ooooool0003ooooo05Cooooo0_l00009ooooo`04oij_i?nM[N?o
WJgSoif]h`CoWJcQ0_nLZN000onJY]ooVJCMoiVTg@02oiVTg@?oVJ;K1?nJXMT2oiZOf004oiRKe_nI
V]CoVI[DoiVJe0CoVY[B0onLVM04oijIc`;oX9[>00?oWiK;oj6GbonQUl/00_nQUl/4oj>HbP;oYY[9
00?oYYO7ojRIaonXVLL00onXVLL4oj^Ka`04ojfMaon^W<Go[Yc5ojjLa@Co/9k600Co/Z77ok>PaOnc
X<Go/j351?neXlH4okRUaP03o`000?niZ<Oo_:S600;o_:S60onlZlP00ono[<Oo_jk9okn^b@02okn^
b@03ol:`b?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool002Sooooo0ol0000Iooooo`03
ojfTc_n_YLko[jG>00;o[jG>0onaYll00onbY/go/jS>ok>XcP03ok>XcP04okF[c_nfZ/go]Z[=okJZ
c@?o]jc>00?o^Jc<okV^c_ni[/h00oni[/h01?nj/<oo_;3>okb`c_nl/<h3okbbd003okfbconm]=7o
_KCA00?o_KCA1Onn]]801Onm^=Co_kSCoknhdono^=?o_[[F00?o_k[E0onn^mP2oknle`?o_KgI00?o
_[kIokbnfonl_]/00_nl_]/00onm_m_o^koMo`000002ok^og@03okRogoni`=oo^L3O00;o^L3O0_ng
`>401?nh`N7o]L3RokG0h_ne`>82okK1hPCo/l3T00?oooooo`000?ooool0D?ooool3o`0000Sooooo
0_nO/ND3oij_i0?oWJgS0_nM[>400onJZ>3oVZKOoiZVg`02oiZVg`CoVJCM0onIX]/2oiZQf@03oiNM
eonHVmKoV9_F00;oV9_F0onIV]@3oiZJdPCoW9W@0_nNVLl00onLU/goWiK;oinFb`02oinFb`?oXIO;
0onSV<X00onSU/OoYYO7ojJGa`02ojJGa`CoZ9W70_n[VlL2oj^Ia@Co[Yc50on`W/H00onaWLCo/j35
ok>Pa@02ok>Pa@?o]J?60_ngX/@3okRUaP03o`000?nlZ<Ko_:S600?o_:S600Co_:_8okn/aono[<Oo
_jc70_no[/T2ol:`b0Oooooo00?o0000ooooooooool0:Oooool002Kooooo0_l0000Iooooo`03oj^R
c_n]Y<ko[JC>00;o[JC>1?n_YLh01?naYloo/ZK=ok:VcOnbY/d3ok>XcP03okBXc?nfZ/go]Z[=00?o
]Z[=00Co]jc>okV/c?ni[<co^Jc<0oni[/h00onk[/co_;3>okb`cP03okb`cP04okbbd?nm//oo_K;?
okfbc`?o_KCA0_no]=03okjfdP05ol2gdOno^=?o_kSCoknhdoo1^M801Ono^]D00onn^mSo_kcGoknl
e`02oknle`05okfmfOnn_]Wo_[kIokjnfOnl_]/01?nm_m/01?l0003o^koMokc0gOnl`=d3okW0g`03
ok[1gonh`N7o^<7Q00;o^<7Q00?o]L3RokK1h_nf`N800_nf`N82ok?0i003okC1i?oooooo000004oo
oooo0_l00005ooooo`03oj6ei_nP/nGoX;?U00;oX;?U1?nO/ND00onN[nCoW:gSoi^[hP03oi^[hP?o
VZSP1?nJY]l2oiVTg@04oiJQfonFW]WoUYkIoiJNf@CoUigG0onHVmH4oiVJe0?oVY[B0_nLVM000onJ
U/koW9K=oibFc@02oibFc@?oWiK;1?nQUl/01?nSV<[oXiK7oj>FaonSU/L3ojJGa`?oZ9W700?oZ9O4
oj^IaOn[VLD00_n[VLD5ojjLa@04ok2Na_naWLCo/Ig4ok6Ma0Co/j3500Co]J?6okNRa?ngX/Co]j;4
0onhYLH00ol0003o_:S6okbXaP02okbXaP03okjYaOno[<Oo_jc700;o_jc700?o_jk9ol:`b?o2/<P0
0_o2/<P6ooooo`03o`000?oooooooooo02Wooooo000Sooooo`?o00006_ooool3oj^RcPCo[JC>0_n_
YLh00on`Y<co/ZK=ok:Vc@03ok:Vc@04ok>Xc_ndZ<co]:S<okBXc0?o]Z[=00?o]jW;okV/c?ni[<`0
0oni[<`01?ni[/ko^jk<ok^^c?nk[/`3okb`cP03okf`cOnm//oo_K;?00?o_K;?00Go_KCAokndd?no
]=3o_kC@okjfdP04ol2gd@04oknhdoo1^M;o`KWBol6idP?o_k[E0_o1^m@3oknle`04ol6meonn_]Wo
_[kIokjnf@;o`;kI1?nm_m/00ol0003o_<3Mokc0g@02okc0g@04okW0gonj`Moo^/7Ook[1g`Co^<7Q
1?nf`N84okC1i003ooooool0003ooooo04[ooooo0ol00004ooooo`03oj:fionQ]NKoXKGV00;oXKGV
1?nP/nD2oinai@04oif_i?nL[N?oW:gSoib]h`CoVj_R0onJZ>02oiZVg`03oiJSgOnFXM_oUZ7K00;o
UZ7K0onFW]T3oiNMe`CoV9_F0_nIV]@01?nFU]7oV9K@oiRFd?nHU]04oiZFcP?oW9K=1?nOU//2oj6G
b`03oj2Db?nSU/OoXiK700;oXiK71?nVUlL01?nXVLOoZ9O4ojRGa?nXUl@4oj^Ia@?o[Yc500?o[Y_3
ok6Ma?naWL@00_naWL@3ok>Pa@03okBO`ongX/Co]j;400?o]j;400Co^:G6okZUa?l0003o^ZG40_nl
Z<H2okjYa@Co_jc71Oo2/<P7ooooo`03o`000?oooooooooo02Sooooo000Qooooo`;o00006oooool0
0onXX<koZj;>oj^RcP02oj^RcP?o[JC>00?o[Z;<ok2Tc?n`Y<`00_n`Y<`3ok:Vc@03ok>UbondZ<co
]:S<00?o]:S<00Co]Z[=okNYbongZL_o]jW;1?ni[<`5ok^^c004okb`c_nm/<go_K3=okf`c@?o_K;?
00Go_k;=okndd?no]=3o_kC@ol6ec`05ol2gd@Go`KWB00?o_k[Eol6ke?o1^m@00_o1^m@01Ono_=Oo
`KgGol6meoo1_MOo_[kI00Co`;kI0_nm_m/00onn`=_o0000okc0g@02okc0g@04okg1gOnj`Moo^/7O
ok[1g`;o^l7O1?nh`N44okK1hPCo]<7T00?oooooo`000?ooool0Aoooool2o`0000Cooooo0_nS]nL3
oj:fi`CoXKGV0_nP/nD2oijai@?oWJoT0onL[N<2oi^[hP04oiRXhOnGYMooUjGOoiNUg`CoUZ?M0onF
XM/4oiJNf@?oUigG0_nHVmH00onEUm?oUYKAoiJFd@02oiJFd@?oV9K@0onJU/h4oibFc@;oWiK;00?o
WI?9oj2Db?nPU<P00_nPU<P4oj>Fa`;oYYO700?oYIG5ojRGa?nXUl@00_nXUl@4oj^Ia@04ojjLaOn^
Vl?o[Y_3ojjK``Go/Ig400Co/j35okBO`ondWl?o]9o30ongX/@01_niXl?o^ZG4okZUa?l0003o^ZG4
okbXaPCo_ZW50_no[<L2ol6]aPCo`[382?ooool00ol0003oooooooooo`0Wooooo`007_ooool3o`00
01[ooooo00?oYYo?ojRPc_nXX<h00_nXX<h4oj^RcP04ojfTc_n^X/co[Z;<ojjRc0Co/:C<00Co/ZK=
ok>UboncYL_o/jG;0ondZ<`00onfYl[o]jW;okNYb`02okNYb`?o^Jc<0_nj[</4ok^^c0Co_K3=00?o
_K;?oknbcOno//d00_no//d01?no]=3o`KG?ol6ecoo1]Ll3ol2gd@;o`[O@0oo1^M82ol:jdP?o`K_D
00Go`kcDol6meoo1_MOo`KgGol:neP05ol2nf@?o_/3K00?o0000okc0gOnm`Md00onm`Md00onj`Moo
^l7Ook_1g`02ok_1g`;o^<7Q00Co^L;QokK1h_nf`N;o]/7R0_ng`^84okC1i003o`000?oooooooooo
04?ooooo0ol00003ooooo`;oY;WW1?nS]nL3oj:fi`;oXKGV0_nO/nH4oijai@;oWJoT0_nL[N<00onI
Z^?oV:SQoiRXh@02oiRXh@?oUjGO1?nFXmd3oiJQf`;oUYkI00CoTi[HoiBIe_nDVMKoU9WF1?nEUm<3
oiJFd@CoV9K@0onJU/h2oibFc@03oi^Bb_nMTlWoWI?900;oWI?90onPU<P3oj>Fa`03oj>CaOnUULGo
YIG500;oYIG50onXUl@3oj^Ia@03ojbH`on^Vl?o[Y_300?o[Y_30onaWL@00onbWL;o]9o3okBO``02
okBO``04okNRa?niXl?o^J?3okVS``;o^ZG400?o0000okZUa?nnZLD01?nnZLD01?no[<Oo`Jg6ol6]
a_o1[LH3ol:`b0;oa;771oooool00ol0003oooooooooo`0Wooooo`007?ooool2o`0001cooooo0onV
Wll4ojRPcP;oZj;>00?oZj7<ojjRc?n^X/`00_n^X/`3ok2Tc003ok6SboncYL_o/jG;00?o/jG;00Co
]:S<okJWb_nfYl[o]ZO:1?ngZL/01?ni[<co^Zc;okZ/bonj[</3ok^^c0;o_Jk;0_nm/<d00ono/<_o
_k;=oknbc@03oknbc@Go`KG?00?o`;OAol:gd?o2]m000_o2]m000oo1^M;o`[[Bol:jdP02ol:jdP05
ol6ke?o3_=Co`kcDol>le?o1_ML00oo2_]H3ol2nf@;o`KoH0_nn`=/00ol0003o_l7Kokg1g@02okg1
g@03okk2gOnk`Moo^l7O00;o^l7O00?o^l;OokW2hOni`^400_ni`^400onf`N;o]l;RokO2hP02okO2
hP?o]<7T00?oooooo`000?ooool0@Oooool2o`0000Cooooo0_nU^^P3ojBii`;oXkOW00?oX[KWoj6e
ionQ]NL00_nQ]NL4oinciP;oW[7U00CoW:oUoiZ]i?nJ[NCoVZgT0onIZ^<4oiRXh@?oUjGO0_nFXmd0
1?nCWmcoTicJoi>Lf_nCW=X4oi>Jf0?oU9WF0onEUm<4oiJFd@;oV9K@00CoUY;=oiRBc?nHT/coV9;<
1?nKT/X3oifCb@CoX9C800CoXiK7oj>CaOnSTlGoXi?50onUULD4ojRGa004oj^IaOn/V<?o[9S3ojbH
``Co[Y_300Co/Ig4ok:M`_nbWL;o/Yg21?ndWl<5okVS``04okZUa?l0003o_:K3okbV``Co_ZW51Oo1
[LH00oo2/<Soa;77olBaa`02olBaa`Oooooo00?o0000ooooooooool09_ooool001Wooooo0ol0000L
ooooo`03oj>MconVWlooYYo?00;oYYo?0onXX<h00onXWlcoZj7<oj^Qc002oj^Qc0Co[Z;<00Co/:C<
ok6SbonaXl_o/J?;0oncYL/00ondYLWo]ZO:okJWbP02okJWbP?o]jW;00?o^JW9okZ/bonj[</00onj
[</01Onk[/co_Jk;okf^bonm[/_o_K3=00?o_k3;0ono//d2ol6cc0?o`KG?00?o`[K>ol:gd?o2]m00
0oo2]m04ol:jdP03olBkdOo3_=Co`kcD00;o`kcD1Oo2_]H01oo0_]Wo`KoHol6of?o1_mSo_/3Koko1
fol000000_no`M/01Onm`Mgo_/;Mokk2gOnn`]go^l7O00Co^l;O0oni`^44okO2hP03okO2hond`NCo
]<7T00;o]<7T00?oooooo`000?ooool0?Oooool3o`0000?ooooo0_nV^^P4ojFjj003ojBiionS^>Oo
X[KW00?oX[KW1?nQ]NL2oinciP;oWK7V0onL[nD3oiZ]i0?oVJ[S0_nHZ>400onDY>3oTj;Noi>RgP02
oi>RgP?oTioL0onCW=X3oi>Jf0?oU9WF0_nEUm<00onBTm;oTi;?oi>Bc`02oi>Bc`?oUY;=0onHT/`4
oi^BbPCoWI?90_nPU<P00onOT/KoXi?5oj>Ca@02oj>Ca@CoYIG50_nXUl@00onYU/;o[9S3ojbH``02
ojbH``?o[Y_300?o/9[1ok:M`_nbWL800onbWL82okBO``;o]Yo11?niXl<01?njYLCo0000okbV`onl
Y/<3okjYa@;o`:[40oo1[LH00oo4[lGoa;77olBaa`03olBaa`Sooooo00?o0000ooooooooool09Ooo
ool001Kooooo0ol0000Looooo`03oj2Ld?nSWLooXig?00;oXig?1?nVWll01?nXX<koZ9o<ojROc?nX
Wl`4oj^Qc0;o[Z;<00?o[Z7:ok6SbonaXl/00onaXl/00oncYL_o]:G9okBUb@05okJWbP04okNYboni
ZLWo^JW9okVYb@?o^Zc;00?o_:c9okf^bonm[//00_nm[//5okn`b`03oknbcOo1/lco`K?<00;o`K?<
00Co`KG?ol:fc_o2]/ko`[K>0oo2]m02olBhc`;o`[[B0oo4^m42ol>le0;oa;gC0oo2_]H01?o3_mKo
`KoHol6of?o1_mP2ol;1f004oko1fol0003o_l7Kol72f`?o_/;M0_nn`md3ok_2g`03okc3goni`^7o
^L;Q00;o^L;Q00?o]l;RokO2hong`^<00_ng`^<2okC1i003okC2i?oooooo000003_ooooo0ol00003
ooooo`;oY[_X1?nV^^P2ojFjj0;oY;WX0_nS^>L4oj:fi`;oXKGW0_nO/nH4oifaiP;oW:oU0_nJ[N@0
0onGZ^?oUZORoiJWhP02oiJWhP?oU:CP1?nCX]h3oi>Og0?oTicJ00?oTi[HohnFe_n@U=@00_n@U=@4
oi:CdP?oTi;?1?nFT/d3oiRBc0CoVi;:0_nMTlT00onLT<OoWi;6oinBaP02oinBaP?oXi?50onUULD0
0onVTl?oZIK2ojVF`P02ojVF`PCo[9S300Co[Y_3ok2J`On`V/7o/9[11?nbWL801?ndWl?o]Yo1okJO
`OnfWl43okVS``03ok^S`OnlY/?o000000?o_:K300?o_ZW5ol2Za?o0Z/@00_o0Z/@01?o1[LKoa:o5
olB_aOo4[lD3olBaa`;oak?71oooool00ol0003oooooooooo`0Uooooo`005?ooool2o`0001cooooo
00?oWI_Boj2Ld?nPW=000_nPW=04oj>Mc`;oYYo?00?oYYg=ojROc?nXWl`00_nXWl`3oj^Qc003ojbO
b_n^XL[o[Z7:00;o[Z7:0onaXl/00onbXlWo]:G9okBUb@02okBUb@?o]ZO:00?o]jO8okVYbOniZLT0
0_niZLT00onj[<_o_:c9okb/b@02okb/b@;o_Jk;0_nn[/X3okn`b`03ol6ab_o1/lco`K?<00?o`K?<
1Oo2]/h01Oo2]m3oa;S?olBhcoo4^<oo`[[B00Coa;_A00?o`kcDolBmdoo4_M<00_o4_M<01Oo2_]Ko
`koFol>oe_o3_mKo`KoH00Co`/7H00Go0000ol72foo1`]_o`L;Kokk2g@04okk3g@04ok_2gonl`moo
_<?Ookc3g`;o^L;Q0_nj`n43okO2h`03okO3hond`^Co]<;T00;o]<;T00?oooooo`000?ooool0=ooo
ool2o`0000?ooooo0_nW^nP4ojJkj0;oY[[X0_nU^^P4ojBij0;oXkSW0_nR]^L2oj2ei`CoWk?V0_nM
/NH01?nK[nKoVJgUoiV]iOnI[ND3oiNZh`CoUZOR0onDY>02oi>RgP04ohnNgOn?Vm_oSi_KohnKf`?o
SiWI0on?U]H3oi2De0?oTY?B1?nCT/l3oiJBc@?oV9;<0_nKT/X2oiV?b0?oW9371?nOT/H4oj>Ca@04
ojFEaOnVTl?oYY?3ojJC``?oZIK20on/V<<00on]Ul7o/9[1ok2J`@02ok2J`@?o/Yg200?o]9g1okJO
`OnfWl400onfWl401OniXl?o^j?1ok^S`OnkXl7o000000?o_:K31Oo0Z/@5olB_a@04olBaaoo7/lOo
ak?7olNca`Sooooo00?o0000ooooooooool09?ooool0017ooooo0ol0000Hooooo`04oiRKe?nKVm?o
Vi_Coi^Kd`CoWI_B1?nPW=02oj>Mc`03oj>Kc_nVWLgoYYg=00;oYYg=1?nXWl`00on[XLco[9o:ojbO
bP04ojjQbP04ok6SbonbXlWo/Z?9ok:Sb@Co]:G900?o]ZO:okNWb?ngYlP00_ngYlP2okVYb@03okZY
b?nl[<Wo_:c900?o_:c900?o_Jk;okj^b_nn[/X00_nn[/X01?no/<_o`K7:ol6ab_o1/LX3ol6cc0;o
`kC;0oo2]/h01?o4]lgoa;S?olBhcoo4^<l2olFic`?oa;_A0_o6_=43olBmd`04olJndoo3_mKo`koF
ol>oeP;oaL3F0oo2`MP2o`0000;o`L;K0_o2`m/3okk3g@03oko3gOnl`moo_<?O00;o_<?O00?o^L;Q
ok[3hOnj`n400_nj`n401?ng`^?o]l?SokO3hong`n<4okC2i003ooooool0003ooooo03?ooooo0ol0
0003ooooo`;oZ;cX0onW^nP4ojJkj0CoYK[X0_nT^NP01?nS^>SoX[OWoj:gionR]nL4oj2ei`;oWk?V
0_nM/^H3oi^_iP?oVJgU0onGZ^<2oiJWhP04oi:Th_nAXMooTJ7Ooi6Qg`CoSikM0on?Vm/3ohnIf@;o
SiKF1?n@U=@3oi:CdP?oTi;?0_nFT/d01?nCS/coUXo:oiJ?b_nFSlX4oiV?b0CoW9371?nOT/H2oj>C
a@03oj:A`onVTl?oYY?300;oYY?31?nYU/801?n/V<?o[IO1ojfG`On]Ul44ok2J`@04ok:M`_ndWL7o
]9g1okBM`@Co]Yo10onkXl42o`0000;o_:K30_noYl83ol2Za003ol>/`oo4[lGoa:o500;oa:o500?o
ak75olNcaoo7/lL00_o7/lL9ooooo`03o`000?oooooooooo02?ooooo000@ooooo`;o00005oooool0
0onFVmKoV9_DoiRKe002oiRKe0?oVi_C1?nMVm82oj2Ld003oinJconSVlkoXi_>00;oXi_>1?nVWLd2
ojROc003ojVMbon/Wl[o[9o:00;o[9o:0_n^XLX00on_X<Wo/Z?9ok:Sb@03ok:Sb@;o]:G900?o]JC8
okNWb?ngYlP00ongYlP01?niZLWo^ZW8okZYb?njZLP3okb/b@03okf/b?nn[/[o_Zk:00?o_Zk:1Oo1
/LX00oo1/lco`kC;ol>db`02ol>db`05ol:fc_o4]lgoa;O=olBgcOo4^<l01?o5^Ll00oo4^m7oa[cA
olJld@02olJld@05olBmdoo6_]?oa[kColJndoo3_mH00oo5`=H3o`000003ol?2f?l0003o`L;K00Co
`/?K00Co_/?Moko3gOno`mgo_l?M0_nl`ml2okg4g`?o^/?Q00?o^/?RokO3hong`n<00_ng`n<5okC2
i003o`000?oooooooooo037ooooo0_l00002ooooo`KoZ;cX0onW^nP4ojJkj0;oYK[X0_nT^NP3oj>h
j0?oX[OW0_nP]NL2oijdi`CoWK;V0onK[nH00onI[NGoUZ_UoiBWh`03oiBWh`?oTZCR0onAXMl3ohnN
g@?oSi_K0on?VMT3ohnFeP;oT9CD00CoS93Bohj?d?n>Sm3oSXo@0on@Slh4oi>>c0?oUXo:1?nISlP3
oib@a`;oWi;60_nOT<@3oj:A``CoYY?30onYU/800onYUL7o[IO1ojfG`@02ojfG`@?o/9[100?o/I[0
okBM`OndWL400_ndWL43okJO`@07okRP`?l0003o0000o`000?nkXl7o0000okbV``04oknW`P04ol2Z
a?o3[<?o`jc3ol>/``;oa:o50oo7/LD2olNca`;ob[K72?ooool00ol0003oooooooooo`0Sooooo`00
4?ooool00ol0003oooooo`00000Aooooo`03oi6Lf_nCVmSoTi_H00CoUY_F0onHVm@4oi^Kd`;oWI_B
00?oW9W@oinJconOV/l00_nOV/l3oj>KcP?oYYg=00CoYY_;ojVMbonYWL_oZIg;1?n/WlX01?n^XL[o
[j39ojnPbOn_X<T4ok:Sb@04okBUbOneY<So]JC8okFTb0?o]jO800?o^JO7okZYb?njZLP00onjZLP0
1?nl[<Wo_Jc8okf/b?nm[<P3okj^bP;o`:o80oo1/LX00oo3/LWo`kC;ol>db`03ol>db`Coa;O=1Oo5
^Ll5olJld@Coa[kC00GoakoCo`000?l0003o0000olK1eP03ol?2f003olC3f?l0003o`/?K00;o`/?K
00Co`/CKoko3gOno`mgo_l?M0_o0a=d4okg4g`04ok[3hOnj`n;o^/?Rok[3hPCo]l?S0_nd`^@2okG2
i003ooooool0003ooooo037ooooo00?o0000ojRlj?nX_>P01_nX_>P2ojNlj0?oYk_X0_nV^nP2ojFj
j0CoY;WX0onS^>P00onR]nOoX;KXoj2fj004oijdi`;oWK;V00CoV[3WoiR^i_nH[^KoV:kV0onFZnD4
oiBWh`?oTZCR0onAXMl00on?W]goRi[Moh^GfP02oh^GfP?oRiCH0on;T]D4ohb@dP?oSXo@0on@Slh3
oi>>c0?oUXo:1?nISlP2oib@a`03oi^>aOnOT<CoWi3400;oWi341?nRTL<4ojJC``04ojVF`_nYUL7o
ZIG1ojVE`@Co[IO100Co/9[1ok6J`?naV/3o/I[01?ndWL43o`000006okRP`?nkXl7o^j?1ok^S`Onm
YL7o00001?noYl84ol>/``03olB_aOo7/LGoak7500;oak7500?oak?7olZfaoo:]/L00_o:]/L8oooo
o`03o`000?oooooooooo02;ooooo000@ooooo`04o`000?ooooooooooo`0000[ooooo00CoT9oNoi2M
g?n@WMcoT9gL1?nAW=X2oi>Kf0CoUY_F0onHVm@2oi^Kd`03oiVHdOnLVM3oW9W@00;oW9W@0onOV/l4
oj>KcP03ojJMcOnVVl_oYY_;00CoZIg;0_n/WlX00on/W/Wo[j39ojnPb@02ojnPb@?o/Z?900?o/j;7
okFTb?neY<P00oneY<P01?ngYlSo^JO7okVWaoniYlL4okZYb0Go_Jc800?o_Zk:ol2_b?o0[lP00_o0
[lP01?o1/L[o`k79ol>abOo3/LT3ol>db`;oaKC;0_o4]ld2olJhc0?oaKW?0_o7^/h3olJld@;oakg@
00Koa[kCo`000?l0003o0000olNodoo5`=H3olK1eP06ol?2f?o4`mSoa<?HolC3f?l0003o`/?K0oo2
a=/00ono`mgo`<CMol34g@02ol34g@;o_LCO00Go_LCPok[3h_nj`n;o^/?Rok[4hP05okO3h`Co]L;T
00?o0000ooooooooool0<?ooool00ol0003oZ;cXojRlj005ojRlj0CoYkcX00?oYk_XojJkj?nV^nP0
1?nU^^P2ojBij0;oXkWX0_nR]nP4oj2fj0;oW[CW0_nL/^L3oiZ`i`?oV:kV0onFZnD2oiBWh`04oi2U
hon>XN7oSZ7QohjQh@?oS9gO0on;V]d3oh^GfP?oRiCH0on;T]D3ohb@dP?oSXo@0on@Slh4oi>>c0?o
UXo:0_nISlP00onHSLKoVhk5oi^>a@02oi^>a@CoWi340onRTL<2ojJC``;oYY;11?nYUL43ojfG`@03
ojjG_onaV/3o/I[000;o/I[000Co]9g1o`000?l0003o00001OnhX<001OnkXl7o_JG1okfU`OnmYL7o
000000;o_jO200?o`ZW1ol>/`oo3[<<00_o3[<<5olNaa@Gob[K72?ooool00ol0003oooooooooo`0R
ooooo`004?ooool01Ol0003ooooooooooooooooo000000Cooooo00CoT:?RohnQh?n?XN3oSj7P0on@
Wmh3oi2Mg0CoTIcJ0_nCVmP2oiJKeP04oi>HeOnFV=?oUYSCoiJHd`CoVISA0onLVM04oinJc`;oXi_>
00?oXY[<ojJKbonVVl/00_nVVl/3ojVMb`04ojbOb_n/W/Wo[9k9ojbNb@Co[j3900Co/Z?9ok>Raonc
X/Oo/j;71?neY<P4okVWa`?o^ZW80_nlZLL3okf/b003okn/aoo0[lSo`:o800?o`:o81Oo3/LT01Oo3
]<_oaKC;olFdboo5]<_oa;O=00Coa[S<00?oaKW?olNjc_o7^/h00_o7^/h00oo6_=7oakg@o`000002
o`0000CoakoC1?o6`MH01_o7`mKoa<?HolC3f?o4`mSoaLCIo`0000;o`/CK0_o3aM/3ol34g@03ol35
g_nma>3o_LCP00;o_LCP00Co^/?Rok[4h_nja>;o^/CR1Ong`n<2okG2i003okC3iOoooooo0000037o
oooo00?o0000oooooonX_>P01_nX_>P2ojNlj0;oYk_X0onV^nP2ojFjj0;oY;[X1?nS^NP2oj:gj0;o
X;KX0_nN]>P4oibbi`?oV[3W00?oV:kVoiF[i_nBZ>D00onBZ>D3oi2Uh`?oSZ7Q0on<WMl2oh^Jg@Co
RiOJ0on;U=P3oh^Be@?oS93B0on>Sm03oi2?cP;oThk<00CoTH_:oiB<b?nDS<SoU8c81?nHSLH3oi^>
a@CoWi340_nRTL<00onRT<;oYY;1ojJB`@02ojJB`@GoZIG100?o[IO1ojjG_on^Ukl00_naV/03o`00
0004okBM`OnfWKoo]YfookJM_`Co^:301OnmYL401?l0003o`ZW1ol:Y`Oo2ZL42ol>/``;oaZo30oo7
/LD2olZda@?ob[K70_o=^LL8ooooo`03o`000?oooooooooo027ooooo000?ooooo`03o`000?oooooo
Tj_V00?oTZSU0onAYN<3oi2ShP?oSj7P0on@Wmh3oi2Mg0;oTIcJ00?oSiWIoi6HeonAV=L01?nCV=D3
oiJHd`?oVISA1?nLVM02oinJc`03oinHcOnRV/coXY[<00;oXY[<0onVVl/2ojVMb`03ojVLbOn/W/Wo
[9k900;o[9k90on_X<T00on`X<Oo/j;7ok>Ra`02ok>Ra`?o]JC80_ngY<H4okVWa`03okZYb?nlZLOo
_:W700;o_:W700Co_Jc8okn/aono[<Oo_jc70oo0[lP2ol:_b0?o`k7900?oa;;8olFdboo5]</00_o5
]</5olJhc004olRic?o7^/koak[>olNjcP?o000000?oakg@olVnd?o9_]000oo7_m<2olS1d`;oa/7F
0oo7`mH01Oo4`mSoaLCIolG4fOl0003o`/CK00Co`lGK00Co`<CMol35g_o0aMko`<GN0_nma>02okg5
h0;o^/CR0_njaN83okO3h`03okO4i?nd`nGo]<?U00;o]<?U00?oooooo`000?ooool0;_ooool01?l0
003oooooooooooooool5ojRlj0;oYkcX1?nW^nP00onV^nSoYK[XojFjj004ojBjj0;oXkWX00CoX[SX
oj2fj?nP]^SoX;KX1?nN]>P2oibbi`04oiZaionH[^OoV:kWoiR^i`?oUJ_V1?nBZ>D3oi2Uh`?oSZ7Q
0_n<WMl3oh^Jg@;oRiOJ00CoQI?IohJ@eon6T=OoQY3G0on7S]@3ohR=d@?oRhc?0on=Rl`4oi6;bP?o
U8c80onHSLH4oi^>a@;oWi3400?oWXk3oj:@`_nRT<800_nRT<84ojJB`@?oZIG100?oZYC0ojjG_on^
Ukl00ol00002ok6J`003ok>K_onfWKoo]Yfo00;o]Yfo0onhX<000onkX[oo_JG1okfU`@02okfU`@03
ol2V`?l0003o`ZW100;o`ZW100?o`jc3olJ_`oo6[l<00_o6[l<00oo7/LGob[C5olZda@02olZda@04
olZfaoo=^LOocKW7olfia`Wooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oi>[i_nC
ZnKoTj_V0onBZ>D3oi6Uh`?oT:?R0_n?XN02oi2OgP04ohbLgOn=V]_oSI[KohfJf`?oSiWI0onAV=L3
oi>He@CoUYSC0onIV=42oibId004oi^GconOV<goWiS=oinHc@CoXY[<0_nVVl/00onVV/[oZIc9ojVL
b@02ojVLb@Co[9k900Co[j39ok2Paon`X<Oo/:371?ncX/L01?neY<So]jC6okNTa_ngY<H3okVWa`03
okZWa_nlZLOo_:W700?o_:W71Ono[<L01Oo0[lSo`Zo8ol:_b?o2[lSo`k7900Coa;;80_o5]</2olJf
bP?oa[S<0_o8^L`3o`0000;obKc>00?oakg@olVnd?o9_]000_o9_]001Oo7_m?ob<7ColS1doo8`M?o
a/7F00Coal?F0oo5a=T00oo6aMWo0000ol?5f`02ol?5f`05olC6g?o0aMko`<GNol35g_o1a]h00onm
aN02okg6h@Co^/GR00Co]l?SokO4i?nga>Co]lCT0ond`nD00ooooooo0000ooooo`0^ooooo`03o`00
0?oooooooooo00;ooooo0onX_>P4ojNlj0;oYk_X0_nV^nP3ojFjj0;oY;[X0_nS^NP3oj:hj0?oX;KX
0_nN]>P2oibcj0?oV[7W0onH[^L3oiF[iP;oTZSU00CoSjGUohbRhon<X^?oS:;S0on9W^42ohNJgP?o
QYKL1?n5TmT3ohJ@e`?oQhkD0on8SM43oh^<c`?oSH_<0onARlX3oiB<b0CoV8g60_nKS/D00onJS<Co
WXk3oij>``02oij>``?oXY321?nVT/400onYUL7oZYC0ojZD`003o`0000;o[YNo0_naV/02ok>K_`Go
]Yfo00Co^:30ok^R_onkX[oo^j:o0_nmYL42ol2V`004ol:Y`Ol0003o`ZW1ol:Y`@GoaZo31Oo:]<D4
olfia`03om2mb?oooooooooo00Kooooo00?o0000ooooooooool08?ooool000oooooo00?o0000oooo
oonCZnH00_nCZnH2oi:Xi@;oTJGS00CoSJ?SohbPhOn<X>7oS:3Q0on<W]l3ohbLg@?oSI[K0on?VMT3
oi6He`?oTiSE0_nFV=<01?nDUM;oV9K@oiRFd?nHU]04oi^Gc`?oWiS=0_nRV/`00onRV<_oYY[:ojJJ
bP02ojJJbPCoZIc90_n/W/T00on]WLOo/:37ok2Pa`02ok2Pa`?o/j;700?o]:;6okNTa_ngY<H00ong
Y<H01?niYlOo^ZO6okZWa_njYlH3okbYa`;o_Z[61?no[<L4ol:_b0Goa;;800?oaKC;olJfb_o6]/X0
0_o6]/X01Oo6^<co0000o`000?l0003ob;W<00CobKc>1Oo9_]03olS1d`;ob/;C0oo7`mH2olS4eP06
olG4fOo6aMWoa/GIolK5fOl0003o`lGK0oo4a]`01Oo0aMko`LKNol76g_o1a]ko_LGP00Co_LKQ0_nj
aN800onjaN?o]lCTokO4i002okO4i0Co]<?U00?oooooo`000?ooool0;Oooool00ol0003ooooooooo
o`03ooooo`?oZ;cX1?nW_>P4ojJkj0?oYK[X1?nS^NP3oj:hj003oj2fj?nO]^SoWkKX00CoW;?X0onJ
/NL00onH[^OoU:gWoiB]i`03oi6YiP?oSjGU0on<X^<3ohVNh@;oQi[N0on6U]`3ohFCf@?oQY3G0on7
S]@3ohR=d@?oRhc?0on=Rl`4oi6;bP?oU8c80_nHSLH00onFRlGoVXc4oiZ<a002oiZ<a0?oWXk30onR
T<83ojJB`@04ojJB`?l0003o0000o`0000;oZYC00on^Ukl00onaV/3o/i^ook>K_`02ok>K_`?o]Yfo
00?o^9nook^R_onkX[l00_nkX[l00onmYL7o`:K0ol2V`002ol2V`004ol:Y`Ol0003oaJc1olF/`@?o
aZo30_o9//<3olZda@;ocKS50_o=^LL3om2mb0Sooooo00?o0000ooooooooool07oooool000oooooo
00?o0000oooooon@Z>H00on@Z>H2ohjUi@?oSJ?S0on<X>43ohbNg`?oS9cM0on=V]/2ohnIf@;oTISG
00CoSYGFoi6Ee?nAUMCoTIGD1?nDUM83oiRFd0?oViO?0onOV<d01?nRV/coXYS;oj:HbonRV</3ojJJ
bP?oZIc900?oZI_8ojfMaon]WLL00_n]WLL4ok2Pa`04ok>RaondX/Ko]:;6okBRaP?o]jC600?o^:G5
okZWa_njYlH00onjYlH01?nlZLOo_Z[6okjZa_nnZ/H3okn/a`;o`Jg60_o2[lP2olB`a`?oa;;80_o6
]<P2olJfbP?o00000oo8^L`2olZjb`;obKc>0_o;_Lh3olVnd0;obl3@00?ob<7Col[2doo:`]<00_o:
`]<01Oo7`mKob<CFolS4e_o8a=KobLKF00?oa/GI00GoalOIo`000?o4a]coa<KLolC7g003ol76gP;o
`LOO1?nma^44ok[5h`Co]lCT1Ond`nD00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Co
oooo00?oZ;cXojNlj?nW_>P01?nW_>P4ojJkj0?oYK[X0_nS^NP2oj:hj0?oXKOX0onO]^P2oibcj0;o
V[;X0onH/>P3oiB]i`?oTJWV0on?YND3ohbRh`;oRIkQ0on7V]h3ohJFg0?oQI?I0on6T=L3ohN>e0?o
R8gA0on;S<l3ohf;c0;oTH_:00CoSXS9oi:9aonBRLOoTXW71?nFRlD3oiZ<a0?oWXk31?nRT<83o`00
0003ojJB`?nZU<3oZYC000;oZYC00_n^Ukl00on_V;oo/i^ook>K_`03ok>K_`;o]Yfo0_nhWkl4ok^R
_`Go`:K000?o`ZW1olF/`Ol000000_o5[<400oo6[l?obK;3olVb``02olVb``05olZdaOo=^<GocKS5
olfhaOo=^LL01?o@_LP9ooooo`03o`000?oooooooooo01kooooo000?ooooo`03o`000?oooooooooo
00CoT:SV0_n>YND3ohfSh`?oS:3Q00?oS9kOohRJgon8V=d00_n8V=d3ohVGfP;oRiKH1?n>UMH3oi6E
e0?oU9GB1?nHU]000onKUlooVYG=oijGc002oijGc0CoXYS;1?nVV/X01?nYW<WoZI_8ojVKb?nYVlP4
ojfMa`;o/:3700?o/Io6okBRa_ndX/H00ondX/H01?ngY<Ko^:G5okRUaOnhYLD3okZWaP03okbWaOnn
Z/Ko_Z[600?o_Z[600Go_jc7ol6]a_o1[LKo`Jg6ol:_b004olB`a`04olBbb?o6]<Soa[C8olJdb0;o
00001?o8]lT01Oo8^Lcob[[;olZjboo:^/_obKc>00Cobkg>00GobKk@ol_0d?o;`=3obl3@olc2d003
ol[2d`04ol_4doo8a=Kob<CFolS4eP?obLKF00Goa/GIolO7fOo7amWo0000olC6g003olC7g003ol76
g_o1amoo`LOO00;o`LOO1?nma^42ok[5h`;o^/KS1?nga>@4okC3i@03o`000?oooooooooo02_ooooo
00?o0000ooooooooool01Oooool5ojNlj0KoY[_X00?oYK[XojBjj?nT^^P01?nR^>P3oj6gj003oinf
j?nM]>WoWKCY00CoV[;X0onH/>P00onD[NOoTJ_WohjWiP02ohjWiPCoRZ?U0_n7W^<3ohBJh@;oPYKN
0on1T]/3oh2?f@?oPHcF0on2R]<3ohB9d0?oQhS=0on:R</3ohj8b@CoTXW70onFRlD3oiZ<a0CoWXk3
00?oXY32o`000?l000001?nVT/04ojZD`004ojjG_on_V;oo[iRoojnH_`Co/i^o00?o]YfookRO_onh
Wkl00_nhWkl2ok^R_`;o_JBo1?o0Y/02olF/`@03o`000?o5[<7oaJc100GobK;31?o=^<D5om2mb003
om?2b?oooooooooo00Kooooo00?o0000ooooooooool07_ooool000oooooo00Co0000oooooooooooo
oooo0_n@Z>H00on=Y^KoRj?Uoh^Si@03ohVPh`CoR9gQ0_n8V]l3ohRHg@?oRIOJ0_n;U]P3ohjEePCo
TIGD0onDUM82oiRFd004oiJDconJULgoVYG=oiZEc@?oWYO<1?nRV</2ojJJbP03ojJIb?nYVlSoZI_8
00;oZI_80on]WLL00on^WLKo/Io6ok6OaP02ok6OaP?o]:;600?o]J;5okRUaOnhYLD00onhYLD01?nj
YlKo_:O5okbWaOnlYlD3okjZaP03okn[aOo1[LKo`Jg600;o`Jg61Oo4/<L01Oo6]<So0000o`000?l0
003oa[C800Cob;O900?ob[W9olZjboo:^//00_o:^//01Oo<_<_obkg>ol^mc_o;_Lkoc;o>00?obl3@
0oo<`]001Oo:`]?oblCCol_4doo;a=?ob<CF00CobLKF0oo7amT01?o8b=[o0000olC7g?o4am`2olG8
g@?o`LOO00Go`LSOokg6hOnma^7o_LKQokg7hP05ok[6h`Co]lCT1?nd`nD00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00Kooooo0onW_>P6ojJkj0;oYK[X0onT^^P2oj:hj0;oXKSY0_nO]^T4
oifdj@;oV[;X00CoV;7YoiB^j?nD[^SoU:kX0onAZnL3ohjWiPCoRZ?U0_n7W^<3ohBJh@;oPYKN0on1
T]/3oh2?f@?oPHcF0_n2R]<3ohB9d0?oQhS=0on:R</4ohj8b@?oTXW70onFRlD4oiZ<a004oij>`ol0
003o0000o`0000?oXXo10onVT/03ojZD`003oj^E_on_V;oo[iRo00;o[iRo0oncVkl00ondW;ko^9no
okRO_`03okRO_`04ok^R_onmY;oo_JBookfT_`?o`:K00_o3ZL02olF/`@03o`000?o5[<7obK;300?o
bK;30_o=]L<2olfha@;od;c60oo@_LP2om?2b0Wooooo00?o0000ooooooooool07Oooool000kooooo
00?o0000ooooooooool00oooool3ohfViP;oRj?U0on9X><4ohRMh@;oR9[O0on8V=d3ohVGfP;oRiKH
0on>UMH2oi6Ee004ohjBdonBTm7oTY?Aoi:Cd@?oUYC?0onJULd4oijGc0;oXYS;00?oXYO9ojJIb?nV
VLP00_nVVLP4ojVKb004ojfMaon^WLKo[Yg6ojjMaPCo/Io600Co]:;6okFRaOneX/Go]J;51?nhYLD4
okbWa@03okjZa_noZlGo_j_500;o_j_50_o1[LH2ol>^a@;oa;370ol00003olJdb0;ob;G70_o8]lT3
olZib@;ob[[;0oo<_</01Oo;_Lkoc;o>olboc_o<_lkobl3@00Coc<;@0oo;a=<2olc6e0?obLKF0_o:
amL01Oo7amWob<SJolS8f_o8b=[o000000CoaLSM00Go`LOOol78goo1b=oo`LSOokg6h@03okg7hPGo
^/KS0_nga>@01ongaNGo]<?UokC3iOnd`nGo]<?Vooooool00000:_ooool00ol0003oooooooooo`08
ooooo`?oYkcX1?nV^nP4ojFjj003ojBjj?nS^NWoXkWY00CoXKSY0_nO]^T2oifdj@;oVk?Y0onH/NT3
oiB^j0?oTJ_W0on>YnH2ohZSi@03ohFPiOn2Vn?oPY_S00?oOYOQ0omlT]h3oh6Bf`?oP8oI0_n1S=H3
oh::d`?oQ8W@0on7R<d3ohZ8b`?oSXS91?nBRLL3oiJ;a@04oiZ<a?l0003o0000o`0000?oWXg20onR
Sl44ojJB`004ojZD`?n[UKooZiFooj^E_`Co[iRo00Co/i^ookBL__ndW;ko]9bn1?nhWkl5okfT_`04
ol2V`?o3ZL3o`jW0ol>Y`0?oaJc100Co0000olR_`_o9//?obK;30oo=]L<00oo=^<God;c6om2laP02
om2laP04om2mb?oC`/Sodl;8om?2b0[ooooo00?o0000ooooooooool07?ooool000kooooo00?o0000
ooooooooool01?ooool3ohfViP;oRj?U0on9X><2ohRMh@03oh>JhOn3UmkoPiON00?oQ9GL0on5TmX2
ohRBe`?oRi;E1?n>T]<3oi:Cd@?oUYC?0onJULd2oijGc003oifEbonRUlWoXYO900;oXYO90onVVLP3
ojVKb003ojZKaon^WLKo[Yg600;o[Yg60onaWlH00onbWlGo]J;5okFRa@02okFRa@?o^:G500?o^JG4
okbWaOnlYlD00_nlYlD5okn[a@03ol6]a_o3[/Go`jk500?o00001?o6//H01Oo6]<Sob;G7olReaoo8
]LOob;O900Cob[W900?ob[[;olblboo<_</00_o<_</4olbocP04olk1c_o<`]3oc<;@olc2d0;oc/CA
00?oblCColc6e?o<a]@00_o<a]@01?o9a]Kob/OGol[7eoo:amL3olS8fP;ob<WK00Co0000olG8gOo5
b=goaLWM0oo1b=l01?o1bN3o_LORokg7h_nman82okg8hP?o^/KS00?o^/KTokO5iOngaND00_ngaND0
1Ond`nGo]<?VokC3i_nd`nKo000002[ooooo00?o0000ooooooooool02Oooool3ojNlj0CoY[_X0_nU
^^P00onT^^WoXkWYoj>ij@02oj>ij@;oXKSY0_nP]nT2oiffj@CoVk?Y0onH/NT00onD[^SoTJgYoi6]
j@03ohfYj0?oRJGW0on5X>D2oh:Kh`?oOYOQ0_mlT]h3ogZ>f`?oNX_H0_mkR=D3ogb6dP?oQ8W@0on7
R<d3ohZ8b`?oSXS90_nBRLL2oi27aP04oiB9a?l0003o0000o`0000;oVH_31?nNSL84oj:?`@;oYY;0
00?oYi:ooj^E_on[UKl00_n[UKl3ojnH_`03ok6I__ndW;ko]9bn00;o]9bn0onhWkl2okZQ_`Co_JBo
1Oo3ZL001Oo5[<7ob:o2olR_`_l0003obK;300CocKG31Oo@_<H3om?2b0;oelK:2Oooool00ol0003o
ooooooooo`0Looooo`003_ooool00ol0003oooooooooo`04ooooo`CoR:?V0_n6X>@3ohBMh`?oPi[Q
0_n3Umh3ohBEg0?oQI?J0_n8T]L3oh^Be@?oSY;C0onBTm43oiJDc`;oVYG=00?oVI?<oifEbonMUL/0
0_nMUL/3oj:Gb@CoYYW800CoZI_8ojZKaonZVlOoZY_71?n^WLH01?naWlKo/Yo5ok:OaOnbWlD4okFR
a@04okRUaOniYLCo^JG4okVUa0;o_:O50_nmZ<@4okn[a@?o00000_o3[/D5olJbaPCob;G71Oo:^LT0
1?o<^lWoc;c;olblboo<_</2oljnb`;oc;o>0oo>`Lh01Oo<`]3oc/CAolk4dOo>a=7oclGA00?oc<KD
00CocLODol[7eoo:amOob/OG0_o;bMP01_o8b=[ob<WKolS9foo8bM_o0000olG8g@?oaLWM00Go`LSO
ol79h?o1bN3o`LWPokg7hP04okg8hP04ok[6honja^Co^/KTok[6i0;o]lGU0_nfaND2okC3iP03ok?4
i_oooooo000002Wooooo00?o0000ooooooooool02_ooool3ojNlj0;oY[_X0_nU^nT3ojBjj@;oXkWY
0_nR^NT4oj2gj@;oWKKY0_nK/nT2oiVbj@;oUK3Y1?nA[NT3ohfYj0?oRJGW0_n5X>D3oh:Kh`?oOYOQ
0_mlT]h3ogZ>f`?oNX_H0_mkR=D2ogb6dP?oOhG?0on3QLd3ohN5b`?oRhK80_n@QlH3o`0000;oU8W4
1?nIRl<3oij=`P?oXXo100?oXho0ojNB_onWT[l00_nWT[l4oj^E_`04ojnH_onaVKko/IVnok6I_PCo
]9bn00Co^9nookZQ_onjXKoo^Z6o0onmY;l2ol2V_`Co`jW00oo8[l800ol0003ocKG3olfe``03olfe
``04om2ja?o@_<Kod;c6om2laP;oe<3700Godl;8omO6b_oGa/[oelK:om[<b`09ooooo`03o`000?oo
oooooooo01_ooooo000>ooooo`03o`000?oooooooooo00Gooooo1?n8XnH2ohJPi0?oQ9gS0_n3V^43
oh>GgP?oQ9GL0_n5TmX3ohRBe`?oRi;E0on>T]<00onBTm7oT93@oiBBcP02oiBBcPCoVI?<0onMUL/4
oj:Gb@;oYYW800?oYYS7ojZKaonZVlL00_nZVlL3ojjMaP03ojnMaOnbWlGo/Yo500;o/Yo50oneX/D0
0ongXlCo^JG4okVUa002okVUa005okbWaOnmZ<Co_JS4okfXa?noZlD00ol000001?o1[<Co`jk5ol>^
aOo3[/D2olF_a@?oa[;60_o8/lH2olRea`;obkO70oo:^LT3olbkb@05olblboo>_/_oc[k;oljnboo<
_lh01?o>`Lh3olk4d@?oclGA00Goc<KDolg7e?o=amCocLODol[7e`03ol_9f006olc:f?o8bM_ob<WK
olS9foo8bm_o00000_o5bMd2olG:gP;o`LWP0oo1bN42okg8hP05okg8honja^Co^/KTok[6i?nian@0
0onfaND00onfaNKo/lCVok?4iP02ok?4iP03ooooool0003ooooo02Oooooo00?o0000ooooooooool0
2oooool00onW_>SoY[_XojJkj004ojFkj@03ojBjjOnS^^WoXk[Y00CoX[WY0_nP]nT01?nN]nWoW;GY
oibejOnL]NT4oiVbj@;oUK3Y0_nA[NT00on>ZnWoRJOXohVWj002ohVWj0;oQ:;W0_n0WND3og^Hh`?o
N9?Q0omeSmh2ogZ>f`?oNX_H0_mkR=D3ogb6dP?oOhG?0on3QLd3ohN5b`04oh^6b?l0003o0000o`00
00?oT8O60onDRL@3oiV;``CoWXg200CoXXo1oj>?`?nSSl3oXho00onWT[l3oj^E_`03ojfF_onaVKko
/IVn00;o/IVn0ondW;h00ongW[oo^Z6ookZQ_`03okZQ_`04okfT_oo0Y[oo`:Jool2V_`?o`jW00_o6
[L42olR_`P03ol^c`_l0003ocKG300;ocKG30oo@^/@01?o@_<Koe<37omC0aooD`<L3omO6bP?of/c;
2Oooool00ol0003oooooooooo`0Jooooo`003_ooool00ol0003oooooooooo`06ooooo`;oR:?V00?o
Q:7Voh6Mi?n1WN@00omoVN82ogjFh0?oOY?N0omoTM/2oh6@f@?oQ8oG0on7Sm@3ohb@dP?oT93@0onD
T/h3oiVCc0CoWIG;0_nRUlT00onRU/WoYYS7ojJHa`02ojJHa`CoZY_700?o[Yg6ojnMaOn_WLD01Onb
WlD01?neX/Go]j?4okNSa?ngXl@2okVUa003ok^Va?nmZ<Co_JS400?o000000?o_j_5ol6/a?o1[<@0
0_o1[<@00oo3[/GoaJo5olF_a@02olF_a@05olJba_o8/lKob;?6olRca_o8]LL01?o;]lL00oo:^LWo
c;_9olbkb@02olbkb@Coc[k;00Cocl3;olk1c_o>`Lkoc/7>0_o@`lh00oo>a=7oclGAolo5d@02olo5
d@?ocLOD00Coc/WEol_9f?o;bMSoblWH0oo<b]P01Oo8bM_ob<_KolS;foo8bm_o000000;oaL[N0_o5
bml3ol79h@03ol7:h_nmb>?o_LSS00;o_LSS00Go^/KTokW7i?nianCo^LOTokK5i@03okK5iP?o/lCV
00?oooooo`000?ooool09oooool00ol0003oooooooooo`0=ooooo`;oY[_X1?nU^nT3oj>jj@;oX[WY
0_nQ^>T3oijgj@?oW;GY0_nI/^T2oiJbjP;oTZoZ0on>ZnT4ohVWj0;oQ:;W0_n0WND3og^Hh`?oN9?Q
0_meSmh2og>;f`?oLhOH0omdQ=D3ogb6dP;oOhG?0on3QLd01?n7QL_o0000o`000?l00002oh^6b0Co
T8O60onDRL@3oiV;``;oWXg20_nNSL44oj>?`0CoYi:o00CoZiFoojfF_on]U[oo[IJo1?naVKh01?nd
W;ko]ijookNN_ongW[l4okZQ_`Go`:Jo00Go`jW0olJ]`Oo6[L7oaZg1olR_`P03ol^c`P03o`000?o=
]L?od;[400?od;[41?oD`<L00ooHaLSoelK:om[<b`03om[<b`Wooooo00?o0000ooooooooool06_oo
ool000kooooo00?o0000ooooooooool01oooool3ohBQiP;oPIgT0omoVN82ogjFh0?oOY?N0omoTM/2
oh6@f@?oQ8oG0on7Sm@3ohb@dP;oT93@0onDT/h4oiVCc0;oWIG;00?oWIC:oj:FbOnRU/T00_nRU/T3
ojJHa`?oZY_700?oZi[6ojnMaOn_WLD00_n_WLD3ok:Oa@03ok>Pa?ngXlCo]j?400;o]j?400?o^JG4
ok^Va?l000000_l00002okfXa003oknYa?o1[<Co`Jc400?o`Jc41Oo5[lD4olRcaPGobkO700CocKW7
olbkbOo<^lWoc;_90_o>_LT2oljnb`?ocl3;00Goc/7>om33c_o@`lkod<?>om75c`03olo5d@;od<OB
00GocLODolk9eOo>bMGoc/WEol_9f003olc:f007olc<fOo8bm_ob<_KolS;foo9c=co0000olG:gP04
olG;g`04ol79hOo1b^;o`L[Rol7:hP;o_LSS0_nlb><2okW7i0;o^LOU0onfaNH4ok?4iP03ooooool0
003ooooo02Kooooo00?o0000ooooooooool03Oooool4ojJkj@?oYK_Y0onS^^T4oj6hj@03oijgjOnM
]^[oWKKZ00?oV[CZ1?nF/^X2oi:_jP?oSZ_Y0_n9YnP00on5YNWoOj3XognPj003ogZKiP?oNiSS0omh
Tn42ogF?gP;oLh_K0omcQmP2ogB4e@?oMh?B0omjP/l3o`0000?oQhG;0on;Q/P3oi27aP;oU8W400Co
ThS4oiV:`onIR/?oVH[31?nNSL44oj>?`0?oYi:o00?oZ9>oojfF_on]U[l00_n]U[l4ok6I_PCo]ijo
0onjXKl00onmXkoo`:Jool2V_`02ol2V_`03ol>Z`?o6[L7oaZg100;oaZg11?o;/l800ol0003od;[4
om2ja002om2ja0;oe;o50_oD`<L2omS5b004om_;b_oJc<_of/c;om[<b`;ogM7=2Oooool00ol0003o
ooooooooo`0Iooooo`003Oooool00ol0003oooooooooo`09ooooo`?oQ:7V0_n1WN@3ognIhP;oOYKP
0omnTmh3ognAf`04oh6@fOn4SmOoQ8oGohB?e`?oQhoD0on<T=83oi2@d0?oU9;>0_nITl`00onHT/co
WIC:oifDbP02oifDbP?oXYK91?nVV<L00onZVlOoZi[6oj^JaP04ojnMa@04ok:OaOncX<Co/j34ok>P
a0?o]j?40ol00003ok^Va004okfXa?noZLCo_jW4oknYa0?o`Jc40_o3[L@3olF_a@;oak750_o8/lH2
olZeaP?obkO70oo=^LL01Oo<^lWoc[g9oljmbOo>_LWoc[k;00Cocl3;0oo@`lh3om75c`05olo5dOo@
am;od<OBom37d_oAbM800oo>bMD2olo;eP05olc:f?o<c=Woc<cIolc<fOo8bm/00oo9c=`01Ol0003o
aL_OolG;goo5bmooa<cP00?o`L[R00Go`<_Rokc8honlb>?o_<SSokc9i003okW7i@03okS7iOnfaNKo
]/GV00;o]/GV0_nca>H2ok?4i`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool2
ojJkj@;oYK_Y1?nT^^T2oj>jj@;oXKSY0_nO^>X3oiffjP?oV[CZ0_nF/^X01?nD/N_oSjg[ohn]jon?
[N/3ohZYjP?oQJGY0_moX>P3ogZKiP?oMIGT0_maT>42ofj;gP?oLh_K0_mcQmP3ogB4e@;oMh?B0ol0
0003ogj2c@?oPh?:0on8Q<P3ohj6aPCoThS40onIR/<4oij=`@CoXho000?oYi:oojRC_onXTkl01?n]
U[l3ok6I_P03ok>K_ongW[oo]ijo00?o]ijo00Co^Z6ookfS_onmXkoo_J>o0_o0Y[l2ol>Z`0CoaZg1
00KobK72ol^c`_o;/l;obk?2olnh`ol00002om2ja0?oe;o500Coe<37omS5b?oHaLSof<G80_oKblX0
1?oJc<_ogM7=omgAcOoMdLd9ooooo`03o`000?oooooooooo01Wooooo000=ooooo`03o`000?oooooo
oooo00[ooooo0_moW^H2ogbJi0?oNYKR0_miTn03ogV@g@?oNXkK0_mlSMP3ohB?e`?oQhoD00?oS93B
ohV=dOn>S/l00_n>S/l3oi>@c@CoV9;<0onMU<X4oj:Fb@?oYYS71?n[V/H2ojnMa@03ok2MaOncX<Co
/j3400?o/j340_l00002okRSa0Co^jK41OnoZL@00oo1[<Co`jg4ol>]a002ol>]a005olF_aOo7/LGo
ak75olNaaOo8/lH01?o:]LH00oo;]lOocKW7olfia`02olfia`Coc[g900Cod;o9olo0boo?`<_ocl3;
0_oA`/`00oo@`lkodLG?om75c`02om75c`?od<OB0ooAbM801?o>bMGocl_Folo;e_o?bmH3olc<f@04
olc=f_o9c=cobLcLolW<g0;ob<gM00?o0000olG;goo4c>000_o4c>001Oo1b^;o`<_Rol3;h_o0bn;o
_<SS00?o_<WT00Co^LOUokS7iOnhanGo^<OU0_nfaNH2okG5iP?o/lCW00?o//?Wo`000?ooool09?oo
ool00ol0003oooooooooo`0@ooooo`CoYK_Y0_nT^^T00onS^^WoX[WYoj:ij@02oj:ij@?oWkSZ00?o
WKKZoi^fjonK]^/00onH/n/3oiBaj`?oSjg[0on:ZNX2ohFUj@?oOj3X0omjVnH3ogFEi0;oLI3Q00Co
KX_Nofb6fom/Q]_oK8KK0om/PmP2ogB4e@;o000000CoMh?BogZ2comjP/ooNX;?0omnP/d3oh>3bP?o
R8C80on>Q/H3oi>8a0?oVH[31?nNSL42oj>?`0;oXi311?nXTkl4ojfF_`04ok6I__ncVkoo/i^ook>K
_`?o]ijo00?o^Z6ookfS_onmXkl00_nmXkl00oo0Y[oo`j[0ol>Z`002ol>Z`0;oaZg10oo9/L801Oo;
/l;ockS3olnh`oo?^<?o000000Coe;o50ooHaLP3om_;bP?ogM7=0_oOell9ooooo`03o`000?oooooo
oooo01Sooooo000=ooooo`03o`000?oooooooooo00_ooooo0_moW^H2ogbJi0?oNYKR0_miTn03ogV@
g@;oNXkK0_mlSMP3oh2<eP?oQ8cC0on9SM43ohj>c`?oTi3=0onHT/`4oifDbP;oXYK900?oXYK8ojJH
aonVV<L00_nVV<L3oj^JaP05ojnMaOn`WLGo/9g5ok2MaOncX<@00ol000001?ngXlCo^:?4okRSa?nh
Xl@3ok^Va0;o_JO31?noZL@5ol>]a0Coak751Oo:]LH5olfia`03olnkaoo>_LWoc[g900?od;o900Go
cl3;om72c?oA`/codL;<om?5c003om75c`;od/O?00?od<OBom79d_oAbM800_oAbM83olo;eP;od<gG
00Goc<cIolc=f_o<cM[oc<gJolW<g003olS=g@05olS>g_l0003oa<cPolC<h?o4cN400oo0bn82oko;
h`;o_<WT00Co^lWUokS7iOnhanGo^<OU0_nhanH4okG5iP05ok?4ionb`nOo//?Wok;3iol000009?oo
ool00ol0003oooooooooo`0Aooooo`CoYK_Y0onS^^T2oj:ij@;oXKWZ0_nN^>X4oi^fj`?oV;?[00?o
U;7[oi6`jonA/>/00on<[>/2ohJXj`?oP:?Z0omjW^T2og>Hi`?oKI;U0_mXS>82ofj;gP?oK8KK00Go
K8?Ho`000?l0003o0000off1e@03og1odP;oNX;?0omnP/d3oh>3bP?oR8C80on>Q/H3oi>8a0CoVH[3
0_nNSL400onNSL;oXi31oj>@`@02oj>@`@CoZ9>o0on]U[l00on^V;oo/i^ook>K_`02ok>K_`;o]ijo
0_njXKl4okfS_`Go`j[000?oaZg1olVa`_o9/L800_o9/L84olnh``04om>maOl0003oe;o5omBoa@;o
f<G700?of<G8om_;b_oKblX00_oKblX00ooNdLcogM7=omoGc`02omoGc`;ohMgA2?ooool00ol0003o
ooooooooo`0Gooooo`003Oooool00ol0003oooooooooo`0;ooooo`;oNI_V0omfU^@3ogZFhP;oNI?P
0omiT=d2ogZ>f`;oO8gH0on0S=H3ohB<d`;oRHgA0on>S/l4oi>@c@?oV9;<0_nMU<X01?nLTlWoXYK8
oj:Fb?nRU/P4ojJHa`;oZi[600?o[9_5ok2MaOn`WLD00ol00002ok>Pa003okFQa?nhXlCo^:?400?o
^:?400Co^jK4okfW`onmYl?o_JO30onoZL@2ol6[``?o`jg40_o5[l@2olNaa@;obK?40oo:]LH2olbg
aP?ocKW70_o?^lL00oo>_LWod;o9om2ob@02om2ob@?odL;<0ooCaL`01OoAaLood/O?om;7cooBaloo
e<[@00?odLWB0_oBc=<01Oo?bmKod<gGom3=eoo@cMOod<oH00?oc<gJ0_o=cm/01Oo8cMgob<kNolS>
g_l0003oa<cP00?oa<gQ00?o`<_Roko;honobn<00_nobn@3ok_9i@03okS7iOnhanKo^<OV00;o^<OV
0_neaNH2okC5i`?o//?W00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Booooo`CoYK_Y
0onS^^T4oj6ijP;oW[SZ0_nK]^/2oiZej`;oU[?[1?nA/>/3ohb/j`;oQZS[0on0XnX3ogZNj@;oLiSW
0om]T^D01?mXS>;oIHOOofF7gomUQml3o`0000;oK8?H0om]PMD2og1odP?oM7o@0omnP/d3oh>3bP?o
R8C80on>Q/H3oi>8a0;oVH[300?oV8[3oij=`_nNSL800_nNSL84oj>@`@?oZ9>o00Co[IJoojjH_on^
V;oo[YRo1?ncVkl00ongW[oo^Z6ookZQ_`02okZQ_`;o_J>o0_o0Yl04ol>Z`0GobK7200?ocKK3olnh
`oo?^<<00_oC_LD00ol0003oe;o5omS5a`02omS5a`04om_;bOoKbl[ofl_:om_;bP;og]7<0ooOell3
on7Md@03on;Sdooooooooooo00Gooooo00?o0000ooooooooool05oooool000gooooo00?o0000oooo
ooooool03?ooool2ogVKiP?oMYKT0_mdT^82og:?h0?oLhcM0_mdRm/3ogb=f0?oP8cF0_n4S=<3ohV=
d@?oSXk?0_nCT<d01?nAS/goUi7;oiNAbonGTL/3oibCb@CoXYK80_nVV<L00onWV<Ko[9_5ojbKa@03
o`0000?o/9g500Co/j34okFQa?neXLCo]J740onhXl@00onjY<?o_JO3okfW``03okfW``03oknYa?o1
Zl?o`J_300;o`J_300Go`jg4olF_a?o5[lCoaJo4olNaa@04olVca003olZea_o<]lKoc;O600;oc;O6
00GocKW7olnkaoo?^lOock_7om6ma`03om2ob@;od/7:00?odL;<om?5c?oCaL`00_oCaL`3om;7c`?o
e<[@00CodLWBom;<dooBc=?od/cC0oo@cML3om3?f004olc=f_o=cm_ocLoKolc@g0?ob<kN00Cob<oO
o`000?o4cN7oa<gQ0_o3cN800onobn?o_l_Toko;i002oko;i0Co^lWU0_nhanH2okO7iP?o]<GW1?nb
`nL00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo0_nU^nT2ojBkj@?oXk[Y0_nQ
^NX2oj2ijP;oWKO[1?nJ]N/2oiJcj`;oTK3[0_n?[n`3ohV/k0;oPZO/0omkX^/2og>LjP;oK9GX0om]
T^D01OmXS>;o0000o`000?l0003oIHOO00;oHh?L0omSOmT2off1e@;oL7oB0omdOm03ogUoc@?oOh7;
0on5P/P3oh^5aP?oTXO51?nHR/<3oij=`PCoXi310_nXTkl00onYU<3o[YRoojjH_`03ojjH_`;o/i^o
00?o]Ig0okZQ_onjXKl00onjXKl01?nmXkoo`:O0ol2W`?o0Yl03ol>Z`0;oajk10oo9/L82olff``03
olnh`ooC_LGodkg500;odkg500Co0000omS5aooHaLOof<G70_oKblT01_oKbl[og]7<omkAc?oNdLco
hMS>omoGc`?ohMgA0_oRhm<00ooRj=Koooooooooo`05ooooo`03o`000?oooooooooo01Kooooo000=
ooooo`03o`000?oooooooooo00gooooo0_miVnH3ogJFi0;oM9;R0_mbSn03og><g@04ogB;fomhRMSo
N8WHogR9f0?oO8WF0_n0R]<3ohJ;d@?oS8g?1?nAS/d3oiNAb`?oW9?90onRU/P00onVV<OoYiS6o`00
0002o`0000;o[9_50on`WLD00onaW/Co]J74okFQa003okFQa004okRSa?njY<?o^ZC3okZT``Co_JO3
1Oo1Zl<4olF_a0GobK?41Oo<]lH3olnka`?odKg700God;o9om;1b_oB`L[od/7:omC4bP03om?5c0;o
e<O=00?od/O?omC:d?oDb]000_oDb]03om;<d`;odlkD00Cod<gGom3?f?o@cmSod<oH0_o@d=T01Oo=
cm_oc=3Lolc@g?o<d=cob<kN00;ob<oO00?oam3Qo`000?o3cN800_o3cN801Oo3c^?o_l_Toko;i?no
bnCo_/_U00?o^lWU00Go^/WVokO7i_nganKo]lOVokK7i`04okC5i`;o//?W0_na`nL00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01Cooooo1?nT^nT00onS^^WoX[[Zoj:jjP04oj2ijP;oWKO[
0_nJ]N/2oiRek0?oU;;/0on?[n`3ohV/k0;oPZO/0omkX^/2og>LjP;oK9GX0ol00002of29h`?oIHOO
0_mSPm`2of=of@?oIGgF0_m`Om83ogAod0;oNGo=0omoPL/4ohF2b0?oRhG60onBQlD3oiR:``?oWXg2
0onST<400onTTL7oZIC0ojVD`002ojVD`0Co[YRo00Co/i^ookFM`?neWL3o]Ig01?njXKl5ol2W`003
ol>Z`?o7[/7oajk100;oajk100CobK72olff`oo=]/?ocKK31OoC_LD00ooG`lOo0000omS5a`03om_;
b@?og]7<0_oQf<h2on?Nd005on7MdOoRhm?oh^?Con;SdooRj=H02?ooool00ol0003oooooooooo`0E
ooooo`003?ooool00ol0003oooooooooo`0?ooooo`;oLiSW0_m_Tn@2off?hP?oLXoP0omcS=d01?md
Rm_oN8WHogR9f?mhRMP3ogb9eP;oP8[C0on6Rm43ohb=c`?oTHk=0onGTL/3oibCb@;oXYK80ol00002
ojNHaPCo[9_500Co/9g5ok6Na?naW/Co/Ik41?neXL@4okZT``?o_JO30_noZ<<3ol6[``;oa:g30_o5
[l@2olRaa0?obK?40_o;]LD3olbgaP;oc[[600?ock_7om6maooA_LL00_oA_LL3om;1bP?oe<C:00Go
dlG<omC7cOoDalgoe<O=omK:cP03omC:d0;oeLcA00?od/cCom?>e?oCc]@00ooCd=H01?o@cmSod=3I
om3@fOo@d=T3olc@g0;oc=7N00Kob<oOolO@hOo7d>7oam3Qo`000?o3cN83ol?>h`05oko;i?nnbnGo
_/_Uokk;iOnkbND00onjbNH01?nganKo]/OWokK7ionfanL2okC5i`06ok?5iona`nOo/L?Wok73ion`
`nSo00008Oooool00ol0003oooooooooo`0Fooooo`?oY;_Y1?nR^^X2oj2ijP03oinijonL]n_oW;O[
00;oW;O[0onH]N`00onD/^coT[;]oi:bk@03ohb_k@;oQJ_]0omnY^d3ogJPk0?o000000?oI9?YofF?
iOmUSnD00omPRN<2oe^3g`?oFGkM0_mSOmT2ofEmeP;oJ7cC0omdOm03ogUoc@?oOh7;0on5P/P3oh^5
aP?oTXO50onHR/<4oij=`P04oj>@`OnTTL7oY971ojBA`@?oZIC00on^V;l00on`V/7o]Ig0okFM`002
okFM`0?o^Z6o0_nlY<04ol2W`0Goajk11?o=]/<01?oA^lGodkg5om>maOoC_LD2omO3a`03omS5aol0
003ofl_900;ofl_900Cogm;;omkAc?oQf<kohMS>0ooSg]03on;Sd`;oh^SF00?ohNcHooooooooool0
1Oooool00ol0003oooooooooo`0Eooooo`003?ooool00ol0003oooooooooo`0@ooooo`;oLiSW0_m_
Tn@2off?hP;oK8_O0om/R=d2ofn7fP?oN8WH0_mlRMH2oh2:d`?oQX_A0on<SLl4oi6>c@?oUi7;00Co
W9?9o`000?l0003o00000_nRULP4ojNHaP;o[9_500?o[I_5ok6Na?naW/@00_naW/@3okFQa0;o]Z;4
1?njY<<00onmYl?o_jS3oknX``02oknX``05ol6[`oo4[L?oa:g3olB]`oo5[l@01?o8/L@00oo9/lCo
bkG5ol^ea@02ol^ea@04olbga_o>^/Koc[[6oljjaPGodKg700?odl38om;1b_oDa<X00ooDa<X3omC7
c@?oe/[>00Koe<[@omG<dOoEc=7oeLcAomK?d_oCc]@4om?@eP?od=3I0_o@d]X01Oo<d=coc=7NolcA
g_o<dMkobm;O00?oam3Q00Co0000olK@h_o3c^?o`lkS0_o2c^@2okk;i@;o_L_U0_njbNH2okW9iP;o
]/OW00?o]LKWok?5ioncaNL00_ncaNL01Ona`nOo/<?Xok33j?n``nSo0000023ooooo00?o0000oooo
ooooool06?ooool2ojBkj@;oX[[Z0_nQ^^X3oinij`;oW;O[0_nK]n`2oiNek0CoT[;]0on<[nd2ohF[
k@;oOZK]0ol000000omfX>coKI[[ofBCj@02ofBCj@;oG8cV0omPRN<2oe^3g`;oFGkM0_mINmX3ofEm
eP04ofQldom]O=7oKGcAofeld@?oLgg>0omoPL/3ohF2b0?oRhG61?nBQlD3oiR:``;oWXg200?oWXk3
ojBA`OnTTL400_nTTL44ojVD`004ojjH_on`V/7o/9[1ok2J`@Co]Ig000Co^Z6ookbT`?nlY<3o_:C0
0oo0Yl02olB/`P?oajk10_o;/l<2olff``?odK_500Kodkg5omO3aooG`lOoel?7om_:bOl00002om_;
b@;ogm;;00?oh]W=on7Hc_oSg]000ooSg]001OoTiM;oh^?Con;Xe_oRj=KohNcH00;ogo3K00?ogO?M
ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`003?ooool00ol0003oooooooooo`0@oooo
o`;oK9CW0omXSn@2off?hP;oK8_O0om/R=d01?m_Qm[oLXKHog:6f?mbQ]P2ogN6eP?oO8OC0on6Rm43
ohb=c`;oTHk=00?oT8g=oiJ@bol000000_l00002oibBb@?oXYG81?nWV<H4ojfKa@Co/Ik400Co]J74
okJRa?nfX/Co]Z;40onjY<<00onlY/?o_jS3oknX``02oknX``03ol6Z`oo4[L?oa:g300;oa:g31Oo8
/L@5ol^ea@?oc[[60_oA_<H3om6ma`;odl381OoDa<X00ooFal_oe<O=omK:cP03omK:cP?oeLcA0_oF
cm801?oGdM?odm3Fom?@e_oCd=H2omCBe`03om3@fOo@d][od=;J00?od=?L00Goc=7Nol_Bgoo;d]oo
bm;OolO@h@02olK@hP05o`000?o2c^Co`/kTol;>i?o1c^D00onmbnD01OnlbnKo^LWVokW9i_nibNKo
^<SW00Co]LKW0_ncaNL2ok;4i`?o/<?X00?oooooo`000?ooool07_ooool00ol0003oooooooooo`0I
ooooo`?oXk_Z0onQ^^X00onO^N_oW[W[oijij`04oi^gk0;oUkG/0_nB/^d2oi2bkP;oRJk^00CoPZ[^
o`000?l0003o00000_mjYNh2og2Ok@;oIYS/0omTTnT2oeb<iP;oEXGS0_mAOn03oeUng@04oeUkf_mL
NMOoG7WGoeaie`;oJ7cC0om]O=42og=mcP?oNWo<0on2PLX01?n5P/SoRhG6oh^5a_n;QLH2oi:7a@04
oi27a_nGRlCoUh_4oiN;a0CoWXk30onTTL43ojVD`003oj^G`_n`V/7o/9[100;o/9[10oneWL000onh
XL7o_:C0okbT`003okbT`003ol2W`?o4[<;oa:c200;oa:c200Goajk1ol^c`oo;/l?obk?3olff``04
om6ka@?oel?70ooKb/T01_l0003ogm;;omoBbooOd/_oh]W=onCQc`?ohmk@0_oTiM800ooTjmCoh^SF
on7/f002omo`f`;ogO?M00?ofOGPooooooooool01?ooool00ol0003oooooooooo`0Cooooo`003?oo
ool00ol0003oooooooooo`0Aooooo`;oK9CW0omXSn@01?mURn;oI8OOofB7gomTQml2ofb8g@;oKhOJ
0ombQ]P2ogN6eP;oO8OC0on3RM43ohV;c`;oT8g=0_l00002oiJ@b`?oW9;91?nRULP4ojNHaP?o[I_5
0onaW/@00onbWlCo]Z;4okJRa003okJRa004okZT`onlY/?o_:K3okbV``;o_jS30oo1Z/<2olB]``;o
aZo31?o8/L@01?o:/lCobkG5ol^eaOo;]LD2oljha@03oljja_oA_<KodKc600;odKc600GodKg7om?0
b?oC`<Sodl38omG3b@03omC4bP;oe/O;00Cof<[<omK:c_oFb/koe/[>0_oGcLl01?oEc=7oe/oBomK?
d_oFcm82omOAd`03om?@e_oDd]Ooe=;G00;oe=CH00?od=;Jom3Cg?o@dm`00_o@dm`3ol_Bg`;obm?P
00Goa]3RolG@hoo5d>?o0000ol;>i003ol7>i@05okg;iOnlbnKo_<_Vokc;i_nibNH00onhb>L2okG6
i`;o]<KW0_nba>L00onaa>So/<?Xok33j002ok33j003o`000?oooooooooo01gooooo00?o0000oooo
ooooool06_ooool3oj>kjPCoXK[[0_nN^N/2oi^gk0;oV[O/0_nE]Nd4oi2bkP;o00000on2Z^h3ogZU
kP;oL9o]0_mVV>`2oeb@jP?oDhSW0_mFQN<01?mAOn3oCW[ModijgOm>N]d2oeUkfP;oG7WG0omPNM@2
ofeld@?oLgg>0omjOl`3oh:1bP?oRHC80on@QlH4oiN;a0?oWXk31?nTTL401?nYU<3oZiO2oj^G`_n[
Ul84ok2J`@04okFM`?nhXL7o^:71okRQ`@Co_:C01Oo4[<84ol^c``GodK_500?oe/;7omO3aooKb/T0
0ooKb/T00ooOd/_o0000omoBb`02on;Ic@;oi>7?00?ohmk@onCUd_oTiM800_oTjm@00ooSl=OohOCI
omo`f`02omgcg@;ofOGP00?oe_KSooooooooool00oooool00ol0003oooooooooo`0Cooooo`003?oo
ool00ol0003oooooooooo`0Booooo`;oK9CW0omXSn@00omURn;oI8OOofB7g`02ofF5g@?oJ8?J0omb
Q]P01?mgQ]KoO8OCogb7domlQm<3oh>9d@04ohV;col0003o0000o`0000;oT8g=0onFT</3oibBb@?o
XYG81?nWV<H4ojfKa@04ok6Na?nbWlCo/Yo4ok:Oa0?o]Z;400?o^:?4okbV`onlY/<00_nlY/<00ono
Z<?o`J[3ol6Z``02ol6Z``04olB]`oo6[l?oaZo3olJ_``?ob;740oo:/l@01?o;]LGoc[S5oljhaOo>
^<D5om6laP?odl380ooE`lT01?oDa<[oe/O;omK7booFal/2omS:c004omK:c_oGcLooelg?omO=c`;o
f<o@00Koe/oBomOAdooGdM?oem7ComOCeOoDd]L3omCDf004omCFf_o@dmcod=?Lom3Cg0;ocmCM00Co
bm;Ool_Ch?o;dn3obM?R0oo5d><01?o4dNCo0000ol7>iOo1c^D2oko>i@;o_<_V0_nkbnH2okS8i`05
okO8ionda^Oo]<KWokC6ionca^P01?naa>P2ok33j0;o[l;X00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Kooooo`?oXk_Z0_nQ^^/00onP^^_oWKS/oifhk002oifhk0?oV[O/0_nE]Nd3o`00
00?oQjk_0omoZ^l2ogFTk`?oJik^0_mOU^d2oeb@jP;oDhSW0_m;PN@2oe5oh0;oCW[M0om>Mm/2oeai
e`;oH7WD0omVNM82og=mcP?oNWo<0on2PLX3ohV4b0CoT8O60onGRl@4oij>``;oY97100?oYI?3oj^G
`_n[Ul800_n[Ul83ok2J`@03ok>N`_nhXL7o^:7100;o^:710onlY<02ol2Y`P?oa:c20_o8/L<2ol^c
``;ock[50ooA^lD2omK2a`Gofl[90_oOd//00ol0003oh]W=onCQc`02onCQc`04onKWd_oTiM;oi>_D
onC[e0;oho3G00?ohOCIomkgfooMlmd00ooImN000ooFm^?odOGVom7eiP04ooooo`03o`000?oooooo
oooo01;ooooo000<ooooo`03o`000?oooooooooo01;ooooo0omUTNL2of2;i0;oGHOR0_mTQml2ofF5
g@;oJ8?J0om/PmP2og:3eP?oO8OC0ol00003ohV;c`;oT8g=0onFT</3oibBb@CoXYG81?nWV<H2ojfK
a@03ojjLaOnbWlCo/Yo400?o/Yo400?o]Z;4okRSa?nhXl@01?nlY/<5ol6Z``GoaZo300?ob;74olZc
a?o:/l@00_o:/l@4oljha@04om2kaOoA_<KodKc6om6laP;odko700?odl38omG3bOoE`lT00_oE`lT3
omK7b`?of<[<0ooGcLl3omS?d0?oem7C0_oGdmD01?oGe]Koe=CHomCDf?oDe=P2omCFfP03om3Cg?o?
e=gocmCM00;oc]KO00Gobm?PolWCh_o9dn;obM?RolG@h`02olCAi005o`000?noc^Go_lkUoko>iOnn
c^H00onkbnH00onjbnOo]lSWokO8i`02okO8i`04okC6ionca^So/lKXok?6j0Co/LCX0on_`^P00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?oXk_Zoj:kj_nR^nX00onP^^/2oifh
k0;oW;W/00CoVKO]o`000?l0003o00000_nD]Nh2ohjbkP?oQjk_0omoZ^l2ogFTk`?oJik^0_mOU^d2
oeB>j`;oDhSW0_m;PN@2odEkh@;oCW[M0_m>Mm/2oe5ef0?oH7WD0_mVNM83ofekd0;oNWo<1?n2PLX3
ohV4b0?oT8O61?nGRl@2oij>``03oij@a?nUTl?oYI?300;oYI?31?n[Ul801?n`V/7o/ik2ok>N`_nc
W/84okRQ`@03okbT`?o0ZL;o`:W200;o`:W200Goa:c2olRa`oo8/L?ob;73ol^c``04olnja@05om6k
aOoF`/Ooe/;7omK2aooJb/T00ooKb/T2omoBb`03on?JcOl0003oi>7?00;oi>7?0_oVim801OoVk]?o
i>_Don?`eooSl=OohOCI00;og_OK0_oJnMh01OoImN3oe_KSom7ei_oAmNKocOCY00;obO;]0_ooool0
0ol0003oooooooooo`0Booooo`003?ooool00ol0003oooooooooo`0Cooooo`?oII7W0_mPRn@01?mM
Qn;oG8?Ooeb3gomLPml2ofF5g@;oJ8?J0_m/PmP2og:3eP?o00000omoQm43ohN9c`;oSXc=0onESl/4
oibBb@?oXYG80onWV<H00onXVLKo[Yc5ojjLa@02ojjLa@?o/Yo400?o]:34okRSa?nhXl@00_nhXl@2
okbV``;o_ZS30oo1Z/<2ol>]``CoaZo300Cob;74olZca?o:/lCob[?40_o<]/@2oljha@?od;_500Go
dKc6om>oaooC_lOodko7omG2a`03omG3b@;oelK900Coe/O;omS:c?oHb/cof<[<0_oIcLd01?oGcLoo
f<o@omS?d?oHcm02omWBd@03omOAdooGdmGoem?E00?oemKF00?oe=CHomCFf_oDe]X00_oCem/01?o?
e=goc]KOolkFgoo=en03olWChP;ob=CS00Goa=7Tol?AiOo3dNGo0000oko>i@03okk>iP04ok_;i_nj
bnOo^/_Wok[;i`;o]lSW0_nfb>P2ok?6j0;o/lGX0_naa>P00on``nSo[l;Xojo2j002ojo2j003o`00
0?oooooooooo01_ooooo00?o0000ooooooooool07Oooool3oj:kjP04oj2jjonO^^_oWk[[oibik0?o
00000_nI]nd2oiBekP;oTkG^0_n=/^l3ohF^l0;oO:W`0omaY?03ofFMl0;oF9G^00?oE8k[odR5iom8
QNL00oloON@01?m5Nn7o@GKNod5fg_m1M]h2odigf`;oDGGH0_mPNM@3ofIidP;oKG_@0omeO/h3oh:1
bP?oRHC80on@QlH2oiN;a0;oUhc60onNT<@4ojFC``?oZiO200?o[I[4ok>N`_ncW/800_ncW/83okRQ
`@03ok^V`oo0ZL;o`:W200;o`:W200?oa:k5olRa`oo8/L<00_o8/L<5olnja@?oe/;70ooJb/T00ooK
b/Wogm;;omoBb`02on?Jc@03onGRd?l0003oi>7?00;oi^OB0_oVk]<00ooTm=Goho3Gon7df@03omkg
f`06om[ig_oEn^7oeO[Qom7ji?oAmNKocOCY0_o9l^d2olK_k`;ooooo00?o0000ooooooooool04Ooo
ool000_ooooo00?o0000ooooooooool05Oooool2oef=i`;oF8OT0_mMQn82oeb3g`;oGH7M0omQOmX3
o`000004og:3e_mhQM?oN8GCogR5d`;oOhOA0on7RLl3ohj<c@?oUHo;0onLT/T4oj:Eb004ojNHa_nX
VLKoZ9W6ojRIaPCo[Yc500?o/Yo4okBPa?ndX<@01?nhXl@00onlY/?o_ZS3okjX``02okjX``04ol6Z
`oo3[L?o`jg3ol>]``?oaZo30oo8/L@01Oo:/lCoc;K4olbfa?o<]/Coc[S500Cod;_50ooC_lL3omG2
a`04omG3bOoGa/WoelK9omO6b@;ofLW;00Cof<[<omW=cOoIcLgofLg=0_oJd<h01_oHcm3ofM;AomWB
dOoId]7of]GComOCe@CoemKF00CoemSHomCFf_oCem_odmOK0_oBfMd01Oo>e]oocMOPolgGh?o=en3o
bM?R00?ob=CS0_o7e>@01Oo3dNGo`M7Vo`000?o1dNKo_/kV00?o_<gW00Go^/_WokS:j?nhb^So^<[X
okK8j002okG7j0?o/lGX00Co//GXok33j?n``nSo/<?X0_n_`^P00on^`^Soooooo`00000Kooooo`03
o`000?oooooooooo01oooooo0onR^n/3o`0000?oW;W/1?nH]nd3oi>ekP;oSK;_0on5[_02ogbYl0?o
LJC`0omUWO000omHUNkoBhc[od^<j`02odR5i`;o?ggT0_lgM^42od5fgP?o@G;K00CoDGGHoeIee_mF
MMKoEWGF0_mVNM83ofekd0;oMGk>0omnPL`3ohJ4bP?oShS81?nGS<H4oij@a0CoYI?300?oZiO2ojfJ
a?n]V/@01OncW/801?nhXL7o^jK3ok^V`onkY/<2ol2Y`P;oa:k51?o8/L<01?o<^<Kock[5olnjaOo?
^/D2omC1a`03omK2aooJb/Wof/[900;of/[900?og];<omoBbooSf/d00_oSf/d2onGRd004o`000?oV
im;oi^kConK^d`;oi?CE00GohOSGomgkf?oMnmSog_OKom[igP02omGjh@05om7ji?o=nNOob?O[olSg
joo9l^d00_o6knl2ol;[l@;ooooo00?o0000ooooooooool04?ooool000_ooooo00?o0000oooooooo
ool05_ooool2oef=i`04oeR7i?mDP^;oE8;RoeB2hP;oG8?O00CoGH7Mo`000?l0003o00000_mUOmP3
og:3eP;oN8GC0omoQm43ohN9c`;oSXc=1?nESl/3oibBb@;oXYG800?oXYK8ojRIa_nXVLH00_nXVLH3
ojjLa@03ojnMa_ndX<Co]:3400;o]:340_nhXl@00onjYLCo_ZS3okjX``03okjX``Go`jg300?oaZo3
olRaa?o8/L@00_o8/L@4olbfa004olniaOo@^lGod;_5om2ka@;od[k600?odko7omG2aooE`/L00_oE
`/L3omO6b@?ofLW;0ooIcLd3om[@cP?ofM;A0_oJeM<01?oJemCoemKFomOFe_oGe]H2omOHf003omOJ
f_oCem_od]WM00;od]WM0oo=en03olcGhP04olSDhoo7e>CoamCTolGDi@?o`M7V00Go0000okc=ionl
cNOo_<gWok_=i`03okS:j003okO9j?neanSo]LOX00;o]LOX00Go/lGXok;5j?nbaNSo//GXok33j002
ojo3j0?o[/;X00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Oooooo`?o000000?oX[_[
oinjk?nO^^`00_nO^^`2oibik0;oV;O]0_nG]nh2oi:ek`CoRk;`0_n3[_43ogVZlP;oKJCb0_mPW?42
oe6Dk`;oBhc[0_lnPnP2ocmmi0;o=gKQ0_m1M]h2od5bf`;oA77I0_mFMMH3oeege0;oKG_@0omeO/h3
ogj1c0?oQXC:0on?R<P4oiN<aP?oWY340onUTl<00onVUlGo[I[4ojfJa002ojfJa0?o/ik200?o]Z;5
ok^V`onkY/<00_nkY/<00oo0ZL;oa:k5olB^a@02olB^a@;ob;730oo<^<H01Oo?^/Goe<77omC1aooD
`LOofLW;00?of/[90_oNd/`00ooRfloohm[=on?Jc@03onGRd003onKZd_l0003oi^kC00;oi?CE0_oQ
n=L01ooMnmSof?gJomSmf_oCoMgoeO[Qom7ji?o=nNL00_o8mn/2olGdkP03olK_koo2jo7o`^_a00;o
_^Ob00?oooooo`000?ooool04Oooool000_ooooo00?o0000ooooooooool05oooool2oeB9i`03oeR7
i?mDP^;oE8;R00?o00000_mMPMd2of5ofP04ofEof?m/PMKoK87Fofb1eP?oM8?D0_moQm43ohN9c`?o
SXc=0_nESl/01?nDSlcoW9?:oibCb_nLTlX4oj:Fb0CoZ9W600?o[Yc5ojnMa_n_WLH01?ndX<@01?nh
XlCo^ZG4okZUa?njYL@3okjX``;o`:[41?o3[L<5olRaa003ol^da?o<]/Coc;K400?ockW500God;_5
om:na_oB_/Kod[k6omG1a`03omG2a`;oelK800?oelK9omW9booIbL/00_oIbL/00ooKcLcofLg=om[@
cP03om[@cP04omcCd?oId]7of]GCom[Ed`?of]OD00?oemKFomOHf?oGf=P00_oGf]X3om;Ig@;odM[O
00CocMOPolcGh_o<en;oc=OR0_o;en<02Oo7e>CoaMCUolGDiOo5e>Go`M7Vol3@iol0003o`=3Wokc=
i`03ok_=i`04okS:j?ngbNSo]lWXokO9j0;o]LOX0_ndanP2ok;5j003ok74j?n_`nSo[l?X00;o[l?X
00Co[/;Xojk1j?n^`NSo00006_ooool00ol0003oooooooooo`0Looooo`?o00000_ooool3oj:kj`Co
Wk[/0_nK^Nd4oiNgkP;oT[G_0_n;/_001?n:/o7oPJoboh6_l_n1[o83ogNZl`;oJZCc0_mPW?42oe6D
k`;o@X[/0_lnPnP2oc9ji004ocMfhOlcLMko<g7Noc=agP;o@G;K0_m4LMT2oeIeeP;oGGOD0omUNM83
ogEncP;oOX7<0on6Q<X3ohn8b0CoUhc60onNT<@01?nUTl?oYYO5ojJGaOnVUlD4ojfJa004ok>N`_nf
X/Go]Z;5okJRa@Co^jK31Oo4[/D00oo8/L?oc;S6olbhaP02olbhaPCoe<770_oIbL/01?oJb/Wog];<
omkBc?oNd/`2on;Kc`03on?JcOoUh]3oiN;@00;oi^[B00?o0000onCge?oTm=D00_oQn=L01OoMnmSo
f?gJomSmf_oCoMgoc_gP00;obOcT00CoaO_XolSgjoo5m>koaOC^0_o2l?400oo2jo7o_^ObokkWlP02
ok_Rl`03ooooool0003ooooo013ooooo000;ooooo`03o`000?oooooooooo01Sooooo00CoE8WWo`00
0?l0003o00000_mDP^800omCO]ooE7cMoeAlg@02oeQkfP;oIGoH0om/PMH2ogB3e0;oO8GB0on4R=03
ohf<cPCoU8o<0onLTlX4oj:Fb0;oZ9W600?oZI[7ojnMa_n_WLH00_n_WLH2okBPa003okJRaOnjYLCo
^ZG400?o^ZG400Co_ZS3ol2Za?o0Z/Co`:[40oo3[L<2olJ_a0?ob;740_o;]<@00oo<]/CockW5olni
a@02olnia@Cod[k60_oE`LL01OoE`/OoelK8omO6b?oGa/SofLW900?ofLW;0_oKcL`01?oLd<gof]3>
om[@c_oJd<h2omcCd003omcFdOoJeM?of]OD00;of]OD0_oJf]H00ooGf=Soem[JomOJfP02omKKg004
om;IgOoAf]oodM[Oom7Jg`;od=[Q00Coc=ORol_Ghoo;en?obMOU0oo5e>D2ol?CiP;o`=3W00Co0000
okk@ionkcNOo^lgW0_njc>P2okO9j0;o]/WX0_ndanP00onca^So/LCXok74j002ok74j0;o[l?X0_n_
`^P01?n^`NSo[L7Xojg1j?l0000Iooooo`03o`000?oooooooooo01Wooooo0ol00006ooooo`03oj:k
jonQ^n_oXK_[00CoWk[/0_nK^Nd2oiNgkP03oiNhk_nA]O3oTKG`00;oTKG`0_n:/o43oh6_lP?oMj[c
0_mZY?<2oe^LlP;oBi?`0_m2R^`2oc9oi`03oc9ji?lXL^3o:7;P00;o<g7N0_lbK]`2odAaf@;oBG;H
0omMMm@2ofEidP?oKggA0omiPLl3ohJ4bP?oShS80_nGS<H01?nFS/WoWi;7oinBaonOT/L5ojJGa@;o
[I[400?o/9o6okJRaOnfX/D00onfX/D2ok^V``;o_jc61?o4[/D5olbhaP03om6obOoD`LOoe<7700?o
fLW;0ooNd/`3on;Kc`07onGTdOoUh]3oi^[BonKZd_oVlM?oi?ODo`000002omoke005om[neOoComKo
f?gJom?mgOo>oN000_o9o>@01?o5nnSo`_S]okodl?nom?02ol;`l@03okk/lonkioCo^nOd00;o^n;c
0_nhgO<2o`00013ooooo000;ooooo`03o`000?oooooooooo01Kooooo0ol000000om;QNOoCX?Todj3
i002odYnh@;oBG[O0_mDO=d01?mHNm[oGWcIoeilfOmNO=T2ofb1eP?oM8?D0_mlQM83ohB8d0?oSHc>
0onDSl`3oibCbP?oXYK800CoXiO9ojVJaonYV/OoZI[71?n_WLH01?ndX<Co]Z;5okJRaOnfX/D3okZU
a003okbWaOo0Z/Co`:[400?o`:[400?o`jg3olJ_a?o6[l@00_o6[l@01?o8/LCobkC4ol^da?o;]<@5
olnia@03om6la_oB_/Kod[k600?oeL7700CoelG8omO6b?oGa/SoelK80_oIbLT00ooIbL_oflg<om_=
c003omc@c@03om[@c_oLdm3og=?@00;og=KA0_oMfM<01_oJemCof][Fom[Je_oJf]Kof]cHomOJfP?o
e]_L0_oEgMd00ooAf]ood=[Qom3Jh@02olkKhP05ol_Ghoo9enGobMOUolWGiOo5e>D00_o3dnH2ol;C
i`;o_]3W00Co0000okc?j?njc>So^/cX0_nhbnP2okK9j003okC8jOnca^So/lKX00;o/lKX0_naa>P2
ok34j0;o[l;X00Go[/;Xojg1j?n]`NSo[L7Xo`00000Iooooo`03o`000?oooooooooo01Kooooo0ol0
000;ooooo`;oXK_[0_nO^^`00onN^^coVkW]oi^ik@02oi^ik@;oUkS^0_nA]O02oi2fl0;oRK?b0on0
/?<2ogF[m0?oIjGd0_mHWO<2od^Cl0;o>HS/00?o<WoWobAfholTM^<00_lXL^02ob=/g@05oc9^g?ld
KM[o=6gJodAafOm9L]P00omBM=L3ofEidP;oKggA0omiPLl3oh>5c@?oSH[;1?nFS/T3oinBa`CoYYO5
00Co[I[4ok2Oa_n`WlKo/9o61?nfX/D01?nkY/?o_jc6okn/a_no[<H3olB^a@;ob;G70oo<^<H2om6o
b@03omC1aooIbL_ofLW;00;ofLW;00?ogM;>omkBc?oRfll00_oRfll2onGTd@03onK]dooVj];oi_7C
00;oi?OD00Kogo_Do`000?oJo]GodooFolgof?o7om/2ol?ng`03olWli?o5nnSo`_S]00;o_oC`0_nm
l?<00onnk??o^nOdok_Wm002okSRm0;o^=gc0_nffO800ol0003oooooooooo`0>ooooo`002oooool0
0ol0003oooooooooo`0Dooooo`;o00000oooool01?m;QNOoA7kTodAni?m4O^@2odYnh@05odUjgom;
N=coBgSLod]hg?mHNmX00_mNO=T3ofIne`;oM8?D0_mlQM83ohB8d0?oSHc>1?nDSl`3oibCbP03oj:F
b?nSUlWoXiO900CoZI[70_n_WLH00on`WlKo]Z;5okJRa@03okJRa@04okZUa?nlYlGo_:O5okbWa@?o
`:[400?o`Zg4olJ_a?o6[l@00oo6[l@3ol^da0;ocKO50oo?^LD2om6laP03om:na_oE`LOoeL7700;o
eL770_oGaLP01_oGa/SofLW9omW9bOoIbLWoflg;om_=c0Cog=3=00?ogMC?omcCd?oLe]400_oLe]42
omgId`?of][F0_oJg=P2omWNfP03omKKg?oEgMgoeMgM00;oe=kO00?od=[QolkKh_o>fn800_o<fn@2
olWGi@;oamOV00Co`m?Vol;Cioo2dnOo_m;X0onlcnP01Ol0003o^<_XokS;j?nhbnSo]l[Y00Co]<SY
0_nca^P2ok;5j@;o/<CX00?o[l?Xojk2j?n^`^P00_n^`^P2ojg1j003o`000?oooooooooo01Oooooo
00?o0000ooooooooool05?ooool2o`0000kooooo1?nQ^n/2oijjk0;oVkW]00?oVkW^oiJhkonF^>l0
0_nF^>l3oi2fl0;oRK?b0on0/?<2ogF[m0?oIjGd0_mHWO<2odFCl0;o>HS/00?o9ggWobAfholTM^<0
0_lIKMh00olSK=go8FSKob5Xf`02ocA]fP;oBG;H0_mBM=L3oeaheP?oKggA0omiPLl3oh>5c@?oSH[;
0onFS/T3oinBa`?oYYO500?oZ9_8ok2Oa_n`WlH00_n`WlH3okJRa@03okVXb?no[<Ko_jc600?o_jc6
00?oa:k5olReaoo8]LL00_o8]LL01Oo<^<KodKo9om6obOoA_lWoe/S=00?ofLW;0_oMd/h2on7Ld@03
on;KcooUi=7oiNCA00;oi^gC00?oiOGDon7jdooTmm@00_oOnm@01?oJo]Go0000olgof?o7om/2ol?n
g`05okomi?nmnnWo^oS^ok_hk_nom?000_nml?<2ok[[m003ok_Wm?nhh_Co^>;d00;o]]cc0_nffO80
0onceO7o0000ooooo`0?ooooo`002_ooool00ol0003oooooooooo`0Booooo`?o00001_ooool00om;
QNOoA7kTodAni002ocmih@;oBG[O0_m;N=`2odmhf`;oGWcI0_mVO]L2ofn1e@?oN8CC0on4R=03ohf<
cP;oU8o<00CoTi3=oi^CbonKTl_oVi?;1?nSUlT3ojVJa`04ojnMa_n`WlKo/9o6ok2OaPCo]Z;51Onl
YlD01?o0Z/Co`Zg4ol:]a?o2[L@3olJ_a0;ob;;500?obkC4olfgaOo=]lD00_o=]lD01Oo?^LGodKc6
om6la_oA_<Koe<3700?oeL770ooGaLP3omW9b@;oflg;00CogM7<omc@cOoLd<gog=3=0_oMe<l2omkH
d003omcFdOoMfM?ogMWC00;ogMcE00Cof][Fom[Lf?oJg=Sof]cH0_oIg]X01?oHh=coeMgMomCNgooD
g]l2om;Nh@03olkKh_o<fnCoc=_T00;ob]_U0_o7enH2olGGi`09ol;Cionod^So_m;XokoBj?nlcnSo
^lkYo`000?nkc^Wo^<_X00?o]l[Y0_ndb>T2ok?7j@;o//GY00?o/LGYojo3j?n_`nP00_n_`nP2ojk2
j0?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Booooo`?o00004Oooool3oj6k
j`CoW[[/0_nK^Nh4oiJhk`;oT;Oa1?n9]?82ognam0?oM:ce0_mVY_D2oeFNm0;oAI?`0_laQn`2oaek
iP04oaMbhOlIKMko6FgNoa5Vf`;o8FSK0_ldKMX2oc]^fP;oDWCG0_mLN=H3ofQme0?oNH7?0on3QLd3
ohf:b`?oUXk91?nOT/L01?nVUlGoZ9_8ojRKb?nXVlP4ok2OaP04okJRaOniZ<So^JS8okVXb0?o_jc6
00?o`k?:olReaoo8]LL00oo8]LL3om6ob@?oe/S=00?ofLW;omgBc_oMd/h00ooQg=401?oTim?oiNCA
onK]dooVkM<2onGee00;on7jdooKo];ofokBomCodOo;om3o0000okgmdonioMSo`okOokomi?nmnnT0
0_nkn>h00onjlo;o^>oeokS_m@02ok[[m0;o^>Ge00?o^>;dokKLlonfg?<00_ndf?<2ok?El@03o`00
0?oooooooooo00kooooo000:ooooo`03o`000?oooooooooo00oooooo0ol0000:ooooo`04od61i_m4
O^CoA7kTocmih@?o?WGN0_m;N=`01?m?N=_oEWWIoeIifOmFNMT2ofIne`;oKh7E0_mhQ=<3oh:8d@?o
Rhc?0onCT<d4oi^Cb`?oXiO90_nYV/L00onZW<So/9o6ok2OaP02ok2OaP?o]Z;50_nhYLH4okbWa@Go
`Zg400CoaZo4olRbaOo8//Gob;;51Oo=]lD3om6laP?oe<3700?oeL77omO5b?oGaLP00_oGaLP00ooJ
bLWofLW9om_=b`02om_=b`;ogM7<00?og=3=omgDcooMe<l00ooNf=000ooOfm;ogMWComgLe@02omgL
e@;ogMoG00?of]cHomWNf_oIg]X00_oHh=`01?oGhMkoe=kOom;NhOoBg^42om3Oh`05olcKi?o:fnGo
b]_Uol[KiOo8f^L00oo5enL00oo3e^So_m;XokoBj002okkAj@;o^lkY00Co0000okW=jOngb^Wo]l[Y
0_nfbNT2ok?7j@03ok;6jOnaaNWo/LGY00;o/LGY0_n_`nP7ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03oooool3o`0001Gooooo0onQ^n/2oijjk0;oW[_]0onK^^h3oiJhk`;oT;Oa
0_n9]?801?n9]O?oOk;dognbm?mo/_@3ogB]mP;oIJOf0_mEW_@2od6Cl@;o:hO/00?o7G_Vo`U^g_l9
K]h00_l8J=/00olAI]_o8FSKob5Xf`02ob=WfP03oc]^f_m5LMWoAG7I00?oG7SF0_mXOM@3ogB2d`04
ogV1con3QLgoPhG=oh>5c@?oSH[;0onFS/T2oinBa`03oinGbonXVlSoZ9_800;oZ9_80on`WlH00onb
YL[o^JS8okVXb003okVXb004okn/a_o3/l[o`k?:ol>cbP?ob;G70_o=_//00ooA_lWoe/S=omK8c@02
omK8c@03om_Cd?oMd/kohMcA00?ohMcA00?oi>OConG`eOoVkM<00_oUmM@2on7jd`09om_nd_oDom7o
boo@olCndOnmoM?o0000okKlgOnennCo]?W[00;o]?Ka00?o^_?bokS_mOnhkoD00_nfjOH2okSUm@;o
]^3e00?o]]ccokCHlondf?<01?ooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003ooooo
ooooo`0<ooooo`?o00003_ooool01?m1PNKo>7WSocQiholoNN42ociegP;o?g?L0_m?N=/2oeIif@;o
Gg_H0_m_PMD3ogR4d`?oPXSA0on;S<l3oi>@c@?oVi?;0_nSUlT00onSV<[oZYc8ojZLb002ojZLb0Co
/9o600Co]Z;5okRUa_nhYLKo^:G60onlYlD00onnZ/Go`Zg4ol:]a002ol:]a003olF`aOo8//Gob;;5
00;ob;;500CobkK6olfgaOo=]lGocKO50_o@^lH00ooA_<Koe<37omC0a`02omC0a`04omO4b?oGaLSo
elG8omO5b0;of/W900?og<g;om_=booKcL/00ooMdL`00ooOeLkogMC?omkHd003omkHd004omoKd_oM
g=GogMcEomgLe@?ogMoG00Cog>7IomWNf_oHh=cof>3L0_oGhMh00ooEh^3od]kQom3Oh`02om3Oh`;o
c]oU00Gob]_UolSJioo8f^Oob=[WolGGi`02ol?Fj004ol7DjOnndNWo_]7YokkAj@;o_=3Y00?o^LgY
o`000?nfbNT00_nfbNT00ondb>Wo//KYok;6j@02ok;6j@;o/LGY2_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00cooooo0ol0000Iooooo`04oj6kjonQ^ncoXK_/oj6kk0?oW[_]0onK
^^h3oiJik`?oT;Oa0_n9]O<3ognbm0?oM:gf0_mUYoH3oe>Om@04ocjElOl[Qnco57[ToaAji0;o2FkN
00?o26SKo`1Pe_l=H]P00_l=H]P00olSIm[o:FWJobUYfP02odEaf@;oG7SF0omXOM@3ogB2d`?oP8OA
0on;SLl3oiJBc@CoWiO;1?nXVlP01?n`WlKo/ZG:ok:Ub_nbYLX4okVXb0Go`k?:00Gob;G7olfnboo=
_/_ocKk;om;7d003omK8c@;ofm?@00CogmkDon7LdOoQg=7ohMcA0_oTim<00ooUl=Goh_SEonGee002
on7jd`09om_nd_oDom7oboo@olCndOnmoM?o^OgHokKlgOl0003o]?W[00;o]?Ka00?o]?7eok?/monc
k?L00_nfjOH2okCSmP;o]^3e0_ncfo@00ondf??oooooooooo`03ooooo`03o`000?oooooooooo00go
oooo000:ooooo`03o`000?oooooooooo00Wooooo0ol0000Aooooo`;o=WcU00?o>7WSoc=cgolcLml0
0_lnMMh01?loLmcoAG?KodEcfom5Lm/2oeIif@04oemkf?mYOmKoJGoFofUoeP?oN8CC0on2R=43oh^<
c`;oTi3=0_nKTl/00onLU<coXiS:oj>HbP02oj>HbPCoZYc80_n`WlH00onbX/Oo^:G6okRUaP03okRU
aP04okbWaOnnZ/Go_Z[5okjZa@;o`Zg40oo5/<D2olRba@?obkK600GocKO5om2ka_o@^lKod;_6om:o
a`03omC0a`?oelC800CoelG8om[9bOoJbLWof/W90_oLcL/00ooKcL_ogM7<omgAc002omoEcP04on3I
cooNf=3og]S@omkHd0;ogm_B00?ogmkDomgLeOoMgmL00_oMgmL01?oLhMWofn?Kom_SfooHh=`2omOQ
gP;oeN;P0_oChn800oo@gn?oc]oUolkOi@02olcNiP;ob=[W0_o6fNP01Oo3e^So`MCYol7DjOo1e>Wo
_]7Y00;o_=3Y00Go^/oZokS<jOl0003o^<cYokK9j@03okC8j@;o//KY3Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Wooooo0ol0000Nooooo`03oj6kk?nQ_>coXKc/00?oW[_]0onK
^^h00onF^NooUk[`oiNjl002oi6hl@CoRKKc0on0/oD2ogB_m`?oIJWg00CoDj;focfGl_lmUo;o9XS/
0_lDN^@2o`1/f`04o`1Seol0H=Ko3F;Ho`eRf0;o3V7H0_lYJMX2odEaf@;oDGOI0_mXOM@4ogB2d`;o
P8OA0on;SLl4oiJBc@CoWiO;0_nXVlP00onZXLgo/ZG:ok:UbP02ok:UbP?o^JS80_nm/<`3ol>cbP04
olRkc_o=_/_ocKk;olfnb`?od/O@00Coe/S=om_Cd?oKdm3ofm?@0_oOg]@01?oQg=7oi>OConCWdooU
l=D2on;he@;ogOgC00coe?o@ol[oc?nen/So[_W9oj[hc_nXn=GoZ?WMoj[hi_l0003o[OO^ojkcm?nd
lOD2ok?/m`;o/^Kg0_ndhoH2ok?NmP;o/m_d1oooool00ol0003oooooooooo`0=ooooo`002_ooool0
0ol0003oooooooooo`06ooooo`?o00005Oooool2ocIli@03obadhOlcLmoo<g?O00;o<G3M00?o?g?L
odEcfom5Lm/00om=MMX00omONmSoJGoFofUoeP03ogB3e0?oOXSB0on9S=02oi>@cPCoW9C<0onSV<X3
ojZLb003ojbNbOnbX/Oo/Z;700;o/Z;70onhYLH00onjYlOo_Z[5okjZa@02okjZa@03ol:]a?o5/<Go
aK3500;oaK3500?ob;;5ol^fa_o;]/H00_o;]/H4om2kaP;od[o700?oe<37omO4b?oGa<P00_oGa<P3
om[9b@?og<g;00?og]7<omgAc?oOeLh00_oOeLh2on3Ic`03omkHd?oOfm;ogm_B00;ogmkD0_oOhMH0
1?oMgmOog>7Iom_SfooKhm/2om[Ug@05omOQg_oEh^3oeN;PomGRh?oChn800_oAhn@00oo>gnGoc=kV
olcNiP02olWMj0;oa]WX0_o4f>T2ol7Dj@;o_]?Z00Ko_=3Yok[?j_njcn[o^/oZokS<jOl00002okK;
jP03okC8jOoooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`06oooo
o`?o00008Oooool4oj6lk0?oW[_]0onK^nh3oiNjl0;oTKSa0_n9]_<2oh^gm0;oPKGf0omf/OL2ofN/
n0;oE:Cg0olmUo801_lTR^co3GWRo`1/fol0K=_o05kAo`1Id0;o05_C0_l>HMP01OlYJM[o=6kKocA^
foldK]_oDGOI00?oGWgI0omdP]<3oh27d@?oRhg?1?nFT/d2oinGb`03oj6Ld?nZXLgoZZ7=00;oZZ7=
1?nbYLX01OniZ<So_K3<okf`c?nm/<co`k?:00Cob;_>00?ocKk;om;7d?oBam000_oBam03om_Cd0?o
gmkD00?oh^WGonCWdooUl=D00_oRn=D2omgmd`08omCod?o:olco]O[8ojkibOnZn<koZ?SEoigegonZ
n>H2ojggkP04o`000?n_koOo[nogok3Yn0;o/^Kg0_nah?L2ok?NmP[ooooo00?o0000ooooooooool0
3Oooool000[ooooo00?o0000ooooooooool00oooool3o`0001Wooooo0_lZN>@01?l/M>7o9VkNobI^
g_laL=d2oc=^f`;oAG?K0_m=MMX2oeMif@;oJGoF0omdPm@2ogj8dP?oRHc@0onCT<h3oibDc0CoXiS:
00CoZYc8ojbNbOn/W/Wo[9k91?nbX/L01?nhYLKo^ZO7okZWaonjYlL2okjZa@;o`Jk70oo5/<D2olNd
a`?obkK60_o>^/L2om2kaP?od[o700CoeLC9omO4b?oGa<SoelC80_oIb<T01?oJbLWog<g;omc=booL
cL/2omkAc003omoFc_oOeLkogmG>00?oh=W?00?ohMgAomoKd_oOg]@00_oOg]@01OoOhMKognCHomoT
f?oNim[ofn?K00?of^GM0_oHi]l01?oEh^3odn?Rom7Si?oAhn@2olkSiP04olcNi_o9gNSobMgXolKL
j@?oa=SY0_o1enX2okkCjP;o_=;Z0_njcnX2okS>jP03okK;j_l0003ooooo017ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`?o00009Oooool4oj6lk0?oW[_]00?oVk_^oibk
k_nL^nh01?nG^_02oi:ilP?oRkOd0_n1]OH3ogJam`;oIjch0omDY?L2ocjJl`;o98g/00Co27[Qo`1Z
eol0G]7o05W@0_l0Fm<00ol0F];o56CIobUYfP02ocA^f`;o@WGM0_mNOMT3off4f0?oNh[G0on;SLl2
oiJBc@;oUYOB0onQW=05ojZQc@;o/ZG:00?o]Zc?okf`c?nm/<`00_nm/<`5olRkcP04olg6dooBam3o
d/O@om;7d0;oem?D00Cofm?@omoNe?oOg]CogmkD0_oRjML00ooRlmSog__Gon;he@02omgmd`07omCo
d?o:olcoV^nmoiK_`OnFl<WoVO;Doigeg`02oj;ejP05ojKcl_nZl?OoZ_3go`000?n`jOP00_n_hoP2
ok7Pm`gooooo00?o0000ooooooooool03Oooool000Wooooo00Co0000oooooooooooooooo0ol0000M
ooooo`;o:WST00Go7foOobI^g_lVK]ko96[Koc=^f`03ocU_fP;oCGGJ00CoEgWIof=mf?mSOMSoHggH
0_mdPm@3ogj8dP?oRHc@0_nCT<h4oibDc0;oXiS:00?oY9[;ojbNbOn/W/T00_n/W/T3ok:Ra`03okBT
bOnjYlOo^ZO700;o^ZO700?o_Z[5ol6^aoo1[/L00_o1[/L00oo5/<GoakC7olNda`02olNda`05ol^f
a_o>^/Ooc[[7oljjaoo@^lH01?oB_lL2omG4b@04omO4b?oIb<WofLS9omW8b@;oflg;00Cog<g;omkA
c?oNdLcog]7<0_oOe/h00ooOeLkoh=W?on3Ic`02on7Md@;ohN7C00CogmkDomoQe_oOi=SognCH0_oN
imX2omcYg003om[UgOoHi]oof>KO00;oe^OR00Coe>OTom7Si?o>hnKoc^?V0_o<h^P01Oo9gNSoa]cY
olKLjOo6g>Woa=SY00;o`MOZ0_noe^/2okcBjP;o^]3[0_nhc^X3ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05?ooool01?l0003oooooooooooooool3o`0002[ooooo00?oXKc/oj:l
k?nR_>`01?nO_>d2oibkkP;oUk[`00?oV;_`oi>jl_nC^_800_nC^_82ohbhm0?oPkKf0_mh/oP3ofV^
n@;oEjSh0_m1W_D2obB=k008o`MmhOl0JM?o05_:o`1Kb_l0DlOo05?;o`1Jd_lDI=T3ocA^f`;o@WGM
0_mNOMT3off4f0;oNh[G0on9TMD4oiJGdPCoXIc@0onZXLd00on]Z=?o]Zc?okJ/c`02okJ/c`;o_K3<
0_o2^M83olRkcP?ocLKC00Cod/O@omOCe?oGdmCoem?D0_oKgmT01?oOg]Coh^WGon;YeooRlmP2omkk
e`;oeOoC00SobOo=ojkg_onJkkgoU^o1ohGYb?n=k]OoUO7Toigbk`;oXo3f0_nZl?L01?n/joWo[NGi
o`000?n_hoP@ooooo`03o`000?oooooooooo00gooooo0009ooooo`Co00008Oooool2oaichP03oam_
golHJ=_o66SK00;o9VSJ0_liKmX2od9afP;oEgWI0_mSOMP3ofn2eP;oOXSB0on9S=03oi>@cP;oW9C<
00?oW9K>ojBJbonTV//00_nTV//4ojbNb@04ok:RaondY<Wo]:C9okBTb@;o^ZO700?o_:_8ol6^aoo1
[/L00oo1[/L5olNda`Coc[[700Cod;k8om:oaooB_lOod[o70ooEa<T3omW8b@?oflg;0ooNdL`3omoF
cP04on7JcooPfLoohMgAon7Md@?ohN7C00?ohNCEon7WeooOi=P00ooNimX2omcYg005om[ZgooHi]oo
e^ORomKWh_oDin@00_oAinH01Oo>hnKoc>;XolcRj?o<h^SobN7Y00;oa]cY0_o4fnX01?o1en[o_mK[
okoFjonle>/3ok[@j`Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`Co
0000;_ooool3oj:lk0?oWkc]1?nL^nh2oiRkl0;oTk[b00CoU;_bohjjm?n>^_CoS[[d0on5^?H3og^e
n0;oKK7i0omK[?T01om6XoOo9Y;^obJBk_lVT^ko2H;Ro`1[dOl0FL@00_l0Bl001?l0DLWo05cDoamZ
g?lOJ]`2od9eg@?oDWgN0_m]Q=P3og^:e`?oRI7E1?nFUm83oj6Ld003ojZQcOn]Z=?o[JSC00;o[JSC
0onf[<l00onm/<co`[WBol:idP02ol:idP03olRkc_o=a]?ocLKC00;ocLKC0ooGdm@2om_Of@;ogNcL
00Coh^WGon;cf?oNnmOog__G0_oEom<02?o9olgo[_Nooh;R[_n0i;coQNW8ohg^eonElNCoWO;_0_nS
l?H00onWk?WoZNKjojWVnP02ojgUn@03o`000?oooooooooo00oooooo00?o0000ooooooooool03Ooo
ool000Wooooo0_l0000Tooooo`05oaich_lBJMco4VWLoaQXfolEI=T00_lVJ=X2ocU_fP04od9af_m>
M][oCWKJodiffP;oHggH0_m_P]H2og^8e0?oQhgB0onBT]04oibFcPCoY9[;0_n/W/T00on]XL_o]:C9
okBTb@02okBTb@04okZWaonlZlSo_:_8okb[b0?o`Jk70_o4/LP3olNda`;ob[S80_o>^/L3om2nb003
om:oaooEa<WoeLC900;oeLC900?of<S:omW8bOoKcL/00ooKcL/00ooNd/gog]7<omoFcP02omoFcP;o
hM[?00?oh]oAon7MdOoQhM<00_oQhM<00ooQi=GohNOGon7We`02omoZfP04omkWf_oLjMcog>WLom[Z
g`;of>_Q00?oe^ORomCWi?oAinH00_oAinH2olkVj003olcRj?o9hNWobN7Y00;oa]o[00Coa=_Zol7I
joo1fN_o_mK[0onle>/00onjd>_oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04oooool2o`00037ooooo1?nR_>`2oinlk@;oW;_^00?oWKc^oiVkl?nI^o000_nI^o02
oiBklP?oS[[d00?oQKSfohRim_n8^OH00omn]oP3og6dnP;oHJoj0_m=Z?P2obbGl003o`n8i?l0Km7o
05Vo00;o04_000Co0579o`1Le?lOJ]co7f[L0_l_L]l2oe9mgP?oI8KN0omkR]L3ohVAe@?oUYOB0_nQ
W=000onRXmKo[JSCojfXd`03ojfXd`;o]Zc?0_ni]]H3ol:idP;oa/CH0oo=a]<2om;Bf@03omOCe?oK
gmWofmoI00?ogNcL00?og?KMomKmf_oNnmL00_oEom<02?o9olgoP^:^oh;R[_m_g;coN^C=ohK[gOnA
kn_oV^od0_nQk?T00onWk?WoZNKjojWVnP04ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03?ooool000_ooooo00?o0000ooooooooool08_ooool01OlCK]oo4VWLoa9Yg?lHJ=_o5FCI
00;o9VSJ00?o;6[Jod9af_m2LMX00_m>M]X3oe]lf@;oKh;F0_mkR=@3ohN=dP?oTY;@1?nLU/h2ojBJ
b`03ojFMcOn]XL_o[J7;00;o[J7;0_ndY<T00onfZ<_o_:_8okb[b003okb[b003ol6^aoo4/LSoa;78
00;oa;7800GoakC7olZhb?o:^<Sob[S8oljja`04om2nb004om?3b_oEa<WoeLC9omG4b@;of<S:00Co
flg<om_=booKcL_oflg;0_oNd/d2omoGcP03omoFc_oQf/oohM[?00;oh]oA0_oRhm<01?oQhM?ohNCE
on7WeooQimL3omoZfP03omk/g?oLjMcof^[O00;of>_Q0_oFk><2om?/iP03om7Wi_o>i^Soc^KX00;o
bnGZ00?obN7YolKOjoo6gn/00_o3gN`01Oo1fN_o_mO/okoGk?noenco_=C[00_ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02oooooo0_nR_>`00onR
_NcoX;c]oj2lk@02oj2lk@;oWKc^0_nI^o000onJ_?3oU[_aoiJkl@02oiJkl@;oT;_d0on8^OH00omn
]oSoP[Whoh:in002ogJgnP?oJ;?k0_m=Z?P3ocBNl`04oaN@j?l0M]?o05bmo`14/`;o05?;0_l7I=T0
1?l_L]oo@ggSod=mhomBOMh2ofB6gP?oMHkN0on6U]`3oiFMf@CoXZ?F0on]Z=<00on_/][o^KKFokVf
eP03okVfeP03ol:id_o6a=Soa/CH00;oa/CH00KocLKCom;BfOoBd]Wod];IomKPg_oKgmT3omg/g00;
omcfgOoFoM[obOoColWodoninlSoYoBmofK?WOmVfL;oM^?FohGZionAk?800_nKjoT2oj7/n@03ojGV
nooooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`003?oo
ool00ol0003oooooooooo`0Rooooo`03oa=^gol5HmWo1F?I00;o5FCI0_lGH]P3ocI]fP;oCWKJ0_mK
O=T2ofV2f0?oNhSD0on7SM83oi:Bd0;oW9K>00CoW9W@ojFMcOnUWLgoYIg=1?n]XL/01?ndY<Wo]ZS;
okJXbonfZ</3okb[b003okj_boo4/LSoa;7800?oa;781?o:^<P01?o=_<[od;k8om2nb?o@_/P3om?3
bP04omG4bOoHb<[of<S:omS8bP;oflg<00?oflg;omkBcOoNd/d00ooOelh00ooQg=3ohM[?on;Od@02
on;Od@;oh^?C00?oh^OEon;[eooQimL00ooOj]X01OoNk=cog>kNomc^g_oJkn7of>_Q00?oe^cS00Co
dncVom3[j?o@jnSoc^KX0_o;iNX2olSSj`03olKOjoo3gNco`mg/00;o`M_]0_noen`>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`?oX[g/
0_nP_>d00onQ_NgoW[c^oijlkP02oijlkP;oV[c`0_nF^o400onG_?7oT[ccoi:ll`02oi:ll`;oRk_f
0on2^OP2ogJgnP?oJ;?k0omE[_X2ocjUmP04ob>Ik?l0O]Oo07kGo`0nY`;o05?;0_l7I=T00olHK]oo
@ggSod=mh`03ofB6gP?oMHkN0on6U]`3oiFMf@CoXZ?F00Co[JSCojnbf_n_/][o[k;J0oni]]H00onm
`]goa/CHolK4f002olK4f004ol_BgooBd]Wod];Iom;Bf@;oe^3N0_oGk^<00ooMk=cog?KMomKmfP02
olWod`05okWkb?nWm;goI/nMogSTh_n8jO400onDjOT00onKjoWoXNKlooooo`0;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool08Oooool2
o`MYg006o`ESfOl0FmCo1EgEo`EMeOlGH]So7FCI0_lfKMX3od=cf`;oFgcI00CoJH;HogR8eomhR=Oo
N8SG0on5S]D3oi6DdP?oW9W@1?nUWLd2ojfQb`03ojnUcOnfZ<_o]ZS;00?o]ZS;00Co_:_8okj_bonn
[l_o_Zo;0oo4/LP2olJfbP;ob[S80oo=_<X00oo@_/Sodl?:om?3bP02om?3bP?of<S:0ooKcL`00ooM
dlkog];=omoGcP02omoGcP;ohMc@0_oRhM800ooRgm7oh^?Con;Sd`02on;We@05on;[eooQk]WohNkI
omoZf_oNk=`00_oLk]h2om[_h@;oeo3S00Coe^cSom?/i_o@jnSod>_X0_o=jNX00oo;iN[ob>?[olSS
j`02olGRk@03ol?Mk?o1fngo`M_]017ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02oooooo00CoX[g/oj>mk?nS_NcoXkg/0_nQ_Nd2oijlkP03oinm
k_nK_>ooVkc_00;oVkc_0_nG_?42oi:ll`;oU;cc0on>_?D2ohJkn0?oO;[j0om_]o/2oejbn`?oBJci
00Go<J;ao`F8gOl5R=goE`00o`19_002o`1Kd003oaQ^gom3ON?o@ggS00;oF8SU1?meS]h3ohJFg0?o
UIgI0_nRXmH2oj>/gPCo[k;J00Go^KKFokg2gOnm`]go_L;MolK4f004ol_Bg`03om;BfOoFh=koe^3N
00;oenkS0_oDnN<01oo9o]go^?cBokSld_n=ik;o0000of_Mg_mniNl00_n=ioT2oiCYn@03oicVo?oo
oooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`003_ooool2
o`0002;ooooo0_l7JM`01_l0GMCo05_Do`EMeOl5GMGo5f;HoaeTf@;o=VgJ0_m3Lm/2oe=jf`;oJH;H
0omhR=L3ohF>e@?oTICB0onLVM03ojFMc@04ojfQbon_YLgo[jG=ojnUc@?o]ZS;00?o^:c=okj_bonn
[l/00onn[l/01Oo4/LSoa[K:olJfb_o6]/[ob[S800CocKc:00Cod<;<om?3b_oC`l[odl?:0_oFb<`0
1?oHb<[oflg<om_=c?oKcL`2omgCcP;ogmS@00?ogmO>on7Ld?oQg=000ooRhM801?oSiMCoh^?Con;W
eOoRimD2on;[e`;ohNkI00?ogo3Lomcbg_oLk]h00_oJkn42omO`h`04omC`iOoAknSodNoXom3[j0;o
cNWZ00?ob^S/olOVkOo7i^d00_o5h^d2ol;Ok@03ol7KkOoooooooooo017ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Hooooo`;o0000<?ooool2oj>mk003oj>mjonQ_NgoXKg]00;o
XKg]0_nO_Nh2oi^lk`;oWKg_0onI_O400onD_??oUkgboiNmlP03oi6mm0?oR[gg0_n1_?T3ogJjn`?o
IkOl0_mF/_/3od2[mP03obJPkOl0Pm;o053100;o06OI0_l]O>H2oeR8i@?oKI?V0on1WND3oi>VhPGo
XjcN0_n_/]X01?nb_^?o_L;Mokg2gOnm`]d2ol7@iP?obm;O0_o>h>H00ooFh=koenkSomO^h`02omCi
h`06olWngOnho=;o^?cBohgW/_mehNkoQnCi0_nChod2oiOTo1;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`004?ooool00ol0003oooooooooo`0Qooooo`03o`1Uf?l0GMCo
05C>00;o05K@0_lMI=T2obQYfP;o@g?K00CoDg[Kof>2fomSP]_oHh;K0_mhR=L3ohF>e@CoTICB0_nL
VM02ojFMc@03ojJQd?n_YLgo[jG=00?o[jG=00Co]ZS;okR/cOnh[<go^:c=0onn[l/00oo1]<goa[K:
olJfbP02olJfbP04olVkc?o=_<[ocKc:olflbP?od<;<00Codl?:omK8c?oFb<coe/S<0_oIcLh01?oK
cLcogM?>omgCc_oMdlh2omoHd003on7Nd_oQg=3oh^7B00;oh^7B0_oSiM@01?oSj]Koh^OEon;[eooR
jmL2on7^f@03omo`g?oLl]kog?;N00;of_?P00?oeoCSomO`hooDl>D00_oAknP2olk^jP03ol_/k?o:
j>coanK]00;oanK]0_o4hnh00oo2gngoooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0_ooooo`;oXkg[0_nQ_Nd00onR_NcoX;g]oj2m
k@02oj2mk@03oifmkonN_NooW[g_00?oVkg`0onG_O800onA_OCoU;kdoiBnm003ohjnmP?oQkgi0_mm
_O/3og6ko0?oH[Sm0_m?/oX2ocV[l`03o`1@`Ol0ImWo06OI00;o;GcV0_m6Rn/3offCiP?oPIgU0onC
Y^82oj>/gP;oXkSX1?nb_^<00onm`]go`M3Vol7@iP02ol7@iP03ol_Bgoo>h>Koc^3V00?ocNoZ00?o
ao[YomCihoo9o]d00_nho=800on1hOWoSn7mohoQo@02oi?SoAKooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`0Qooooo`05o`1Qe?l0F<oo
05C>o`1Fd?l0E=000_l=G]H00olXJM[o>73LocQ`g002oe=jf`;oHh;K0omcRMX3ohF>e@;oTICB00?o
T9OFoibLdonLW=<01?nVXM03ojnUc@03ok6Yd?nh[<go^:c=00?o^:c=00Co_Zo;ol6dcOo1]<go`KC=
0_o6]/X3olVkc003olflb_o@`/cod<;<00;od<;<0ooFb<`3omW=cP?ogM?>0ooOf=001?oQg];oh^?D
on;Se?oRhM82on?Ue0;ohn[F0_oRk]P00ooQlM[ohNkIomo`g002omcbgP;of_?P00GoeoCSomCdiOo@
lnSod??Xom7_j002olk^jP;obnc/0_o7j^h00oo7i^goa>?^olCSkP0Iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0_ooooo`?oY;g[0_nR_N`2oj2m
k@;oXKg]0onN_Nl00onK_O3oW;k`oibnl003oiVnlP?oU;kd00CoS[kfoi:omOnB_oGoT[oe0_n<_oP3
ohBonP;oN[kl0om]_?d3oejjo@04odbenOl0@j_o04>[o`1LbP;o4WOS0_m6Rn/2of6IkP?oNZK_0_nC
Y^82oi2`k0CoXkSX0_nb_^<2ok?<k@?o`M3V0_o2gnh01_o>h>KocNoZolg_j_o=kn[oao[YokOlh0;o
WoC>00?oOMkjohcNo_ooool06oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo000Booooo`03o`000?oooooooooo027ooooo00Go067Do`1CbOl0C/Oo04k:o`1Dd002o`eNeP03
oaUTfOlhL=coBGWN00;oBGWN0_mSP]/2og>9fP?oPi3H0on@UmH3oibLd`CoYZ7@00Co[jG=ok6Yd?na
ZM3o/JW@0onh[<d00onk/M3o`KC=ol6dc@02ol6dc@03olJfb_o9^lcobK_<00;obK_<00Coc<7?om32
c?o@`/cod<;<0_oCalh00ooFb<cofLg>omW=cP02omW=cP03om_Cd?oMdlkogmS@00;ogmS@0_oQg]82
on;Se003on;Xe_oSiMCohn[F00;ohn[F00Coh^kHon7af_oNm=cog_CL0_oLm]h01?oImn3of_?PomOd
hooDm>D3om3cj004olgbj_o:lNcob_7/ol_/k0;oan[^0_o4inl00oo4hnkoooooooooo`0Hooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0_ooooo`;o
Y;g[1?nS_N`00onQ_NgoX[g]oj:mk@03oinnkP?oW;k`00CoVKkboi^nlOnK__7oVkka0_nG__<2oi:o
m@03oiJom?n@`?OoT<3g00;oT<3g0_n:`?T3oh;0n`04ogS0oOn1`_coPL;loh72o0;oN<;n0_m]`_h0
0ol0Ck;o06kFobn;k@02obn;k@;oHIW^0omjY^l4oi2`k0;oXkSX0_nQa_<4ok?<k@03ol7@i_o2gnko
`]o^00?o_nkb00?ocNoZolOjjOngo>000_nOm<hOooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool001?ooooo0_l0000Rooooo`05o`1Nd?l0DlWo04k7o`1>b_l0CLT00_l0Em80
1?lII=Wo>73LodUig_m9NMh3oeb2gP;oLhWJ0on3T=P3oi2GeP?oW9cC0_nVXM000onWYM?o/JW@ok6Y
d003ok6Yd004okR/cOnk/M3o^k7@ok^ad0;o`KC=0_o4^Ll3olVkc0?oc<7?00God<;<om?7c_oCalko
dlO>omK>d@03omW=cP;ofm?@0_oNfM800ooOf=3ohMkBon7NdP02on;Se0;oh^SF0_oRkMP00ooSj]Ko
h^kHon7afP03omkdg005omcfg_oImn3oeOSRomGhh_oBn>D00_o?n>L01Oo@lnSocO;Zol[ak?o:lNco
ank^00;oa>c`0_o4inlMooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool2
o`00033ooooo0_nT_N/2oj>mk0;oY;g/0onR_Nd01?nO_^koXKk^oj6nk_nQ_^h2oijnk`;oVkka00?o
WKo`oiZol_nJ_o800_nJ_o82oiJom0;oT<3g0_nD`OD3oho1n0;oRL;j0_n1`_`2ohW3n`?oP/Cm0_mj
aOh00ol0K]Ko;h_]obn;k@03odjNm0?oNZK_0_n@/>`2ohVmm`CoXLKc0_ncc>d2ok7LmP06ol;Ok_no
k_;o_nkboko^l_ncmnooW?CP0_moi/LRooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02oooool001Gooooo00?o0000ooooooooool08?ooool2o`1Lc@05o`1?a?l0Al?o04g9o`1Gd_l8
G]H00_lYKM`2odUigP;oG8;N0om^Rmh2oh>@f0?oT9OF0_nLW=<00onLX=OoYjGCojNUd`02ojNUd`?o
/JW@00?o/jkCok^ad?nk/M000_nk/M000oo1]<goa;W?olBic`02olBic`03olVkc?o<`Looc<7?00;o
c<7?0ooCalh3omK>d@03omW=c_oKdm3ofm?@00?og]WB00CogmoDon7Nd_oRhmCoh^?D0_oRj=H3on;]
f007on7afOoOmM_og?SLomchg?oNm=cog?KNomWgh002omGhhP;od_SU00KocoSWol_fj_o8m>cob?C/
ol[ak?o7k^h3olC/l23ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02kooooo0onU_N/00onT_NcoY;k[ojBnj`03oj>nk0;oXKk^00?oX[k]oj2nk_nP
_^h00_nP_^h2oifol0;oV[ob0_nL_o43oiW0l`03oiC1mOnH`OCoV<7d00?oU<;f0on?`oP01?n9`o_o
T<Cioi34nOn@a?T2oh[5n`?oQ<Km00?oOLOnoa25iOm>W_@00_m>W_@3off_n0CoRKgg0_nQa_<2oi_E
o0;o/Mcf0_nYj_X2oiO_lP03ok?gkonLm>3o000002Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`005_ooool00ol0003oooooooooo`0Pooooo`;o05c=00Go04:io`10^_l0
AL7o05OBo`QNeP02obU]g0;o?GOP0_mLP]h2ofj;gP;oP9?L1?n?V]X3oibPe`CoYjGC00Co/JW@ok>^
donc[]?o/jkC0onk/M001?nm]m?oa;W?olBicoo4^Ll2olNodP?oc<7?0_o?am800ooCalkoe/kAomK>
d@02omK>d@03omWDdooKdm3og]WB00;og]WB0_oOgm@2on7Ve`03on7[fOoRj=Koh^gH00;oh^gH00Go
hO7IomoefooOmM_og?SLomWigP02omKkh006om;kh_o>nnCoc__Tom;hiOo?n>OoboKZ0_o8m>`2olGb
k`;o`^oa00?oa>c`ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0;_ooool4ojFmj`;oY;k[00CoXkk/ojBnk?nT_^coY;k/0_nR_^d2
oj2nkP;oXKk^0onO_nl00onL_o7oW[o`oijol003oi_0lP?oV<7d00CoU<;foiS2m?nH`_CoV<;d0_nD
`oL2oi34n@;oULCg0_nAaOT3ohg7n`03ohS8oOl0NLoo07W?00?o<ikb0omI]_`3ogg8o`;oVmGl0on<
god01OnYj_[oUnoboiO_l_miiM_oF=2k02Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0;ooooo`005oooool00ol0003oooooooooo`0Qooooo`04o`1Kb_l0@[Wo042jo`15`@;o25kF
0_lJJ=`01?lmMn3oDh;Roe>2h_mCP^82ofj;gP;oP9?L1?n?V]X3oibPe`;oYjGC0_nYZ]L4ok>^d`05
ok^ad?nm]m?o_KOCokfgdoo4^Ll01?o7_m801Oo<`LooclOBolo7d_o?am;od/kE00?oe/kA0_oIe=<2
om_KeP05omkId_oOgmCogmoDomoOe?oQi]L00_oQjmT2on3`fP06on;]f?oQlMWogoGKomoefooLn=co
fOWN0_oFnn001?oBnn;oc__Tolkki?o;nnH2olOij@04olChk?o2m^oo`_K_olGbk`;o`^oa9?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool2
ojFmj`04ojJmj_nU_^_oYKk[ojFnj`?oY;k/1?nS_^d00onQ_^koX[k]oj:nk@03oj6okP?oW[o`00Co
Vl3boik0l?nN`?3oW/3`0_nK`O82oiS2m0;oVl;c0_nH`oD2oiG4m`03oiW4mOnGaOOoUlGg00;oUlGg
0_nCaoT2oi38n`;oU/Sh00?oTlWjo`23`Olk/o400_lk/o44ofK=n`;oS=om00?oLMk_odk=d?ooool0
:oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000Hooooo`;o00008ooo
ool00ol0B[Wo03fgo`18a002o`1Gd@03oaYXg?l`MN7o<7GQ00;oDh;R0_mXSN83oh2Cg0;oSi[J00Co
SYkNoifUfonMYM_oWJGK1OnYZ]L2ok>^d`04okFdeonm]m?o_KOCokfgd`;o`;gG0oo7_m801?o:a]Ko
clOBolo7d_o?am83om;>e@04omK>dOoIe=?ofMCComWDd`;ofm_F0_oMh]P01?oOgmCohNKGon7[fOoQ
jmT2on3`fP;og_GK0_oLn=`02?oHnmgoe?cNom3mgoo@oMoobogQolOmhoo>nnCobo_V0_o7nNT01?o4
n>co`_K_ol;fkonolo4Xooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool2
o`00033ooooo0_nV_NX01?nU_^_oY[k[ojJnjonV_^/2ojBnk0;oXkk]0_nT_^`3oj:nk@04oj6ok_nR
_nkoX[o^oj:okP;oX;o_0_nN`?02oj30k`;oW/7a0_nK`_<00onN`O7oW<;coic2l`02oic2l`;oVLCe
0_nGaOL2oi_4m@?oVLKg00?oU/Shooooooooool0>Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00_ooooo000Jooooo`03o`000?oooooooooo027ooooo00?o05g7o`0m]ol0B<@00_l0
Em400ol8HmWo<7GQoc1eh@02oe>2hP;oJ8gR0omlU^43ohjNgP?oWJGK0onYZ]L00onZ/=co]KCGokFd
e`02okFde`03okfgdoo0_MOo`;gG00;o`;gG00GoakoBol[6e_o:a]Kob/KFolo7dP03om;>e@?oeMGH
00?ofMCCom_Ke_oKfmH00ooMh]P00ooNj=_og^oLon7[f@02on3`fP;og_GK0_oLn=`01_oHnmgoe?cN
om3mgoo@oMoobogQolOmh`;oa?cU00?o`O_Xokkjjonln>h00_njmO400onolo7oooooooooo`0Xoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0]oooo
o`?oY[kZ0_nV_^/00onV_^[oYKk[ojFnj`02ojFnj`03ojBnk?nU_^_oYKk[00?oY;k/0_nR_nh01?nS
_ngoX[o^oj:ok_nR_nh2oj30k`03oj;0k_nP`O3oX<7`00;oX<7`0_nN`O42oic2l`;oWl;a0onM`o<0
0onKa?Goooooooooo`0oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0
01_ooooo00?o0000ooooooooool08_ooool01_l0=:Oo03J/o`0o^Ol0D<[o26?Ioc1eh@;oB8;U0omQ
SnL3ogbFh@?oSYkN0onMYM/01?nYZ]OoZ[3LojZ`g?nZ/=`2okFde`;o]k[L0oo0_ML01?o3a=_ob/KF
ol[6e_o:a]H3olg=fP03om;>eOoEeMSoeMGH00;oeMGH00?of=cKom_Ke_oMh]P00_oMh]P00ooNj=_o
g^oLomk_g002omcdgP06om[hg_oNmM_og?SLomchg?oHnmgoe?cN0_o@oMl01oo;oN7oaogSolCliOo4
o>Go`O_Xokkjjonln>h00_njmO4]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0]ooooo`04ojJnj_nW_^[oYkkZojNnjP;oY[kZ0_nU_^/2ojJnj`?o
YKk[00CoY;k/ojFnk?nU_^coYKk/0_nS_nd01?nR_nkoXko]oj>okOnS_nd2oj;0kP;oX<7`0_nR`>h3
oj71l003oio2lOoooooooooo04Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`007?ooool00ol0003oooooooooo`0Rooooo`04o`1VbOl0<9ko03R]o`1Md`;o87;Q0_m8P^D3
of6?i`;oN9[V0on<Xn@3oifZh0CoZ[3L00?o]KCGokNjg?ng^]`00_ng^]`01Oo0_MOo`lCKol?4foo3
a=_ob/KF00CocLgJ00Cod=GMomGEf?oEeMSoeMGH0_oHg=/2omWTgP03omgRf?oNj=_og^oL00;og^oL
00Gog?CNom[hg_oJn=koe__Nom7mgP02olcngP03olKng_o1o]oo_OgP00;o^OcS00?o]o_VokGjjOnd
n>d00_ncm_0_ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0^ooooo`03ojNnj_nW_^WoYkkZ00?oYkkZ00?oY[k[ojJnj_nV_^X00onV_^/2ojFnk004
ojFnjonT_ncoY;o/ojBok0;oXko]00?oY;o/oj>okOnS_nd00_nS_nd00onR`>koooooooooo`1:oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool001gooooo00?o0000oooooooo
ool08oooool00ol0KLgo03R]o`1Md`02ob1bh@;o>h;X0omQSnL2ogRJiP?oS:?T0onMZ^02ojZ`g0;o
[;OQ0ong^]`2ok[2h@?o`lCK00Coa/gOolg=f_o=cM[ocLgJ0oo@eMd00ooEeMSof=cKomSLf`02omWT
gP;of^_P0_oIl^401_oNkmcog?CNom[hg_oJn=koe__Nom7mgP;oc?kN00?oa_kNol7ngon[nMh00_nY
n>800onXn>KoZOO[ojWfk`0cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0^ooooo`;oYkkY1?nW_^X3ojJnjP?oY[k[0onU_^/01?nT_ncoYKo[ojFo
jonU_n/2ojBok0;oXko]Coooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
000Nooooo`;o00009Oooool01?l0<:7o03nco`1Ebol>K]h2oc^2j0;oF97/0ombW^`2ohbSi0;oWJ[P
0_nL/NH4ojbgh@03okNjg?nj`^7o^/;Q00;o^/;Q00Go`lCKolK=goo6cMooa/gOolg=fP03om3Eg@;o
d]kQ00?of=cKomWTg_oIi=h00_oJjn02omWbh@04omKgh_oBnn;od__Rolgmh@;oa_kO00Go_okMokWm
g?ncnm_o[_[Loj_igP02ojWhhP03ojShi_nYmn_oZOK_03Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Vooooo`;o0000;_ooool4ojRnj@03ojNnj_nW_^WoYkkY00?oYkkZ00?oY[k[
ojNnj_nW_^X00onV_^/2ojFojeGooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:
ooooo`008?ooool00ol0003oooooooooo`0Sooooo`04o`1nf?mT003o04foo`1Xf@;o;87X0_mHTN`2
og:Nk0?oRJWZ1?nL/NH2ojbgh@;o[KkW0onj`^401?nkbnKoa/gOolK=goo6cMl3olSEi003om3EgOoB
g^7od]kQ00?odnKT00God^kVom[[h?oIl^7ofO;QomKghP02om;khP07olgmhOo6o]ooa_kOokongOni
oMcoV_?FoiSbf002oiObg003oiSchOnJlnOoWO?]03Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02cooooo0_nX_^T2ojRmj@?oYkkY00?oYkkZojNn
jOnW_^T00onW_^X00onV_^_oooooooooo`1Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0CKoo06SIobb1j002odbCl0?o
LYk/0on9ZNX2oibaiP;oW;W]1?n]_^L01Onj`^7o^l_Vok_;i_nkbnKoa/gO00?ob=GT0_o9g^P01OoB
g^7odnKTom?Vi?oCi^Cod^kV00;od?CW0_o<nNL2olKli@;o]_cN00Ko[O[JojGgeonOmMKoV_?Foh7X
e?n4j]X2ohW/hP03ohk^jOoooooooooo03Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo02gooooo0onX_NT3ojRnj@03ojNnjOoooooooooo05cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003ooooooooo
o`0Uooooo`03o`14/?l0HLko6WkV00?oC9?`0_m[Y?84ohJ`l@?oW;W]0_n]_^L2ojg7k@;o^l_V0onm
e>/00oo8eNCobMkXolWNj003olWWk004om?Vi?oBk^Kod?CWom3di`;oc?WW0_o6o>D2okKlgP07ojgj
f_n5jLgoPNS=oh3Wcon1j=CoM^?KogkWi00nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0]ooooo`?oZ;gY00?oZ;kYooooooooool0Goooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo000Sooooo`;o00009oooool00ol0?:3o
05W1o`Ejh002ocfDl@;oHJSg0_n6/?400on1]oOoV/7coi[1l`02oi[1l`;o[LO]0on]dO<2okgDj`;o
_Mk`00CobMkXolWWk?o9incobNO/0_o8knh01?o3m^ko_OW/okgik?o<nNL2olKli@06oikef_nDlMCo
Rng?ohGYcOmUf<CoJ=_:0_m/g]m1ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
:_ooool2o`0002gooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Wooooo000Uooooo`03o`000?oooooooooo02Kooooo00CoG`00o`1ce?l0LmCo;9C_
0omQZ?L2oh6gm`;oV/7c0_nGb_T3ojgAl`;oZm[h0_nmg_03ok_Wm004olWWk?o8knkob>o^ol?fkP;o
_OW/0_ncn^L01?nYnN7oW_GJof_La?mVf<42odk;_`03oe[Df_oooooooooo04;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo000Vooooo`03
o`000?oooooooooo02Oooooo0_l0Lm@2oaRAj0;oE:cj0omi__`3oiO:n@03ojgAlon[f_SoZm[h00?o
Y^?k0_nkio@2okO^m@04ok3cm?nUmNkoYOG^oiWbiP;oRnkL00?oO^OBogCQb_m4`k40B_ooool01Ol0
003ooooooooooooooooo000002oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1T
ooooo`05o`000?ooooooooooooooool000002oooool002Oooooo00?o0000ooooooooool0:?ooool0
0om[__ko066ao`B:f`03odB]n0?oK/Co0_nAd_h2ohOIo`;oY^?k0onNjO/01_ngk_Go/??dojGek_nU
mNkoVO;VoeSAa@;oC/ZkC_ooool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0IOooool01?l0003oooooooooool0000;ooooo`00:?ooool2o`0002So
oooo00Go0000ooooooooooooooooo`21b@03oc:[k`;oH<Kl0_n7fOl3og_Kn`;oW^Wk00GoT^_fohCX
k?n4j>coM>;Oobje/`1Cooooo`03o`000?oooooo0000037ooooo0_l0000Xooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooool000002oooool002[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`05ooooo`?o2i[=0_lk_N<2obVcd0;oFM;RF?ooool00ol0003oooooo`00000coooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;oooo
o`00:oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Oooooo00?o0000ooooool0
0000<oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Oooooo00?o0000ooooool0
00002_ooool002cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Xooooo`;o0000
=?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo0_l0000:ooooo`00;Ooo
ool2o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0003Gooooo0_l0000Sooooo`03o`000?oo
oooooooo06Oooooo0ol0000:ooooo`00;oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo06?ooooo1?l0000jooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hoooool4
o`0000gooooo000`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0H?ooool3o`00
03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool0037o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`Co0000@oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l0000Dooooo`00<_ooool2o`0001kooooo
00?o0000ooooooooool0F?ooool4o`0004Sooooo0_l0000Nooooo`03o`000?oooooooooo05Sooooo
1?l0000Hooooo`00=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Cooooo1?l0
001>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?ooool4o`0001cooooo000e
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3o`0005?ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o00008?ooool003Kooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1=ooooo`Co0000Eoooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo04gooooo1?l0000Sooooo`00=oooool2o`0001Wooooo00?o0000oooooooo
ool0BOooool4o`0005cooooo0_l0000Iooooo`03o`000?oooooooooo04Wooooo1?l0000Wooooo`00
>Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo1?l0001Rooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0002_ooooo000jooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0006Oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`13ooooo`?o0000;oooool003_ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0oooooo`Co0000Joooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo03oooooo1?l0000booooo`00??ooool2o`0001?ooooo00?o0000ooooooooool0>oooool4o`00
073ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000fooooo`00?_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0001fooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0=oooool4o`0003[ooooo000oooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0<oooool4o`0007_ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0cooooo`Co0000?_ooool0043ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0`ooooo`?o0000P?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo0ol0
0012ooooo`00@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l00024
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4o`0004Gooooo0012oooo
o`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000ROooool2o`0000gooooo00?o0000oooo
ooooool0:?ooool4o`0004Wooooo0014ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool09?ooool4o`0008oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`Co
0000COooool004Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`?o0000
U?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0001Aooooo`00A_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0002Hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0017ooooo`;o00002?ooool0
0ol0003oooooooooo`0Iooooo`Co0000WOooool2o`0000Sooooo00?o0000ooooooooool06Oooool4
o`0005Sooooo0019ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool4o`00
0:?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000G?ooool004[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000Z?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001Pooooo`00Boooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002/ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03_ooool4o`0006?ooooo001<ooooo`;o00000oooool00ol0003ooooooooo
o`0:ooooo`Co0000/Oooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`0006Oooooo001>
ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002gooooo`04o`000?ooooooooooo`0000Sooooo
1?l0001[ooooo`00Coooool00ol0003oooooo`000005ooooo`?o0000_?ooool00ol0003oooooo`00
0005ooooo`?o0000Koooool0053ooooo0_l000000ooooooo0000o`000002o`000<3ooooo0_l00000
0ooooooo0000o`000002o`0007;ooooo001Aooooo`;o0000aOooool2o`0007Kooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-0.209219, \
-0.0749526, 0.00708998, 0.00708998}, {{208.5, 389.375}, {315.688, 169}} -> \
{-1.61946, -0.0749526, 0.00708998, 0.00708998}, {{9.625, 190.438}, {154.375, \
7.6875}} -> {-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, \
389.375}, {154.375, 7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification of input space", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        GraphicsArray[{PlotTwoClassificationRegions[pdf1, pdf2, pr, x, 
              y, {class1Color, class2Color}, Axes \[Rule] False, 
              Frame \[Rule] True, nF, nS], idealPlot}], yS, \ 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.0098 .0098 m
.02863 .0098 L
.04917 .0098 L
.06845 .0098 L
.087 .0098 L
.10674 .0098 L
.12574 .0098 L
.14594 .0098 L
.1654 .0098 L
.18412 .0098 L
.20404 .0098 L
.22322 .0098 L
.24166 .0098 L
.26129 .0098 L
.28019 .0098 L
.30028 .0098 L
.31963 .0098 L
.33824 .0098 L
.35805 .0098 L
.37712 .0098 L
.39739 .0098 L
.41691 .0098 L
.4357 .0098 L
.45568 .0098 L
.47395 .0098 L
s
.0098 .9902 m
.02863 .9902 L
.04917 .9902 L
.06845 .9902 L
.087 .9902 L
.10674 .9902 L
.12574 .9902 L
.14594 .9902 L
.1654 .9902 L
.18412 .9902 L
.20404 .9902 L
.22322 .9902 L
.24166 .9902 L
.26129 .9902 L
.28019 .9902 L
.30028 .9902 L
.31963 .9902 L
.33824 .9902 L
.35805 .9902 L
.37712 .9902 L
.39739 .9902 L
.41691 .9902 L
.4357 .9902 L
.45568 .9902 L
.47395 .9902 L
s
1 1 .5 r
.0098 .0098 m
.02863 .0098 L
.04917 .0098 L
.06845 .0098 L
.087 .0098 L
.10674 .0098 L
.12574 .0098 L
.14594 .0098 L
.1654 .0098 L
.18412 .0098 L
.20404 .0098 L
.22322 .0098 L
.24166 .0098 L
.26129 .0098 L
.28019 .0098 L
.30028 .0098 L
.31963 .0098 L
.33824 .0098 L
.35805 .0098 L
.37712 .0098 L
.39739 .0098 L
.41691 .0098 L
.4357 .0098 L
.45568 .0098 L
.47395 .0098 L
.47395 .9902 L
.45568 .9902 L
.4357 .9902 L
.41691 .9902 L
.39739 .9902 L
.37712 .9902 L
.35805 .9902 L
.33824 .9902 L
.31963 .9902 L
.30028 .9902 L
.28019 .9902 L
.26129 .9902 L
.24166 .9902 L
.22322 .9902 L
.20404 .9902 L
.18412 .9902 L
.1654 .9902 L
.14594 .9902 L
.12574 .9902 L
.10674 .9902 L
.087 .9902 L
.06845 .9902 L
.04917 .9902 L
.02863 .9902 L
.0098 .9902 L
F
0 g
.0098 .0098 m
.02863 .0098 L
.04917 .0098 L
.06845 .0098 L
.087 .0098 L
.10674 .0098 L
.12574 .0098 L
.14594 .0098 L
.1654 .0098 L
.18412 .0098 L
.20404 .0098 L
.22322 .0098 L
.24166 .0098 L
.26129 .0098 L
.28019 .0098 L
.30028 .0098 L
.31963 .0098 L
.33824 .0098 L
.35805 .0098 L
.37712 .0098 L
.39739 .0098 L
.41691 .0098 L
.4357 .0098 L
.45568 .0098 L
.47395 .0098 L
s
.0098 .9902 m
.02863 .9902 L
.04917 .9902 L
.06845 .9902 L
.087 .9902 L
.10674 .9902 L
.12574 .9902 L
.14594 .9902 L
.1654 .9902 L
.18412 .9902 L
.20404 .9902 L
.22322 .9902 L
.24166 .9902 L
.26129 .9902 L
.28019 .9902 L
.30028 .9902 L
.31963 .9902 L
.33824 .9902 L
.35805 .9902 L
.37712 .9902 L
.39739 .9902 L
.41691 .9902 L
.4357 .9902 L
.45568 .9902 L
.47395 .9902 L
s
.47395 .0098 m
.47893 .0098 L
.48436 .0098 L
.48946 .0098 L
.49437 .0098 L
.49959 .0098 L
.50462 .0098 L
.50996 .0098 L
.51511 .0098 L
.52006 .0098 L
.52533 .0098 L
.53041 .0098 L
.53528 .0098 L
.54048 .0098 L
.54548 .0098 L
.55079 .0098 L
.55591 .0098 L
.56084 .0098 L
.56608 .0098 L
.57112 .0098 L
.57648 .0098 L
.58165 .0098 L
.58662 .0098 L
.59191 .0098 L
.59674 .0098 L
s
.47395 .45878 m
.4741 .44284 L
.47424 .43671 L
.47455 .427 L
.47511 .4146 L
.47576 .40354 L
.47637 .39482 L
.47893 .36715 L
.48153 .34575 L
.48436 .32642 L
.48963 .29648 L
.4947 .27221 L
.49958 .25158 L
.50478 .23171 L
.50978 .21415 L
.51509 .19679 L
.52021 .18114 L
.52513 .16689 L
.53037 .15249 L
.53542 .13926 L
.54078 .12581 L
.54595 .11336 L
.55092 .10181 L
.5562 .08994 L
.56129 .07889 L
.56619 .06857 L
.5714 .05789 L
.57642 .04789 L
.58175 .03754 L
.58689 .02781 L
.59183 .01868 L
.59674 .0098 L
s
1 1 .5 r
.47395 .0098 m
.47893 .0098 L
.48436 .0098 L
.48946 .0098 L
.49437 .0098 L
.49959 .0098 L
.50462 .0098 L
.50996 .0098 L
.51511 .0098 L
.52006 .0098 L
.52533 .0098 L
.53041 .0098 L
.53528 .0098 L
.54048 .0098 L
.54548 .0098 L
.55079 .0098 L
.55591 .0098 L
.56084 .0098 L
.56608 .0098 L
.57112 .0098 L
.57648 .0098 L
.58165 .0098 L
.58662 .0098 L
.59191 .0098 L
.59674 .0098 L
.59674 .0098 L
.59183 .01868 L
.58689 .02781 L
.58175 .03754 L
.57642 .04789 L
.5714 .05789 L
.56619 .06857 L
.56129 .07889 L
.5562 .08994 L
.55092 .10181 L
.54595 .11336 L
.54078 .12581 L
.53542 .13926 L
.53037 .15249 L
.52513 .16689 L
.52021 .18114 L
.51509 .19679 L
.50978 .21415 L
.50478 .23171 L
.49958 .25158 L
.4947 .27221 L
.48963 .29648 L
.48436 .32642 L
.48153 .34575 L
.47893 .36715 L
.47637 .39482 L
.47576 .40354 L
.47511 .4146 L
.47455 .427 L
.47424 .43671 L
.4741 .44284 L
.47395 .45878 L
F
0 g
.47395 .0098 m
.47893 .0098 L
.48436 .0098 L
.48946 .0098 L
.49437 .0098 L
.49959 .0098 L
.50462 .0098 L
.50996 .0098 L
.51511 .0098 L
.52006 .0098 L
.52533 .0098 L
.53041 .0098 L
.53528 .0098 L
.54048 .0098 L
.54548 .0098 L
.55079 .0098 L
.55591 .0098 L
.56084 .0098 L
.56608 .0098 L
.57112 .0098 L
.57648 .0098 L
.58165 .0098 L
.58662 .0098 L
.59191 .0098 L
.59674 .0098 L
s
.47395 .45878 m
.4741 .44284 L
.47424 .43671 L
.47455 .427 L
.47511 .4146 L
.47576 .40354 L
.47637 .39482 L
.47893 .36715 L
.48153 .34575 L
.48436 .32642 L
.48963 .29648 L
.4947 .27221 L
.49958 .25158 L
.50478 .23171 L
.50978 .21415 L
.51509 .19679 L
.52021 .18114 L
.52513 .16689 L
.53037 .15249 L
.53542 .13926 L
.54078 .12581 L
.54595 .11336 L
.55092 .10181 L
.5562 .08994 L
.56129 .07889 L
.56619 .06857 L
.5714 .05789 L
.57642 .04789 L
.58175 .03754 L
.58689 .02781 L
.59183 .01868 L
.59674 .0098 L
s
.59674 .91848 m
.59841 .92161 L
.60024 .92499 L
.60195 .92815 L
.6036 .93117 L
.60535 .93436 L
.60704 .93741 L
.60884 .94063 L
.61057 .94371 L
.61223 .94666 L
.614 .94978 L
.6157 .95276 L
.61734 .95561 L
.61909 .95863 L
.62077 .96151 L
.62255 .96456 L
.62427 .96748 L
.62593 .97028 L
.62769 .97323 L
.62938 .97606 L
.63118 .97905 L
.63292 .98192 L
.63459 .98466 L
.63637 .98756 L
.63799 .9902 L
s
.59674 .9902 m
.59841 .9902 L
.60024 .9902 L
.60195 .9902 L
.6036 .9902 L
.60535 .9902 L
.60704 .9902 L
.60884 .9902 L
.61057 .9902 L
.61223 .9902 L
.614 .9902 L
.6157 .9902 L
.61734 .9902 L
.61909 .9902 L
.62077 .9902 L
.62255 .9902 L
.62427 .9902 L
.62593 .9902 L
.62769 .9902 L
.62938 .9902 L
.63118 .9902 L
.63292 .9902 L
.63459 .9902 L
.63637 .9902 L
.63799 .9902 L
s
1 1 .5 r
.59674 .91848 m
.59841 .92161 L
.60024 .92499 L
.60195 .92815 L
.6036 .93117 L
.60535 .93436 L
.60704 .93741 L
.60884 .94063 L
.61057 .94371 L
.61223 .94666 L
.614 .94978 L
.6157 .95276 L
.61734 .95561 L
.61909 .95863 L
.62077 .96151 L
.62255 .96456 L
.62427 .96748 L
.62593 .97028 L
.62769 .97323 L
.62938 .97606 L
.63118 .97905 L
.63292 .98192 L
.63459 .98466 L
.63637 .98756 L
.63799 .9902 L
.63799 .9902 L
.63637 .9902 L
.63459 .9902 L
.63292 .9902 L
.63118 .9902 L
.62938 .9902 L
.62769 .9902 L
.62593 .9902 L
.62427 .9902 L
.62255 .9902 L
.62077 .9902 L
.61909 .9902 L
.61734 .9902 L
.6157 .9902 L
.614 .9902 L
.61223 .9902 L
.61057 .9902 L
.60884 .9902 L
.60704 .9902 L
.60535 .9902 L
.6036 .9902 L
.60195 .9902 L
.60024 .9902 L
.59841 .9902 L
.59674 .9902 L
F
0 g
.59674 .91848 m
.59841 .92161 L
.60024 .92499 L
.60195 .92815 L
.6036 .93117 L
.60535 .93436 L
.60704 .93741 L
.60884 .94063 L
.61057 .94371 L
.61223 .94666 L
.614 .94978 L
.6157 .95276 L
.61734 .95561 L
.61909 .95863 L
.62077 .96151 L
.62255 .96456 L
.62427 .96748 L
.62593 .97028 L
.62769 .97323 L
.62938 .97606 L
.63118 .97905 L
.63292 .98192 L
.63459 .98466 L
.63637 .98756 L
.63799 .9902 L
s
.59674 .9902 m
.59841 .9902 L
.60024 .9902 L
.60195 .9902 L
.6036 .9902 L
.60535 .9902 L
.60704 .9902 L
.60884 .9902 L
.61057 .9902 L
.61223 .9902 L
.614 .9902 L
.6157 .9902 L
.61734 .9902 L
.61909 .9902 L
.62077 .9902 L
.62255 .9902 L
.62427 .9902 L
.62593 .9902 L
.62769 .9902 L
.62938 .9902 L
.63118 .9902 L
.63292 .9902 L
.63459 .9902 L
.63637 .9902 L
.63799 .9902 L
s
.47395 .45896 m
.4741 .47492 L
.47424 .48105 L
.47455 .49078 L
.47511 .50324 L
.47576 .51436 L
.47637 .52312 L
.47893 .55102 L
.48153 .57264 L
.48436 .59222 L
.48963 .6226 L
.4947 .64731 L
.49958 .66836 L
.50478 .68867 L
.50978 .70667 L
.51509 .72448 L
.52021 .74057 L
.52513 .75524 L
.53037 .77009 L
.53542 .78375 L
.54078 .79767 L
.54595 .81056 L
.55092 .82254 L
.5562 .83486 L
.56129 .84635 L
.56619 .85709 L
.5714 .86822 L
.57642 .87865 L
.58175 .88946 L
.58689 .89962 L
.59183 .90918 L
.59674 .91848 L
s
.47395 .9902 m
.47893 .9902 L
.48436 .9902 L
.48946 .9902 L
.49437 .9902 L
.49959 .9902 L
.50462 .9902 L
.50996 .9902 L
.51511 .9902 L
.52006 .9902 L
.52533 .9902 L
.53041 .9902 L
.53528 .9902 L
.54048 .9902 L
.54548 .9902 L
.55079 .9902 L
.55591 .9902 L
.56084 .9902 L
.56608 .9902 L
.57112 .9902 L
.57648 .9902 L
.58165 .9902 L
.58662 .9902 L
.59191 .9902 L
.59674 .9902 L
s
1 1 .5 r
.47395 .45896 m
.4741 .47492 L
.47424 .48105 L
.47455 .49078 L
.47511 .50324 L
.47576 .51436 L
.47637 .52312 L
.47893 .55102 L
.48153 .57264 L
.48436 .59222 L
.48963 .6226 L
.4947 .64731 L
.49958 .66836 L
.50478 .68867 L
.50978 .70667 L
.51509 .72448 L
.52021 .74057 L
.52513 .75524 L
.53037 .77009 L
.53542 .78375 L
.54078 .79767 L
.54595 .81056 L
.55092 .82254 L
.5562 .83486 L
.56129 .84635 L
.56619 .85709 L
.5714 .86822 L
.57642 .87865 L
.58175 .88946 L
.58689 .89962 L
.59183 .90918 L
.59674 .91848 L
.59674 .9902 L
.59191 .9902 L
.58662 .9902 L
.58165 .9902 L
.57648 .9902 L
.57112 .9902 L
.56608 .9902 L
.56084 .9902 L
.55591 .9902 L
.55079 .9902 L
.54548 .9902 L
.54048 .9902 L
.53528 .9902 L
.53041 .9902 L
.52533 .9902 L
.52006 .9902 L
.51511 .9902 L
.50996 .9902 L
.50462 .9902 L
.49959 .9902 L
.49437 .9902 L
.48946 .9902 L
.48436 .9902 L
.47893 .9902 L
.47395 .9902 L
F
0 g
.47395 .45896 m
.4741 .47492 L
.47424 .48105 L
.47455 .49078 L
.47511 .50324 L
.47576 .51436 L
.47637 .52312 L
.47893 .55102 L
.48153 .57264 L
.48436 .59222 L
.48963 .6226 L
.4947 .64731 L
.49958 .66836 L
.50478 .68867 L
.50978 .70667 L
.51509 .72448 L
.52021 .74057 L
.52513 .75524 L
.53037 .77009 L
.53542 .78375 L
.54078 .79767 L
.54595 .81056 L
.55092 .82254 L
.5562 .83486 L
.56129 .84635 L
.56619 .85709 L
.5714 .86822 L
.57642 .87865 L
.58175 .88946 L
.58689 .89962 L
.59183 .90918 L
.59674 .91848 L
s
.47395 .9902 m
.47893 .9902 L
.48436 .9902 L
.48946 .9902 L
.49437 .9902 L
.49959 .9902 L
.50462 .9902 L
.50996 .9902 L
.51511 .9902 L
.52006 .9902 L
.52533 .9902 L
.53041 .9902 L
.53528 .9902 L
.54048 .9902 L
.54548 .9902 L
.55079 .9902 L
.55591 .9902 L
.56084 .9902 L
.56608 .9902 L
.57112 .9902 L
.57648 .9902 L
.58165 .9902 L
.58662 .9902 L
.59191 .9902 L
.59674 .9902 L
s
.59674 .0098 m
.59841 .0098 L
.60024 .0098 L
.60195 .0098 L
.6036 .0098 L
.60535 .0098 L
.60704 .0098 L
.60884 .0098 L
.61057 .0098 L
.61223 .0098 L
.614 .0098 L
.6157 .0098 L
.61734 .0098 L
.61909 .0098 L
.62077 .0098 L
.62255 .0098 L
.62427 .0098 L
.62593 .0098 L
.62769 .0098 L
.62938 .0098 L
.63118 .0098 L
.63292 .0098 L
.63459 .0098 L
.63637 .0098 L
.63799 .0098 L
s
.59674 .91848 m
.59841 .92161 L
.60024 .92499 L
.60195 .92815 L
.6036 .93117 L
.60535 .93436 L
.60704 .93741 L
.60884 .94063 L
.61057 .94371 L
.61223 .94666 L
.614 .94978 L
.6157 .95276 L
.61734 .95561 L
.61909 .95863 L
.62077 .96151 L
.62255 .96456 L
.62427 .96748 L
.62593 .97028 L
.62769 .97323 L
.62938 .97606 L
.63118 .97905 L
.63292 .98192 L
.63459 .98466 L
.63637 .98756 L
.63799 .9902 L
s
.5 1 1 r
.59674 .0098 m
.59841 .0098 L
.60024 .0098 L
.60195 .0098 L
.6036 .0098 L
.60535 .0098 L
.60704 .0098 L
.60884 .0098 L
.61057 .0098 L
.61223 .0098 L
.614 .0098 L
.6157 .0098 L
.61734 .0098 L
.61909 .0098 L
.62077 .0098 L
.62255 .0098 L
.62427 .0098 L
.62593 .0098 L
.62769 .0098 L
.62938 .0098 L
.63118 .0098 L
.63292 .0098 L
.63459 .0098 L
.63637 .0098 L
.63799 .0098 L
.63799 .9902 L
.63637 .98756 L
.63459 .98466 L
.63292 .98192 L
.63118 .97905 L
.62938 .97606 L
.62769 .97323 L
.62593 .97028 L
.62427 .96748 L
.62255 .96456 L
.62077 .96151 L
.61909 .95863 L
.61734 .95561 L
.6157 .95276 L
.614 .94978 L
.61223 .94666 L
.61057 .94371 L
.60884 .94063 L
.60704 .93741 L
.60535 .93436 L
.6036 .93117 L
.60195 .92815 L
.60024 .92499 L
.59841 .92161 L
.59674 .91848 L
F
0 g
.59674 .0098 m
.59841 .0098 L
.60024 .0098 L
.60195 .0098 L
.6036 .0098 L
.60535 .0098 L
.60704 .0098 L
.60884 .0098 L
.61057 .0098 L
.61223 .0098 L
.614 .0098 L
.6157 .0098 L
.61734 .0098 L
.61909 .0098 L
.62077 .0098 L
.62255 .0098 L
.62427 .0098 L
.62593 .0098 L
.62769 .0098 L
.62938 .0098 L
.63118 .0098 L
.63292 .0098 L
.63459 .0098 L
.63637 .0098 L
.63799 .0098 L
s
.59674 .91848 m
.59841 .92161 L
.60024 .92499 L
.60195 .92815 L
.6036 .93117 L
.60535 .93436 L
.60704 .93741 L
.60884 .94063 L
.61057 .94371 L
.61223 .94666 L
.614 .94978 L
.6157 .95276 L
.61734 .95561 L
.61909 .95863 L
.62077 .96151 L
.62255 .96456 L
.62427 .96748 L
.62593 .97028 L
.62769 .97323 L
.62938 .97606 L
.63118 .97905 L
.63292 .98192 L
.63459 .98466 L
.63637 .98756 L
.63799 .9902 L
s
.63799 .0098 m
.65228 .0098 L
.66786 .0098 L
.68249 .0098 L
.69657 .0098 L
.71155 .0098 L
.72597 .0098 L
.7413 .0098 L
.75606 .0098 L
.77027 .0098 L
.78538 .0098 L
.79993 .0098 L
.81393 .0098 L
.82883 .0098 L
.84316 .0098 L
.85841 .0098 L
.87309 .0098 L
.88722 .0098 L
.90225 .0098 L
.91672 .0098 L
.9321 .0098 L
.94692 .0098 L
.96117 .0098 L
.97634 .0098 L
.9902 .0098 L
s
.63799 .9902 m
.65228 .9902 L
.66786 .9902 L
.68249 .9902 L
.69657 .9902 L
.71155 .9902 L
.72597 .9902 L
.7413 .9902 L
.75606 .9902 L
.77027 .9902 L
.78538 .9902 L
.79993 .9902 L
.81393 .9902 L
.82883 .9902 L
.84316 .9902 L
.85841 .9902 L
.87309 .9902 L
.88722 .9902 L
.90225 .9902 L
.91672 .9902 L
.9321 .9902 L
.94692 .9902 L
.96117 .9902 L
.97634 .9902 L
.9902 .9902 L
s
.5 1 1 r
.63799 .0098 m
.65228 .0098 L
.66786 .0098 L
.68249 .0098 L
.69657 .0098 L
.71155 .0098 L
.72597 .0098 L
.7413 .0098 L
.75606 .0098 L
.77027 .0098 L
.78538 .0098 L
.79993 .0098 L
.81393 .0098 L
.82883 .0098 L
.84316 .0098 L
.85841 .0098 L
.87309 .0098 L
.88722 .0098 L
.90225 .0098 L
.91672 .0098 L
.9321 .0098 L
.94692 .0098 L
.96117 .0098 L
.97634 .0098 L
.9902 .0098 L
.9902 .9902 L
.97634 .9902 L
.96117 .9902 L
.94692 .9902 L
.9321 .9902 L
.91672 .9902 L
.90225 .9902 L
.88722 .9902 L
.87309 .9902 L
.85841 .9902 L
.84316 .9902 L
.82883 .9902 L
.81393 .9902 L
.79993 .9902 L
.78538 .9902 L
.77027 .9902 L
.75606 .9902 L
.7413 .9902 L
.72597 .9902 L
.71155 .9902 L
.69657 .9902 L
.68249 .9902 L
.66786 .9902 L
.65228 .9902 L
.63799 .9902 L
F
0 g
.63799 .0098 m
.65228 .0098 L
.66786 .0098 L
.68249 .0098 L
.69657 .0098 L
.71155 .0098 L
.72597 .0098 L
.7413 .0098 L
.75606 .0098 L
.77027 .0098 L
.78538 .0098 L
.79993 .0098 L
.81393 .0098 L
.82883 .0098 L
.84316 .0098 L
.85841 .0098 L
.87309 .0098 L
.88722 .0098 L
.90225 .0098 L
.91672 .0098 L
.9321 .0098 L
.94692 .0098 L
.96117 .0098 L
.97634 .0098 L
.9902 .0098 L
s
.63799 .9902 m
.65228 .9902 L
.66786 .9902 L
.68249 .9902 L
.69657 .9902 L
.71155 .9902 L
.72597 .9902 L
.7413 .9902 L
.75606 .9902 L
.77027 .9902 L
.78538 .9902 L
.79993 .9902 L
.81393 .9902 L
.82883 .9902 L
.84316 .9902 L
.85841 .9902 L
.87309 .9902 L
.88722 .9902 L
.90225 .9902 L
.91672 .9902 L
.9321 .9902 L
.94692 .9902 L
.96117 .9902 L
.97634 .9902 L
.9902 .9902 L
s
.47395 .45878 m
.4741 .44284 L
.47424 .43671 L
.47455 .427 L
.47511 .4146 L
.47576 .40354 L
.47637 .39482 L
.47893 .36715 L
.48153 .34575 L
.48436 .32642 L
.48963 .29648 L
.4947 .27221 L
.49958 .25158 L
.50478 .23171 L
.50978 .21415 L
.51509 .19679 L
.52021 .18114 L
.52513 .16689 L
.53037 .15249 L
.53542 .13926 L
.54078 .12581 L
.54595 .11336 L
.55092 .10181 L
.5562 .08994 L
.56129 .07889 L
.56619 .06857 L
.5714 .05789 L
.57642 .04789 L
.58175 .03754 L
.58689 .02781 L
.59183 .01868 L
.59674 .0098 L
s
.47395 .45896 m
.4741 .47492 L
.47424 .48105 L
.47455 .49078 L
.47511 .50324 L
.47576 .51436 L
.47637 .52312 L
.47893 .55102 L
.48153 .57264 L
.48436 .59222 L
.48963 .6226 L
.4947 .64731 L
.49958 .66836 L
.50478 .68867 L
.50978 .70667 L
.51509 .72448 L
.52021 .74057 L
.52513 .75524 L
.53037 .77009 L
.53542 .78375 L
.54078 .79767 L
.54595 .81056 L
.55092 .82254 L
.5562 .83486 L
.56129 .84635 L
.56619 .85709 L
.5714 .86822 L
.57642 .87865 L
.58175 .88946 L
.58689 .89962 L
.59183 .90918 L
.59674 .91848 L
s
.5 1 1 r
.47395 .45878 m
.4741 .44284 L
.47424 .43671 L
.47455 .427 L
.47511 .4146 L
.47576 .40354 L
.47637 .39482 L
.47893 .36715 L
.48153 .34575 L
.48436 .32642 L
.48963 .29648 L
.4947 .27221 L
.49958 .25158 L
.50478 .23171 L
.50978 .21415 L
.51509 .19679 L
.52021 .18114 L
.52513 .16689 L
.53037 .15249 L
.53542 .13926 L
.54078 .12581 L
.54595 .11336 L
.55092 .10181 L
.5562 .08994 L
.56129 .07889 L
.56619 .06857 L
.5714 .05789 L
.57642 .04789 L
.58175 .03754 L
.58689 .02781 L
.59183 .01868 L
.59674 .0098 L
.59674 .91848 L
.59183 .90918 L
.58689 .89962 L
.58175 .88946 L
.57642 .87865 L
.5714 .86822 L
.56619 .85709 L
.56129 .84635 L
.5562 .83486 L
.55092 .82254 L
.54595 .81056 L
.54078 .79767 L
.53542 .78375 L
.53037 .77009 L
.52513 .75524 L
.52021 .74057 L
.51509 .72448 L
.50978 .70667 L
.50478 .68867 L
.49958 .66836 L
.4947 .64731 L
.48963 .6226 L
.48436 .59222 L
.48153 .57264 L
.47893 .55102 L
.47637 .52312 L
.47576 .51436 L
.47511 .50324 L
.47455 .49078 L
.47424 .48105 L
.4741 .47492 L
.47395 .45896 L
F
0 g
.47395 .45878 m
.4741 .44284 L
.47424 .43671 L
.47455 .427 L
.47511 .4146 L
.47576 .40354 L
.47637 .39482 L
.47893 .36715 L
.48153 .34575 L
.48436 .32642 L
.48963 .29648 L
.4947 .27221 L
.49958 .25158 L
.50478 .23171 L
.50978 .21415 L
.51509 .19679 L
.52021 .18114 L
.52513 .16689 L
.53037 .15249 L
.53542 .13926 L
.54078 .12581 L
.54595 .11336 L
.55092 .10181 L
.5562 .08994 L
.56129 .07889 L
.56619 .06857 L
.5714 .05789 L
.57642 .04789 L
.58175 .03754 L
.58689 .02781 L
.59183 .01868 L
.59674 .0098 L
s
.47395 .45896 m
.4741 .47492 L
.47424 .48105 L
.47455 .49078 L
.47511 .50324 L
.47576 .51436 L
.47637 .52312 L
.47893 .55102 L
.48153 .57264 L
.48436 .59222 L
.48963 .6226 L
.4947 .64731 L
.49958 .66836 L
.50478 .68867 L
.50978 .70667 L
.51509 .72448 L
.52021 .74057 L
.52513 .75524 L
.53037 .77009 L
.53542 .78375 L
.54078 .79767 L
.54595 .81056 L
.55092 .82254 L
.5562 .83486 L
.56129 .84635 L
.56619 .85709 L
.5714 .86822 L
.57642 .87865 L
.58175 .88946 L
.58689 .89962 L
.59183 .90918 L
.59674 .91848 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 1 .5 r
.02381 .02381 m
.02381 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.5 1 1 r
.78571 .02381 m
.78571 .97619 L
.97619 .97619 L
.97619 .02381 L
F
.21429 .59524 m
.21429 .78571 L
.78571 .78571 L
.78571 .59524 L
F
.21429 .21429 m
.21429 .40476 L
.78571 .40476 L
.78571 .21429 L
F
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_oooonco`000003
ooooool0003ooooo013ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol00000oomo0?ooO`1W0?ooO`03o`00001oool0Oooo04D0Oooo0_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
00000?ooO`3oogl0I`3oogl00ol00000Oooo07ooo`1507ooo`;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo06H0oomo00?o000007ooo`1oool0AP1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0IP3oogl00ol00000Oooo07ooo`1607ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1U0?ooO`03o`00001oool0Oooo04L0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo06D0oomo00?o000007ooo`1oool0A`1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0I@3oogl00ol00000Oooo07ooo`1707ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1T0?ooO`03o`00001oool0Oooo04P0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo06@0oomo00?o000007ooo`1oool0B01oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0H`3oogl00ol00000Oooo07ooo`19
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1S0?ooO`03o`00001oool0
Oooo04T0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0680oomo00?o0000
07ooo`1oool0BP1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0HP3oogl0
0ol00000Oooo07ooo`1:07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1Q
0?ooO`03o`00001oool0Oooo04/0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0640oomo00?o000007ooo`1oool0B`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0H03oogl00ol00000Oooo07ooo`1<07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1P0?ooO`03o`00001oool0Oooo04`0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05l0oomo00?o000007ooo`1oool0C@1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0G`3oogl00ol00000Oooo07ooo`1=07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1N0?ooO`03o`00001oool0Oooo04h0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05h0oomo00?o000007ooo`1oool0CP1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0G@3oogl00ol00000Oooo07ooo`1?
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1M0?ooO`03o`00001oool0
Oooo04l0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05d0oomo00?o0000
07ooo`1oool0C`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0G03oogl0
0ol00000Oooo07ooo`1@07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1L
0?ooO`03o`00001oool0Oooo0500Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05/0oomo00?o000007ooo`1oool0D@1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0F`3oogl00ol00000Oooo07ooo`1A07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1K0?ooO`03o`00001oool0Oooo0540Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05X0oomo00?o000007ooo`1oool0DP1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0FP3oogl00ol00000Oooo07ooo`1B07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1I0?ooO`03o`00001oool0Oooo05<0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05T0oomo00?o000007ooo`1oool0D`1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0F@3oogl00ol00000Oooo07ooo`1C
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1I0?ooO`03o`00001oool0
Oooo05<0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05T0oomo00?o0000
07ooo`1oool0D`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0F@3oogl0
0ol00000Oooo07ooo`1C07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1H
0?ooO`03o`00001oool0Oooo05@0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05P0oomo00?o000007ooo`1oool0E01oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0F03oogl00ol00000Oooo07ooo`1D07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1H0?ooO`03o`00001oool0Oooo05@0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05L0oomo00?o000007ooo`1oool0E@1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0E`3oogl00ol00000Oooo07ooo`1E07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1G0?ooO`03o`00001oool0Oooo05D0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05L0oomo00?o000007ooo`1oool0E@1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0EP3oogl00ol00000Oooo07ooo`1F
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1F0?ooO`03o`00001oool0
Oooo05H0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05H0oomo00?o0000
07ooo`1oool0EP1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8ooo
ogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0EP3oogl0
0ol00000Oooo07ooo`1F07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1E
0?ooO`03o`00001oool0Oooo05L0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05D0oomo00?o000007ooo`1oool0E`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0E@3oogl00ol00000Oooo07ooo`1G07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1E0?ooO`03o`00001oool0Oooo05L0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05D0oomo00?o000007ooo`1oool0E`1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0E03oogl00ol00000Oooo07ooo`1H07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1D0?ooO`03o`00001oool0Oooo05P0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05@0oomo00?o000007ooo`1oool0F01oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0E03oogl00ol00000Oooo07ooo`1H
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1C0?ooO`03o`00001oool0
Oooo05T0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05<0oomo00?o0000
07ooo`1oool0F@1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8ooo
ogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0D`3oogl0
0ol00000Oooo07ooo`1I07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1C
0?ooO`03o`00001oool0Oooo05T0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05<0oomo00?o000007ooo`1oool0F@1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0D`3oogl00ol00000Oooo07ooo`1I07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1C0?ooO`03o`00001oool0Oooo05T0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05<0oomo00?o000007ooo`1oool0F@1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0DP3oogl00ol00000Oooo07ooo`1J07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1B0?ooO`03o`00001oool0Oooo05X0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0580oomo00?o000007ooo`1oool0FP1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0DP3oogl00ol00000Oooo07ooo`1J
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1B0?ooO`03o`00001oool0
Oooo05X0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0580oomo00?o0000
07ooo`1oool0FP1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0DP3oogl0
0ol00000Oooo07ooo`1J07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1B
0?ooO`03o`00001oool0Oooo05X0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0580oomo00?o000007ooo`1oool0FP1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0DP3oogl00ol00000Oooo07ooo`1J07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1B0?ooO`03o`00001oool0Oooo05X0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0580oomo00?o000007ooo`1oool0FP1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0DP3oogl00ol00000Oooo07ooo`1J07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1B0?ooO`03o`00001oool0Oooo05X0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0580oomo00?o000007ooo`1oool0FP1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0DP3oogl00ol00000Oooo07ooo`1J
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1B0?ooO`03o`00001oool0
Oooo05X0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0580oomo00?o0000
07ooo`1oool0FP1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0DP3oogl0
0ol00000Oooo07ooo`1J07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1B
0?ooO`03o`00001oool0Oooo05X0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0580oomo00?o000007ooo`1oool0FP1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0DP3oogl00ol00000Oooo07ooo`1J07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1B0?ooO`03o`00001oool0Oooo05X0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0580oomo00?o000007ooo`1oool0FP1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0DP3oogl00ol00000Oooo07ooo`1J07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1B0?ooO`03o`00001oool0Oooo05X0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo0580oomo00?o000007ooo`1oool0FP1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0DP3oogl00ol00000Oooo07ooo`1J
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1C0?ooO`03o`00001oool0
Oooo05T0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05<0oomo00?o0000
07ooo`1oool0F@1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0D`3oogl0
0ol00000Oooo07ooo`1I07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1C
0?ooO`03o`00001oool0Oooo05T0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05<0oomo00?o000007ooo`1oool0F@1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0D`3oogl00ol00000Oooo07ooo`1I07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1C0?ooO`03o`00001oool0Oooo05T0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05<0oomo00?o000007ooo`1oool0F@1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0E03oogl00ol00000Oooo07ooo`1H07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1D0?ooO`03o`00001oool0Oooo05P0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05@0oomo00?o000007ooo`1oool0F01oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0E03oogl00ol00000Oooo07ooo`1H
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1D0?ooO`03o`00001oool0
Oooo05P0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05D0oomo00?o0000
07ooo`1oool0E`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8ooo
ogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0E@3oogl0
0ol00000Oooo07ooo`1G07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1E
0?ooO`03o`00001oool0Oooo05L0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05D0oomo00?o000007ooo`1oool0E`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0E@3oogl00ol00000Oooo07ooo`1G07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1F0?ooO`03o`00001oool0Oooo05H0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05H0oomo00?o000007ooo`1oool0EP1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0EP3oogl00ol00000Oooo07ooo`1F07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1F0?ooO`03o`00001oool0Oooo05H0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05L0oomo00?o000007ooo`1oool0E@1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0E`3oogl00ol00000Oooo07ooo`1E
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1G0?ooO`03o`00001oool0
Oooo05D0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05L0oomo00?o0000
07ooo`1oool0E@1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8ooo
ogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0F03oogl0
0ol00000Oooo07ooo`1D07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1H
0?ooO`03o`00001oool0Oooo05@0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05P0oomo00?o000007ooo`1oool0E01oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0F@3oogl00ol00000Oooo07ooo`1C07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1I0?ooO`03o`00001oool0Oooo05<0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05T0oomo00?o000007ooo`1oool0D`1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0F@3oogl00ol00000Oooo07ooo`1C07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1I0?ooO`03o`00001oool0Oooo05<0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05T0oomo00?o000007ooo`1oool0D`1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0FP3oogl00ol00000Oooo07ooo`1B
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1J0?ooO`03o`00001oool0
Oooo0580Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooooooob?ooomoROmo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05X0oomo00?o0000
07ooo`1oool0DP1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooooooo8ooo
ogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0F`3oogl0
0ol00000Oooo07ooo`1A07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1K
0?ooO`03o`00001oool0Oooo0540Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
ooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo05/0oomo00?o000007ooo`1oool0D@1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0G03oogl00ol00000Oooo07ooo`1@07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1L0?ooO`03o`00001oool0Oooo0500Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooooooob?ooomoROmoool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo05d0oomo00?o000007ooo`1oool0C`1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000oooooooooooooooo8oooogn9ogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0G@3oogl00ol00000Oooo07ooo`1?07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooolSooooOhWoOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1M0?ooO`03o`00001oool0Oooo04l0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05h0oomo00?o000007ooo`1oool0CP1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0GP3oogl00ol00000Oooo07ooo`1>
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1O0?ooO`03o`00001oool0
Oooo04d0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo05l0oomo00?o0000
07ooo`1oool0C@1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0G`3oogl0
0ol00000Oooo07ooo`1=07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1P
0?ooO`03o`00001oool0Oooo04`0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo0600oomo00?o000007ooo`1oool0C01oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0H@3oogl00ol00000Oooo07ooo`1;07ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1Q0?ooO`03o`00001oool0Oooo04/0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo0680oomo00?o000007ooo`1oool0BP1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0HP3oogl00ol00000Oooo07ooo`1:07ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1S0?ooO`03o`00001oool0Oooo04T0Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo06<0oomo00?o000007ooo`1oool0B@1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0I03oogl00ol00000Oooo07ooo`18
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1T0?ooO`03o`00001oool0
Oooo04P0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo06D0oomo00?o0000
07ooo`1oool0A`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0I@3oogl0
0ol00000Oooo07ooo`1707ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooo
oon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1U
0?ooO`03o`00001oool0Oooo04L0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooo
oooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0
oomo06D0oomo00?o000007ooo`1oool0A`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000
ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
0?ooO`3oogl0IP3oogl00ol00000Oooo07ooo`1607ooo`;ooooo00?o0000ooooooooool03oooool0
1?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol00000oomo0?ooO`1V0?ooO`03o`00001oool0Oooo04H0Oooo0_ooool00ol0003oooooooooo`0?
ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`00003oogl0oomo06L0oomo00?o000007ooo`1oool0A@1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0J03oogl00ol00000Oooo07ooo`1407ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1X0?ooO`;o0000A@1oool2ooooo`03o`000?oooooo
oooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o00000?ooO`3oogl0J@3oogl00ol00000Oooo07ooo`1307ooo`;ooooo00?o0000
ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol00000oomo0?ooO`1Z0?ooO`03o`00001oool0Oooo0480Oooo0_ooool0
0ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_moool4ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`00003oogl0oomo06X0oomo00?o000007ooo`1oool0@P1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0J`3oogl00ol00000Oooo07ooo`11
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1[0?ooO`;o0000@P1oool2
ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oooglRogooo`Cooooo00?o
0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0K03oogl00ol00000Oooo07ooo`10
07ooo`;ooooo00?o0000ooooooooool03oooool01?l0003ooooooooooooooon:ooooOb;oOooo1?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol00000oomo0?ooO`1]0?ooO`03o`00001oool0
Oooo03l0Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo06d0oomo00?o0000
07ooo`1oool0?`1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0K@3oogl2
o`000400Oooo0_ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooooooooh[ooomo8_mo
ool4ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00003oogl0oomo06h0oomo00?o0000
07ooo`1oool0?P1oool2ooooo`03o`000?oooooooooo00oooooo00Co0000ooooooooooooooooR_oo
oglRogooo`Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o00000?ooO`3oogl0K`3oogl0
0ol00000Oooo07ooo`0m07ooo`;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2a
ooooo`03o`000?oooooooooo00Wooooo000:oooook?o000000?oooooo`000?ooool04?ooool00ol0
003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wo
oooo000:oooookGo00004Oooooneo`0000_ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-0.0557921, \
-0.0252998, 0.00554406, 0.00554406}, {{10.0625, 190.438}, {184.875, 4.5}} -> \
{-0.0676948, -0.0365494, 0.00566279, 0.00566279}, {{10.0625, 190.438}, \
{184.875, 4.5}} -> {-0.0676948, -0.0365494, 0.00566279, 0.00566279}, {{208.5, \
388.938}, {184.875, 4.5}} -> {-1.24073, -0.0521387, 0.00582732, 0.00582732}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{693, 550},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 63, 0, 62, "Title"],
Cell[1820, 53, 272, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[2117, 63, 42, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2184, 67, 53, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2262, 71, 36, 0, 43, "Subsubsection"],
Cell[2301, 73, 166, 4, 63, "Input"],
Cell[2470, 79, 174, 3, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2681, 87, 53, 0, 43, "Subsubsection"],
Cell[2737, 89, 207, 4, 63, "Input"],
Cell[2947, 95, 84, 1, 47, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3080, 102, 40, 0, 49, "Subsection"],
Cell[3123, 104, 63, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3223, 110, 36, 0, 49, "Subsection"],
Cell[3262, 112, 130, 2, 63, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3441, 120, 68, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3534, 124, 77, 0, 49, "Subsection"],
Cell[3614, 126, 893, 17, 255, "Input"],
Cell[4510, 145, 857, 17, 255, "Input"],

Cell[CellGroupData[{
Cell[5392, 166, 50, 0, 43, "Subsubsection"],
Cell[5445, 168, 613, 9, 159, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6095, 182, 65, 0, 43, "Subsubsection"],
Cell[6163, 184, 1094, 18, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7294, 207, 43, 0, 43, "Subsubsection"],
Cell[7340, 209, 299, 6, 79, "Input"],
Cell[7642, 217, 628, 10, 175, "Input"],
Cell[8273, 229, 296, 5, 95, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8618, 240, 44, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[8687, 244, 70, 1, 47, "Input"],
Cell[8760, 247, 21390, 327, 296, 893, 69, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30199, 580, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[30284, 584, 55, 0, 43, "Subsubsection"],
Cell[30342, 586, 159, 4, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30538, 595, 39, 0, 43, "Subsubsection"],
Cell[30580, 597, 160, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30777, 604, 39, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[30841, 608, 251, 5, 79, "Input"],
Cell[31095, 615, 131994, 3219, 296, 38290, 2058, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[163150, 3841, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[163235, 3845, 46, 0, 43, "Subsubsection"],
Cell[163284, 3847, 147, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163468, 3854, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[163536, 3858, 91, 1, 47, "Input"],
Cell[163630, 3861, 477314, 12034, 333, 293547, 9762, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[641005, 15902, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[641081, 15906, 260, 5, 111, "Input"],
Cell[641344, 15913, 56248, 1979, 199, 23377, 1570, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[697653, 17899, 68, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[697746, 17903, 55, 0, 49, "Subsection"],
Cell[697804, 17905, 325, 6, 127, "Input"],
Cell[698132, 17913, 291, 5, 127, "Input"],
Cell[698426, 17920, 441, 9, 175, "Input"],
Cell[698870, 17931, 433, 8, 175, "Input"],
Cell[699306, 17941, 76, 1, 47, "Input"],
Cell[699385, 17944, 267, 5, 95, "Input"],
Cell[699655, 17951, 275, 5, 111, "Input"],
Cell[699933, 17958, 393, 6, 159, "Input"],
Cell[700329, 17966, 386, 7, 127, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[700752, 17978, 44, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[700821, 17982, 70, 1, 47, "Input"],
Cell[700894, 17985, 19321, 308, 296, 1010, 77, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[720264, 18299, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[720349, 18303, 55, 0, 43, "Subsubsection"],
Cell[720407, 18305, 159, 4, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[720603, 18314, 39, 0, 35, "Subsubsection"],
Cell[720645, 18316, 116, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[720798, 18323, 39, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[720862, 18327, 251, 5, 79, "Input"],
Cell[721116, 18334, 132744, 3228, 296, 38306, 2058, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[853921, 21569, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[854006, 21573, 46, 0, 43, "Subsubsection"],
Cell[854055, 21575, 147, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[854239, 21582, 43, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[854307, 21586, 91, 1, 47, "Input"],
Cell[854401, 21589, 479629, 11978, 333, 291472, 9652, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1334091, 33574, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1334167, 33578, 260, 5, 111, "Input"],
Cell[1334430, 33585, 51182, 1786, 199, 20478, 1404, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

